(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   3318752,     126182]
NotebookOptionsPosition[   3309192,     125862]
NotebookOutlinePosition[   3309696,     125882]
CellTagsIndexPosition[   3309653,     125879]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\<ElasticaBook/Packages\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.402069450654505*^9, 3.402069451919267*^9}}],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Creating expressions for symmetric 2 and 4 order tensors ", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SymIndex", "[", 
   RowBox[{"2", ",", " ", "dim_"}], "]"}], " ", ":=", 
  RowBox[{"Apply", "[", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Sort", "[", 
       RowBox[{"List", "[", "##", "]"}], "]"}], " ", "&"}], ")"}], ",", 
    RowBox[{"Array", "[", " ", 
     RowBox[{"List", ",", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"dim", " ", "&"}], ",", " ", "2"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", "2", "}"}]}], " ", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SymIndex", "[", 
  RowBox[{"2", ",", "3"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"SymIndex", "[", 
  RowBox[{"2", ",", "6"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "6"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "6"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "6"}], "}"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SymIndex", "[", "4", "]"}], " ", "=", "  ", 
  RowBox[{"Apply", "[", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"Flatten", "[", " ", 
      RowBox[{"Sort", "[", " ", 
       RowBox[{"Map", "[", " ", 
        RowBox[{"Sort", ",", 
         RowBox[{"Partition", "[", 
          RowBox[{
           RowBox[{"List", "[", "##", "]"}], ",", " ", "2"}], "]"}]}], "]"}], 
       "]"}], "]"}], " ", "&"}], ",", " ", 
    RowBox[{"Array", "[", " ", 
     RowBox[{"List", ",", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"3", " ", "&"}], ",", " ", "4"}], "]"}]}], "]"}], ",", " ", 
    RowBox[{"{", "4", "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "2", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "2", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "3", ",", "3"}], "}"}]}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "1", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "2", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "1", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "3", ",", "3"}], "}"}]}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "1", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "1", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "1", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "2", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "2", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "1", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "3", ",", "3"}], "}"}]}], "}"}]}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "1", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "2", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "1", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "3", ",", "3"}], "}"}]}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "2", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "2", ",", "2"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "2", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "3", ",", "3"}], "}"}]}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "2", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3", ",", "2", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3", ",", "3", ",", "3"}], "}"}]}], "}"}]}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "1", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "1", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "1", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "2", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "2", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "1", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "3", ",", "3"}], "}"}]}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "2", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3", ",", "2", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3", ",", "3", ",", "3"}], "}"}]}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "3", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "3", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "3", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "3", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2", ",", "3", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3", ",", "3", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "3", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3", ",", "3", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "3", ",", "3", ",", "3"}], "}"}]}], "}"}]}], 
      "}"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeName", "[", "myexp__", "]"}], " ", ":=", " ", 
  RowBox[{"ToExpression", " ", "//@", " ", 
   RowBox[{"(", 
    RowBox[{Cell[""], 
     RowBox[{"StringJoin", "  ", "@@", " ", 
      RowBox[{"Map", "[", "  ", 
       RowBox[{
        RowBox[{
         RowBox[{"ToString", "[", " ", "#", "]"}], " ", "&"}], ",", 
        RowBox[{"List", "[", " ", "myexp", "]"}]}], "]"}]}]}], 
    ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeTensor", "[", " ", 
   RowBox[{"mystring_", ",", " ", "2", ",", " ", "dim_"}], " ", "]"}], " ", ":=",
   " ", 
  RowBox[{"Apply", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"MakeName", "[", 
       RowBox[{"mystring", ",", " ", "##"}], "]"}], " ", "&"}], ")"}], ",", 
    " ", 
    RowBox[{"SymIndex", "[", 
     RowBox[{"2", ",", "dim"}], "]"}], ",", " ", 
    RowBox[{"{", "2", "}"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"MakeTensor", "[", " ", 
    RowBox[{"mystring_", ",", " ", "4"}], " ", "]"}], " ", ":=", " ", 
   RowBox[{"Apply", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"MakeName", "[", 
        RowBox[{"mystring", ",", " ", "##"}], "]"}], " ", "&"}], ")"}], ",", 
     " ", 
     RowBox[{"SymIndex", "[", "4", "]"}], ",", " ", 
     RowBox[{"{", "4", "}"}]}], "]"}]}], " "}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"stress", " ", "=", " ", 
    RowBox[{"MakeTensor", "[", 
     RowBox[{"\"\<sig\>\"", ",", " ", "2", ",", "3"}], "]"}]}], ")"}], " ", "//",
   " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"sig11", "sig12", "sig13"},
     {"sig12", "sig22", "sig23"},
     {"sig13", "sig23", "sig33"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"strain", " ", "=", " ", 
    RowBox[{"MakeTensor", "[", 
     RowBox[{"\"\<eps\>\"", ",", " ", "2", ",", " ", "3"}], "]"}]}], ")"}], 
  " ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"eps11", "eps12", "eps13"},
     {"eps12", "eps22", "eps23"},
     {"eps13", "eps23", "eps33"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"C4", " ", "=", " ", 
    RowBox[{"MakeTensor", "[", 
     RowBox[{"\"\<C\>\"", ",", " ", "4"}], "]"}]}], " ", ")"}], " ", "//", 
  " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1111", "C1112", "C1113"},
         {"C1112", "C1122", "C1123"},
         {"C1113", "C1123", "C1133"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1112", "C1212", "C1213"},
         {"C1212", "C1222", "C1223"},
         {"C1213", "C1223", "C1233"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1113", "C1213", "C1313"},
         {"C1213", "C1322", "C1323"},
         {"C1313", "C1323", "C1333"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1112", "C1212", "C1213"},
         {"C1212", "C1222", "C1223"},
         {"C1213", "C1223", "C1233"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1122", "C1222", "C1322"},
         {"C1222", "C2222", "C2223"},
         {"C1322", "C2223", "C2233"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1123", "C1223", "C1323"},
         {"C1223", "C2223", "C2323"},
         {"C1323", "C2323", "C2333"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1113", "C1213", "C1313"},
         {"C1213", "C1322", "C1323"},
         {"C1313", "C1323", "C1333"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1123", "C1223", "C1323"},
         {"C1223", "C2223", "C2323"},
         {"C1323", "C2323", "C2333"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1133", "C1233", "C1333"},
         {"C1233", "C2233", "C2333"},
         {"C1333", "C2333", "C3333"}
        }], "\[NoBreak]", ")"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{{{{C1111, C1112, C1113}, {C1112, C1122, C1123}, {
      C1113, C1123, C1133}}, {{C1112, C1212, C1213}, {C1212, C1222, C1223}, {
      C1213, C1223, C1233}}, {{C1113, C1213, C1313}, {C1213, C1322, C1323}, {
      C1313, C1323, C1333}}}, {{{C1112, C1212, C1213}, {
      C1212, C1222, C1223}, {C1213, C1223, C1233}}, {{C1122, C1222, C1322}, {
      C1222, C2222, C2223}, {C1322, C2223, C2233}}, {{C1123, C1223, C1323}, {
      C1223, C2223, C2323}, {C1323, C2323, C2333}}}, {{{
      C1113, C1213, C1313}, {C1213, C1322, C1323}, {C1313, C1323, C1333}}, {{
      C1123, C1223, C1323}, {C1223, C2223, C2323}, {C1323, C2323, C2333}}, {{
      C1133, C1233, C1333}, {C1233, C2233, C2333}, {
      C1333, C2333, C3333}}}}]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Hooke tensor - Passage from the 4 order to the 2 order tensor or 2 order \
Voigt form \
\>", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"indexrule2to1", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], " ", "\[Rule]", " ", "1"}], ",", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], " ", "\[Rule]", " ", "2"}], ",", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}], " ", "\[Rule]", " ", "3"}], ",", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], " ", "\[Rule]", " ", "4"}], " ", ",", 
    " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], " ", "\[Rule]", " ", "5"}], ",", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], " ", "\[Rule]", " ", "6"}], ",", "  ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "2"}], "}"}], " ", "\[Rule]", " ", "4"}], " ", ",", 
    " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], " ", "\[Rule]", " ", "5"}], ",", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], " ", "\[Rule]", " ", "6"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"indexrule1to2", " ", "=", " ", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Rule", "[", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
       RowBox[{"#", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], " ", "]"}], " ", "&"}], " ", ",", 
    "indexrule2to1"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "2"}], "}"}], "\[Rule]", "2"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "3"}], "}"}], "\[Rule]", "3"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}], "\[Rule]", "4"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "1"}], "}"}], "\[Rule]", "5"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", "6"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "2"}], "}"}], "\[Rule]", "4"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", "5"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", "6"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}]}], ",", 
   RowBox[{"2", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", ",", "2"}], "}"}]}], ",", 
   RowBox[{"3", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"3", ",", "3"}], "}"}]}], ",", 
   RowBox[{"4", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}]}], ",", 
   RowBox[{"5", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"3", ",", "1"}], "}"}]}], ",", 
   RowBox[{"6", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}]}], ",", 
   RowBox[{"4", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"3", ",", "2"}], "}"}]}], ",", 
   RowBox[{"5", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}]}], ",", 
   RowBox[{"6", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Index6", "[", "1", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"Range", "[", " ", "6", "]"}], " ", "/.", " ", 
   "indexrule1to2"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"HookeVto4", "[", " ", "myC_", "]"}], " ", ":=", " ", 
  RowBox[{"Array", "[", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"myC", "[", 
      RowBox[{"[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"#1", ",", " ", "#2"}], "}"}], " ", "/.", " ", 
         "indexrule2to1"}], ",", " ", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"#3", ",", " ", "#4"}], "}"}], " ", "/.", " ", 
         "indexrule2to1"}]}], "]"}], "]"}], "&"}], ",", " ", 
    RowBox[{"Array", "[", 
     RowBox[{
      RowBox[{"3", " ", "&"}], ",", " ", "4"}], "]"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C2", " ", "=", " ", 
    RowBox[{"MakeTensor", "[", 
     RowBox[{"\"\<C\>\"", ",", " ", "2", ",", " ", "6"}], "]"}]}], ")"}], " ",
   "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C11", "C12", "C13", "C14", "C15", "C16"},
     {"C12", "C22", "C23", "C24", "C25", "C26"},
     {"C13", "C23", "C33", "C34", "C35", "C36"},
     {"C14", "C24", "C34", "C44", "C45", "C46"},
     {"C15", "C25", "C35", "C45", "C55", "C56"},
     {"C16", "C26", "C36", "C46", "C56", "C66"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["C2"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "C11", ",", "C12", ",", "C13", ",", "C14", ",", "C15", ",", "C16"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "C12", ",", "C22", ",", "C23", ",", "C24", ",", "C25", ",", "C26"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "C13", ",", "C23", ",", "C33", ",", "C34", ",", "C35", ",", "C36"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "C14", ",", "C24", ",", "C34", ",", "C44", ",", "C45", ",", "C46"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "C15", ",", "C25", ",", "C35", ",", "C45", ",", "C55", ",", "C56"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "C16", ",", "C26", ",", "C36", ",", "C46", ",", "C56", ",", "C66"}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C2to4", " ", "=", " ", 
    RowBox[{"HookeVto4", "[", "C2", "]"}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C11", "C16", "C15"},
         {"C16", "C12", "C14"},
         {"C15", "C14", "C13"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C16", "C66", "C56"},
         {"C66", "C26", "C46"},
         {"C56", "C46", "C36"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C15", "C56", "C55"},
         {"C56", "C25", "C45"},
         {"C55", "C45", "C35"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C16", "C66", "C56"},
         {"C66", "C26", "C46"},
         {"C56", "C46", "C36"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C12", "C26", "C25"},
         {"C26", "C22", "C24"},
         {"C25", "C24", "C23"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C14", "C46", "C45"},
         {"C46", "C24", "C44"},
         {"C45", "C44", "C34"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C15", "C56", "C55"},
         {"C56", "C25", "C45"},
         {"C55", "C45", "C35"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C14", "C46", "C45"},
         {"C46", "C24", "C44"},
         {"C45", "C44", "C34"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C13", "C36", "C35"},
         {"C36", "C23", "C34"},
         {"C35", "C34", "C33"}
        }], "\[NoBreak]", ")"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{{{{C11, C16, C15}, {C16, C12, C14}, {C15, C14, C13}}, {{
      C16, C66, C56}, {C66, C26, C46}, {C56, C46, C36}}, {{C15, C56, C55}, {
      C56, C25, C45}, {C55, C45, C35}}}, {{{C16, C66, C56}, {C66, C26, C46}, {
      C56, C46, C36}}, {{C12, C26, C25}, {C26, C22, C24}, {C25, C24, C23}}, {{
      C14, C46, C45}, {C46, C24, C44}, {C45, C44, C34}}}, {{{C15, C56, C55}, {
      C56, C25, C45}, {C55, C45, C35}}, {{C14, C46, C45}, {C46, C24, C44}, {
      C45, C44, C34}}, {{C13, C36, C35}, {C36, C23, C34}, {
      C35, C34, C33}}}}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"C2to4", "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"C11", ",", "C16", ",", "C15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C16", ",", "C12", ",", "C14"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C15", ",", "C14", ",", "C13"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}]}], "}"}], ",",
    
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"C12", ",", "C26", ",", "C25"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C26", ",", "C22", ",", "C24"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C25", ",", "C24", ",", "C23"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}]}], "}"}], ",",
    
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"C13", ",", "C36", ",", "C35"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C36", ",", "C23", ",", "C34"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C35", ",", "C34", ",", "C33"}], "}"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hooke4toV", "[", " ", "myC_", "]"}], " ", ":=", 
  RowBox[{"Apply", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Part", "[", " ", 
      RowBox[{"myC", ",", " ", "##"}], "]"}], " ", "&"}], ",", " ", 
    RowBox[{"Array", "[", "   ", 
     RowBox[{
      RowBox[{
       RowBox[{"Join", "[", " ", 
        RowBox[{
         RowBox[{"#1", "  ", "/.", " ", "indexrule1to2"}], " ", ",", " ", 
         RowBox[{"#2", "/.", " ", "indexrule1to2"}]}], "]"}], " ", "&"}], ",",
       " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"6", " ", "&"}], ",", " ", "2"}], "]"}]}], "]"}], " ", ",", 
    " ", 
    RowBox[{"{", "2", "}"}]}], "]"}], " "}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C2back", " ", "=", " ", 
    RowBox[{"Hooke4toV", "[", "C2to4", "]"}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C11", "C12", "C13", "C14", "C15", "C16"},
     {"C12", "C22", "C23", "C24", "C25", "C26"},
     {"C13", "C23", "C33", "C34", "C35", "C36"},
     {"C14", "C24", "C34", "C44", "C45", "C46"},
     {"C15", "C25", "C35", "C45", "C55", "C56"},
     {"C16", "C26", "C36", "C46", "C56", "C66"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C4to2", " ", "=", " ", 
    RowBox[{"Hooke4toV", "[", "C4", "]"}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C1111", "C1122", "C1133", "C1123", "C1113", "C1112"},
     {"C1122", "C2222", "C2233", "C2223", "C1322", "C1222"},
     {"C1133", "C2233", "C3333", "C2333", "C1333", "C1233"},
     {"C1123", "C2223", "C2333", "C2323", "C1323", "C1223"},
     {"C1113", "C1322", "C1333", "C1323", "C1313", "C1213"},
     {"C1112", "C1222", "C1233", "C1223", "C1213", "C1212"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C4back", " ", "=", " ", 
    RowBox[{"HookeVto4", "[", "C4to2", "]"}]}], ")"}], "  ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1111", "C1112", "C1113"},
         {"C1112", "C1122", "C1123"},
         {"C1113", "C1123", "C1133"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1112", "C1212", "C1213"},
         {"C1212", "C1222", "C1223"},
         {"C1213", "C1223", "C1233"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1113", "C1213", "C1313"},
         {"C1213", "C1322", "C1323"},
         {"C1313", "C1323", "C1333"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1112", "C1212", "C1213"},
         {"C1212", "C1222", "C1223"},
         {"C1213", "C1223", "C1233"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1122", "C1222", "C1322"},
         {"C1222", "C2222", "C2223"},
         {"C1322", "C2223", "C2233"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1123", "C1223", "C1323"},
         {"C1223", "C2223", "C2323"},
         {"C1323", "C2323", "C2333"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1113", "C1213", "C1313"},
         {"C1213", "C1322", "C1323"},
         {"C1313", "C1323", "C1333"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1123", "C1223", "C1323"},
         {"C1223", "C2223", "C2323"},
         {"C1323", "C2323", "C2333"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1133", "C1233", "C1333"},
         {"C1233", "C2233", "C2333"},
         {"C1333", "C2333", "C3333"}
        }], "\[NoBreak]", ")"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{{{{C1111, C1112, C1113}, {C1112, C1122, C1123}, {
      C1113, C1123, C1133}}, {{C1112, C1212, C1213}, {C1212, C1222, C1223}, {
      C1213, C1223, C1233}}, {{C1113, C1213, C1313}, {C1213, C1322, C1323}, {
      C1313, C1323, C1333}}}, {{{C1112, C1212, C1213}, {
      C1212, C1222, C1223}, {C1213, C1223, C1233}}, {{C1122, C1222, C1322}, {
      C1222, C2222, C2223}, {C1322, C2223, C2233}}, {{C1123, C1223, C1323}, {
      C1223, C2223, C2323}, {C1323, C2323, C2333}}}, {{{
      C1113, C1213, C1313}, {C1213, C1322, C1323}, {C1313, C1323, C1333}}, {{
      C1123, C1223, C1323}, {C1223, C2223, C2323}, {C1323, C2323, C2333}}, {{
      C1133, C1233, C1333}, {C1233, C2233, C2333}, {
      C1333, C2333, C3333}}}}]]], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Hooke2toV", "[", "myc2_", "]"}], ":=", " ", 
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Which", "[", "    ", "\[IndentingNewLine]", "  ", 
      RowBox[{
       RowBox[{
        RowBox[{"i", " ", "\[LessEqual]", " ", "3"}], " ", "&&", " ", 
        RowBox[{"j", " ", "\[LessEqual]", " ", "3"}]}], " ", ",", " ", 
       RowBox[{"myc2", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", "  ", 
       "\[IndentingNewLine]", "  ", 
       RowBox[{
        RowBox[{"4", " ", "\[LessEqual]", " ", "i"}], " ", "&&", " ", 
        RowBox[{"j", " ", "\[LessEqual]", " ", "3"}]}], " ", ",", " ", 
       RowBox[{
        RowBox[{"myc2", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", "/", " ", 
        RowBox[{"2", "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}]}], ",", "  ", 
       "\[IndentingNewLine]", "  ", 
       RowBox[{
        RowBox[{"i", " ", "\[LessEqual]", " ", "3"}], " ", "&&", " ", 
        RowBox[{"4", " ", "\[LessEqual]", " ", "j"}]}], " ", ",", " ", 
       RowBox[{
        RowBox[{"myc2", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "/", " ", 
        RowBox[{"2", "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}]}], ",", "  ", 
       "\[IndentingNewLine]", "  ", 
       RowBox[{
        RowBox[{"4", " ", "\[LessEqual]", " ", "i"}], " ", "&&", " ", 
        RowBox[{"4", " ", "\[LessEqual]", " ", "j"}]}], " ", ",", " ", 
       RowBox[{
        RowBox[{"myc2", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "/", " ", "2"}]}], 
      "\[IndentingNewLine]", "       ", "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "6"}], "}"}]}], "]"}]}], " ", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"HookeVto2", "[", "mycV_", "]"}], ":=", " ", 
   RowBox[{"Table", "[", " ", "\[IndentingNewLine]", "   ", 
    RowBox[{
     RowBox[{"Which", "[", "    ", "\[IndentingNewLine]", "  ", 
      RowBox[{
       RowBox[{
        RowBox[{"i", " ", "\[LessEqual]", " ", "3"}], " ", "&&", " ", 
        RowBox[{"j", " ", "\[LessEqual]", " ", "3"}]}], " ", ",", 
       RowBox[{"mycV", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", " ", "j"}], "]"}], "]"}], ",", "  ", 
       "\[IndentingNewLine]", "  ", 
       RowBox[{
        RowBox[{"4", " ", "\[LessEqual]", " ", "i"}], " ", "&&", " ", 
        RowBox[{"j", " ", "\[LessEqual]", " ", "3"}]}], " ", ",", 
       RowBox[{
        RowBox[{"mycV", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", "*", " ", 
        RowBox[{"2", "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}]}], ",", "  ", 
       "\[IndentingNewLine]", "  ", 
       RowBox[{
        RowBox[{"i", " ", "\[LessEqual]", " ", "3"}], " ", "&&", " ", 
        RowBox[{"4", " ", "\[LessEqual]", " ", "j"}]}], " ", ",", 
       RowBox[{
        RowBox[{"mycV", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", "*", 
        RowBox[{"2", "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}]}], ",", "  ", 
       "\[IndentingNewLine]", "  ", 
       RowBox[{
        RowBox[{"4", " ", "\[LessEqual]", " ", "i"}], " ", "&&", " ", 
        RowBox[{"4", " ", "\[LessEqual]", " ", "j"}]}], " ", ",", 
       RowBox[{
        RowBox[{"mycV", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", "*", " ", "2"}]}], 
      "\[IndentingNewLine]", "       ", "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "6"}], "}"}]}], "]"}]}], " ", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Hooke4to2", "[", "myC_", "]"}], " ", ":=", " ", 
  RowBox[{"HookeVto2", "[", 
   RowBox[{"Hooke4toV", "[", " ", "myC", " ", "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Hooke2to4", "[", "myC_", "]"}], " ", ":=", " ", 
   RowBox[{"HookeVto4", "[", 
    RowBox[{"Hooke2toV", "[", " ", "myC", " ", "]"}], "]"}]}], 
  "\[IndentingNewLine]"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"CV", " ", "=", " ", 
    RowBox[{"Hooke2toV", "[", " ", "C2", " ", "]"}]}], " ", ")"}], " ", "//", 
  " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C11", "C12", "C13", 
      FractionBox["C14", 
       SqrtBox["2"]], 
      FractionBox["C15", 
       SqrtBox["2"]], 
      FractionBox["C16", 
       SqrtBox["2"]]},
     {"C12", "C22", "C23", 
      FractionBox["C24", 
       SqrtBox["2"]], 
      FractionBox["C25", 
       SqrtBox["2"]], 
      FractionBox["C26", 
       SqrtBox["2"]]},
     {"C13", "C23", "C33", 
      FractionBox["C34", 
       SqrtBox["2"]], 
      FractionBox["C35", 
       SqrtBox["2"]], 
      FractionBox["C36", 
       SqrtBox["2"]]},
     {
      FractionBox["C14", 
       SqrtBox["2"]], 
      FractionBox["C24", 
       SqrtBox["2"]], 
      FractionBox["C34", 
       SqrtBox["2"]], 
      FractionBox["C44", "2"], 
      FractionBox["C45", "2"], 
      FractionBox["C46", "2"]},
     {
      FractionBox["C15", 
       SqrtBox["2"]], 
      FractionBox["C25", 
       SqrtBox["2"]], 
      FractionBox["C35", 
       SqrtBox["2"]], 
      FractionBox["C45", "2"], 
      FractionBox["C55", "2"], 
      FractionBox["C56", "2"]},
     {
      FractionBox["C16", 
       SqrtBox["2"]], 
      FractionBox["C26", 
       SqrtBox["2"]], 
      FractionBox["C36", 
       SqrtBox["2"]], 
      FractionBox["C46", "2"], 
      FractionBox["C56", "2"], 
      FractionBox["C66", "2"]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C2back", " ", "=", " ", 
    RowBox[{"HookeVto2", "[", " ", "CV", " ", "]"}]}], " ", ")"}], " ", "//", 
  " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C11", "C12", "C13", "C14", "C15", "C16"},
     {"C12", "C22", "C23", "C24", "C25", "C26"},
     {"C13", "C23", "C33", "C34", "C35", "C36"},
     {"C14", "C24", "C34", "C44", "C45", "C46"},
     {"C15", "C25", "C35", "C45", "C55", "C56"},
     {"C16", "C26", "C36", "C46", "C56", "C66"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"CV", " ", "=", " ", 
    RowBox[{"Hooke4to2", "[", "C4", "]"}]}], ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C1111", "C1122", "C1133", 
      RowBox[{
       SqrtBox["2"], " ", "C1123"}], 
      RowBox[{
       SqrtBox["2"], " ", "C1113"}], 
      RowBox[{
       SqrtBox["2"], " ", "C1112"}]},
     {"C1122", "C2222", "C2233", 
      RowBox[{
       SqrtBox["2"], " ", "C2223"}], 
      RowBox[{
       SqrtBox["2"], " ", "C1322"}], 
      RowBox[{
       SqrtBox["2"], " ", "C1222"}]},
     {"C1133", "C2233", "C3333", 
      RowBox[{
       SqrtBox["2"], " ", "C2333"}], 
      RowBox[{
       SqrtBox["2"], " ", "C1333"}], 
      RowBox[{
       SqrtBox["2"], " ", "C1233"}]},
     {
      RowBox[{
       SqrtBox["2"], " ", "C1123"}], 
      RowBox[{
       SqrtBox["2"], " ", "C2223"}], 
      RowBox[{
       SqrtBox["2"], " ", "C2333"}], 
      RowBox[{"2", " ", "C2323"}], 
      RowBox[{"2", " ", "C1323"}], 
      RowBox[{"2", " ", "C1223"}]},
     {
      RowBox[{
       SqrtBox["2"], " ", "C1113"}], 
      RowBox[{
       SqrtBox["2"], " ", "C1322"}], 
      RowBox[{
       SqrtBox["2"], " ", "C1333"}], 
      RowBox[{"2", " ", "C1323"}], 
      RowBox[{"2", " ", "C1313"}], 
      RowBox[{"2", " ", "C1213"}]},
     {
      RowBox[{
       SqrtBox["2"], " ", "C1112"}], 
      RowBox[{
       SqrtBox["2"], " ", "C1222"}], 
      RowBox[{
       SqrtBox["2"], " ", "C1233"}], 
      RowBox[{"2", " ", "C1223"}], 
      RowBox[{"2", " ", "C1213"}], 
      RowBox[{"2", " ", "C1212"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C4back", "=", " ", 
    RowBox[{"Hooke2to4", "[", "CV", "]"}]}], ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1111", "C1112", "C1113"},
         {"C1112", "C1122", "C1123"},
         {"C1113", "C1123", "C1133"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1112", "C1212", "C1213"},
         {"C1212", "C1222", "C1223"},
         {"C1213", "C1223", "C1233"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1113", "C1213", "C1313"},
         {"C1213", "C1322", "C1323"},
         {"C1313", "C1323", "C1333"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1112", "C1212", "C1213"},
         {"C1212", "C1222", "C1223"},
         {"C1213", "C1223", "C1233"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1122", "C1222", "C1322"},
         {"C1222", "C2222", "C2223"},
         {"C1322", "C2223", "C2233"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1123", "C1223", "C1323"},
         {"C1223", "C2223", "C2323"},
         {"C1323", "C2323", "C2333"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1113", "C1213", "C1313"},
         {"C1213", "C1322", "C1323"},
         {"C1313", "C1323", "C1333"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1123", "C1223", "C1323"},
         {"C1223", "C2223", "C2323"},
         {"C1323", "C2323", "C2333"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C1133", "C1233", "C1333"},
         {"C1233", "C2233", "C2333"},
         {"C1333", "C2333", "C3333"}
        }], "\[NoBreak]", ")"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{{{{C1111, C1112, C1113}, {C1112, C1122, C1123}, {
      C1113, C1123, C1133}}, {{C1112, C1212, C1213}, {C1212, C1222, C1223}, {
      C1213, C1223, C1233}}, {{C1113, C1213, C1313}, {C1213, C1322, C1323}, {
      C1313, C1323, C1333}}}, {{{C1112, C1212, C1213}, {
      C1212, C1222, C1223}, {C1213, C1223, C1233}}, {{C1122, C1222, C1322}, {
      C1222, C2222, C2223}, {C1322, C2223, C2233}}, {{C1123, C1223, C1323}, {
      C1223, C2223, C2323}, {C1323, C2323, C2333}}}, {{{
      C1113, C1213, C1313}, {C1213, C1322, C1323}, {C1313, C1323, C1333}}, {{
      C1123, C1223, C1323}, {C1223, C2223, C2323}, {C1323, C2323, C2333}}, {{
      C1133, C1233, C1333}, {C1233, C2233, C2333}, {
      C1333, C2333, C3333}}}}]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Compliance tensor - Passage from the 4 order to the 2 order tensor or 2 order \
Voigt form \
\>", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"S4", " ", "=", " ", 
    RowBox[{"MakeTensor", "[", 
     RowBox[{"\"\<S\>\"", ",", " ", "4"}], "]"}]}], " ", ")"}], " ", "//", 
  " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"S1111", "S1112", "S1113"},
         {"S1112", "S1122", "S1123"},
         {"S1113", "S1123", "S1133"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"S1112", "S1212", "S1213"},
         {"S1212", "S1222", "S1223"},
         {"S1213", "S1223", "S1233"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"S1113", "S1213", "S1313"},
         {"S1213", "S1322", "S1323"},
         {"S1313", "S1323", "S1333"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"S1112", "S1212", "S1213"},
         {"S1212", "S1222", "S1223"},
         {"S1213", "S1223", "S1233"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"S1122", "S1222", "S1322"},
         {"S1222", "S2222", "S2223"},
         {"S1322", "S2223", "S2233"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"S1123", "S1223", "S1323"},
         {"S1223", "S2223", "S2323"},
         {"S1323", "S2323", "S2333"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"S1113", "S1213", "S1313"},
         {"S1213", "S1322", "S1323"},
         {"S1313", "S1323", "S1333"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"S1123", "S1223", "S1323"},
         {"S1223", "S2223", "S2323"},
         {"S1323", "S2323", "S2333"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"S1133", "S1233", "S1333"},
         {"S1233", "S2233", "S2333"},
         {"S1333", "S2333", "S3333"}
        }], "\[NoBreak]", ")"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{{{{S1111, S1112, S1113}, {S1112, S1122, S1123}, {
      S1113, S1123, S1133}}, {{S1112, S1212, S1213}, {S1212, S1222, S1223}, {
      S1213, S1223, S1233}}, {{S1113, S1213, S1313}, {S1213, S1322, S1323}, {
      S1313, S1323, S1333}}}, {{{S1112, S1212, S1213}, {
      S1212, S1222, S1223}, {S1213, S1223, S1233}}, {{S1122, S1222, S1322}, {
      S1222, S2222, S2223}, {S1322, S2223, S2233}}, {{S1123, S1223, S1323}, {
      S1223, S2223, S2323}, {S1323, S2323, S2333}}}, {{{
      S1113, S1213, S1313}, {S1213, S1322, S1323}, {S1313, S1323, S1333}}, {{
      S1123, S1223, S1323}, {S1223, S2223, S2323}, {S1323, S2323, S2333}}, {{
      S1133, S1233, S1333}, {S1233, S2233, S2333}, {
      S1333, S2333, S3333}}}}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"SV", " ", "=", " ", 
    RowBox[{"MakeTensor", "[", 
     RowBox[{"\"\<SV\>\"", ",", " ", "2", ",", " ", "6"}], "]"}]}], " ", 
   ")"}], " ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"SV11", "SV12", "SV13", "SV14", "SV15", "SV16"},
     {"SV12", "SV22", "SV23", "SV24", "SV25", "SV26"},
     {"SV13", "SV23", "SV33", "SV34", "SV35", "SV36"},
     {"SV14", "SV24", "SV34", "SV44", "SV45", "SV46"},
     {"SV15", "SV25", "SV35", "SV45", "SV55", "SV56"},
     {"SV16", "SV26", "SV36", "SV46", "SV56", "SV66"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Compliance2toV", "[", "mys2_", "]"}], ":=", " ", 
  RowBox[{"Hooke2toV", "[", "mys2", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ComplianceVto2", "[", "mys2_", "]"}], ":=", " ", 
  RowBox[{"HookeVto2", "[", "mys2", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Compliance4toV", "[", "myS4_", "]"}], ":=", " ", 
  RowBox[{"ComplianceVto2", "[", " ", 
   RowBox[{"ComplianceVto2", "[", " ", 
    RowBox[{"Hooke4toV", "[", " ", "myS4", " ", "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ComplianceVto4", "[", "mysV_", "]"}], ":=", " ", 
   RowBox[{"HookeVto4", "[", " ", 
    RowBox[{"Compliance2toV", "[", " ", 
     RowBox[{"Compliance2toV", "[", " ", "mysV", "]"}], "]"}], " ", "]"}]}], 
  "\[IndentingNewLine]"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hooke4toV", "[", " ", 
   RowBox[{"ComplianceVto4", "[", " ", "SV", "]"}], "]"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"SV11", "SV12", "SV13", 
      FractionBox["SV14", "2"], 
      FractionBox["SV15", "2"], 
      FractionBox["SV16", "2"]},
     {"SV12", "SV22", "SV23", 
      FractionBox["SV24", "2"], 
      FractionBox["SV25", "2"], 
      FractionBox["SV26", "2"]},
     {"SV13", "SV23", "SV33", 
      FractionBox["SV34", "2"], 
      FractionBox["SV35", "2"], 
      FractionBox["SV36", "2"]},
     {
      FractionBox["SV14", "2"], 
      FractionBox["SV24", "2"], 
      FractionBox["SV34", "2"], 
      FractionBox["SV44", "4"], 
      FractionBox["SV45", "4"], 
      FractionBox["SV46", "4"]},
     {
      FractionBox["SV15", "2"], 
      FractionBox["SV25", "2"], 
      FractionBox["SV35", "2"], 
      FractionBox["SV45", "4"], 
      FractionBox["SV55", "4"], 
      FractionBox["SV56", "4"]},
     {
      FractionBox["SV16", "2"], 
      FractionBox["SV26", "2"], 
      FractionBox["SV36", "2"], 
      FractionBox["SV46", "4"], 
      FractionBox["SV56", "4"], 
      FractionBox["SV66", "4"]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"ComplianceVto2", "[", " ", "SV", "]"}], " ", "//", " ", 
   "MatrixForm"}]}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"SV11", "SV12", "SV13", 
      RowBox[{
       SqrtBox["2"], " ", "SV14"}], 
      RowBox[{
       SqrtBox["2"], " ", "SV15"}], 
      RowBox[{
       SqrtBox["2"], " ", "SV16"}]},
     {"SV12", "SV22", "SV23", 
      RowBox[{
       SqrtBox["2"], " ", "SV24"}], 
      RowBox[{
       SqrtBox["2"], " ", "SV25"}], 
      RowBox[{
       SqrtBox["2"], " ", "SV26"}]},
     {"SV13", "SV23", "SV33", 
      RowBox[{
       SqrtBox["2"], " ", "SV34"}], 
      RowBox[{
       SqrtBox["2"], " ", "SV35"}], 
      RowBox[{
       SqrtBox["2"], " ", "SV36"}]},
     {
      RowBox[{
       SqrtBox["2"], " ", "SV14"}], 
      RowBox[{
       SqrtBox["2"], " ", "SV24"}], 
      RowBox[{
       SqrtBox["2"], " ", "SV34"}], 
      RowBox[{"2", " ", "SV44"}], 
      RowBox[{"2", " ", "SV45"}], 
      RowBox[{"2", " ", "SV46"}]},
     {
      RowBox[{
       SqrtBox["2"], " ", "SV15"}], 
      RowBox[{
       SqrtBox["2"], " ", "SV25"}], 
      RowBox[{
       SqrtBox["2"], " ", "SV35"}], 
      RowBox[{"2", " ", "SV45"}], 
      RowBox[{"2", " ", "SV55"}], 
      RowBox[{"2", " ", "SV56"}]},
     {
      RowBox[{
       SqrtBox["2"], " ", "SV16"}], 
      RowBox[{
       SqrtBox["2"], " ", "SV26"}], 
      RowBox[{
       SqrtBox["2"], " ", "SV36"}], 
      RowBox[{"2", " ", "SV46"}], 
      RowBox[{"2", " ", "SV56"}], 
      RowBox[{"2", " ", "SV66"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Some computations with the constitutive law", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CEDot", "[", 
     RowBox[{"Ctensor_", ",", " ", "straintensor_"}], " ", "]"}], " ", ":=", 
    " ", 
    RowBox[{"GTr", "[", " ", 
     RowBox[{
      RowBox[{"GDot", "[", 
       RowBox[{"Ctensor", ",", "straintensor", ",", "4", ",", "1"}], "]"}], 
      ",", "3", ",", "4"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ECDot", "[", 
     RowBox[{"Ctensor_", ",", " ", "straintensor_"}], " ", "]"}], " ", ":=", 
    " ", 
    RowBox[{"GTr", "[", " ", 
     RowBox[{
      RowBox[{"GDot", "[", 
       RowBox[{"Ctensor", ",", "straintensor", ",", "4", ",", "1"}], "]"}], 
      ",", "3", ",", "4"}], "]"}]}]}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(GDot\\)\
\\\" is similar to existing symbol \\\"\\!\\(Dot\\)\\\".\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(ECDot\\)\\\" is similar to existing symbol \
\\\"\\!\\(CEDot\\)\\\".\"\>"}]], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"sigma", " ", "=", " ", 
    RowBox[{"CEDot", "[", 
     RowBox[{"C4", ",", " ", "strain"}], "]"}]}], " ", ")"}], "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"GTr", "[", 
   RowBox[{
    RowBox[{"GDot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1111", ",", "C1112", ",", "C1113"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1112", ",", "C1122", ",", "C1123"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1113", ",", "C1123", ",", "C1133"}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1112", ",", "C1212", ",", "C1213"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1212", ",", "C1222", ",", "C1223"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1213", ",", "C1223", ",", "C1233"}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1113", ",", "C1213", ",", "C1313"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1213", ",", "C1322", ",", "C1323"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1313", ",", "C1323", ",", "C1333"}], "}"}]}], "}"}]}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1112", ",", "C1212", ",", "C1213"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1212", ",", "C1222", ",", "C1223"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1213", ",", "C1223", ",", "C1233"}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1122", ",", "C1222", ",", "C1322"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1222", ",", "C2222", ",", "C2223"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1322", ",", "C2223", ",", "C2233"}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1123", ",", "C1223", ",", "C1323"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1223", ",", "C2223", ",", "C2323"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1323", ",", "C2323", ",", "C2333"}], "}"}]}], "}"}]}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1113", ",", "C1213", ",", "C1313"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1213", ",", "C1322", ",", "C1323"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1313", ",", "C1323", ",", "C1333"}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1123", ",", "C1223", ",", "C1323"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1223", ",", "C2223", ",", "C2323"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1323", ",", "C2323", ",", "C2333"}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1133", ",", "C1233", ",", "C1333"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1233", ",", "C2233", ",", "C2333"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1333", ",", "C2333", ",", "C3333"}], "}"}]}], "}"}]}], 
         "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"eps11", ",", "eps12", ",", "eps13"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"eps12", ",", "eps22", ",", "eps23"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"eps13", ",", "eps23", ",", "eps33"}], "}"}]}], "}"}], ",", 
      "4", ",", "1"}], "]"}], ",", "3", ",", "4"}], "]"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check symmetry of the Hooke tensor C_ijkl = C_klij !", "Subsubsection",
 FontFamily->"Arial"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"sigma", " ", "=", " ", 
    RowBox[{"ECDot", "[", 
     RowBox[{"C4", ",", " ", "strain"}], "]"}]}], " ", ")"}], "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"GTr", "[", 
   RowBox[{
    RowBox[{"GDot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1111", ",", "C1112", ",", "C1113"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1112", ",", "C1122", ",", "C1123"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1113", ",", "C1123", ",", "C1133"}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1112", ",", "C1212", ",", "C1213"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1212", ",", "C1222", ",", "C1223"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1213", ",", "C1223", ",", "C1233"}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1113", ",", "C1213", ",", "C1313"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1213", ",", "C1322", ",", "C1323"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1313", ",", "C1323", ",", "C1333"}], "}"}]}], "}"}]}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1112", ",", "C1212", ",", "C1213"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1212", ",", "C1222", ",", "C1223"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1213", ",", "C1223", ",", "C1233"}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1122", ",", "C1222", ",", "C1322"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1222", ",", "C2222", ",", "C2223"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1322", ",", "C2223", ",", "C2233"}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1123", ",", "C1223", ",", "C1323"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1223", ",", "C2223", ",", "C2323"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1323", ",", "C2323", ",", "C2333"}], "}"}]}], "}"}]}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1113", ",", "C1213", ",", "C1313"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1213", ",", "C1322", ",", "C1323"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1313", ",", "C1323", ",", "C1333"}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1123", ",", "C1223", ",", "C1323"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1223", ",", "C2223", ",", "C2323"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1323", ",", "C2323", ",", "C2333"}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"C1133", ",", "C1233", ",", "C1333"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1233", ",", "C2233", ",", "C2333"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"C1333", ",", "C2333", ",", "C3333"}], "}"}]}], "}"}]}], 
         "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"eps11", ",", "eps12", ",", "eps13"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"eps12", ",", "eps22", ",", "eps23"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"eps13", ",", "eps23", ",", "eps33"}], "}"}]}], "}"}], ",", 
      "4", ",", "1"}], "]"}], ",", "3", ",", "4"}], "]"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check symmetry of the computed stress  tensor !", "Subsubsection",
 FontFamily->"Arial"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"sigma", " ", "-", " ", 
    RowBox[{"Transpose", "[", "sigma", "]"}]}], "]"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{
   RowBox[{"GTr", "[", 
    RowBox[{
     RowBox[{"GDot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"C1111", ",", "C1112", ",", "C1113"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1112", ",", "C1122", ",", "C1123"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1113", ",", "C1123", ",", "C1133"}], "}"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"C1112", ",", "C1212", ",", "C1213"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1212", ",", "C1222", ",", "C1223"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1213", ",", "C1223", ",", "C1233"}], "}"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"C1113", ",", "C1213", ",", "C1313"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1213", ",", "C1322", ",", "C1323"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1313", ",", "C1323", ",", "C1333"}], "}"}]}], "}"}]}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"C1112", ",", "C1212", ",", "C1213"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1212", ",", "C1222", ",", "C1223"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1213", ",", "C1223", ",", "C1233"}], "}"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"C1122", ",", "C1222", ",", "C1322"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1222", ",", "C2222", ",", "C2223"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1322", ",", "C2223", ",", "C2233"}], "}"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"C1123", ",", "C1223", ",", "C1323"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1223", ",", "C2223", ",", "C2323"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1323", ",", "C2323", ",", "C2333"}], "}"}]}], "}"}]}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"C1113", ",", "C1213", ",", "C1313"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1213", ",", "C1322", ",", "C1323"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1313", ",", "C1323", ",", "C1333"}], "}"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"C1123", ",", "C1223", ",", "C1323"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1223", ",", "C2223", ",", "C2323"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1323", ",", "C2323", ",", "C2333"}], "}"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"C1133", ",", "C1233", ",", "C1333"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1233", ",", "C2233", ",", "C2333"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"C1333", ",", "C2333", ",", "C3333"}], "}"}]}], "}"}]}],
           "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"eps11", ",", "eps12", ",", "eps13"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"eps12", ",", "eps22", ",", "eps23"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"eps13", ",", "eps23", ",", "eps33"}], "}"}]}], "}"}], ",", 
       "4", ",", "1"}], "]"}], ",", "3", ",", "4"}], "]"}], "-", 
   RowBox[{"Transpose", "[", 
    RowBox[{"GTr", "[", 
     RowBox[{
      RowBox[{"GDot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"C1111", ",", "C1112", ",", "C1113"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1112", ",", "C1122", ",", "C1123"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1113", ",", "C1123", ",", "C1133"}], "}"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"C1112", ",", "C1212", ",", "C1213"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1212", ",", "C1222", ",", "C1223"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1213", ",", "C1223", ",", "C1233"}], "}"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"C1113", ",", "C1213", ",", "C1313"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1213", ",", "C1322", ",", "C1323"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1313", ",", "C1323", ",", "C1333"}], "}"}]}], 
             "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"C1112", ",", "C1212", ",", "C1213"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1212", ",", "C1222", ",", "C1223"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1213", ",", "C1223", ",", "C1233"}], "}"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"C1122", ",", "C1222", ",", "C1322"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1222", ",", "C2222", ",", "C2223"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1322", ",", "C2223", ",", "C2233"}], "}"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"C1123", ",", "C1223", ",", "C1323"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1223", ",", "C2223", ",", "C2323"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1323", ",", "C2323", ",", "C2333"}], "}"}]}], 
             "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"C1113", ",", "C1213", ",", "C1313"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1213", ",", "C1322", ",", "C1323"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1313", ",", "C1323", ",", "C1333"}], "}"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"C1123", ",", "C1223", ",", "C1323"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1223", ",", "C2223", ",", "C2323"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1323", ",", "C2323", ",", "C2333"}], "}"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"C1133", ",", "C1233", ",", "C1333"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1233", ",", "C2233", ",", "C2333"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"C1333", ",", "C2333", ",", "C3333"}], "}"}]}], 
             "}"}]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"eps11", ",", "eps12", ",", "eps13"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"eps12", ",", "eps22", ",", "eps23"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"eps13", ",", "eps23", ",", "eps33"}], "}"}]}], "}"}], ",",
         "4", ",", "1"}], "]"}], ",", "3", ",", "4"}], "]"}], "]"}]}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Material Symmetry ", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "C11", ",", "C12", ",", "C13", ",", "C14", ",", "C15", ",", "C16", ",", 
   "C22", ",", "C23", ",", "C24", ",", "C25", ",", "C26", ",", "C33", ",", 
   "C34", ",", "C35", ",", "C36", ",", "C44", ",", "C45", ",", "C46", ",", 
   "C55", ",", "C56", ",", "C66"}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "C11", ",", "C12", ",", "C13", ",", "C14", ",", "C15", ",", "C16", ",", 
   "C22", ",", "C23", ",", "C24", ",", "C25", ",", "C26", ",", "C33", ",", 
   "C34", ",", "C35", ",", "C36", ",", "C44", ",", "C45", ",", "C46", ",", 
   "C55", ",", "C56", ",", "C66"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"monoclinice2", " ", "=", " ", 
  RowBox[{"Thread", "[", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "C14", ",", "C16", ",", "C24", ",", "C26", ",", "C34", ",", "C36", ",", 
      "C45", ",", "C56"}], "}"}], " ", "\[Rule]", " ", "0"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"monoclinice3", " ", "=", " ", 
  RowBox[{"Thread", "[", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "C14", ",", "C16", ",", "C24", ",", "C25", ",", "C34", ",", "C35", ",", 
      "C45", ",", "C56"}], "}"}], " ", "\[Rule]", " ", "0"}], 
   "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"C14", "\[Rule]", "0"}], ",", 
   RowBox[{"C16", "\[Rule]", "0"}], ",", 
   RowBox[{"C24", "\[Rule]", "0"}], ",", 
   RowBox[{"C26", "\[Rule]", "0"}], ",", 
   RowBox[{"C34", "\[Rule]", "0"}], ",", 
   RowBox[{"C36", "\[Rule]", "0"}], ",", 
   RowBox[{"C45", "\[Rule]", "0"}], ",", 
   RowBox[{"C56", "\[Rule]", "0"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"C14", "\[Rule]", "0"}], ",", 
   RowBox[{"C16", "\[Rule]", "0"}], ",", 
   RowBox[{"C24", "\[Rule]", "0"}], ",", 
   RowBox[{"C25", "\[Rule]", "0"}], ",", 
   RowBox[{"C34", "\[Rule]", "0"}], ",", 
   RowBox[{"C35", "\[Rule]", "0"}], ",", 
   RowBox[{"C45", "\[Rule]", "0"}], ",", 
   RowBox[{"C56", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C2", " ", "/.", " ", "monoclinice2"}], ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C11", "C12", "C13", "0", "C15", "0"},
     {"C12", "C22", "C23", "0", "C25", "0"},
     {"C13", "C23", "C33", "0", "C35", "0"},
     {"0", "0", "0", "C44", "0", "C46"},
     {"C15", "C25", "C35", "0", "C55", "0"},
     {"0", "0", "0", "C46", "0", "C66"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tetragonal", " ", "=", " ", 
  RowBox[{"Join", "[", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Thread", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "C14", ",", "C15", ",", "C16", ",", "C24", ",", "C25", ",", "C26", ",",
         "C34", ",", "C35", ",", "C36", ",", "C45", ",", "C46", ",", "C56"}], 
       "}"}], " ", "\[Rule]", " ", "0"}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"C22", " ", "\[Rule]", " ", "C11"}], ",", 
      RowBox[{"C23", "\[Rule]", " ", "C13"}], ",", " ", 
      RowBox[{"C55", " ", "\[Rule]", " ", "C44"}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"C14", "\[Rule]", "0"}], ",", 
   RowBox[{"C15", "\[Rule]", "0"}], ",", 
   RowBox[{"C16", "\[Rule]", "0"}], ",", 
   RowBox[{"C24", "\[Rule]", "0"}], ",", 
   RowBox[{"C25", "\[Rule]", "0"}], ",", 
   RowBox[{"C26", "\[Rule]", "0"}], ",", 
   RowBox[{"C34", "\[Rule]", "0"}], ",", 
   RowBox[{"C35", "\[Rule]", "0"}], ",", 
   RowBox[{"C36", "\[Rule]", "0"}], ",", 
   RowBox[{"C45", "\[Rule]", "0"}], ",", 
   RowBox[{"C46", "\[Rule]", "0"}], ",", 
   RowBox[{"C56", "\[Rule]", "0"}], ",", 
   RowBox[{"C22", "\[Rule]", "C11"}], ",", 
   RowBox[{"C23", "\[Rule]", "C13"}], ",", 
   RowBox[{"C55", "\[Rule]", "C44"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C2", " ", "/.", " ", "tetragonal"}], ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C11", "C12", "C13", "0", "0", "0"},
     {"C12", "C11", "C13", "0", "0", "0"},
     {"C13", "C13", "C33", "0", "0", "0"},
     {"0", "0", "0", "C44", "0", "0"},
     {"0", "0", "0", "0", "C44", "0"},
     {"0", "0", "0", "0", "0", "C66"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"trigonal", " ", "=", " ", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"Thread", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "C14", ",", "C16", ",", "C24", ",", "C26", ",", "C34", ",", "C35", ",",
         "C36", ",", "C45", ",", "C56"}], "}"}], " ", "\[Rule]", " ", "0"}], 
     "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"C25", " ", "\[Rule]", " ", 
       RowBox[{"-", " ", "C15"}]}], ",", " ", 
      RowBox[{"C22", " ", "\[Rule]", " ", "C11"}], ",", " ", 
      RowBox[{"C23", " ", "\[Rule]", " ", "C13"}], ",", 
      RowBox[{"C46", "\[Rule]", " ", 
       RowBox[{"-", "C15"}]}], ",", " ", 
      RowBox[{"C55", " ", "\[Rule]", " ", "C44"}], ",", " ", 
      RowBox[{"C66", "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", " ", "-", "C12"}], ")"}], "/", "2"}]}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"C14", "\[Rule]", "0"}], ",", 
   RowBox[{"C16", "\[Rule]", "0"}], ",", 
   RowBox[{"C24", "\[Rule]", "0"}], ",", 
   RowBox[{"C26", "\[Rule]", "0"}], ",", 
   RowBox[{"C34", "\[Rule]", "0"}], ",", 
   RowBox[{"C35", "\[Rule]", "0"}], ",", 
   RowBox[{"C36", "\[Rule]", "0"}], ",", 
   RowBox[{"C45", "\[Rule]", "0"}], ",", 
   RowBox[{"C56", "\[Rule]", "0"}], ",", 
   RowBox[{"C25", "\[Rule]", 
    RowBox[{"-", "C15"}]}], ",", 
   RowBox[{"C22", "\[Rule]", "C11"}], ",", 
   RowBox[{"C23", "\[Rule]", "C13"}], ",", 
   RowBox[{"C46", "\[Rule]", 
    RowBox[{"-", "C15"}]}], ",", 
   RowBox[{"C55", "\[Rule]", "C44"}], ",", 
   RowBox[{"C66", "\[Rule]", 
    FractionBox[
     RowBox[{"C11", "-", "C12"}], "2"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C2", " ", "/.", " ", "trigonal"}], ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C11", "C12", "C13", "0", "C15", "0"},
     {"C12", "C11", "C13", "0", 
      RowBox[{"-", "C15"}], "0"},
     {"C13", "C13", "C33", "0", "0", "0"},
     {"0", "0", "0", "C44", "0", 
      RowBox[{"-", "C15"}]},
     {"C15", 
      RowBox[{"-", "C15"}], "0", "0", "C44", "0"},
     {"0", "0", "0", 
      RowBox[{"-", "C15"}], "0", 
      FractionBox[
       RowBox[{"C11", "-", "C12"}], "2"]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"orthotropic", " ", "=", " ", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "C14", ",", "C15", ",", "C16", ",", "C24", ",", "C25", ",", "C26", ",", 
      "C34", ",", "C35", ",", "C36", ",", "C45", ",", "C46", ",", "C56"}], 
     "}"}], " ", "\[Rule]", " ", "0"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"C14", "\[Rule]", "0"}], ",", 
   RowBox[{"C15", "\[Rule]", "0"}], ",", 
   RowBox[{"C16", "\[Rule]", "0"}], ",", 
   RowBox[{"C24", "\[Rule]", "0"}], ",", 
   RowBox[{"C25", "\[Rule]", "0"}], ",", 
   RowBox[{"C26", "\[Rule]", "0"}], ",", 
   RowBox[{"C34", "\[Rule]", "0"}], ",", 
   RowBox[{"C35", "\[Rule]", "0"}], ",", 
   RowBox[{"C36", "\[Rule]", "0"}], ",", 
   RowBox[{"C45", "\[Rule]", "0"}], ",", 
   RowBox[{"C46", "\[Rule]", "0"}], ",", 
   RowBox[{"C56", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C2", " ", "/.", " ", "orthotropic"}], ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C11", "C12", "C13", "0", "0", "0"},
     {"C12", "C22", "C23", "0", "0", "0"},
     {"C13", "C23", "C33", "0", "0", "0"},
     {"0", "0", "0", "C44", "0", "0"},
     {"0", "0", "0", "0", "C55", "0"},
     {"0", "0", "0", "0", "0", "C66"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"transverseisotropic", " ", "=", " ", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"Thread", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "C14", ",", "C15", ",", "C16", ",", "C24", ",", "C25", ",", "C26", ",",
         "C34", ",", "C35", ",", "C36", ",", "C45", ",", "C46", ",", "C56"}], 
       "}"}], " ", "\[Rule]", " ", "0"}], "]"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"C22", " ", "\[Rule]", " ", "C11"}], ",", " ", 
      RowBox[{"C23", " ", "\[Rule]", " ", "C13"}], ",", " ", 
      RowBox[{"C55", " ", "\[Rule]", " ", "C44"}], ",", " ", 
      RowBox[{"C66", "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", " ", "-", "C12"}], ")"}], "/", "2"}]}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"C14", "\[Rule]", "0"}], ",", 
   RowBox[{"C15", "\[Rule]", "0"}], ",", 
   RowBox[{"C16", "\[Rule]", "0"}], ",", 
   RowBox[{"C24", "\[Rule]", "0"}], ",", 
   RowBox[{"C25", "\[Rule]", "0"}], ",", 
   RowBox[{"C26", "\[Rule]", "0"}], ",", 
   RowBox[{"C34", "\[Rule]", "0"}], ",", 
   RowBox[{"C35", "\[Rule]", "0"}], ",", 
   RowBox[{"C36", "\[Rule]", "0"}], ",", 
   RowBox[{"C45", "\[Rule]", "0"}], ",", 
   RowBox[{"C46", "\[Rule]", "0"}], ",", 
   RowBox[{"C56", "\[Rule]", "0"}], ",", 
   RowBox[{"C22", "\[Rule]", "C11"}], ",", 
   RowBox[{"C23", "\[Rule]", "C13"}], ",", 
   RowBox[{"C55", "\[Rule]", "C44"}], ",", 
   RowBox[{"C66", "\[Rule]", 
    FractionBox[
     RowBox[{"C11", "-", "C12"}], "2"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C2", " ", "/.", " ", "transverseisotropic"}], " ", ")"}], " ", "//",
   " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C11", "C12", "C13", "0", "0", "0"},
     {"C12", "C11", "C13", "0", "0", "0"},
     {"C13", "C13", "C33", "0", "0", "0"},
     {"0", "0", "0", "C44", "0", "0"},
     {"0", "0", "0", "0", "C44", "0"},
     {"0", "0", "0", "0", "0", 
      FractionBox[
       RowBox[{"C11", "-", "C12"}], "2"]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cubic", " ", "=", "  ", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"Thread", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "C14", ",", "C15", ",", "C16", ",", "C24", ",", "C25", ",", "C26", ",",
         "C34", ",", "C35", ",", "C36", ",", "C45", ",", "C46", ",", "C56"}], 
       "}"}], " ", "\[Rule]", " ", "0"}], "]"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"C13", " ", "\[Rule]", " ", "C12"}], ",", " ", 
      RowBox[{"C22", " ", "\[Rule]", " ", "C11"}], ",", " ", 
      RowBox[{"C23", " ", "\[Rule]", " ", "C12"}], ",", 
      RowBox[{"C33", " ", "\[Rule]", " ", "C11"}], ",", " ", 
      RowBox[{"C55", " ", "\[Rule]", " ", "C44"}], ",", " ", 
      RowBox[{"C66", "\[Rule]", "C44"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"C14", "\[Rule]", "0"}], ",", 
   RowBox[{"C15", "\[Rule]", "0"}], ",", 
   RowBox[{"C16", "\[Rule]", "0"}], ",", 
   RowBox[{"C24", "\[Rule]", "0"}], ",", 
   RowBox[{"C25", "\[Rule]", "0"}], ",", 
   RowBox[{"C26", "\[Rule]", "0"}], ",", 
   RowBox[{"C34", "\[Rule]", "0"}], ",", 
   RowBox[{"C35", "\[Rule]", "0"}], ",", 
   RowBox[{"C36", "\[Rule]", "0"}], ",", 
   RowBox[{"C45", "\[Rule]", "0"}], ",", 
   RowBox[{"C46", "\[Rule]", "0"}], ",", 
   RowBox[{"C56", "\[Rule]", "0"}], ",", 
   RowBox[{"C13", "\[Rule]", "C12"}], ",", 
   RowBox[{"C22", "\[Rule]", "C11"}], ",", 
   RowBox[{"C23", "\[Rule]", "C12"}], ",", 
   RowBox[{"C33", "\[Rule]", "C11"}], ",", 
   RowBox[{"C55", "\[Rule]", "C44"}], ",", 
   RowBox[{"C66", "\[Rule]", "C44"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C2", " ", "/.", "cubic"}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C11", "C12", "C12", "0", "0", "0"},
     {"C12", "C11", "C12", "0", "0", "0"},
     {"C12", "C12", "C11", "0", "0", "0"},
     {"0", "0", "0", "C44", "0", "0"},
     {"0", "0", "0", "0", "C44", "0"},
     {"0", "0", "0", "0", "0", "C44"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"isotropic", " ", "=", "  ", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"Thread", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "C14", ",", "C15", ",", "C16", ",", "C24", ",", "C25", ",", "C26", ",",
         "C34", ",", "C35", ",", "C36", ",", "C45", ",", "C46", ",", "C56"}], 
       "}"}], " ", "\[Rule]", " ", "0"}], "]"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"C13", " ", "\[Rule]", " ", "C12"}], ",", " ", 
      RowBox[{"C22", " ", "\[Rule]", " ", "C11"}], ",", " ", 
      RowBox[{"C23", " ", "\[Rule]", " ", "C12"}], ",", 
      RowBox[{"C33", " ", "\[Rule]", " ", "C11"}], ",", " ", 
      RowBox[{"C44", "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", " ", "-", "C12"}], ")"}], "/", "2"}]}], ",", " ", 
      RowBox[{"C55", " ", "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", " ", "-", "C12"}], ")"}], "/", "2"}]}], ",", " ", 
      RowBox[{"C66", "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", " ", "-", "C12"}], ")"}], "/", "2"}]}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"C14", "\[Rule]", "0"}], ",", 
   RowBox[{"C15", "\[Rule]", "0"}], ",", 
   RowBox[{"C16", "\[Rule]", "0"}], ",", 
   RowBox[{"C24", "\[Rule]", "0"}], ",", 
   RowBox[{"C25", "\[Rule]", "0"}], ",", 
   RowBox[{"C26", "\[Rule]", "0"}], ",", 
   RowBox[{"C34", "\[Rule]", "0"}], ",", 
   RowBox[{"C35", "\[Rule]", "0"}], ",", 
   RowBox[{"C36", "\[Rule]", "0"}], ",", 
   RowBox[{"C45", "\[Rule]", "0"}], ",", 
   RowBox[{"C46", "\[Rule]", "0"}], ",", 
   RowBox[{"C56", "\[Rule]", "0"}], ",", 
   RowBox[{"C13", "\[Rule]", "C12"}], ",", 
   RowBox[{"C22", "\[Rule]", "C11"}], ",", 
   RowBox[{"C23", "\[Rule]", "C12"}], ",", 
   RowBox[{"C33", "\[Rule]", "C11"}], ",", 
   RowBox[{"C44", "\[Rule]", 
    FractionBox[
     RowBox[{"C11", "-", "C12"}], "2"]}], ",", 
   RowBox[{"C55", "\[Rule]", 
    FractionBox[
     RowBox[{"C11", "-", "C12"}], "2"]}], ",", 
   RowBox[{"C66", "\[Rule]", 
    FractionBox[
     RowBox[{"C11", "-", "C12"}], "2"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C2", " ", "/.", "isotropic"}], ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C11", "C12", "C12", "0", "0", "0"},
     {"C12", "C11", "C12", "0", "0", "0"},
     {"C12", "C12", "C11", "0", "0", "0"},
     {"0", "0", "0", 
      FractionBox[
       RowBox[{"C11", "-", "C12"}], "2"], "0", "0"},
     {"0", "0", "0", "0", 
      FractionBox[
       RowBox[{"C11", "-", "C12"}], "2"], "0"},
     {"0", "0", "0", "0", "0", 
      FractionBox[
       RowBox[{"C11", "-", "C12"}], "2"]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Check that the compliance matrix, inverse of the stiffness has exactely the \
same form in the distribution of zeros and symmetries\
\>", "Subsubsection",
 FontFamily->"Arial"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Inverse", "[", 
   RowBox[{"(", 
    RowBox[{"C2", " ", "/.", "isotropic"}], ")"}], " ", "]"}], " ", "//", " ",
   "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["C11", "5"], "8"], "-", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["C11", "4"], " ", "C12"}], "8"], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["C11", "3"], " ", 
          SuperscriptBox["C12", "2"]}], "4"], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["C11", "2"], " ", 
          SuperscriptBox["C12", "3"]}], "4"], "-", 
        FractionBox[
         RowBox[{"3", " ", "C11", " ", 
          SuperscriptBox["C12", "4"]}], "8"], "+", 
        FractionBox[
         SuperscriptBox["C12", "5"], "8"]}], 
       RowBox[{
        FractionBox[
         SuperscriptBox["C11", "6"], "8"], "-", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["C11", "5"], " ", "C12"}], "8"], "+", 
        FractionBox[
         RowBox[{"5", " ", 
          SuperscriptBox["C11", "3"], " ", 
          SuperscriptBox["C12", "3"]}], "4"], "-", 
        FractionBox[
         RowBox[{"15", " ", 
          SuperscriptBox["C11", "2"], " ", 
          SuperscriptBox["C12", "4"]}], "8"], "+", 
        FractionBox[
         RowBox[{"9", " ", "C11", " ", 
          SuperscriptBox["C12", "5"]}], "8"], "-", 
        FractionBox[
         SuperscriptBox["C12", "6"], "4"]}]], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"C11", " ", "C12"}], "-", 
           SuperscriptBox["C12", "2"]}], ")"}]}], 
        RowBox[{"8", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            SuperscriptBox["C11", "6"], "8"], "-", 
           FractionBox[
            RowBox[{"3", " ", 
             SuperscriptBox["C11", "5"], " ", "C12"}], "8"], "+", 
           FractionBox[
            RowBox[{"5", " ", 
             SuperscriptBox["C11", "3"], " ", 
             SuperscriptBox["C12", "3"]}], "4"], "-", 
           FractionBox[
            RowBox[{"15", " ", 
             SuperscriptBox["C11", "2"], " ", 
             SuperscriptBox["C12", "4"]}], "8"], "+", 
           FractionBox[
            RowBox[{"9", " ", "C11", " ", 
             SuperscriptBox["C12", "5"]}], "8"], "-", 
           FractionBox[
            SuperscriptBox["C12", "6"], "4"]}], ")"}]}]]}], 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "C11"}], " ", "C12"}], "+", 
          SuperscriptBox["C12", "2"]}], ")"}]}], 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           SuperscriptBox["C11", "6"], "8"], "-", 
          FractionBox[
           RowBox[{"3", " ", 
            SuperscriptBox["C11", "5"], " ", "C12"}], "8"], "+", 
          FractionBox[
           RowBox[{"5", " ", 
            SuperscriptBox["C11", "3"], " ", 
            SuperscriptBox["C12", "3"]}], "4"], "-", 
          FractionBox[
           RowBox[{"15", " ", 
            SuperscriptBox["C11", "2"], " ", 
            SuperscriptBox["C12", "4"]}], "8"], "+", 
          FractionBox[
           RowBox[{"9", " ", "C11", " ", 
            SuperscriptBox["C12", "5"]}], "8"], "-", 
          FractionBox[
           SuperscriptBox["C12", "6"], "4"]}], ")"}]}]], "0", "0", "0"},
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"C11", " ", "C12"}], "-", 
           SuperscriptBox["C12", "2"]}], ")"}]}], 
        RowBox[{"8", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            SuperscriptBox["C11", "6"], "8"], "-", 
           FractionBox[
            RowBox[{"3", " ", 
             SuperscriptBox["C11", "5"], " ", "C12"}], "8"], "+", 
           FractionBox[
            RowBox[{"5", " ", 
             SuperscriptBox["C11", "3"], " ", 
             SuperscriptBox["C12", "3"]}], "4"], "-", 
           FractionBox[
            RowBox[{"15", " ", 
             SuperscriptBox["C11", "2"], " ", 
             SuperscriptBox["C12", "4"]}], "8"], "+", 
           FractionBox[
            RowBox[{"9", " ", "C11", " ", 
             SuperscriptBox["C12", "5"]}], "8"], "-", 
           FractionBox[
            SuperscriptBox["C12", "6"], "4"]}], ")"}]}]]}], 
      FractionBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["C11", "5"], "8"], "-", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["C11", "4"], " ", "C12"}], "8"], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["C11", "3"], " ", 
          SuperscriptBox["C12", "2"]}], "4"], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["C11", "2"], " ", 
          SuperscriptBox["C12", "3"]}], "4"], "-", 
        FractionBox[
         RowBox[{"3", " ", "C11", " ", 
          SuperscriptBox["C12", "4"]}], "8"], "+", 
        FractionBox[
         SuperscriptBox["C12", "5"], "8"]}], 
       RowBox[{
        FractionBox[
         SuperscriptBox["C11", "6"], "8"], "-", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["C11", "5"], " ", "C12"}], "8"], "+", 
        FractionBox[
         RowBox[{"5", " ", 
          SuperscriptBox["C11", "3"], " ", 
          SuperscriptBox["C12", "3"]}], "4"], "-", 
        FractionBox[
         RowBox[{"15", " ", 
          SuperscriptBox["C11", "2"], " ", 
          SuperscriptBox["C12", "4"]}], "8"], "+", 
        FractionBox[
         RowBox[{"9", " ", "C11", " ", 
          SuperscriptBox["C12", "5"]}], "8"], "-", 
        FractionBox[
         SuperscriptBox["C12", "6"], "4"]}]], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"C11", " ", "C12"}], "-", 
           SuperscriptBox["C12", "2"]}], ")"}]}], 
        RowBox[{"8", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            SuperscriptBox["C11", "6"], "8"], "-", 
           FractionBox[
            RowBox[{"3", " ", 
             SuperscriptBox["C11", "5"], " ", "C12"}], "8"], "+", 
           FractionBox[
            RowBox[{"5", " ", 
             SuperscriptBox["C11", "3"], " ", 
             SuperscriptBox["C12", "3"]}], "4"], "-", 
           FractionBox[
            RowBox[{"15", " ", 
             SuperscriptBox["C11", "2"], " ", 
             SuperscriptBox["C12", "4"]}], "8"], "+", 
           FractionBox[
            RowBox[{"9", " ", "C11", " ", 
             SuperscriptBox["C12", "5"]}], "8"], "-", 
           FractionBox[
            SuperscriptBox["C12", "6"], "4"]}], ")"}]}]]}], "0", "0", "0"},
     {
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"C11", "-", "C12"}], ")"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "C11"}], " ", "C12"}], "+", 
          SuperscriptBox["C12", "2"]}], ")"}]}], 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           SuperscriptBox["C11", "6"], "8"], "-", 
          FractionBox[
           RowBox[{"3", " ", 
            SuperscriptBox["C11", "5"], " ", "C12"}], "8"], "+", 
          FractionBox[
           RowBox[{"5", " ", 
            SuperscriptBox["C11", "3"], " ", 
            SuperscriptBox["C12", "3"]}], "4"], "-", 
          FractionBox[
           RowBox[{"15", " ", 
            SuperscriptBox["C11", "2"], " ", 
            SuperscriptBox["C12", "4"]}], "8"], "+", 
          FractionBox[
           RowBox[{"9", " ", "C11", " ", 
            SuperscriptBox["C12", "5"]}], "8"], "-", 
          FractionBox[
           SuperscriptBox["C12", "6"], "4"]}], ")"}]}]], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"C11", "-", "C12"}], ")"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"C11", " ", "C12"}], "-", 
           SuperscriptBox["C12", "2"]}], ")"}]}], 
        RowBox[{"8", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            SuperscriptBox["C11", "6"], "8"], "-", 
           FractionBox[
            RowBox[{"3", " ", 
             SuperscriptBox["C11", "5"], " ", "C12"}], "8"], "+", 
           FractionBox[
            RowBox[{"5", " ", 
             SuperscriptBox["C11", "3"], " ", 
             SuperscriptBox["C12", "3"]}], "4"], "-", 
           FractionBox[
            RowBox[{"15", " ", 
             SuperscriptBox["C11", "2"], " ", 
             SuperscriptBox["C12", "4"]}], "8"], "+", 
           FractionBox[
            RowBox[{"9", " ", "C11", " ", 
             SuperscriptBox["C12", "5"]}], "8"], "-", 
           FractionBox[
            SuperscriptBox["C12", "6"], "4"]}], ")"}]}]]}], 
      FractionBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["C11", "5"], "8"], "-", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["C11", "4"], " ", "C12"}], "8"], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["C11", "3"], " ", 
          SuperscriptBox["C12", "2"]}], "4"], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["C11", "2"], " ", 
          SuperscriptBox["C12", "3"]}], "4"], "-", 
        FractionBox[
         RowBox[{"3", " ", "C11", " ", 
          SuperscriptBox["C12", "4"]}], "8"], "+", 
        FractionBox[
         SuperscriptBox["C12", "5"], "8"]}], 
       RowBox[{
        FractionBox[
         SuperscriptBox["C11", "6"], "8"], "-", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["C11", "5"], " ", "C12"}], "8"], "+", 
        FractionBox[
         RowBox[{"5", " ", 
          SuperscriptBox["C11", "3"], " ", 
          SuperscriptBox["C12", "3"]}], "4"], "-", 
        FractionBox[
         RowBox[{"15", " ", 
          SuperscriptBox["C11", "2"], " ", 
          SuperscriptBox["C12", "4"]}], "8"], "+", 
        FractionBox[
         RowBox[{"9", " ", "C11", " ", 
          SuperscriptBox["C12", "5"]}], "8"], "-", 
        FractionBox[
         SuperscriptBox["C12", "6"], "4"]}]], "0", "0", "0"},
     {"0", "0", "0", 
      FractionBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["C11", "5"], "4"], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["C11", "4"], " ", "C12"}], "2"], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["C11", "3"], " ", 
          SuperscriptBox["C12", "2"]}], "2"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["C11", "2"], " ", 
         SuperscriptBox["C12", "3"]}], "-", 
        FractionBox[
         RowBox[{"7", " ", "C11", " ", 
          SuperscriptBox["C12", "4"]}], "4"], "+", 
        FractionBox[
         SuperscriptBox["C12", "5"], "2"]}], 
       RowBox[{
        FractionBox[
         SuperscriptBox["C11", "6"], "8"], "-", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["C11", "5"], " ", "C12"}], "8"], "+", 
        FractionBox[
         RowBox[{"5", " ", 
          SuperscriptBox["C11", "3"], " ", 
          SuperscriptBox["C12", "3"]}], "4"], "-", 
        FractionBox[
         RowBox[{"15", " ", 
          SuperscriptBox["C11", "2"], " ", 
          SuperscriptBox["C12", "4"]}], "8"], "+", 
        FractionBox[
         RowBox[{"9", " ", "C11", " ", 
          SuperscriptBox["C12", "5"]}], "8"], "-", 
        FractionBox[
         SuperscriptBox["C12", "6"], "4"]}]], "0", "0"},
     {"0", "0", "0", "0", 
      FractionBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["C11", "5"], "4"], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["C11", "4"], " ", "C12"}], "2"], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["C11", "3"], " ", 
          SuperscriptBox["C12", "2"]}], "2"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["C11", "2"], " ", 
         SuperscriptBox["C12", "3"]}], "-", 
        FractionBox[
         RowBox[{"7", " ", "C11", " ", 
          SuperscriptBox["C12", "4"]}], "4"], "+", 
        FractionBox[
         SuperscriptBox["C12", "5"], "2"]}], 
       RowBox[{
        FractionBox[
         SuperscriptBox["C11", "6"], "8"], "-", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["C11", "5"], " ", "C12"}], "8"], "+", 
        FractionBox[
         RowBox[{"5", " ", 
          SuperscriptBox["C11", "3"], " ", 
          SuperscriptBox["C12", "3"]}], "4"], "-", 
        FractionBox[
         RowBox[{"15", " ", 
          SuperscriptBox["C11", "2"], " ", 
          SuperscriptBox["C12", "4"]}], "8"], "+", 
        FractionBox[
         RowBox[{"9", " ", "C11", " ", 
          SuperscriptBox["C12", "5"]}], "8"], "-", 
        FractionBox[
         SuperscriptBox["C12", "6"], "4"]}]], "0"},
     {"0", "0", "0", "0", "0", 
      FractionBox[
       RowBox[{
        FractionBox[
         SuperscriptBox["C11", "5"], "4"], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["C11", "4"], " ", "C12"}], "2"], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["C11", "3"], " ", 
          SuperscriptBox["C12", "2"]}], "2"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["C11", "2"], " ", 
         SuperscriptBox["C12", "3"]}], "-", 
        FractionBox[
         RowBox[{"7", " ", "C11", " ", 
          SuperscriptBox["C12", "4"]}], "4"], "+", 
        FractionBox[
         SuperscriptBox["C12", "5"], "2"]}], 
       RowBox[{
        FractionBox[
         SuperscriptBox["C11", "6"], "8"], "-", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox["C11", "5"], " ", "C12"}], "8"], "+", 
        FractionBox[
         RowBox[{"5", " ", 
          SuperscriptBox["C11", "3"], " ", 
          SuperscriptBox["C12", "3"]}], "4"], "-", 
        FractionBox[
         RowBox[{"15", " ", 
          SuperscriptBox["C11", "2"], " ", 
          SuperscriptBox["C12", "4"]}], "8"], "+", 
        FractionBox[
         RowBox[{"9", " ", "C11", " ", 
          SuperscriptBox["C12", "5"]}], "8"], "-", 
        FractionBox[
         SuperscriptBox["C12", "6"], "4"]}]]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Extension experiment ", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"normal", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "p", "]"}], " ", 
     RowBox[{"Sin", "[", "t", "]"}]}], ",", " ", 
    RowBox[{
     RowBox[{"Sin", "[", "p", "]"}], " ", 
     RowBox[{"Sin", "[", "t", "]"}]}], ",", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(normal\\)\\\" is similar to existing symbol \
\\\"\\!\\(Normal\\)\\\".\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{
    RowBox[{"Sin", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"Cos", "[", "t", "]"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"stress", " ", "=", " ", 
    RowBox[{"Outer", "[", " ", 
     RowBox[{"Times", " ", ",", " ", "normal", ",", "normal"}], "]"}]}], 
   ")"}], " ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", "p", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
      RowBox[{
       RowBox[{"Cos", "[", "p", "]"}], " ", 
       RowBox[{"Sin", "[", "p", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
      RowBox[{
       RowBox[{"Cos", "[", "p", "]"}], " ", 
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]},
     {
      RowBox[{
       RowBox[{"Cos", "[", "p", "]"}], " ", 
       RowBox[{"Sin", "[", "p", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", "p", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
      RowBox[{
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       RowBox[{"Sin", "[", "p", "]"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]},
     {
      RowBox[{
       RowBox[{"Cos", "[", "p", "]"}], " ", 
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       RowBox[{"Sin", "[", "p", "]"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      SuperscriptBox[
       RowBox[{"Cos", "[", "t", "]"}], "2"]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"cubic", " ", "=", "  ", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"Thread", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "c14", ",", "c15", ",", "c16", ",", "c24", ",", "c25", ",", "c26", ",",
         "c34", ",", "c35", ",", "c36", ",", "c45", ",", "c46", ",", "c56"}], 
       "}"}], " ", "\[Rule]", " ", "0"}], "]"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c13", " ", "\[Rule]", " ", "c12"}], ",", " ", 
      RowBox[{"c22", " ", "\[Rule]", " ", "c11"}], ",", " ", 
      RowBox[{"c23", " ", "\[Rule]", " ", "c12"}], ",", 
      RowBox[{"c33", " ", "\[Rule]", " ", "c11"}], ",", " ", 
      RowBox[{"c55", " ", "\[Rule]", " ", "c44"}], ",", " ", 
      RowBox[{"c66", "\[Rule]", "c44"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C2cubic", " ", "=", " ", 
    RowBox[{
     RowBox[{"MakeTensor", "[", 
      RowBox[{"\"\<c\>\"", ",", " ", "2", ",", " ", "6"}], "]"}], " ", "/.", 
     " ", "cubic"}]}], " ", ")"}], " ", "//", " ", "MatrixForm"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(c14\\)\\\" is similar to existing symbol \
\\\"\\!\\(C14\\)\\\".\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(c15\\)\\\" is similar to existing symbol \
\\\"\\!\\(C15\\)\\\".\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(c16\\)\\\" is similar to existing symbol \
\\\"\\!\\(C16\\)\\\".\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"stop\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Further output of \\!\\(General :: \\\"spell1\\\"\\) will \
be suppressed during this calculation.\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"c14", "\[Rule]", "0"}], ",", 
   RowBox[{"c15", "\[Rule]", "0"}], ",", 
   RowBox[{"c16", "\[Rule]", "0"}], ",", 
   RowBox[{"c24", "\[Rule]", "0"}], ",", 
   RowBox[{"c25", "\[Rule]", "0"}], ",", 
   RowBox[{"c26", "\[Rule]", "0"}], ",", 
   RowBox[{"c34", "\[Rule]", "0"}], ",", 
   RowBox[{"c35", "\[Rule]", "0"}], ",", 
   RowBox[{"c36", "\[Rule]", "0"}], ",", 
   RowBox[{"c45", "\[Rule]", "0"}], ",", 
   RowBox[{"c46", "\[Rule]", "0"}], ",", 
   RowBox[{"c56", "\[Rule]", "0"}], ",", 
   RowBox[{"c13", "\[Rule]", "c12"}], ",", 
   RowBox[{"c22", "\[Rule]", "c11"}], ",", 
   RowBox[{"c23", "\[Rule]", "c12"}], ",", 
   RowBox[{"c33", "\[Rule]", "c11"}], ",", 
   RowBox[{"c55", "\[Rule]", "c44"}], ",", 
   RowBox[{"c66", "\[Rule]", "c44"}]}], "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"c11", "c12", "c12", "0", "0", "0"},
     {"c12", "c11", "c12", "0", "0", "0"},
     {"c12", "c12", "c11", "0", "0", "0"},
     {"0", "0", "0", "c44", "0", "0"},
     {"0", "0", "0", "0", "c44", "0"},
     {"0", "0", "0", "0", "0", "c44"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"S2cubic", " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Inverse", "[", "C2cubic", "]"}], "]"}]}], ")"}], " ", "//", " ",
   "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"c11", "+", "c12"}], 
       RowBox[{
        SuperscriptBox["c11", "2"], "+", 
        RowBox[{"c11", " ", "c12"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c12", "2"]}]}]], 
      RowBox[{"-", 
       FractionBox["c12", 
        RowBox[{
         SuperscriptBox["c11", "2"], "+", 
         RowBox[{"c11", " ", "c12"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["c12", "2"]}]}]]}], 
      RowBox[{"-", 
       FractionBox["c12", 
        RowBox[{
         SuperscriptBox["c11", "2"], "+", 
         RowBox[{"c11", " ", "c12"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["c12", "2"]}]}]]}], "0", "0", "0"},
     {
      RowBox[{"-", 
       FractionBox["c12", 
        RowBox[{
         SuperscriptBox["c11", "2"], "+", 
         RowBox[{"c11", " ", "c12"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["c12", "2"]}]}]]}], 
      FractionBox[
       RowBox[{"c11", "+", "c12"}], 
       RowBox[{
        SuperscriptBox["c11", "2"], "+", 
        RowBox[{"c11", " ", "c12"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c12", "2"]}]}]], 
      RowBox[{"-", 
       FractionBox["c12", 
        RowBox[{
         SuperscriptBox["c11", "2"], "+", 
         RowBox[{"c11", " ", "c12"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["c12", "2"]}]}]]}], "0", "0", "0"},
     {
      RowBox[{"-", 
       FractionBox["c12", 
        RowBox[{
         SuperscriptBox["c11", "2"], "+", 
         RowBox[{"c11", " ", "c12"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["c12", "2"]}]}]]}], 
      RowBox[{"-", 
       FractionBox["c12", 
        RowBox[{
         SuperscriptBox["c11", "2"], "+", 
         RowBox[{"c11", " ", "c12"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["c12", "2"]}]}]]}], 
      FractionBox[
       RowBox[{"c11", "+", "c12"}], 
       RowBox[{
        SuperscriptBox["c11", "2"], "+", 
        RowBox[{"c11", " ", "c12"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c12", "2"]}]}]], "0", "0", "0"},
     {"0", "0", "0", 
      FractionBox["1", "c44"], "0", "0"},
     {"0", "0", "0", "0", 
      FractionBox["1", "c44"], "0"},
     {"0", "0", "0", "0", "0", 
      FractionBox["1", "c44"]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s11", " ", "\[Equal]", " ", 
        RowBox[{"S2cubic", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"s12", " ", "\[Equal]", " ", 
        RowBox[{"S2cubic", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
       RowBox[{"s44", " ", "\[Equal]", " ", 
        RowBox[{"S2cubic", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "4"}], "]"}], "]"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"c11", ",", "c12", ",", "c44"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"c44", "\[Rule]", 
    FractionBox["1", "s44"]}], ",", 
   RowBox[{"c11", "\[Rule]", 
    FractionBox[
     RowBox[{"s11", "+", "s12"}], 
     RowBox[{
      SuperscriptBox["s11", "2"], "+", 
      RowBox[{"s11", " ", "s12"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["s12", "2"]}]}]]}], ",", 
   RowBox[{"c12", "\[Rule]", 
    FractionBox["s12", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["s11", "2"]}], "-", 
      RowBox[{"s11", " ", "s12"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["s12", "2"]}]}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"S2cubic", " ", "=", " ", 
    RowBox[{"Simplify", "[", " ", 
     RowBox[{"S2cubic", " ", "/.", " ", "sol"}], " ", "]"}]}], ")"}], " ", "//",
   " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"s11", "s12", "s12", "0", "0", "0"},
     {"s12", "s11", "s12", "0", "0", "0"},
     {"s12", "s12", "s11", "0", "0", "0"},
     {"0", "0", "0", "s44", "0", "0"},
     {"0", "0", "0", "0", "s44", "0"},
     {"0", "0", "0", "0", "0", "s44"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"aluminum", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"s11", "\[Rule]", 
     RowBox[{".6", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "2"}]}]}]}], ",", 
    RowBox[{"s12", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "0.58"}], " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "2"}]}]}]}], ",", 
    RowBox[{"s44", "\[Rule]", 
     RowBox[{"3.5", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "2"}]}]}]}]}], " ", "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"copper", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"s11", "\[Rule]", " ", 
     RowBox[{"1.49", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "2"}]}]}]}], ",", " ", 
    RowBox[{"s12", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"-", "0.63"}], " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "2"}]}]}]}], ",", 
    RowBox[{"s44", "->", 
     RowBox[{"1.33", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "2"}]}]}]}]}], " ", "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"austenite", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"s11", "->", 
     RowBox[{"1.49", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "2"}]}]}]}], ",", 
    RowBox[{"s12", "->", 
     RowBox[{
      RowBox[{"-", "0.63"}], " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "2"}]}]}]}], ",", 
    RowBox[{"s44", "->", 
     RowBox[{"1.33", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "2"}]}]}]}]}], " ", "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"TiN", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"s11", "->", 
     RowBox[{"2.17", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "3"}]}]}]}], ",", 
    RowBox[{"s12", "->", 
     RowBox[{
      RowBox[{"-", "3.8"}], " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "4"}]}]}]}], ",", 
    RowBox[{"s44", "->", 
     RowBox[{"5.95", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "3"}]}]}]}]}], " ", "}"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"s11", "\[Rule]", "0.006`"}], ",", 
   RowBox[{"s12", "\[Rule]", 
    RowBox[{"-", "0.0058`"}]}], ",", 
   RowBox[{"s44", "\[Rule]", "0.035`"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"s11", "\[Rule]", "0.0149`"}], ",", 
   RowBox[{"s12", "\[Rule]", 
    RowBox[{"-", "0.0063`"}]}], ",", 
   RowBox[{"s44", "\[Rule]", "0.013300000000000001`"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"s11", "\[Rule]", "0.0149`"}], ",", 
   RowBox[{"s12", "\[Rule]", 
    RowBox[{"-", "0.0063`"}]}], ",", 
   RowBox[{"s44", "\[Rule]", "0.013300000000000001`"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"s11", "\[Rule]", "0.00217`"}], ",", 
   RowBox[{"s12", "\[Rule]", 
    RowBox[{"-", "0.00037999999999999997`"}]}], ",", 
   RowBox[{"s44", "\[Rule]", "0.00595`"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"S4cubic", " ", "=", " ", 
    RowBox[{"ComplianceVto4", "[", "S2cubic", "]"}]}], ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"s11", "0", "0"},
         {"0", "s12", "0"},
         {"0", "0", "s12"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", 
          FractionBox["s44", "4"], "0"},
         {
          FractionBox["s44", "4"], "0", "0"},
         {"0", "0", "0"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "0", 
          FractionBox["s44", "4"]},
         {"0", "0", "0"},
         {
          FractionBox["s44", "4"], "0", "0"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", 
          FractionBox["s44", "4"], "0"},
         {
          FractionBox["s44", "4"], "0", "0"},
         {"0", "0", "0"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"s12", "0", "0"},
         {"0", "s11", "0"},
         {"0", "0", "s12"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "0", "0"},
         {"0", "0", 
          FractionBox["s44", "4"]},
         {"0", 
          FractionBox["s44", "4"], "0"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "0", 
          FractionBox["s44", "4"]},
         {"0", "0", "0"},
         {
          FractionBox["s44", "4"], "0", "0"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "0", "0"},
         {"0", "0", 
          FractionBox["s44", "4"]},
         {"0", 
          FractionBox["s44", "4"], "0"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"s12", "0", "0"},
         {"0", "s12", "0"},
         {"0", "0", "s11"}
        }], "\[NoBreak]", ")"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{{{{s11, 0, 0}, {0, s12, 0}, {0, 0, s12}}, {{
      0, Rational[1, 4] s44, 0}, {Rational[1, 4] s44, 0, 0}, {0, 0, 0}}, {{
      0, 0, Rational[1, 4] s44}, {0, 0, 0}, {Rational[1, 4] s44, 0, 0}}}, {{{
      0, Rational[1, 4] s44, 0}, {Rational[1, 4] s44, 0, 0}, {0, 0, 0}}, {{
      s12, 0, 0}, {0, s11, 0}, {0, 0, s12}}, {{0, 0, 0}, {
      0, 0, Rational[1, 4] s44}, {0, Rational[1, 4] s44, 0}}}, {{{
      0, 0, Rational[1, 4] s44}, {0, 0, 0}, {Rational[1, 4] s44, 0, 0}}, {{0, 
      0, 0}, {0, 0, Rational[1, 4] s44}, {0, Rational[1, 4] s44, 0}}, {{
      s12, 0, 0}, {0, s12, 0}, {0, 0, s11}}}}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{"MakeTensor", "[", 
     RowBox[{"\"\<sig\>\"", ",", "2", ",", "3"}], "]"}]}], ")"}], " ", "//", 
  " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"sig11", "sig12", "sig13"},
     {"sig12", "sig22", "sig23"},
     {"sig13", "sig23", "sig33"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"CEDot", "[", 
     RowBox[{"S4cubic", ",", " ", "sig"}], "]"}]}], ")"}], " ", "//", " ", 
  "MatrixForm", " "}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"s11", " ", "sig11"}], "+", 
       RowBox[{"s12", " ", "sig22"}], "+", 
       RowBox[{"s12", " ", "sig33"}]}], 
      FractionBox[
       RowBox[{"s44", " ", "sig12"}], "2"], 
      FractionBox[
       RowBox[{"s44", " ", "sig13"}], "2"]},
     {
      FractionBox[
       RowBox[{"s44", " ", "sig12"}], "2"], 
      RowBox[{
       RowBox[{"s12", " ", "sig11"}], "+", 
       RowBox[{"s11", " ", "sig22"}], "+", 
       RowBox[{"s12", " ", "sig33"}]}], 
      FractionBox[
       RowBox[{"s44", " ", "sig23"}], "2"]},
     {
      FractionBox[
       RowBox[{"s44", " ", "sig13"}], "2"], 
      FractionBox[
       RowBox[{"s44", " ", "sig23"}], "2"], 
      RowBox[{
       RowBox[{"s12", " ", "sig11"}], "+", 
       RowBox[{"s12", " ", "sig22"}], "+", 
       RowBox[{"s11", " ", "sig33"}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"strain", " ", "=", " ", 
    RowBox[{"CEDot", "[", " ", 
     RowBox[{"S4cubic", ",", " ", "stress"}], "]"}]}], ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"s12", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "t", "]"}], "2"]}], "+", 
       RowBox[{"s11", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "p", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}], "+", 
       RowBox[{"s12", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "p", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}]}], 
      RowBox[{
       FractionBox["1", "2"], " ", "s44", " ", 
       RowBox[{"Cos", "[", "p", "]"}], " ", 
       RowBox[{"Sin", "[", "p", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
      RowBox[{
       FractionBox["1", "2"], " ", "s44", " ", 
       RowBox[{"Cos", "[", "p", "]"}], " ", 
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]},
     {
      RowBox[{
       FractionBox["1", "2"], " ", "s44", " ", 
       RowBox[{"Cos", "[", "p", "]"}], " ", 
       RowBox[{"Sin", "[", "p", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
      RowBox[{
       RowBox[{"s12", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "t", "]"}], "2"]}], "+", 
       RowBox[{"s12", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "p", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}], "+", 
       RowBox[{"s11", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "p", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}]}], 
      RowBox[{
       FractionBox["1", "2"], " ", "s44", " ", 
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       RowBox[{"Sin", "[", "p", "]"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]},
     {
      RowBox[{
       FractionBox["1", "2"], " ", "s44", " ", 
       RowBox[{"Cos", "[", "p", "]"}], " ", 
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{
       FractionBox["1", "2"], " ", "s44", " ", 
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       RowBox[{"Sin", "[", "p", "]"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{
       RowBox[{"s11", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "t", "]"}], "2"]}], "+", 
       RowBox[{"s12", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "p", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}], "+", 
       RowBox[{"s12", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "p", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"epsnn", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"Nest", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Dot", "[", " ", 
       RowBox[{"#", " ", ",", " ", "normal"}], "]"}], " ", "&"}], ",", " ", 
     "S4cubic", " ", ",", " ", "4"}], "]"}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"s11", " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "t", "]"}], "4"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "s12"}], "+", "s44"}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "t", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"s11", " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "p", "]"}], "4"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "s12"}], "+", "s44"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "p", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "p", "]"}], "2"]}], "+", 
     RowBox[{"s11", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "p", "]"}], "4"]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "t", "]"}], "4"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"epsnn", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"normal", " ", ".", " ", "strain", " ", ".", " ", "normal"}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"s11", " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "t", "]"}], "4"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "s12"}], "+", "s44"}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "t", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"s11", " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "p", "]"}], "4"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "s12"}], "+", "s44"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "p", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "p", "]"}], "2"]}], "+", 
     RowBox[{"s11", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "p", "]"}], "4"]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "t", "]"}], "4"]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  RowBox[{"Check", " ", "the", " ", "isotropic", " ", 
   RowBox[{"case", ":"}]}], "Subsubsection"]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{"epsnn", " ", "/.", " ", 
   RowBox[{"s44", " ", "\[Rule]", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s11", " ", "-", " ", "s12"}], ")"}], "/", "2"}]}]}], 
  "]"}]], "Input"],

Cell[BoxData["s11"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"epsnn", " ", "normal"}], ")"}], "/.", " ", "aluminum"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot3D", "[", " ", 
  RowBox[{
   RowBox[{"Evaluate", "[", "%", "]"}], "  ", ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "0", ",", "  ", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"p", ",", " ", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], " ", ",", " ", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", " ", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "50"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<aluminum.pdf\>\"", ",", "%"}], "]"}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.08447 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0562947 1.16517 0 1.16517 [
[.16907 .19677 -34.5279 -9 ]
[.16907 .19677 1.47209 0 ]
[.35445 .11851 -5.39225 -9 ]
[.35445 .11851 .60775 0 ]
[.55457 .03411 -25.1492 -9 ]
[.55457 .03411 4.85079 0 ]
[.07967 .87449 -20.369 0 ]
[.07967 .87449 15.631 9 ]
[.22049 .97328 -3.26269 0 ]
[.22049 .97328 2.73731 9 ]
[.34258 1.05892 -15.7702 0 ]
[.34258 1.05892 14.2298 9 ]
[.06179 .33287 -36 -2.68082 ]
[.06179 .33287 0 6.31918 ]
[.0344 .50436 -6 -2.8341 ]
[.0344 .50436 0 6.1659 ]
[.0035 .69787 -30 -3.00921 ]
[.0035 .69787 0 5.99079 ]
[ 0 0 0 0 ]
[ 1 1.08447 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08825 .24561 m
.67257 0 L
s
.17892 .2075 m
.18385 .21286 L
s
[(-0.005)] .16907 .19677 .91822 1 Mshowa
.36353 .1299 m
.36807 .13559 L
s
[(0)] .35445 .11851 .79742 1 Mshowa
.56273 .04617 m
.56681 .0522 L
s
[(0.005)] .55457 .03411 .67661 1 Mshowa
.125 Mabswid
.21475 .19244 m
.21767 .19569 L
s
.25112 .17715 m
.25398 .18045 L
s
.28803 .16164 m
.29085 .16497 L
s
.32549 .14589 m
.32827 .14927 L
s
.40215 .11367 m
.40482 .11712 L
s
.44136 .09718 m
.44398 .10068 L
s
.48119 .08044 m
.48375 .08398 L
s
.52164 .06344 m
.52415 .06702 L
s
.14361 .22234 m
.14661 .22552 L
s
.10881 .23697 m
.11185 .24011 L
s
.60448 .02862 m
.60686 .03228 L
s
.64689 .01079 m
.64922 .01449 L
s
.25 Mabswid
0 .80261 m
.40027 1.08447 L
s
.08157 .86005 m
.08252 .85283 L
s
[(-0.005)] .07967 .87449 .13161 -1 Mshowa
.22176 .95877 m
.22239 .95151 L
s
[(0)] .22049 .97328 .08756 -1 Mshowa
.34333 1.04438 m
.3437 1.0371 L
s
[(0.005)] .34258 1.05892 .05134 -1 Mshowa
.125 Mabswid
.1113 .88099 m
.11183 .87665 L
s
.14015 .9013 m
.14064 .89696 L
s
.16815 .92102 m
.1686 .91667 L
s
.19534 .94017 m
.19576 .93582 L
s
.24744 .97685 m
.24778 .9725 L
s
.27241 .99443 m
.27272 .99007 L
s
.29669 1.01153 m
.29698 1.00717 L
s
.32032 1.02818 m
.32058 1.02381 L
s
.05092 .83847 m
.05153 .83414 L
s
.01929 .8162 m
.01995 .81188 L
s
.36573 1.06015 m
.36593 1.05579 L
s
.38755 1.07552 m
.38772 1.07115 L
s
.25 Mabswid
.08825 .24561 m
0 .80261 L
s
.07529 .32742 m
.08204 .32469 L
s
[(-0.005)] .06179 .33287 1 -0.40426 Mshowa
.04806 .49931 m
.05489 .49678 L
s
[(0)] .0344 .50436 1 -0.3702 Mshowa
.01732 .69329 m
.02423 .691 L
s
[(0.005)] .0035 .69787 1 -0.33129 Mshowa
.125 Mabswid
.0701 .36021 m
.07416 .35859 L
s
.06478 .39377 m
.06885 .39218 L
s
.05934 .42812 m
.06341 .42655 L
s
.05376 .46329 m
.05785 .46174 L
s
.04221 .53621 m
.04632 .53471 L
s
.03622 .57402 m
.04034 .57256 L
s
.03008 .61278 m
.0342 .61134 L
s
.02378 .65252 m
.02792 .65112 L
s
.08037 .29536 m
.08441 .2937 L
s
.08534 .26402 m
.08937 .26234 L
s
.01069 .73512 m
.01485 .73378 L
s
.00389 .77805 m
.00806 .77674 L
s
.25 Mabswid
.08825 .24561 m
0 .80261 L
s
0 .80261 m
.40027 1.08447 L
s
.40027 1.08447 m
.41786 .5816 L
s
.41786 .5816 m
.08825 .24561 L
s
.67257 0 m
.92728 .41494 L
s
.92728 .41494 m
1 .947 L
s
1 .947 m
.7065 .58421 L
s
.7065 .58421 m
.67257 0 L
s
.08825 .24561 m
0 .80261 L
s
0 .80261 m
.7065 .58421 L
s
.7065 .58421 m
.67257 0 L
s
.67257 0 m
.08825 .24561 L
s
.41786 .5816 m
.92728 .41494 L
s
.92728 .41494 m
1 .947 L
s
1 .947 m
.40027 1.08447 L
s
.40027 1.08447 m
.41786 .5816 L
s
0 0 m
1 0 L
1 1.08447 L
0 1.08447 L
closepath
clip
newpath
.5 Mabswid
.46008 .63341 m .46445 .58778 L .48359 .58972 L p .703 .542 .667 r
F P
0 g
s
.48359 .58972 m .48069 .63503 L .46008 .63341 L p .703 .542 .667 r
F P
0 g
s
.488 .54394 m .48359 .58972 L .46445 .58778 L p .706 .591 .725 r
F P
0 g
s
.48069 .63503 m .48359 .58972 L .50269 .5909 L p .676 .514 .659 r
F P
0 g
s
.48359 .58972 m .488 .54394 L .50506 .54533 L p .685 .57 .72 r
F P
0 g
s
.50506 .54533 m .50269 .5909 L .48359 .58972 L p .685 .57 .72 r
F P
0 g
s
.43972 .63079 m .44553 .5851 L .46445 .58778 L p .731 .569 .672 r
F P
0 g
s
.46445 .58778 m .46008 .63341 L .43972 .63079 L p .731 .569 .672 r
F P
0 g
s
.47096 .54196 m .46445 .58778 L .44553 .5851 L p .727 .613 .73 r
F P
0 g
s
.46445 .58778 m .47096 .54196 L .488 .54394 L p .706 .591 .725 r
F P
0 g
s
.50269 .5909 m .50118 .63564 L .48069 .63503 L p .676 .514 .659 r
F P
0 g
s
.50118 .63564 m .50269 .5909 L .52151 .59134 L p .649 .486 .65 r
F P
0 g
s
.50269 .5909 m .50506 .54533 L .52198 .54613 L p .665 .549 .713 r
F P
0 g
s
.52198 .54613 m .52151 .59134 L .50269 .5909 L p .665 .549 .713 r
F P
0 g
s
.41999 .62718 m .4271 .58169 L .44553 .5851 L p .759 .596 .676 r
F P
0 g
s
.44553 .5851 m .43972 .63079 L .41999 .62718 L p .759 .596 .676 r
F P
0 g
s
.45411 .5394 m .44553 .5851 L .4271 .58169 L p .748 .634 .734 r
F P
0 g
s
.44553 .5851 m .45411 .5394 L .47096 .54196 L p .727 .613 .73 r
F P
0 g
s
.49376 .50135 m .488 .54394 L .47096 .54196 L p .699 .641 .788 r
F P
0 g
s
.488 .54394 m .49376 .50135 L .50821 .50267 L p .684 .625 .784 r
F P
0 g
s
.50821 .50267 m .50506 .54533 L .488 .54394 L p .684 .625 .784 r
F P
0 g
s
.47936 .49956 m .47096 .54196 L .45411 .5394 L p .714 .657 .792 r
F P
0 g
s
.47096 .54196 m .47936 .49956 L .49376 .50135 L p .699 .641 .788 r
F P
0 g
s
.50506 .54533 m .50821 .50267 L .52261 .50349 L p .671 .611 .779 r
F P
0 g
s
.52261 .50349 m .52198 .54613 L .50506 .54533 L p .671 .611 .779 r
F P
0 g
s
.52151 .59134 m .52123 .63531 L .50118 .63564 L p .649 .486 .65 r
F P
0 g
s
.52123 .63531 m .52151 .59134 L .53988 .59106 L p .623 .459 .639 r
F P
0 g
s
.52151 .59134 m .52198 .54613 L .53862 .54631 L p .647 .53 .706 r
F P
0 g
s
.53862 .54631 m .53988 .59106 L .52151 .59134 L p .647 .53 .706 r
F P
0 g
s
.40123 .62264 m .4094 .5776 L .4271 .58169 L p .787 .623 .678 r
F P
0 g
s
.4271 .58169 m .41999 .62718 L .40123 .62264 L p .787 .623 .678 r
F P
0 g
s
.43763 .5363 m .4271 .58169 L .4094 .5776 L p .769 .656 .737 r
F P
0 g
s
.4271 .58169 m .43763 .5363 L .45411 .5394 L p .748 .634 .734 r
F P
0 g
s
.46513 .49731 m .45411 .5394 L .43763 .5363 L p .729 .673 .796 r
F P
0 g
s
.45411 .5394 m .46513 .49731 L .47936 .49956 L p .714 .657 .792 r
F P
0 g
s
.52198 .54613 m .52261 .50349 L .53687 .50381 L p .659 .597 .775 r
F P
0 g
s
.53687 .50381 m .53862 .54631 L .52198 .54613 L p .659 .597 .775 r
F P
0 g
s
.43643 .67393 m .43972 .63079 L .46008 .63341 L p .729 .529 .62 r
F P
0 g
s
.46008 .63341 m .45764 .67632 L .43643 .67393 L p .729 .529 .62 r
F P
0 g
s
.45764 .67632 m .46008 .63341 L .48069 .63503 L p .694 .495 .614 r
F P
0 g
s
.48069 .63503 m .47914 .67733 L .45764 .67632 L p .694 .495 .614 r
F P
0 g
s
.47914 .67733 m .48069 .63503 L .50118 .63564 L p .659 .46 .605 r
F P
0 g
s
.41598 .6702 m .41999 .62718 L .43972 .63079 L p .764 .561 .623 r
F P
0 g
s
.43972 .63079 m .43643 .67393 L .41598 .6702 L p .764 .561 .623 r
F P
0 g
s
.4094 .5776 m .42169 .53268 L .43763 .5363 L p .769 .656 .737 r
F P
0 g
s
.45116 .49463 m .43763 .5363 L .42169 .53268 L p .744 .69 .799 r
F P
0 g
s
.43763 .5363 m .45116 .49463 L .46513 .49731 L p .729 .673 .796 r
F P
0 g
s
.53988 .59106 m .53862 .54631 L .55491 .54589 L p .631 .511 .699 r
F P
0 g
s
.53862 .54631 m .53687 .50381 L .55092 .50359 L p .648 .585 .77 r
F P
0 g
s
.55092 .50359 m .55491 .54589 L .53862 .54631 L p .648 .585 .77 r
F P
0 g
s
.53988 .59106 m .5406 .63412 L .52123 .63531 L p .623 .459 .639 r
F P
0 g
s
.5406 .63412 m .53988 .59106 L .55767 .5901 L p .598 .432 .627 r
F P
0 g
s
.55491 .54589 m .55767 .5901 L .53988 .59106 L p .631 .511 .699 r
F P
0 g
s
.50118 .63564 m .50043 .67702 L .47914 .67733 L p .659 .46 .605 r
F P
0 g
s
.50043 .67702 m .50118 .63564 L .52123 .63531 L p .623 .424 .592 r
F P
0 g
s
.38373 .61728 m .39266 .57289 L .4094 .5776 L p .816 .649 .677 r
F P
0 g
s
.4094 .5776 m .40123 .62264 L .38373 .61728 L p .816 .649 .677 r
F P
0 g
s
.42169 .53268 m .4094 .5776 L .39266 .57289 L p .791 .677 .739 r
F P
0 g
s
.39675 .66519 m .40123 .62264 L .41999 .62718 L p .8 .593 .622 r
F P
0 g
s
.41999 .62718 m .41598 .6702 L .39675 .66519 L p .8 .593 .622 r
F P
0 g
s
.55767 .5901 m .55491 .54589 L .57078 .54485 L p .617 .496 .692 r
F P
0 g
s
.55491 .54589 m .55092 .50359 L .56474 .50282 L p .64 .576 .766 r
F P
0 g
s
.56474 .50282 m .57078 .54485 L .55491 .54589 L p .64 .576 .766 r
F P
0 g
s
.39266 .57289 m .40644 .52857 L .42169 .53268 L p .791 .677 .739 r
F P
0 g
s
.43758 .49152 m .42169 .53268 L .40644 .52857 L p .759 .706 .802 r
F P
0 g
s
.42169 .53268 m .43758 .49152 L .45116 .49463 L p .744 .69 .799 r
F P
0 g
s
.52123 .63531 m .52111 .6755 L .50043 .67702 L p .623 .424 .592 r
F P
0 g
s
.52111 .6755 m .52123 .63531 L .5406 .63412 L p .587 .386 .576 r
F P
0 g
s
.55767 .5901 m .55911 .63218 L .5406 .63412 L p .598 .432 .627 r
F P
0 g
s
.55911 .63218 m .55767 .5901 L .57482 .5885 L p .577 .407 .614 r
F P
0 g
s
.57078 .54485 m .57482 .5885 L .55767 .5901 L p .617 .496 .692 r
F P
0 g
s
.57482 .5885 m .57078 .54485 L .58624 .54319 L p .607 .483 .685 r
F P
0 g
s
.57078 .54485 m .56474 .50282 L .57828 .50148 L p .635 .568 .762 r
F P
0 g
s
.57828 .50148 m .58624 .54319 L .57078 .54485 L p .635 .568 .762 r
F P
0 g
s
.36772 .61121 m .37703 .56763 L .39266 .57289 L p .844 .675 .673 r
F P
0 g
s
.39266 .57289 m .38373 .61728 L .36772 .61121 L p .844 .675 .673 r
F P
0 g
s
.40644 .52857 m .39266 .57289 L .37703 .56763 L p .812 .698 .739 r
F P
0 g
s
.50037 .46555 m .49376 .50135 L .47936 .49956 L p .678 .691 .855 r
F P
0 g
s
.49376 .50135 m .50037 .46555 L .51185 .46662 L p .67 .681 .852 r
F P
0 g
s
.51185 .46662 m .50821 .50267 L .49376 .50135 L p .67 .681 .852 r
F P
0 g
s
.37911 .65906 m .38373 .61728 L .40123 .62264 L p .836 .625 .617 r
F P
0 g
s
.40123 .62264 m .39675 .66519 L .37911 .65906 L p .836 .625 .617 r
F P
0 g
s
.50821 .50267 m .51185 .46662 L .52334 .46728 L p .662 .672 .849 r
F P
0 g
s
.52334 .46728 m .52261 .50349 L .50821 .50267 L p .662 .672 .849 r
F P
0 g
s
.37703 .56763 m .39198 .524 L .40644 .52857 L p .812 .698 .739 r
F P
0 g
s
.42448 .48801 m .40644 .52857 L .39198 .524 L p .773 .721 .804 r
F P
0 g
s
.40644 .52857 m .42448 .48801 L .43758 .49152 L p .759 .706 .802 r
F P
0 g
s
.48895 .4641 m .47936 .49956 L .46513 .49731 L p .687 .702 .858 r
F P
0 g
s
.47936 .49956 m .48895 .4641 L .50037 .46555 L p .678 .691 .855 r
F P
0 g
s
.52261 .50349 m .52334 .46728 L .53477 .46752 L p .656 .664 .846 r
F P
0 g
s
.53477 .46752 m .53687 .50381 L .52261 .50349 L p .656 .664 .846 r
F P
0 g
s
.5406 .63412 m .54085 .67294 L .52111 .6755 L p .587 .386 .576 r
F P
0 g
s
.54085 .67294 m .5406 .63412 L .55911 .63218 L p .551 .346 .556 r
F P
0 g
s
.57482 .5885 m .57671 .62959 L .55911 .63218 L p .577 .407 .614 r
F P
0 g
s
.57671 .62959 m .57482 .5885 L .59136 .58629 L p .561 .385 .601 r
F P
0 g
s
.58624 .54319 m .59136 .58629 L .57482 .5885 L p .607 .483 .685 r
F P
0 g
s
.47766 .46228 m .46513 .49731 L .45116 .49463 L p .696 .712 .861 r
F P
0 g
s
.46513 .49731 m .47766 .46228 L .48895 .4641 L p .687 .702 .858 r
F P
0 g
s
.43486 .71377 m .43643 .67393 L .45764 .67632 L p .724 .497 .581 r
F P
0 g
s
.45764 .67632 m .45652 .71579 L .43486 .71377 L p .724 .497 .581 r
F P
0 g
s
.45652 .71579 m .45764 .67632 L .47914 .67733 L p .682 .458 .575 r
F P
0 g
s
.53687 .50381 m .53477 .46752 L .5461 .46733 L p .651 .658 .844 r
F P
0 g
s
.5461 .46733 m .55092 .50359 L .53687 .50381 L p .651 .658 .844 r
F P
0 g
s
.59136 .58629 m .58624 .54319 L .60131 .5409 L p .601 .474 .678 r
F P
0 g
s
.58624 .54319 m .57828 .50148 L .59155 .49955 L p .632 .563 .759 r
F P
0 g
s
.59155 .49955 m .60131 .5409 L .58624 .54319 L p .632 .563 .759 r
F P
0 g
s
.47914 .67733 m .47848 .71602 L .45652 .71579 L p .682 .458 .575 r
F P
0 g
s
.47848 .71602 m .47914 .67733 L .50043 .67702 L p .639 .417 .564 r
F P
0 g
s
.41408 .70995 m .41598 .6702 L .43643 .67393 L p .766 .534 .583 r
F P
0 g
s
.43643 .67393 m .43486 .71377 L .41408 .70995 L p .766 .534 .583 r
F P
0 g
s
.46656 .4601 m .45116 .49463 L .43758 .49152 L p .705 .723 .864 r
F P
0 g
s
.45116 .49463 m .46656 .4601 L .47766 .46228 L p .696 .712 .861 r
F P
0 g
s
.55092 .50359 m .5461 .46733 L .5573 .46667 L p .648 .653 .841 r
F P
0 g
s
.5573 .46667 m .56474 .50282 L .55092 .50359 L p .648 .653 .841 r
F P
0 g
s
.50043 .67702 m .50017 .71453 L .47848 .71602 L p .639 .417 .564 r
F P
0 g
s
.50017 .71453 m .50043 .67702 L .52111 .6755 L p .594 .372 .549 r
F P
0 g
s
.36259 .56188 m .37838 .519 L .39198 .524 L p .832 .717 .738 r
F P
0 g
s
.39198 .524 m .37703 .56763 L .36259 .56188 L p .832 .717 .738 r
F P
0 g
s
.41192 .48411 m .39198 .524 L .37838 .519 L p .786 .735 .806 r
F P
0 g
s
.39198 .524 m .41192 .48411 L .42448 .48801 L p .773 .721 .804 r
F P
0 g
s
.35329 .60455 m .36259 .56188 L .37703 .56763 L p .872 .699 .665 r
F P
0 g
s
.37703 .56763 m .36772 .61121 L .35329 .60455 L p .872 .699 .665 r
F P
0 g
s
.59136 .58629 m .59345 .62648 L .57671 .62959 L p .561 .385 .601 r
F P
0 g
s
.59345 .62648 m .59136 .58629 L .60737 .5835 L p .551 .37 .589 r
F P
0 g
s
.60131 .5409 m .60737 .5835 L .59136 .58629 L p .601 .474 .678 r
F P
0 g
s
.60737 .5835 m .60131 .5409 L .61608 .53798 L p .6 .469 .673 r
F P
0 g
s
.60131 .5409 m .59155 .49955 L .60458 .49701 L p .632 .561 .756 r
F P
0 g
s
.60458 .49701 m .61608 .53798 L .60131 .5409 L p .632 .561 .756 r
F P
0 g
s
.56474 .50282 m .5573 .46667 L .56832 .46555 L p .647 .65 .839 r
F P
0 g
s
.56832 .46555 m .57828 .50148 L .56474 .50282 L p .647 .65 .839 r
F P
0 g
s
.36335 .65198 m .36772 .61121 L .38373 .61728 L p .872 .655 .606 r
F P
0 g
s
.38373 .61728 m .37911 .65906 L .36335 .65198 L p .872 .655 .606 r
F P
0 g
s
.55911 .63218 m .55944 .66953 L .54085 .67294 L p .551 .346 .556 r
F P
0 g
s
.55944 .66953 m .55911 .63218 L .57671 .62959 L p .519 .308 .534 r
F P
0 g
s
.39475 .70444 m .39675 .66519 L .41598 .6702 L p .808 .571 .579 r
F P
0 g
s
.41598 .6702 m .41408 .70995 L .39475 .70444 L p .808 .571 .579 r
F P
0 g
s
.45573 .45758 m .43758 .49152 L .42448 .48801 L p .714 .733 .866 r
F P
0 g
s
.43758 .49152 m .45573 .45758 L .46656 .4601 L p .705 .723 .864 r
F P
0 g
s
.57828 .50148 m .56832 .46555 L .57916 .46393 L p .648 .648 .836 r
F P
0 g
s
.57916 .46393 m .59155 .49955 L .57828 .50148 L p .648 .648 .836 r
F P
0 g
s
.61608 .53798 m .62299 .58014 L .60737 .5835 L p .6 .469 .673 r
F P
0 g
s
.62299 .58014 m .61608 .53798 L .63062 .53438 L p .604 .469 .67 r
F P
0 g
s
.61608 .53798 m .60458 .49701 L .61738 .49384 L p .635 .561 .754 r
F P
0 g
s
.61738 .49384 m .63062 .53438 L .61608 .53798 L p .635 .561 .754 r
F P
0 g
s
.52111 .6755 m .52109 .71152 L .50017 .71453 L p .594 .372 .549 r
F P
0 g
s
.52109 .71152 m .52111 .6755 L .54085 .67294 L p .547 .324 .528 r
F P
0 g
s
.44523 .45471 m .42448 .48801 L .41192 .48411 L p .722 .743 .868 r
F P
0 g
s
.42448 .48801 m .44523 .45471 L .45573 .45758 L p .714 .733 .866 r
F P
0 g
s
.60737 .5835 m .60949 .62293 L .59345 .62648 L p .551 .37 .589 r
F P
0 g
s
.60949 .62293 m .60737 .5835 L .62299 .58014 L p .55 .362 .579 r
F P
0 g
s
.59155 .49955 m .57916 .46393 L .5898 .46181 L p .65 .648 .834 r
F P
0 g
s
.5898 .46181 m .60458 .49701 L .59155 .49955 L p .65 .648 .834 r
F P
0 g
s
.34935 .5557 m .36565 .51358 L .37838 .519 L p .85 .735 .735 r
F P
0 g
s
.37838 .519 m .36259 .56188 L .34935 .5557 L p .85 .735 .735 r
F P
0 g
s
.39997 .47982 m .37838 .519 L .36565 .51358 L p .798 .747 .806 r
F P
0 g
s
.37838 .519 m .39997 .47982 L .41192 .48411 L p .786 .735 .806 r
F P
0 g
s
.37731 .69742 m .37911 .65906 L .39675 .66519 L p .851 .607 .569 r
F P
0 g
s
.39675 .66519 m .39475 .70444 L .37731 .69742 L p .851 .607 .569 r
F P
0 g
s
.57671 .62959 m .57682 .66551 L .55944 .66953 L p .519 .308 .534 r
F P
0 g
s
.57682 .66551 m .57671 .62959 L .59345 .62648 L p .492 .274 .51 r
F P
0 g
s
.34044 .59745 m .34935 .5557 L .36259 .56188 L p .898 .72 .653 r
F P
0 g
s
.36259 .56188 m .35329 .60455 L .34044 .59745 L p .898 .72 .653 r
F P
0 g
s
.63062 .53438 m .63842 .5762 L .62299 .58014 L p .604 .469 .67 r
F P
0 g
s
.63842 .5762 m .63062 .53438 L .64503 .53009 L p .61 .472 .668 r
F P
0 g
s
.63062 .53438 m .61738 .49384 L .62999 .49002 L p .64 .563 .752 r
F P
0 g
s
.62999 .49002 m .64503 .53009 L .63062 .53438 L p .64 .563 .752 r
F P
0 g
s
.34959 .64418 m .35329 .60455 L .36772 .61121 L p .907 .683 .586 r
F P
0 g
s
.36772 .61121 m .36335 .65198 L .34959 .64418 L p .907 .683 .586 r
F P
0 g
s
.43509 .45151 m .41192 .48411 L .39997 .47982 L p .729 .751 .87 r
F P
0 g
s
.41192 .48411 m .43509 .45151 L .44523 .45471 L p .722 .743 .868 r
F P
0 g
s
.60458 .49701 m .5898 .46181 L .60024 .45916 L p .655 .649 .832 r
F P
0 g
s
.60024 .45916 m .61738 .49384 L .60458 .49701 L p .655 .649 .832 r
F P
0 g
s
.62299 .58014 m .62507 .61901 L .60949 .62293 L p .55 .362 .579 r
F P
0 g
s
.62507 .61901 m .62299 .58014 L .63842 .5762 L p .557 .363 .574 r
F P
0 g
s
.54085 .67294 m .54083 .70724 L .52109 .71152 L p .547 .324 .528 r
F P
0 g
s
.54083 .70724 m .54085 .67294 L .55944 .66953 L p .499 .272 .502 r
F P
0 g
s
.43399 .75142 m .43486 .71377 L .45652 .71579 L p .721 .482 .564 r
F P
0 g
s
.45652 .71579 m .45591 .75304 L .43399 .75142 L p .721 .482 .564 r
F P
0 g
s
.45591 .75304 m .45652 .71579 L .47848 .71602 L p .674 .44 .559 r
F P
0 g
s
.64503 .53009 m .65384 .57166 L .63842 .5762 L p .61 .472 .668 r
F P
0 g
s
.62999 .49002 m .64503 .53009 L .65939 .52509 L p .642 .565 .752 r
F P
0 g
s
.64503 .53009 m .65384 .57166 L .66941 .56646 L p .615 .476 .669 r
F P
0 g
s
.66941 .56646 m .65939 .52509 L .64503 .53009 L p .615 .476 .669 r
F P
0 g
s
.61738 .49384 m .60024 .45916 L .61047 .456 L p .66 .651 .83 r
F P
0 g
s
.61047 .456 m .62999 .49002 L .61738 .49384 L p .66 .651 .83 r
F P
0 g
s
.47848 .71602 m .47815 .75243 L .45591 .75304 L p .674 .44 .559 r
F P
0 g
s
.47815 .75243 m .47848 .71602 L .50017 .71453 L p .626 .397 .55 r
F P
0 g
s
.41304 .74753 m .41408 .70995 L .43486 .71377 L p .767 .522 .564 r
F P
0 g
s
.43486 .71377 m .43399 .75142 L .41304 .74753 L p .767 .522 .564 r
F P
0 g
s
.33722 .54911 m .35378 .50773 L .36565 .51358 L p .867 .749 .73 r
F P
0 g
s
.36565 .51358 m .34935 .5557 L .33722 .54911 L p .867 .749 .73 r
F P
0 g
s
.38864 .47513 m .36565 .51358 L .35378 .50773 L p .808 .757 .805 r
F P
0 g
s
.36565 .51358 m .38864 .47513 L .39997 .47982 L p .798 .747 .806 r
F P
0 g
s
.59345 .62648 m .59308 .66109 L .57682 .66551 L p .492 .274 .51 r
F P
0 g
s
.59308 .66109 m .59345 .62648 L .60949 .62293 L p .476 .248 .488 r
F P
0 g
s
.42536 .44797 m .39997 .47982 L .38864 .47513 L p .735 .757 .87 r
F P
0 g
s
.39997 .47982 m .42536 .44797 L .43509 .45151 L p .729 .751 .87 r
F P
0 g
s
.36211 .68917 m .36335 .65198 L .37911 .65906 L p .894 .642 .549 r
F P
0 g
s
.37911 .65906 m .37731 .69742 L .36211 .68917 L p .894 .642 .549 r
F P
0 g
s
.51563 .43944 m .51185 .46662 L .50037 .46555 L p .634 .736 .922 r
F P
0 g
s
.51185 .46662 m .51563 .43944 L .52411 .43988 L p .632 .733 .92 r
F P
0 g
s
.52411 .43988 m .52334 .46728 L .51185 .46662 L p .632 .733 .92 r
F P
0 g
s
.50718 .43869 m .50037 .46555 L .48895 .4641 L p .636 .74 .923 r
F P
0 g
s
.50037 .46555 m .50718 .43869 L .51563 .43944 L p .634 .736 .922 r
F P
0 g
s
.52334 .46728 m .52411 .43988 L .53257 .43999 L p .632 .731 .919 r
F P
0 g
s
.53257 .43999 m .53477 .46752 L .52334 .46728 L p .632 .731 .919 r
F P
0 g
s
.63842 .5762 m .64049 .61475 L .62507 .61901 L p .557 .363 .574 r
F P
0 g
s
.64049 .61475 m .63842 .5762 L .65384 .57166 L p .569 .371 .572 r
F P
0 g
s
.49878 .43764 m .48895 .4641 L .47766 .46228 L p .638 .743 .925 r
F P
0 g
s
.48895 .4641 m .49878 .43764 L .50718 .43869 L p .636 .74 .923 r
F P
0 g
s
.61047 .456 m .62999 .49002 L .64242 .48554 L p .663 .653 .83 r
F P
0 g
s
.65939 .52509 m .64242 .48554 L .62999 .49002 L p .642 .565 .752 r
F P
0 g
s
.53477 .46752 m .53257 .43999 L .54099 .43976 L p .634 .73 .917 r
F P
0 g
s
.54099 .43976 m .5461 .46733 L .53477 .46752 L p .634 .73 .917 r
F P
0 g
s
.64242 .48554 m .65939 .52509 L .67377 .51933 L p .643 .568 .754 r
F P
0 g
s
.65939 .52509 m .66941 .56646 L .68526 .56054 L p .617 .48 .673 r
F P
0 g
s
.68526 .56054 m .67377 .51933 L .65939 .52509 L p .617 .48 .673 r
F P
0 g
s
.50017 .71453 m .50006 .74971 L .47815 .75243 L p .626 .397 .55 r
F P
0 g
s
.50006 .74971 m .50017 .71453 L .52109 .71152 L p .576 .35 .537 r
F P
0 g
s
.32901 .59 m .33722 .54911 L .34935 .5557 L p .921 .737 .636 r
F P
0 g
s
.34935 .5557 m .34044 .59745 L .32901 .59 L p .921 .737 .636 r
F P
0 g
s
.39369 .74152 m .39475 .70444 L .41408 .70995 L p .813 .562 .559 r
F P
0 g
s
.41408 .70995 m .41304 .74753 L .39369 .74152 L p .813 .562 .559 r
F P
0 g
s
.49048 .43629 m .47766 .46228 L .46656 .4601 L p .641 .747 .926 r
F P
0 g
s
.47766 .46228 m .49048 .43629 L .49878 .43764 L p .638 .743 .925 r
F P
0 g
s
.5461 .46733 m .54099 .43976 L .54933 .4392 L p .636 .73 .915 r
F P
0 g
s
.54933 .4392 m .5573 .46667 L .5461 .46733 L p .636 .73 .915 r
F P
0 g
s
.55944 .66953 m .55915 .70202 L .54083 .70724 L p .499 .272 .502 r
F P
0 g
s
.55915 .70202 m .55944 .66953 L .57682 .66551 L p .452 .219 .47 r
F P
0 g
s
.3378 .63589 m .34044 .59745 L .35329 .60455 L p .94 .705 .556 r
F P
0 g
s
.35329 .60455 m .34959 .64418 L .3378 .63589 L p .94 .705 .556 r
F P
0 g
s
.5573 .46667 m .54933 .4392 L .55757 .43827 L p .641 .73 .914 r
F P
0 g
s
.55757 .43827 m .56832 .46555 L .5573 .46667 L p .641 .73 .914 r
F P
0 g
s
.48233 .43466 m .46656 .4601 L .45573 .45758 L p .644 .751 .927 r
F P
0 g
s
.46656 .4601 m .48233 .43466 L .49048 .43629 L p .641 .747 .926 r
F P
0 g
s
.64242 .48554 m .62049 .4523 L .61047 .456 L p .663 .653 .83 r
F P
0 g
s
.62049 .4523 m .64242 .48554 L .6547 .48039 L p .666 .655 .83 r
F P
0 g
s
.67377 .51933 m .6547 .48039 L .64242 .48554 L p .643 .568 .754 r
F P
0 g
s
.6547 .48039 m .67377 .51933 L .68817 .51281 L p .644 .571 .758 r
F P
0 g
s
.67377 .51933 m .68526 .56054 L .70146 .55386 L p .618 .485 .678 r
F P
0 g
s
.70146 .55386 m .68817 .51281 L .67377 .51933 L p .618 .485 .678 r
F P
0 g
s
.65384 .57166 m .65606 .61011 L .64049 .61475 L p .569 .371 .572 r
F P
0 g
s
.65384 .57166 m .65606 .61011 L .67206 .60505 L p .58 .38 .575 r
F P
0 g
s
.67206 .60505 m .66941 .56646 L .65384 .57166 L p .58 .38 .575 r
F P
0 g
s
.35378 .50773 m .37795 .47004 L .38864 .47513 L p .808 .757 .805 r
F P
0 g
s
.41608 .44408 m .38864 .47513 L .37795 .47004 L p .74 .762 .87 r
F P
0 g
s
.38864 .47513 m .41608 .44408 L .42536 .44797 L p .735 .757 .87 r
F P
0 g
s
.60949 .62293 m .60845 .65646 L .59308 .66109 L p .476 .248 .488 r
F P
0 g
s
.60845 .65646 m .60949 .62293 L .62507 .61901 L p .475 .236 .471 r
F P
0 g
s
.56832 .46555 m .55757 .43827 L .56569 .43698 L p .646 .732 .911 r
F P
0 g
s
.56569 .43698 m .57916 .46393 L .56832 .46555 L p .646 .732 .911 r
F P
0 g
s
.32606 .54215 m .34267 .50145 L .35378 .50773 L p .88 .758 .723 r
F P
0 g
s
.35378 .50773 m .33722 .54911 L .32606 .54215 L p .88 .758 .723 r
F P
0 g
s
.37795 .47004 m .35378 .50773 L .34267 .50145 L p .817 .764 .804 r
F P
0 g
s
.47435 .43275 m .45573 .45758 L .44523 .45471 L p .647 .755 .928 r
F P
0 g
s
.45573 .45758 m .47435 .43275 L .48233 .43466 L p .644 .751 .927 r
F P
0 g
s
.52109 .71152 m .52108 .74514 L .50006 .74971 L p .576 .35 .537 r
F P
0 g
s
.52108 .74514 m .52109 .71152 L .54083 .70724 L p .523 .3 .518 r
F P
0 g
s
.57916 .46393 m .56569 .43698 L .57365 .43532 L p .653 .734 .909 r
F P
0 g
s
.57365 .43532 m .5898 .46181 L .57916 .46393 L p .653 .734 .909 r
F P
0 g
s
.6547 .48039 m .63028 .44807 L .62049 .4523 L p .666 .655 .83 r
F P
0 g
s
.63028 .44807 m .6547 .48039 L .66681 .47457 L p .668 .658 .831 r
F P
0 g
s
.68817 .51281 m .66681 .47457 L .6547 .48039 L p .644 .571 .758 r
F P
0 g
s
.37645 .73359 m .37731 .69742 L .39475 .70444 L p .861 .602 .547 r
F P
0 g
s
.39475 .70444 m .39369 .74152 L .37645 .73359 L p .861 .602 .547 r
F P
0 g
s
.66681 .47457 m .68817 .51281 L .70256 .5055 L p .644 .575 .762 r
F P
0 g
s
.68817 .51281 m .70146 .55386 L .71797 .54634 L p .619 .491 .685 r
F P
0 g
s
.71797 .54634 m .70256 .5055 L .68817 .51281 L p .619 .491 .685 r
F P
0 g
s
.66941 .56646 m .67206 .60505 L .68871 .59946 L p .586 .389 .582 r
F P
0 g
s
.68871 .59946 m .68526 .56054 L .66941 .56646 L p .586 .389 .582 r
F P
0 g
s
.34927 .67998 m .34959 .64418 L .36335 .65198 L p .935 .672 .514 r
F P
0 g
s
.36335 .65198 m .36211 .68917 L .34927 .67998 L p .935 .672 .514 r
F P
0 g
s
.46658 .43056 m .44523 .45471 L .43509 .45151 L p .649 .757 .928 r
F P
0 g
s
.44523 .45471 m .46658 .43056 L .47435 .43275 L p .647 .755 .928 r
F P
0 g
s
.5898 .46181 m .57365 .43532 L .58146 .43329 L p .66 .737 .906 r
F P
0 g
s
.58146 .43329 m .60024 .45916 L .5898 .46181 L p .66 .737 .906 r
F P
0 g
s
.57682 .66551 m .57599 .6962 L .55915 .70202 L p .452 .219 .47 r
F P
0 g
s
.57599 .6962 m .57682 .66551 L .59308 .66109 L p .412 .17 .435 r
F P
0 g
s
.34267 .50145 m .36785 .46452 L .37795 .47004 L p .817 .764 .804 r
F P
0 g
s
.40725 .43984 m .37795 .47004 L .36785 .46452 L p .744 .764 .869 r
F P
0 g
s
.37795 .47004 m .40725 .43984 L .41608 .44408 L p .74 .762 .87 r
F P
0 g
s
.31876 .58227 m .32606 .54215 L .33722 .54911 L p .939 .746 .615 r
F P
0 g
s
.33722 .54911 m .32901 .59 L .31876 .58227 L p .939 .746 .615 r
F P
0 g
s
.66681 .47457 m .63981 .44334 L .63028 .44807 L p .668 .658 .831 r
F P
0 g
s
.63981 .44334 m .66681 .47457 L .67871 .46809 L p .669 .661 .833 r
F P
0 g
s
.70256 .5055 m .67871 .46809 L .66681 .47457 L p .644 .575 .762 r
F P
0 g
s
.62507 .61901 m .62329 .65179 L .60845 .65646 L p .475 .236 .471 r
F P
0 g
s
.62329 .65179 m .62507 .61901 L .64049 .61475 L p .489 .24 .463 r
F P
0 g
s
.67871 .46809 m .70256 .5055 L .71686 .49743 L p .643 .579 .768 r
F P
0 g
s
.70256 .5055 m .71797 .54634 L .7347 .53797 L p .617 .497 .693 r
F P
0 g
s
.7347 .53797 m .71686 .49743 L .70256 .5055 L p .617 .497 .693 r
F P
0 g
s
.68526 .56054 m .68871 .59946 L .70613 .59322 L p .591 .4 .591 r
F P
0 g
s
.70613 .59322 m .70146 .55386 L .68526 .56054 L p .591 .4 .591 r
F P
0 g
s
.45906 .4281 m .43509 .45151 L .42536 .44797 L p .652 .759 .928 r
F P
0 g
s
.43509 .45151 m .45906 .4281 L .46658 .43056 L p .649 .757 .928 r
F P
0 g
s
.60024 .45916 m .58146 .43329 L .58908 .43088 L p .668 .74 .904 r
F P
0 g
s
.58908 .43088 m .61047 .456 L .60024 .45916 L p .668 .74 .904 r
F P
0 g
s
.32776 .6273 m .32901 .59 L .34044 .59745 L p .965 .719 .514 r
F P
0 g
s
.34044 .59745 m .3378 .63589 L .32776 .6273 L p .965 .719 .514 r
F P
0 g
s
.31564 .53479 m .33222 .49471 L .34267 .50145 L p .89 .763 .715 r
F P
0 g
s
.34267 .50145 m .32606 .54215 L .31564 .53479 L p .89 .763 .715 r
F P
0 g
s
.36785 .46452 m .34267 .50145 L .33222 .49471 L p .822 .767 .801 r
F P
0 g
s
.54083 .70724 m .54077 .73908 L .52108 .74514 L p .523 .3 .518 r
F P
0 g
s
.54077 .73908 m .54083 .70724 L .55915 .70202 L p .468 .246 .493 r
F P
0 g
s
.433 .78909 m .43399 .75142 L .45591 .75304 L p .72 .485 .569 r
F P
0 g
s
.45591 .75304 m .45518 .79038 L .433 .78909 L p .72 .485 .569 r
F P
0 g
s
.45518 .79038 m .45591 .75304 L .47815 .75243 L p .674 .446 .567 r
F P
0 g
s
.67871 .46809 m .64907 .4381 L .63981 .44334 L p .669 .661 .833 r
F P
0 g
s
.64907 .4381 m .67871 .46809 L .69035 .46098 L p .67 .665 .836 r
F P
0 g
s
.71686 .49743 m .69035 .46098 L .67871 .46809 L p .643 .579 .768 r
F P
0 g
s
.58908 .43088 m .61047 .456 L .62049 .4523 L p .675 .742 .901 r
F P
0 g
s
.41184 .78516 m .41304 .74753 L .43399 .75142 L p .767 .525 .568 r
F P
0 g
s
.43399 .75142 m .433 .78909 L .41184 .78516 L p .767 .525 .568 r
F P
0 g
s
.47815 .75243 m .47768 .78905 L .45518 .79038 L p .674 .446 .567 r
F P
0 g
s
.47768 .78905 m .47815 .75243 L .50006 .74971 L p .627 .406 .563 r
F P
0 g
s
.70146 .55386 m .70613 .59322 L .72429 .58621 L p .595 .411 .602 r
F P
0 g
s
.72429 .58621 m .71797 .54634 L .70146 .55386 L p .595 .411 .602 r
F P
0 g
s
.69035 .46098 m .71686 .49743 L .73094 .4886 L p .641 .583 .774 r
F P
0 g
s
.71686 .49743 m .7347 .53797 L .75143 .52872 L p .613 .502 .703 r
F P
0 g
s
.75143 .52872 m .73094 .4886 L .71686 .49743 L p .613 .502 .703 r
F P
0 g
s
.45181 .42537 m .42536 .44797 L .41608 .44408 L p .654 .759 .927 r
F P
0 g
s
.42536 .44797 m .45181 .42537 L .45906 .4281 L p .652 .759 .928 r
F P
0 g
s
.36169 .72409 m .36211 .68917 L .37731 .69742 L p .908 .642 .523 r
F P
0 g
s
.37731 .69742 m .37645 .73359 L .36169 .72409 L p .908 .642 .523 r
F P
0 g
s
.64049 .61475 m .63802 .64713 L .62329 .65179 L p .489 .24 .463 r
F P
0 g
s
.63802 .64713 m .64049 .61475 L .65606 .61011 L p .516 .259 .464 r
F P
0 g
s
.33222 .49471 m .35832 .45854 L .36785 .46452 L p .822 .767 .801 r
F P
0 g
s
.39888 .43523 m .36785 .46452 L .35832 .45854 L p .747 .764 .867 r
F P
0 g
s
.36785 .46452 m .39888 .43523 L .40725 .43984 L p .744 .764 .869 r
F P
0 g
s
.62049 .4523 m .59649 .4281 L .58908 .43088 L p .675 .742 .901 r
F P
0 g
s
.59649 .4281 m .62049 .4523 L .63028 .44807 L p .68 .744 .9 r
F P
0 g
s
.59308 .66109 m .59148 .69015 L .57599 .6962 L p .412 .17 .435 r
F P
0 g
s
.59148 .69015 m .59308 .66109 L .60845 .65646 L p .387 .132 .401 r
F P
0 g
s
.71797 .54634 m .72429 .58621 L .74306 .57833 L p .594 .42 .615 r
F P
0 g
s
.74306 .57833 m .7347 .53797 L .71797 .54634 L p .594 .42 .615 r
F P
0 g
s
.69035 .46098 m .658 .43239 L .64907 .4381 L p .67 .665 .836 r
F P
0 g
s
.658 .43239 m .69035 .46098 L .70164 .45328 L p .67 .668 .84 r
F P
0 g
s
.73094 .4886 m .70164 .45328 L .69035 .46098 L p .641 .583 .774 r
F P
0 g
s
.50006 .74971 m .49983 .78529 L .47768 .78905 L p .627 .406 .563 r
F P
0 g
s
.49983 .78529 m .50006 .74971 L .52108 .74514 L p .579 .366 .556 r
F P
0 g
s
.39233 .77871 m .39369 .74152 L .41304 .74753 L p .814 .566 .563 r
F P
0 g
s
.41304 .74753 m .41184 .78516 L .39233 .77871 L p .814 .566 .563 r
F P
0 g
s
.33876 .67021 m .3378 .63589 L .34959 .64418 L p .967 .693 .46 r
F P
0 g
s
.34959 .64418 m .34927 .67998 L .33876 .67021 L p .967 .693 .46 r
F P
0 g
s
.44486 .42236 m .41608 .44408 L .40725 .43984 L p .655 .758 .925 r
F P
0 g
s
.41608 .44408 m .44486 .42236 L .45181 .42537 L p .654 .759 .927 r
F P
0 g
s
.70164 .45328 m .73094 .4886 L .74461 .47909 L p .637 .587 .782 r
F P
0 g
s
.73094 .4886 m .75143 .52872 L .76789 .51863 L p .607 .506 .713 r
F P
0 g
s
.76789 .51863 m .74461 .47909 L .73094 .4886 L p .607 .506 .713 r
F P
0 g
s
.30934 .57431 m .31564 .53479 L .32606 .54215 L p .951 .748 .592 r
F P
0 g
s
.32606 .54215 m .31876 .58227 L .30934 .57431 L p .951 .748 .592 r
F P
0 g
s
.63028 .44807 m .60369 .42495 L .59649 .4281 L p .68 .744 .9 r
F P
0 g
s
.60369 .42495 m .63028 .44807 L .63981 .44334 L p .685 .747 .899 r
F P
0 g
s
.65606 .61011 m .65308 .64251 L .63802 .64713 L p .516 .259 .464 r
F P
0 g
s
.65606 .61011 m .65308 .64251 L .66889 .63783 L p .54 .282 .473 r
F P
0 g
s
.66889 .63783 m .67206 .60505 L .65606 .61011 L p .54 .282 .473 r
F P
0 g
s
.30572 .52697 m .3223 .48744 L .33222 .49471 L p .896 .762 .707 r
F P
0 g
s
.33222 .49471 m .31564 .53479 L .30572 .52697 L p .896 .762 .707 r
F P
0 g
s
.35832 .45854 m .33222 .49471 L .3223 .48744 L p .826 .767 .797 r
F P
0 g
s
.55915 .70202 m .55885 .73197 L .54077 .73908 L p .468 .246 .493 r
F P
0 g
s
.55885 .73197 m .55915 .70202 L .57599 .6962 L p .415 .191 .464 r
F P
0 g
s
.7347 .53797 m .74306 .57833 L .76215 .5695 L p .59 .427 .628 r
F P
0 g
s
.76215 .5695 m .75143 .52872 L .7347 .53797 L p .59 .427 .628 r
F P
0 g
s
.70164 .45328 m .66654 .42625 L .658 .43239 L p .67 .668 .84 r
F P
0 g
s
.66654 .42625 m .70164 .45328 L .71246 .44505 L p .669 .672 .844 r
F P
0 g
s
.74461 .47909 m .71246 .44505 L .70164 .45328 L p .637 .587 .782 r
F P
0 g
s
.3223 .48744 m .34931 .45208 L .35832 .45854 L p .826 .767 .797 r
F P
0 g
s
.39097 .43024 m .35832 .45854 L .34931 .45208 L p .748 .762 .864 r
F P
0 g
s
.35832 .45854 m .39097 .43024 L .39888 .43523 L p .747 .764 .867 r
F P
0 g
s
.63981 .44334 m .61064 .42145 L .60369 .42495 L p .685 .747 .899 r
F P
0 g
s
.61064 .42145 m .63981 .44334 L .64907 .4381 L p .689 .749 .898 r
F P
0 g
s
.31912 .61859 m .31876 .58227 L .32901 .59 L p .98 .719 .461 r
F P
0 g
s
.32901 .59 m .32776 .6273 L .31912 .61859 L p .98 .719 .461 r
F P
0 g
s
.43824 .41908 m .40725 .43984 L .39888 .43523 L p .657 .755 .922 r
F P
0 g
s
.40725 .43984 m .43824 .41908 L .44486 .42236 L p .655 .758 .925 r
F P
0 g
s
.52108 .74514 m .52104 .77941 L .49983 .78529 L p .579 .366 .556 r
F P
0 g
s
.52104 .77941 m .52108 .74514 L .54077 .73908 L p .531 .326 .547 r
F P
0 g
s
.67206 .60505 m .66889 .63783 L .68575 .63297 L p .556 .302 .486 r
F P
0 g
s
.68575 .63297 m .68871 .59946 L .67206 .60505 L p .556 .302 .486 r
F P
0 g
s
.71246 .44505 m .74461 .47909 L .75766 .46896 L p .631 .591 .79 r
F P
0 g
s
.74461 .47909 m .76789 .51863 L .78375 .50775 L p .597 .509 .725 r
F P
0 g
s
.78375 .50775 m .75766 .46896 L .74461 .47909 L p .597 .509 .725 r
F P
0 g
s
.37502 .76999 m .37645 .73359 L .39369 .74152 L p .862 .608 .553 r
F P
0 g
s
.39369 .74152 m .39233 .77871 L .37502 .76999 L p .862 .608 .553 r
F P
0 g
s
.60845 .65646 m .6059 .68418 L .59148 .69015 L p .387 .132 .401 r
F P
0 g
s
.6059 .68418 m .60845 .65646 L .62329 .65179 L p .387 .116 .377 r
F P
0 g
s
.34957 .71342 m .34927 .67998 L .36211 .68917 L p .951 .676 .482 r
F P
0 g
s
.36211 .68917 m .36169 .72409 L .34957 .71342 L p .951 .676 .482 r
F P
0 g
s
.75143 .52872 m .76215 .5695 L .78118 .55968 L p .582 .431 .642 r
F P
0 g
s
.78118 .55968 m .76789 .51863 L .75143 .52872 L p .582 .431 .642 r
F P
0 g
s
.51918 .42074 m .51563 .43944 L .50718 .43869 L p .571 .776 .976 r
F P
0 g
s
.51563 .43944 m .51918 .42074 L .52483 .42098 L p .577 .78 .976 r
F P
0 g
s
.52483 .42098 m .52411 .43988 L .51563 .43944 L p .577 .78 .976 r
F P
0 g
s
.52411 .43988 m .52483 .42098 L .53049 .42099 L p .583 .784 .975 r
F P
0 g
s
.53049 .42099 m .53257 .43999 L .52411 .43988 L p .583 .784 .975 r
F P
0 g
s
.64907 .4381 m .61732 .41761 L .61064 .42145 L p .689 .749 .898 r
F P
0 g
s
.61732 .41761 m .64907 .4381 L .658 .43239 L p .693 .752 .897 r
F P
0 g
s
.51355 .42028 m .50718 .43869 L .49878 .43764 L p .567 .773 .976 r
F P
0 g
s
.50718 .43869 m .51355 .42028 L .51918 .42074 L p .571 .776 .976 r
F P
0 g
s
.53257 .43999 m .53049 .42099 L .53612 .42078 L p .591 .789 .974 r
F P
0 g
s
.53612 .42078 m .54099 .43976 L .53257 .43999 L p .591 .789 .974 r
F P
0 g
s
.71246 .44505 m .67465 .41972 L .66654 .42625 L p .669 .672 .844 r
F P
0 g
s
.67465 .41972 m .71246 .44505 L .72269 .43635 L p .667 .676 .849 r
F P
0 g
s
.75766 .46896 m .72269 .43635 L .71246 .44505 L p .631 .591 .79 r
F P
0 g
s
.50797 .4196 m .49878 .43764 L .49048 .43629 L p .563 .77 .975 r
F P
0 g
s
.49878 .43764 m .50797 .4196 L .51355 .42028 L p .567 .773 .976 r
F P
0 g
s
.54099 .43976 m .53612 .42078 L .54171 .42033 L p .6 .794 .973 r
F P
0 g
s
.54171 .42033 m .54933 .4392 L .54099 .43976 L p .6 .794 .973 r
F P
0 g
s
.68871 .59946 m .68575 .63297 L .70385 .62773 L p .57 .324 .503 r
F P
0 g
s
.70385 .62773 m .70613 .59322 L .68871 .59946 L p .57 .324 .503 r
F P
0 g
s
.54933 .4392 m .54171 .42033 L .54724 .41964 L p .611 .799 .971 r
F P
0 g
s
.54724 .41964 m .55757 .43827 L .54933 .4392 L p .611 .799 .971 r
F P
0 g
s
.43194 .41551 m .39888 .43523 L .39097 .43024 L p .657 .751 .919 r
F P
0 g
s
.39888 .43523 m .43194 .41551 L .43824 .41908 L p .657 .755 .922 r
F P
0 g
s
.50246 .41871 m .49048 .43629 L .48233 .43466 L p .561 .767 .975 r
F P
0 g
s
.49048 .43629 m .50246 .41871 L .50797 .4196 L p .563 .77 .975 r
F P
0 g
s
.31278 .47959 m .34075 .44508 L .34931 .45208 L p .827 .764 .793 r
F P
0 g
s
.34931 .45208 m .3223 .48744 L .31278 .47959 L p .827 .764 .793 r
F P
0 g
s
.38352 .42484 m .34931 .45208 L .34075 .44508 L p .749 .758 .86 r
F P
0 g
s
.34931 .45208 m .38352 .42484 L .39097 .43024 L p .748 .762 .864 r
F P
0 g
s
.29603 .51863 m .31278 .47959 L .3223 .48744 L p .897 .757 .699 r
F P
0 g
s
.3223 .48744 m .30572 .52697 L .29603 .51863 L p .897 .757 .699 r
F P
0 g
s
.30033 .56607 m .30572 .52697 L .31564 .53479 L p .956 .741 .571 r
F P
0 g
s
.31564 .53479 m .30934 .57431 L .30033 .56607 L p .956 .741 .571 r
F P
0 g
s
.55757 .43827 m .54724 .41964 L .55269 .41871 L p .622 .804 .969 r
F P
0 g
s
.55269 .41871 m .56569 .43698 L .55757 .43827 L p .622 .804 .969 r
F P
0 g
s
.49703 .41761 m .48233 .43466 L .47435 .43275 L p .559 .763 .974 r
F P
0 g
s
.48233 .43466 m .49703 .41761 L .50246 .41871 L p .561 .767 .975 r
F P
0 g
s
.43168 .82871 m .433 .78909 L .45518 .79038 L p .723 .494 .578 r
F P
0 g
s
.45518 .79038 m .45415 .82977 L .43168 .82871 L p .723 .494 .578 r
F P
0 g
s
.45415 .82977 m .45518 .79038 L .47768 .78905 L p .68 .459 .579 r
F P
0 g
s
.72269 .43635 m .75766 .46896 L .76984 .45831 L p .624 .594 .8 r
F P
0 g
s
.75766 .46896 m .78375 .50775 L .79863 .4962 L p .585 .51 .737 r
F P
0 g
s
.79863 .4962 m .76984 .45831 L .75766 .46896 L p .585 .51 .737 r
F P
0 g
s
.57599 .6962 m .57525 .72428 L .55885 .73197 L p .415 .191 .464 r
F P
0 g
s
.57525 .72428 m .57599 .6962 L .59148 .69015 L p .37 .141 .431 r
F P
0 g
s
.3303 .66018 m .32776 .6273 L .3378 .63589 L p .982 .695 .381 r
F P
0 g
s
.3378 .63589 m .33876 .67021 L .3303 .66018 L p .982 .695 .381 r
F P
0 g
s
.658 .43239 m .62369 .41345 L .61732 .41761 L p .693 .752 .897 r
F P
0 g
s
.62369 .41345 m .658 .43239 L .66654 .42625 L p .696 .755 .897 r
F P
0 g
s
.76789 .51863 m .78118 .55968 L .79968 .54891 L p .569 .432 .655 r
F P
0 g
s
.79968 .54891 m .78375 .50775 L .76789 .51863 L p .569 .432 .655 r
F P
0 g
s
.70613 .59322 m .70385 .62773 L .72318 .6219 L p .579 .343 .522 r
F P
0 g
s
.72318 .6219 m .72429 .58621 L .70613 .59322 L p .579 .343 .522 r
F P
0 g
s
.56569 .43698 m .55269 .41871 L .55804 .41755 L p .634 .809 .967 r
F P
0 g
s
.55804 .41755 m .57365 .43532 L .56569 .43698 L p .634 .809 .967 r
F P
0 g
s
.47768 .78905 m .47693 .828 L .45415 .82977 L p .68 .459 .579 r
F P
0 g
s
.47693 .828 m .47768 .78905 L .49983 .78529 L p .638 .427 .581 r
F P
0 g
s
.54077 .73908 m .54086 .77186 L .52104 .77941 L p .531 .326 .547 r
F P
0 g
s
.54086 .77186 m .54077 .73908 L .55885 .73197 L p .484 .287 .537 r
F P
0 g
s
.4102 .82476 m .41184 .78516 L .433 .78909 L p .767 .53 .576 r
F P
0 g
s
.433 .78909 m .43168 .82871 L .4102 .82476 L p .767 .53 .576 r
F P
0 g
s
.49172 .4163 m .47435 .43275 L .46658 .43056 L p .557 .76 .972 r
F P
0 g
s
.47435 .43275 m .49172 .4163 L .49703 .41761 L p .559 .763 .974 r
F P
0 g
s
.62329 .65179 m .61973 .67854 L .6059 .68418 L p .387 .116 .377 r
F P
0 g
s
.61973 .67854 m .62329 .65179 L .63802 .64713 L p .415 .129 .368 r
F P
0 g
s
.72269 .43635 m .68224 .41285 L .67465 .41972 L p .667 .676 .849 r
F P
0 g
s
.68224 .41285 m .72269 .43635 L .73219 .42726 L p .664 .679 .855 r
F P
0 g
s
.76984 .45831 m .73219 .42726 L .72269 .43635 L p .624 .594 .8 r
F P
0 g
s
.57365 .43532 m .55804 .41755 L .56327 .41614 L p .647 .813 .963 r
F P
0 g
s
.56327 .41614 m .58146 .43329 L .57365 .43532 L p .647 .813 .963 r
F P
0 g
s
.36027 .75939 m .36169 .72409 L .37645 .73359 L p .909 .651 .536 r
F P
0 g
s
.37645 .73359 m .37502 .76999 L .36027 .75939 L p .909 .651 .536 r
F P
0 g
s
.72429 .58621 m .72318 .6219 L .74355 .61527 L p .582 .358 .541 r
F P
0 g
s
.74355 .61527 m .74306 .57833 L .72429 .58621 L p .582 .358 .541 r
F P
0 g
s
.42601 .41167 m .39097 .43024 L .38352 .42484 L p .658 .745 .914 r
F P
0 g
s
.39097 .43024 m .42601 .41167 L .43194 .41551 L p .657 .751 .919 r
F P
0 g
s
.48655 .4148 m .46658 .43056 L .45906 .4281 L p .557 .755 .97 r
F P
0 g
s
.46658 .43056 m .48655 .4148 L .49172 .4163 L p .557 .76 .972 r
F P
0 g
s
.66654 .42625 m .62974 .409 L .62369 .41345 L p .696 .755 .897 r
F P
0 g
s
.62974 .409 m .66654 .42625 L .67465 .41972 L p .698 .757 .897 r
F P
0 g
s
.58146 .43329 m .56327 .41614 L .56836 .4145 L p .66 .818 .959 r
F P
0 g
s
.56836 .4145 m .58908 .43088 L .58146 .43329 L p .66 .818 .959 r
F P
0 g
s
.49983 .78529 m .49939 .82361 L .47693 .828 L p .638 .427 .581 r
F P
0 g
s
.49939 .82361 m .49983 .78529 L .52104 .77941 L p .598 .398 .582 r
F P
0 g
s
.31137 .60987 m .30934 .57431 L .31876 .58227 L p .983 .705 .405 r
F P
0 g
s
.31876 .58227 m .31912 .61859 L .31137 .60987 L p .983 .705 .405 r
F P
0 g
s
.39033 .81805 m .39233 .77871 L .41184 .78516 L p .811 .569 .573 r
F P
0 g
s
.41184 .78516 m .4102 .82476 L .39033 .81805 L p .811 .569 .573 r
F P
0 g
s
.48153 .41309 m .45906 .4281 L .45181 .42537 L p .556 .751 .968 r
F P
0 g
s
.45906 .4281 m .48153 .41309 L .48655 .4148 L p .557 .755 .97 r
F P
0 g
s
.30352 .47109 m .33262 .43752 L .34075 .44508 L p .826 .758 .788 r
F P
0 g
s
.34075 .44508 m .31278 .47959 L .30352 .47109 L p .826 .758 .788 r
F P
0 g
s
.37652 .41903 m .34075 .44508 L .33262 .43752 L p .748 .752 .856 r
F P
0 g
s
.34075 .44508 m .37652 .41903 L .38352 .42484 L p .749 .758 .86 r
F P
0 g
s
.78375 .50775 m .79968 .54891 L .8171 .53725 L p .55 .429 .668 r
F P
0 g
s
.8171 .53725 m .79863 .4962 L .78375 .50775 L p .55 .429 .668 r
F P
0 g
s
.74306 .57833 m .74355 .61527 L .76462 .60767 L p .578 .368 .559 r
F P
0 g
s
.76462 .60767 m .76215 .5695 L .74306 .57833 L p .578 .368 .559 r
F P
0 g
s
.73219 .42726 m .76984 .45831 L .78091 .44728 L p .614 .597 .81 r
F P
0 g
s
.76984 .45831 m .79863 .4962 L .81216 .48411 L p .568 .51 .75 r
F P
0 g
s
.81216 .48411 m .78091 .44728 L .76984 .45831 L p .568 .51 .75 r
F P
0 g
s
.56836 .4145 m .58908 .43088 L .59649 .4281 L p .671 .821 .956 r
F P
0 g
s
.34001 .70203 m .33876 .67021 L .34927 .67998 L p .979 .699 .417 r
F P
0 g
s
.34927 .67998 m .34957 .71342 L .34001 .70203 L p .979 .699 .417 r
F P
0 g
s
.28634 .50965 m .30352 .47109 L .31278 .47959 L p .894 .748 .692 r
F P
0 g
s
.31278 .47959 m .29603 .51863 L .28634 .50965 L p .894 .748 .692 r
F P
0 g
s
.63802 .64713 m .63349 .6734 L .61973 .67854 L p .415 .129 .368 r
F P
0 g
s
.63349 .6734 m .63802 .64713 L .65308 .64251 L p .465 .168 .376 r
F P
0 g
s
.73219 .42726 m .68924 .4057 L .68224 .41285 L p .664 .679 .855 r
F P
0 g
s
.68924 .4057 m .73219 .42726 L .74081 .41788 L p .66 .683 .861 r
F P
0 g
s
.78091 .44728 m .74081 .41788 L .73219 .42726 L p .614 .597 .81 r
F P
0 g
s
.67465 .41972 m .63542 .40429 L .62974 .409 L p .698 .757 .897 r
F P
0 g
s
.63542 .40429 m .67465 .41972 L .68224 .41285 L p .7 .759 .897 r
F P
0 g
s
.47669 .41119 m .45181 .42537 L .44486 .42236 L p .556 .745 .965 r
F P
0 g
s
.45181 .42537 m .47669 .41119 L .48153 .41309 L p .556 .751 .968 r
F P
0 g
s
.42043 .40753 m .38352 .42484 L .37652 .41903 L p .658 .739 .909 r
F P
0 g
s
.38352 .42484 m .42043 .40753 L .42601 .41167 L p .658 .745 .914 r
F P
0 g
s
.59649 .4281 m .5733 .41263 L .56836 .4145 L p .671 .821 .956 r
F P
0 g
s
.5733 .41263 m .59649 .4281 L .60369 .42495 L p .68 .823 .952 r
F P
0 g
s
.29133 .5575 m .29603 .51863 L .30572 .52697 L p .955 .727 .555 r
F P
0 g
s
.30572 .52697 m .30033 .56607 L .29133 .5575 L p .955 .727 .555 r
F P
0 g
s
.59148 .69015 m .59014 .71651 L .57525 .72428 L p .37 .141 .431 r
F P
0 g
s
.59014 .71651 m .59148 .69015 L .6059 .68418 L p .345 .106 .401 r
F P
0 g
s
.76215 .5695 m .76462 .60767 L .78587 .59896 L p .568 .372 .575 r
F P
0 g
s
.78587 .59896 m .78118 .55968 L .76215 .5695 L p .568 .372 .575 r
F P
0 g
s
.55885 .73197 m .55901 .76315 L .54086 .77186 L p .484 .287 .537 r
F P
0 g
s
.55901 .76315 m .55885 .73197 L .57525 .72428 L p .442 .251 .526 r
F P
0 g
s
.52104 .77941 m .52095 .81694 L .49939 .82361 L p .598 .398 .582 r
F P
0 g
s
.52095 .81694 m .52104 .77941 L .54086 .77186 L p .56 .372 .584 r
F P
0 g
s
.60369 .42495 m .57807 .41054 L .5733 .41263 L p .68 .823 .952 r
F P
0 g
s
.57807 .41054 m .60369 .42495 L .61064 .42145 L p .689 .825 .948 r
F P
0 g
s
.47204 .4091 m .44486 .42236 L .43824 .41908 L p .557 .739 .961 r
F P
0 g
s
.44486 .42236 m .47204 .4091 L .47669 .41119 L p .556 .745 .965 r
F P
0 g
s
.37257 .80883 m .37502 .76999 L .39233 .77871 L p .855 .611 .568 r
F P
0 g
s
.39233 .77871 m .39033 .81805 L .37257 .80883 L p .855 .611 .568 r
F P
0 g
s
.32342 .65019 m .31912 .61859 L .32776 .6273 L p .971 .672 .282 r
F P
0 g
s
.32776 .6273 m .3303 .66018 L .32342 .65019 L p .971 .672 .282 r
F P
0 g
s
.79863 .4962 m .8171 .53725 L .8329 .52485 L p .524 .423 .682 r
F P
0 g
s
.8329 .52485 m .81216 .48411 L .79863 .4962 L p .524 .423 .682 r
F P
0 g
s
.29445 .46187 m .32487 .42936 L .33262 .43752 L p .824 .752 .784 r
F P
0 g
s
.33262 .43752 m .30352 .47109 L .29445 .46187 L p .824 .752 .784 r
F P
0 g
s
.36995 .4128 m .33262 .43752 L .32487 .42936 L p .747 .746 .851 r
F P
0 g
s
.33262 .43752 m .36995 .4128 L .37652 .41903 L p .748 .752 .856 r
F P
0 g
s
.65308 .64251 m .64776 .66878 L .63349 .6734 L p .465 .168 .376 r
F P
0 g
s
.65308 .64251 m .64776 .66878 L .66308 .66462 L p .51 .211 .395 r
F P
0 g
s
.66308 .66462 m .66889 .63783 L .65308 .64251 L p .51 .211 .395 r
F P
0 g
s
.68224 .41285 m .64069 .39934 L .63542 .40429 L p .7 .759 .897 r
F P
0 g
s
.64069 .39934 m .68224 .41285 L .68924 .4057 L p .702 .761 .898 r
F P
0 g
s
.74081 .41788 m .78091 .44728 L .79065 .43599 L p .602 .6 .821 r
F P
0 g
s
.78091 .44728 m .81216 .48411 L .82396 .47166 L p .546 .507 .763 r
F P
0 g
s
.82396 .47166 m .79065 .43599 L .78091 .44728 L p .546 .507 .763 r
F P
0 g
s
.61064 .42145 m .58265 .40823 L .57807 .41054 L p .689 .825 .948 r
F P
0 g
s
.58265 .40823 m .61064 .42145 L .61732 .41761 L p .697 .827 .945 r
F P
0 g
s
.34826 .74739 m .34957 .71342 L .36169 .72409 L p .952 .693 .508 r
F P
0 g
s
.36169 .72409 m .36027 .75939 L .34826 .74739 L p .952 .693 .508 r
F P
0 g
s
.78118 .55968 m .78587 .59896 L .80666 .5891 L p .551 .37 .589 r
F P
0 g
s
.80666 .5891 m .79968 .54891 L .78118 .55968 L p .551 .37 .589 r
F P
0 g
s
.41523 .40312 m .37652 .41903 L .36995 .4128 L p .659 .732 .904 r
F P
0 g
s
.37652 .41903 m .41523 .40312 L .42043 .40753 L p .658 .739 .909 r
F P
0 g
s
.46761 .40681 m .43824 .41908 L .43194 .41551 L p .558 .732 .957 r
F P
0 g
s
.43824 .41908 m .46761 .40681 L .47204 .4091 L p .557 .739 .961 r
F P
0 g
s
.74081 .41788 m .69558 .39833 L .68924 .4057 L p .66 .683 .861 r
F P
0 g
s
.69558 .39833 m .74081 .41788 L .74842 .4083 L p .655 .686 .867 r
F P
0 g
s
.79065 .43599 m .74842 .4083 L .74081 .41788 L p .602 .6 .821 r
F P
0 g
s
.27647 .49994 m .29445 .46187 L .30352 .47109 L p .889 .738 .688 r
F P
0 g
s
.30352 .47109 m .28634 .50965 L .27647 .49994 L p .889 .738 .688 r
F P
0 g
s
.30394 .60116 m .30033 .56607 L .30934 .57431 L p .978 .68 .358 r
F P
0 g
s
.30934 .57431 m .31137 .60987 L .30394 .60116 L p .978 .68 .358 r
F P
0 g
s
.61732 .41761 m .58702 .40571 L .58265 .40823 L p .697 .827 .945 r
F P
0 g
s
.58702 .40571 m .61732 .41761 L .62369 .41345 L p .705 .829 .941 r
F P
0 g
s
.66889 .63783 m .66308 .66462 L .67983 .66073 L p .543 .25 .419 r
F P
0 g
s
.67983 .66073 m .68575 .63297 L .66889 .63783 L p .543 .25 .419 r
F P
0 g
s
.43051 .87048 m .43168 .82871 L .45415 .82977 L p .726 .492 .573 r
F P
0 g
s
.45415 .82977 m .45319 .87146 L .43051 .87048 L p .726 .492 .573 r
F P
0 g
s
.45319 .87146 m .45415 .82977 L .47693 .828 L p .687 .463 .577 r
F P
0 g
s
.54086 .77186 m .54117 .80849 L .52095 .81694 L p .56 .372 .584 r
F P
0 g
s
.54117 .80849 m .54086 .77186 L .55901 .76315 L p .526 .352 .587 r
F P
0 g
s
.6059 .68418 m .60384 .7091 L .59014 .71651 L p .345 .106 .401 r
F P
0 g
s
.60384 .7091 m .6059 .68418 L .61973 .67854 L p .351 .097 .381 r
F P
0 g
s
.47693 .828 m .47618 .86958 L .45319 .87146 L p .687 .463 .577 r
F P
0 g
s
.47618 .86958 m .47693 .828 L .49939 .82361 L p .651 .438 .582 r
F P
0 g
s
.68924 .4057 m .64553 .39419 L .64069 .39934 L p .702 .761 .898 r
F P
0 g
s
.64553 .39419 m .68924 .4057 L .69558 .39833 L p .702 .763 .899 r
F P
0 g
s
.4634 .40434 m .43194 .41551 L .42601 .41167 L p .56 .725 .951 r
F P
0 g
s
.43194 .41551 m .4634 .40434 L .46761 .40681 L p .558 .732 .957 r
F P
0 g
s
.28194 .54845 m .28634 .50965 L .29603 .51863 L p .947 .71 .547 r
F P
0 g
s
.29603 .51863 m .29133 .5575 L .28194 .54845 L p .947 .71 .547 r
F P
0 g
s
.40873 .86657 m .4102 .82476 L .43168 .82871 L p .765 .525 .57 r
F P
0 g
s
.43168 .82871 m .43051 .87048 L .40873 .86657 L p .765 .525 .57 r
F P
0 g
s
.79968 .54891 m .80666 .5891 L .8263 .57812 L p .526 .362 .602 r
F P
0 g
s
.8263 .57812 m .8171 .53725 L .79968 .54891 L p .526 .362 .602 r
F P
0 g
s
.57525 .72428 m .57542 .75389 L .55901 .76315 L p .442 .251 .526 r
F P
0 g
s
.57542 .75389 m .57525 .72428 L .59014 .71651 L p .411 .225 .515 r
F P
0 g
s
.32487 .42936 m .36384 .40613 L .36995 .4128 L p .747 .746 .851 r
F P
0 g
s
.41041 .39841 m .36995 .4128 L .36384 .40613 L p .659 .725 .898 r
F P
0 g
s
.36995 .4128 m .41041 .39841 L .41523 .40312 L p .659 .732 .904 r
F P
0 g
s
.28552 .45188 m .3175 .42058 L .32487 .42936 L p .821 .746 .781 r
F P
0 g
s
.32487 .42936 m .29445 .46187 L .28552 .45188 L p .821 .746 .781 r
F P
0 g
s
.36384 .40613 m .32487 .42936 L .3175 .42058 L p .745 .74 .847 r
F P
0 g
s
.68575 .63297 m .67983 .66073 L .69824 .65684 L p .569 .285 .446 r
F P
0 g
s
.69824 .65684 m .70385 .62773 L .68575 .63297 L p .569 .285 .446 r
F P
0 g
s
.62369 .41345 m .59117 .403 L .58702 .40571 L p .705 .829 .941 r
F P
0 g
s
.59117 .403 m .62369 .41345 L .62974 .409 L p .712 .829 .937 r
F P
0 g
s
.33271 .69039 m .3303 .66018 L .33876 .67021 L p .981 .697 .325 r
F P
0 g
s
.33876 .67021 m .34001 .70203 L .33271 .69039 L p .981 .697 .325 r
F P
0 g
s
.49939 .82361 m .4989 .86507 L .47618 .86958 L p .651 .438 .582 r
F P
0 g
s
.4989 .86507 m .49939 .82361 L .52095 .81694 L p .617 .417 .589 r
F P
0 g
s
.35731 .79753 m .36027 .75939 L .37502 .76999 L p .898 .654 .561 r
F P
0 g
s
.37502 .76999 m .37257 .80883 L .35731 .79753 L p .898 .654 .561 r
F P
0 g
s
.81216 .48411 m .8329 .52485 L .84656 .51191 L p .49 .411 .695 r
F P
0 g
s
.84656 .51191 m .82396 .47166 L .81216 .48411 L p .49 .411 .695 r
F P
0 g
s
.45943 .40169 m .42601 .41167 L .42043 .40753 L p .562 .717 .945 r
F P
0 g
s
.42601 .41167 m .45943 .40169 L .4634 .40434 L p .56 .725 .951 r
F P
0 g
s
.70385 .62773 m .69824 .65684 L .71834 .65262 L p .585 .314 .472 r
F P
0 g
s
.71834 .65262 m .72318 .6219 L .70385 .62773 L p .585 .314 .472 r
F P
0 g
s
.74842 .4083 m .70119 .39079 L .69558 .39833 L p .655 .686 .867 r
F P
0 g
s
.70119 .39079 m .74842 .4083 L .75491 .39862 L p .649 .689 .874 r
F P
0 g
s
.74842 .4083 m .79065 .43599 L .79884 .42458 L p .588 .602 .833 r
F P
0 g
s
.79884 .42458 m .75491 .39862 L .74842 .4083 L p .588 .602 .833 r
F P
0 g
s
.79065 .43599 m .82396 .47166 L .83372 .45904 L p .519 .503 .778 r
F P
0 g
s
.83372 .45904 m .79884 .42458 L .79065 .43599 L p .519 .503 .778 r
F P
0 g
s
.3884 .85986 m .39033 .81805 L .4102 .82476 L p .806 .561 .567 r
F P
0 g
s
.4102 .82476 m .40873 .86657 L .3884 .85986 L p .806 .561 .567 r
F P
0 g
s
.62974 .409 m .59507 .40011 L .59117 .403 L p .712 .829 .937 r
F P
0 g
s
.59507 .40011 m .62974 .409 L .63542 .40429 L p .719 .83 .934 r
F P
0 g
s
.26632 .48937 m .28552 .45188 L .29445 .46187 L p .883 .729 .686 r
F P
0 g
s
.29445 .46187 m .27647 .49994 L .26632 .48937 L p .883 .729 .686 r
F P
0 g
s
.69558 .39833 m .6499 .38887 L .64553 .39419 L p .702 .763 .899 r
F P
0 g
s
.6499 .38887 m .69558 .39833 L .70119 .39079 L p .702 .764 .9 r
F P
0 g
s
.72318 .6219 m .71834 .65262 L .73989 .64777 L p .591 .333 .495 r
F P
0 g
s
.73989 .64777 m .74355 .61527 L .72318 .6219 L p .591 .333 .495 r
F P
0 g
s
.31749 .64045 m .31137 .60987 L .31912 .61859 L p .942 .626 .183 r
F P
0 g
s
.31912 .61859 m .32342 .65019 L .31749 .64045 L p .942 .626 .183 r
F P
0 g
s
.3175 .42058 m .35818 .39903 L .36384 .40613 L p .745 .74 .847 r
F P
0 g
s
.40599 .39344 m .36384 .40613 L .35818 .39903 L p .659 .718 .892 r
F P
0 g
s
.36384 .40613 m .40599 .39344 L .41041 .39841 L p .659 .725 .898 r
F P
0 g
s
.52095 .81694 m .52083 .85829 L .4989 .86507 L p .617 .417 .589 r
F P
0 g
s
.52083 .85829 m .52095 .81694 L .54117 .80849 L p .588 .401 .597 r
F P
0 g
s
.61973 .67854 m .6169 .70242 L .60384 .7091 L p .351 .097 .381 r
F P
0 g
s
.6169 .70242 m .61973 .67854 L .63349 .6734 L p .395 .122 .378 r
F P
0 g
s
.45571 .39886 m .42043 .40753 L .41523 .40312 L p .564 .709 .939 r
F P
0 g
s
.42043 .40753 m .45571 .39886 L .45943 .40169 L p .562 .717 .945 r
F P
0 g
s
.55901 .76315 m .55979 .79885 L .54117 .80849 L p .526 .352 .587 r
F P
0 g
s
.55979 .79885 m .55901 .76315 L .57542 .75389 L p .501 .338 .592 r
F P
0 g
s
.8171 .53725 m .8263 .57812 L .84406 .56614 L p .49 .347 .614 r
F P
0 g
s
.84406 .56614 m .8329 .52485 L .8171 .53725 L p .49 .347 .614 r
F P
0 g
s
.74355 .61527 m .73989 .64777 L .76247 .64197 L p .587 .343 .515 r
F P
0 g
s
.76247 .64197 m .76462 .60767 L .74355 .61527 L p .587 .343 .515 r
F P
0 g
s
.3389 .73453 m .34001 .70203 L .34957 .71342 L p .983 .727 .465 r
F P
0 g
s
.34957 .71342 m .34826 .74739 L .3389 .73453 L p .983 .727 .465 r
F P
0 g
s
.63542 .40429 m .59872 .39705 L .59507 .40011 L p .719 .83 .934 r
F P
0 g
s
.59872 .39705 m .63542 .40429 L .64069 .39934 L p .725 .829 .93 r
F P
0 g
s
.27675 .44108 m .31053 .41119 L .3175 .42058 L p .817 .741 .78 r
F P
0 g
s
.3175 .42058 m .28552 .45188 L .27675 .44108 L p .817 .741 .78 r
F P
0 g
s
.35818 .39903 m .3175 .42058 L .31053 .41119 L p .743 .735 .844 r
F P
0 g
s
.29622 .59242 m .29133 .5575 L .30033 .56607 L p .969 .651 .332 r
F P
0 g
s
.30033 .56607 m .30394 .60116 L .29622 .59242 L p .969 .651 .332 r
F P
0 g
s
.52547 .40712 m .52483 .42098 L .51918 .42074 L p .536 .799 .994 r
F P
0 g
s
.52483 .42098 m .52547 .40712 L .52865 .4071 L p .546 .807 .994 r
F P
0 g
s
.52865 .4071 m .53049 .42099 L .52483 .42098 L p .546 .807 .994 r
F P
0 g
s
.5223 .40701 m .51918 .42074 L .51355 .42028 L p .527 .791 .993 r
F P
0 g
s
.51918 .42074 m .5223 .40701 L .52547 .40712 L p .536 .799 .994 r
F P
0 g
s
.53049 .42099 m .52865 .4071 L .53182 .40695 L p .558 .815 .994 r
F P
0 g
s
.53182 .40695 m .53612 .42078 L .53049 .42099 L p .558 .815 .994 r
F P
0 g
s
.51914 .40677 m .51355 .42028 L .50797 .4196 L p .519 .783 .993 r
F P
0 g
s
.51355 .42028 m .51914 .40677 L .5223 .40701 L p .527 .791 .993 r
F P
0 g
s
.53612 .42078 m .53182 .40695 L .53496 .40666 L p .57 .823 .993 r
F P
0 g
s
.53496 .40666 m .54171 .42033 L .53612 .42078 L p .57 .823 .993 r
F P
0 g
s
.27186 .53877 m .27647 .49994 L .28634 .50965 L p .936 .693 .546 r
F P
0 g
s
.28634 .50965 m .28194 .54845 L .27186 .53877 L p .936 .693 .546 r
F P
0 g
s
.516 .4064 m .50797 .4196 L .50246 .41871 L p .512 .775 .991 r
F P
0 g
s
.50797 .4196 m .516 .4064 L .51914 .40677 L p .519 .783 .993 r
F P
0 g
s
.54171 .42033 m .53496 .40666 L .53808 .40624 L p .584 .831 .991 r
F P
0 g
s
.53808 .40624 m .54724 .41964 L .54171 .42033 L p .584 .831 .991 r
F P
0 g
s
.51291 .4059 m .50246 .41871 L .49703 .41761 L p .507 .767 .99 r
F P
0 g
s
.50246 .41871 m .51291 .4059 L .516 .4064 L p .512 .775 .991 r
F P
0 g
s
.54724 .41964 m .53808 .40624 L .54114 .40569 L p .599 .838 .99 r
F P
0 g
s
.54114 .40569 m .55269 .41871 L .54724 .41964 L p .599 .838 .99 r
F P
0 g
s
.59014 .71651 m .59025 .74466 L .57542 .75389 L p .411 .225 .515 r
F P
0 g
s
.59025 .74466 m .59014 .71651 L .60384 .7091 L p .401 .213 .508 r
F P
0 g
s
.76462 .60767 m .76247 .64197 L .78546 .63499 L p .574 .346 .531 r
F P
0 g
s
.78546 .63499 m .78587 .59896 L .76462 .60767 L p .574 .346 .531 r
F P
0 g
s
.37 .85058 m .37257 .80883 L .39033 .81805 L p .846 .599 .565 r
F P
0 g
s
.39033 .81805 m .3884 .85986 L .37 .85058 L p .846 .599 .565 r
F P
0 g
s
.70119 .39079 m .65375 .38342 L .6499 .38887 L p .702 .764 .9 r
F P
0 g
s
.65375 .38342 m .70119 .39079 L .706 .38315 L p .702 .765 .901 r
F P
0 g
s
.75491 .39862 m .706 .38315 L .70119 .39079 L p .649 .689 .874 r
F P
0 g
s
.50987 .40527 m .49703 .41761 L .49172 .4163 L p .502 .759 .988 r
F P
0 g
s
.49703 .41761 m .50987 .40527 L .51291 .4059 L p .507 .767 .99 r
F P
0 g
s
.55269 .41871 m .54114 .40569 L .54415 .40502 L p .614 .845 .987 r
F P
0 g
s
.54415 .40502 m .55804 .41755 L .55269 .41871 L p .614 .845 .987 r
F P
0 g
s
.45227 .39585 m .41523 .40312 L .41041 .39841 L p .566 .701 .932 r
F P
0 g
s
.41523 .40312 m .45227 .39585 L .45571 .39886 L p .564 .709 .939 r
F P
0 g
s
.82396 .47166 m .84656 .51191 L .85762 .49867 L p .444 .393 .707 r
F P
0 g
s
.85762 .49867 m .83372 .45904 L .82396 .47166 L p .444 .393 .707 r
F P
0 g
s
.706 .38315 m .75491 .39862 L .76019 .38894 L p .642 .692 .881 r
F P
0 g
s
.75491 .39862 m .79884 .42458 L .80534 .41321 L p .571 .603 .846 r
F P
0 g
s
.80534 .41321 m .76019 .38894 L .75491 .39862 L p .571 .603 .846 r
F P
0 g
s
.64069 .39934 m .60208 .39384 L .59872 .39705 L p .725 .829 .93 r
F P
0 g
s
.60208 .39384 m .64069 .39934 L .64553 .39419 L p .73 .829 .926 r
F P
0 g
s
.55804 .41755 m .54415 .40502 L .54709 .40421 L p .629 .851 .984 r
F P
0 g
s
.54709 .40421 m .56327 .41614 L .55804 .41755 L p .629 .851 .984 r
F P
0 g
s
.5069 .40453 m .49172 .4163 L .48655 .4148 L p .499 .751 .986 r
F P
0 g
s
.49172 .4163 m .5069 .40453 L .50987 .40527 L p .502 .759 .988 r
F P
0 g
s
.31053 .41119 m .353 .39151 L .35818 .39903 L p .743 .735 .844 r
F P
0 g
s
.40198 .38819 m .35818 .39903 L .353 .39151 L p .658 .711 .887 r
F P
0 g
s
.35818 .39903 m .40198 .38819 L .40599 .39344 L p .659 .718 .892 r
F P
0 g
s
.34468 .78464 m .34826 .74739 L .36027 .75939 L p .937 .698 .55 r
F P
0 g
s
.36027 .75939 m .35731 .79753 L .34468 .78464 L p .937 .698 .55 r
F P
0 g
s
.79884 .42458 m .83372 .45904 L .84121 .44646 L p .485 .495 .792 r
F P
0 g
s
.84121 .44646 m .80534 .41321 L .79884 .42458 L p .485 .495 .792 r
F P
0 g
s
.25588 .47787 m .27675 .44108 L .28552 .45188 L p .877 .723 .687 r
F P
0 g
s
.28552 .45188 m .26632 .48937 L .25588 .47787 L p .877 .723 .687 r
F P
0 g
s
.54117 .80849 m .54158 .84972 L .52083 .85829 L p .588 .401 .597 r
F P
0 g
s
.54158 .84972 m .54117 .80849 L .55979 .79885 L p .564 .392 .606 r
F P
0 g
s
.63349 .6734 m .62993 .69671 L .6169 .70242 L p .395 .122 .378 r
F P
0 g
s
.62993 .69671 m .63349 .6734 L .64776 .66878 L p .464 .177 .392 r
F P
0 g
s
.56327 .41614 m .54709 .40421 L .54995 .40328 L p .644 .856 .98 r
F P
0 g
s
.54995 .40328 m .56836 .4145 L .56327 .41614 L p .644 .856 .98 r
F P
0 g
s
.504 .40366 m .48655 .4148 L .48153 .41309 L p .497 .743 .983 r
F P
0 g
s
.48655 .4148 m .504 .40366 L .5069 .40453 L p .499 .751 .986 r
F P
0 g
s
.78587 .59896 m .78546 .63499 L .80807 .62667 L p .553 .34 .545 r
F P
0 g
s
.80807 .62667 m .80666 .5891 L .78587 .59896 L p .553 .34 .545 r
F P
0 g
s
.54995 .40328 m .56836 .4145 L .5733 .41263 L p .658 .86 .976 r
F P
0 g
s
.32712 .67891 m .32342 .65019 L .3303 .66018 L p .949 .665 .214 r
F P
0 g
s
.3303 .66018 m .33271 .69039 L .32712 .67891 L p .949 .665 .214 r
F P
0 g
s
.26821 .42946 m .30403 .4012 L .31053 .41119 L p .814 .739 .781 r
F P
0 g
s
.31053 .41119 m .27675 .44108 L .26821 .42946 L p .814 .739 .781 r
F P
0 g
s
.353 .39151 m .31053 .41119 L .30403 .4012 L p .741 .731 .843 r
F P
0 g
s
.50119 .40267 m .48153 .41309 L .47669 .41119 L p .495 .735 .979 r
F P
0 g
s
.48153 .41309 m .50119 .40267 L .504 .40366 L p .497 .743 .983 r
F P
0 g
s
.4491 .39269 m .41041 .39841 L .40599 .39344 L p .569 .693 .924 r
F P
0 g
s
.41041 .39841 m .4491 .39269 L .45227 .39585 L p .566 .701 .932 r
F P
0 g
s
.64553 .39419 m .60515 .3905 L .60208 .39384 L p .73 .829 .926 r
F P
0 g
s
.60515 .3905 m .64553 .39419 L .6499 .38887 L p .734 .827 .922 r
F P
0 g
s
.8329 .52485 m .84406 .56614 L .85926 .55335 L p .44 .322 .622 r
F P
0 g
s
.85926 .55335 m .84656 .51191 L .8329 .52485 L p .44 .322 .622 r
F P
0 g
s
.5733 .41263 m .55271 .40222 L .54995 .40328 L p .658 .86 .976 r
F P
0 g
s
.55271 .40222 m .5733 .41263 L .57807 .41054 L p .671 .862 .972 r
F P
0 g
s
.57542 .75389 m .57675 .78864 L .55979 .79885 L p .501 .338 .592 r
F P
0 g
s
.57675 .78864 m .57542 .75389 L .59025 .74466 L p .486 .334 .599 r
F P
0 g
s
.49847 .40157 m .47669 .41119 L .47204 .4091 L p .495 .727 .975 r
F P
0 g
s
.47669 .41119 m .49847 .40157 L .50119 .40267 L p .495 .735 .979 r
F P
0 g
s
.706 .38315 m .65707 .37787 L .65375 .38342 L p .702 .765 .901 r
F P
0 g
s
.65707 .37787 m .706 .38315 L .70997 .37547 L p .701 .766 .902 r
F P
0 g
s
.76019 .38894 m .70997 .37547 L .706 .38315 L p .642 .692 .881 r
F P
0 g
s
.45316 .91311 m .45319 .87146 L .47618 .86958 L p .69 .446 .549 r
F P
0 g
s
.47618 .86958 m .47603 .91145 L .45316 .91311 L p .69 .446 .549 r
F P
0 g
s
.47603 .91145 m .47618 .86958 L .4989 .86507 L p .657 .426 .557 r
F P
0 g
s
.43057 .9121 m .43051 .87048 L .45319 .87146 L p .726 .471 .542 r
F P
0 g
s
.45319 .87146 m .45316 .91311 L .43057 .9121 L p .726 .471 .542 r
F P
0 g
s
.26091 .5283 m .26632 .48937 L .27647 .49994 L p .923 .679 .551 r
F P
0 g
s
.27647 .49994 m .27186 .53877 L .26091 .5283 L p .923 .679 .551 r
F P
0 g
s
.57807 .41054 m .55537 .40105 L .55271 .40222 L p .671 .862 .972 r
F P
0 g
s
.55537 .40105 m .57807 .41054 L .58265 .40823 L p .683 .865 .968 r
F P
0 g
s
.30403 .4012 m .34834 .3836 L .353 .39151 L p .741 .731 .843 r
F P
0 g
s
.39841 .3827 m .353 .39151 L .34834 .3836 L p .658 .705 .882 r
F P
0 g
s
.353 .39151 m .39841 .3827 L .40198 .38819 L p .658 .711 .887 r
F P
0 g
s
.64776 .66878 m .6436 .69204 L .62993 .69671 L p .464 .177 .392 r
F P
0 g
s
.64776 .66878 m .6436 .69204 L .65851 .68835 L p .528 .236 .415 r
F P
0 g
s
.65851 .68835 m .66308 .66462 L .64776 .66878 L p .528 .236 .415 r
F P
0 g
s
.28767 .58353 m .28194 .54845 L .29133 .5575 L p .958 .625 .333 r
F P
0 g
s
.29133 .5575 m .29622 .59242 L .28767 .58353 L p .958 .625 .333 r
F P
0 g
s
.49587 .40036 m .47204 .4091 L .46761 .40681 L p .496 .719 .971 r
F P
0 g
s
.47204 .4091 m .49587 .40036 L .49847 .40157 L p .495 .727 .975 r
F P
0 g
s
.31176 .63107 m .30394 .60116 L .31137 .60987 L p .914 .576 .109 r
F P
0 g
s
.31137 .60987 m .31749 .64045 L .31176 .63107 L p .914 .576 .109 r
F P
0 g
s
.80666 .5891 m .80807 .62667 L .82948 .61697 L p .521 .325 .555 r
F P
0 g
s
.82948 .61697 m .8263 .57812 L .80666 .5891 L p .521 .325 .555 r
F P
0 g
s
.35385 .83914 m .35731 .79753 L .37257 .80883 L p .884 .64 .564 r
F P
0 g
s
.37257 .80883 m .37 .85058 L .35385 .83914 L p .884 .64 .564 r
F P
0 g
s
.60384 .7091 m .60387 .73601 L .59025 .74466 L p .401 .213 .508 r
F P
0 g
s
.60387 .73601 m .60384 .7091 L .6169 .70242 L p .419 .224 .508 r
F P
0 g
s
.4989 .86507 m .49871 .90733 L .47603 .91145 L p .657 .426 .557 r
F P
0 g
s
.49871 .90733 m .4989 .86507 L .52083 .85829 L p .628 .41 .566 r
F P
0 g
s
.44623 .38936 m .40599 .39344 L .40198 .38819 L p .572 .685 .917 r
F P
0 g
s
.40599 .39344 m .44623 .38936 L .4491 .39269 L p .569 .693 .924 r
F P
0 g
s
.40876 .90833 m .40873 .86657 L .43051 .87048 L p .763 .5 .537 r
F P
0 g
s
.43051 .87048 m .43057 .9121 L .40876 .90833 L p .763 .5 .537 r
F P
0 g
s
.70997 .37547 m .76019 .38894 L .76419 .37933 L p .635 .695 .888 r
F P
0 g
s
.76019 .38894 m .80534 .41321 L .81006 .40199 L p .551 .603 .858 r
F P
0 g
s
.81006 .40199 m .76419 .37933 L .76019 .38894 L p .551 .603 .858 r
F P
0 g
s
.6499 .38887 m .6079 .38705 L .60515 .3905 L p .734 .827 .922 r
F P
0 g
s
.6079 .38705 m .6499 .38887 L .65375 .38342 L p .738 .825 .918 r
F P
0 g
s
.58265 .40823 m .55792 .39977 L .55537 .40105 L p .683 .865 .968 r
F P
0 g
s
.55792 .39977 m .58265 .40823 L .58702 .40571 L p .694 .866 .963 r
F P
0 g
s
.24527 .46537 m .26821 .42946 L .27675 .44108 L p .872 .721 .691 r
F P
0 g
s
.27675 .44108 m .25588 .47787 L .24527 .46537 L p .872 .721 .691 r
F P
0 g
s
.55979 .79885 m .56092 .83996 L .54158 .84972 L p .564 .392 .606 r
F P
0 g
s
.56092 .83996 m .55979 .79885 L .57675 .78864 L p .547 .388 .617 r
F P
0 g
s
.33187 .72137 m .33271 .69039 L .34001 .70203 L p .993 .745 .408 r
F P
0 g
s
.34001 .70203 m .3389 .73453 L .33187 .72137 L p .993 .745 .408 r
F P
0 g
s
.49339 .39904 m .46761 .40681 L .4634 .40434 L p .497 .71 .966 r
F P
0 g
s
.46761 .40681 m .49339 .39904 L .49587 .40036 L p .496 .719 .971 r
F P
0 g
s
.83372 .45904 m .85762 .49867 L .86574 .48539 L p .38 .364 .716 r
F P
0 g
s
.86574 .48539 m .84121 .44646 L .83372 .45904 L p .38 .364 .716 r
F P
0 g
s
.66308 .66462 m .65851 .68835 L .67513 .68542 L p .573 .284 .439 r
F P
0 g
s
.67513 .68542 m .67983 .66073 L .66308 .66462 L p .573 .284 .439 r
F P
0 g
s
.58702 .40571 m .56035 .39838 L .55792 .39977 L p .694 .866 .963 r
F P
0 g
s
.56035 .39838 m .58702 .40571 L .59117 .403 L p .705 .866 .958 r
F P
0 g
s
.26005 .41706 m .29807 .39065 L .30403 .4012 L p .812 .739 .784 r
F P
0 g
s
.30403 .4012 m .26821 .42946 L .26005 .41706 L p .812 .739 .784 r
F P
0 g
s
.34834 .3836 m .30403 .4012 L .29807 .39065 L p .738 .729 .842 r
F P
0 g
s
.80534 .41321 m .84121 .44646 L .84627 .43409 L p .44 .482 .806 r
F P
0 g
s
.84627 .43409 m .81006 .40199 L .80534 .41321 L p .44 .482 .806 r
F P
0 g
s
.52083 .85829 m .52076 .90107 L .49871 .90733 L p .628 .41 .566 r
F P
0 g
s
.52076 .90107 m .52083 .85829 L .54158 .84972 L p .603 .399 .577 r
F P
0 g
s
.49104 .39762 m .4634 .40434 L .45943 .40169 L p .5 .702 .96 r
F P
0 g
s
.4634 .40434 m .49104 .39762 L .49339 .39904 L p .497 .71 .966 r
F P
0 g
s
.38819 .90191 m .3884 .85986 L .40873 .86657 L p .8 .533 .533 r
F P
0 g
s
.40873 .86657 m .40876 .90833 L .38819 .90191 L p .8 .533 .533 r
F P
0 g
s
.70997 .37547 m .65983 .37226 L .65707 .37787 L p .701 .766 .902 r
F P
0 g
s
.65983 .37226 m .70997 .37547 L .71307 .36779 L p .7 .766 .903 r
F P
0 g
s
.76419 .37933 m .71307 .36779 L .70997 .37547 L p .635 .695 .888 r
F P
0 g
s
.44366 .3859 m .40198 .38819 L .39841 .3827 L p .575 .678 .91 r
F P
0 g
s
.40198 .38819 m .44366 .3859 L .44623 .38936 L p .572 .685 .917 r
F P
0 g
s
.29807 .39065 m .34424 .37534 L .34834 .3836 L p .738 .729 .842 r
F P
0 g
s
.39528 .37698 m .34834 .3836 L .34424 .37534 L p .657 .701 .879 r
F P
0 g
s
.34834 .3836 m .39528 .37698 L .39841 .3827 L p .658 .705 .882 r
F P
0 g
s
.59117 .403 m .56264 .39688 L .56035 .39838 L p .705 .866 .958 r
F P
0 g
s
.56264 .39688 m .59117 .403 L .59507 .40011 L p .715 .866 .953 r
F P
0 g
s
.65375 .38342 m .61033 .3835 L .6079 .38705 L p .738 .825 .918 r
F P
0 g
s
.61033 .3835 m .65375 .38342 L .65707 .37787 L p .742 .823 .914 r
F P
0 g
s
.67983 .66073 m .67513 .68542 L .69372 .68291 L p .604 .322 .463 r
F P
0 g
s
.69372 .68291 m .69824 .65684 L .67983 .66073 L p .604 .322 .463 r
F P
0 g
s
.33463 .77077 m .3389 .73453 L .34826 .74739 L p .968 .739 .537 r
F P
0 g
s
.34826 .74739 m .34468 .78464 L .33463 .77077 L p .968 .739 .537 r
F P
0 g
s
.84656 .51191 m .85926 .55335 L .87129 .54003 L p .369 .282 .626 r
F P
0 g
s
.87129 .54003 m .85762 .49867 L .84656 .51191 L p .369 .282 .626 r
F P
0 g
s
.48882 .3961 m .45943 .40169 L .45571 .39886 L p .503 .694 .954 r
F P
0 g
s
.45943 .40169 m .48882 .3961 L .49104 .39762 L p .5 .702 .96 r
F P
0 g
s
.59025 .74466 m .59218 .77853 L .57675 .78864 L p .486 .334 .599 r
F P
0 g
s
.59218 .77853 m .59025 .74466 L .60387 .73601 L p .487 .341 .608 r
F P
0 g
s
.8263 .57812 m .82948 .61697 L .84878 .60595 L p .476 .3 .562 r
F P
0 g
s
.84878 .60595 m .84406 .56614 L .8263 .57812 L p .476 .3 .562 r
F P
0 g
s
.24908 .51688 m .25588 .47787 L .26632 .48937 L p .913 .671 .56 r
F P
0 g
s
.26632 .48937 m .26091 .5283 L .24908 .51688 L p .913 .671 .56 r
F P
0 g
s
.69824 .65684 m .69372 .68291 L .7143 .6804 L p .619 .348 .484 r
F P
0 g
s
.7143 .6804 m .71834 .65262 L .69824 .65684 L p .619 .348 .484 r
F P
0 g
s
.59507 .40011 m .56478 .39529 L .56264 .39688 L p .715 .866 .953 r
F P
0 g
s
.56478 .39529 m .59507 .40011 L .59872 .39705 L p .725 .865 .947 r
F P
0 g
s
.6169 .70242 m .61681 .72839 L .60387 .73601 L p .419 .224 .508 r
F P
0 g
s
.61681 .72839 m .6169 .70242 L .62993 .69671 L p .464 .258 .514 r
F P
0 g
s
.71834 .65262 m .7143 .6804 L .73662 .67745 L p .623 .361 .502 r
F P
0 g
s
.73662 .67745 m .73989 .64777 L .71834 .65262 L p .623 .361 .502 r
F P
0 g
s
.48676 .39448 m .45571 .39886 L .45227 .39585 L p .507 .685 .947 r
F P
0 g
s
.45571 .39886 m .48676 .39448 L .48882 .3961 L p .503 .694 .954 r
F P
0 g
s
.54158 .84972 m .54186 .89315 L .52076 .90107 L p .603 .399 .577 r
F P
0 g
s
.54186 .89315 m .54158 .84972 L .56092 .83996 L p .584 .394 .59 r
F P
0 g
s
.27786 .57427 m .27186 .53877 L .28194 .54845 L p .943 .604 .353 r
F P
0 g
s
.28194 .54845 m .28767 .58353 L .27786 .57427 L p .943 .604 .353 r
F P
0 g
s
.44141 .3823 m .39841 .3827 L .39528 .37698 L p .578 .672 .903 r
F P
0 g
s
.39841 .3827 m .44141 .3823 L .44366 .3859 L p .575 .678 .91 r
F P
0 g
s
.3225 .66792 m .31749 .64045 L .32342 .65019 L p .901 .612 .111 r
F P
0 g
s
.32342 .65019 m .32712 .67891 L .3225 .66792 L p .901 .612 .111 r
F P
0 g
s
.71307 .36779 m .76419 .37933 L .7669 .36985 L p .626 .697 .895 r
F P
0 g
s
.76419 .37933 m .81006 .40199 L .81295 .39103 L p .527 .601 .871 r
F P
0 g
s
.81295 .39103 m .7669 .36985 L .76419 .37933 L p .527 .601 .871 r
F P
0 g
s
.23469 .45187 m .26005 .41706 L .26821 .42946 L p .87 .724 .699 r
F P
0 g
s
.26821 .42946 m .24527 .46537 L .23469 .45187 L p .87 .724 .699 r
F P
0 g
s
.57675 .78864 m .57878 .82964 L .56092 .83996 L p .547 .388 .617 r
F P
0 g
s
.57878 .82964 m .57675 .78864 L .59218 .77853 L p .54 .392 .629 r
F P
0 g
s
.65707 .37787 m .61241 .37986 L .61033 .3835 L p .742 .823 .914 r
F P
0 g
s
.61241 .37986 m .65707 .37787 L .65983 .37226 L p .744 .819 .911 r
F P
0 g
s
.73989 .64777 m .73662 .67745 L .76022 .67365 L p .615 .365 .516 r
F P
0 g
s
.76022 .67365 m .76247 .64197 L .73989 .64777 L p .615 .365 .516 r
F P
0 g
s
.59872 .39705 m .56678 .39361 L .56478 .39529 L p .725 .865 .947 r
F P
0 g
s
.56678 .39361 m .59872 .39705 L .60208 .39384 L p .733 .863 .942 r
F P
0 g
s
.34008 .82605 m .34468 .78464 L .35731 .79753 L p .918 .681 .564 r
F P
0 g
s
.35731 .79753 m .35385 .83914 L .34008 .82605 L p .918 .681 .564 r
F P
0 g
s
.25246 .40395 m .29278 .37962 L .29807 .39065 L p .809 .742 .789 r
F P
0 g
s
.29807 .39065 m .26005 .41706 L .25246 .40395 L p .809 .742 .789 r
F P
0 g
s
.34424 .37534 m .29807 .39065 L .29278 .37962 L p .736 .728 .844 r
F P
0 g
s
.36925 .89306 m .37 .85058 L .3884 .85986 L p .837 .568 .531 r
F P
0 g
s
.3884 .85986 m .38819 .90191 L .36925 .89306 L p .837 .568 .531 r
F P
0 g
s
.29278 .37962 m .34077 .36678 L .34424 .37534 L p .736 .728 .844 r
F P
0 g
s
.39263 .37106 m .34424 .37534 L .34077 .36678 L p .657 .697 .876 r
F P
0 g
s
.34424 .37534 m .39263 .37106 L .39528 .37698 L p .657 .701 .879 r
F P
0 g
s
.30548 .62207 m .29622 .59242 L .30394 .60116 L p .906 .538 .086 r
F P
0 g
s
.30394 .60116 m .31176 .63107 L .30548 .62207 L p .906 .538 .086 r
F P
0 g
s
.71307 .36779 m .662 .36661 L .65983 .37226 L p .7 .766 .903 r
F P
0 g
s
.662 .36661 m .71307 .36779 L .71528 .36014 L p .698 .765 .904 r
F P
0 g
s
.7669 .36985 m .71528 .36014 L .71307 .36779 L p .626 .697 .895 r
F P
0 g
s
.48485 .39278 m .45227 .39585 L .4491 .39269 L p .511 .677 .94 r
F P
0 g
s
.45227 .39585 m .48485 .39278 L .48676 .39448 L p .507 .685 .947 r
F P
0 g
s
.76247 .64197 m .76022 .67365 L .78437 .66862 L p .599 .361 .527 r
F P
0 g
s
.78437 .66862 m .78546 .63499 L .76247 .64197 L p .599 .361 .527 r
F P
0 g
s
.60208 .39384 m .56861 .39185 L .56678 .39361 L p .733 .863 .942 r
F P
0 g
s
.56861 .39185 m .60208 .39384 L .60515 .3905 L p .741 .86 .936 r
F P
0 g
s
.43949 .37858 m .39528 .37698 L .39263 .37106 L p .581 .666 .897 r
F P
0 g
s
.39528 .37698 m .43949 .37858 L .44141 .3823 L p .578 .672 .903 r
F P
0 g
s
.84121 .44646 m .86574 .48539 L .87072 .47234 L p .29 .32 .72 r
F P
0 g
s
.87072 .47234 m .84627 .43409 L .84121 .44646 L p .29 .32 .72 r
F P
0 g
s
.81006 .40199 m .84627 .43409 L .84886 .42211 L p .383 .463 .818 r
F P
0 g
s
.84886 .42211 m .81295 .39103 L .81006 .40199 L p .383 .463 .818 r
F P
0 g
s
.48311 .391 m .4491 .39269 L .44623 .38936 L p .516 .67 .933 r
F P
0 g
s
.4491 .39269 m .48311 .391 L .48485 .39278 L p .511 .677 .94 r
F P
0 g
s
.62993 .69671 m .62975 .72212 L .61681 .72839 L p .464 .258 .514 r
F P
0 g
s
.62975 .72212 m .62993 .69671 L .6436 .69204 L p .526 .305 .523 r
F P
0 g
s
.65983 .37226 m .61415 .37617 L .61241 .37986 L p .744 .819 .911 r
F P
0 g
s
.61415 .37617 m .65983 .37226 L .662 .36661 L p .746 .816 .907 r
F P
0 g
s
.84406 .56614 m .84878 .60595 L .86515 .59379 L p .41 .259 .564 r
F P
0 g
s
.86515 .59379 m .85926 .55335 L .84406 .56614 L p .41 .259 .564 r
F P
0 g
s
.60387 .73601 m .60646 .76911 L .59218 .77853 L p .487 .341 .608 r
F P
0 g
s
.60646 .76911 m .60387 .73601 L .61681 .72839 L p .505 .36 .617 r
F P
0 g
s
.56092 .83996 m .56181 .88409 L .54186 .89315 L p .584 .394 .59 r
F P
0 g
s
.56181 .88409 m .56092 .83996 L .57878 .82964 L p .571 .394 .603 r
F P
0 g
s
.2365 .50438 m .24527 .46537 L .25588 .47787 L p .905 .67 .572 r
F P
0 g
s
.25588 .47787 m .24908 .51688 L .2365 .50438 L p .905 .67 .572 r
F P
0 g
s
.60515 .3905 m .57028 .39002 L .56861 .39185 L p .741 .86 .936 r
F P
0 g
s
.57028 .39002 m .60515 .3905 L .6079 .38705 L p .748 .857 .93 r
F P
0 g
s
.78546 .63499 m .78437 .66862 L .80823 .6621 L p .573 .348 .536 r
F P
0 g
s
.80823 .6621 m .80807 .62667 L .78546 .63499 L p .573 .348 .536 r
F P
0 g
s
.32658 .70844 m .32712 .67891 L .33271 .69039 L p .984 .746 .346 r
F P
0 g
s
.33271 .69039 m .33187 .72137 L .32658 .70844 L p .984 .746 .346 r
F P
0 g
s
.28827 .36819 m .33798 .35799 L .34077 .36678 L p .733 .729 .847 r
F P
0 g
s
.34077 .36678 m .29278 .37962 L .28827 .36819 L p .733 .729 .847 r
F P
0 g
s
.39049 .36498 m .34077 .36678 L .33798 .35799 L p .656 .695 .874 r
F P
0 g
s
.34077 .36678 m .39049 .36498 L .39263 .37106 L p .657 .697 .876 r
F P
0 g
s
.48154 .38914 m .44623 .38936 L .44366 .3859 L p .521 .663 .926 r
F P
0 g
s
.44623 .38936 m .48154 .38914 L .48311 .391 L p .516 .67 .933 r
F P
0 g
s
.22446 .43744 m .25246 .40395 L .26005 .41706 L p .869 .732 .709 r
F P
0 g
s
.26005 .41706 m .23469 .45187 L .22446 .43744 L p .869 .732 .709 r
F P
0 g
s
.85762 .49867 m .87129 .54003 L .87971 .52649 L p .261 .218 .619 r
F P
0 g
s
.87971 .52649 m .86574 .48539 L .85762 .49867 L p .261 .218 .619 r
F P
0 g
s
.24569 .39023 m .28827 .36819 L .29278 .37962 L p .808 .749 .798 r
F P
0 g
s
.29278 .37962 m .25246 .40395 L .24569 .39023 L p .808 .749 .798 r
F P
0 g
s
.59218 .77853 m .5953 .81941 L .57878 .82964 L p .54 .392 .629 r
F P
0 g
s
.5953 .81941 m .59218 .77853 L .60646 .76911 L p .542 .403 .641 r
F P
0 g
s
.26653 .56444 m .26091 .5283 L .27186 .53877 L p .926 .591 .383 r
F P
0 g
s
.27186 .53877 m .27786 .57427 L .26653 .56444 L p .926 .591 .383 r
F P
0 g
s
.6079 .38705 m .57176 .38811 L .57028 .39002 L p .748 .857 .93 r
F P
0 g
s
.57176 .38811 m .6079 .38705 L .61033 .3835 L p .754 .853 .924 r
F P
0 g
s
.52603 .39253 m .52547 .40712 L .5223 .40701 L p .591 .79 .975 r
F P
0 g
s
.52547 .40712 m .52603 .39253 L .52705 .39252 L p .599 .796 .975 r
F P
0 g
s
.52705 .39252 m .52865 .4071 L .52547 .40712 L p .599 .796 .975 r
F P
0 g
s
.52865 .4071 m .52705 .39252 L .52807 .39246 L p .606 .801 .975 r
F P
0 g
s
.52807 .39246 m .53182 .40695 L .52865 .4071 L p .606 .801 .975 r
F P
0 g
s
.4379 .37477 m .39263 .37106 L .39049 .36498 L p .583 .661 .891 r
F P
0 g
s
.39263 .37106 m .4379 .37477 L .43949 .37858 L p .581 .666 .897 r
F P
0 g
s
.52501 .39249 m .5223 .40701 L .51914 .40677 L p .585 .784 .974 r
F P
0 g
s
.5223 .40701 m .52501 .39249 L .52603 .39253 L p .591 .79 .975 r
F P
0 g
s
.53182 .40695 m .52807 .39246 L .52908 .39237 L p .614 .807 .974 r
F P
0 g
s
.52908 .39237 m .53496 .40666 L .53182 .40695 L p .614 .807 .974 r
F P
0 g
s
.52399 .39242 m .51914 .40677 L .516 .4064 L p .579 .778 .974 r
F P
0 g
s
.51914 .40677 m .52399 .39242 L .52501 .39249 L p .585 .784 .974 r
F P
0 g
s
.71528 .36014 m .7669 .36985 L .76833 .36054 L p .617 .698 .902 r
F P
0 g
s
.7669 .36985 m .81295 .39103 L .81406 .38041 L p .5 .598 .883 r
F P
0 g
s
.81406 .38041 m .76833 .36054 L .7669 .36985 L p .5 .598 .883 r
F P
0 g
s
.35221 .88213 m .35385 .83914 L .37 .85058 L p .872 .605 .531 r
F P
0 g
s
.37 .85058 m .36925 .89306 L .35221 .88213 L p .872 .605 .531 r
F P
0 g
s
.71528 .36014 m .66359 .36093 L .662 .36661 L p .698 .765 .904 r
F P
0 g
s
.66359 .36093 m .71528 .36014 L .7166 .35255 L p .696 .764 .904 r
F P
0 g
s
.76833 .36054 m .7166 .35255 L .71528 .36014 L p .617 .698 .902 r
F P
0 g
s
.32682 .75653 m .33187 .72137 L .3389 .73453 L p .988 .773 .525 r
F P
0 g
s
.3389 .73453 m .33463 .77077 L .32682 .75653 L p .988 .773 .525 r
F P
0 g
s
.53496 .40666 m .52908 .39237 L .53008 .39223 L p .623 .812 .973 r
F P
0 g
s
.53008 .39223 m .53808 .40624 L .53496 .40666 L p .623 .812 .973 r
F P
0 g
s
.52299 .3923 m .516 .4064 L .51291 .4059 L p .574 .771 .972 r
F P
0 g
s
.516 .4064 m .52299 .3923 L .52399 .39242 L p .579 .778 .974 r
F P
0 g
s
.53808 .40624 m .53008 .39223 L .53106 .39205 L p .631 .816 .971 r
F P
0 g
s
.53106 .39205 m .54114 .40569 L .53808 .40624 L p .631 .816 .971 r
F P
0 g
s
.522 .39214 m .51291 .4059 L .50987 .40527 L p .569 .765 .971 r
F P
0 g
s
.51291 .4059 m .522 .39214 L .52299 .3923 L p .574 .771 .972 r
F P
0 g
s
.662 .36661 m .61551 .37242 L .61415 .37617 L p .746 .816 .907 r
F P
0 g
s
.61551 .37242 m .662 .36661 L .66359 .36093 L p .747 .812 .903 r
F P
0 g
s
.54114 .40569 m .53106 .39205 L .53202 .39183 L p .641 .821 .969 r
F P
0 g
s
.53202 .39183 m .54415 .40502 L .54114 .40569 L p .641 .821 .969 r
F P
0 g
s
.6436 .69204 m .64336 .71731 L .62975 .72212 L p .526 .305 .523 r
F P
0 g
s
.6436 .69204 m .64336 .71731 L .65828 .71391 L p .582 .351 .531 r
F P
0 g
s
.65828 .71391 m .65851 .68835 L .6436 .69204 L p .582 .351 .531 r
F P
0 g
s
.52102 .39194 m .50987 .40527 L .5069 .40453 L p .565 .758 .969 r
F P
0 g
s
.50987 .40527 m .52102 .39194 L .522 .39214 L p .569 .765 .971 r
F P
0 g
s
.54415 .40502 m .53202 .39183 L .53297 .39156 L p .65 .824 .967 r
F P
0 g
s
.53297 .39156 m .54709 .40421 L .54415 .40502 L p .65 .824 .967 r
F P
0 g
s
.48014 .38721 m .44366 .3859 L .44141 .3823 L p .526 .656 .918 r
F P
0 g
s
.44366 .3859 m .48014 .38721 L .48154 .38914 L p .521 .663 .926 r
F P
0 g
s
.80807 .62667 m .80823 .6621 L .83084 .65396 L p .537 .326 .542 r
F P
0 g
s
.83084 .65396 m .82948 .61697 L .80807 .62667 L p .537 .326 .542 r
F P
0 g
s
.52007 .39169 m .5069 .40453 L .504 .40366 L p .561 .752 .967 r
F P
0 g
s
.5069 .40453 m .52007 .39169 L .52102 .39194 L p .565 .758 .969 r
F P
0 g
s
.54709 .40421 m .53297 .39156 L .53388 .39126 L p .659 .827 .964 r
F P
0 g
s
.53388 .39126 m .54995 .40328 L .54709 .40421 L p .659 .827 .964 r
F P
0 g
s
.45503 .95003 m .45316 .91311 L .47603 .91145 L p .683 .394 .478 r
F P
0 g
s
.47603 .91145 m .47719 .94882 L .45503 .95003 L p .683 .394 .478 r
F P
0 g
s
.47719 .94882 m .47603 .91145 L .49871 .90733 L p .652 .377 .491 r
F P
0 g
s
.61033 .3835 m .57307 .38615 L .57176 .38811 L p .754 .853 .924 r
F P
0 g
s
.57307 .38615 m .61033 .3835 L .61241 .37986 L p .759 .848 .918 r
F P
0 g
s
.51914 .39141 m .504 .40366 L .50119 .40267 L p .558 .745 .964 r
F P
0 g
s
.504 .40366 m .51914 .39141 L .52007 .39169 L p .561 .752 .967 r
F P
0 g
s
.32864 .81188 m .33463 .77077 L .34468 .78464 L p .945 .72 .567 r
F P
0 g
s
.34468 .78464 m .34008 .82605 L .32864 .81188 L p .945 .72 .567 r
F P
0 g
s
.43312 .94891 m .43057 .9121 L .45316 .91311 L p .717 .416 .467 r
F P
0 g
s
.45316 .91311 m .45503 .95003 L .43312 .94891 L p .717 .416 .467 r
F P
0 g
s
.53388 .39126 m .54995 .40328 L .55271 .40222 L p .667 .83 .961 r
F P
0 g
s
.49871 .90733 m .49924 .94546 L .47719 .94882 L p .652 .377 .491 r
F P
0 g
s
.49924 .94546 m .49871 .90733 L .52076 .90107 L p .625 .365 .505 r
F P
0 g
s
.57878 .82964 m .58056 .87448 L .56181 .88409 L p .571 .394 .603 r
F P
0 g
s
.58056 .87448 m .57878 .82964 L .5953 .81941 L p .565 .4 .616 r
F P
0 g
s
.51824 .39109 m .50119 .40267 L .49847 .40157 L p .556 .738 .961 r
F P
0 g
s
.50119 .40267 m .51824 .39109 L .51914 .39141 L p .558 .745 .964 r
F P
0 g
s
.318 .65764 m .31176 .63107 L .31749 .64045 L p .873 .566 .049 r
F P
0 g
s
.31749 .64045 m .3225 .66792 L .318 .65764 L p .873 .566 .049 r
F P
0 g
s
.29795 .61333 m .28767 .58353 L .29622 .59242 L p .912 .518 .117 r
F P
0 g
s
.29622 .59242 m .30548 .62207 L .29795 .61333 L p .912 .518 .117 r
F P
0 g
s
.55271 .40222 m .53476 .39092 L .53388 .39126 L p .667 .83 .961 r
F P
0 g
s
.53476 .39092 m .55271 .40222 L .55537 .40105 L p .676 .831 .958 r
F P
0 g
s
.61681 .72839 m .62008 .76088 L .60646 .76911 L p .505 .36 .617 r
F P
0 g
s
.62008 .76088 m .61681 .72839 L .62975 .72212 L p .537 .387 .624 r
F P
0 g
s
.33798 .35799 m .38887 .35878 L .39049 .36498 L p .656 .695 .874 r
F P
0 g
s
.43667 .37087 m .39049 .36498 L .38887 .35878 L p .585 .657 .887 r
F P
0 g
s
.39049 .36498 m .43667 .37087 L .4379 .37477 L p .583 .661 .891 r
F P
0 g
s
.51737 .39073 m .49847 .40157 L .49587 .40036 L p .554 .732 .958 r
F P
0 g
s
.49847 .40157 m .51737 .39073 L .51824 .39109 L p .556 .738 .961 r
F P
0 g
s
.65851 .68835 m .65828 .71391 L .67499 .71169 L p .624 .386 .537 r
F P
0 g
s
.67499 .71169 m .67513 .68542 L .65851 .68835 L p .624 .386 .537 r
F P
0 g
s
.47894 .38522 m .44141 .3823 L .43949 .37858 L p .531 .651 .911 r
F P
0 g
s
.44141 .3823 m .47894 .38522 L .48014 .38721 L p .526 .656 .918 r
F P
0 g
s
.2847 .35649 m .33594 .34904 L .33798 .35799 L p .73 .731 .851 r
F P
0 g
s
.33798 .35799 m .28827 .36819 L .2847 .35649 L p .73 .731 .851 r
F P
0 g
s
.38887 .35878 m .33798 .35799 L .33594 .34904 L p .654 .693 .874 r
F P
0 g
s
.22348 .49073 m .23469 .45187 L .24527 .46537 L p .902 .677 .587 r
F P
0 g
s
.24527 .46537 m .2365 .50438 L .22348 .49073 L p .902 .677 .587 r
F P
0 g
s
.55537 .40105 m .53561 .39055 L .53476 .39092 L p .676 .831 .958 r
F P
0 g
s
.53561 .39055 m .55537 .40105 L .55792 .39977 L p .684 .832 .955 r
F P
0 g
s
.41186 .9454 m .40876 .90833 L .43057 .9121 L p .753 .442 .458 r
F P
0 g
s
.43057 .9121 m .43312 .94891 L .41186 .9454 L p .753 .442 .458 r
F P
0 g
s
.51654 .39034 m .49587 .40036 L .49339 .39904 L p .553 .725 .954 r
F P
0 g
s
.49587 .40036 m .51654 .39034 L .51737 .39073 L p .554 .732 .958 r
F P
0 g
s
.52076 .90107 m .52084 .94025 L .49924 .94546 L p .625 .365 .505 r
F P
0 g
s
.52084 .94025 m .52076 .90107 L .54186 .89315 L p .602 .358 .519 r
F P
0 g
s
.61241 .37986 m .57418 .38414 L .57307 .38615 L p .759 .848 .918 r
F P
0 g
s
.57418 .38414 m .61241 .37986 L .61415 .37617 L p .763 .842 .912 r
F P
0 g
s
.66359 .36093 m .61651 .36864 L .61551 .37242 L p .747 .812 .903 r
F P
0 g
s
.61651 .36864 m .66359 .36093 L .66458 .35526 L p .748 .807 .899 r
F P
0 g
s
.7166 .35255 m .66458 .35526 L .66359 .36093 L p .696 .764 .904 r
F P
0 g
s
.55792 .39977 m .53642 .39013 L .53561 .39055 L p .684 .832 .955 r
F P
0 g
s
.53642 .39013 m .55792 .39977 L .56035 .39838 L p .691 .833 .951 r
F P
0 g
s
.85926 .55335 m .86515 .59379 L .87786 .58077 L p .311 .194 .555 r
F P
0 g
s
.87786 .58077 m .87129 .54003 L .85926 .55335 L p .311 .194 .555 r
F P
0 g
s
.51575 .38991 m .49339 .39904 L .49104 .39762 L p .552 .719 .95 r
F P
0 g
s
.49339 .39904 m .51575 .38991 L .51654 .39034 L p .553 .725 .954 r
F P
0 g
s
.23999 .37608 m .2847 .35649 L .28827 .36819 L p .806 .758 .808 r
F P
0 g
s
.28827 .36819 m .24569 .39023 L .23999 .37608 L p .806 .758 .808 r
F P
0 g
s
.67513 .68542 m .67499 .71169 L .69377 .71026 L p .648 .408 .541 r
F P
0 g
s
.69377 .71026 m .69372 .68291 L .67513 .68542 L p .648 .408 .541 r
F P
0 g
s
.81295 .39103 m .84886 .42211 L .84907 .41064 L p .309 .434 .826 r
F P
0 g
s
.84907 .41064 m .81406 .38041 L .81295 .39103 L p .309 .434 .826 r
F P
0 g
s
.21496 .42217 m .24569 .39023 L .25246 .40395 L p .87 .744 .722 r
F P
0 g
s
.25246 .40395 m .22446 .43744 L .21496 .42217 L p .87 .744 .722 r
F P
0 g
s
.56035 .39838 m .5372 .38969 L .53642 .39013 L p .691 .833 .951 r
F P
0 g
s
.5372 .38969 m .56035 .39838 L .56264 .39688 L p .699 .833 .947 r
F P
0 g
s
.60646 .76911 m .61077 .80986 L .5953 .81941 L p .542 .403 .641 r
F P
0 g
s
.61077 .80986 m .60646 .76911 L .62008 .76088 L p .554 .419 .651 r
F P
0 g
s
.66458 .35526 m .7166 .35255 L .71704 .34504 L p .694 .763 .904 r
F P
0 g
s
.7166 .35255 m .76833 .36054 L .76852 .35143 L p .608 .699 .908 r
F P
0 g
s
.76852 .35143 m .71704 .34504 L .7166 .35255 L p .608 .699 .908 r
F P
0 g
s
.84627 .43409 m .87072 .47234 L .8725 .45974 L p .159 .249 .708 r
F P
0 g
s
.8725 .45974 m .84886 .42211 L .84627 .43409 L p .159 .249 .708 r
F P
0 g
s
.47792 .38318 m .43949 .37858 L .4379 .37477 L p .536 .645 .904 r
F P
0 g
s
.43949 .37858 m .47792 .38318 L .47894 .38522 L p .531 .651 .911 r
F P
0 g
s
.515 .38945 m .49104 .39762 L .48882 .3961 L p .552 .712 .946 r
F P
0 g
s
.49104 .39762 m .515 .38945 L .51575 .38991 L p .552 .719 .95 r
F P
0 g
s
.25363 .55378 m .24908 .51688 L .26091 .5283 L p .912 .587 .415 r
F P
0 g
s
.26091 .5283 m .26653 .56444 L .25363 .55378 L p .912 .587 .415 r
F P
0 g
s
.82948 .61697 m .83084 .65396 L .85119 .64418 L p .485 .293 .544 r
F P
0 g
s
.85119 .64418 m .84878 .60595 L .82948 .61697 L p .485 .293 .544 r
F P
0 g
s
.69372 .68291 m .69377 .71026 L .71464 .70914 L p .658 .418 .545 r
F P
0 g
s
.71464 .70914 m .7143 .6804 L .69372 .68291 L p .658 .418 .545 r
F P
0 g
s
.56264 .39688 m .53792 .38921 L .5372 .38969 L p .699 .833 .947 r
F P
0 g
s
.53792 .38921 m .56264 .39688 L .56478 .39529 L p .705 .833 .943 r
F P
0 g
s
.61415 .37617 m .5751 .38209 L .57418 .38414 L p .763 .842 .912 r
F P
0 g
s
.5751 .38209 m .61415 .37617 L .61551 .37242 L p .766 .836 .906 r
F P
0 g
s
.33594 .34904 m .38781 .3525 L .38887 .35878 L p .654 .693 .874 r
F P
0 g
s
.43579 .36692 m .38887 .35878 L .38781 .3525 L p .588 .654 .882 r
F P
0 g
s
.38887 .35878 m .43579 .36692 L .43667 .37087 L p .585 .657 .887 r
F P
0 g
s
.54186 .89315 m .54174 .93357 L .52084 .94025 L p .602 .358 .519 r
F P
0 g
s
.54174 .93357 m .54186 .89315 L .56181 .88409 L p .585 .355 .534 r
F P
0 g
s
.5143 .38896 m .48882 .3961 L .48676 .39448 L p .553 .706 .942 r
F P
0 g
s
.48882 .3961 m .5143 .38896 L .515 .38945 L p .552 .712 .946 r
F P
0 g
s
.3372 .86959 m .34008 .82605 L .35385 .83914 L p .903 .643 .535 r
F P
0 g
s
.35385 .83914 m .35221 .88213 L .3372 .86959 L p .903 .643 .535 r
F P
0 g
s
.76833 .36054 m .81406 .38041 L .8135 .37014 L p .47 .593 .894 r
F P
0 g
s
.8135 .37014 m .76852 .35143 L .76833 .36054 L p .47 .593 .894 r
F P
0 g
s
.39159 .93957 m .38819 .90191 L .40876 .90833 L p .79 .472 .45 r
F P
0 g
s
.40876 .90833 m .41186 .9454 L .39159 .93957 L p .79 .472 .45 r
F P
0 g
s
.7143 .6804 m .71464 .70914 L .73737 .70781 L p .656 .419 .549 r
F P
0 g
s
.73737 .70781 m .73662 .67745 L .7143 .6804 L p .656 .419 .549 r
F P
0 g
s
.56478 .39529 m .5386 .38871 L .53792 .38921 L p .705 .833 .943 r
F P
0 g
s
.5386 .38871 m .56478 .39529 L .56678 .39361 L p .712 .832 .939 r
F P
0 g
s
.5953 .81941 m .59819 .8649 L .58056 .87448 L p .565 .4 .616 r
F P
0 g
s
.59819 .8649 m .5953 .81941 L .61077 .80986 L p .566 .409 .627 r
F P
0 g
s
.32228 .69617 m .3225 .66792 L .32712 .67891 L p .968 .736 .302 r
F P
0 g
s
.32712 .67891 m .32658 .70844 L .32228 .69617 L p .968 .736 .302 r
F P
0 g
s
.62975 .72212 m .63368 .75419 L .62008 .76088 L p .537 .387 .624 r
F P
0 g
s
.63368 .75419 m .62975 .72212 L .64336 .71731 L p .576 .416 .627 r
F P
0 g
s
.51365 .38844 m .48676 .39448 L .48485 .39278 L p .554 .7 .937 r
F P
0 g
s
.48676 .39448 m .51365 .38844 L .5143 .38896 L p .553 .706 .942 r
F P
0 g
s
.4771 .3811 m .4379 .37477 L .43667 .37087 L p .542 .641 .897 r
F P
0 g
s
.4379 .37477 m .4771 .3811 L .47792 .38318 L p .536 .645 .904 r
F P
0 g
s
.73662 .67745 m .73737 .70781 L .76144 .70573 L p .645 .412 .552 r
F P
0 g
s
.76144 .70573 m .76022 .67365 L .73662 .67745 L p .645 .412 .552 r
F P
0 g
s
.66458 .35526 m .61714 .36484 L .61651 .36864 L p .748 .807 .899 r
F P
0 g
s
.61714 .36484 m .66458 .35526 L .66498 .3496 L p .749 .802 .895 r
F P
0 g
s
.71704 .34504 m .66498 .3496 L .66458 .35526 L p .694 .763 .904 r
F P
0 g
s
.28221 .34466 m .33472 .34003 L .33594 .34904 L p .727 .735 .858 r
F P
0 g
s
.33594 .34904 m .2847 .35649 L .28221 .34466 L p .727 .735 .858 r
F P
0 g
s
.38781 .3525 m .33594 .34904 L .33472 .34003 L p .652 .692 .874 r
F P
0 g
s
.56678 .39361 m .53923 .38817 L .5386 .38871 L p .712 .832 .939 r
F P
0 g
s
.53923 .38817 m .56678 .39361 L .56861 .39185 L p .718 .83 .934 r
F P
0 g
s
.86574 .48539 m .87971 .52649 L .88425 .51307 L p .092 .111 .587 r
F P
0 g
s
.88425 .51307 m .87072 .47234 L .86574 .48539 L p .092 .111 .587 r
F P
0 g
s
.61551 .37242 m .57583 .38001 L .5751 .38209 L p .766 .836 .906 r
F P
0 g
s
.57583 .38001 m .61551 .37242 L .61651 .36864 L p .768 .83 .9 r
F P
0 g
s
.51305 .38789 m .48485 .39278 L .48311 .391 L p .555 .694 .932 r
F P
0 g
s
.48485 .39278 m .51305 .38789 L .51365 .38844 L p .554 .7 .937 r
F P
0 g
s
.56861 .39185 m .53981 .38761 L .53923 .38817 L p .718 .83 .934 r
F P
0 g
s
.53981 .38761 m .56861 .39185 L .57028 .39002 L p .724 .828 .93 r
F P
0 g
s
.76022 .67365 m .76144 .70573 L .78615 .70245 L p .625 .399 .554 r
F P
0 g
s
.78615 .70245 m .78437 .66862 L .76022 .67365 L p .625 .399 .554 r
F P
0 g
s
.32071 .7425 m .32658 .70844 L .33187 .72137 L p .997 .799 .519 r
F P
0 g
s
.33187 .72137 m .32682 .75653 L .32071 .7425 L p .997 .799 .519 r
F P
0 g
s
.21045 .47595 m .22446 .43744 L .23469 .45187 L p .904 .69 .603 r
F P
0 g
s
.23469 .45187 m .22348 .49073 L .21045 .47595 L p .904 .69 .603 r
F P
0 g
s
.28862 .60464 m .27786 .57427 L .28767 .58353 L p .912 .509 .185 r
F P
0 g
s
.28767 .58353 m .29795 .61333 L .28862 .60464 L p .912 .509 .185 r
F P
0 g
s
.5125 .38731 m .48311 .391 L .48154 .38914 L p .557 .688 .927 r
F P
0 g
s
.48311 .391 m .5125 .38731 L .51305 .38789 L p .555 .694 .932 r
F P
0 g
s
.56181 .88409 m .56179 .92586 L .54174 .93357 L p .585 .355 .534 r
F P
0 g
s
.56179 .92586 m .56181 .88409 L .58056 .87448 L p .573 .357 .549 r
F P
0 g
s
.33472 .34003 m .38733 .34619 L .38781 .3525 L p .652 .692 .874 r
F P
0 g
s
.43529 .36293 m .38781 .3525 L .38733 .34619 L p .59 .651 .879 r
F P
0 g
s
.38781 .3525 m .43529 .36293 L .43579 .36692 L p .588 .654 .882 r
F P
0 g
s
.47647 .37898 m .43667 .37087 L .43579 .36692 L p .547 .637 .891 r
F P
0 g
s
.43667 .37087 m .47647 .37898 L .4771 .3811 L p .542 .641 .897 r
F P
0 g
s
.62008 .76088 m .62563 .80148 L .61077 .80986 L p .554 .419 .651 r
F P
0 g
s
.62563 .80148 m .62008 .76088 L .63368 .75419 L p .573 .437 .657 r
F P
0 g
s
.57028 .39002 m .54033 .38703 L .53981 .38761 L p .724 .828 .93 r
F P
0 g
s
.54033 .38703 m .57028 .39002 L .57176 .38811 L p .729 .825 .925 r
F P
0 g
s
.66498 .3496 m .71704 .34504 L .71663 .3376 L p .692 .761 .904 r
F P
0 g
s
.71704 .34504 m .76852 .35143 L .76756 .34248 L p .599 .698 .913 r
F P
0 g
s
.76756 .34248 m .71663 .3376 L .71704 .34504 L p .599 .698 .913 r
F P
0 g
s
.23563 .36169 m .28221 .34466 L .2847 .35649 L p .804 .77 .821 r
F P
0 g
s
.2847 .35649 m .23999 .37608 L .23563 .36169 L p .804 .77 .821 r
F P
0 g
s
.31925 .79727 m .32682 .75653 L .33463 .77077 L p .963 .754 .574 r
F P
0 g
s
.33463 .77077 m .32864 .81188 L .31925 .79727 L p .963 .754 .574 r
F P
0 g
s
.37262 .93159 m .36925 .89306 L .38819 .90191 L p .826 .505 .445 r
F P
0 g
s
.38819 .90191 m .39159 .93957 L .37262 .93159 L p .826 .505 .445 r
F P
0 g
s
.51201 .38672 m .48154 .38914 L .48014 .38721 L p .56 .683 .922 r
F P
0 g
s
.48154 .38914 m .51201 .38672 L .5125 .38731 L p .557 .688 .927 r
F P
0 g
s
.31276 .64816 m .30548 .62207 L .31176 .63107 L p .886 .543 .051 r
F P
0 g
s
.31176 .63107 m .318 .65764 L .31276 .64816 L p .886 .543 .051 r
F P
0 g
s
.61651 .36864 m .57635 .3779 L .57583 .38001 L p .768 .83 .9 r
F P
0 g
s
.57635 .3779 m .61651 .36864 L .61714 .36484 L p .77 .823 .894 r
F P
0 g
s
.64336 .71731 m .64789 .74919 L .63368 .75419 L p .576 .416 .627 r
F P
0 g
s
.64336 .71731 m .64789 .74919 L .66332 .74585 L p .615 .442 .624 r
F P
0 g
s
.66332 .74585 m .65828 .71391 L .64336 .71731 L p .615 .442 .624 r
F P
0 g
s
.20662 .40626 m .23999 .37608 L .24569 .39023 L p .872 .762 .738 r
F P
0 g
s
.24569 .39023 m .21496 .42217 L .20662 .40626 L p .872 .762 .738 r
F P
0 g
s
.57176 .38811 m .54079 .38642 L .54033 .38703 L p .729 .825 .925 r
F P
0 g
s
.54079 .38642 m .57176 .38811 L .57307 .38615 L p .733 .822 .92 r
F P
0 g
s
.23933 .54209 m .2365 .50438 L .24908 .51688 L p .904 .591 .445 r
F P
0 g
s
.24908 .51688 m .25363 .55378 L .23933 .54209 L p .904 .591 .445 r
F P
0 g
s
.78437 .66862 m .78615 .70245 L .81058 .69759 L p .597 .379 .556 r
F P
0 g
s
.81058 .69759 m .80823 .6621 L .78437 .66862 L p .597 .379 .556 r
F P
0 g
s
.66498 .3496 m .61738 .36103 L .61714 .36484 L p .749 .802 .895 r
F P
0 g
s
.61738 .36103 m .66498 .3496 L .66478 .34395 L p .749 .796 .891 r
F P
0 g
s
.71663 .3376 m .66478 .34395 L .66498 .3496 L p .692 .761 .904 r
F P
0 g
s
.84878 .60595 m .85119 .64418 L .86836 .63289 L p .41 .242 .54 r
F P
0 g
s
.86836 .63289 m .86515 .59379 L .84878 .60595 L p .41 .242 .54 r
F P
0 g
s
.51157 .38611 m .48014 .38721 L .47894 .38522 L p .562 .678 .917 r
F P
0 g
s
.48014 .38721 m .51157 .38611 L .51201 .38672 L p .56 .683 .922 r
F P
0 g
s
.61077 .80986 m .61493 .85588 L .59819 .8649 L p .566 .409 .627 r
F P
0 g
s
.61493 .85588 m .61077 .80986 L .62563 .80148 L p .572 .42 .637 r
F P
0 g
s
.47605 .37684 m .43579 .36692 L .43529 .36293 L p .552 .633 .885 r
F P
0 g
s
.43579 .36692 m .47605 .37684 L .47647 .37898 L p .547 .637 .891 r
F P
0 g
s
.57307 .38615 m .5412 .3858 L .54079 .38642 L p .733 .822 .92 r
F P
0 g
s
.5412 .3858 m .57307 .38615 L .57418 .38414 L p .737 .819 .915 r
F P
0 g
s
.28094 .33284 m .33438 .33104 L .33472 .34003 L p .723 .74 .865 r
F P
0 g
s
.33472 .34003 m .28221 .34466 L .28094 .33284 L p .723 .74 .865 r
F P
0 g
s
.38733 .34619 m .33472 .34003 L .33438 .33104 L p .65 .692 .876 r
F P
0 g
s
.87129 .54003 m .87786 .58077 L .88636 .56724 L p .152 .086 .522 r
F P
0 g
s
.88636 .56724 m .87971 .52649 L .87129 .54003 L p .152 .086 .522 r
F P
0 g
s
.81406 .38041 m .84907 .41064 L .84709 .39973 L p .215 .392 .824 r
F P
0 g
s
.84709 .39973 m .8135 .37014 L .81406 .38041 L p .215 .392 .824 r
F P
0 g
s
.5112 .38547 m .47894 .38522 L .47792 .38318 L p .565 .674 .912 r
F P
0 g
s
.47894 .38522 m .5112 .38547 L .51157 .38611 L p .562 .678 .917 r
F P
0 g
s
.61714 .36484 m .57666 .37577 L .57635 .3779 L p .77 .823 .894 r
F P
0 g
s
.57666 .37577 m .61714 .36484 L .61738 .36103 L p .771 .816 .888 r
F P
0 g
s
.33438 .33104 m .38746 .33989 L .38733 .34619 L p .65 .692 .876 r
F P
0 g
s
.43516 .35892 m .38733 .34619 L .38746 .33989 L p .591 .649 .876 r
F P
0 g
s
.38733 .34619 m .43516 .35892 L .43529 .36293 L p .59 .651 .879 r
F P
0 g
s
.58056 .87448 m .58092 .91761 L .56179 .92586 L p .573 .357 .549 r
F P
0 g
s
.58092 .91761 m .58056 .87448 L .59819 .8649 L p .567 .363 .563 r
F P
0 g
s
.76852 .35143 m .8135 .37014 L .81143 .36021 L p .436 .585 .902 r
F P
0 g
s
.81143 .36021 m .76756 .34248 L .76852 .35143 L p .436 .585 .902 r
F P
0 g
s
.65828 .71391 m .66332 .74585 L .68042 .74394 L p .648 .461 .617 r
F P
0 g
s
.68042 .74394 m .67499 .71169 L .65828 .71391 L p .648 .461 .617 r
F P
0 g
s
.57418 .38414 m .54154 .38516 L .5412 .3858 L p .737 .819 .915 r
F P
0 g
s
.54154 .38516 m .57418 .38414 L .5751 .38209 L p .74 .815 .91 r
F P
0 g
s
.32417 .85597 m .32864 .81188 L .34008 .82605 L p .927 .679 .542 r
F P
0 g
s
.34008 .82605 m .3372 .86959 L .32417 .85597 L p .927 .679 .542 r
F P
0 g
s
.51089 .38483 m .47792 .38318 L .4771 .3811 L p .569 .669 .906 r
F P
0 g
s
.47792 .38318 m .51089 .38483 L .5112 .38547 L p .565 .674 .912 r
F P
0 g
s
.84886 .42211 m .8725 .45974 L .87122 .4478 L p 0 .138 .664 r
F P
0 g
s
.87122 .4478 m .84907 .41064 L .84886 .42211 L p 0 .138 .664 r
F P
0 g
s
.63368 .75419 m .64043 .79463 L .62563 .80148 L p .573 .437 .657 r
F P
0 g
s
.64043 .79463 m .63368 .75419 L .64789 .74919 L p .595 .453 .659 r
F P
0 g
s
.47584 .37468 m .43529 .36293 L .43516 .35892 L p .557 .63 .88 r
F P
0 g
s
.43529 .36293 m .47584 .37468 L .47605 .37684 L p .552 .633 .885 r
F P
0 g
s
.5751 .38209 m .54182 .38451 L .54154 .38516 L p .74 .815 .91 r
F P
0 g
s
.54182 .38451 m .5751 .38209 L .57583 .38001 L p .743 .811 .905 r
F P
0 g
s
.80823 .6621 m .81058 .69759 L .83375 .69092 L p .558 .352 .557 r
F P
0 g
s
.83375 .69092 m .83084 .65396 L .80823 .6621 L p .558 .352 .557 r
F P
0 g
s
.66478 .34395 m .61725 .35722 L .61738 .36103 L p .749 .796 .891 r
F P
0 g
s
.61725 .35722 m .66478 .34395 L .66401 .33833 L p .748 .79 .887 r
F P
0 g
s
.66478 .34395 m .71663 .3376 L .71542 .33021 L p .69 .758 .903 r
F P
0 g
s
.71542 .33021 m .66401 .33833 L .66478 .34395 L p .69 .758 .903 r
F P
0 g
s
.67499 .71169 m .68042 .74394 L .69946 .74307 L p .666 .469 .609 r
F P
0 g
s
.69946 .74307 m .69377 .71026 L .67499 .71169 L p .666 .469 .609 r
F P
0 g
s
.71663 .3376 m .76756 .34248 L .76554 .33367 L p .59 .697 .917 r
F P
0 g
s
.76554 .33367 m .71542 .33021 L .71663 .3376 L p .59 .697 .917 r
F P
0 g
s
.61738 .36103 m .57677 .37363 L .57666 .37577 L p .771 .816 .888 r
F P
0 g
s
.57677 .37363 m .61738 .36103 L .61725 .35722 L p .772 .809 .883 r
F P
0 g
s
.19798 .46011 m .21496 .42217 L .22446 .43744 L p .909 .709 .621 r
F P
0 g
s
.22446 .43744 m .21045 .47595 L .19798 .46011 L p .909 .709 .621 r
F P
0 g
s
.51064 .38417 m .4771 .3811 L .47647 .37898 L p .572 .666 .901 r
F P
0 g
s
.4771 .3811 m .51064 .38417 L .51089 .38483 L p .569 .669 .906 r
F P
0 g
s
.27716 .59571 m .26653 .56444 L .27786 .57427 L p .901 .507 .259 r
F P
0 g
s
.27786 .57427 m .28862 .60464 L .27716 .59571 L p .901 .507 .259 r
F P
0 g
s
.35517 .92177 m .35221 .88213 L .36925 .89306 L p .86 .54 .443 r
F P
0 g
s
.36925 .89306 m .37262 .93159 L .35517 .92177 L p .86 .54 .443 r
F P
0 g
s
.23288 .34728 m .28094 .33284 L .28221 .34466 L p .802 .784 .836 r
F P
0 g
s
.28221 .34466 m .23563 .36169 L .23288 .34728 L p .802 .784 .836 r
F P
0 g
s
.31808 .68488 m .318 .65764 L .3225 .66792 L p .969 .73 .298 r
F P
0 g
s
.3225 .66792 m .32228 .69617 L .31808 .68488 L p .969 .73 .298 r
F P
0 g
s
.57583 .38001 m .54204 .38384 L .54182 .38451 L p .743 .811 .905 r
F P
0 g
s
.54204 .38384 m .57583 .38001 L .57635 .3779 L p .746 .806 .901 r
F P
0 g
s
.522 .39214 m .52102 .39194 L p .52554 .38243 L .67 .731 .896 r
F P
0 g
s
.5257 .38209 m .52602 .38262 L .52554 .38243 L .67 .731 .896 r
F
.52595 .38156 m .52556 .38149 L .52576 .38163 L F
.52595 .38156 m .52576 .38163 L .52629 .38198 L F
.52613 .38179 m .52607 .38171 L .52607 .38131 L F
.51099 .37879 m .52531 .38178 L p .52556 .38149 L F P
0 g
s
.52531 .38178 m .52629 .38198 L p .52556 .38149 L .67 .731 .896 r
F P
0 g
s
.52585 .38177 m .52495 .38159 L .52566 .38168 L .67 .731 .896 r
F
.52629 .38198 m .52531 .38178 L p .52585 .38177 L F P
0 g
s
.52531 .38178 m .52432 .38157 L p .52585 .38177 L .67 .731 .896 r
F P
0 g
s
.52432 .38157 m .52437 .38147 L .52585 .38177 L .67 .731 .896 r
F
.52613 .38179 m .52609 .38207 L .52607 .38171 L F
.52609 .38207 m .52607 .38223 L .52607 .38206 L F
.52609 .38207 m .52607 .38206 L .52607 .38171 L F
.52432 .38157 m .51707 .38006 L p .52437 .38147 L F P
0 g
s
.51707 .38006 m .51099 .37879 L p .51806 .38021 L .67 .731 .896 r
F P
0 g
s
.51707 .38006 m .51806 .38021 L .52437 .38147 L .67 .731 .896 r
F
.52495 .38159 m .51099 .37879 L .52499 .38155 L F
.52529 .38182 m .52499 .38177 L p .52595 .38156 L F P
0 g
s
.52499 .38177 m .52401 .38161 L p .525 .38143 L .67 .731 .896 r
F P
0 g
s
.52401 .38161 m .521 .38088 L .525 .38143 L .67 .731 .896 r
F
.52495 .38159 m .52499 .38155 L .52566 .38168 L F
.52499 .38177 m .525 .38143 L .52595 .38156 L F
.52662 .38119 m .52623 .38211 L p .52624 .38119 L F P
0 g
s
.52623 .38211 m .52609 .38207 L .52625 .38094 L .67 .731 .896 r
F
.52595 .38156 m .52607 .38188 L .52585 .38177 L F
.52607 .38171 m .52607 .38188 L .52595 .38156 L F
.52595 .38156 m .52585 .38177 L .52612 .38177 L F
.52612 .38177 m .52566 .38168 L .52595 .38156 L F
.52727 .38181 m .52676 .38171 L .52727 .38187 L F
.53063 .37171 m .52963 .37155 L p .5262 .38078 L F P
0 g
s
.52626 .38162 m .52595 .38156 L .52626 .38164 L .67 .731 .896 r
F
.52662 .38119 m .52624 .38119 L .52625 .38094 L F
.52629 .38198 m .52657 .38133 L p .52626 .38162 L F P
0 g
s
.52617 .38148 m .52613 .38179 L .5261 .38151 L .67 .731 .896 r
F
.52595 .38156 m .52623 .38191 L .52624 .38163 L F
.52623 .38191 m .52629 .38198 L .52624 .38163 L F
.52625 .38163 m .52612 .38177 L .52595 .38156 L F
.52626 .38162 m .52625 .38163 L .52595 .38156 L F
.52595 .38156 m .52612 .38177 L .52625 .38146 L F
.52625 .38146 m .52626 .38162 L .52653 .38103 L F
.53063 .37171 m .52669 .38103 L p .52625 .38094 L F P
0 g
s
.52645 .38103 m .52653 .38103 L .52855 .37644 L .67 .731 .896 r
F
.52645 .38103 m .52855 .37644 L .52834 .37681 L F
.52625 .38146 m .52653 .38103 L .52645 .38103 L F
.52649 .38202 m .54154 .38516 L p .52655 .3817 L F P
0 g
s
.52624 .38163 m .52649 .38202 L .52655 .3817 L .67 .731 .896 r
F
.52654 .3817 m .52612 .38177 L .52625 .38163 L F
.52727 .38181 m .52727 .38187 L .54154 .38516 L F
.54154 .38516 m .52939 .38263 L p .53149 .38283 L F P
0 g
s
.5412 .3858 m .54154 .38516 L p .53146 .38282 L .67 .731 .896 r
F P
0 g
s
.53144 .38281 m .52642 .38183 L .52654 .3817 L .67 .731 .896 r
F
.53146 .38282 m .52642 .38183 L .53144 .38281 L F
.52629 .38198 m .52649 .38202 L p .52624 .38163 L F P
0 g
s
.52626 .38162 m .52618 .38184 L .52629 .38198 L .67 .731 .896 r
F
.52642 .38183 m .52629 .38198 L .52612 .38177 L F
.52908 .38235 m .52649 .38201 L .52642 .38183 L F
.53149 .38283 m .52903 .38243 L .52908 .38235 L F
.52903 .38243 m .52649 .38201 L .52908 .38235 L F
.52649 .38201 m .52629 .38198 L .52642 .38183 L F
.52602 .38262 m .522 .39214 L p .52554 .38243 L F P
0 g
s
.52452 .38532 m .52509 .38451 L .5261 .38202 L .67 .731 .896 r
F
.52612 .38177 m .52629 .38198 L .52566 .38168 L F
.52608 .38201 m .5261 .38202 L .52626 .38162 L F
.52452 .38532 m .5261 .38202 L .52608 .38201 L F
.53149 .38283 m .52642 .38183 L .53146 .38282 L F
.52642 .38183 m .52612 .38177 L .52642 .38183 L F
.52642 .38183 m .52642 .38183 L .53146 .38282 L F
.52605 .38192 m .52602 .38197 L .52617 .38183 L F
.52602 .38197 m .52608 .38201 L .52617 .38183 L F
.52612 .38177 m .52603 .38196 L .52623 .38191 L F
.52607 .38223 m .52602 .38262 L .5257 .38209 L F
.52602 .38197 m .52524 .38373 L .52608 .38201 L F
.52524 .38373 m .52452 .38532 L .52527 .38373 L F
.52524 .38373 m .52527 .38373 L .52608 .38201 L F
.52607 .38188 m .52607 .38223 L .52585 .38177 L F
.52612 .38177 m .52599 .38197 L .52603 .38196 L F
.52585 .38177 m .52607 .38223 L .5257 .38209 L F
.52585 .38177 m .5257 .38209 L .52612 .38177 L F
.5257 .38209 m .52484 .38391 L .5259 .38213 L F
.5257 .38209 m .5259 .38213 L .52612 .38177 L F
.52583 .38205 m .52617 .38183 L .52612 .38177 L F
.52612 .38177 m .52566 .38168 L .52606 .38171 L F
.52612 .38177 m .52617 .38183 L .52626 .38162 L F
.52642 .38183 m .52612 .38177 L .52654 .3817 L F
.52669 .38103 m .52662 .38119 L p .52625 .38094 L F P
0 g
s
.52657 .38133 m .52685 .38066 L p .52626 .38162 L .67 .731 .896 r
F P
0 g
s
.52626 .38162 m .52685 .38066 L .5268 .38065 L .67 .731 .896 r
F
.52626 .38162 m .52703 .38024 L .52689 .38021 L F
.52624 .38177 m .52633 .38177 L .52663 .38134 L F
.52612 .38177 m .52606 .38171 L .52663 .38174 L F
.52625 .38143 m .52605 .38169 L .52626 .38162 L F
.52605 .38169 m .52612 .38177 L .52626 .38162 L F
.52612 .38177 m .52566 .38168 L .52612 .38177 L F
.52629 .38198 m .52566 .38168 L .52612 .38177 L F
.52605 .38169 m .5258 .38204 L .52612 .38177 L F
.5258 .38204 m .52568 .3822 L .52583 .38205 L F
.5258 .38204 m .52583 .38205 L .52612 .38177 L F
.52625 .38146 m .52646 .38152 L .52631 .38144 L F
.52626 .38162 m .52626 .38164 L .52675 .38175 L F
.52676 .38171 m .52675 .38175 L .52727 .38187 L F
.54154 .38516 m .54182 .38451 L p .52727 .38181 L F P
0 g
s
.54182 .38451 m .5315 .38283 L p .52725 .38186 L .67 .731 .896 r
F P
0 g
s
.52007 .39169 m .51914 .39141 L p .52021 .38987 L .67 .731 .896 r
F P
0 g
s
.52711 .38179 m .52709 .38182 L .52625 .38163 L .67 .731 .896 r
F
.52703 .38024 m .53063 .37171 L p .52689 .38021 L F P
0 g
s
.52834 .37681 m .52855 .37644 L .53063 .37171 L .67 .731 .896 r
F
.53161 .37192 m .53063 .37171 L p .52873 .37572 L F P
0 g
s
.52873 .37572 m .52607 .38131 L .52781 .37836 L .67 .731 .896 r
F
.52873 .37572 m .52781 .37836 L .53161 .37192 L F
.52607 .38131 m .52609 .38132 L .53161 .37192 L F
.52617 .38148 m .5261 .38151 L .52607 .38131 L F
.52607 .38131 m .52607 .38171 L .52595 .38156 L F
.52663 .38134 m .52693 .38077 L p .52595 .38156 L F P
0 g
s
.52595 .38156 m .52693 .38077 L .52684 .38073 L .67 .731 .896 r
F
.52685 .38066 m .52703 .38024 L p .5268 .38065 L F P
0 g
s
.5262 .38131 m .52617 .38148 L .52607 .38131 L .67 .731 .896 r
F
.52625 .38094 m .5262 .38131 L .52607 .38131 L F
.52595 .38156 m .52707 .38051 L .52778 .37844 L F
.52595 .38156 m .52557 .38151 L .52556 .38149 L F
.52593 .38154 m .52566 .38168 L .52482 .38128 L F
.52625 .38146 m .52624 .38177 L .52646 .38152 L F
.52582 .38183 m .52568 .3822 L .52591 .38189 L F
.52582 .38183 m .52591 .38189 L .52625 .38143 L F
.52623 .38211 m .52602 .38262 L p .52609 .38207 L F P
0 g
s
.51071 .37945 m .51099 .37879 L p .51706 .37992 L .67 .731 .896 r
F P
0 g
s
.52556 .38149 m .52088 .38085 L .51706 .37992 L .67 .731 .896 r
F
.52088 .38085 m .51071 .37945 L .51706 .37992 L F
.52557 .38151 m .51071 .37945 L .52556 .38149 L F
.52566 .38168 m .51099 .37879 L .52482 .38128 L F
.51099 .37879 m .51132 .37815 L p .52482 .38128 L F P
0 g
s
.51132 .37815 m .52327 .38121 L p .52482 .38128 L .67 .731 .896 r
F P
0 g
s
.5218 .38125 m .52529 .38182 L p .52342 .38123 L .67 .731 .896 r
F P
0 g
s
.52347 .38125 m .52331 .38121 L .52342 .38125 L .67 .731 .896 r
F
.522 .39214 m .52602 .38262 L p .52589 .38255 L F P
0 g
s
.52596 .38238 m .52589 .38255 L .52599 .3824 L .67 .731 .896 r
F
.52596 .38238 m .52599 .3824 L .52629 .38198 L F
.52602 .38262 m .52629 .38198 L p .52589 .38255 L F P
0 g
s
.52599 .38197 m .52484 .38391 L .52618 .38198 L .67 .731 .896 r
F
.52453 .3853 m .52452 .38532 L .52568 .38274 L F
.52568 .38274 m .52568 .38274 L .52605 .38192 L F
.52453 .3853 m .52568 .38274 L .52568 .38274 L F
.52599 .38254 m .52609 .38236 L p .52582 .3825 L F P
0 g
s
.52618 .38184 m .52596 .38238 L .52629 .38198 L .67 .731 .896 r
F
.52617 .38192 m .52621 .38194 L .52623 .38191 L F
.52599 .38197 m .52621 .38194 L .52617 .38192 L F
.52599 .38197 m .52618 .38198 L .52621 .38194 L F
.52609 .38236 m .52629 .38198 L p .52592 .38235 L F P
0 g
s
.52592 .38235 m .52629 .38198 L .52618 .38198 L .67 .731 .896 r
F
.52612 .38177 m .52612 .38177 L .52721 .38198 L F
.52721 .38198 m .52721 .38198 L .53146 .38282 L F
.52612 .38177 m .52721 .38198 L .52721 .38198 L F
.52721 .38198 m .52629 .38198 L .52612 .38177 L F
.53146 .38282 m .52716 .38212 L .52721 .38198 L F
.52716 .38212 m .52629 .38198 L .52721 .38198 L F
.54182 .38451 m .52725 .38186 L .52727 .38182 L F
.52832 .38204 m .52816 .38204 L .54182 .38451 L F
.52453 .38531 m .52599 .38254 L p .52484 .38391 L F P
0 g
s
.52484 .38391 m .52599 .38254 L .52582 .3825 L .67 .731 .896 r
F
.52568 .3822 m .52532 .38316 L .52605 .38192 L F
.52585 .38207 m .52617 .38183 L .52583 .38205 L F
.52585 .38225 m .52584 .38207 L .52592 .38181 L F
.52532 .38316 m .52548 .38319 L .52605 .38192 L F
.52583 .38241 m .52584 .38225 L .52585 .38225 L F
.52584 .38225 m .52584 .38207 L .52585 .38225 L F
.52615 .38213 m .52575 .38259 L .52601 .38199 L F
.52629 .38198 m .52563 .38187 L p .52566 .38168 L F P
0 g
s
.52636 .38164 m .52606 .38171 L .52593 .38154 L .67 .731 .896 r
F
.52582 .3825 m .52609 .38236 L .52592 .38235 L F
.52588 .38187 m .52629 .38198 L .52592 .38181 L F
.52606 .38171 m .52566 .38168 L .52593 .38154 L F
.52593 .38154 m .52582 .38183 L .52602 .38165 L F
.52612 .38177 m .52623 .38191 L .52625 .38146 L F
.52639 .38173 m .52606 .38171 L .52636 .38164 L F
.52727 .38182 m .52725 .38186 L .52709 .38182 L F
.52759 .37135 m .52656 .37131 L p .52631 .37463 L F P
0 g
s
.52763 .38193 m .52612 .38177 L .52689 .38176 L .67 .731 .896 r
F
.52778 .38197 m .52762 .38195 L .52763 .38193 L F
.52762 .38195 m .52612 .38177 L .52763 .38193 L F
.5262 .38078 m .52625 .38146 L .52837 .37674 L F
.5262 .38078 m .52837 .37674 L .52856 .37595 L F
.52693 .38077 m .52707 .38051 L p .52684 .38073 L F P
0 g
s
.52707 .38051 m .53161 .37192 L p .52778 .37844 L .67 .731 .896 r
F P
0 g
s
.53161 .37192 m .52663 .38134 L p .5269 .38001 L .67 .731 .896 r
F P
0 g
s
.52696 .37988 m .5269 .38001 L .5262 .38078 L .67 .731 .896 r
F
.52695 .37991 m .5269 .38001 L .52691 .37998 L F
.53161 .37192 m .5269 .38001 L .52695 .37991 L F
.52963 .37155 m .52696 .37988 L p .5262 .38078 L F P
0 g
s
.52696 .37989 m .52695 .3799 L .53258 .37216 L .67 .731 .896 r
F
.52695 .37991 m .52693 .37999 L .5269 .38001 L F
.52695 .3799 m .52693 .37999 L p .52695 .37991 L F P
0 g
s
.52693 .37996 m .52691 .37999 L .52693 .37999 L .67 .731 .896 r
F
.52695 .3799 m .52667 .38053 L .52733 .37959 L F
.52695 .3799 m .52733 .37959 L .53258 .37216 L F
.52696 .37988 m .52695 .3799 L p .52695 .37991 L F P
0 g
s
.52729 .37635 m .52622 .38032 L .52691 .37999 L .67 .731 .896 r
F
.52729 .37635 m .52691 .37999 L .52693 .37996 L F
.52963 .37155 m .52861 .37143 L p .52729 .37635 L F P
0 g
s
.52693 .37999 m .52963 .37155 L p .52729 .37635 L .67 .731 .896 r
F P
0 g
s
.52861 .37143 m .52678 .37975 L p .52622 .38032 L .67 .731 .896 r
F P
0 g
s
.52759 .37135 m .52604 .38039 L .52776 .37531 L .67 .731 .896 r
F
.52759 .37135 m .52686 .37734 L p .52645 .37802 L F P
0 g
s
.52604 .38039 m .52649 .38074 L .52776 .37531 L .67 .731 .896 r
F
.52626 .38147 m .52624 .38148 L .52626 .38145 L F
.52642 .38158 m .52612 .38141 L .5262 .38078 L F
.52676 .38171 m .52626 .38162 L .52675 .38175 L F
.52773 .3819 m .52625 .38163 L .52626 .38162 L F
.54182 .38451 m .52773 .38191 L .52773 .3819 L F
.52773 .38191 m .52625 .38163 L .52773 .3819 L F
.52634 .38157 m .52628 .3814 L .5264 .38113 L F
.52634 .38157 m .5264 .38113 L .52671 .38044 L F
.52342 .38123 m .52544 .38176 L .52546 .38159 L F
.52342 .38125 m .52533 .38173 L p .52555 .38166 L F P
0 g
s
.52563 .38187 m .52529 .38182 L p .5256 .3817 L .67 .731 .896 r
F P
0 g
s
.52514 .38168 m .52596 .38193 L .52588 .38187 L .67 .731 .896 r
F
.52342 .38123 m .52511 .38169 L .52514 .38168 L F
.52511 .38169 m .52596 .38193 L .52514 .38168 L F
.5269 .38001 m .52634 .38128 L .5262 .38078 L F
.52671 .38044 m .52625 .38131 L .52675 .3803 L F
.52691 .37998 m .52625 .38131 L .52621 .38118 L F
.52681 .38031 m .52675 .3803 L .52691 .37998 L F
.52696 .37989 m .52618 .38123 L .52667 .38053 L F
.52656 .38101 m .52652 .38102 L .52671 .38044 L F
.52638 .38169 m .52652 .38102 L .52656 .38101 L F
.52631 .38144 m .52646 .38152 L .52663 .38134 L F
.52638 .38169 m .52634 .38157 L .52652 .38102 L F
.52672 .3806 m .52675 .3803 L .52681 .38031 L F
.52638 .38169 m .52667 .38061 L .52672 .3806 L F
.52667 .38061 m .52675 .3803 L .52672 .3806 L F
.52177 .38144 m .52109 .38137 L .5213 .38137 L F
.52401 .38161 m .51071 .37945 L p .521 .38088 L F P
0 g
s
.52177 .38144 m .5213 .38137 L .52471 .38149 L .67 .731 .896 r
F
.52533 .38173 m .52342 .38125 L .52533 .38173 L F
.52342 .38123 m .52528 .38182 L .5254 .38178 L F
.52489 .38181 m .52177 .38144 L .52471 .38149 L F
.52428 .38174 m .52527 .38186 L p .52323 .38134 L F P
0 g
s
.52593 .38154 m .52592 .38181 L .52582 .38183 L .67 .731 .896 r
F
.52587 .38182 m .52592 .38181 L .52586 .38178 L F
.52588 .38187 m .52592 .38181 L .52587 .38182 L F
.52607 .38131 m .52595 .38156 L .52609 .38132 L F
.5262 .38078 m .52593 .38154 L .52625 .38143 L F
.52604 .38136 m .52592 .38181 L .526 .38134 L F
.52566 .3816 m .52568 .38168 L .52612 .38177 L F
.52546 .38159 m .52592 .38181 L .52606 .3817 L F
.52592 .38181 m .52629 .38198 L .52612 .38177 L F
.52593 .38154 m .52602 .38165 L .52625 .38143 L F
.52607 .38178 m .52592 .38181 L .52613 .38104 L F
.52592 .38181 m .52612 .38177 L .52606 .3817 L F
.52608 .38172 m .52615 .38175 L .52598 .3816 L F
.52851 .38224 m .52826 .38219 L .52848 .38213 L F
.52826 .38219 m .52612 .38177 L .52831 .3821 L F
.52826 .38219 m .52831 .3821 L .52848 .38213 L F
.52779 .38202 m .52612 .38177 L .52778 .38197 L F
.52629 .38198 m .52663 .38134 L p .52618 .38198 L F P
0 g
s
.5264 .38177 m .52629 .38198 L p .52638 .38169 L .67 .731 .896 r
F P
0 g
s
.52615 .38175 m .52676 .38196 L .52623 .38171 L .67 .731 .896 r
F
.52624 .38177 m .52623 .38191 L .52633 .38177 L F
.52629 .38198 m .52612 .38177 L .52626 .38169 L F
.52596 .38193 m .52629 .38198 L p .52595 .38192 L F P
0 g
s
.52615 .38213 m .52601 .38199 L .52609 .38183 L .67 .731 .896 r
F
.5261 .38199 m .52605 .3819 L .52611 .38179 L F
.52608 .38264 m .52606 .38199 L .5261 .38199 L F
.52606 .38199 m .52605 .3819 L .5261 .38199 L F
.52647 .38185 m .52656 .38199 L .5271 .382 L F
.52676 .38196 m .52702 .38205 L .52678 .38195 L F
.52712 .38191 m .52728 .382 L .52723 .38194 L F
.53147 .38282 m .52629 .38198 L p .53146 .38282 L F P
0 g
s
.52629 .38198 m .53147 .38282 L p .52736 .38201 L .67 .731 .896 r
F P
0 g
s
.52728 .382 m .52819 .38247 L .52736 .38201 L .67 .731 .896 r
F
.52728 .382 m .52736 .38201 L .52723 .38194 L F
.53146 .38282 m .52851 .38224 L .52848 .38213 L F
.52848 .38213 m .52779 .38202 L .52778 .38197 L F
.52939 .38263 m .52629 .38198 L p .53149 .38283 L F P
0 g
s
.53146 .38282 m .52689 .38176 L .541 .38575 L .67 .731 .896 r
F
.5315 .38283 m .53146 .38282 L .53144 .38281 L F
.52689 .38176 m .52723 .38194 L .5412 .3858 L F
.5279 .38203 m .52736 .38201 L .5315 .38283 L F
.5315 .38283 m .53147 .38282 L p .53146 .38282 L F P
0 g
s
.53147 .38282 m .5315 .38283 L p .52736 .38201 L .67 .731 .896 r
F P
0 g
s
.52708 .38196 m .5271 .382 L .52736 .38201 L .67 .731 .896 r
F
.52704 .38202 m .52819 .38247 L .52712 .38191 L F
.52819 .38247 m .5411 .38578 L p .52723 .38194 L F P
0 g
s
.53189 .38319 m .5267 .38196 L .52854 .38224 L .67 .731 .896 r
F
.53153 .38324 m .5267 .38196 L .53189 .38319 L F
.52612 .38177 m .52656 .38199 L .52647 .38185 L F
.52612 .38177 m .5271 .382 L .52708 .38196 L F
.52676 .38196 m .52678 .38195 L .52623 .38171 L F
.52323 .38134 m .52527 .38186 L .5251 .38176 L F
.52544 .38176 m .52561 .38169 L .52546 .38159 L F
.52629 .38198 m .52615 .38213 L .52609 .38183 L F
.52629 .38198 m .52609 .38183 L .52612 .38177 L F
.52617 .38199 m .52611 .38179 L .52612 .38177 L F
.52622 .38221 m .52616 .38199 L .52617 .38199 L F
.52616 .38199 m .52611 .38179 L .52617 .38199 L F
.52702 .38205 m .52703 .38204 L .52598 .3816 L F
.52612 .38177 m .52663 .38174 L .52663 .38176 L F
.52628 .38168 m .52649 .3818 L .52655 .38176 L F
.52598 .3816 m .52624 .3817 L .52628 .38168 L F
.52629 .38198 m .52627 .38168 L .52638 .38169 L F
.52624 .3817 m .52649 .3818 L .52628 .38168 L F
.52627 .38168 m .52625 .38131 L .52636 .38164 L F
.52627 .38168 m .52636 .38164 L .52638 .38169 L F
.52649 .3818 m .52704 .38202 L .52655 .38176 L F
.52631 .38173 m .52626 .38174 L .52705 .38188 L F
.52612 .38177 m .52629 .38198 L .52656 .38199 L F
.52619 .38185 m .52629 .38198 L .52637 .38191 L F
.52694 .38187 m .52711 .38191 L .52712 .38191 L F
.52655 .38176 m .52711 .38191 L .52694 .38187 L F
.52655 .38176 m .52684 .38191 L .52711 .38191 L F
.52618 .38123 m .52824 .37892 L .52838 .3781 L F
.52724 .38004 m .52689 .38103 L .52824 .37892 L F
.52693 .37999 m .52673 .38062 L p .52655 .38082 L F P
0 g
s
.52673 .38062 m .52642 .38158 L p .52655 .38082 L .67 .731 .896 r
F P
0 g
s
.52655 .38082 m .52642 .38158 L .52634 .38128 L .67 .731 .896 r
F
.52628 .3814 m .52625 .38131 L .52671 .38044 L F
.52667 .38116 m .52657 .38117 L .52691 .37998 L F
.52618 .38123 m .52689 .38103 L .52724 .38004 L F
.52838 .3781 m .52824 .37892 L .53258 .37216 L F
.53258 .37216 m .52689 .38104 L p .52656 .38079 L F P
0 g
s
.52837 .37819 m .52656 .38079 L .52828 .37872 L .67 .731 .896 r
F
.52732 .38216 m .52735 .38214 L .52704 .38202 L F
.52703 .38204 m .52704 .38202 L .52598 .3816 L F
.52732 .38216 m .52704 .38202 L .52703 .38204 L F
.52634 .38175 m .52633 .3818 L .52706 .38191 L F
.52626 .38174 m .52633 .3818 L .52634 .38175 L F
.52627 .38179 m .52612 .38177 L .52632 .38181 L F
.52615 .38175 m .52612 .38177 L .52627 .38179 L F
.52626 .38174 m .52612 .38177 L .52633 .3818 L F
.52102 .39194 m .52453 .38531 L p .52484 .38391 L F P
0 g
s
.52532 .38316 m .52453 .3853 L .52548 .38319 L .67 .731 .896 r
F
.52568 .3822 m .52532 .38353 L .52453 .3853 L F
.52629 .38198 m .52484 .38472 L p .52575 .38259 L F P
0 g
s
.52484 .38472 m .52453 .38531 L p .52481 .38469 L .67 .731 .896 r
F P
0 g
s
.52484 .38472 m .52481 .38469 L .52575 .38259 L .67 .731 .896 r
F
.52452 .38532 m .522 .39214 L .52509 .38451 L F
.52573 .38248 m .52299 .3923 L .52568 .3822 L F
.52626 .38174 m .52706 .38191 L .52705 .38189 L F
.52627 .38168 m .52624 .38148 L .52626 .38147 L F
.52629 .38198 m .52626 .38169 L .52627 .38168 L F
.52636 .38164 m .52593 .38154 L .5263 .38167 L F
.52593 .38154 m .52563 .38147 L .52595 .38156 L F
.52593 .38154 m .52595 .38156 L .5263 .38167 L F
.52611 .38179 m .52605 .3819 L .52608 .38172 L F
.52563 .38147 m .52564 .38151 L .52598 .3816 L F
.52689 .38176 m .52639 .38173 L .52636 .38164 L F
.52574 .38215 m .52275 .38836 L .52571 .38213 L F
.52275 .38836 m .52102 .39194 L .52271 .3884 L F
.52275 .38836 m .52271 .3884 L .52571 .38213 L F
.5256 .38263 m .52102 .39194 L .52552 .3826 L F
.52582 .38183 m .52573 .38248 L .52568 .3822 L F
.52583 .38241 m .52575 .3824 L .52584 .38207 L F
.52588 .38187 m .52595 .38192 L .52629 .38198 L F
.52598 .38242 m .52592 .38181 L .52607 .38178 L F
.5259 .38241 m .52583 .38241 L .52592 .38181 L F
.52601 .38199 m .52563 .38264 L .52595 .38193 L F
.52563 .38264 m .52547 .3829 L .5256 .38263 L F
.52563 .38264 m .5256 .38263 L .52595 .38193 L F
.52347 .38125 m .52342 .38125 L .52526 .3816 L F
.52588 .38187 m .52563 .38167 L .52556 .38166 L F
.52595 .38156 m .52598 .3816 L .52691 .38185 L F
.52642 .38158 m .52638 .38171 L p .52615 .38168 L F P
0 g
s
.52612 .38177 m .52611 .38179 L .52611 .38176 L .67 .731 .896 r
F
.52632 .38181 m .52611 .38177 L .52637 .38191 L F
.52611 .38177 m .52555 .38166 L .52604 .38181 L F
.52612 .38177 m .52609 .38183 L .52608 .38179 L F
.52611 .38177 m .52604 .38181 L .52637 .38191 L F
.52611 .38179 m .52608 .38172 L .52611 .38176 L F
.52555 .38166 m .52597 .38184 L .52604 .38181 L F
.52586 .38191 m .52583 .38192 L .52597 .38159 L F
.52609 .38183 m .52595 .38193 L .52606 .3817 L F
.52588 .38187 m .52586 .38178 L .52583 .38183 L F
.52568 .3822 m .52585 .38207 L .52583 .38205 L F
.52592 .38181 m .52573 .38248 L .52582 .38183 L F
.5256 .38263 m .52552 .3826 L .52574 .38215 L F
.52563 .38187 m .5256 .3817 L .52566 .38168 L F
.52544 .38176 m .52588 .38187 L .52561 .38169 L F
.52533 .38173 m .5259 .38188 L p .52555 .38166 L F P
0 g
s
.5259 .38188 m .52629 .38198 L p .52597 .38184 L .67 .731 .896 r
F P
0 g
s
.52583 .38183 m .52586 .38178 L .52563 .38167 L .67 .731 .896 r
F
.52555 .38166 m .5259 .38188 L .52597 .38184 L F
.52579 .38218 m .52574 .38215 L .52586 .38191 L F
.52596 .38158 m .52592 .38181 L .52593 .38154 L F
.52482 .38128 m .52608 .38172 L .52598 .3816 L F
.52638 .38171 m .52619 .38175 L .52615 .38168 L F
.52615 .38175 m .52623 .38171 L .52598 .3816 L F
.52626 .38169 m .52612 .38177 L .52624 .38148 L F
.52603 .38167 m .52626 .38174 L .52631 .38173 L F
.52537 .38153 m .52605 .38169 L .52603 .38167 L F
.52612 .38177 m .52611 .38176 L .52612 .38141 L F
.52615 .38168 m .52612 .38177 L .52612 .38141 L F
.52612 .38177 m .52606 .3817 L .52626 .38145 L F
.52605 .38169 m .52626 .38174 L .52603 .38167 L F
.52592 .38187 m .52586 .38191 L .52599 .38162 L F
.52601 .38164 m .52599 .38162 L .52621 .38118 L F
.5252 .38141 m .52612 .38177 L .52615 .38175 L F
.52592 .38187 m .52599 .38162 L .52601 .38164 L F
.52579 .38218 m .52586 .38191 L .52592 .38187 L F
.5256 .38263 m .52574 .38215 L .52579 .38218 L F
.52575 .38259 m .52452 .38533 L .52547 .3829 L F
.5258 .38248 m .52573 .38248 L .52575 .3824 L F
.52577 .38253 m .52573 .38248 L .5258 .38248 L F
.52575 .38259 m .52547 .3829 L .52601 .38199 L F
.52589 .38266 m .52577 .38253 L .5258 .38248 L F
.52589 .38266 m .52575 .3824 L .5259 .38241 L F
.52576 .38267 m .52573 .38248 L .52589 .38266 L F
.52587 .3833 m .52299 .3923 L p .52573 .38248 L F P
0 g
s
.52583 .38233 m .52529 .38321 L .52562 .38287 L .67 .731 .896 r
F
.52561 .38258 m .52539 .38337 L .52575 .38245 L F
.52539 .38337 m .52539 .3834 L .52541 .38333 L F
.52529 .38321 m .52539 .38337 L .5254 .38337 L F
.52539 .3834 m .52565 .38328 L .52587 .38254 L F
.52594 .38242 m .52592 .38181 L .52598 .38242 L F
.5259 .38266 m .52592 .38181 L .52595 .38265 L F
.52579 .38249 m .52587 .38254 L .52607 .38186 L F
.52539 .3834 m .52587 .38254 L .52579 .38249 L F
.52323 .38134 m .52499 .38169 L .52493 .38166 L F
.52347 .38125 m .52526 .3816 L .52526 .3816 L F
.52361 .38143 m .52431 .38158 L .52368 .38143 L F
.52515 .38177 m .52489 .38181 L .52483 .3817 L F
.52515 .38177 m .52483 .3817 L .52471 .38149 L F
.52526 .3816 m .52526 .3816 L .52568 .38168 L F
.52526 .3816 m .52568 .38168 L .52568 .38168 L F
.52548 .38172 m .52533 .38173 L .52551 .38165 L F
.52573 .38171 m .52548 .38172 L .52551 .38165 L F
.52533 .38173 m .52531 .38173 L .52532 .38173 L F
.52533 .38173 m .52532 .38173 L .52551 .38165 L F
.5252 .38142 m .52612 .38177 L .5252 .38141 L F
.52505 .38136 m .52612 .38177 L .52505 .38136 L F
.52537 .38153 m .52546 .38159 L .52626 .38174 L F
.52482 .38128 m .52347 .38125 L .52568 .38168 L F
.52482 .38128 m .52568 .38168 L .52566 .3816 L F
.5254 .38151 m .52537 .38153 L .52602 .38165 L F
.5254 .38151 m .52602 .38165 L .52599 .38162 L F
.52537 .38153 m .52531 .38157 L .52546 .38159 L F
.52556 .38166 m .52563 .38167 L .52546 .38159 L F
.52597 .38159 m .52572 .38169 L .52471 .38148 L F
.52583 .38233 m .52562 .38287 L .52584 .38237 L F
.52612 .38177 m .52608 .38179 L .52606 .3817 L F
.52611 .38176 m .52608 .38172 L .52612 .38141 L F
.52616 .38172 m .52614 .38171 L .52615 .38168 L F
.52616 .38176 m .52614 .38171 L .52616 .38172 L F
.52616 .38176 m .52612 .38177 L .52614 .38171 L F
.52606 .3817 m .52612 .38177 L .52626 .38174 L F
.52599 .38162 m .52588 .38186 L .52597 .38159 L F
.52732 .38216 m .52819 .38247 L .52735 .38214 L F
.52819 .38247 m .52629 .38198 L .52914 .38261 L F
.52595 .38156 m .52691 .38185 L .52691 .38185 L F
.52663 .38176 m .52663 .38174 L .52689 .38176 L F
.52636 .38164 m .5263 .38167 L .52723 .38194 L F
.52602 .38165 m .52705 .38188 L .52703 .38183 L F
.52537 .38153 m .52603 .38167 L .52602 .38165 L F
.52603 .38167 m .52705 .38188 L .52602 .38165 L F
.52607 .38178 m .52613 .38104 L .52615 .38105 L F
.52615 .38152 m .52606 .3817 L .52605 .38156 L F
.52606 .3817 m .52595 .38193 L .52602 .38165 L F
.52606 .3817 m .52602 .38165 L .52605 .38156 L F
.52595 .38193 m .5256 .38263 L .52591 .38189 L F
.52595 .38193 m .52591 .38189 L .52605 .38156 L F
.52629 .38198 m .5259 .38188 L .52626 .38195 L F
.5259 .38188 m .52533 .38173 L .52588 .38186 L F
.52601 .38199 m .52595 .38193 L .52609 .38183 L F
.5259 .38188 m .52588 .38186 L .52626 .38195 L F
.52629 .38198 m .52819 .38247 L p .52637 .38191 L F P
0 g
s
.52629 .38198 m .52626 .38195 L .52724 .38217 L .67 .731 .896 r
F
.52588 .38186 m .52588 .38185 L .52597 .38159 L F
.52616 .38182 m .52588 .38186 L .52584 .38181 L F
.52584 .38181 m .52596 .38179 L .52606 .38171 L F
.52602 .38178 m .52584 .38181 L .52573 .38171 L F
.52616 .38182 m .52584 .38181 L .52602 .38178 L F
.52568 .38168 m .52568 .38168 L .52632 .38181 L F
.52597 .38159 m .52584 .38181 L .52606 .38171 L F
.52633 .38164 m .5254 .38151 L .52636 .38168 L F
.5259 .38175 m .52588 .38177 L .52597 .38159 L F
.52574 .38215 m .52588 .38177 L .5259 .38175 L F
.52574 .38215 m .52571 .38213 L .52588 .38177 L F
.52588 .38186 m .52533 .38173 L .52573 .38171 L F
.52597 .38159 m .5258 .38194 L .52575 .38196 L F
.52584 .38181 m .52575 .38196 L .52596 .38179 L F
.52633 .38164 m .52572 .38169 L .52597 .38159 L F
.52727 .38182 m .52709 .38182 L .52711 .38179 L F
.52633 .38164 m .52636 .38168 L .52823 .38203 L F
.52824 .38199 m .52823 .38203 L .54182 .38451 L F
.52633 .38164 m .52823 .38203 L .52824 .38199 L F
.52638 .38171 m .5265 .38131 L p .52632 .38163 L F P
0 g
s
.52656 .38167 m .52626 .38168 L .52633 .38164 L .67 .731 .896 r
F
.52626 .38168 m .52572 .38169 L .52633 .38164 L F
.52602 .38206 m .52602 .38206 L .52608 .38186 L F
.52609 .38173 m .52604 .38168 L .52626 .38168 L F
.52588 .38186 m .52586 .38191 L .52588 .38185 L F
.52586 .38191 m .52574 .38215 L .52583 .38192 L F
.52533 .38173 m .52533 .38173 L .52629 .38198 L F
.52612 .38177 m .52527 .38186 L .52571 .38169 L F
.52631 .38191 m .52629 .38198 L p .52626 .38191 L F P
0 g
s
.52631 .38191 m .52626 .38191 L .52619 .38175 L .67 .731 .896 r
F
.52638 .38171 m .52631 .38191 L p .52619 .38175 L F P
0 g
s
.52606 .38171 m .52609 .38174 L .52619 .3816 L .67 .731 .896 r
F
.52624 .38148 m .52615 .38168 L .52612 .38141 L F
.52626 .38145 m .52606 .3817 L .52625 .38131 L F
.52597 .38159 m .52606 .38171 L .52637 .38146 L F
.52586 .38206 m .52599 .38204 L .52612 .38177 L F
.52609 .38174 m .52612 .38177 L .52619 .3816 L F
.52622 .38221 m .52612 .38177 L .52616 .38176 L F
.52604 .38181 m .52629 .38198 L .52619 .38185 L F
.52597 .38184 m .52629 .38198 L .52604 .38181 L F
.52623 .3819 m .52588 .38186 L .52616 .38182 L F
.52586 .38206 m .52612 .38177 L .52609 .38174 L F
.52684 .38191 m .52704 .38202 L .52708 .38196 L F
.52644 .38185 m .52637 .38191 L .52819 .38247 L F
.52728 .3821 m .52629 .38198 L .52703 .38195 L F
.52572 .38183 m .52629 .38198 L .52572 .38183 L F
.52629 .38198 m .52533 .38173 L p .52629 .38198 L F P
0 g
s
.52575 .38196 m .52586 .38206 L .52607 .38178 L .67 .731 .896 r
F
.52603 .38178 m .52607 .38178 L .52609 .38174 L F
.52575 .38196 m .52607 .38178 L .52603 .38178 L F
.52572 .38183 m .52629 .38198 L .52629 .38198 L F
.52533 .38173 m .52572 .38183 L .52572 .38183 L F
.52602 .38206 m .52608 .38186 L .52607 .38186 L F
.52607 .38171 m .52611 .38176 L .52627 .3812 L F
.52602 .38206 m .5261 .38178 L .5261 .38178 L F
.52616 .38174 m .52609 .38173 L .52626 .38168 L F
.52626 .38169 m .52624 .38148 L .52627 .38168 L F
.52629 .38198 m .52617 .38184 L .52615 .38168 L F
.52642 .38158 m .52615 .38168 L .52624 .38148 L F
.52614 .38172 m .52619 .38186 L .5265 .38131 L F
.52687 .38184 m .5268 .3819 L .52611 .38176 L F
.52609 .38173 m .52611 .38176 L .52572 .38169 L F
.52619 .38186 m .52638 .38171 L .52633 .38164 L F
.52616 .38174 m .52611 .38176 L .52609 .38173 L F
.5266 .3818 m .52612 .38176 L .52616 .38174 L F
.52612 .38176 m .52611 .38176 L .52616 .38174 L F
.52619 .38186 m .52633 .38164 L .52631 .38165 L F
.52689 .38176 m .52636 .38164 L .52723 .38194 L F
.52599 .38162 m .52602 .38165 L .52816 .38204 L F
.52616 .38174 m .52626 .38168 L .52656 .38167 L F
.52631 .38165 m .52633 .38164 L .52632 .38163 L F
.52623 .38191 m .52638 .38171 L .52619 .38186 L F
.52632 .38181 m .52637 .38191 L .52644 .38185 L F
.52656 .38193 m .52602 .38178 L .52652 .38185 L F
.52602 .38178 m .52551 .38165 L .52612 .38177 L F
.52612 .38177 m .52619 .38186 L .52614 .38172 L F
.52602 .38178 m .52612 .38177 L .52652 .38185 L F
.52637 .38146 m .52618 .38176 L .52651 .38162 L F
.5267 .38196 m .52623 .3819 L .52616 .38182 L F
.52656 .38193 m .52652 .38185 L .5268 .3819 L F
.5268 .3819 m .52623 .38191 L .52612 .38177 L F
.52612 .38177 m .52595 .38228 L .52619 .38186 L F
.52611 .38176 m .5261 .38178 L .52612 .38177 L F
.52608 .38264 m .52595 .38265 L .52605 .3819 L F
.5261 .38178 m .52595 .38228 L .52612 .38177 L F
.52626 .38174 m .52662 .3818 L .52671 .38182 L F
.52691 .38185 m .52691 .38185 L .52723 .38194 L F
.52662 .3818 m .52749 .38197 L .52671 .38182 L F
.52671 .38182 m .52749 .38197 L .52749 .38196 L F
.52687 .38184 m .52659 .38181 L .5266 .3818 L F
.52659 .38181 m .52611 .38176 L .5266 .3818 L F
.52684 .38183 m .52616 .38174 L .52656 .38167 L F
.5268 .3819 m .52612 .38177 L .5267 .38173 L F
.52618 .38176 m .52615 .38181 L .52639 .38172 L F
.52638 .38198 m .52588 .38186 L .5267 .38196 L F
.52622 .38221 m .52609 .38222 L .52611 .38179 L F
.52615 .38181 m .52601 .38203 L .5262 .38188 L F
.52615 .38181 m .5262 .38188 L .52639 .38172 L F
.54182 .38451 m .54204 .38384 L p .52826 .38191 L F P
0 g
s
.52826 .38191 m .52824 .38199 L .54182 .38451 L .67 .731 .896 r
F
.52703 .38183 m .52705 .38188 L .54182 .38451 L F
.54033 .38703 m .54048 .38682 L p .53338 .38423 L F P
0 g
s
.52723 .38194 m .5411 .38578 L .54104 .38576 L .67 .731 .896 r
F
.5279 .38203 m .5315 .38283 L .53342 .38301 L F
.53071 .3825 m .52855 .38225 L p .53071 .3825 L F P
0 g
s
.52855 .38225 m .52629 .38198 L p .52854 .38225 L .67 .731 .896 r
F P
0 g
s
.52855 .38225 m .52854 .38225 L .53071 .3825 L .67 .731 .896 r
F
.54117 .38579 m .53153 .38324 L .53189 .38319 L F
.51654 .39034 m .51575 .38991 L p .52009 .38643 L F P
0 g
s
.5309 .38316 m .53246 .38356 L .53246 .38356 L .67 .731 .896 r
F
.52629 .38198 m .5309 .38316 L .5309 .38316 L F
.5309 .38316 m .53246 .38356 L .5309 .38316 L F
.52902 .38272 m .53053 .38328 L .53088 .38331 L F
.52702 .38205 m .52732 .38216 L .52703 .38204 L F
.52914 .38261 m .52638 .38198 L .5267 .38196 L F
.52629 .38198 m .52629 .38198 L .52854 .38224 L F
.52629 .38198 m .52854 .38224 L .52854 .38225 L F
.53071 .3825 m .5314 .38258 L .5314 .38258 L F
.52629 .38198 m .52854 .38225 L .52854 .38225 L F
.52705 .38189 m .52706 .38191 L .52749 .38197 L F
.52684 .38191 m .52708 .38196 L .52712 .38191 L F
.52612 .38177 m .52736 .38201 L .5279 .38203 L F
.52749 .38196 m .52749 .38197 L .5279 .38203 L F
.52629 .38198 m .52629 .38198 L .52962 .38283 L F
.52629 .38198 m .52622 .38221 L p .52617 .38184 L F P
0 g
s
.52595 .38228 m .52623 .38191 L .52619 .38186 L .67 .731 .896 r
F
.52601 .38203 m .52607 .38202 L .52651 .38162 L F
.52663 .38134 m .5264 .38177 L p .52657 .38117 L F P
0 g
s
.52612 .38177 m .52643 .38172 L .5267 .38173 L .67 .731 .896 r
F
.52467 .38143 m .52471 .38148 L .52395 .38134 L F
.5254 .38151 m .52342 .38123 L .52531 .38157 L F
.52597 .38159 m .52471 .38148 L .52467 .38143 L F
.52393 .3813 m .52395 .38134 L .52342 .38123 L F
.5254 .38151 m .52395 .38134 L .52393 .3813 L F
.52597 .38159 m .52541 .38152 L .5254 .38151 L F
.52541 .38152 m .52395 .38134 L .5254 .38151 L F
.52609 .38173 m .52572 .38169 L .52604 .38168 L F
.52571 .38169 m .52551 .38165 L .52563 .38161 L F
.52563 .38147 m .52598 .3816 L .52595 .38156 L F
.52571 .38169 m .52563 .38161 L .5259 .3815 L F
.52596 .38227 m .52611 .38213 L .52608 .38211 L F
.52595 .38228 m .52596 .38227 L .52596 .38227 L F
.52596 .38227 m .52629 .38198 L .52596 .38227 L F
.52595 .38265 m .52594 .38242 L .52598 .38242 L F
.52589 .3831 m .5259 .38266 L .52595 .38265 L F
.52587 .38311 m .52588 .38287 L .52589 .3831 L F
.52588 .38287 m .52592 .38181 L .5259 .38288 L F
.52588 .38287 m .5259 .38288 L .52589 .3831 L F
.52623 .38191 m .52629 .38198 L .52651 .38162 L F
.52629 .38198 m .52638 .38171 L p .52608 .38211 L F P
0 g
s
.52611 .38213 m .52629 .38198 L .52608 .38211 L .67 .731 .896 r
F
.52595 .38228 m .52595 .38228 L .52602 .38206 L F
.52583 .38233 m .52629 .38198 L .52623 .38191 L F
.52629 .38198 m .52585 .38193 L .52623 .38191 L F
.5267 .38196 m .52656 .38193 L .5268 .3819 L F
.5267 .38196 m .5268 .3819 L .52683 .38196 L F
.52629 .38198 m .52623 .38191 L .52703 .38195 L F
.52638 .38196 m .5264 .38196 L .52624 .38192 L F
.52619 .3816 m .52599 .38204 L .52637 .38146 L F
.52599 .38204 m .52601 .38203 L .52637 .38146 L F
.52595 .382 m .52607 .38186 L .5261 .38178 L F
.52595 .382 m .5261 .38178 L .52609 .38179 L F
.52595 .382 m .52611 .38176 L .52607 .38171 L F
.52607 .38186 m .52608 .38186 L .5261 .38178 L F
.52623 .38191 m .52591 .38189 L .52612 .38177 L F
.52625 .38193 m .52624 .38192 L .52591 .38184 L F
.52629 .38198 m .52621 .38173 L .52631 .3817 L F
.52638 .38196 m .52624 .38192 L .52625 .38193 L F
.52595 .38228 m .52602 .38206 L .52602 .38206 L F
.52595 .38214 m .52591 .38222 L .52651 .38162 L F
.52591 .38222 m .52589 .38226 L .52593 .38222 L F
.52591 .38222 m .52593 .38222 L .52651 .38162 L F
.52644 .38165 m .52605 .38169 L .5259 .3815 L F
.52657 .38169 m .52645 .38169 L .52644 .38165 L F
.52599 .38162 m .52816 .38204 L .52832 .38204 L F
.52645 .38169 m .52605 .38169 L .52644 .38165 L F
.52519 .38158 m .52446 .38144 L .52446 .38144 L F
.52611 .38176 m .52519 .38158 L .52519 .38158 L F
.52519 .38158 m .52446 .38144 L .52519 .38158 L F
.52587 .3833 m .52576 .38267 L .52589 .38266 L F
.52622 .38221 m .52608 .38264 L p .52609 .38222 L F P
0 g
s
.52595 .38228 m .52523 .38472 L .52629 .38198 L .67 .731 .896 r
F
.52562 .38372 m .5256 .38369 L .5257 .38312 L F
.52562 .38372 m .5257 .38312 L .52588 .38213 L F
.52583 .38405 m .52562 .38372 L .52588 .38213 L F
.52565 .38395 m .52579 .38376 L .52606 .38262 L F
.52663 .38134 m .52657 .38117 L .52667 .38116 L F
.5264 .38177 m .52638 .38169 L .52685 .38016 L F
.52686 .38015 m .52685 .38016 L .52691 .37998 L F
.5264 .38177 m .52685 .38016 L .52686 .38015 L F
.52643 .38106 m .52614 .38172 L .5265 .38131 L F
.52629 .38137 m .52651 .38162 L .52638 .38117 L F
.52638 .38117 m .52651 .38162 L .52689 .38103 L F
.52633 .38141 m .5263 .38134 L .52656 .38079 L F
.52693 .37999 m .52634 .38128 L .5269 .38001 L F
.5265 .38131 m .52693 .37999 L p .52622 .38032 L F P
0 g
s
.52618 .38123 m .52629 .38137 L .52638 .38117 L .67 .731 .896 r
F
.52637 .38086 m .52614 .38172 L .52643 .38106 L F
.5263 .38134 m .52643 .38106 L .52643 .38106 L F
.52643 .38106 m .52652 .38085 L .52643 .38106 L F
.52643 .38106 m .52652 .38085 L .52656 .38079 L F
.52446 .38144 m .52338 .38123 L .52342 .38123 L F
.52446 .38144 m .52338 .38123 L .52446 .38144 L F
.52523 .38472 m .52497 .38561 L .52531 .38467 L F
.52587 .3833 m .52587 .38311 L .52589 .3831 L F
.52517 .38548 m .52527 .38518 L p .52497 .38561 L F P
0 g
s
.52575 .38196 m .52609 .38174 L .52606 .38171 L .67 .731 .896 r
F
.52585 .38193 m .52572 .38191 L .52588 .38191 L F
.52529 .38182 m .52596 .38193 L p .5254 .38178 L F P
0 g
s
.52591 .38189 m .52527 .38186 L .52612 .38177 L .67 .731 .896 r
F
.52612 .38177 m .52551 .38165 L .52611 .38176 L F
.52629 .38198 m .52585 .38193 L p .52629 .38198 L F P
0 g
s
.5262 .38572 m .52603 .39253 L p .52596 .38525 L .67 .731 .896 r
F P
0 g
s
.52608 .38264 m .52587 .3833 L p .52595 .38265 L .67 .731 .896 r
F P
0 g
s
.52523 .38472 m .52531 .38467 L .52629 .38198 L .67 .731 .896 r
F
.52583 .38405 m .52399 .39242 L p .5256 .38369 L F P
0 g
s
.52458 .38897 m .52584 .38369 L .52579 .38376 L .67 .731 .896 r
F
.52499 .38788 m .52617 .38251 L p .52458 .38897 L F P
0 g
s
.52612 .38277 m .52595 .38354 L p .52598 .38281 L .67 .731 .896 r
F P
0 g
s
.52595 .38354 m .52583 .38405 L p .52589 .38338 L .67 .731 .896 r
F P
0 g
s
.52458 .38897 m .52617 .38251 L .52611 .38257 L .67 .731 .896 r
F
.52589 .38362 m .52501 .39249 L .52577 .38341 L F
.52625 .38131 m .52615 .38152 L .52621 .38118 L F
.52615 .38152 m .52605 .38156 L .52621 .38118 L F
.52621 .38118 m .52599 .38162 L .52597 .38159 L F
.52618 .38123 m .52597 .38159 L .52637 .38146 L F
.52621 .38173 m .52629 .3813 L .52633 .38141 L F
.52617 .38184 m .52617 .38175 L .52621 .38173 L F
.52599 .38204 m .52607 .38186 L .52595 .382 L F
.52585 .38193 m .52585 .38193 L .52629 .38198 L F
.52585 .38193 m .52588 .38191 L .52623 .38191 L F
.52572 .38191 m .52569 .38188 L .52623 .38191 L F
.52585 .38193 m .52667 .38203 L p .52585 .38186 L F P
0 g
s
.52551 .38165 m .52551 .38165 L .52611 .38176 L .67 .731 .896 r
F
.52605 .38169 m .52571 .38169 L .5259 .3815 L F
.52618 .38176 m .52639 .38172 L .52651 .38162 L F
.52643 .38172 m .52571 .38169 L .52657 .38169 L F
.5259 .3815 m .52579 .38188 L .52605 .38169 L F
.52579 .38188 m .52577 .38198 L .52583 .38191 L F
.52579 .38188 m .52583 .38191 L .52605 .38169 L F
.52609 .38179 m .5261 .38178 L .52611 .38176 L F
.52575 .38196 m .52583 .38233 L .52595 .38214 L F
.5258 .38189 m .52585 .38193 L .52585 .3819 L F
.5258 .38189 m .52585 .3819 L .52585 .38186 L F
.52579 .38188 m .5258 .38189 L .52585 .38186 L F
.52586 .38186 m .52584 .38186 L .5259 .3815 L F
.52577 .38198 m .52596 .38186 L .52605 .38169 L F
.52528 .38182 m .52529 .38182 L .5254 .38178 L F
.52527 .38186 m .52489 .38181 L .52571 .38169 L F
.52368 .38143 m .52574 .3819 L .52574 .38184 L F
.52574 .3819 m .52585 .38193 L .52579 .38188 L F
.52574 .3819 m .52579 .38188 L .52574 .38184 L F
.52585 .38186 m .52584 .38186 L .52586 .38186 L F
.52583 .38206 m .52584 .38187 L .52585 .38186 L F
.52584 .38187 m .52584 .38186 L .52585 .38186 L F
.52575 .38196 m .52515 .383 L .52583 .38233 L F
.52102 .39194 m .52007 .39169 L p .52479 .3836 L F P
0 g
s
.52575 .38196 m .52496 .38363 L .52479 .3836 L .67 .731 .896 r
F
.52496 .38363 m .52102 .39194 L .52479 .3836 L F
.52586 .38217 m .52607 .38171 L .52605 .38169 L F
.52575 .38247 m .52587 .38218 L .52586 .38217 L F
.52587 .38218 m .52607 .38171 L .52586 .38217 L F
.52556 .38296 m .52576 .38247 L .52556 .38295 L F
.52587 .38186 m .52585 .38186 L .5259 .3815 L F
.52587 .38219 m .52587 .38218 L .52575 .38247 L F
.52575 .38247 m .52607 .38171 L .52575 .38247 L F
.52568 .38243 m .52575 .38245 L .52605 .38169 L F
.52515 .383 m .52524 .38314 L .52583 .38233 L F
.52561 .38258 m .52574 .38247 L .52568 .38243 L F
.52574 .38247 m .52575 .38245 L .52568 .38243 L F
.52591 .38184 m .52589 .38185 L .52594 .38155 L F
.52615 .38105 m .52613 .38104 L .52616 .38095 L F
.52618 .38095 m .52616 .38095 L .5262 .38078 L F
.5262 .38078 m .52604 .38136 L .526 .38134 L F
.52606 .38089 m .5259 .3815 L .52637 .38086 L F
.52594 .38156 m .52594 .38155 L .526 .38113 L F
.52591 .38184 m .52594 .38155 L .52594 .38156 L F
.52711 .38218 m .52743 .38229 L .52745 .38229 L F
.52629 .38198 m .52724 .38217 L .52724 .38219 L F
.52622 .3819 m .52711 .38219 L .52711 .38218 L F
.52711 .38219 m .52743 .38229 L .52711 .38218 L F
.52583 .38233 m .52589 .38259 L .52629 .38198 L F
.5259 .3826 m .52629 .38198 L p .52589 .38259 L F P
0 g
s
.52589 .38259 m .52629 .38198 L .52629 .38198 L .67 .731 .896 r
F
.52637 .38197 m .52667 .38203 L .52638 .38196 L F
.52624 .38192 m .52742 .3823 L .52622 .3819 L F
.52742 .3823 m .52906 .38283 L .52743 .38229 L F
.52638 .38196 m .52667 .38203 L .5264 .38196 L F
.52742 .3823 m .52743 .38229 L .52622 .3819 L F
.52598 .38246 m .52613 .38222 L .52613 .38222 L F
.52613 .38222 m .52646 .38171 L .52613 .38222 L F
.52598 .38246 m .52613 .38222 L .52598 .38246 L F
.52613 .38222 m .52646 .38171 L .52613 .38222 L F
.52613 .38222 m .52613 .38222 L .52598 .38246 L F
.52515 .383 m .52438 .38431 L .52524 .38314 L F
.52438 .38431 m .52017 .39152 L .52465 .38425 L F
.5258 .38194 m .52499 .38364 L .52575 .38196 L F
.52499 .38364 m .52102 .39194 L .52496 .38363 L F
.52499 .38364 m .52496 .38363 L .52575 .38196 L F
.52336 .38163 m .52028 .38127 L p .52336 .38163 L F P
0 g
s
.52431 .38158 m .52432 .38158 L .52368 .38143 L .67 .731 .896 r
F
.52459 .38149 m .52109 .38137 L .52165 .38133 L F
.52459 .38149 m .52165 .38133 L .52338 .38123 L F
.52531 .38173 m .52342 .38125 L .5235 .38125 L F
.52551 .38165 m .52395 .38134 L .52551 .38165 L F
.52395 .38134 m .52338 .38123 L .52395 .38134 L F
.52395 .38134 m .52395 .38134 L .52611 .38176 L F
.52551 .38165 m .5235 .38125 L .5259 .3815 L F
.52531 .38173 m .5235 .38125 L .52551 .38165 L F
.52471 .38149 m .52459 .38149 L .52338 .38123 L F
.52109 .38137 m .523 .38124 L .52338 .38123 L F
.52336 .38163 m .52336 .38163 L .52358 .38166 L F
.52358 .38166 m .52358 .38166 L .52585 .38193 L F
.52336 .38163 m .52358 .38166 L .52358 .38166 L F
.52568 .3818 m .52591 .38184 L .52548 .38164 L F
.52591 .38184 m .52622 .3819 L .52598 .38182 L F
.52591 .38184 m .52598 .38182 L .52548 .38164 L F
.52587 .38219 m .52607 .38171 L .52587 .38218 L F
.52586 .38206 m .52595 .38214 L .52599 .38204 L F
.52577 .38198 m .52576 .38201 L .52596 .38186 L F
.52608 .38108 m .52594 .38183 L .526 .38113 L F
.52594 .38183 m .52584 .38236 L .52591 .38184 L F
.52612 .38277 m .52598 .38281 L .52603 .38196 L F
.52599 .38269 m .52606 .38262 L .52619 .38204 L F
.52745 .38229 m .52906 .38283 L .52909 .38282 L F
.52743 .38229 m .52906 .38283 L .52745 .38229 L F
.52585 .38186 m .52626 .38194 L .52587 .38186 L F
.52613 .38222 m .52646 .38171 L .52646 .38171 L F
.5268 .3819 m .52612 .38177 L .52611 .38176 L F
.52646 .38171 m .52629 .38198 L p .52631 .3817 L F P
0 g
s
.52626 .38194 m .52637 .38197 L .52626 .38194 L .67 .731 .896 r
F
.52626 .38194 m .52626 .38194 L .52572 .38182 L F
.52607 .38212 m .52615 .38181 L .52617 .38184 L F
.52594 .38183 m .52591 .38184 L .52594 .38156 L F
.52594 .38183 m .52594 .38156 L .52596 .38158 L F
.52563 .38147 m .52482 .38128 L .52564 .38151 L F
.52527 .38137 m .52573 .38169 L .52611 .38177 L F
.52611 .38176 m .52612 .38177 L .52614 .38172 L F
.52612 .38177 m .52571 .38169 L .52643 .38172 L F
.52596 .38249 m .5259 .3826 L p .52597 .38239 L F P
0 g
s
.52596 .38249 m .52597 .38239 L .52608 .3821 L .67 .731 .896 r
F
.52629 .38198 m .52596 .38249 L p .52608 .3821 L F P
0 g
s
.52599 .38255 m .52596 .38255 L .526 .38202 L .67 .731 .896 r
F
.52601 .382 m .526 .38202 L .52602 .3818 L F
.52601 .38203 m .52595 .38214 L .52607 .38202 L F
.52599 .38204 m .52595 .38214 L .52601 .38203 L F
.5259 .3826 m .52594 .38195 L .52605 .38209 L F
.52599 .38255 m .526 .38202 L .52601 .382 L F
.52598 .38225 m .52594 .38183 L .52602 .3818 L F
.52604 .38194 m .52594 .38195 L .52603 .3818 L F
.52605 .38209 m .526 .38203 L .52604 .38194 L F
.526 .38203 m .52594 .38195 L .52604 .38194 L F
.52606 .3817 m .52611 .38177 L .52612 .38177 L F
.52598 .38182 m .52622 .3819 L .52602 .3818 L F
.52637 .38086 m .52611 .38176 L .52614 .38172 L F
.52654 .38081 m .52637 .38119 L .5265 .38082 L F
.52654 .38182 m .5267 .38188 L .52658 .3818 L F
.52647 .38195 m .52728 .3821 L .52714 .38197 L F
.52683 .38196 m .5268 .3819 L .52703 .38195 L F
.52703 .38195 m .52677 .38193 L .5268 .3819 L F
.5304 .3823 m .5268 .3819 L .52687 .38184 L F
.53272 .38265 m .52855 .38225 L .5268 .3819 L F
.54175 .3838 m .53286 .38275 L .53272 .38265 L F
.53286 .38275 m .52855 .38225 L .53272 .38265 L F
.52714 .38197 m .5268 .3819 L .52679 .38188 L F
.52714 .38197 m .52679 .38188 L .5267 .38173 L F
.52657 .38169 m .5267 .38184 L .52706 .38195 L F
.52792 .38212 m .5268 .3819 L .5268 .3819 L F
.52855 .38225 m .52792 .38212 L .52792 .38212 L F
.52792 .38212 m .5268 .3819 L .52792 .38212 L F
.5268 .3819 m .52612 .38177 L .5268 .3819 L F
.5268 .3819 m .5268 .3819 L .52792 .38212 L F
.52595 .38354 m .52589 .38338 L .52596 .38255 L F
.52584 .38369 m .52611 .38257 L .52579 .38376 L F
.52629 .38198 m .52612 .38277 L p .52604 .38202 L F P
0 g
s
.52602 .3818 m .52622 .3819 L .52611 .38177 L .67 .731 .896 r
F
.52587 .38186 m .52625 .38194 L .52591 .38184 L F
.52605 .38209 m .52603 .3818 L .52611 .38177 L F
.52614 .38179 m .52611 .38177 L .52615 .38175 L F
.52591 .38184 m .52667 .38203 L .52663 .38198 L F
.52605 .38209 m .52611 .38177 L .52614 .38179 L F
.52625 .38194 m .52638 .38196 L .52625 .38193 L F
.52625 .38194 m .52625 .38193 L .52591 .38184 L F
.52612 .38177 m .52611 .38177 L .52612 .38177 L F
.52606 .3817 m .52612 .38177 L .52657 .38186 L F
.52602 .38165 m .52606 .3817 L .52651 .38184 L F
.52652 .38184 m .52651 .38184 L .52657 .38186 L F
.52602 .38165 m .52651 .38184 L .52652 .38184 L F
.52555 .38429 m .52629 .38198 L p .52545 .38427 L F P
0 g
s
.52595 .38214 m .52583 .38233 L .52589 .38226 L .67 .731 .896 r
F
.52583 .38405 m .52588 .38213 L .52598 .38225 L F
.52537 .38435 m .52565 .38395 L .52615 .38207 L F
.52637 .38119 m .52635 .38117 L .5265 .38082 L F
.52607 .38171 m .52627 .3812 L .52605 .38169 L F
.52602 .38165 m .52622 .38173 L .52598 .3816 L F
.52647 .38195 m .52714 .38197 L .52675 .38189 L F
.5268 .3819 m .52612 .38177 L .5268 .3819 L F
.52629 .38198 m .52652 .38163 L p .52629 .38198 L F P
0 g
s
.52652 .38163 m .52824 .37894 L p .52651 .38162 L .67 .731 .896 r
F P
0 g
s
.52651 .38162 m .52824 .37894 L .52824 .37894 L .67 .731 .896 r
F
.52629 .38198 m .52652 .38163 L .52651 .38162 L F
.52502 .38141 m .5249 .38143 L .52555 .38163 L F
.52505 .38136 m .5252 .38142 L .5252 .38141 L F
.52482 .38128 m .52505 .38136 L .52505 .38136 L F
.5259 .3815 m .52485 .38139 L .52504 .38126 L F
.52527 .38137 m .52502 .38141 L .52573 .38169 L F
.52549 .38133 m .52528 .38163 L .52483 .38122 L F
.52544 .38132 m .52483 .38122 L .52465 .38105 L F
.52549 .38133 m .52483 .38122 L .52544 .38132 L F
.52622 .38173 m .52652 .38184 L .52627 .38171 L F
.52652 .38184 m .52652 .38184 L .52627 .38171 L F
.52657 .38186 m .52662 .38187 L .52627 .38171 L F
.52608 .38172 m .52618 .38178 L .52697 .38184 L F
.53173 .38253 m .5268 .3819 L .53164 .38247 L F
.52854 .38224 m .52714 .38197 L .5267 .38173 L F
.52781 .3821 m .52883 .38253 L .52869 .3824 L F
.52657 .38169 m .52753 .38205 L .52781 .3821 L F
.5267 .38196 m .52703 .38195 L .52854 .38224 L F
.52855 .38225 m .52728 .3821 L .52703 .38195 L F
.52728 .3821 m .52855 .38225 L p .52762 .38206 L F P
0 g
s
.52753 .38205 m .52883 .38253 L .52781 .3821 L .67 .731 .896 r
F
.53164 .38247 m .53044 .38233 L .5304 .3823 L F
.53044 .38233 m .5268 .3819 L .5304 .3823 L F
.54175 .3838 m .53173 .38253 L .53164 .38247 L F
.5282 .382 m .52762 .38206 L .54204 .38384 L F
.52854 .38224 m .52657 .38169 L .52781 .3821 L F
.52855 .38225 m .52781 .3821 L .52869 .3824 L F
.52854 .38224 m .52781 .3821 L .52855 .38225 L F
.52854 .38225 m .5307 .3825 L .53071 .3825 L F
.52854 .38225 m .5307 .3825 L .52854 .38225 L F
.5307 .3825 m .5314 .38258 L .53071 .3825 L F
.52854 .38225 m .52854 .38224 L .5314 .38258 L F
.5314 .38258 m .5314 .38258 L .54175 .3838 L F
.54194 .38383 m .53071 .3825 L p .54175 .3838 L F P
0 g
s
.53071 .3825 m .53071 .3825 L .54175 .3838 L .67 .731 .896 r
F
.52855 .38225 m .54204 .38384 L p .52762 .38206 L F P
0 g
s
.52826 .38191 m .52633 .38164 L .52824 .38199 L .67 .731 .896 r
F
.51737 .39073 m .51654 .39034 L p .51941 .38771 L F P
0 g
s
.52916 .38204 m .52684 .38183 L .52656 .38167 L .67 .731 .896 r
F
.52608 .38172 m .52697 .38184 L .52697 .38184 L F
.52622 .38173 m .52627 .38171 L .52598 .3816 L F
.52598 .3816 m .52654 .38182 L .52658 .3818 L F
.52615 .38175 m .52622 .38152 L .52617 .38175 L F
.52636 .38168 m .52617 .38183 L .5262 .38174 L F
.5267 .38173 m .52643 .38172 L .52657 .38169 L F
.52657 .38169 m .52644 .38165 L .5267 .38184 L F
.52604 .38179 m .52602 .3818 L .52603 .38166 L F
.52607 .38178 m .52616 .38095 L .52618 .38095 L F
.526 .38134 m .52596 .38158 L .52593 .38154 L F
.5259 .3815 m .52605 .38169 L .52637 .38086 L F
.52604 .38168 m .52603 .38166 L .52608 .38108 L F
.52604 .38179 m .52603 .38166 L .52604 .38168 L F
.52644 .38165 m .5259 .3815 L .52629 .3817 L F
.52621 .38267 m .52501 .39249 L p .52594 .38318 L F P
0 g
s
.52503 .38634 m .52551 .38497 L .52579 .38376 L .67 .731 .896 r
F
.52503 .38634 m .52579 .38376 L .52565 .38395 L F
.52501 .39249 m .52616 .38306 L p .52566 .38351 L F P
0 g
s
.5262 .38572 m .52596 .38525 L .52594 .384 L .67 .731 .896 r
F
.52622 .38152 m .52617 .38175 L .52617 .38175 L F
.52611 .38177 m .52611 .38177 L .52622 .38151 L F
.52593 .38154 m .52587 .38186 L .5259 .3815 L F
.52527 .38137 m .52611 .38177 L .52602 .38165 L F
.52612 .38431 m .52594 .384 L .52593 .38267 L F
.52646 .38171 m .52631 .3817 L .52644 .38165 L F
.52644 .38165 m .52629 .3817 L .5267 .38184 L F
.52622 .38152 m .52623 .38151 L .52617 .38175 L F
.5259 .3815 m .52598 .3816 L .52629 .3817 L F
.5261 .38178 m .5261 .38178 L .52637 .38086 L F
.52616 .38139 m .52627 .3812 L .52623 .38121 L F
.52605 .38169 m .52618 .38141 L .52616 .38139 L F
.52618 .38141 m .52627 .3812 L .52616 .38139 L F
.52635 .38117 m .52603 .38196 L .52619 .38101 L F
.52602 .3818 m .52594 .38183 L .52608 .38108 L F
.52626 .38121 m .52607 .38171 L .52598 .38161 L F
.52623 .38121 m .52627 .3812 L .52637 .38086 L F
.5265 .38082 m .52635 .38117 L .52619 .38101 L F
.52656 .38079 m .52634 .3812 L .52626 .38121 L F
.52634 .3812 m .52607 .38171 L .52626 .38121 L F
.52623 .38151 m .52622 .38151 L .52635 .38117 L F
.52617 .38175 m .52629 .3813 L .52621 .38173 L F
.52631 .38169 m .52621 .38173 L .52633 .38141 L F
.52631 .3817 m .52621 .38173 L .52631 .38169 L F
.52631 .3817 m .52621 .38173 L .52621 .38173 L F
.52637 .38119 m .52636 .38168 L .52611 .38177 L F
.52656 .38079 m .52654 .38081 L .52655 .38081 L F
.52646 .38171 m .52633 .38141 L .52656 .38079 L F
.52654 .38081 m .52645 .38126 L .52637 .38119 L F
.52655 .38079 m .52655 .38081 L p .52654 .38081 L F P
0 g
s
.52655 .38081 m .52645 .38126 L p .52654 .38081 L .67 .731 .896 r
F P
0 g
s
.52644 .38165 m .52631 .3817 L .52633 .38141 L .67 .731 .896 r
F
.52645 .38126 m .52636 .38168 L p .52637 .38119 L F P
0 g
s
.52593 .38211 m .52588 .38213 L .5259 .38204 L .67 .731 .896 r
F
.52593 .38211 m .5259 .38204 L .52594 .38183 L F
.52541 .38333 m .52599 .38204 L .52595 .382 L F
.52596 .3821 m .52593 .38211 L .52594 .38183 L F
.52593 .38219 m .52588 .38213 L .52596 .3821 L F
.52584 .38236 m .52582 .38237 L .52589 .38185 L F
.52576 .38247 m .52587 .38219 L .52575 .38247 L F
.52513 .38515 m .52555 .38429 L .52545 .38427 L F
.52452 .38533 m .5237 .38649 L .52547 .3829 L F
.52529 .38321 m .52527 .38324 L .52535 .38331 L F
.52527 .38324 m .52017 .39152 L .52535 .38331 L F
.52535 .38331 m .52017 .39152 L .52539 .38337 L F
.52529 .38321 m .5254 .38337 L .52562 .38287 L F
.52567 .38276 m .5243 .38509 L .52543 .38294 L F
.52539 .38337 m .52598 .38246 L .52598 .38246 L F
.52562 .38287 m .5254 .38337 L .52589 .38259 L F
.52539 .38338 m .5259 .3826 L p .52539 .38337 L F P
0 g
s
.52539 .38337 m .5259 .3826 L .52589 .38259 L .67 .731 .896 r
F
.5259 .3826 m .52539 .38338 L p .52567 .38276 L F P
0 g
s
.52576 .38201 m .52561 .38256 L .5258 .38219 L .67 .731 .896 r
F
.52541 .38333 m .52556 .38296 L .52556 .38295 L F
.52561 .38256 m .52561 .38258 L .52561 .38257 L F
.52539 .3834 m .52558 .38296 L .52541 .38333 L F
.52558 .38296 m .52607 .38186 L .52558 .38296 L F
.52558 .38296 m .52558 .38296 L .52541 .38333 L F
.52657 .38169 m .52689 .38186 L .52699 .38184 L F
.52701 .38185 m .52714 .38197 L .52753 .38205 L F
.52675 .38189 m .52714 .38197 L .527 .38184 L F
.52636 .38168 m .52639 .38172 L .52781 .38191 L F
.52617 .38175 m .52617 .38175 L .52615 .38181 L F
.52614 .38179 m .52615 .38175 L .52615 .38181 L F
.52615 .38175 m .52617 .38175 L .52615 .38181 L F
.52615 .38181 m .52617 .38175 L .52617 .38184 L F
.52629 .38198 m .52617 .38184 L .52621 .38173 L F
.52622 .3819 m .52647 .38195 L .52608 .38172 L F
.52618 .38178 m .52647 .38195 L .52658 .38192 L F
.52677 .38193 m .52623 .38191 L .5268 .3819 L F
.52651 .38184 m .52658 .38192 L .52675 .38189 L F
.52618 .38178 m .52658 .38192 L .52651 .38184 L F
.52636 .38168 m .52629 .3817 L .52639 .38172 L F
.52611 .38177 m .52605 .38179 L .52641 .3819 L F
.52644 .38189 m .52641 .3819 L .52682 .38203 L F
.52611 .38177 m .52641 .3819 L .52644 .38189 L F
.5263 .38172 m .52625 .38193 L .52617 .38183 L F
.52636 .38168 m .52625 .38193 L .5263 .38172 L F
.52636 .38168 m .52629 .38198 L p .52625 .38193 L F P
0 g
s
.52571 .38169 m .52515 .38177 L .52471 .38149 L .67 .731 .896 r
F
.52497 .3815 m .52579 .38177 L .52582 .38177 L F
.5254 .38158 m .52548 .38164 L .5262 .38174 L F
.52607 .38171 m .52603 .3818 L .52598 .38161 L F
.52595 .38182 m .52624 .38192 L .52596 .38182 L F
.52637 .38197 m .52638 .38196 L .52572 .38182 L F
.52614 .38179 m .52615 .38181 L .52607 .38212 L F
.52611 .38177 m .52629 .38198 L .52603 .38196 L F
.52582 .38177 m .52624 .38192 L .52622 .3819 L F
.52619 .38101 m .52603 .38196 L .52608 .38108 L F
.52587 .38185 m .52629 .38198 L p .52595 .38182 L F P
0 g
s
.52629 .38198 m .52906 .38283 L p .52634 .38195 L .67 .731 .896 r
F P
0 g
s
.52629 .38198 m .52608 .3821 L .52617 .38184 L .67 .731 .896 r
F
.52595 .38182 m .52629 .38198 L .52634 .38195 L F
.52629 .38198 m .52587 .38185 L p .52628 .38196 L F P
0 g
s
.5259 .3815 m .52584 .38184 L .52581 .38183 L .67 .731 .896 r
F
.52584 .38184 m .52581 .38203 L .52581 .38183 L F
.52581 .38183 m .52581 .38203 L .52577 .38198 L F
.52323 .38134 m .52568 .3818 L .52548 .38164 L F
.52497 .38158 m .52587 .38185 L p .52497 .38156 L F P
0 g
s
.52587 .38185 m .52533 .38169 L p .52586 .38184 L .67 .731 .896 r
F P
0 g
s
.52587 .38185 m .52586 .38184 L .52628 .38196 L .67 .731 .896 r
F
.52603 .3818 m .52594 .38195 L .52588 .38185 L F
.52583 .38206 m .52573 .38262 L .52581 .38203 L F
.52576 .38201 m .5258 .38219 L .52596 .38186 L F
.52584 .38236 m .52589 .38185 L .52591 .38184 L F
.52561 .38256 m .52561 .38257 L .52568 .38243 L F
.52568 .38243 m .52568 .38243 L .52605 .38169 L F
.52561 .38256 m .52568 .38243 L .52568 .38243 L F
.52267 .38155 m .52428 .38174 L p .52415 .38169 L F P
0 g
s
.52323 .38134 m .52267 .38155 L .52415 .38169 L .67 .731 .896 r
F
.52109 .38137 m .52028 .38127 L .523 .38124 L F
.51071 .37945 m .5218 .38125 L p .52339 .38123 L F P
0 g
s
.5233 .38121 m .52342 .38125 L p .52331 .38121 L .67 .731 .896 r
F P
0 g
s
.52028 .38127 m .51051 .38011 L p .52334 .38122 L .67 .731 .896 r
F P
0 g
s
.52482 .38128 m .52327 .38121 L .52347 .38125 L .67 .731 .896 r
F
.52342 .38123 m .52331 .38121 L .52339 .38123 L F
.52338 .38123 m .52334 .38122 L .52342 .38123 L F
.52342 .38125 m .5233 .38121 L p .52338 .38123 L F P
0 g
s
.52028 .38127 m .52334 .38122 L .52338 .38123 L .67 .731 .896 r
F
.52338 .38123 m .51132 .37815 L .51863 .37946 L F
.52327 .38121 m .5233 .38121 L p .52331 .38121 L F P
0 g
s
.5233 .38121 m .51132 .37815 L p .52338 .38123 L .67 .731 .896 r
F P
0 g
s
.51051 .38011 m .52267 .38155 L p .52323 .38134 L .67 .731 .896 r
F P
0 g
s
.52343 .38177 m .51036 .38079 L p .52463 .38148 L .67 .731 .896 r
F P
0 g
s
.52191 .38148 m .52428 .38171 L .52163 .38144 L .67 .731 .896 r
F
.52625 .38193 m .52623 .38202 L .52623 .38202 L F
.52633 .38165 m .52625 .38193 L .52625 .38193 L F
.52625 .38193 m .52623 .38202 L .52625 .38193 L F
.52829 .38249 m .52909 .38282 L .52902 .38272 L F
.52447 .38378 m .52445 .38395 L .52396 .3845 L F
.52445 .38395 m .5243 .38509 L .52396 .3845 L F
.52396 .3845 m .5243 .38509 L .52021 .38987 L F
.52011 .39163 m .52539 .38338 L p .52017 .39152 L F P
0 g
s
.52017 .39152 m .52539 .38338 L .52539 .38337 L .67 .731 .896 r
F
.52007 .39169 m .52011 .39163 L p .52017 .39152 L F P
0 g
s
.5243 .38509 m .52007 .39169 L p .52021 .38987 L .67 .731 .896 r
F P
0 g
s
.52466 .3835 m .51975 .39054 L .52452 .38432 L .67 .731 .896 r
F
.51914 .39141 m .52031 .38986 L p .51975 .39054 L F P
0 g
s
.52031 .38986 m .52452 .38432 L p .51975 .39054 L .67 .731 .896 r
F P
0 g
s
.52595 .38182 m .52596 .38182 L .52582 .38177 L .67 .731 .896 r
F
.52577 .38168 m .52592 .38175 L .52594 .3817 L F
.52602 .3818 m .52602 .3818 L .52602 .3818 L F
.52601 .38171 m .52603 .38179 L .52608 .38172 L F
.52598 .38182 m .52602 .3818 L .52583 .38171 L F
.52605 .38175 m .52611 .38177 L .52608 .38172 L F
.52602 .3818 m .52611 .38177 L .52605 .38175 L F
.52611 .38177 m .52573 .38169 L .52605 .38179 L F
.5254 .38158 m .5262 .38174 L .52629 .3817 L F
.52603 .3818 m .52588 .38185 L .52598 .38161 L F
.52593 .38182 m .52595 .38182 L .52595 .38182 L F
.52523 .38159 m .52587 .38185 L .52595 .38182 L F
.52504 .38126 m .52342 .38125 L .51863 .37946 L F
.51863 .37946 m .52486 .38152 L .52523 .38159 L F
.52486 .38152 m .52587 .38185 L .52523 .38159 L F
.52504 .38152 m .52467 .38148 L .52501 .38153 L F
.52467 .38148 m .52464 .38148 L .52469 .38149 L F
.52464 .38148 m .52466 .38153 L .52548 .38164 L F
.51863 .37946 m .52497 .38158 L .52497 .38156 L F
.52467 .38148 m .52469 .38149 L .52501 .38153 L F
.52532 .38168 m .52621 .38188 L .52621 .38189 L F
.52464 .38148 m .52548 .38164 L .52548 .38164 L F
.52497 .38151 m .52525 .3816 L .52497 .3815 L F
.52525 .3816 m .52624 .38192 L .52524 .38158 L F
.52525 .3816 m .52524 .38158 L .52497 .3815 L F
.52589 .38362 m .52577 .38341 L .52585 .38256 L F
.52438 .38431 m .52465 .38425 L .52529 .38321 L F
.52524 .38314 m .52529 .38321 L .52583 .38233 L F
.52438 .38431 m .52529 .38321 L .52524 .38314 L F
.52576 .38247 m .52575 .38247 L .52556 .38295 L F
.52556 .38295 m .52575 .38247 L .52575 .38247 L F
.52581 .38203 m .52554 .3836 L .52577 .38198 L F
.52527 .38518 m .52555 .38429 L p .52513 .38515 L F P
0 g
s
.52299 .39228 m .523 .39227 L .52474 .38636 L .67 .731 .896 r
F
.52474 .38636 m .52474 .38636 L .52595 .38228 L F
.52299 .39228 m .52474 .38636 L .52474 .38636 L F
.52554 .3836 m .52551 .38356 L .52577 .38198 L F
.52573 .38262 m .52569 .38271 L .52581 .38203 L F
.52593 .38219 m .52564 .38262 L .52593 .38209 L F
.52539 .38337 m .52541 .38333 L .52575 .38245 L F
.52577 .38198 m .52563 .38286 L .52539 .38337 L F
.52563 .38286 m .52551 .38356 L .52539 .38338 L F
.52563 .38286 m .52539 .38338 L .52539 .38337 L F
.52564 .38262 m .52543 .38294 L .52593 .38209 L F
.52574 .38287 m .52587 .38186 L .52589 .38185 L F
.52573 .38294 m .52574 .38287 L .52574 .38287 L F
.52584 .38237 m .52562 .38287 L .52589 .38259 L F
.5259 .3826 m .52567 .38276 L .52593 .38219 L F
.52574 .38287 m .52587 .38186 L .52574 .38287 L F
.54175 .3838 m .53013 .38227 L .53028 .38219 L F
.52629 .3817 m .5262 .38174 L .52782 .38195 L F
.5291 .38207 m .52684 .38183 L .52916 .38204 L F
.53013 .38227 m .52684 .38183 L .53028 .38219 L F
.52781 .38191 m .52875 .38208 L .52875 .38204 L F
.52629 .3817 m .52781 .38193 L .52781 .38191 L F
.52781 .38193 m .52875 .38208 L .52781 .38191 L F
.52781 .38193 m .52782 .38195 L .52875 .38208 L F
.52629 .3817 m .52782 .38195 L .52781 .38193 L F
.52466 .3835 m .52513 .3835 L .52447 .38378 L F
.52543 .38294 m .52513 .3835 L .52466 .3835 L F
.52513 .3835 m .5243 .38509 L .52447 .38378 L F
.52452 .38432 m .52561 .38287 L p .52466 .3835 L F P
0 g
s
.51983 .39047 m .51973 .39058 L .52558 .38229 L .67 .731 .896 r
F
.51983 .39047 m .52558 .38229 L .52558 .38229 L F
.52642 .38125 m .52642 .38125 L .52632 .38164 L F
.52633 .38164 m .52651 .3809 L .52632 .38164 L F
.52594 .38195 m .52588 .38186 L .52588 .38185 L F
.52574 .38184 m .52585 .38186 L .52572 .38182 L F
.52585 .38186 m .52587 .38186 L .52572 .38182 L F
.52574 .38184 m .52579 .38188 L .52585 .38186 L F
.52585 .38193 m .52336 .38163 L p .52585 .38193 L F P
0 g
s
.52572 .38191 m .52527 .38186 L .52569 .38188 L .67 .731 .896 r
F
.52299 .39228 m .52595 .38228 L .52595 .38228 L F
.52571 .38285 m .52596 .38525 L .52559 .38453 L F
.52397 .38181 m .52395 .38178 L .52562 .38182 L F
.52493 .38166 m .52587 .38186 L .52591 .38184 L F
.52562 .38183 m .52562 .38182 L .52601 .38183 L F
.52397 .38181 m .52562 .38182 L .52562 .38183 L F
.52593 .38209 m .52543 .38294 L .52594 .38195 L F
.52587 .38186 m .52583 .38206 L .52585 .38186 L F
.52594 .38195 m .52548 .38284 L .52588 .38186 L F
.52574 .38287 m .52569 .38283 L .52587 .38186 L F
.52573 .38294 m .52571 .38288 L .52574 .38287 L F
.52571 .38288 m .52569 .38283 L .52574 .38287 L F
.54204 .38384 m .54194 .38383 L p .54175 .3838 L F P
0 g
s
.52875 .38204 m .52875 .38208 L .54204 .38384 L .67 .731 .896 r
F
.53964 .38293 m .5291 .38191 L .53334 .38266 L F
.53028 .38219 m .5291 .38207 L .52916 .38204 L F
.5291 .38191 m .52837 .38198 L .53334 .38266 L F
.54204 .38384 m .54219 .38317 L p .53964 .38293 L F P
0 g
s
.53964 .38293 m .53334 .38266 L .54204 .38384 L .67 .731 .896 r
F
.54219 .38317 m .53022 .38228 L p .5291 .38191 L F P
0 g
s
.52747 .38175 m .52627 .3818 L .5261 .38176 L .67 .731 .896 r
F
.52633 .38165 m .52632 .38164 L .52625 .38193 L F
.52589 .38185 m .52587 .38186 L .526 .38113 L F
.52622 .38032 m .52606 .38089 L .52637 .38086 L F
.52655 .38078 m .52608 .38108 L .52622 .38032 L F
.52622 .38032 m .52608 .38108 L .526 .38113 L F
.52604 .38039 m .52591 .38118 L .52649 .38074 L F
.52636 .38168 m .52533 .38154 L .52629 .3817 L F
.52632 .38164 m .52533 .38154 L .52636 .38168 L F
.52579 .38177 m .52595 .38182 L .52582 .38177 L F
.52623 .38151 m .52611 .38177 L .52622 .38151 L F
.52523 .38159 m .52595 .38182 L .52593 .38182 L F
.52568 .38171 m .52598 .38182 L .52583 .38171 L F
.52573 .38169 m .52583 .38171 L .52577 .38168 L F
.52568 .38171 m .52583 .38171 L .52573 .38169 L F
.52615 .38175 m .52603 .3818 L .52629 .3813 L F
.52573 .38169 m .52597 .38182 L .52605 .38179 L F
.52622 .38153 m .52584 .38181 L .52611 .38177 L F
.52527 .38137 m .52602 .38165 L .52598 .3816 L F
.52598 .38161 m .52584 .38181 L .52622 .38153 L F
.52611 .38176 m .5261 .38176 L .52598 .38161 L F
.52592 .38173 m .52578 .38174 L .52576 .3817 L F
.52548 .38164 m .52568 .38171 L .52577 .38168 L F
.52548 .38164 m .52548 .38164 L .52548 .38164 L F
.52534 .38161 m .52597 .38182 L .52573 .38169 L F
.52633 .38165 m .52625 .38193 L .52625 .38193 L F
.52666 .38192 m .5264 .38187 L .52682 .38203 L F
.52657 .38186 m .5264 .38187 L .52666 .38192 L F
.52657 .38186 m .52611 .38177 L .5264 .38187 L F
.52606 .38212 m .52615 .38207 L .5262 .38187 L F
.52632 .38164 m .52611 .38176 L .52598 .38161 L F
.52617 .38183 m .52625 .38169 L .52621 .38171 L F
.52643 .38165 m .52632 .38164 L .52636 .38168 L F
.52632 .38164 m .52632 .38164 L .52633 .38165 L F
.52643 .38165 m .52636 .38168 L .52781 .38191 L F
.52605 .38209 m .52614 .38179 L .52607 .38212 L F
.52629 .38198 m .52604 .38202 L .52603 .38196 L F
.52606 .38212 m .5262 .38187 L .52617 .38183 L F
.52617 .38183 m .5262 .38187 L .52625 .38169 L F
.5263 .3818 m .52613 .38179 L .52618 .38178 L F
.52678 .38176 m .52612 .38176 L .52691 .3817 L F
.52705 .38219 m .52627 .38196 L .52697 .38208 L F
.52627 .38196 m .52532 .38168 L .52622 .3819 L F
.52611 .38177 m .52603 .38196 L .52611 .38177 L F
.51824 .39109 m .51737 .39073 L p .5238 .38396 L F P
0 g
s
.52597 .38182 m .52636 .38194 L .52605 .38179 L .67 .731 .896 r
F
.52636 .38194 m .52745 .38229 L .5264 .38191 L F
.52636 .38194 m .5264 .38191 L .52605 .38179 L F
.52522 .3827 m .52543 .38294 L .52466 .3835 L F
.52469 .38149 m .52548 .38164 L .5254 .38158 L F
.52533 .38169 m .52467 .38148 L p .52532 .38168 L F P
0 g
s
.52464 .38148 m .52548 .38164 L .52469 .38149 L .67 .731 .896 r
F
.51707 .37916 m .52497 .38158 L p .51863 .37946 L F P
0 g
s
.52467 .38148 m .52467 .38148 L .52532 .38168 L .67 .731 .896 r
F
.52475 .38144 m .52595 .38182 L .52475 .38144 L F
.52485 .38139 m .52342 .38125 L .52504 .38126 L F
.52109 .38023 m .52534 .38161 L .52573 .38169 L F
.51863 .37946 m .5211 .38025 L .52109 .38023 L F
.5211 .38025 m .52534 .38161 L .52109 .38023 L F
.52527 .38186 m .52585 .38193 L p .5251 .38176 L F P
0 g
s
.52582 .38195 m .52483 .38187 L p .52601 .38183 L .67 .731 .896 r
F P
0 g
s
.52622 .38152 m .52629 .3813 L .52623 .38151 L .67 .731 .896 r
F
.52637 .38119 m .52623 .38151 L .52635 .38117 L F
.5263 .38134 m .52629 .3813 L .52652 .38085 L F
.52655 .38081 m .52598 .38161 L .52622 .38153 L F
.52654 .38081 m .52598 .38161 L .52655 .38081 L F
.52655 .38078 m .52655 .38079 L p .52608 .38108 L F P
0 g
s
.52591 .38118 m .52624 .38155 L .52649 .38074 L .67 .731 .896 r
F
.5259 .3815 m .52424 .38104 L .52598 .3816 L F
.52596 .38158 m .52594 .38156 L .526 .38113 L F
.526 .38113 m .52593 .38149 L .5259 .3815 L F
.52591 .38118 m .52586 .38146 L .52624 .38155 L F
.5261 .38176 m .526 .38174 L .52605 .3817 L F
.52582 .38171 m .52576 .3817 L .52583 .38167 L F
.52581 .38177 m .52578 .38174 L .52602 .38178 L F
.52581 .38177 m .52602 .38178 L .52595 .38179 L F
.52593 .38149 m .52593 .38154 L .5259 .3815 L F
.52586 .38146 m .52606 .3817 L .52624 .38155 L F
.52649 .38167 m .52591 .38152 L .52586 .38146 L F
.52691 .3817 m .52612 .38176 L .52632 .38164 L F
.5265 .3817 m .52654 .38165 L p .52611 .38177 L F P
0 g
s
.5264 .38128 m .52641 .38124 L .52637 .38129 L .67 .731 .896 r
F
.52646 .38171 m .5267 .38133 L .5267 .38133 L F
.52689 .38104 m .52646 .38171 L p .52654 .38098 L F P
0 g
s
.52636 .38168 m .52655 .38078 L p .52634 .38165 L .67 .731 .896 r
F P
0 g
s
.52411 .38178 m .52433 .38166 L .52513 .38157 L .67 .731 .896 r
F
.52517 .38158 m .52513 .38157 L .52536 .38155 L F
.52411 .38178 m .52513 .38157 L .52517 .38158 L F
.52532 .38168 m .52467 .38148 L .52528 .38163 L F
.52464 .38148 m .52343 .38177 L .52463 .38148 L F
.52532 .38155 m .52529 .38155 L .52531 .38156 L F
.52533 .38154 m .52529 .38155 L .52532 .38155 L F
.52533 .38154 m .52504 .38152 L .52529 .38155 L F
.52536 .38155 m .52513 .38157 L .52464 .38148 L F
.52467 .38148 m .5247 .38149 L .52528 .38163 L F
.52513 .38157 m .52343 .38177 L .52464 .38148 L F
.52467 .38148 m .52463 .38147 L .5247 .38149 L F
.52505 .38177 m .52413 .38168 L .52412 .38168 L F
.52642 .38127 m .52649 .38104 L .52647 .38104 L F
.52533 .38169 m .52532 .38168 L .52627 .38196 L F
.52628 .38196 m .52627 .38196 L .52785 .38242 L F
.52785 .38243 m .52785 .38242 L .52815 .38251 L F
.52628 .38196 m .52785 .38242 L .52785 .38243 L F
.52631 .37463 m .52585 .38092 L .52686 .37734 L F
.52621 .38043 m .52616 .38088 L .52601 .38057 L F
.52724 .38219 m .52724 .38217 L .52914 .38261 L F
.52658 .3818 m .5282 .38247 L .52781 .3822 L F
.52714 .38197 m .52728 .3821 L .52762 .38206 L F
.52753 .38205 m .52706 .38195 L .52883 .38253 L F
.52775 .38213 m .52669 .38192 L .52776 .38212 L F
.52805 .38219 m .5268 .3819 L .52775 .38209 L F
.5276 .38206 m .52776 .38217 L .52776 .38212 L F
.527 .38184 m .52714 .38197 L .5282 .382 L F
.52722 .38198 m .52672 .38185 L .52771 .38187 L F
.5268 .3819 m .52672 .38185 L .52722 .38198 L F
.52775 .38209 m .5268 .3819 L .52706 .38186 L F
.52699 .38203 m .52771 .38187 L .52773 .38199 L F
.52714 .38197 m .52762 .38206 L .5282 .382 L F
.52706 .38186 m .52745 .38203 L .5276 .38206 L F
.52775 .38209 m .52706 .38186 L .5276 .38206 L F
.52778 .3821 m .52775 .38209 L .52775 .38209 L F
.52774 .38204 m .52699 .38203 L .52773 .38199 L F
.52775 .38209 m .52706 .38186 L .52775 .38209 L F
.52953 .38205 m .52774 .38204 L .5291 .38191 L F
.52774 .38204 m .52773 .38199 L .5291 .38191 L F
.53022 .38228 m .52964 .38223 L p .52953 .38205 L F P
0 g
s
.52964 .38223 m .52699 .38203 L p .52953 .38205 L .67 .731 .896 r
F P
0 g
s
.52745 .38229 m .5282 .38253 L .52747 .38228 L .67 .731 .896 r
F
.52752 .38225 m .52822 .38252 L .52829 .38249 L F
.52822 .38252 m .52909 .38282 L .52829 .38249 L F
.52816 .38245 m .5282 .38247 L .52817 .38245 L F
.52629 .38198 m .52962 .38283 L .52962 .38283 L F
.5411 .38578 m .5309 .38316 L p .54117 .38579 L F P
0 g
s
.5309 .38316 m .52629 .38198 L p .5309 .38316 L .67 .731 .896 r
F P
0 g
s
.5309 .38316 m .5309 .38316 L .54117 .38579 L .67 .731 .896 r
F
.52619 .38223 m .52626 .38195 L .52619 .38222 L F
.52475 .38144 m .52475 .38144 L .51985 .37985 L F
.51863 .37946 m .52497 .38151 L .52497 .3815 L F
.52217 .38045 m .51863 .37946 L .52264 .38072 L F
.52217 .38045 m .52264 .38072 L .52364 .38103 L F
.52423 .38103 m .52217 .38045 L .52364 .38103 L F
.52442 .38098 m .5232 .38104 L .5212 .37991 L F
.52353 .38104 m .52595 .38182 L .52353 .38104 L F
.52424 .38104 m .52423 .38103 L .52424 .38104 L F
.52423 .38103 m .52364 .38103 L .5249 .38143 L F
.52463 .38147 m .5232 .38104 L p .52442 .38098 L F P
0 g
s
.52012 .37976 m .52533 .38164 L p .5212 .37991 L .67 .731 .896 r
F P
0 g
s
.52626 .38195 m .52643 .38127 L .52626 .38195 L .67 .731 .896 r
F
.52643 .38127 m .52643 .38127 L .52626 .38195 L F
.52667 .38203 m .52728 .3821 L p .52663 .38198 L F P
0 g
s
.52692 .38199 m .52682 .38203 L .5282 .38247 L .67 .731 .896 r
F
.52736 .38217 m .52752 .3822 L .52746 .3822 L F
.52622 .3819 m .52735 .38216 L .52736 .38217 L F
.52735 .38216 m .52752 .3822 L .52736 .38217 L F
.5267 .38133 m .52835 .37876 L .5267 .38133 L F
.52724 .38072 m .52832 .37931 L p .52702 .38061 L F P
0 g
s
.52758 .38028 m .52707 .38095 L p .5276 .37984 L .67 .731 .896 r
F P
0 g
s
.52832 .37931 m .53351 .37245 L p .52802 .37922 L .67 .731 .896 r
F P
0 g
s
.52855 .379 m .52758 .38028 L p .5288 .3782 L .67 .731 .896 r
F P
0 g
s
.5267 .38133 m .52835 .37876 L .52835 .37876 L .67 .731 .896 r
F
.52632 .38131 m .52832 .37931 L .52802 .37922 L F
.52758 .38028 m .5276 .37984 L .5288 .3782 L F
.52759 .38051 m .53442 .37278 L p .52709 .38071 L F P
0 g
s
.52643 .38127 m .52655 .38078 L .52643 .38127 L .67 .731 .896 r
F
.52643 .38127 m .52649 .38104 L .52642 .38127 L F
.52532 .38168 m .52621 .38189 L .52622 .3819 L F
.52533 .38169 m .52627 .38196 L .52628 .38196 L F
.52612 .38176 m .52611 .38176 L .52632 .38164 L F
.52595 .38179 m .52602 .38178 L .52615 .38181 L F
.52595 .38179 m .52615 .38181 L .52617 .38183 L F
.52613 .38179 m .52602 .38178 L .52611 .38177 L F
.52532 .38168 m .52528 .38163 L .52619 .38186 L F
.52745 .38229 m .52747 .38228 L .52679 .38204 L F
.52677 .38205 m .52679 .38204 L .52605 .38179 L F
.52745 .38229 m .52679 .38204 L .52677 .38205 L F
.52606 .3817 m .52607 .38171 L .52624 .38155 L F
.52618 .38174 m .52616 .38182 L .52611 .38177 L F
.5262 .38174 m .52616 .38182 L .52618 .38174 L F
.5262 .38174 m .52617 .38183 L .52616 .38182 L F
.52601 .38232 m .52602 .3818 L .52604 .38179 L F
.52595 .38354 m .526 .38232 L .52601 .38232 L F
.5259 .3826 m .52605 .38209 L .52607 .38212 L F
.526 .38232 m .52602 .3818 L .52601 .38232 L F
.52559 .38217 m .52547 .38284 L .52522 .3827 L F
.52571 .38226 m .52547 .38284 L .52559 .38217 L F
.52611 .38177 m .52535 .38251 L .52545 .38264 L F
.52567 .38276 m .52543 .38294 L .52593 .38219 L F
.52575 .38257 m .52566 .38259 L .52566 .38277 L F
.52566 .38259 m .52545 .38264 L .52566 .38277 L F
.52566 .38277 m .52545 .38264 L .52561 .38287 L F
.52548 .38284 m .52547 .38284 L .52588 .38185 L F
.52611 .38177 m .52545 .38264 L .52575 .38257 L F
.52652 .38184 m .52657 .38186 L .52652 .38184 L F
.52657 .38186 m .52679 .38194 L .52662 .38187 L F
.52679 .38194 m .52676 .38191 L .52627 .38171 L F
.5267 .38188 m .52686 .38191 L .52658 .3818 L F
.52618 .38178 m .52675 .38189 L .527 .38184 L F
.52657 .38186 m .52682 .38203 L .52692 .38199 L F
.52669 .38192 m .52639 .38182 L .5268 .3819 L F
.52621 .38188 m .52619 .38186 L .52695 .38205 L F
.52605 .38179 m .52748 .38227 L .52752 .38225 L F
.52621 .38189 m .52752 .3822 L .52622 .3819 L F
.52627 .38196 m .52622 .3819 L .52697 .38208 L F
.52617 .38183 m .52615 .38181 L .52733 .38204 L F
.52621 .38189 m .52695 .38205 L .52696 .38206 L F
.52621 .38188 m .52695 .38205 L .52621 .38189 L F
.52625 .38193 m .52625 .38193 L .52623 .38202 L F
.52611 .38177 m .52616 .38182 L .52619 .38172 L F
.52615 .38181 m .52602 .38178 L .52613 .38179 L F
.52627 .3818 m .52605 .3818 L .52611 .38177 L F
.52607 .38171 m .52619 .38172 L .52624 .38155 L F
.52602 .38178 m .52607 .38172 L .52611 .38177 L F
.52628 .38196 m .52636 .38168 L .52626 .38195 L F
.52752 .3822 m .52735 .38215 L .52805 .38219 L F
.52679 .38194 m .5282 .38247 L .52676 .38191 L F
.52625 .38199 m .52626 .38194 L .52624 .38199 L F
.52626 .38194 m .52633 .38164 L .52625 .38193 L F
.52626 .38194 m .52625 .38193 L .52624 .38199 L F
.5267 .38188 m .52816 .38245 L .52686 .38191 L F
.52735 .38215 m .52619 .38186 L .52733 .38205 L F
.52619 .38186 m .52581 .38177 L .52617 .38184 L F
.52619 .38186 m .52617 .38184 L .52733 .38205 L F
.52735 .38215 m .52733 .38205 L .52805 .38219 L F
.52626 .38194 m .52643 .38127 L .52642 .38127 L F
.52654 .38165 m .52724 .38072 L p .52632 .38131 L F P
0 g
s
.52677 .38135 m .52654 .38165 L p .5267 .38119 L .67 .731 .896 r
F P
0 g
s
.52663 .38141 m .52694 .38113 L .52643 .38148 L .67 .731 .896 r
F
.52707 .38095 m .52677 .38135 L .52703 .38063 L F
.52694 .38113 m .52759 .38051 L .52643 .38148 L F
.52677 .38135 m .5267 .38119 L .52703 .38063 L F
.52643 .38148 m .52759 .38051 L .52635 .38151 L F
.52759 .38051 m .52713 .38104 L p .52758 .38041 L F P
0 g
s
.52611 .38177 m .52619 .38172 L .52607 .38171 L .67 .731 .896 r
F
.52602 .38178 m .52578 .38174 L .52607 .38172 L F
.52626 .38195 m .52643 .38127 L .52626 .38194 L F
.52619 .38204 m .5264 .38128 L .52637 .38129 L F
.52622 .38202 m .52641 .38124 L .52619 .38204 L F
.52621 .38171 m .52625 .38169 L .52635 .3813 L F
.52633 .38164 m .52632 .38164 L .52633 .38165 L F
.52642 .38125 m .52632 .38164 L .52632 .38164 L F
.52641 .38128 m .5264 .38128 L .52622 .38202 L F
.52625 .38193 m .52622 .38202 L .52623 .38202 L F
.52654 .38075 m .52624 .38193 L .52625 .38193 L F
.52624 .38193 m .52622 .38202 L .52625 .38193 L F
.52614 .38171 m .52611 .38177 L .52636 .3817 L F
.52626 .38195 m .52636 .38168 L .52634 .38165 L F
.52614 .38171 m .52636 .3817 L .52654 .38165 L F
.52606 .38212 m .52635 .3813 L .52632 .38131 L F
.5262 .38187 m .52622 .3819 L .52649 .38074 L F
.52632 .38131 m .52614 .38171 L .52654 .38165 L F
.5265 .38169 m .52607 .38172 L .52649 .38168 L F
.52607 .38172 m .52592 .38173 L .52607 .38171 L F
.52607 .38172 m .52607 .38171 L .52649 .38168 L F
.52611 .38177 m .52607 .38172 L .5265 .38169 L F
.5265 .3817 m .5265 .38169 L .52656 .38169 L F
.52611 .38177 m .5265 .38169 L .5265 .3817 L F
.5261 .38176 m .52557 .38177 L .52576 .3817 L F
.52581 .38177 m .52528 .38163 L .52578 .38174 L F
.5255 .38171 m .52611 .38177 L .52548 .3817 L F
.52594 .37975 m .52612 .38001 L .52591 .3802 L F
.52686 .37734 m .52759 .37135 L p .52631 .37463 L F P
0 g
s
.52656 .37131 m .52612 .38001 L .52594 .37975 L .67 .731 .896 r
F
.52649 .38168 m .52592 .38173 L .52568 .38153 L F
.52532 .38168 m .52619 .38186 L .52621 .38188 L F
.5258 .38181 m .52562 .38182 L .5258 .3818 L F
.52583 .38206 m .52581 .38203 L .52584 .38186 L F
.52598 .38161 m .52571 .38226 L .52559 .38217 L F
.5258 .38181 m .5258 .3818 L .52611 .38177 L F
.5263 .3818 m .5265 .3817 L .52651 .38171 L F
.52632 .38164 m .52632 .38164 L .52632 .38164 L F
.52632 .38164 m .52632 .38164 L .52618 .38221 L F
.52632 .38164 m .52632 .38164 L .52632 .38164 L F
.5268 .3819 m .5266 .38186 L .52672 .38185 L F
.52776 .38212 m .52669 .38192 L .5268 .3819 L F
.52699 .38203 m .5268 .3819 L .52722 .38198 L F
.52736 .3822 m .52736 .38217 L .52746 .3822 L F
.52681 .38124 m .5271 .3809 L .5271 .3809 L F
.52659 .38185 m .52651 .38184 L .5267 .38179 L F
.52669 .38192 m .52615 .38181 L .52639 .38182 L F
.52601 .38183 m .52615 .38184 L .52616 .38182 L F
.52651 .38184 m .52601 .38183 L .52635 .38181 L F
.52651 .38184 m .52635 .38181 L .5267 .38179 L F
.52615 .38181 m .52613 .38179 L .5263 .3818 L F
.52639 .38182 m .5263 .3818 L .52706 .38186 L F
.52615 .38181 m .5263 .3818 L .52639 .38182 L F
.52584 .38181 m .52559 .38217 L .52611 .38177 L F
.52601 .38183 m .52562 .38182 L .52605 .3818 L F
.52611 .38177 m .52562 .38182 L .5261 .38176 L F
.52586 .38146 m .52578 .38192 L .52606 .3817 L F
.5261 .38176 m .52562 .38182 L .52557 .38177 L F
.52578 .38192 m .52607 .38171 L .52606 .3817 L F
.5268 .3819 m .52639 .38182 L .52706 .38186 L F
.52411 .38178 m .52343 .38177 L .52433 .38166 L F
.52483 .38187 m .52397 .38181 L p .52478 .38182 L F P
0 g
s
.52397 .38181 m .52343 .38177 L p .52395 .38178 L .67 .731 .896 r
F P
0 g
s
.52534 .38159 m .52262 .38144 L .52548 .3817 L .67 .731 .896 r
F
.52431 .38158 m .52585 .38193 L .52432 .38158 L F
.5247 .3818 m .52411 .38178 L .52517 .38158 L F
.52574 .38184 m .52572 .38182 L .52493 .38166 L F
.52163 .38144 m .52566 .38183 L .52558 .38177 L F
.52297 .38158 m .52433 .38173 L .52428 .38171 L F
.52343 .38177 m .52456 .38185 L p .52297 .38158 L F P
0 g
s
.52297 .38158 m .52456 .38185 L .52433 .38173 L .67 .731 .896 r
F
.52372 .3819 m .52086 .38181 L p .52476 .38156 L F P
0 g
s
.52326 .38165 m .52353 .3818 L .52397 .38182 L .67 .731 .896 r
F
.5263 .3818 m .52618 .38178 L .5265 .3817 L F
.52613 .38179 m .52611 .38177 L .52656 .38169 L F
.52629 .38198 m .5265 .3817 L p .52611 .38177 L F P
0 g
s
.52605 .3818 m .5258 .38181 L .52611 .38177 L .67 .731 .896 r
F
.52601 .38183 m .52616 .38182 L .52611 .38177 L F
.52577 .38149 m .52629 .38172 L .52633 .38171 L F
.52649 .38167 m .52591 .38152 L .52649 .38167 L F
.52578 .38192 m .52582 .38195 L .52607 .38171 L F
.52586 .38146 m .5259 .38186 L .52578 .38192 L F
.52566 .38183 m .52621 .38188 L .52558 .38177 L F
.52615 .38207 m .52622 .3819 L .5262 .38187 L F
.52696 .38206 m .52735 .38215 L .52735 .38216 L F
.52625 .38193 m .52608 .38259 L .52608 .38259 L F
.52651 .3809 m .52625 .38193 L .52625 .38193 L F
.52625 .38193 m .52608 .38259 L .52625 .38193 L F
.52621 .38189 m .52696 .38206 L .52696 .38206 L F
.52532 .38168 m .52621 .38189 L .52621 .38189 L F
.52621 .38189 m .52696 .38206 L .52621 .38189 L F
.52696 .38206 m .52735 .38215 L .52696 .38206 L F
.52699 .38203 m .52629 .38198 L p .5266 .38186 L F P
0 g
s
.52632 .38164 m .52618 .38221 L .52618 .38221 L .67 .731 .896 r
F
.52626 .38195 m .52626 .38195 L .52619 .38222 L F
.52619 .38222 m .52626 .38195 L .52626 .38194 L F
.52615 .38207 m .52619 .38204 L .52622 .3819 L F
.52611 .38177 m .52598 .38207 L .52629 .38198 L F
.52559 .38217 m .52574 .38213 L .52611 .38177 L F
.52598 .38225 m .52593 .38219 L .52596 .3821 L F
.52584 .38236 m .52573 .38294 L .52582 .38237 L F
.52578 .38192 m .52562 .38287 L .52606 .38213 L F
.52561 .3833 m .52556 .38361 L .52565 .38328 L F
.52539 .3834 m .52556 .38361 L .52561 .3833 L F
.52539 .3834 m .52299 .39228 L .52556 .38361 L F
.52573 .38262 m .5252 .38559 L .52569 .38271 L F
.52573 .38294 m .5256 .38369 L .52569 .38283 L F
.5256 .38369 m .52555 .38362 L .52569 .38283 L F
.52562 .38287 m .52537 .38435 L .52583 .38286 L F
.52562 .38287 m .52583 .38286 L .52606 .38213 L F
.52625 .38199 m .52624 .38199 L .52618 .38221 L F
.52598 .38207 m .52562 .38285 L .52629 .38198 L F
.52539 .38338 m .5243 .38509 L p .52567 .38276 L F P
0 g
s
.52561 .38287 m .52563 .38285 L p .52562 .38285 L .67 .731 .896 r
F P
0 g
s
.52563 .38285 m .52629 .38198 L p .52562 .38285 L .67 .731 .896 r
F P
0 g
s
.52592 .3822 m .52596 .38213 L .52597 .38213 L .67 .731 .896 r
F
.52587 .38232 m .52579 .38248 L .52577 .38197 L F
.52569 .38252 m .52593 .38217 L .52592 .3822 L F
.52593 .38217 m .52596 .38213 L .52592 .3822 L F
.52589 .38208 m .52587 .38232 L .52577 .38197 L F
.52609 .38224 m .52563 .38285 L p .526 .38208 L F P
0 g
s
.52563 .38285 m .52478 .38397 L p .52592 .3822 L .67 .731 .896 r
F P
0 g
s
.52478 .38397 m .52366 .38544 L p .52487 .3837 L .67 .731 .896 r
F P
0 g
s
.52548 .38284 m .52543 .38294 L .52547 .38284 L .67 .731 .896 r
F
.52478 .38397 m .52487 .3837 L .52592 .3822 L F
.52563 .38285 m .52592 .3822 L .526 .38208 L F
.52581 .38295 m .52577 .38293 L .52577 .38253 L F
.52579 .38248 m .52577 .38253 L .52577 .38197 L F
.52581 .38295 m .52577 .38253 L .52579 .38248 L F
.52587 .38232 m .52581 .38295 L .52579 .38248 L F
.52578 .38149 m .52634 .3817 L .52635 .3817 L F
.52632 .38131 m .52635 .3813 L .52649 .38074 L F
.52597 .38213 m .526 .38208 L .526 .38208 L F
.52577 .38197 m .52577 .38341 L .52559 .38307 L F
.52569 .38252 m .52562 .38255 L .52598 .38206 L F
.52582 .38195 m .52606 .38213 L .52615 .38184 L F
.52582 .38195 m .52615 .38184 L .52601 .38183 L F
.52582 .38195 m .52601 .38183 L .52672 .38185 L F
.52591 .38186 m .52621 .38189 L .52621 .38189 L F
.52595 .38214 m .52598 .38206 L .52616 .38182 L F
.52595 .38213 m .52587 .38232 L .5259 .38186 L F
.52569 .38252 m .52598 .38206 L .52595 .38214 L F
.52603 .38222 m .52595 .38214 L .52595 .38213 L F
.526 .38202 m .52595 .38213 L .52596 .38183 L F
.52603 .38222 m .52595 .38213 L .526 .38202 L F
.52582 .38195 m .52611 .38177 L .52607 .38171 L F
.52649 .38167 m .52568 .38153 L .52578 .38149 L F
.52601 .38183 m .52605 .3818 L .52747 .38175 L F
.52697 .38184 m .52697 .38184 L .527 .38184 L F
.52706 .38186 m .52655 .38182 L .52656 .38169 L F
.52655 .38182 m .5263 .3818 L .52651 .38171 L F
.52655 .38182 m .52651 .38171 L .52656 .38169 L F
.52649 .38167 m .52629 .38198 L .52641 .38169 L F
.52654 .38165 m .5265 .3817 L p .52649 .38167 L F P
0 g
s
.5265 .3817 m .52629 .38198 L p .52649 .38167 L .67 .731 .896 r
F P
0 g
s
.52656 .38169 m .52649 .38168 L .52649 .38167 L .67 .731 .896 r
F
.52649 .38168 m .52568 .38153 L .52649 .38167 L F
.52625 .38173 m .52627 .38172 L .52577 .38149 L F
.52586 .38146 m .52587 .38147 L .52643 .38168 L F
.52591 .38152 m .52593 .38154 L .52635 .3817 L F
.52607 .38178 m .52603 .3818 L .52602 .38081 L F
.52603 .38082 m .52602 .38081 L .52601 .38057 L F
.52607 .38178 m .52602 .38081 L .52603 .38082 L F
.52629 .38198 m .52582 .38195 L p .52654 .38187 L F P
0 g
s
.52621 .38188 m .52618 .38185 L .52558 .38177 L .67 .731 .896 r
F
.52591 .38186 m .52591 .38186 L .52621 .38189 L F
.52659 .38191 m .52733 .38204 L .52733 .38205 L F
.52581 .38177 m .52659 .38191 L .52659 .38191 L F
.52659 .38191 m .52733 .38204 L .52659 .38191 L F
.52636 .3812 m .52618 .38099 L .52625 .38025 L F
.52638 .38116 m .52632 .38125 L .52638 .38115 L F
.52621 .38189 m .52621 .38188 L .52566 .38183 L F
.52603 .3818 m .52596 .38183 L .52597 .38159 L F
.52603 .38166 m .52597 .38159 L .52601 .38057 L F
.52603 .3818 m .52597 .38159 L .52603 .38166 L F
.52533 .38154 m .52531 .38156 L .52629 .3817 L F
.52502 .38141 m .52555 .38163 L .52573 .38169 L F
.52504 .38152 m .52501 .38153 L .52629 .3817 L F
.52548 .38164 m .52548 .38164 L .5262 .38174 L F
.52598 .38161 m .52576 .3817 L .52536 .38155 L F
.52578 .38174 m .5253 .38161 L .52576 .3817 L F
.52576 .3817 m .52557 .38177 L .52544 .38163 L F
.52576 .3817 m .52544 .38163 L .52536 .38155 L F
.52523 .38159 m .52595 .38182 L .52523 .38159 L F
.52578 .38174 m .52528 .38163 L .5253 .38161 L F
.52576 .3817 m .5253 .38161 L .52549 .38133 L F
.52572 .38151 m .5256 .38155 L .52608 .38172 L F
.52601 .38164 m .52616 .38175 L .52622 .38174 L F
.52636 .3812 m .52611 .38176 L .52618 .38099 L F
.52632 .38125 m .52592 .38181 L .52632 .38125 L F
.52578 .38192 m .52589 .38208 L .52577 .38197 L F
.52592 .38181 m .52558 .38229 L .52592 .38181 L F
.52558 .38229 m .52318 .38569 L .52558 .38229 L F
.52558 .38229 m .52558 .38229 L .52592 .38181 L F
.52318 .38569 m .52318 .38569 L .52558 .38229 L F
.52558 .38229 m .52558 .38229 L .52592 .38181 L F
.52318 .38569 m .52558 .38229 L .52558 .38229 L F
.5247 .3818 m .52517 .38158 L .52523 .38159 L F
.52401 .38157 m .5255 .38171 L .52548 .3817 L F
.52505 .38177 m .52413 .38168 L .52505 .38177 L F
.52632 .38125 m .52632 .38125 L .52638 .38115 L F
.52632 .38125 m .52632 .38125 L .52638 .38116 L F
.52601 .38164 m .52608 .38172 L .52616 .38175 L F
.52649 .38167 m .52586 .38146 L .52643 .38168 L F
.52611 .38176 m .52608 .38172 L .52614 .38115 L F
.52617 .38115 m .52614 .38115 L .52645 .37802 L F
.52611 .38176 m .52614 .38115 L .52617 .38115 L F
.52659 .38185 m .5267 .38179 L .52747 .38175 L F
.52718 .38198 m .5264 .38169 L .52714 .38199 L F
.5264 .38169 m .52581 .38148 L .52638 .3817 L F
.5264 .38169 m .52638 .3817 L .52714 .38199 L F
.52596 .3818 m .52632 .38125 L .52632 .38126 L F
.5259 .38186 m .52589 .38208 L .52578 .38192 L F
.52464 .38187 m .52372 .3819 L .52405 .38184 L F
.52612 .38165 m .52602 .38171 L .52636 .3812 L F
.52616 .38096 m .52608 .38172 L .52603 .38082 L F
.52608 .38172 m .52605 .38169 L .52612 .38165 L F
.52595 .38214 m .52616 .38182 L .52593 .38217 L F
.52622 .38189 m .52699 .38203 L .52717 .38198 L F
.52617 .38183 m .52623 .38173 L .52617 .38183 L F
.52586 .38146 m .52556 .38143 L .52568 .3814 L F
.52569 .38141 m .5257 .38144 L .52666 .38179 L F
.52643 .38165 m .52781 .38191 L .52781 .38189 L F
.52769 .38187 m .52659 .38185 L .52747 .38175 L F
.52667 .38178 m .52666 .38179 L .52718 .38198 L F
.52625 .38194 m .52617 .38184 L .52625 .38173 L F
.52634 .38171 m .52625 .38173 L .52642 .38149 L F
.52625 .38194 m .52625 .38173 L .52634 .38171 L F
.52641 .38169 m .52666 .38179 L .52667 .38178 L F
.52569 .38141 m .5264 .38169 L .52641 .38169 L F
.5264 .38169 m .52666 .38179 L .52641 .38169 L F
.52627 .38172 m .52629 .38172 L .52577 .38149 L F
.52623 .38173 m .52641 .38147 L .52624 .38173 L F
.52623 .38173 m .52624 .38173 L .52617 .38183 L F
.52637 .3812 m .52636 .3812 L .5264 .38113 L F
.52617 .38184 m .52624 .38173 L .52625 .38173 L F
.52617 .38183 m .52624 .38173 L .52617 .38184 L F
.52608 .38178 m .52638 .38182 L .52633 .38181 L F
.52606 .38179 m .52643 .38183 L .52608 .38178 L F
.52653 .38185 m .52662 .38186 L .52629 .38172 L F
.52643 .38183 m .52673 .38186 L .52638 .38182 L F
.52643 .38183 m .52638 .38182 L .52608 .38178 L F
.52622 .38174 m .52616 .38175 L .52627 .3818 L F
.52616 .38182 m .52682 .3819 L .52655 .38185 L F
.52558 .38177 m .52617 .38183 L .52616 .38182 L F
.52617 .38183 m .52682 .3819 L .52616 .38182 L F
.52626 .38195 m .52642 .38149 L .52646 .3816 L F
.52671 .382 m .52671 .382 L .52536 .38184 L F
.52483 .38187 m .52478 .38182 L .52601 .38183 L F
.52635 .38036 m .52625 .38025 L .5263 .37962 L F
.52639 .38113 m .52636 .3812 L .52625 .38025 L F
.52639 .38113 m .52625 .38025 L .52635 .38036 L F
.52641 .37966 m .5263 .37962 L .52642 .37832 L F
.52639 .38113 m .5263 .37962 L .52641 .37966 L F
.52639 .38113 m .52642 .37832 L .52644 .37832 L F
.52616 .38088 m .52616 .38096 L .52603 .38081 L F
.52616 .38096 m .52603 .38082 L .52603 .38081 L F
.52616 .38088 m .52603 .38081 L .52601 .38057 L F
.52686 .37734 m .52639 .38113 L p .52645 .37802 L F P
0 g
s
.52645 .37802 m .52621 .38043 L .52601 .38057 L .67 .731 .896 r
F
.52639 .38113 m .52686 .37734 L p .52585 .38092 L F P
0 g
s
.52634 .37982 m .52632 .3809 L p .52591 .3802 L .67 .731 .896 r
F P
0 g
s
.52483 .38187 m .52629 .38198 L p .52493 .38181 L .67 .731 .896 r
F P
0 g
s
.52533 .38185 m .52629 .38198 L .52627 .38195 L .67 .731 .896 r
F
.52433 .38173 m .5253 .38186 L .52533 .38185 L F
.5253 .38186 m .52629 .38198 L .52533 .38185 L F
.52617 .38183 m .52624 .38173 L .52617 .38183 L F
.52446 .38172 m .52626 .38195 L .52622 .38189 L F
.52617 .38183 m .52617 .38183 L .526 .38208 L F
.52623 .38201 m .52625 .38194 L .52626 .38195 L F
.52625 .38194 m .52642 .38149 L .52626 .38195 L F
.52622 .38174 m .52627 .3818 L .52642 .38183 L F
.52637 .38129 m .52641 .38124 L .52639 .3812 L F
.5266 .38121 m .52622 .38174 L .52638 .38119 L F
.52622 .38174 m .52616 .38182 L .52618 .38175 L F
.52622 .38174 m .52618 .38175 L .52638 .38119 L F
.52596 .38183 m .5259 .38186 L .52593 .38154 L F
.52597 .38159 m .52593 .38154 L .52601 .38057 L F
.52596 .38183 m .52593 .38154 L .52597 .38159 L F
.52577 .38149 m .52594 .38155 L .52578 .38149 L F
.52594 .38155 m .52633 .38171 L .52593 .38155 L F
.52591 .38144 m .52591 .38151 L .52586 .38146 L F
.52591 .38151 m .5259 .38186 L .52586 .38146 L F
.52594 .38155 m .52593 .38155 L .52578 .38149 L F
.52633 .38171 m .5271 .382 L .52634 .3817 L F
.52633 .38171 m .52634 .3817 L .52578 .38149 L F
.52699 .38203 m .52775 .38209 L p .52717 .38198 L F P
0 g
s
.5271 .382 m .52729 .38208 L .5271 .382 L .67 .731 .896 r
F
.5271 .382 m .5271 .382 L .52578 .38149 L F
.52627 .38278 m .5262 .38572 L p .52604 .3827 L F P
0 g
s
.52537 .38435 m .52615 .38207 L .52606 .38212 L .67 .731 .896 r
F
.52581 .38295 m .52577 .38341 L .52577 .38293 L F
.52573 .38263 m .52566 .38351 L .52593 .38265 L F
.52595 .38354 m .52596 .38255 L .52599 .38255 L F
.52565 .38395 m .52606 .38262 L .52599 .38269 L F
.52593 .38309 m .52596 .38525 L .52571 .38285 L F
.5262 .38572 m .52594 .384 L .52612 .38431 L F
.52581 .38354 m .52601 .39197 L .52623 .38361 L F
.52027 .38256 m .51045 .3835 L .52077 .38236 L F
.51548 .38302 m .52362 .38224 L p .51516 .38295 L F P
0 g
s
.52562 .38232 m .52595 .38181 L .52596 .3818 L .67 .731 .896 r
F
.52519 .38297 m .52562 .38232 L .52562 .38232 L F
.52562 .38232 m .52595 .38181 L .52562 .38232 L F
.52276 .38187 m .52517 .38194 L p .52259 .3818 L F P
0 g
s
.52547 .38284 m .52543 .38294 L .52522 .3827 L .67 .731 .896 r
F
.52535 .38251 m .52466 .3835 L .52544 .38299 L F
.52515 .3829 m .52514 .3829 L .52557 .38229 L F
.52403 .38158 m .52513 .38168 L .52401 .38157 L F
.52646 .38171 m .52745 .38016 L .52646 .38171 L F
.52745 .38016 m .52835 .37876 L .52745 .38016 L F
.52745 .38016 m .52745 .38016 L .52646 .38171 L F
.52753 .3825 m .53981 .38761 L p .52743 .38239 L F P
0 g
s
.52629 .38198 m .52699 .38203 L p .52627 .38195 L .67 .731 .896 r
F P
0 g
s
.52633 .38158 m .52641 .38147 L .52633 .3816 L .67 .731 .896 r
F
.52549 .38133 m .52718 .38198 L .52721 .38197 L F
.52633 .38158 m .52633 .3816 L .52625 .38173 L F
.52624 .38173 m .52633 .38158 L .52625 .38173 L F
.52591 .38152 m .52635 .3817 L .52638 .3817 L F
.52616 .38182 m .52617 .38156 L .52626 .38152 L F
.52621 .38154 m .52633 .38166 L .52611 .38176 L F
.52513 .38168 m .52649 .38181 L .52513 .38167 L F
.52611 .38249 m .52611 .38249 L .52608 .38259 L F
.52579 .38376 m .52622 .38202 L .52619 .38204 L F
.52611 .38257 m .52613 .3825 L .52612 .3825 L F
.52623 .38202 m .52622 .38202 L .52579 .38376 L F
.52611 .38257 m .52619 .38222 L .52608 .38259 L F
.52611 .38257 m .52608 .38259 L .52579 .38376 L F
.52608 .38259 m .52608 .38259 L .52579 .38376 L F
.52621 .38267 m .52594 .38318 L .52605 .38203 L F
.52617 .38251 m .52636 .38168 L p .52611 .38257 L F P
0 g
s
.52621 .38267 m .52625 .38228 L p .52593 .38265 L .67 .731 .896 r
F P
0 g
s
.52632 .38164 m .52611 .38249 L .52611 .38249 L .67 .731 .896 r
F
.52629 .38198 m .52609 .38224 L p .52626 .38195 L F P
0 g
s
.52612 .3825 m .52628 .38196 L .52626 .38195 L .67 .731 .896 r
F
.52613 .3825 m .52636 .38168 L .52612 .3825 L F
.52623 .38202 m .52623 .38202 L .52618 .38221 L F
.52619 .38222 m .52625 .38199 L .52618 .38221 L F
.52618 .38221 m .52618 .38221 L .52611 .38249 L F
.52611 .38257 m .52619 .38223 L .52619 .38222 L F
.52609 .38224 m .52602 .3821 L .52623 .38201 L F
.52602 .3821 m .526 .38208 L .52623 .38201 L F
.52619 .38222 m .52618 .38221 L .52608 .38259 L F
.52599 .38269 m .52619 .38204 L .52615 .38207 L F
.52629 .38198 m .52621 .38267 L p .52605 .38203 L F P
0 g
s
.52625 .38228 m .52633 .38166 L p .52612 .38218 L .67 .731 .896 r
F P
0 g
s
.52593 .38265 m .52625 .38228 L .52612 .38218 L .67 .731 .896 r
F
.52499 .38169 m .52574 .38184 L .52493 .38166 L F
.52562 .38182 m .5247 .3818 L .52534 .38155 L F
.52446 .38172 m .5259 .38186 L .52448 .38172 L F
.52478 .38186 m .52464 .38187 L .52534 .38159 L F
.52511 .38169 m .52515 .3817 L .52515 .3817 L F
.52403 .38158 m .52417 .38165 L .52616 .38182 L F
.52479 .38162 m .52491 .38173 L .52551 .38177 L F
.526 .38208 m .52617 .38183 L .526 .38208 L F
.52596 .38213 m .52617 .38183 L .52597 .38213 L F
.52494 .3818 m .52671 .382 L .52496 .38179 L F
.52617 .38183 m .52617 .38183 L .52597 .38213 L F
.52623 .38201 m .526 .38208 L .52617 .38184 L F
.52603 .38222 m .52601 .38211 L .52603 .38212 L F
.52601 .38211 m .526 .38202 L .52603 .38212 L F
.52603 .38212 m .526 .38202 L .52603 .38195 L F
.52593 .38217 m .52616 .38182 L .52617 .38183 L F
.526 .38208 m .52617 .38183 L .52617 .38184 L F
.52623 .38201 m .52617 .38184 L .52625 .38194 L F
.52611 .38177 m .52611 .38176 L .52611 .38176 L F
.52663 .38193 m .52505 .38177 L .52663 .38193 L F
.52611 .38176 m .52629 .38198 L .52607 .38187 L F
.52629 .38198 m .52605 .38203 L .52607 .38187 L F
.52597 .38209 m .52608 .38216 L .52622 .38169 L F
.52598 .38234 m .52629 .38198 L p .52597 .38208 L F P
0 g
s
.52621 .38189 m .52566 .38183 L .52621 .38189 L .67 .731 .896 r
F
.52603 .38195 m .52596 .38183 L .52603 .3818 L F
.526 .38202 m .52596 .38183 L .52603 .38195 L F
.52515 .3817 m .52616 .38182 L .52614 .3818 L F
.52611 .38176 m .52607 .38187 L .52607 .38178 L F
.52611 .38176 m .52607 .38178 L .52608 .38172 L F
.52592 .38173 m .52576 .3817 L .52556 .38143 L F
.5256 .38155 m .52587 .38172 L .52608 .38172 L F
.5259 .38186 m .52719 .38198 L .52591 .38186 L F
.52719 .38198 m .52725 .38199 L .52719 .38198 L F
.52719 .38198 m .52719 .38198 L .52591 .38186 L F
.52572 .38151 m .52673 .38197 L .5267 .38192 L F
.52649 .38181 m .52649 .3818 L .52615 .38177 L F
.52649 .38181 m .52615 .38177 L .52616 .38177 L F
.52617 .38183 m .52616 .38182 L .52641 .38147 L F
.52626 .38195 m .52699 .38203 L .52622 .38189 L F
.52652 .38192 m .52621 .38189 L .52652 .38192 L F
.52671 .382 m .52699 .38203 L .52671 .382 L F
.52719 .38198 m .52621 .38188 L .52621 .38189 L F
.52629 .38198 m .52654 .38187 L .5266 .38186 L F
.52699 .38203 m .52678 .38194 L .52687 .38195 L F
.52678 .38194 m .5266 .38186 L .52687 .38195 L F
.52687 .38195 m .5266 .38186 L .5268 .3819 L F
.52629 .38198 m .52626 .38195 L .52641 .38169 L F
.52621 .38188 m .52718 .38198 L .52618 .38185 L F
.52621 .38189 m .52621 .38189 L .52719 .38198 L F
.5282 .38253 m .52822 .38252 L .52605 .38179 L F
.52719 .38198 m .52621 .38189 L .52621 .38189 L F
.52627 .3818 m .52669 .38212 L .52695 .38205 L F
.52608 .38172 m .52615 .38177 L .52627 .3818 L F
.52614 .3818 m .52616 .38182 L .52655 .38185 L F
.52615 .38177 m .52669 .38212 L .52627 .3818 L F
.52651 .38184 m .52655 .38185 L .52671 .38187 L F
.52614 .3818 m .52655 .38185 L .52651 .38184 L F
.52633 .38166 m .52629 .38198 L .52611 .38176 L F
.52653 .38185 m .52629 .38172 L .52627 .38172 L F
.52621 .38189 m .52621 .38189 L .52652 .38192 L F
.52713 .38199 m .52712 .382 L .52788 .38229 L F
.52638 .3817 m .52788 .38229 L .5279 .38228 L F
.52838 .38258 m .52751 .38232 L .52789 .3824 L F
.52818 .38245 m .5282 .38247 L .5287 .38262 L F
.52629 .38198 m .52629 .38198 L .53276 .38364 L F
.53276 .38364 m .53276 .38364 L .54117 .38579 L F
.52629 .38198 m .53276 .38364 L .53276 .38364 L F
.52616 .38182 m .52599 .38205 L .52611 .38176 L F
.52608 .38172 m .52607 .38178 L .52607 .38171 L F
.52587 .38172 m .52611 .38176 L .52608 .38172 L F
.52606 .38175 m .52606 .38175 L .52605 .38175 L F
.52652 .38192 m .52566 .38183 L .52566 .38183 L F
.52621 .38189 m .52544 .38181 L .52621 .38189 L F
.52595 .38213 m .5259 .38186 L .52596 .38183 L F
.52611 .38176 m .52562 .38255 L .52608 .38172 L F
.52616 .38177 m .52615 .38177 L .52513 .38167 L F
.52571 .38172 m .52571 .38172 L .52548 .3817 L F
.52611 .38177 m .52571 .38172 L .52571 .38172 L F
.52633 .38171 m .52671 .38188 L .52688 .38192 L F
.52653 .38184 m .52671 .38187 L .52673 .38186 L F
.52403 .38158 m .52654 .38185 L .52653 .38184 L F
.52629 .38172 m .52662 .38186 L .52633 .38171 L F
.52719 .38198 m .52663 .38193 L .52663 .38193 L F
.52662 .38186 m .52745 .38224 L .52671 .38188 L F
.52662 .38186 m .52671 .38188 L .52633 .38171 L F
.52616 .38182 m .52608 .38172 L .52617 .38156 L F
.52615 .38177 m .52611 .38177 L .52611 .38177 L F
.52736 .38189 m .52612 .38177 L .52615 .38177 L F
.52612 .38177 m .52611 .38177 L .52615 .38177 L F
.52654 .38185 m .52671 .38187 L .52653 .38184 L F
.52626 .38152 m .52617 .38156 L .5264 .38113 L F
.52638 .38115 m .52633 .38162 L .52621 .38154 L F
.52625 .38159 m .52638 .38126 L .52636 .38124 L F
.52445 .38173 m .52626 .38195 L .52446 .38172 L F
.52403 .38158 m .52633 .38181 L .52617 .38178 L F
.5256 .38155 m .52538 .38162 L .52587 .38172 L F
.52572 .38151 m .52608 .38172 L .52601 .38164 L F
.526 .38162 m .52534 .38159 L .5261 .38175 L F
.526 .38162 m .52569 .38168 L .52534 .38159 L F
.52589 .38187 m .52589 .38186 L .52592 .38181 L F
.52611 .38176 m .52611 .38176 L .52571 .38172 L F
.52587 .38172 m .52629 .38198 L .52611 .38176 L F
.52593 .38181 m .52592 .38181 L .52603 .38166 L F
.52589 .38187 m .52592 .38181 L .52593 .38181 L F
.52611 .38177 m .52611 .38177 L .52401 .38157 L F
.52533 .38164 m .52586 .38183 L p .52587 .38172 L F P
0 g
s
.52598 .38206 m .52562 .38255 L .52611 .38176 L .67 .731 .896 r
F
.52599 .38205 m .52599 .38205 L .52611 .38176 L F
.52607 .38178 m .52603 .38222 L .52603 .3818 L F
.52586 .38183 m .52629 .38198 L p .52599 .38179 L F P
0 g
s
.52611 .38176 m .52605 .38175 L .52548 .3817 L .67 .731 .896 r
F
.52548 .3817 m .52611 .38176 L .5261 .38175 L F
.52596 .38115 m .52593 .38154 L .52591 .38118 L F
.52593 .38154 m .5259 .38186 L .52591 .38151 L F
.52593 .38154 m .52591 .38151 L .52591 .38118 L F
.52568 .3814 m .52569 .38141 L .52588 .38148 L F
.52587 .38147 m .52588 .38148 L .52643 .38168 L F
.52568 .3814 m .52588 .38148 L .52587 .38147 L F
.52587 .38172 m .52586 .38183 L .52599 .38179 L F
.52562 .38182 m .52534 .38155 L .52536 .38155 L F
.52534 .38159 m .52548 .3817 L .52613 .38175 L F
.52564 .38168 m .52581 .38174 L .52559 .38167 L F
.52538 .38162 m .52533 .38164 L .52587 .38172 L F
.52564 .38168 m .52559 .38167 L .52547 .38164 L F
.52557 .38166 m .52564 .38168 L .52547 .38164 L F
.52536 .38184 m .52536 .38184 L .52428 .38171 L F
.52516 .38157 m .52516 .38155 L .52639 .38196 L F
.52403 .38158 m .52606 .38179 L .52608 .38178 L F
.52544 .38181 m .52544 .38181 L .52413 .38168 L F
.52408 .38465 m .52373 .38492 L .52513 .38293 L F
.52535 .38251 m .52544 .38299 L .52561 .38287 L F
.52518 .38296 m .52513 .38293 L .52589 .38186 L F
.52408 .38465 m .52513 .38293 L .52518 .38296 L F
.52518 .38296 m .52589 .38186 L .52589 .38187 L F
.52408 .38465 m .52518 .38296 L .52518 .38296 L F
.52518 .38296 m .52589 .38186 L .52518 .38296 L F
.52706 .38186 m .5273 .382 L .52745 .38203 L F
.52719 .38198 m .53022 .38228 L .52727 .38195 L F
.52718 .38198 m .5272 .38198 L .52719 .38198 L F
.5272 .38198 m .53022 .38228 L .52719 .38198 L F
.52706 .38186 m .52715 .38195 L .5273 .382 L F
.52733 .38205 m .52733 .38204 L .52805 .38219 L F
.52745 .38203 m .5273 .382 L .52776 .38217 L F
.52713 .38187 m .52736 .38189 L .52713 .38186 L F
.52736 .38189 m .53088 .38222 L .52736 .38188 L F
.52719 .38198 m .52718 .38198 L .52621 .38188 L F
.52601 .38057 m .52596 .38115 L .52591 .38118 L F
.52632 .3809 m .52596 .38114 L .52591 .3802 L F
.52577 .38039 m .52577 .38055 L .52631 .38089 L F
.52581 .38174 m .52597 .38179 L .52582 .38176 L F
.52629 .38198 m .52669 .38212 L p .52608 .38172 L F P
0 g
s
.52597 .38179 m .52619 .38186 L .52594 .38179 L .67 .731 .896 r
F
.52619 .38186 m .52664 .382 L .5262 .38187 L F
.52619 .38186 m .5262 .38187 L .52594 .38179 L F
.52608 .38216 m .52619 .38185 L .52608 .38216 L F
.52611 .38177 m .52712 .38186 L .52611 .38176 L F
.52712 .38186 m .52736 .38188 L .52712 .38186 L F
.52712 .38186 m .52712 .38186 L .52611 .38176 L F
.52638 .38115 m .52632 .38125 L .52631 .38124 L F
.52585 .38092 m .52583 .38122 L .52635 .38122 L F
.52585 .38092 m .52586 .3812 L .52583 .38122 L F
.52596 .38114 m .52592 .38116 L .52591 .3802 L F
.52591 .38075 m .52592 .38116 L .52585 .38092 L F
.52592 .38116 m .52586 .3812 L .52585 .38092 L F
.52585 .38092 m .52635 .38122 L .52624 .38107 L F
.52577 .38055 m .52578 .38117 L .52626 .38115 L F
.5282 .38253 m .52909 .38282 L .52822 .38252 L F
.52815 .38251 m .52815 .38251 L .52866 .38266 L F
.52628 .38196 m .52815 .38251 L .52815 .38251 L F
.52748 .38227 m .52822 .38252 L .52752 .38225 L F
.52846 .38264 m .52629 .38198 L p .52866 .38266 L F P
0 g
s
.52629 .38198 m .52628 .38196 L .52866 .38266 L .67 .731 .896 r
F
.5271 .3822 m .52705 .38219 L .52736 .38217 L F
.52705 .38219 m .52697 .38208 L .52736 .38217 L F
.5271 .3822 m .52736 .38217 L .52736 .3822 L F
.52751 .38232 m .5271 .3822 L .52762 .38224 L F
.5411 .38578 m .5412 .3858 L p .54104 .38576 L F P
0 g
s
.54117 .38579 m .52819 .38247 L .52914 .38261 L .67 .731 .896 r
F
.52781 .3822 m .52818 .38245 L .54079 .38642 L F
.52816 .38245 m .52817 .38245 L .52686 .38191 L F
.52751 .38232 m .52762 .38224 L .52979 .38276 L F
.52906 .38283 m .53053 .38328 L p .52909 .38282 L F P
0 g
s
.53053 .38328 m .54079 .38642 L p .53088 .38331 L .67 .731 .896 r
F P
0 g
s
.53447 .38449 m .52846 .38264 L p .53609 .38486 L .67 .731 .896 r
F P
0 g
s
.52818 .38245 m .5287 .38262 L .54079 .38642 L .67 .731 .896 r
F
.52909 .38282 m .52912 .38283 L .52911 .38281 L F
.52912 .38283 m .53053 .38328 L .52902 .38272 L F
.52846 .38264 m .52866 .38266 L .53609 .38486 L F
.52669 .38212 m .54033 .38703 L p .52695 .38205 L F P
0 g
s
.52744 .38226 m .52745 .38226 L .52665 .38201 L .67 .731 .896 r
F
.52744 .38226 m .52665 .38201 L .52665 .38201 L F
.52664 .382 m .52704 .38213 L .52665 .38201 L F
.52562 .38255 m .52408 .38465 L .5254 .38265 L F
.52553 .38244 m .52603 .38166 L .52604 .38167 L F
.52408 .38465 m .52553 .38243 L .52553 .38244 L F
.52553 .38243 m .52603 .38166 L .52553 .38244 L F
.52719 .38198 m .52652 .38192 L .52652 .38192 L F
.52689 .38191 m .52689 .38192 L .52695 .38193 L F
.52718 .38198 m .52727 .38195 L .52717 .38194 L F
.52718 .38198 m .52717 .38194 L .52558 .38177 L F
.52718 .38198 m .52717 .38194 L .52718 .38198 L F
.52631 .38124 m .52591 .38182 L .52582 .38184 L F
.52572 .38151 m .52625 .38173 L .52577 .38149 L F
.5263 .38166 m .526 .38162 L .52613 .38175 L F
.52633 .38166 m .5263 .38166 L .52613 .38175 L F
.52637 .38164 m .5263 .38164 L .52633 .38166 L F
.5263 .38164 m .526 .38162 L .52633 .38166 L F
.52604 .38168 m .52619 .38159 L .5262 .38156 L F
.52603 .38166 m .52558 .38229 L .52602 .38165 L F
.52589 .38186 m .52603 .38166 L .52603 .38166 L F
.52588 .3818 m .52605 .38169 L .52604 .38168 L F
.52603 .38166 m .52602 .38165 L .52631 .38124 L F
.52591 .38118 m .52591 .38144 L .52586 .38146 L F
.52583 .38122 m .52582 .3814 L .52621 .38155 L F
.52562 .38255 m .52596 .3818 L .52604 .38178 L F
.52586 .38183 m .52585 .3818 L .52623 .38191 L F
.52595 .38181 m .52632 .38125 L .52596 .3818 L F
.52592 .38181 m .52592 .38181 L .52632 .38125 L F
.52592 .38181 m .52592 .38181 L .52632 .38125 L F
.526 .38162 m .52585 .3818 L .52615 .38157 L F
.52586 .38183 m .52527 .38162 L p .52584 .38179 L F P
0 g
s
.52585 .3818 m .52582 .38184 L .52587 .3818 L .67 .731 .896 r
F
.52585 .3818 m .52587 .3818 L .52615 .38157 L F
.52605 .38169 m .52631 .38152 L .52604 .38168 L F
.52637 .38164 m .52607 .38171 L .526 .38162 L F
.52625 .38173 m .52653 .38185 L .52627 .38172 L F
.52656 .38169 m .5265 .38169 L .52649 .38168 L F
.52651 .38171 m .5265 .3817 L .52656 .38169 L F
.52649 .38167 m .52643 .38168 L .52715 .38195 L F
.52656 .38179 m .52685 .3819 L .52657 .38179 L F
.52656 .38179 m .52657 .38179 L .52635 .3817 L F
.52634 .3817 m .52656 .38179 L .52635 .3817 L F
.52637 .38164 m .52613 .38175 L .52711 .38184 L F
.5265 .38173 m .52614 .38177 L .52637 .38164 L F
.52562 .38255 m .5254 .38265 L .52596 .3818 L F
.52567 .38217 m .52575 .38215 L .52611 .38176 L F
.52608 .38172 m .52607 .38171 L .52601 .38057 L F
.526 .38162 m .5261 .38175 L .52613 .38175 L F
.52611 .38176 m .52607 .38171 L .52627 .38166 L F
.52612 .38176 m .52625 .38159 L .52621 .38156 L F
.52705 .38112 m .52759 .38051 L p .52701 .38105 L F P
0 g
s
.52684 .3813 m .52683 .3813 L .52758 .38041 L .67 .731 .896 r
F
.52682 .38124 m .52705 .38112 L .52701 .38105 L F
.52654 .38165 m .52641 .38169 L .5267 .38119 L F
.52618 .38184 m .52687 .38127 L .52682 .38124 L F
.52687 .38127 m .52705 .38112 L .52682 .38124 L F
.52618 .38172 m .52625 .38159 L .52612 .38176 L F
.5261 .38175 m .52611 .38176 L .52635 .38151 L F
.5261 .38175 m .52635 .38151 L .52609 .38174 L F
.52556 .38229 m .52635 .38151 L .52555 .38229 L F
.52513 .38168 m .52513 .38167 L .52401 .38157 L F
.52403 .38158 m .5251 .3817 L .52511 .38169 L F
.52428 .38171 m .52445 .38173 L .52446 .38172 L F
.52428 .38171 m .52446 .38172 L .52426 .3817 L F
.52446 .38172 m .52448 .38172 L .52426 .3817 L F
.52527 .38162 m .52519 .38159 L p .52528 .38161 L F P
0 g
s
.52523 .38159 m .52517 .38158 L .52536 .38155 L .67 .731 .896 r
F
.52519 .38158 m .52533 .38164 L .52532 .38144 L F
.52534 .38159 m .52527 .3816 L .52519 .38159 L F
.52353 .38104 m .52523 .38159 L .52523 .38159 L F
.52424 .38104 m .52424 .38104 L .52598 .3816 L F
.52423 .38103 m .5249 .38143 L .52527 .38137 L F
.52528 .38163 m .52463 .38147 L .52465 .38105 L F
.52519 .38158 m .52519 .38159 L .52516 .38158 L F
.52534 .38159 m .52519 .38159 L .52519 .38158 L F
.52532 .38144 m .52533 .38164 L .5256 .38155 L F
.52465 .38105 m .52463 .38147 L .52442 .38098 L F
.5212 .37991 m .52519 .38158 L .52532 .38144 L F
.52519 .38159 m .52516 .38157 L p .5252 .38159 L F P
0 g
s
.52519 .38159 m .5252 .38159 L .52528 .38161 L .67 .731 .896 r
F
.52516 .38158 m .52372 .3819 L .52476 .38156 L F
.52527 .3816 m .52372 .3819 L .52516 .38158 L F
.52479 .38162 m .52457 .38162 L .52486 .38168 L F
.52428 .38171 m .52426 .3817 L .52163 .38144 L F
.52457 .38162 m .52317 .38161 L .52486 .38168 L F
.52486 .38168 m .52317 .38161 L .52491 .38173 L F
.52317 .38161 m .52492 .38174 L .52491 .38173 L F
.52317 .38161 m .52326 .38165 L .52506 .38186 L F
.52129 .38161 m .52343 .38177 L p .52015 .38131 L F P
0 g
s
.52015 .38131 m .52343 .38177 L .52297 .38158 L .67 .731 .896 r
F
.51036 .38079 m .52129 .38161 L p .52015 .38131 L F P
0 g
s
.52086 .38181 m .51029 .38147 L p .52262 .38144 L .67 .731 .896 r
F P
0 g
s
.52189 .38159 m .51627 .38153 L .52129 .38172 L .67 .731 .896 r
F
.52412 .38168 m .52413 .38168 L .52163 .38144 L F
.52476 .38156 m .52086 .38181 L .52169 .38164 L F
.52189 .38159 m .52129 .38172 L .52353 .3818 L F
.52317 .38161 m .52189 .38159 L .52353 .3818 L F
.51627 .38153 m .52508 .38187 L .52506 .38186 L F
.51627 .38153 m .52259 .3818 L .52251 .38177 L F
.5218 .38184 m .52276 .38187 L p .52197 .38183 L F P
0 g
s
.51627 .38153 m .5218 .38184 L .52197 .38183 L .67 .731 .896 r
F
.51713 .38169 m .5218 .38184 L p .51627 .38153 L F P
0 g
s
.51627 .38153 m .52276 .38187 L .52259 .3818 L .67 .731 .896 r
F
.52543 .38163 m .51766 .38207 L .52005 .38157 L F
.52604 .38178 m .52602 .38171 L .52605 .38169 L F
.52604 .38178 m .52605 .38169 L .52608 .38172 L F
.52604 .38178 m .52596 .3818 L .52602 .38171 L F
.52588 .38186 m .52603 .38166 L .52589 .38186 L F
.52582 .38184 m .52586 .38197 L .52631 .38152 L F
.52606 .3817 m .52611 .38176 L .52614 .3817 L F
.52606 .3817 m .52614 .3817 L .52621 .38155 L F
.52604 .38167 m .52603 .38166 L .52632 .38125 L F
.52614 .3815 m .52603 .38166 L .52614 .3815 L F
.52582 .3814 m .52606 .3817 L .52621 .38155 L F
.52621 .38156 m .52625 .38159 L .52636 .38124 L F
.52609 .38174 m .52635 .38151 L .52631 .38152 L F
.52633 .38162 m .52633 .38166 L .52621 .38154 L F
.52618 .38172 m .52622 .38169 L .52625 .38159 L F
.52578 .38149 m .52568 .38153 L .52556 .38143 L F
.52614 .3818 m .52618 .38172 L .52612 .38177 L F
.52653 .38185 m .52661 .38188 L .52661 .38186 L F
.52719 .38198 m .52591 .38186 L .52719 .38198 L F
.52661 .38188 m .52745 .38224 L .52661 .38186 L F
.52661 .38186 m .52745 .38224 L .52662 .38186 L F
.52866 .38266 m .52838 .38258 L .52979 .38276 L F
.52838 .38258 m .52789 .3824 L .52979 .38276 L F
.52671 .38188 m .52745 .38224 L .52688 .38192 L F
.52696 .38206 m .52695 .38205 L .52735 .38215 L F
.5271 .3822 m .52746 .3822 L .52762 .38224 L F
.5267 .38192 m .52673 .38197 L .52745 .38224 L F
.52909 .38282 m .52911 .38281 L .52902 .38272 L F
.52962 .38283 m .52962 .38283 L .53246 .38356 L F
.52869 .3824 m .52883 .38253 L .54079 .38642 L F
.53609 .38486 m .52866 .38266 L .52979 .38276 L F
.52729 .38208 m .53412 .38472 L .52726 .38205 L F
.52735 .38216 m .52735 .38215 L .52752 .3822 L F
.52729 .38208 m .52745 .38224 L .53412 .38472 L F
.52688 .38192 m .52745 .38224 L .52729 .38208 L F
.52886 .38268 m .52663 .38195 L .52661 .38186 L F
.53016 .38315 m .52884 .3827 L .52886 .38268 L F
.52884 .3827 m .52663 .38195 L .52886 .38268 L F
.53321 .38201 m .52703 .38168 L .53113 .38219 L F
.54219 .38317 m .54228 .3825 L p .53321 .38201 L F P
0 g
s
.53321 .38201 m .53113 .38219 L .54219 .38317 L .67 .731 .896 r
F
.54228 .3825 m .53163 .38215 L p .5282 .38174 L F P
0 g
s
.53877 .38178 m .53264 .38198 L .53538 .38213 L .67 .731 .896 r
F
.53877 .38178 m .53016 .38168 L .53264 .38198 L F
.53163 .38215 m .52959 .38196 L .5282 .38174 L F
.53016 .38168 m .52897 .382 L .53457 .38221 L F
.54228 .3825 m .54231 .38182 L p .53877 .38178 L F P
0 g
s
.53877 .38178 m .53457 .38221 L .54228 .3825 L .67 .731 .896 r
F
.54231 .38182 m .52974 .38195 L p .52918 .38167 L F P
0 g
s
.52956 .38193 m .54117 .38183 L .54117 .38183 L .67 .731 .896 r
F
.53015 .38317 m .52882 .38271 L .53016 .38315 L F
.52882 .38271 m .52663 .38195 L .52884 .3827 L F
.52882 .38271 m .52884 .3827 L .53016 .38315 L F
.54231 .38182 m .54226 .38114 L p .52995 .38153 L F P
0 g
s
.53151 .38366 m .52663 .38195 L .53152 .38364 L .67 .731 .896 r
F
.52713 .38188 m .52793 .38197 L .52713 .38187 L F
.52704 .38188 m .52709 .3819 L .52793 .38197 L F
.52685 .3819 m .52689 .38192 L .52689 .38191 L F
.52682 .3819 m .5271 .38194 L .52675 .38189 L F
.52655 .38185 m .53022 .38228 L .53063 .38224 L F
.52655 .38185 m .53063 .38224 L .53041 .38218 L F
.52638 .3817 m .52635 .3817 L .52712 .382 L F
.52638 .3817 m .52712 .382 L .52713 .38199 L F
.52649 .38181 m .52713 .38187 L .52649 .3818 L F
.52652 .38168 m .52649 .38167 L .52649 .38167 L F
.52656 .38169 m .52652 .38168 L .52649 .38167 L F
.52706 .38186 m .52649 .38167 L .52715 .38195 L F
.52736 .38189 m .52736 .38188 L .52712 .38186 L F
.52713 .38186 m .52712 .38186 L .52611 .38177 L F
.52736 .38189 m .52712 .38186 L .52713 .38186 L F
.52682 .38127 m .5271 .3809 L .5271 .38093 L F
.52674 .38135 m .52681 .38125 L .52682 .38127 L F
.52619 .38185 m .52624 .38168 L .52618 .38185 L F
.52624 .38168 m .52627 .38161 L .52624 .38168 L F
.52624 .38168 m .52624 .38168 L .52618 .38185 L F
.52633 .38181 m .52624 .38179 L .52703 .38168 L F
.52661 .38186 m .52654 .3817 L .52657 .3817 L F
.52663 .38195 m .52659 .38186 L .52661 .38186 L F
.52663 .38195 m .52609 .38177 L .52611 .38176 L F
.52608 .38216 m .52627 .38161 L .52625 .38159 L F
.52603 .38182 m .5261 .38177 L .52703 .38168 L F
.52713 .38187 m .52713 .38186 L .52513 .38167 L F
.52638 .38182 m .52673 .38186 L .52633 .38181 L F
.52659 .38186 m .52611 .38176 L .52654 .3817 L F
.52642 .38183 m .52627 .3818 L .52673 .38197 L F
.52663 .38195 m .52611 .38176 L .52659 .38186 L F
.52624 .38192 m .52623 .38191 L .52639 .38196 L F
.52619 .38185 m .52633 .38166 L .52627 .38161 L F
.52629 .38198 m .52586 .38183 L p .52639 .38196 L F P
0 g
s
.52593 .38265 m .52623 .38191 L .52619 .38185 L .67 .731 .896 r
F
.52623 .38191 m .52633 .38166 L .52619 .38185 L F
.52597 .38179 m .52609 .38177 L .52612 .38178 L F
.52617 .38184 m .52612 .38178 L .52663 .38195 L F
.52597 .38179 m .52612 .38178 L .52617 .38184 L F
.52664 .382 m .52663 .38195 L .52814 .38248 L F
.52614 .3818 m .52622 .38169 L .52618 .38172 L F
.52597 .38209 m .52615 .38181 L .52614 .3818 L F
.52615 .38181 m .52622 .38169 L .52614 .3818 L F
.52619 .38186 m .52663 .38195 L .52664 .382 L F
.52597 .38179 m .52617 .38184 L .52619 .38186 L F
.52617 .38184 m .52663 .38195 L .52619 .38186 L F
.5265 .3816 m .52666 .38141 L .52667 .38141 L F
.52629 .38198 m .52615 .38181 L .52633 .38181 L F
.52665 .38201 m .52665 .38201 L .52582 .38176 L F
.52629 .38198 m .52633 .38181 L .52659 .38186 L F
.52664 .382 m .52665 .38201 L .52594 .38179 L F
.52629 .38198 m .52659 .38186 L .52686 .38191 L F
.52618 .38184 m .52628 .38197 L .52648 .38173 L F
.52628 .38197 m .52629 .38198 L .52648 .38173 L F
.52876 .38194 m .52643 .38165 L .52837 .38198 L F
.5291 .38191 m .52876 .38188 L .52876 .38194 L F
.52876 .38188 m .52643 .38165 L .52876 .38194 L F
.52671 .38137 m .52681 .38125 L .52674 .38135 L F
.52677 .38129 m .52676 .3813 L .52681 .38124 L F
.52667 .38141 m .52676 .3813 L .52677 .38129 L F
.52667 .38141 m .52666 .38141 L .52676 .3813 L F
.5269 .38129 m .52705 .38112 L p .52687 .38127 L F P
0 g
s
.52713 .38104 m .52686 .38134 L p .52711 .38097 L .67 .731 .896 r
F P
0 g
s
.52686 .38134 m .52684 .3813 L .52711 .38097 L .67 .731 .896 r
F
.52641 .3817 m .5268 .38124 L .52681 .38124 L F
.52683 .38129 m .52757 .38039 L .52683 .3813 L F
.52696 .38132 m .53529 .37315 L p .52661 .38144 L F P
0 g
s
.52647 .38116 m .52713 .38067 L .52702 .38061 L .67 .731 .896 r
F
.52689 .38104 m .52654 .38098 L .52673 .38092 L F
.52632 .38131 m .52713 .38067 L .52647 .38116 L F
.52632 .38131 m .52724 .38072 L .52713 .38067 L F
.52649 .38104 m .52655 .38078 L .52647 .38104 L F
.52654 .38075 m .5264 .38128 L .52641 .38128 L F
.52824 .37894 m .52835 .37876 L p .52824 .37894 L F P
0 g
s
.52651 .3809 m .5265 .38091 L .52642 .38125 L .67 .731 .896 r
F
.52651 .3809 m .52642 .38125 L .52642 .38125 L F
.52835 .37876 m .53258 .37216 L p .52835 .37876 L F P
0 g
s
.52673 .38092 m .52654 .38098 L .52656 .38079 L .67 .731 .896 r
F
.52641 .38124 m .52654 .38074 L .52639 .3812 L F
.52656 .38079 m .52632 .38131 L .53351 .37245 L F
.52707 .38095 m .52703 .38063 L .5276 .37984 L F
.5288 .3782 m .5266 .38121 L .5264 .38113 L F
.53351 .37245 m .52855 .379 L p .5288 .3782 L F P
0 g
s
.52639 .38116 m .52668 .38115 L .53442 .37278 L .67 .731 .896 r
F
.52912 .37857 m .5271 .3809 L .52919 .37829 L F
.5271 .3809 m .52707 .38077 L .52919 .37829 L F
.5271 .3809 m .52757 .38035 L .52757 .38036 L F
.5268 .38101 m .5266 .38123 L .52703 .38063 L F
.52646 .3816 m .5266 .38123 L .5268 .38101 L F
.52646 .3816 m .52642 .38149 L .5266 .38123 L F
.52635 .38151 m .52759 .38051 L .52709 .38071 L F
.5271 .3809 m .52735 .3806 L .5271 .3809 L F
.52735 .3806 m .52757 .38035 L .5271 .3809 L F
.5271 .3809 m .52757 .38035 L .5271 .3809 L F
.52683 .3813 m .52757 .38039 L .52758 .38041 L F
.52904 .37887 m .52759 .38051 L p .52912 .37857 L F P
0 g
s
.52759 .38051 m .52758 .38041 L .52912 .37857 L .67 .731 .896 r
F
.5271 .38093 m .5271 .3809 L .52912 .37857 L F
.52716 .38088 m .52719 .38083 L .52912 .37857 L F
.52694 .38085 m .52739 .3807 L .53529 .37315 L F
.53239 .37592 m .53097 .37728 L .53265 .37557 L F
.53232 .37601 m .53097 .37728 L .53239 .37592 L F
.53232 .37601 m .52879 .37949 L .53097 .37728 L F
.52747 .38175 m .52678 .38176 L .52691 .3817 L F
.5269 .38171 m .52707 .38175 L .52705 .38172 L F
.52637 .38164 m .52707 .38175 L .5269 .38171 L F
.52637 .38164 m .52711 .38184 L .52707 .38175 L F
.52879 .37949 m .5277 .38056 L .52879 .37941 L F
.52617 .38178 m .52713 .38188 L .52713 .38187 L F
.52642 .3818 m .52633 .38181 L .52643 .38179 L F
.52642 .3818 m .52643 .38179 L .52703 .38168 L F
.52675 .38179 m .52642 .3818 L .52703 .38168 L F
.52629 .38198 m .52654 .3817 L p .52648 .38173 L F P
0 g
s
.52654 .3817 m .5269 .38129 L p .52632 .38173 L .67 .731 .896 r
F P
0 g
s
.52703 .38168 m .52637 .38164 L .52705 .38172 L .67 .731 .896 r
F
.52703 .38168 m .5265 .38173 L .52637 .38164 L F
.52651 .38168 m .52652 .38166 L .52653 .38167 L F
.52611 .38176 m .52712 .38186 L .5261 .38175 L F
.52712 .38186 m .52877 .38202 L .52712 .38185 L F
.52712 .38186 m .52712 .38185 L .5261 .38175 L F
.52673 .38186 m .52671 .38187 L .52709 .3819 L F
.52633 .38181 m .52673 .38186 L .52677 .38185 L F
.52635 .3817 m .52685 .3819 L .52689 .38191 L F
.52633 .38181 m .52793 .38197 L .52617 .38178 L F
.52677 .38185 m .52709 .3819 L .52704 .38188 L F
.52673 .38186 m .52709 .3819 L .52677 .38185 L F
.52736 .38188 m .52736 .38188 L .52611 .38176 L F
.52686 .38191 m .52633 .38181 L .52806 .38175 L F
.52801 .38177 m .52806 .38175 L .5282 .38174 L F
.52781 .38189 m .52781 .38191 L .52837 .38198 L F
.52773 .38199 m .52771 .38187 L .5291 .38191 L F
.5291 .38191 m .52769 .38187 L .52747 .38175 L F
.52705 .38172 m .52711 .38184 L .53113 .38219 L F
.52686 .38191 m .52806 .38175 L .52801 .38177 L F
.52565 .38129 m .52319 .38034 L .52336 .38026 L F
.52618 .38184 m .5269 .38129 L .52687 .38127 L F
.52646 .38169 m .52674 .38135 L .52675 .38135 L F
.52625 .38173 m .52641 .38147 L .52642 .38149 L F
.52611 .38176 m .52663 .38141 L .52635 .38151 L F
.5259 .3818 m .52621 .38189 L .52623 .3819 L F
.52597 .38209 m .52614 .3818 L .52612 .38177 L F
.52713 .38187 m .52793 .38197 L .52796 .38194 L F
.52736 .38188 m .52877 .38202 L .52736 .38188 L F
.52711 .38184 m .52877 .38202 L .52889 .382 L F
.5261 .38175 m .52712 .38185 L .52711 .38184 L F
.52712 .38185 m .52877 .38202 L .52711 .38184 L F
.52682 .38127 m .5271 .38093 L .5271 .38093 L F
.52618 .38184 m .52654 .3817 L .52632 .38173 L F
.52433 .38173 m .52483 .38187 L .52493 .38181 L F
.52487 .38184 m .52478 .38186 L .52483 .38183 L F
.52517 .38194 m .52372 .3819 L p .52545 .38184 L F P
0 g
s
.52259 .3818 m .52517 .38194 L .52512 .38191 L .67 .731 .896 r
F
.52456 .38185 m .52483 .38187 L p .52433 .38173 L F P
0 g
s
.52433 .38173 m .52494 .3818 L .52428 .38171 L .67 .731 .896 r
F
.52494 .3818 m .52496 .38179 L .52428 .38171 L F
.52464 .38187 m .52405 .38184 L .52534 .38159 L F
.5251 .38189 m .5251 .38189 L .52355 .38181 L F
.52484 .38189 m .52512 .38191 L .52487 .38188 L F
.52512 .38191 m .5251 .38189 L .52487 .38188 L F
.52355 .38181 m .5251 .38189 L .52508 .38187 L F
.52506 .38186 m .52531 .38187 L .52532 .38187 L F
.5259 .38186 m .52591 .38186 L .52426 .3817 L F
.52524 .38199 m .51766 .38207 L p .52536 .3818 L F P
0 g
s
.52507 .38198 m .52514 .38198 L .52507 .38198 L .67 .731 .896 r
F
.52585 .3818 m .52587 .3818 L .52639 .38196 L F
.52604 .38221 m .52646 .38169 L .52604 .38221 L F
.52646 .38169 m .52674 .38135 L .52646 .38169 L F
.52646 .38169 m .52646 .38169 L .52604 .38221 L F
.52583 .38177 m .52591 .38179 L .5259 .3818 L F
.52567 .38217 m .52611 .38176 L .5261 .38175 L F
.52609 .38177 m .52609 .38177 L .52611 .38176 L F
.526 .38202 m .52611 .38176 L .52611 .38176 L F
.52611 .38176 m .52611 .38176 L .52611 .38176 L F
.52611 .38176 m .52595 .38173 L .52607 .38171 L F
.52607 .38171 m .52595 .38173 L .526 .38162 L F
.52581 .38174 m .52579 .3817 L .52609 .38177 L F
.52595 .38173 m .52545 .38184 L .52579 .3817 L F
.52595 .38173 m .52579 .3817 L .526 .38162 L F
.52579 .3817 m .52577 .38165 L .52605 .38175 L F
.52579 .3817 m .52605 .38175 L .52609 .38177 L F
.52611 .38176 m .52577 .38165 L .52603 .38167 L F
.52612 .38177 m .52621 .38156 L .52611 .38177 L F
.52612 .38177 m .52618 .38172 L .52612 .38176 L F
.52611 .38176 m .52627 .38166 L .52637 .38164 L F
.52614 .38177 m .52611 .38176 L .52637 .38164 L F
.52629 .38174 m .5265 .38154 L .52611 .38176 L F
.5265 .38154 m .52663 .38141 L .52649 .38151 L F
.5265 .38154 m .52649 .38151 L .52611 .38176 L F
.52626 .38194 m .52646 .38169 L .52626 .38194 L F
.52625 .38199 m .52652 .38166 L .52626 .38199 L F
.52616 .38183 m .52622 .3819 L .52694 .38193 L F
.5271 .38194 m .53022 .38228 L .52675 .38189 L F
.52703 .38194 m .52686 .38191 L .52699 .38189 L F
.52738 .38201 m .52706 .38188 L .52741 .38184 L F
.52675 .38189 m .53022 .38228 L .52655 .38185 L F
.52738 .38201 m .52703 .38194 L .52694 .38184 L F
.52703 .38194 m .52661 .38186 L .52694 .38184 L F
.52694 .38184 m .52661 .38186 L .52657 .3817 L F
.52694 .38184 m .52686 .38191 L .52704 .38195 L F
.5279 .38228 m .52788 .38229 L .52968 .38297 L F
.52725 .38199 m .52719 .38198 L .52719 .38198 L F
.52746 .3822 m .52752 .3822 L .52979 .38276 L F
.53003 .38301 m .52718 .38198 L .52968 .38297 L F
.52979 .38276 m .52752 .3822 L .52805 .38219 L F
.52718 .38198 m .52714 .38199 L .52968 .38297 L F
.52725 .38199 m .5272 .38198 L .52718 .38198 L F
.52725 .38199 m .52718 .38198 L .52719 .38198 L F
.52695 .38193 m .52729 .38208 L .52726 .38205 L F
.52689 .38192 m .52729 .38208 L .52695 .38193 L F
.5302 .3831 m .52661 .38186 L .52738 .38201 L F
.53003 .38301 m .52968 .38297 L .53392 .38459 L F
.53278 .3841 m .53016 .38315 L .5302 .3831 L F
.53016 .38315 m .52661 .38186 L .5302 .3831 L F
.52995 .38153 m .52956 .38193 L .54231 .38182 L F
.52702 .38194 m .52686 .38191 L .52703 .38194 L F
.52702 .38194 m .52703 .38194 L .52738 .38201 L F
.52721 .38197 m .52718 .38198 L .53338 .38423 L F
.52725 .38199 m .53022 .38228 L .5272 .38198 L F
.52738 .38202 m .52702 .38194 L .52738 .38201 L F
.52694 .38184 m .52704 .38195 L .52729 .382 L F
.52627 .38161 m .52638 .38126 L .52625 .38159 L F
.52639 .38115 m .52629 .38198 L p .52638 .38115 L F P
0 g
s
.52623 .38151 m .52643 .38139 L .52642 .38136 L .67 .731 .896 r
F
.52582 .38184 m .5262 .38156 L .52623 .38151 L F
.52621 .38156 m .52625 .38146 L .52621 .38155 L F
.5262 .38156 m .52643 .38139 L .52623 .38151 L F
.52621 .38156 m .52636 .38124 L .52625 .38146 L F
.52621 .38155 m .52625 .38146 L .52621 .38155 L F
.52597 .38179 m .52594 .38179 L .52582 .38176 L F
.52566 .38183 m .52566 .38183 L .52544 .38181 L F
.5261 .38177 m .52558 .38182 L .52611 .38176 L F
.52558 .38182 m .52545 .38184 L .52557 .38182 L F
.52558 .38182 m .52557 .38182 L .52611 .38176 L F
.52591 .38179 m .52621 .38189 L .5259 .3818 L F
.52585 .3818 m .52584 .38179 L .52586 .3818 L F
.52585 .3818 m .52586 .3818 L .52587 .3818 L F
.52585 .3818 m .52585 .3818 L .52587 .3818 L F
.52582 .38184 m .52588 .3818 L .52588 .3818 L F
.52591 .38186 m .52505 .38177 L .52591 .38186 L F
.52663 .38193 m .52505 .38177 L .52505 .38177 L F
.52603 .38182 m .52545 .38184 L .5261 .38177 L F
.52555 .38229 m .5261 .38175 L .52609 .38174 L F
.52609 .38177 m .52605 .38175 L .52611 .38176 L F
.52588 .3818 m .52605 .38169 L .52588 .3818 L F
.52581 .38174 m .52609 .38177 L .52597 .38179 L F
.52611 .38176 m .52545 .38184 L .52595 .38173 L F
.52605 .38175 m .52577 .38165 L .52611 .38176 L F
.52671 .382 m .52536 .38184 L .52536 .38184 L F
.52591 .38152 m .52556 .38143 L .52586 .38146 L F
.52581 .38148 m .52578 .38149 L .52593 .38154 L F
.52581 .38148 m .52593 .38154 L .52591 .38152 L F
.52582 .3814 m .52578 .38195 L .52611 .38176 L F
.52558 .38229 m .52557 .38229 L .52602 .38165 L F
.52558 .38229 m .52558 .38229 L .52602 .38165 L F
.52582 .38184 m .52553 .38225 L .5255 .38223 L F
.52559 .38217 m .52535 .38251 L .52574 .38213 L F
.51756 .38205 m .52373 .382 L .51755 .38205 L F
.52591 .38182 m .52512 .38292 L .52582 .38184 L F
.52512 .38292 m .52511 .38291 L .52582 .38184 L F
.5246 .38366 m .52456 .38364 L .52508 .3829 L F
.52511 .38291 m .52508 .3829 L .52582 .38184 L F
.5246 .38366 m .52508 .3829 L .52511 .38291 L F
.52217 .38202 m .52375 .38201 L p .52209 .38201 L F P
0 g
s
.52558 .38229 m .52515 .3829 L .52558 .38229 L .67 .731 .896 r
F
.52516 .38279 m .526 .38202 L .52611 .38176 L F
.5259 .3821 m .52593 .38217 L .52597 .38208 L F
.52569 .38252 m .52595 .38214 L .52593 .38217 L F
.52573 .3826 m .52573 .38263 L .52609 .38181 L F
.52573 .38263 m .52594 .38217 L .52593 .38217 L F
.52593 .38269 m .52587 .38232 L .52595 .38213 L F
.52573 .38263 m .52608 .38216 L .52597 .38209 L F
.52547 .38252 m .52598 .38234 L .5259 .3821 L F
.52578 .38198 m .52573 .3826 L .52597 .38208 L F
.5258 .38197 m .52597 .38208 L .52611 .38177 L F
.52558 .38229 m .52592 .38181 L .52592 .38181 L F
.52578 .38198 m .52597 .38208 L .5258 .38197 L F
.52611 .38176 m .52621 .38155 L .52621 .38155 L F
.52609 .38181 m .52611 .38176 L .52611 .38176 L F
.52611 .38176 m .52621 .38155 L .52611 .38176 L F
.52592 .38153 m .52577 .38165 L .52566 .38146 L F
.52611 .38177 m .52621 .38156 L .52621 .38155 L F
.52653 .38169 m .52603 .38166 L .52592 .38153 L F
.52603 .38166 m .52577 .38165 L .52592 .38153 L F
.52612 .38177 m .5261 .38177 L .52611 .38176 L F
.52624 .38192 m .52642 .3817 L .52624 .38192 L F
.52642 .3817 m .52681 .38124 L .52643 .3817 L F
.52642 .3817 m .52643 .3817 L .52624 .38192 L F
.52657 .3817 m .52653 .38169 L .52653 .38169 L F
.52657 .3817 m .52653 .38168 L .52666 .38189 L F
.52653 .38169 m .52577 .38165 L .52653 .38169 L F
.52586 .38146 m .52568 .3814 L .52587 .38147 L F
.52657 .3817 m .52566 .38146 L .52582 .3814 L F
.52653 .38168 m .52582 .3814 L .52634 .38172 L F
.52629 .38174 m .52611 .38176 L .52611 .38176 L F
.52611 .38176 m .52603 .38167 L .52653 .38169 L F
.52654 .3817 m .52653 .38169 L .52657 .3817 L F
.52611 .38176 m .52653 .38169 L .52654 .3817 L F
.52664 .38116 m .52666 .38116 L .52668 .38115 L F
.52667 .38116 m .52667 .38116 L .52668 .38115 L F
.526 .38162 m .52615 .38157 L .52668 .38115 L F
.52642 .38149 m .52641 .38147 L .52703 .38063 L F
.52675 .38114 m .52646 .38148 L .52666 .38095 L F
.52616 .38165 m .52606 .3817 L .52596 .38114 L F
.52599 .38205 m .52598 .38206 L .52599 .38205 L F
.52621 .38189 m .52544 .38181 L .52544 .38181 L F
.52597 .38208 m .52612 .38177 L .52611 .38177 L F
.52593 .38217 m .52597 .38208 L .52597 .38208 L F
.52597 .38208 m .52612 .38177 L .52597 .38208 L F
.5258 .38197 m .52517 .38194 L p .52603 .38182 L F P
0 g
s
.52519 .38297 m .52595 .38181 L .52519 .38297 L .67 .731 .896 r
F
.52578 .38195 m .5258 .38196 L .52611 .38176 L F
.52597 .38208 m .52621 .38155 L .52609 .38181 L F
.52593 .38217 m .52597 .38208 L .52597 .38208 L F
.52597 .38208 m .52621 .38155 L .52597 .38208 L F
.52586 .38183 m .52623 .38191 L .52624 .38192 L F
.52594 .38217 m .52597 .38209 L .52593 .38217 L F
.52597 .38209 m .52621 .38156 L .52597 .38208 L F
.52597 .38209 m .52597 .38208 L .52593 .38217 L F
.52517 .38194 m .5258 .38197 L p .52512 .38191 L F P
0 g
s
.526 .38202 m .52604 .38197 L .52602 .38197 L .67 .731 .896 r
F
.52607 .38185 m .52615 .38181 L .52611 .38176 L F
.52619 .38185 m .52618 .38185 L .52608 .38216 L F
.52591 .3821 m .52629 .38198 L .52618 .38184 L F
.52629 .38198 m .5258 .38197 L p .52615 .38181 L F P
0 g
s
.52603 .38222 m .52589 .38362 L .52595 .38214 L .67 .731 .896 r
F
.52577 .38253 m .52604 .38221 L .52604 .38221 L F
.52573 .38263 m .52593 .38309 L .52571 .38285 L F
.52578 .38195 m .52584 .38238 L .52573 .38263 L F
.52589 .38362 m .52585 .38256 L .52593 .38269 L F
.52584 .38238 m .52593 .38309 L .52573 .38263 L F
.52581 .38243 m .52624 .38192 L .52624 .38192 L F
.52504 .38339 m .52574 .38261 L p .52503 .38294 L F P
0 g
s
.52498 .38342 m .52582 .38242 L .52581 .38243 L .67 .731 .896 r
F
.52593 .38217 m .52598 .38234 L .52597 .38208 L F
.52582 .38242 m .52624 .38192 L .52581 .38243 L F
.52574 .38261 m .52598 .38234 L p .52547 .38252 L F P
0 g
s
.52572 .38259 m .52577 .38253 L .52577 .38253 L .67 .731 .896 r
F
.52593 .38269 m .52585 .38256 L .52587 .38232 L F
.52577 .38253 m .52604 .38221 L .52577 .38253 L F
.5258 .38197 m .52603 .38182 L .52615 .38181 L F
.52529 .38188 m .52626 .38194 L .52623 .38191 L F
.52508 .38187 m .52528 .38188 L .52529 .38188 L F
.52528 .38188 m .52626 .38194 L .52529 .38188 L F
.5271 .3809 m .5268 .38123 L .52707 .38077 L F
.5268 .38123 m .52676 .38116 L .52707 .38077 L F
.52642 .38136 m .52643 .38139 L .52667 .38116 L F
.52582 .38184 m .52667 .38116 L .52667 .38116 L F
.52575 .38193 m .52629 .38198 L .52627 .38195 L F
.52527 .38162 m .52528 .38161 L .52639 .38196 L F
.52578 .38198 m .52611 .38177 L .52611 .38176 L F
.5258 .38239 m .52564 .38243 L .52599 .38203 L F
.52589 .38189 m .52623 .38191 L .52622 .3819 L F
.52633 .38181 m .52603 .38182 L .52624 .38179 L F
.5259 .3821 m .52629 .38198 L .52591 .3821 L F
.52588 .38227 m .52599 .38203 L .52646 .38148 L F
.52582 .38184 m .5255 .38223 L .52586 .38197 L F
.52553 .38225 m .51914 .39141 L .5255 .38223 L F
.5255 .38223 m .52502 .38282 L .52565 .38218 L F
.52558 .38229 m .52592 .38181 L .52558 .38229 L F
.52558 .38229 m .52558 .38229 L .52592 .38181 L F
.5255 .38223 m .52565 .38218 L .52586 .38197 L F
.52578 .38195 m .5258 .38197 L .52578 .38195 L F
.52578 .38195 m .52578 .38198 L .5258 .38196 L F
.52589 .38189 m .5259 .38223 L .52578 .38195 L F
.52573 .38263 m .52593 .38265 L .52608 .38216 L F
.52574 .3826 m .52596 .38234 L .52596 .38234 L F
.52572 .38263 m .52569 .38262 L .52626 .38195 L F
.52598 .38234 m .52572 .38263 L p .52596 .38234 L F P
0 g
s
.5259 .38223 m .52593 .38309 L .52584 .38238 L .67 .731 .896 r
F
.5259 .38223 m .52584 .38238 L .52578 .38195 L F
.52572 .38263 m .52574 .3826 L .52574 .3826 L F
.52574 .3826 m .52596 .38234 L .52574 .3826 L F
.5258 .38239 m .52599 .38203 L .52588 .38227 L F
.52614 .38177 m .52612 .38177 L .52611 .38176 L F
.52618 .38184 m .52629 .38174 L .52611 .38176 L F
.52603 .38181 m .52655 .38185 L .52604 .3818 L F
.52655 .38185 m .52805 .38197 L .52651 .38184 L F
.52627 .38196 m .52626 .38195 L .52683 .38128 L F
.52655 .38185 m .52651 .38184 L .52604 .3818 L F
.52738 .38202 m .52629 .38198 L p .52686 .38191 L F P
0 g
s
.52686 .38191 m .52666 .38189 L .52728 .38222 L .67 .731 .896 r
F
.52657 .3817 m .52665 .38187 L .52686 .38191 L F
.52616 .38183 m .52694 .38193 L .52661 .38186 L F
.52665 .38187 m .52666 .38189 L .52686 .38191 L F
.52608 .38182 m .52599 .38183 L .52608 .38178 L F
.52633 .38166 m .52638 .38126 L p .52627 .38161 L F P
0 g
s
.52631 .38098 m .52631 .38115 L p .52625 .38094 L .67 .731 .896 r
F P
0 g
s
.52604 .38178 m .52636 .3812 L .52637 .3812 L .67 .731 .896 r
F
.52592 .38181 m .52632 .38125 L .52632 .38125 L F
.52614 .3815 m .52614 .3815 L .52631 .38124 L F
.52632 .38125 m .52614 .3815 L .52631 .38124 L F
.52603 .38166 m .52638 .38116 L .52638 .38116 L F
.52603 .38166 m .52638 .38116 L .52603 .38166 L F
.52631 .38124 m .526 .38162 L .52626 .38144 L F
.52625 .38146 m .52636 .38124 L .52636 .38123 L F
.52636 .38123 m .52626 .38144 L .52666 .38116 L F
.52631 .38124 m .52626 .38144 L .52636 .38123 L F
.52621 .38155 m .52625 .38146 L .52635 .38122 L F
.52625 .38146 m .52636 .38123 L .52635 .38122 L F
.52636 .38123 m .52636 .38124 L .52638 .38118 L F
.52651 .38117 m .52638 .38119 L .5264 .38113 L F
.5266 .38121 m .52638 .38119 L .52651 .38117 L F
.52638 .38116 m .52638 .38116 L .5264 .38113 L F
.5264 .38113 m .52638 .38116 L .52638 .38115 L F
.52639 .38113 m .52639 .38115 L p .52638 .38115 L F P
0 g
s
.52638 .38126 m .52639 .38113 L p .52636 .38124 L .67 .731 .896 r
F P
0 g
s
.52636 .38123 m .52668 .38115 L .52639 .38116 L .67 .731 .896 r
F
.52666 .38095 m .5263 .38134 L .52694 .38085 L F
.52582 .3814 m .52587 .38147 L .52634 .38172 L F
.52608 .38178 m .52599 .38183 L .52598 .3816 L F
.52605 .38179 m .52615 .38181 L .52611 .38176 L F
.52611 .38176 m .52608 .38182 L .52608 .38178 L F
.52611 .38176 m .52608 .38178 L .52606 .3817 L F
.52597 .38184 m .52592 .38187 L .52592 .38153 L F
.52595 .38156 m .52592 .38153 L .52592 .38116 L F
.52515 .3817 m .52616 .38182 L .52515 .3817 L F
.5251 .3817 m .52616 .38182 L .52511 .38169 L F
.52528 .38159 m .52582 .38176 L .52583 .38177 L F
.52545 .38184 m .52478 .38186 L .52569 .38168 L F
.52579 .3817 m .52569 .38168 L .526 .38162 L F
.52581 .38174 m .52582 .38176 L .52542 .38163 L F
.52545 .38184 m .52569 .38168 L .52579 .3817 L F
.52569 .38168 m .5253 .38161 L .52534 .38159 L F
.52547 .38164 m .52542 .38163 L .52528 .38159 L F
.52581 .38174 m .52542 .38163 L .52547 .38164 L F
.52597 .38184 m .52592 .38153 L .52595 .38156 L F
.52587 .38138 m .52589 .38189 L .52585 .38139 L F
.52568 .3814 m .52556 .38143 L .52549 .38133 L F
.52568 .3814 m .52549 .38133 L .52569 .38141 L F
.52465 .38105 m .52572 .38151 L .52577 .38149 L F
.52581 .38148 m .52465 .38105 L .52578 .38149 L F
.52549 .38133 m .52544 .38134 L .5257 .38144 L F
.52549 .38133 m .5257 .38144 L .52569 .38141 L F
.52465 .38105 m .5256 .38155 L .52572 .38151 L F
.52465 .38105 m .52577 .38149 L .52578 .38149 L F
.52549 .38133 m .52465 .38105 L .52544 .38134 L F
.52465 .38105 m .52437 .38109 L .5256 .38155 L F
.52577 .38165 m .52336 .38081 L .52558 .38131 L F
.51132 .37815 m .51172 .37752 L p .51863 .37946 L F P
0 g
s
.51172 .37752 m .51707 .37916 L p .51863 .37946 L .67 .731 .896 r
F P
0 g
s
.5212 .37991 m .51707 .37916 L .51218 .37691 L .67 .731 .896 r
F
.51985 .37985 m .52475 .38144 L .51985 .37985 L F
.51985 .37985 m .52353 .38104 L .52353 .38104 L F
.51863 .37946 m .51985 .37985 L .51985 .37985 L F
.5232 .38104 m .51707 .37916 L p .5212 .37991 L F P
0 g
s
.52465 .38105 m .5212 .37991 L .52437 .38109 L .67 .731 .896 r
F
.51218 .37691 m .52012 .37976 L p .5212 .37991 L F P
0 g
s
.52336 .38081 m .51218 .37691 L .52359 .38066 L .67 .731 .896 r
F
.52336 .38081 m .52359 .38066 L .52558 .38131 L F
.52558 .38131 m .52526 .38136 L .52606 .3817 L F
.52582 .3814 m .52566 .38146 L .52558 .38131 L F
.52558 .38131 m .52606 .3817 L .52598 .38161 L F
.52577 .38174 m .52588 .38179 L .52615 .38181 L F
.52539 .38168 m .52588 .38179 L .52577 .38174 L F
.52554 .38165 m .52589 .3818 L .5259 .3818 L F
.52582 .38134 m .52589 .38189 L .52578 .38195 L F
.52583 .38122 m .52584 .38135 L .52582 .38134 L F
.52584 .38135 m .52589 .38189 L .52582 .38134 L F
.52592 .38153 m .52592 .38187 L .52587 .38147 L F
.52592 .38187 m .52592 .3821 L .52591 .38188 L F
.52592 .38187 m .52591 .38188 L .52587 .38147 L F
.52575 .38193 m .5258 .38194 L .52573 .38192 L F
.5258 .38194 m .52627 .38195 L .52582 .38193 L F
.5258 .38194 m .52582 .38193 L .52573 .38192 L F
.52502 .38128 m .52605 .38177 L .52611 .38176 L F
.52414 .3809 m .52504 .38131 L .52502 .38128 L F
.52504 .38131 m .52605 .38177 L .52502 .38128 L F
.52592 .3821 m .52593 .38218 L .5259 .38207 L F
.52566 .38351 m .52621 .38267 L .52593 .38265 L F
.52593 .38218 m .52593 .38309 L .5259 .38223 L F
.52593 .38218 m .5259 .38223 L .5259 .38207 L F
.52582 .38242 m .52602 .38218 L .52602 .38218 L F
.5257 .38257 m .52582 .38242 L .52582 .38242 L F
.52582 .38242 m .52602 .38218 L .52582 .38242 L F
.5244 .38398 m .52558 .38229 L .52558 .38229 L F
.52503 .38294 m .52574 .38261 L .52547 .38252 L F
.52569 .38262 m .52566 .38262 L .52571 .38257 L F
.52582 .38241 m .52641 .3817 L .52582 .38241 L F
.52598 .38234 m .52605 .38223 L .52605 .38224 L F
.52593 .38265 m .52608 .38216 L .52608 .38216 L F
.52596 .38234 m .52627 .38196 L .52596 .38234 L F
.5257 .38257 m .52624 .38192 L .52571 .38257 L F
.52624 .38192 m .52681 .38125 L .52624 .38193 L F
.52624 .38192 m .52624 .38193 L .52571 .38257 L F
.52554 .38178 m .52616 .38183 L .52552 .38177 L F
.52625 .38094 m .52627 .3814 L .52596 .38114 L F
.52588 .38229 m .52646 .38148 L .52647 .38153 L F
.52634 .38172 m .52618 .38175 L .52629 .3818 L F
.52646 .38148 m .52616 .38183 L .5264 .38134 L F
.52608 .38178 m .52598 .3816 L .52605 .38169 L F
.52601 .38182 m .52622 .3819 L .52616 .38183 L F
.52554 .38178 m .52595 .38185 L .52601 .38182 L F
.52595 .38185 m .52622 .3819 L .52601 .38182 L F
.52599 .38183 m .52592 .38116 L .52596 .38114 L F
.52602 .38244 m .52597 .38184 L .52599 .38183 L F
.52597 .38184 m .52592 .38116 L .52599 .38183 L F
.52604 .3827 m .52602 .38245 L .52602 .38244 L F
.52587 .38147 m .52618 .38175 L .52634 .38172 L F
.52558 .38131 m .52598 .38161 L .52587 .38147 L F
.52598 .38161 m .52618 .38175 L .52587 .38147 L F
.52606 .3817 m .52597 .38143 L .52602 .38146 L F
.52608 .38178 m .52605 .38169 L .52606 .3817 L F
.52605 .38169 m .52597 .38143 L .52606 .3817 L F
.52616 .38183 m .52613 .38179 L .52628 .38153 L F
.52606 .3817 m .52611 .38176 L .52618 .38175 L F
.52598 .38161 m .52606 .3817 L .52618 .38175 L F
.52611 .38176 m .52606 .3817 L .52616 .38165 L F
.52487 .38184 m .52483 .38183 L .5253 .38161 L F
.52517 .38194 m .52545 .38184 L .52603 .38182 L F
.52492 .38174 m .52506 .38186 L .52589 .38189 L F
.52593 .38186 m .52589 .38189 L .52622 .3819 L F
.52492 .38174 m .52589 .38189 L .52593 .38186 L F
.5258 .38197 m .52629 .38198 L p .52578 .38195 L F P
0 g
s
.52597 .38184 m .52599 .38203 L .52599 .38203 L .67 .731 .896 r
F
.52595 .38156 m .52597 .38184 L .52597 .38184 L F
.52597 .38184 m .52599 .38203 L .52597 .38184 L F
.52593 .38141 m .52595 .38156 L .52595 .38156 L F
.52595 .38156 m .52599 .38203 L .52595 .38156 L F
.52616 .38183 m .52661 .38186 L .52616 .38182 L F
.52582 .38176 m .52665 .38201 L .52583 .38177 L F
.52665 .38201 m .52814 .38248 L .52665 .38202 L F
.52665 .38201 m .52665 .38202 L .52583 .38177 L F
.52577 .38253 m .5258 .38246 L .52651 .38163 L F
.52651 .38163 m .52651 .38163 L .52674 .38135 L F
.52577 .38253 m .52651 .38163 L .52651 .38163 L F
.52605 .38177 m .52684 .38212 L .52626 .38179 L F
.52629 .38198 m .52639 .38196 L .53089 .38347 L F
.52726 .38205 m .53102 .38351 L .53168 .38373 L F
.53102 .38351 m .53412 .38472 L .53168 .38373 L F
.53168 .38373 m .53412 .38472 L .53392 .38459 L F
.53089 .38348 m .53089 .38347 L .53278 .3841 L F
.52629 .38198 m .53089 .38347 L .53089 .38348 L F
.52704 .38213 m .52705 .38214 L .52582 .38176 L F
.52684 .38212 m .52688 .38211 L .52626 .38179 L F
.52582 .38241 m .52613 .38204 L .52613 .38204 L F
.52613 .38204 m .52641 .3817 L .52613 .38204 L F
.52613 .38204 m .52641 .3817 L .52641 .3817 L F
.5277 .38056 m .52769 .38051 L .52879 .37941 L F
.52569 .38262 m .52647 .38169 L .52647 .38169 L F
.52604 .38221 m .52626 .38194 L .52626 .38194 L F
.52602 .38218 m .5265 .3816 L .52602 .38218 L F
.52605 .38224 m .52605 .38223 L .52652 .38166 L F
.52582 .38238 m .5264 .3817 L .52641 .3817 L F
.52629 .38198 m .52628 .3823 L p .52608 .38182 L F P
0 g
s
.52611 .38176 m .52626 .38179 L .52618 .38175 L .67 .731 .896 r
F
.52626 .38194 m .52646 .38169 L .52646 .38169 L F
.52626 .38199 m .52651 .38168 L .52651 .38168 L F
.52602 .38218 m .5265 .3816 L .5265 .3816 L F
.52625 .38193 m .52671 .38137 L .52674 .38135 L F
.52571 .38257 m .52624 .38193 L .52625 .38193 L F
.52624 .38193 m .52671 .38137 L .52625 .38193 L F
.52552 .38177 m .52616 .38182 L .52551 .38177 L F
.52695 .3813 m .52718 .38107 L .52718 .38107 L F
.52623 .38191 m .52622 .3819 L .5265 .38159 L F
.52634 .38172 m .52629 .3818 L .52657 .38185 L F
.52611 .38176 m .52615 .38181 L .52646 .38183 L F
.52572 .38259 m .5267 .38141 L .5267 .38142 L F
.52611 .38176 m .52646 .38183 L .5273 .38189 L F
.52628 .38166 m .52629 .38198 L .52618 .38172 L F
.52559 .38182 m .52622 .3819 L .52554 .38178 L F
.52627 .38196 m .52624 .38192 L .52595 .38179 L F
.52616 .38182 m .52732 .38191 L .52616 .38182 L F
.52659 .38186 m .52654 .3817 L .52661 .38186 L F
.52686 .38134 m .52629 .38198 L p .52684 .3813 L F P
0 g
s
.52627 .38196 m .52683 .38129 L .52627 .38196 L .67 .731 .896 r
F
.52627 .38196 m .52683 .38129 L .52627 .38196 L F
.52653 .38168 m .52634 .38172 L .5266 .38186 L F
.52664 .38187 m .5266 .38186 L .52666 .38189 L F
.52653 .38168 m .5266 .38186 L .52664 .38187 L F
.52609 .38174 m .52611 .38176 L .5273 .38189 L F
.5266 .38186 m .52698 .38209 L .52703 .38209 L F
.52634 .38172 m .52657 .38185 L .5266 .38186 L F
.52648 .38192 m .52737 .382 L .52734 .38195 L F
.52657 .38185 m .52698 .38209 L .5266 .38186 L F
.52639 .38195 m .52725 .38199 L .52648 .38192 L F
.53016 .38309 m .52694 .38184 L .52955 .38301 L F
.52797 .38249 m .52814 .38248 L .53278 .3841 L F
.53017 .3831 m .52955 .38301 L .53033 .38337 L F
.53016 .38309 m .52955 .38301 L .53017 .3831 L F
.52661 .38186 m .52657 .38185 L .52616 .38182 L F
.52657 .38185 m .52629 .3818 L .52698 .38209 L F
.52605 .38179 m .52611 .38176 L .52608 .38176 L F
.52573 .3826 m .52609 .38181 L .52621 .38155 L F
.52599 .38203 m .52612 .38175 L .5264 .38133 L F
.52605 .38177 m .52626 .38179 L .52611 .38176 L F
.52629 .38198 m .52611 .38176 L .52616 .38165 L F
.52725 .38199 m .52722 .38198 L .52648 .38192 L F
.52636 .38196 m .52738 .38202 L .52729 .382 L F
.52704 .38195 m .52686 .38191 L .52728 .38222 L F
.52703 .38168 m .52705 .38172 L .53113 .38219 L F
.52877 .38202 m .53088 .38222 L .52889 .382 L F
.52796 .38194 m .52793 .38197 L .53088 .38222 L F
.53067 .38212 m .52738 .38202 L p .5282 .38174 L F P
0 g
s
.52738 .38202 m .52741 .38184 L .5282 .38174 L .67 .731 .896 r
F
.52663 .38192 m .5267 .38188 L .52716 .38206 L F
.52605 .38177 m .52661 .38186 L .52663 .38192 L F
.52661 .38186 m .5267 .38188 L .52663 .38192 L F
.52647 .38169 m .52682 .38127 L .52682 .38127 L F
.52598 .38234 m .52683 .3813 L .52684 .3813 L F
.52685 .3814 m .52676 .38139 L .52661 .38144 L F
.5267 .38142 m .52682 .38127 L .52682 .38127 L F
.5267 .38141 m .52682 .38127 L .5267 .38142 L F
.52647 .38153 m .52646 .38148 L .52707 .38077 L F
.52648 .38135 m .52739 .3807 L .52646 .3813 L F
.52671 .38137 m .52681 .38124 L .52681 .38125 L F
.5267 .38137 m .52681 .38124 L .52671 .38137 L F
.52647 .38169 m .52682 .38127 L .52647 .38169 L F
.52675 .38135 m .52674 .38135 L .52682 .38127 L F
.52653 .38167 m .52652 .38166 L .52683 .3813 L F
.52627 .38196 m .52683 .38129 L .52683 .3813 L F
.5268 .38123 m .5258 .38239 L .52676 .38116 L F
.52698 .38203 m .52716 .38206 L .52715 .38208 L F
.52605 .38177 m .52695 .382 L .52698 .38203 L F
.52695 .382 m .52716 .38206 L .52698 .38203 L F
.52552 .37133 m .52449 .37138 L p .52558 .38039 L F P
0 g
s
.52498 .38123 m .52611 .38176 L .52606 .3817 L .67 .731 .896 r
F
.52608 .38176 m .52611 .38176 L .52609 .38174 L F
.52603 .38194 m .52599 .38183 L .52608 .38182 L F
.52588 .38189 m .52623 .38191 L .52589 .38189 L F
.52583 .38122 m .52621 .38155 L .52635 .38122 L F
.52627 .3814 m .5262 .38155 L .52606 .38122 L F
.5262 .38155 m .52616 .38165 L .52606 .38122 L F
.52606 .38122 m .52616 .38165 L .52596 .38114 L F
.52612 .38175 m .52611 .38176 L .5263 .38134 L F
.52578 .38195 m .52629 .38198 L .52575 .38193 L F
.52598 .38234 m .52596 .38234 L .52605 .38223 L F
.52599 .38204 m .52592 .38187 L .52597 .38184 L F
.52572 .38263 m .52626 .38195 L .52627 .38196 L F
.52604 .3827 m .52596 .38211 L .52599 .38204 L F
.52596 .38211 m .52592 .38187 L .52599 .38204 L F
.52582 .38242 m .5265 .3816 L .5265 .3816 L F
.52498 .38342 m .52582 .38241 L .52582 .38242 L F
.52582 .38241 m .5265 .3816 L .52582 .38242 L F
.52611 .38176 m .52564 .38243 L .52607 .38171 L F
.52611 .38176 m .52607 .38171 L .5263 .38134 L F
.52542 .38168 m .52605 .38179 L .52608 .38176 L F
.52604 .38177 m .52611 .38176 L .52609 .38173 L F
.52616 .38182 m .52616 .38182 L .52551 .38177 L F
.52616 .38183 m .52616 .38182 L .52552 .38177 L F
.52596 .38173 m .52608 .38176 L .52609 .38174 L F
.5263 .38134 m .52615 .38158 L .52605 .38162 L F
.5254 .38228 m .52526 .38255 L .52533 .38235 L F
.52568 .38188 m .52588 .38189 L .52589 .38189 L F
.5263 .38134 m .52545 .38233 L .5254 .38228 L F
.52545 .38233 m .52526 .38255 L .5254 .38228 L F
.52615 .38158 m .52564 .38243 L .52605 .38162 L F
.52616 .38183 m .52599 .38203 L .52613 .38179 L F
.5259 .3818 m .52627 .38196 L .52595 .38179 L F
.5251 .38189 m .52639 .38195 L .52508 .38187 L F
.52603 .38195 m .526 .38201 L .52599 .38183 L F
.52629 .38198 m .52608 .38182 L .52611 .38176 L F
.52592 .3821 m .5259 .38207 L .52587 .38147 L F
.52587 .38181 m .52586 .38179 L .52621 .38188 L F
.53016 .38168 m .52719 .38165 L .52897 .382 L F
.52651 .38168 m .52652 .38166 L .52651 .38168 L F
.52627 .38167 m .52613 .38175 L .52646 .38178 L F
.52623 .38191 m .5265 .38159 L .5265 .38159 L F
.52633 .38168 m .52646 .38178 L .52857 .38197 L F
.52633 .38168 m .52857 .38197 L .52857 .38195 L F
.52616 .38183 m .52628 .38153 L .52631 .38152 L F
.52631 .38134 m .52629 .38198 L p .52627 .38133 L F P
0 g
s
.52624 .38192 m .5267 .38137 L .52671 .38137 L .67 .731 .896 r
F
.52629 .38198 m .5263 .38165 L p .52628 .38197 L F P
0 g
s
.52629 .38198 m .52626 .38199 L .52698 .38113 L .67 .731 .896 r
F
.52698 .38113 m .52698 .38113 L .52711 .38097 L F
.52629 .38198 m .52698 .38113 L .52698 .38113 L F
.5263 .38165 m .52631 .38134 L p .52629 .38165 L F P
0 g
s
.5262 .38156 m .52631 .38152 L .52622 .38155 L .67 .731 .896 r
F
.52619 .38159 m .52631 .38152 L .5262 .38156 L F
.52666 .38095 m .52612 .38175 L .5263 .38134 L F
.52641 .38134 m .5264 .38134 L .5264 .38133 L F
.52631 .38152 m .52635 .38151 L .52668 .38115 L F
.52631 .38124 m .52666 .38116 L .52664 .38116 L F
.52646 .38148 m .5264 .38133 L .52666 .38095 L F
.5263 .38134 m .52641 .38135 L .52694 .38085 L F
.52631 .38115 m .52631 .38134 L p .52626 .38109 L F P
0 g
s
.52631 .38134 m .52631 .38131 L p .5263 .38134 L .67 .731 .896 r
F P
0 g
s
.52629 .38165 m .52631 .38134 L .5263 .38134 L .67 .731 .896 r
F
.52622 .38155 m .52631 .38152 L .52643 .38139 L F
.52631 .38152 m .52628 .38153 L .5264 .38133 L F
.5268 .38124 m .5268 .38123 L .52757 .38035 L F
.5271 .38093 m .5271 .38093 L .52719 .38083 L F
.52744 .38226 m .52814 .38248 L .52745 .38226 L F
.52746 .38232 m .52814 .38248 L .52797 .38249 L F
.52745 .38227 m .52814 .38248 L .52746 .38232 L F
.53161 .38389 m .52629 .38198 L p .53278 .3841 L F P
0 g
s
.52729 .382 m .52728 .38222 L .53879 .38717 L .67 .731 .896 r
F
.52715 .38216 m .52738 .38214 L .52907 .38281 L F
.52736 .38236 m .52736 .38236 L .52743 .38239 L F
.52731 .38234 m .52753 .3825 L .52743 .38239 L F
.52712 .38231 m .52753 .3825 L .52731 .38234 L F
.52732 .38234 m .52732 .38234 L .52732 .38234 L F
.52732 .38234 m .52743 .38239 L .52734 .38228 L F
.52739 .38235 m .52743 .38239 L .52767 .38249 L F
.52739 .38235 m .52767 .38249 L .53981 .38761 L F
.52728 .38222 m .52739 .38235 L .53981 .38761 L F
.52679 .38219 m .52753 .3825 L p .52679 .38218 L F P
0 g
s
.52731 .38241 m .5267 .38215 L p .52907 .38281 L .67 .731 .896 r
F P
0 g
s
.52684 .38212 m .52681 .38213 L .52736 .38236 L .67 .731 .896 r
F
.52616 .38182 m .52736 .38236 L .52736 .38236 L F
.52684 .38212 m .52732 .38234 L .52688 .38211 L F
.52623 .3819 m .52745 .38227 L .52746 .38232 L F
.52627 .38195 m .52669 .38197 L .52626 .38195 L F
.52599 .38178 m .52712 .38231 L .52731 .38234 L F
.52621 .38189 m .52814 .38248 L .52623 .3819 L F
.52698 .38209 m .52732 .38234 L .52728 .38222 L F
.52688 .38211 m .52732 .38234 L .52698 .38209 L F
.52704 .38213 m .52744 .38226 L .52705 .38214 L F
.52732 .38234 m .52732 .38234 L .52728 .38222 L F
.52732 .38234 m .52734 .38228 L .52728 .38222 L F
.5267 .38215 m .52665 .382 L .52907 .38281 L F
.53981 .38761 m .52731 .38241 L p .52907 .38281 L F P
0 g
s
.52893 .38324 m .53923 .38817 L p .52833 .38258 L .67 .731 .896 r
F P
0 g
s
.52635 .38153 m .52708 .38094 L .52621 .38155 L .67 .731 .896 r
F
.52708 .38094 m .52708 .38092 L .52621 .38155 L F
.5262 .38158 m .52621 .38155 L .52614 .38159 L F
.52628 .38199 m .52629 .38198 L .52628 .38197 L F
.52605 .38224 m .52625 .38199 L .52626 .38199 L F
.52627 .38196 m .52627 .38196 L .52596 .38234 L F
.52596 .38234 m .52627 .38196 L .52627 .38196 L F
.52582 .38238 m .5268 .38124 L .52582 .38238 L F
.52629 .38198 m .52598 .38234 L p .52626 .38199 L F P
0 g
s
.52628 .3823 m .52619 .38235 L .52608 .38182 L .67 .731 .896 r
F
.52615 .38237 m .52603 .38195 L .52619 .38235 L F
.52508 .38187 m .52623 .38191 L .52506 .38186 L F
.52603 .38195 m .52599 .38183 L .52603 .38194 L F
.52603 .38195 m .52603 .38194 L .52619 .38235 L F
.52572 .38259 m .52577 .38253 L .52572 .38259 L F
.52577 .38253 m .52682 .38127 L .52577 .38253 L F
.52577 .38253 m .52577 .38253 L .52572 .38259 L F
.5261 .38219 m .52627 .38229 L .52628 .38199 L F
.52615 .38205 m .52628 .38199 L .52629 .38164 L F
.5261 .38219 m .52628 .38199 L .52615 .38205 L F
.52589 .3818 m .5263 .38198 L .5259 .3818 L F
.5263 .38198 m .52679 .38219 L .5263 .38198 L F
.5263 .38198 m .5263 .38198 L .5259 .3818 L F
.52703 .38209 m .52698 .38209 L .52728 .38222 L F
.52668 .38196 m .52696 .3821 L .52698 .38209 L F
.52618 .38175 m .52696 .3821 L .52668 .38196 L F
.52629 .38198 m .52738 .38202 L p .52636 .38196 L F P
0 g
s
.52618 .38175 m .52688 .38211 L .52696 .3821 L .67 .731 .896 r
F
.52617 .38183 m .52715 .38208 L .52711 .38215 L F
.5282 .38174 m .52675 .38179 L .52703 .38168 L F
.52719 .38165 m .52741 .38181 L .52897 .382 L F
.52728 .38185 m .5273 .38189 L .52897 .382 L F
.52732 .38191 m .52805 .38197 L .52732 .38191 L F
.52974 .38195 m .52717 .38197 L p .52918 .38167 L F P
0 g
s
.52623 .38191 m .52869 .38201 L .52622 .3819 L .67 .731 .896 r
F
.52869 .38201 m .52893 .38201 L .52869 .38201 L F
.52869 .38201 m .52869 .38201 L .52622 .3819 L F
.52449 .37138 m .52347 .37148 L p .52526 .37967 L F P
0 g
s
.52581 .38166 m .5262 .38187 L .52616 .38182 L .67 .731 .896 r
F
.52553 .38154 m .52581 .38168 L .52581 .38166 L F
.52539 .38168 m .52608 .38176 L .52596 .38173 L F
.52581 .38168 m .5262 .38187 L .52581 .38166 L F
.52526 .38156 m .52577 .38165 L .52581 .38174 L F
.52548 .38162 m .52554 .38165 L .52554 .38165 L F
.52513 .38142 m .52595 .38179 L .52599 .38178 L F
.52505 .38139 m .52513 .38142 L .52513 .38142 L F
.52526 .38156 m .52515 .38144 L .52577 .38165 L F
.52513 .38142 m .52595 .38179 L .52513 .38142 L F
.52553 .38154 m .52551 .38158 L .5262 .38187 L F
.52601 .38164 m .52547 .38163 L .52609 .38174 L F
.52604 .38168 m .52587 .3817 L .52587 .3817 L F
.52583 .3817 m .52596 .38173 L .52609 .38174 L F
.5259 .3818 m .5255 .38159 L .52549 .3816 L F
.52547 .38163 m .52582 .3817 L .52583 .3817 L F
.52582 .3817 m .52596 .38173 L .52583 .3817 L F
.51326 .37575 m .51389 .37521 L p .52476 .38077 L F P
0 g
s
.52515 .3829 m .52557 .38229 L .52558 .38229 L .67 .731 .896 r
F
.52536 .38248 m .52543 .3825 L .52575 .38215 L F
.52605 .38162 m .52564 .38243 L .52545 .38249 L F
.52578 .38195 m .52578 .38195 L .52578 .38195 L F
.52568 .38188 m .52623 .38191 L .52568 .38188 L F
.52536 .38248 m .52575 .38215 L .52567 .38217 L F
.52605 .38162 m .52545 .38249 L .52541 .38238 L F
.5259 .3818 m .52595 .38179 L .5255 .38159 L F
.52584 .38181 m .52586 .38186 L .52605 .38168 L F
.52628 .38166 m .52618 .38172 L .52616 .38165 L F
.52601 .38164 m .52613 .38175 L .52627 .38167 L F
.52628 .38164 m .52604 .38168 L .52601 .38164 L F
.52641 .3817 m .52641 .3817 L .5265 .3816 L F
.52716 .38165 m .52601 .38164 L .52724 .38179 L F
.52632 .3809 m .52631 .38098 L p .52625 .38094 L F P
0 g
s
.5263 .38098 m .52632 .3809 L .52631 .38089 L .67 .731 .896 r
F
.52631 .38134 m .52627 .38133 L .52626 .38109 L F
.52628 .38199 m .52631 .38098 L .5263 .38098 L F
.52631 .38098 m .52632 .3809 L .5263 .38098 L F
.52539 .38168 m .52551 .38177 L .52588 .38179 L F
.52492 .38174 m .52559 .38182 L .52554 .38178 L F
.52554 .38178 m .52552 .38177 L .52491 .38173 L F
.52357 .38182 m .5251 .38189 L .52355 .38181 L F
.52317 .38161 m .52506 .38186 L .52492 .38174 L F
.52484 .38189 m .52487 .38188 L .52251 .38177 L F
.5256 .3818 m .52347 .38187 L .52575 .38174 L F
.52347 .38187 m .51766 .38207 L .52341 .38183 L F
.52326 .38165 m .52397 .38182 L .52506 .38186 L F
.52347 .38187 m .52341 .38183 L .52575 .38174 L F
.52628 .3823 m .52627 .38278 L p .52619 .38235 L F P
0 g
s
.52627 .38278 m .52618 .38275 L .52623 .38266 L .67 .731 .896 r
F
.52618 .38275 m .52604 .3827 L .52623 .38266 L F
.52627 .38278 m .52615 .38237 L .52619 .38235 L F
.52616 .38306 m .52621 .38267 L p .52566 .38351 L F P
0 g
s
.52612 .38431 m .52593 .38267 L .52604 .3827 L .67 .731 .896 r
F
.52581 .38354 m .52623 .38361 L .52627 .38229 L F
.52627 .38278 m .52613 .38238 L .52615 .38237 L F
.52572 .38259 m .52674 .38135 L .52572 .38259 L F
.52613 .38238 m .526 .38201 L .52615 .38237 L F
.52623 .38266 m .52604 .3827 L .526 .38201 L F
.52581 .38354 m .52627 .38229 L .5261 .38219 L F
.52618 .38584 m .52621 .38474 L .52618 .38584 L F
.52621 .38474 m .52629 .38198 L .52621 .38473 L F
.52621 .38474 m .52621 .38473 L .52618 .38584 L F
.52632 .38164 m .52627 .38165 L .52628 .38164 L F
.52627 .38165 m .52604 .38168 L .52628 .38164 L F
.52601 .38164 m .52583 .38171 L .526 .38164 L F
.52604 .38168 m .52583 .38171 L .52601 .38164 L F
.52587 .3817 m .52584 .38171 L .52587 .3817 L F
.52587 .3817 m .52584 .38171 L .52583 .38171 L F
.52601 .38164 m .52586 .38179 L .52603 .38167 L F
.52569 .38168 m .52487 .38184 L .5253 .38161 L F
.52547 .38163 m .52479 .38162 L .52596 .38173 L F
.52554 .38165 m .52589 .3818 L .52554 .38165 L F
.52548 .38162 m .52589 .3818 L .52548 .38162 L F
.52557 .38166 m .52547 .38164 L .52528 .38159 L F
.52547 .38163 m .52547 .38164 L .52543 .38163 L F
.52554 .38165 m .5259 .3818 L .52562 .38166 L F
.52551 .38177 m .52603 .38181 L .52604 .3818 L F
.52587 .38181 m .52543 .38162 L p .52583 .38172 L F P
0 g
s
.52548 .38162 m .52587 .38181 L .52589 .3818 L .67 .731 .896 r
F
.525 .38142 m .52547 .38163 L .52548 .38162 L F
.52547 .38163 m .52587 .38181 L .52548 .38162 L F
.52547 .38164 m .51766 .38207 L .52543 .38163 L F
.52584 .38171 m .52541 .38173 L .52547 .38164 L F
.52539 .38168 m .52542 .38168 L .52542 .38168 L F
.52479 .38162 m .52551 .38177 L .52539 .38168 L F
.52251 .38177 m .52357 .38182 L .52355 .38181 L F
.52541 .38173 m .51766 .38207 L .52547 .38164 L F
.525 .38143 m .52587 .38181 L .525 .38142 L F
.52586 .38179 m .52584 .38181 L .52587 .38179 L F
.52586 .38179 m .52587 .38179 L .52603 .38167 L F
.52584 .38171 m .52584 .38171 L .52604 .38168 L F
.52604 .38168 m .52584 .38171 L .52604 .38168 L F
.52593 .38141 m .52592 .38116 L .52594 .38141 L F
.52586 .3812 m .52587 .38138 L .52583 .38122 L F
.52587 .38138 m .52585 .38139 L .52583 .38122 L F
.52592 .38116 m .52592 .38137 L .52586 .3812 L F
.52592 .38137 m .52587 .38138 L .52586 .3812 L F
.52578 .38117 m .52578 .38136 L .52623 .38129 L F
.526 .38164 m .52547 .38164 L .526 .38164 L F
.52583 .38171 m .52574 .38149 L .52596 .38158 L F
.52593 .38141 m .52594 .38141 L .52599 .38203 L F
.52583 .38171 m .52596 .38158 L .52608 .38172 L F
.52586 .38179 m .52583 .38172 L .526 .38177 L F
.526 .38164 m .52583 .38171 L .52547 .38164 L F
.52578 .38136 m .52579 .38198 L .52601 .38164 L F
.52605 .38169 m .52598 .3816 L .52597 .38143 L F
.52602 .38146 m .52597 .38143 L .52596 .38114 L F
.52592 .38137 m .52592 .38153 L .52587 .38138 L F
.52592 .38153 m .52587 .38147 L .52587 .38138 L F
.52578 .38136 m .52601 .38164 L .52623 .38129 L F
.52604 .38167 m .52605 .38168 L .52614 .38159 L F
.52612 .3816 m .52614 .38159 L .52622 .38152 L F
.52632 .38164 m .52604 .38168 L .52604 .38168 L F
.5263 .38134 m .52601 .38164 L .52622 .38152 L F
.52601 .38164 m .52603 .38167 L .52622 .38152 L F
.526 .38164 m .526 .38164 L .52601 .38164 L F
.52601 .38164 m .52601 .38164 L .52632 .38164 L F
.526 .38164 m .52601 .38164 L .52601 .38164 L F
.52627 .3814 m .52628 .38166 L .52616 .38165 L F
.52628 .38164 m .526 .38164 L .52628 .38164 L F
.52639 .38168 m .52584 .38171 L .52632 .38164 L F
.52621 .38169 m .52627 .3814 L .52615 .38173 L F
.5263 .38134 m .52622 .38152 L .52631 .38134 L F
.52627 .3814 m .5263 .38131 L .52623 .38151 L F
.52627 .3814 m .52623 .38151 L .52615 .38173 L F
.52605 .38168 m .52618 .38161 L .52614 .38159 L F
.52621 .38169 m .52629 .38164 L .5263 .38131 L F
.52618 .38161 m .52635 .38153 L .5262 .38158 L F
.52618 .38161 m .5262 .38158 L .52614 .38159 L F
.5254 .38228 m .52609 .38173 L .52605 .38168 L F
.52614 .38169 m .52618 .38161 L .52605 .38168 L F
.52601 .38164 m .52613 .38172 L .52623 .38129 L F
.52621 .38188 m .52629 .38164 L .52618 .38185 L F
.5258 .38172 m .52582 .38171 L .52606 .3817 L F
.52606 .38171 m .52606 .3817 L .52716 .38165 L F
.5258 .38172 m .52606 .3817 L .52606 .38171 L F
.526 .38177 m .52614 .3818 L .52617 .38183 L F
.52587 .38181 m .52621 .38188 L .52621 .38189 L F
.52588 .38227 m .52646 .38148 L .52588 .38229 L F
.52512 .38292 m .5246 .38366 L .52511 .38291 L F
.51914 .39141 m .51824 .39109 L p .5255 .38223 L F P
0 g
s
.52462 .38367 m .52588 .38186 L .52589 .38186 L .67 .731 .896 r
F
.51983 .39047 m .52462 .38367 L .52462 .38367 L F
.52462 .38367 m .52588 .38186 L .52462 .38367 L F
.52209 .38201 m .52375 .38201 L .52373 .382 L F
.52373 .382 m .52373 .382 L .51755 .38205 L F
.52491 .38173 m .52552 .38177 L .52551 .38177 L F
.52539 .38175 m .51766 .38207 L .5254 .38174 L F
.51766 .38207 m .51028 .38215 L p .52005 .38157 L F P
0 g
s
.51176 .3821 m .51779 .38204 L .51779 .38204 L .67 .731 .896 r
F
.51779 .38204 m .52507 .38198 L .51779 .38204 L F
.51779 .38204 m .52507 .38198 L .52507 .38198 L F
.52542 .38168 m .52605 .38179 L .52542 .38168 L F
.52492 .38174 m .52554 .38178 L .52491 .38173 L F
.5258 .38172 m .5245 .38177 L .52582 .38171 L F
.52259 .3818 m .52484 .38189 L .52251 .38177 L F
.5245 .38177 m .51766 .38207 L .52447 .38177 L F
.5245 .38177 m .52447 .38177 L .52582 .38171 L F
.52323 .38602 m .52562 .38255 L .52569 .38252 L F
.52509 .38329 m .52506 .38327 L .52641 .3817 L F
.52704 .38234 m .52893 .38324 L p .52712 .38211 L F P
0 g
s
.52704 .38234 m .52692 .38228 L p .52844 .38265 L .67 .731 .896 r
F P
0 g
s
.52584 .38181 m .52605 .38168 L .52604 .38167 L .67 .731 .896 r
F
.52596 .38211 m .52593 .38218 L .52592 .38187 L F
.52599 .38203 m .52564 .38243 L .52612 .38175 L F
.5261 .38176 m .52611 .38176 L .52611 .38176 L F
.52583 .38172 m .52603 .38177 L .526 .38177 L F
.5261 .38176 m .52611 .38176 L .52607 .38177 L F
.52618 .38185 m .52629 .38164 L .52621 .38169 L F
.52614 .3818 m .52621 .38169 L .52615 .38173 L F
.52583 .38171 m .52611 .38176 L .52605 .38177 L F
.5256 .3818 m .52575 .38174 L .52617 .38172 L F
.52695 .38113 m .52719 .38083 L .52716 .38088 L F
.52569 .38262 m .52693 .38114 L .52695 .38113 L F
.52693 .38114 m .52719 .38083 L .52695 .38113 L F
.5256 .3818 m .52617 .38172 L .52612 .38176 L F
.52577 .38133 m .52578 .38133 L .52577 .38044 L F
.52577 .38044 m .52577 .38044 L .52577 .38039 L F
.52577 .38133 m .52577 .38044 L .52577 .38044 L F
.52622 .3819 m .52683 .38193 L .52682 .38192 L F
.52683 .38193 m .52734 .38195 L .52682 .38192 L F
.52682 .38192 m .52734 .38195 L .52733 .38194 L F
.52716 .38206 m .5267 .38188 L .5272 .38198 L F
.52614 .3818 m .52738 .38214 L .52617 .38183 L F
.52616 .38182 m .52681 .38213 L .52684 .38212 L F
.52621 .38188 m .52617 .38183 L .52665 .382 L F
.52669 .38197 m .52685 .38197 L .52573 .38192 L F
.52623 .38191 m .52639 .38195 L .52648 .38192 L F
.52616 .38182 m .5262 .38187 L .52681 .38213 L F
.52621 .38189 m .52621 .38188 L .52665 .382 L F
.52732 .38191 m .52732 .38191 L .52616 .38182 L F
.52627 .38195 m .52629 .38198 L .52636 .38196 L F
.52661 .38186 m .52694 .38193 L .52805 .38197 L F
.52694 .38184 m .52657 .3817 L .52686 .38191 L F
.526 .38242 m .52602 .38244 L .52615 .38173 L F
.52627 .38195 m .52626 .38195 L .52573 .38192 L F
.52619 .38235 m .52603 .38194 L .52608 .38182 L F
.52626 .38194 m .52639 .38195 L .52623 .38191 L F
.52608 .38185 m .52753 .3825 L .5262 .38188 L F
.52608 .38185 m .5262 .38188 L .52599 .38178 L F
.52595 .38179 m .52608 .38185 L .52599 .38178 L F
.52586 .38179 m .52617 .38183 L .52621 .38188 L F
.52602 .38245 m .52593 .38141 L .52602 .38244 L F
.52569 .38256 m .52641 .3817 L .5257 .38256 L F
.52604 .3822 m .526 .38242 L .52605 .38219 L F
.52615 .38237 m .52606 .38215 L .52607 .3821 L F
.52606 .38215 m .526 .38201 L .52607 .3821 L F
.52607 .3821 m .526 .38201 L .52603 .38195 L F
.52604 .3822 m .52605 .38219 L .52615 .38173 L F
.52627 .38196 m .52753 .3825 L .52624 .38192 L F
.52671 .38215 m .52679 .38219 L .52679 .38218 L F
.5259 .3818 m .5267 .38215 L .52671 .38215 L F
.5267 .38215 m .52679 .38219 L .52671 .38215 L F
.5258 .38244 m .5258 .38249 L .52611 .38176 L F
.52506 .38327 m .52622 .3819 L .52623 .38191 L F
.5244 .38398 m .52461 .38367 L .5244 .38398 L F
.52461 .38367 m .52592 .38181 L .52462 .38367 L F
.52461 .38367 m .52462 .38367 L .5244 .38398 L F
.52506 .38326 m .52622 .3819 L .52506 .38327 L F
.5258 .38249 m .52587 .3825 L .52611 .38176 L F
.52629 .38198 m .52679 .38219 L p .5263 .38198 L F P
0 g
s
.5267 .38215 m .52629 .38198 L p .52665 .382 L .67 .731 .896 r
F P
0 g
s
.52587 .38181 m .52629 .38198 L p .52589 .3818 L .67 .731 .896 r
F P
0 g
s
.52589 .3818 m .52629 .38198 L .5263 .38198 L .67 .731 .896 r
F
.52629 .38198 m .52587 .38181 L p .52621 .38189 L F P
0 g
s
.52629 .38198 m .52621 .38189 L .52665 .382 L .67 .731 .896 r
F
.52642 .38185 m .52662 .38183 L .5264 .38188 L F
.52642 .38185 m .5264 .38188 L .52623 .38191 L F
.52621 .38188 m .52642 .38185 L .52623 .38191 L F
.52629 .38198 m .52658 .38169 L p .52627 .38195 L F P
0 g
s
.52658 .38169 m .52696 .38132 L p .52658 .38167 L .67 .731 .896 r
F P
0 g
s
.52609 .38174 m .5273 .38189 L .52728 .38185 L .67 .731 .896 r
F
.52662 .38183 m .52744 .38173 L .5267 .38187 L F
.52604 .3818 m .52805 .38197 L .52814 .38195 L F
.5267 .38188 m .52635 .38173 L .52717 .38196 L F
.52615 .38173 m .52623 .38151 L .52617 .38164 L F
.52614 .38169 m .52635 .38153 L .52618 .38161 L F
.52627 .38167 m .52646 .38178 L .52633 .38168 L F
.52601 .38164 m .52609 .38174 L .52613 .38175 L F
.52216 .38569 m .52323 .38472 L .52345 .38446 L F
.52439 .38363 m .52503 .38305 L .52503 .38294 L F
.52412 .38391 m .52503 .38305 L .52439 .38363 L F
.52412 .38391 m .52504 .38339 L .52503 .38305 L F
.52611 .38176 m .52604 .38215 L .52614 .38179 L F
.52604 .38215 m .52604 .3822 L .52605 .38215 L F
.52604 .38215 m .52605 .38215 L .52614 .38179 L F
.52575 .38174 m .5258 .38172 L .52713 .38166 L F
.5246 .38366 m .51914 .39141 L .52456 .38364 L F
.52515 .3829 m .51914 .39141 L .52514 .3829 L F
.51824 .39109 m .52407 .38427 L p .52412 .38391 L F P
0 g
s
.51824 .39109 m .52404 .38453 L p .52406 .38439 L .67 .731 .896 r
F P
0 g
s
.52408 .38465 m .52519 .38297 L .52519 .38297 L .67 .731 .896 r
F
.52404 .38453 m .52504 .38339 L p .52412 .38391 L F P
0 g
s
.52567 .38254 m .51824 .39109 L .52517 .38298 L .67 .731 .896 r
F
.52567 .38254 m .52517 .38298 L .52564 .38243 L F
.5258 .38239 m .52567 .38254 L .52564 .38243 L F
.52468 .38356 m .51824 .39109 L .5238 .38396 L F
.52294 .38499 m .52576 .38245 L .52292 .385 L F
.52599 .38203 m .52599 .38203 L .52602 .38244 L F
.52604 .3827 m .52593 .38267 L .52593 .38218 L F
.5257 .38257 m .5265 .3816 L .5257 .38257 L F
.52604 .3827 m .52593 .38218 L .52596 .38211 L F
.5258 .38269 m .52594 .38277 L .52598 .38252 L F
.52587 .3825 m .52598 .38252 L .52611 .38176 L F
.5258 .38269 m .52598 .38252 L .52587 .3825 L F
.52489 .38346 m .52582 .38238 L .52582 .38238 L F
.5252 .38559 m .52519 .38561 L .52581 .38203 L F
.52197 .38622 m .52578 .38249 L p .52216 .38569 L F P
0 g
s
.52549 .38277 m .52546 .38278 L .52576 .38248 L .67 .731 .896 r
F
.52576 .38245 m .52629 .38198 L .52573 .38245 L F
.52581 .38241 m .52579 .38245 L .52602 .38222 L F
.5258 .38239 m .52588 .38227 L .52588 .38229 L F
.52596 .38244 m .52597 .38251 L .52578 .38222 L F
.526 .38242 m .52581 .38354 L .52602 .38244 L F
.52597 .38251 m .52629 .38442 L .52584 .38247 L F
.52579 .38245 m .52579 .38246 L .52602 .38222 L F
.52579 .38246 m .5258 .38246 L .52602 .38222 L F
.52578 .38249 m .52629 .38198 L p .52602 .38222 L F P
0 g
s
.5258 .38246 m .5258 .38245 L .52596 .3823 L .67 .731 .896 r
F
.52597 .38251 m .52584 .38247 L .52578 .38222 L F
.52579 .38246 m .52578 .38249 L .5258 .38246 L F
.51218 .37691 m .51269 .37632 L p .52062 .37939 L F P
0 g
s
.52558 .38131 m .52033 .37959 L .52062 .37939 L .67 .731 .896 r
F
.52033 .37959 m .51218 .37691 L .52062 .37939 L F
.52309 .38044 m .52314 .38047 L .52315 .38046 L F
.52309 .38044 m .52315 .38046 L .52315 .38046 L F
.52247 .38016 m .52309 .38044 L .52315 .38046 L F
.52558 .38131 m .52138 .37968 L .52526 .38136 L F
.52574 .38149 m .52124 .37971 L .52565 .38129 L F
.52138 .37968 m .51699 .37798 L .52089 .37963 L F
.52124 .37971 m .51269 .37632 L .52138 .37965 L F
.52138 .37968 m .52248 .38018 L .52247 .38016 L F
.52124 .37971 m .52138 .37965 L .52565 .38129 L F
.52496 .38105 m .52475 .38095 L .52501 .38111 L F
.52496 .38105 m .52501 .38111 L .52534 .38132 L F
.52552 .3813 m .52496 .38105 L .52534 .38132 L F
.52576 .38245 m .52629 .38198 L .52576 .38245 L F
.52588 .38191 m .52587 .38191 L .52578 .38137 L F
.52618 .38185 m .52621 .38169 L .52614 .3818 L F
.52611 .38176 m .5267 .38188 L .52613 .38178 L F
.52611 .38176 m .52613 .38178 L .52605 .38177 L F
.52628 .38197 m .5263 .38165 L .52629 .38165 L F
.52628 .38199 m .52628 .38197 L .52628 .38197 L F
.52628 .38197 m .5263 .38165 L .52628 .38197 L F
.5261 .38176 m .52607 .38177 L .52604 .38177 L F
.52619 .38178 m .5256 .3818 L .52611 .38176 L F
.52564 .38166 m .5253 .38167 L .52605 .38179 L F
.52635 .38173 m .52574 .38149 L .52644 .38172 L F
.52613 .38172 m .52615 .38173 L .52617 .38164 L F
.52612 .38176 m .52617 .38172 L .52707 .38168 L F
.52611 .38176 m .52614 .38179 L .52615 .38173 L F
.52628 .38164 m .52628 .38164 L .52632 .38164 L F
.52632 .38164 m .52628 .38164 L .52632 .38164 L F
.52681 .38125 m .5271 .3809 L .52682 .38127 L F
.52681 .38125 m .52681 .38124 L .5271 .3809 L F
.5268 .38124 m .5271 .3809 L .52681 .38124 L F
.52713 .38104 m .52711 .38097 L .52758 .38041 L F
.52683 .38129 m .52683 .38128 L .52757 .38039 L F
.52609 .38173 m .52618 .38185 L .52739 .3807 L F
.52608 .38172 m .52635 .38173 L .52611 .38176 L F
.52609 .38173 m .52614 .38169 L .52605 .38168 L F
.52584 .38181 m .52614 .38159 L .52612 .3816 L F
.52611 .38176 m .52615 .38173 L .52601 .38164 L F
.52608 .38172 m .52596 .38158 L .52635 .38173 L F
.52603 .38177 m .52614 .3818 L .526 .38177 L F
.52586 .38179 m .526 .38177 L .52617 .38183 L F
.52532 .38187 m .52568 .38188 L .52568 .38188 L F
.52512 .38191 m .52575 .38193 L .5251 .38189 L F
.52575 .38193 m .52573 .38192 L .5251 .38189 L F
.5251 .38189 m .52639 .38195 L .5251 .38189 L F
.52531 .38187 m .52623 .38191 L .52532 .38187 L F
.52524 .38199 m .52536 .3818 L .52612 .38178 L F
.5262 .38187 m .52612 .38178 L .52725 .38174 L F
.52559 .38241 m .52621 .38201 L .52591 .38211 L F
.52572 .38244 m .52621 .38201 L .52559 .38241 L F
.5254 .38228 m .52591 .38211 L .52598 .38204 L F
.52603 .38193 m .52598 .38204 L .52618 .38185 L F
.5254 .38228 m .52598 .38204 L .52603 .38193 L F
.52578 .38199 m .52579 .38246 L .52579 .38198 L F
.52575 .38248 m .52571 .38248 L .52585 .38234 L F
.52607 .38217 m .52618 .38185 L .52614 .3818 L F
.5261 .38219 m .52621 .38188 L .52618 .38185 L F
.52583 .38172 m .52583 .38171 L .52664 .38193 L F
.52664 .38194 m .52664 .38193 L .52738 .38214 L F
.52583 .38172 m .52664 .38193 L .52664 .38194 L F
.52624 .38198 m .52653 .38171 L .52611 .38198 L F
.52619 .38178 m .52611 .38176 L .52772 .38166 L F
.52635 .38173 m .52644 .38172 L .52659 .38177 L F
.52578 .38199 m .52578 .38133 L .52577 .38133 L F
.52583 .38171 m .52597 .38171 L .52601 .38174 L F
.52707 .38168 m .52575 .38174 L .52712 .38166 L F
.52597 .38171 m .52608 .38172 L .52601 .38174 L F
.52502 .38128 m .52611 .38176 L .52498 .38123 L F
.52601 .38174 m .52608 .38172 L .52611 .38176 L F
.52491 .38141 m .52472 .38109 L .52574 .38149 L F
.52552 .3813 m .52534 .38132 L .52605 .38176 L F
.52629 .38198 m .52623 .38191 L .52654 .38189 L F
.52624 .382 m .52616 .38203 L .52649 .38171 L F
.5261 .38218 m .52618 .38185 L .52607 .38217 L F
.52601 .38224 m .52601 .38224 L .52628 .38197 L F
.52569 .38194 m .52725 .38174 L .52724 .38176 L F
.52524 .38199 m .52569 .38194 L .52569 .38194 L F
.52569 .38194 m .52725 .38174 L .52569 .38194 L F
.52716 .38165 m .5266 .38165 L .52661 .38164 L F
.5266 .38165 m .52632 .38164 L .52661 .38164 L F
.52661 .38164 m .52632 .38164 L .52632 .38164 L F
.52653 .38171 m .52696 .38132 L .52642 .38172 L F
.52673 .38149 m .5266 .38159 L .52769 .38051 L F
.52656 .38167 m .5266 .38159 L .52673 .38149 L F
.52656 .38167 m .52655 .38164 L .5266 .38159 L F
.52708 .38094 m .52739 .3807 L .52708 .38092 L F
.52695 .3813 m .52718 .38107 L .52695 .3813 L F
.52623 .38191 m .5268 .38123 L .5268 .38124 L F
.52627 .38196 m .52683 .38128 L .52683 .38129 L F
.52693 .38127 m .52655 .38164 L .52675 .38098 L F
.52642 .38172 m .52685 .3814 L .52636 .38173 L F
.52646 .38169 m .52674 .38135 L .52646 .38169 L F
.5265 .3816 m .52666 .38141 L .5265 .3816 L F
.5265 .38159 m .5265 .38159 L .5268 .38123 L F
.5265 .3816 m .5265 .3816 L .52666 .38141 L F
.5264 .3817 m .5268 .38124 L .52641 .3817 L F
.52618 .38185 m .52685 .3814 L .52661 .38144 L F
.52655 .38164 m .52646 .38131 L .52675 .38098 L F
.52695 .3813 m .52718 .38107 L .52695 .3813 L F
.52682 .38127 m .5271 .38093 L .52682 .38127 L F
.5277 .38056 m .52655 .3817 L .52764 .38056 L F
.52627 .38195 m .52645 .3818 L .52644 .3818 L F
.52635 .38173 m .52659 .38177 L .5266 .3818 L F
.52645 .3818 m .52657 .38171 L .52644 .3818 L F
.52629 .38198 m .52654 .38189 L .52807 .38176 L F
.5256 .3818 m .52707 .38168 L .52706 .38169 L F
.52717 .38196 m .52644 .38172 L .52659 .3817 L F
.52644 .3818 m .52657 .38171 L .52653 .38171 L F
.52628 .38197 m .52628 .38197 L .52695 .3813 L F
.52657 .38171 m .52658 .38169 L .52653 .38171 L F
.52644 .38172 m .52574 .38149 L .52659 .3817 L F
.52314 .38047 m .52605 .38177 L .52315 .38046 L F
.52632 .38164 m .52547 .38164 L .52547 .38163 L F
.52642 .38171 m .52586 .38146 L .52616 .38175 L F
.5254 .38228 m .5261 .38176 L .52604 .38177 L F
.52579 .38198 m .52611 .38176 L .52601 .38164 L F
.5261 .38176 m .52604 .3818 L .52602 .38166 L F
.52659 .3817 m .52569 .38136 L .52576 .38133 L F
.52628 .38197 m .52631 .38131 L .5263 .38131 L F
.52628 .38199 m .52628 .38197 L .52628 .38197 L F
.52611 .38176 m .52716 .38168 L .52714 .38169 L F
.5256 .3818 m .52612 .38176 L .52611 .38176 L F
.52629 .38163 m .52629 .38163 L .52628 .38197 L F
.52612 .38176 m .52716 .38168 L .52611 .38176 L F
.52635 .38181 m .52643 .38177 L .5267 .38188 L F
.52611 .38176 m .52643 .38177 L .52635 .38181 L F
.52611 .38176 m .52635 .38173 L .52643 .38177 L F
.52653 .38171 m .52642 .38172 L .52621 .38188 L F
.52623 .38191 m .52621 .38188 L .52591 .38211 L F
.52628 .38197 m .52629 .38163 L .52628 .38197 L F
.52653 .38171 m .52621 .38188 L .52623 .38191 L F
.5254 .38228 m .52618 .38185 L .52611 .38176 L F
.52611 .38176 m .52611 .38176 L .52611 .38176 L F
.52612 .38176 m .52611 .38176 L .52611 .38176 L F
.52629 .38163 m .52631 .38131 L .52629 .38163 L F
.52716 .38165 m .52639 .38168 L .52632 .38164 L F
.52657 .3817 m .52593 .38154 L .52657 .3817 L F
.52593 .38154 m .52574 .38149 L .52593 .38154 L F
.52593 .38154 m .52593 .38154 L .52657 .3817 L F
.52576 .38133 m .52569 .38136 L .52565 .38129 L F
.52613 .38172 m .52617 .38164 L .52623 .38129 L F
.52582 .3814 m .52558 .38131 L .52587 .38147 L F
.52657 .3817 m .52574 .38149 L .52569 .38136 L F
.52657 .38169 m .52579 .38135 L .52644 .38171 L F
.52618 .38172 m .52614 .38168 L .52622 .38158 L F
.52635 .38153 m .52631 .38153 L .5263 .38154 L F
.52631 .38153 m .52621 .38155 L .5263 .38154 L F
.5263 .38154 m .52621 .38155 L .5262 .38158 L F
.52618 .38172 m .52622 .38158 L .52646 .38131 L F
.5262 .38174 m .52618 .38172 L .52646 .38131 L F
.52627 .38165 m .52613 .38174 L .52613 .38171 L F
.52576 .38133 m .52584 .38143 L .52644 .38171 L F
.52477 .38169 m .52506 .38197 L .52538 .38186 L F
.52477 .38169 m .52576 .38197 L .52544 .38177 L F
.52549 .3816 m .5255 .38159 L .52505 .38139 L F
.52517 .38144 m .52564 .38167 L p .52475 .38095 L F P
0 g
s
.52607 .38176 m .52623 .38157 L .52624 .38156 L .67 .731 .896 r
F
.5258 .38245 m .52601 .38224 L .52601 .38224 L F
.52579 .38246 m .52581 .38354 L .5258 .38244 L F
.52579 .38246 m .5258 .38244 L .52579 .38198 L F
.52579 .38198 m .52579 .38199 L .52611 .38176 L F
.52579 .38199 m .5258 .38244 L .52596 .38209 L F
.5254 .38228 m .52611 .38176 L .5261 .38176 L F
.52579 .38199 m .52596 .38209 L .52611 .38176 L F
.52584 .38181 m .5254 .38228 L .52586 .38186 L F
.52579 .38199 m .52524 .38199 L p .52585 .38194 L F P
0 g
s
.52577 .38198 m .52578 .38198 L .52577 .38198 L .67 .731 .896 r
F
.52579 .38199 m .52579 .38198 L .52578 .38198 L F
.52591 .38211 m .52621 .38188 L .52618 .38185 L F
.52629 .38198 m .52579 .38199 L p .52623 .38191 L F P
0 g
s
.52578 .38198 m .52629 .38198 L .52578 .38198 L .67 .731 .896 r
F
.52578 .38198 m .52578 .38198 L .52577 .38198 L F
.52578 .38222 m .52582 .3824 L .52579 .38249 L F
.52577 .38248 m .5258 .38245 L .5258 .38245 L F
.5258 .38245 m .52601 .38224 L .5258 .38245 L F
.52598 .38251 m .52597 .38251 L .52592 .38219 L F
.52592 .38218 m .52592 .38219 L .52587 .38191 L F
.52573 .38245 m .52629 .38198 L .52627 .38195 L F
.52624 .382 m .5261 .38213 L .5262 .38202 L F
.5261 .38213 m .52582 .38241 L .5262 .38202 L F
.5262 .38202 m .52582 .38241 L .52616 .38203 L F
.5257 .38256 m .52582 .38241 L .52582 .38241 L F
.52502 .38282 m .52412 .38391 L .52503 .38294 L F
.5251 .3826 m .52468 .38356 L .5238 .38396 L F
.52216 .38569 m .52578 .38249 L .52581 .38241 L F
.52582 .38241 m .52575 .38248 L .52583 .3824 L F
.52582 .38241 m .52583 .3824 L .52616 .38203 L F
.52602 .38166 m .52605 .38188 L .52582 .38141 L F
.52597 .3823 m .52596 .3823 L .52626 .38199 L F
.52563 .3819 m .52612 .38178 L .52569 .38194 L F
.52557 .3818 m .52576 .38197 L .52579 .38197 L F
.52579 .38199 m .52585 .38194 L .52623 .38191 L F
.52571 .38195 m .52621 .38188 L .52623 .38191 L F
.52524 .38199 m .52569 .38194 L .52571 .38195 L F
.52569 .38194 m .52621 .38188 L .52571 .38195 L F
.52595 .38278 m .5261 .38218 L .52607 .38217 L F
.52597 .38279 m .52618 .38185 L .52595 .38278 L F
.52584 .38234 m .52621 .38201 L .52585 .38233 L F
.52583 .3824 m .52585 .38234 L .52616 .38203 L F
.52585 .38234 m .52595 .38211 L .526 .38209 L F
.52612 .38254 m .52597 .38245 L .52591 .38208 L F
.52569 .38194 m .52612 .38178 L .5262 .38187 L F
.52599 .38183 m .52628 .38196 L .52618 .38185 L F
.52539 .38175 m .5254 .38174 L .5258 .38172 L F
.5253 .38167 m .52544 .38177 L .52599 .38183 L F
.52628 .38197 m .52645 .38179 L .52645 .38179 L F
.52623 .38191 m .52665 .38184 L .52654 .38189 L F
.52655 .3817 m .52628 .38196 L .52653 .3817 L F
.52508 .38199 m .52577 .38198 L .52508 .38198 L F
.5272 .38198 m .5267 .38188 L .52717 .38196 L F
.52717 .38197 m .52629 .38198 L p .5272 .38188 L F P
0 g
s
.52577 .38198 m .52757 .38197 L .52578 .38198 L .67 .731 .896 r
F
.52577 .38198 m .52578 .38198 L .52508 .38198 L F
.52594 .38187 m .52579 .38137 L .52582 .38141 L F
.52614 .38255 m .52612 .38254 L .5261 .38247 L F
.52605 .38179 m .52599 .38183 L .52618 .38185 L F
.52592 .38188 m .52628 .38196 L .52599 .38183 L F
.52592 .38188 m .52579 .38197 L .52628 .38196 L F
.52595 .38211 m .52614 .38168 L .526 .38209 L F
.52611 .38246 m .5261 .38247 L .52598 .38203 L F
.52661 .38186 m .52805 .38197 L .52657 .38185 L F
.52629 .38198 m .52807 .38176 L .52803 .3818 L F
.52717 .38197 m .5272 .38188 L .52918 .38167 L F
.52716 .38165 m .52724 .38179 L .52741 .38181 L F
.52599 .38202 m .52582 .38141 L .52582 .38141 L F
.52574 .38147 m .52605 .38176 L .5261 .38176 L F
.52606 .3817 m .5261 .38176 L .52613 .38175 L F
.52579 .38135 m .52579 .38135 L .52644 .38171 L F
.52585 .38144 m .52586 .38146 L .52642 .38171 L F
.52556 .3813 m .52644 .38171 L .52556 .3813 L F
.5266 .3818 m .52659 .38177 L .52717 .38196 L F
.52644 .38171 m .52698 .38196 L .52644 .38171 L F
.52644 .38171 m .52644 .38171 L .52556 .3813 L F
.52599 .38202 m .52598 .38203 L .52581 .38138 L F
.52578 .38198 m .52579 .38198 L .52578 .38133 L F
.52576 .38135 m .52587 .38192 L .52578 .38198 L F
.52557 .3818 m .52579 .38197 L .52592 .38188 L F
.52578 .38199 m .52579 .38199 L .52578 .38198 L F
.52603 .38177 m .52559 .38225 L .52587 .38179 L F
.52601 .38224 m .52628 .38197 L .52628 .38197 L F
.52624 .38198 m .52611 .38198 L .52591 .38211 L F
.52577 .38198 m .52629 .38198 L .52629 .38198 L F
.52621 .38201 m .52624 .38198 L .52591 .38211 L F
.52629 .38198 m .52578 .38198 L .52629 .38198 L F
.5263 .38198 m .52578 .38198 L .5263 .38198 L F
.52629 .38198 m .52629 .38198 L .52578 .38198 L F
.52579 .38197 m .52676 .38196 L .52579 .38197 L F
.52676 .38196 m .52689 .38196 L .52676 .38196 L F
.52676 .38196 m .52676 .38196 L .52579 .38197 L F
.52624 .38237 m .52611 .38174 L .52625 .38236 L F
.52625 .38194 m .52616 .38203 L .5262 .38188 L F
.52616 .38203 m .52585 .38234 L .5262 .38188 L F
.5262 .38188 m .52585 .38234 L .52616 .38182 L F
.52544 .38177 m .52592 .38188 L .52599 .38183 L F
.52508 .38199 m .52577 .38198 L .52577 .38198 L F
.52512 .38191 m .5258 .38197 L .52578 .38195 L F
.52512 .38191 m .52578 .38195 L .52575 .38193 L F
.52524 .38199 m .52563 .3819 L .52569 .38194 L F
.52552 .38181 m .52576 .38197 L .52557 .3818 L F
.52629 .38198 m .52508 .38199 L .52629 .38198 L F
.52605 .38188 m .52599 .38202 L .52582 .38141 L F
.52606 .38186 m .52605 .38188 L .52604 .3818 L F
.52585 .38234 m .52609 .38174 L .5261 .38176 L F
.52612 .38175 m .5261 .38176 L .52591 .38074 L F
.52678 .38197 m .52629 .38198 L .52629 .38198 L F
.52566 .38137 m .52562 .38138 L .52639 .38194 L F
.5264 .38194 m .52639 .38194 L .52674 .3822 L F
.52625 .382 m .52655 .3817 L .52625 .382 L F
.52623 .38191 m .52662 .38183 L .52665 .38184 L F
.52615 .38181 m .52618 .38185 L .52709 .38196 L F
.52621 .38188 m .52642 .38172 L .52618 .38185 L F
.52719 .38165 m .52716 .38165 L .52741 .38181 L F
.52784 .38172 m .52619 .38178 L .52772 .38166 L F
.52642 .38172 m .52636 .38173 L .52618 .38185 L F
.52625 .38194 m .52616 .38182 L .5262 .38174 L F
.52646 .38148 m .5264 .38134 L .52641 .38134 L F
.52632 .38173 m .5262 .38174 L .52646 .38131 L F
.52625 .38194 m .5262 .38174 L .52632 .38173 L F
.52628 .38196 m .52628 .38196 L .52653 .3817 L F
.52628 .38198 m .52628 .38197 L .52656 .38169 L F
.52628 .38197 m .52655 .3817 L .52628 .38197 L F
.52601 .38223 m .52656 .38168 L .52656 .38168 L F
.52593 .3823 m .52601 .38223 L .52601 .38223 L F
.52601 .38223 m .52656 .38168 L .52601 .38223 L F
.52704 .38195 m .52728 .38222 L .52729 .382 L F
.52707 .38195 m .52707 .38196 L .52709 .38196 L F
.52618 .38185 m .52707 .38196 L .52707 .38195 L F
.52618 .38185 m .52628 .38196 L .52707 .38196 L F
.52655 .38164 m .52625 .38194 L .52646 .38131 L F
.52616 .38175 m .52639 .38194 L .5264 .38194 L F
.52609 .38176 m .52605 .38179 L .52664 .38189 L F
.52615 .38175 m .52639 .38194 L .52616 .38175 L F
.52602 .38165 m .52639 .38194 L .526 .38163 L F
.52611 .38175 m .52614 .38168 L .5262 .38174 L F
.52629 .38198 m .52686 .38198 L .52629 .38198 L F
.52624 .382 m .52649 .38171 L .5265 .3817 L F
.52624 .382 m .52655 .38164 L .52656 .38167 L F
.52653 .38171 m .52658 .38169 L .52658 .38167 L F
.52627 .38199 m .52656 .38169 L .52657 .38169 L F
.52564 .38166 m .52664 .38189 L .52659 .38186 L F
.52687 .38197 m .52629 .38198 L .52629 .38198 L F
.52687 .38197 m .52687 .38197 L .52577 .38198 L F
.52709 .38196 m .52722 .38196 L .52722 .38196 L F
.52559 .38047 m .52569 .38128 L .52575 .38059 L F
.52507 .38198 m .52676 .38196 L .52676 .38196 L F
.52687 .38197 m .5263 .38198 L .5263 .38198 L F
.52687 .38197 m .52629 .38198 L .52629 .38198 L F
.5265 .38184 m .52619 .38177 L .52671 .38218 L F
.52676 .38196 m .5271 .38196 L .52709 .38196 L F
.52676 .38196 m .5271 .38196 L .52676 .38196 L F
.52642 .38171 m .52616 .38175 L .52619 .38177 L F
.52627 .38165 m .52629 .38198 L p .52613 .38174 L F P
0 g
s
.52629 .38198 m .52686 .38198 L .52687 .38197 L .67 .731 .896 r
F
.52686 .38198 m .52721 .38197 L p .52687 .38197 L F P
0 g
s
.52737 .382 m .52876 .38206 L .52734 .38195 L .67 .731 .896 r
F
.5271 .38196 m .52757 .38197 L .52756 .38195 L F
.52593 .3823 m .52628 .38196 L .52593 .3823 L F
.52628 .38196 m .52695 .3813 L .52628 .38196 L F
.52628 .38196 m .52628 .38196 L .52593 .3823 L F
.52628 .38197 m .52715 .38197 L .5271 .38196 L F
.52514 .38198 m .52628 .38197 L .52628 .38197 L F
.52628 .38197 m .52715 .38197 L .52628 .38197 L F
.52715 .38197 m .52757 .38197 L .5271 .38196 L F
.52676 .38189 m .52701 .3823 L .52712 .38211 L F
.52662 .3818 m .52667 .38187 L .52676 .38189 L F
.52667 .38187 m .52701 .3823 L .52676 .38189 L F
.52701 .3823 m .52704 .38234 L .52705 .38231 L F
.52701 .3823 m .52705 .38231 L .52712 .38211 L F
.5253 .38167 m .52477 .38169 L .52544 .38177 L F
.52373 .382 m .52508 .38199 L .52373 .382 L F
.52375 .38201 m .52509 .38199 L p .52373 .382 L F P
0 g
s
.52373 .382 m .52508 .38199 L .52372 .38199 L .67 .731 .896 r
F
.52477 .38169 m .51176 .3821 L .52507 .38198 L F
.52491 .38193 m .5233 .38214 L .5253 .38167 L F
.52508 .38199 m .52508 .38198 L .52372 .38199 L F
.52354 .38201 m .52501 .38195 L .52354 .38201 L F
.52575 .38174 m .52539 .38175 L .5258 .38172 L F
.5253 .38167 m .52599 .38183 L .52605 .38179 L F
.52497 .3814 m .52554 .38165 L .52505 .38139 L F
.52554 .38165 m .52562 .38166 L .52505 .38139 L F
.52314 .38047 m .52551 .38158 L .52553 .38154 L F
.52491 .38141 m .52574 .38149 L .52583 .38172 L F
.52564 .38167 m .52588 .38178 L p .5257 .38155 L F P
0 g
s
.52803 .3818 m .52807 .38176 L .52918 .38167 L .67 .731 .896 r
F
.52753 .38181 m .52744 .38173 L .52918 .38167 L F
.52918 .38167 m .52784 .38172 L .52772 .38166 L F
.52995 .38153 m .52732 .38161 L .52956 .38193 L F
.526 .38163 m .52615 .38175 L .52616 .38175 L F
.52556 .3813 m .52644 .38171 L .52644 .38171 L F
.52622 .38149 m .52613 .38171 L .52607 .38142 L F
.52578 .38117 m .52623 .38129 L .52626 .38115 L F
.5262 .38144 m .52607 .38142 L .52585 .38027 L F
.52622 .38149 m .52607 .38142 L .5262 .38144 L F
.52593 .38187 m .52588 .38191 L .52579 .38137 L F
.52564 .38166 m .52605 .38179 L .52609 .38176 L F
.5261 .38176 m .52602 .38166 L .52591 .38074 L F
.52624 .38145 m .52603 .38177 L .52587 .38179 L F
.52623 .38151 m .5263 .38131 L .52617 .38164 L F
.52626 .38142 m .52622 .38148 L .52624 .38145 L F
.52622 .38148 m .52603 .38177 L .52624 .38145 L F
.52631 .38134 m .52622 .38152 L .52641 .38135 L F
.52675 .38098 m .52633 .38144 L .52626 .38142 L F
.52614 .38159 m .52648 .38135 L .52646 .3813 L F
.52633 .38144 m .52603 .38177 L .52626 .38142 L F
.52614 .38167 m .52623 .38157 L .52614 .38167 L F
.52627 .38165 m .52613 .38171 L .52622 .38149 L F
.52624 .38156 m .52655 .38119 L .52656 .38119 L F
.52623 .38157 m .52655 .38119 L .52624 .38156 L F
.52614 .38167 m .52616 .38162 L .52645 .3813 L F
.52606 .38176 m .52645 .3813 L .52646 .38131 L F
.52625 .38412 m .52624 .38413 L .5262 .38387 L F
.5262 .38387 m .5262 .38387 L .52606 .38304 L F
.52582 .38242 m .52624 .382 L .52624 .382 L F
.52323 .38602 m .52295 .3862 L .52562 .38255 L F
.51801 .39011 m .52582 .38241 L .52582 .38242 L F
.52582 .38241 m .52624 .382 L .52582 .38242 L F
.52606 .38304 m .52606 .38304 L .52592 .38219 L F
.52592 .38219 m .52592 .38219 L .5259 .38207 L F
.52606 .38304 m .52592 .38219 L .52592 .38219 L F
.5262 .38387 m .52606 .38304 L .52606 .38304 L F
.5277 .38056 m .5277 .38056 L .52765 .38055 L F
.5277 .38056 m .52764 .38056 L .52765 .38055 L F
.5277 .38053 m .52765 .38055 L .52769 .38051 L F
.5277 .38056 m .52765 .38055 L .5277 .38053 L F
.52685 .3814 m .52696 .38132 L .52676 .38139 L F
.52655 .3817 m .52653 .3817 L .52769 .38051 L F
.52682 .38127 m .52682 .38127 L .5271 .38093 L F
.52718 .38107 m .52802 .38025 L .52802 .38025 L F
.52718 .38107 m .52802 .38025 L .52718 .38107 L F
.52718 .38107 m .52718 .38107 L .52802 .38025 L F
.52802 .38025 m .52802 .38025 L .53441 .37395 L F
.52879 .37952 m .52696 .38132 L p .52879 .37949 L F P
0 g
s
.52696 .38132 m .52695 .3813 L .52879 .37949 L .67 .731 .896 r
F
.52646 .3813 m .52739 .3807 L .52694 .38085 L F
.52758 .38041 m .52757 .38039 L .52912 .37857 L F
.52757 .38036 m .52757 .38035 L .52912 .37857 L F
.53265 .37557 m .52693 .38127 L .52675 .38098 L F
.52709 .38129 m .53612 .37355 L p .52653 .38132 L F P
0 g
s
.52687 .3814 m .52783 .38048 L .52785 .38052 L .67 .731 .896 r
F
.52609 .38173 m .52616 .38162 L .52614 .38167 L F
.52645 .38179 m .52655 .3817 L .52655 .3817 L F
.52657 .38169 m .52644 .38171 L .52687 .38191 L F
.52602 .38165 m .52605 .38169 L .52744 .38179 L F
.52696 .38132 m .52597 .3823 L p .52695 .3813 L F P
0 g
s
.52659 .3817 m .52657 .3817 L .52657 .3817 L .67 .731 .896 r
F
.5265 .3817 m .5265 .3817 L .52655 .38164 L F
.5265 .3817 m .5265 .3817 L .5265 .3817 L F
.5265 .3817 m .52649 .38171 L .5265 .3817 L F
.52713 .38166 m .52713 .38166 L .52718 .38166 L F
.52575 .38174 m .52713 .38166 L .52713 .38166 L F
.52718 .38166 m .52718 .38166 L .52734 .38165 L F
.52575 .38174 m .52718 .38166 L .52718 .38166 L F
.52706 .38169 m .52707 .38168 L .52716 .38168 L F
.52714 .38169 m .52716 .38168 L .52772 .38166 L F
.52593 .3823 m .52695 .3813 L .52695 .3813 L F
.52736 .38167 m .52707 .38168 L .52734 .38165 L F
.52707 .38168 m .52712 .38166 L .52734 .38165 L F
.52713 .38166 m .5258 .38172 L .52716 .38165 L F
.52734 .38165 m .52713 .38166 L .52716 .38165 L F
.52724 .38176 m .52725 .38174 L .52744 .38173 L F
.52732 .38161 m .52602 .38165 L .52744 .38179 L F
.52732 .38161 m .52645 .38174 L .52627 .38164 L F
.52772 .38166 m .52736 .38167 L .52734 .38165 L F
.52732 .38161 m .52744 .38179 L .52956 .38193 L F
.52753 .3816 m .52723 .38164 L .52732 .38161 L F
.52723 .38164 m .52645 .38174 L .52732 .38161 L F
.52323 .38472 m .52584 .38234 L .52345 .38446 L F
.52502 .38282 m .52543 .3825 L .52536 .38248 L F
.52364 .38454 m .52338 .38466 L .52545 .3824 L F
.52503 .38294 m .52519 .38278 L .52516 .38279 L F
.52519 .38278 m .526 .38202 L .52516 .38279 L F
.52502 .38282 m .52503 .38294 L .52543 .3825 L F
.52564 .38243 m .52468 .38356 L .5251 .3826 L F
.52345 .38446 m .52572 .38244 L .52559 .38241 L F
.52584 .38234 m .52585 .38233 L .52345 .38446 L F
.52216 .38569 m .52294 .38499 L .52292 .385 L F
.51737 .39073 m .52197 .38622 L p .52216 .38569 L F P
0 g
s
.52521 .38239 m .52193 .38624 L .51941 .38771 L .67 .731 .896 r
F
.52502 .38282 m .52556 .38229 L .52555 .38229 L F
.52541 .38238 m .52545 .38249 L .52526 .38255 L F
.52533 .38235 m .52526 .38255 L .5251 .3826 L F
.5254 .38228 m .52216 .38569 L .52591 .38211 L F
.52559 .38225 m .52193 .38624 L .52521 .38239 L F
.52364 .38454 m .52545 .3824 L .52552 .38238 L F
.52193 .38624 m .51737 .39073 L .51941 .38771 L F
.51654 .39034 m .52519 .38292 L p .52513 .38246 L F P
0 g
s
.52424 .38362 m .52425 .3836 L .52596 .3821 L .67 .731 .896 r
F
.52642 .38171 m .52619 .38177 L .5265 .38184 L F
.52593 .38187 m .52579 .38137 L .52594 .38187 L F
.52587 .38191 m .52587 .38191 L .52576 .38125 L F
.52587 .38191 m .52587 .38191 L .52578 .38137 L F
.5257 .38155 m .52588 .38178 L .52605 .38176 L F
.52564 .38166 m .5261 .38176 L .52605 .38169 L F
.52606 .38176 m .52608 .38173 L .52609 .38173 L F
.52602 .38165 m .52564 .38166 L .52605 .38169 L F
.52586 .38146 m .526 .38163 L .52616 .38175 L F
.52597 .38125 m .52602 .38166 L .5258 .38132 L F
.5258 .38135 m .5258 .38138 L .52614 .38157 L F
.52588 .38178 m .52564 .38167 L p .52586 .38171 L F P
0 g
s
.52544 .38177 m .52552 .38181 L .52557 .3818 L .67 .731 .896 r
F
.52546 .38186 m .52505 .38192 L .52602 .38165 L F
.52505 .38192 m .52491 .38193 L .52501 .38191 L F
.52505 .38192 m .52501 .38191 L .52602 .38165 L F
.52661 .38179 m .52698 .38196 L .52698 .38196 L F
.52613 .38171 m .52611 .38171 L .52614 .38168 L F
.52611 .38174 m .52591 .38074 L .52613 .38171 L F
.5261 .38176 m .52611 .38171 L .52613 .38171 L F
.5261 .38176 m .52609 .38174 L .52611 .38171 L F
.52606 .38176 m .52609 .38173 L .52607 .38176 L F
.52609 .38173 m .52614 .38167 L .52609 .38174 L F
.52609 .38173 m .52609 .38174 L .52607 .38176 L F
.52606 .38176 m .52603 .38177 L .52616 .38162 L F
.5261 .38176 m .52709 .38196 L .52605 .38169 L F
.5267 .38187 m .52744 .38173 L .52753 .38181 L F
.52685 .38191 m .52662 .3818 L .52676 .38189 L F
.52663 .38186 m .52663 .38186 L .52707 .38195 L F
.52608 .38173 m .52616 .38162 L .52609 .38173 L F
.52614 .38167 m .52614 .38167 L .52607 .38176 L F
.52644 .38171 m .52661 .38179 L .52661 .38179 L F
.52644 .38171 m .52661 .38179 L .52644 .38171 L F
.52661 .38179 m .52698 .38196 L .52661 .38179 L F
.52624 .382 m .52695 .3813 L .52624 .382 L F
.52645 .38179 m .52655 .3817 L .52645 .38179 L F
.52628 .38197 m .52691 .38134 L .52628 .38197 L F
.52644 .38171 m .52642 .38171 L .52698 .38196 L F
.52717 .38196 m .52657 .38169 L .52687 .38191 L F
.52717 .38196 m .52687 .38191 L .52717 .38197 L F
.52605 .38169 m .52709 .38196 L .52906 .38194 L F
.52905 .38193 m .52906 .38194 L .52913 .38194 L F
.52605 .38169 m .52906 .38194 L .52905 .38193 L F
.52347 .37148 m .52246 .37162 L p .5251 .37989 L F P
0 g
s
.52629 .38198 m .52577 .38198 L .52577 .38198 L .67 .731 .896 r
F
.5263 .38198 m .52578 .38198 L .52578 .38198 L F
.52517 .38198 m .52678 .38197 L .52514 .38198 L F
.52678 .38197 m .52757 .38197 L .52678 .38197 L F
.52678 .38197 m .52678 .38197 L .52514 .38198 L F
.52626 .38164 m .52606 .3817 L .52602 .38165 L F
.52579 .38137 m .52588 .38191 L .52578 .38137 L F
.52573 .38149 m .52605 .38176 L .52574 .38147 L F
.52602 .38165 m .52588 .38178 L .52604 .38168 L F
.52606 .3817 m .52595 .38173 L .52602 .38165 L F
.52602 .38165 m .52604 .38168 L .52621 .38158 L F
.52667 .38186 m .52662 .38184 L .5269 .38191 L F
.52662 .38184 m .52645 .38174 L .5269 .38191 L F
.52663 .38186 m .52663 .38184 L .52689 .38191 L F
.5263 .38198 m .52716 .38197 L .5263 .38198 L F
.52662 .3818 m .52642 .38171 L .52651 .38184 L F
.52654 .38189 m .52665 .38184 L .5267 .38187 L F
.52664 .38186 m .52651 .38184 L .52674 .3822 L F
.52662 .3818 m .52651 .38184 L .52664 .38186 L F
.52721 .38197 m .52721 .38197 L .5263 .38198 L F
.52687 .38197 m .52687 .38197 L .52629 .38198 L F
.52716 .38197 m .52687 .38197 L .52687 .38197 L F
.52698 .38196 m .52698 .38196 L .52714 .38204 L F
.52687 .38197 m .52716 .38197 L .52687 .38197 L F
.52699 .38212 m .52646 .38193 L .52707 .38195 L F
.52679 .3819 m .52681 .38191 L .52709 .38196 L F
.52659 .38186 m .52681 .38191 L .52679 .3819 L F
.52659 .38186 m .52664 .38189 L .52681 .38191 L F
.52711 .38215 m .52738 .38214 L .52715 .38216 L F
.52685 .38191 m .52676 .38189 L .52758 .3824 L F
.52763 .38241 m .52758 .3824 L .52893 .38324 L F
.52685 .38191 m .52758 .3824 L .52763 .38241 L F
.52601 .38215 m .52593 .382 L .52597 .382 L F
.52593 .382 m .52588 .38191 L .52597 .382 L F
.52597 .382 m .52588 .38191 L .52593 .38187 L F
.5259 .38208 m .5259 .38207 L .52587 .38191 L F
.52578 .38199 m .52589 .38226 L .52578 .38222 L F
.52554 .38265 m .52541 .38251 L .52609 .38174 L F
.52601 .38215 m .52591 .38208 L .52588 .38191 L F
.52657 .38169 m .52656 .38169 L .52695 .3813 L F
.52695 .3813 m .52695 .3813 L .52624 .382 L F
.52628 .38197 m .52691 .38134 L .52691 .38134 L F
.52655 .3817 m .52655 .3817 L .52691 .38134 L F
.52617 .38184 m .5268 .38154 L .5267 .38153 L F
.5259 .38208 m .52587 .38191 L .52587 .38191 L F
.52598 .38251 m .52587 .38191 L .52587 .38191 L F
.52552 .38238 m .52606 .38176 L .52607 .38176 L F
.52605 .38179 m .52618 .38185 L .52615 .38181 L F
.526 .38209 m .52611 .38175 L .5262 .38174 L F
.52617 .38183 m .5262 .38169 L .52613 .38179 L F
.52588 .38178 m .52599 .38177 L .52606 .38171 L F
.52687 .38197 m .52508 .38199 L .52508 .38199 L F
.52509 .38199 m .52686 .38198 L p .52508 .38199 L F P
0 g
s
.52508 .38199 m .52687 .38197 L .52508 .38199 L .67 .731 .896 r
F
.52587 .38179 m .52559 .38225 L .52528 .38237 L F
.52587 .38179 m .52528 .38237 L .52526 .38235 L F
.52588 .38178 m .52531 .3823 L .52599 .38177 L F
.52691 .38134 m .52691 .38134 L .52695 .3813 L F
.52656 .38147 m .52709 .38129 L .52653 .38132 L F
.52657 .38158 m .52702 .38118 L .52704 .38118 L F
.52591 .382 m .52603 .38193 L .52588 .38185 L F
.52628 .38196 m .52624 .382 L .52628 .38196 L F
.52627 .38199 m .52626 .38199 L .52628 .38197 L F
.52627 .38199 m .52628 .38197 L .52628 .38198 L F
.52625 .382 m .52628 .38197 L .52628 .38197 L F
.52629 .38198 m .52631 .38232 L p .52615 .38181 L F P
0 g
s
.52631 .38232 m .52633 .3825 L p .52629 .38234 L .67 .731 .896 r
F P
0 g
s
.52631 .38232 m .52629 .38234 L .52615 .38181 L .67 .731 .896 r
F
.52689 .38196 m .52689 .38196 L .52514 .38198 L F
.52629 .38198 m .52674 .3822 L p .52618 .38185 L F P
0 g
s
.52605 .38176 m .52629 .38198 L .52618 .38185 L .67 .731 .896 r
F
.52592 .38193 m .52603 .38177 L .52606 .38176 L F
.52597 .3823 m .52626 .38199 L .52627 .38199 L F
.52624 .38237 m .52604 .3818 L .52612 .38175 L F
.52621 .38463 m .52629 .38198 L .52628 .38199 L F
.52636 .38293 m .52621 .38239 L .52624 .38237 L F
.52594 .3823 m .52625 .382 L .52625 .382 L F
.52594 .3823 m .52593 .3823 L .52655 .3817 L F
.52593 .3823 m .52593 .3823 L .52656 .38168 L F
.52621 .38239 m .52604 .3818 L .52624 .38237 L F
.52588 .38178 m .52629 .38198 L p .52605 .38176 L F P
0 g
s
.52588 .38178 m .52588 .38178 L .5262 .38187 L .67 .731 .896 r
F
.52629 .38198 m .52508 .38199 L .52508 .38199 L F
.52538 .38186 m .52507 .38198 L .52576 .38197 L F
.52506 .38197 m .52507 .38198 L .52538 .38186 L F
.52592 .38193 m .52591 .3819 L .52603 .38177 L F
.52577 .38198 m .52577 .38198 L .52508 .38199 L F
.52508 .38199 m .52508 .38199 L .52373 .382 L F
.52578 .38198 m .52578 .38198 L .52508 .38199 L F
.52508 .38199 m .52508 .38199 L .52373 .382 L F
.52514 .38198 m .52579 .38197 L .52514 .38198 L F
.52579 .38197 m .52579 .38197 L .52514 .38198 L F
.52622 .38162 m .52625 .38145 L .52618 .38159 L F
.52602 .38165 m .52621 .38158 L .52702 .38093 L F
.52703 .38091 m .52702 .38093 L .52719 .38079 L F
.52602 .38165 m .52702 .38093 L .52703 .38091 L F
.525 .38104 m .52642 .38171 L .52644 .38171 L F
.52301 .3801 m .525 .38104 L .525 .38104 L F
.525 .38104 m .52642 .38171 L .525 .38104 L F
.52617 .38202 m .52611 .38174 L .52618 .38201 L F
.52604 .38168 m .52606 .38171 L .52621 .38158 L F
.5261 .38175 m .52616 .38158 L .52614 .38157 L F
.52611 .38176 m .52606 .3817 L .52625 .38165 L F
.52617 .38162 m .52709 .38129 L .52621 .38158 L F
.52588 .38185 m .52611 .38175 L .52617 .38162 L F
.5262 .38169 m .52622 .38162 L .52617 .38171 L F
.52588 .38178 m .52601 .38177 L .52616 .38182 L F
.52665 .38185 m .52631 .3818 L .52645 .38174 L F
.52674 .3822 m .52692 .38228 L p .52662 .3818 L F P
0 g
s
.52692 .38228 m .52704 .38234 L p .52701 .3823 L .67 .731 .896 r
F P
0 g
s
.52662 .3818 m .52692 .38228 L .52701 .3823 L .67 .731 .896 r
F
.51755 .38205 m .52373 .382 L .52372 .38199 L F
.52373 .382 m .52373 .382 L .51756 .38205 L F
.51757 .38205 m .52373 .382 L .51756 .38205 L F
.52373 .382 m .52373 .382 L .51756 .38205 L F
.512 .38213 m .52217 .38202 L p .51176 .3821 L F P
0 g
s
.51176 .3821 m .52217 .38202 L .52209 .38201 L .67 .731 .896 r
F
.5233 .38214 m .51033 .38283 L p .52364 .38172 L F P
0 g
s
.52373 .382 m .52477 .38199 L .52373 .382 L .67 .731 .896 r
F
.52477 .38199 m .5263 .38198 L .52477 .38199 L F
.52477 .38199 m .52477 .38199 L .52373 .382 L F
.52591 .3802 m .52591 .38075 L .52585 .38092 L F
.52593 .38068 m .52591 .38074 L .52585 .38027 L F
.52572 .37943 m .52574 .38036 L .52632 .38028 L F
.52615 .38002 m .52618 .38052 L p .52585 .38027 L F P
0 g
s
.52617 .38164 m .5263 .38131 L .52623 .38129 L .67 .731 .896 r
F
.52631 .38115 m .52626 .38109 L .52625 .38094 L F
.52577 .38055 m .52626 .38115 L .52631 .38089 L F
.52574 .38036 m .52631 .38089 L .52632 .38028 L F
.52618 .38052 m .52627 .38165 L p .52591 .38047 L F P
0 g
s
.52618 .38052 m .52591 .38047 L .52585 .38027 L .67 .731 .896 r
F
.52574 .38036 m .52574 .38044 L .52577 .38039 L F
.52656 .37131 m .52636 .37911 L p .52613 .37994 L F P
0 g
s
.52552 .37133 m .52572 .37943 L .52648 .37419 L .67 .731 .896 r
F
.52636 .37911 m .52634 .37982 L p .52613 .37994 L F P
0 g
s
.52613 .37994 m .52634 .37982 L .52612 .38001 L .67 .731 .896 r
F
.52572 .37943 m .52632 .38028 L .52648 .37419 L F
.52601 .37804 m .52615 .38002 L p .52571 .37913 L F P
0 g
s
.52615 .38002 m .52585 .38027 L .52571 .37913 L .67 .731 .896 r
F
.52574 .38044 m .52575 .38072 L .52577 .38039 L F
.52575 .38072 m .52578 .38199 L .52577 .3807 L F
.52575 .38072 m .52577 .3807 L .52577 .38039 L F
.52357 .38213 m .5233 .38214 L p .52353 .38211 L F P
0 g
s
.52209 .3822 m .52367 .38212 L p .52192 .38211 L .67 .731 .896 r
F P
0 g
s
.52181 .38221 m .52184 .38217 L .524 .38196 L .67 .731 .896 r
F
.52615 .38166 m .52622 .38151 L .52622 .38149 L F
.52625 .38145 m .52602 .38165 L .52624 .38147 L F
.52615 .38166 m .52625 .38142 L .52619 .38141 L F
.52624 .38145 m .52602 .38165 L .52625 .38145 L F
.52614 .38157 m .52616 .38158 L .52623 .38115 L F
.52613 .38171 m .52591 .38074 L .52593 .38068 L F
.5258 .38135 m .52614 .38157 L .52623 .38115 L F
.52612 .38095 m .52623 .38164 L p .52599 .38105 L F P
0 g
s
.52514 .38198 m .52514 .38198 L .52507 .38198 L .67 .731 .896 r
F
.52482 .38206 m .52475 .38197 L .52607 .38179 L F
.52503 .38195 m .5259 .38191 L .52501 .38195 L F
.5261 .38176 m .52618 .38185 L .52671 .38218 L F
.52671 .38218 m .52671 .38218 L .52674 .3822 L F
.5261 .38176 m .52671 .38218 L .52671 .38218 L F
.5262 .38187 m .52627 .38165 L .5262 .38187 L F
.52613 .38175 m .5261 .38176 L .52638 .38194 L F
.5261 .38176 m .52605 .38176 L .52618 .38185 L F
.52618 .38185 m .52615 .38181 L .52614 .38178 L F
.52618 .38185 m .52614 .38178 L .52613 .38174 L F
.52629 .38198 m .52618 .38185 L .52613 .38174 L F
.52588 .38178 m .52616 .38182 L .5262 .38187 L F
.52619 .38186 m .52626 .38164 L .52617 .38183 L F
.52588 .38178 m .5262 .38187 L .5262 .38187 L F
.52603 .38193 m .52609 .3818 L .52588 .38185 L F
.52607 .38179 m .52606 .3817 L .52611 .38176 L F
.52618 .38201 m .52612 .38178 L .52614 .3818 L F
.52589 .38226 m .52586 .38232 L .52578 .38222 L F
.5259 .38207 m .52596 .38244 L .52578 .38199 L F
.52588 .38191 m .52598 .38251 L .52587 .38191 L F
.52585 .38234 m .52554 .38265 L .52609 .38174 L F
.52543 .38229 m .5262 .38187 L .52617 .38184 L F
.52663 .38402 m .52641 .38376 L .52616 .38244 L F
.52605 .38188 m .52612 .38245 L .52599 .38202 L F
.52612 .38245 m .52614 .38255 L .52611 .38246 L F
.52612 .38245 m .52611 .38246 L .52599 .38202 L F
.54226 .38114 m .54215 .38046 L p .52739 .38156 L F P
0 g
s
.52602 .38214 m .52612 .38175 L .52611 .38176 L .67 .731 .896 r
F
.52589 .38269 m .52602 .38215 L .52602 .38214 L F
.52602 .38215 m .52612 .38175 L .52602 .38214 L F
.52612 .38178 m .52611 .38174 L .52614 .3818 L F
.52646 .38193 m .52601 .38177 L .52663 .38186 L F
.52589 .38269 m .52611 .38176 L .52608 .38181 L F
.52663 .38186 m .52631 .3818 L .52665 .38185 L F
.52611 .38176 m .52663 .38184 L .52663 .38186 L F
.52639 .38194 m .52638 .38194 L .52674 .3822 L F
.52673 .38218 m .52671 .38218 L .52674 .3822 L F
.52692 .38228 m .52629 .38198 L p .52699 .38212 L F P
0 g
s
.52629 .38198 m .52588 .38178 L p .52621 .38189 L .67 .731 .896 r
F P
0 g
s
.52642 .38171 m .52671 .38218 L .52673 .38218 L .67 .731 .896 r
F
.52629 .38198 m .52621 .38189 L .52699 .38212 L F
.52616 .38204 m .5262 .38187 L .52615 .38204 L F
.5262 .38187 m .52627 .38165 L .5262 .38187 L F
.5262 .38187 m .5262 .38187 L .52615 .38204 L F
.52615 .38204 m .5262 .38187 L .5262 .38187 L F
.52611 .3822 m .52616 .38204 L .52615 .38204 L F
.52613 .38175 m .52638 .38194 L .52639 .38194 L F
.5262 .38187 m .52616 .38182 L .52666 .382 L F
.52609 .38219 m .52619 .38186 L .52617 .38183 L F
.52611 .3822 m .52626 .38164 L .52609 .38219 L F
.52611 .38176 m .52611 .38176 L .52605 .38175 L F
.52589 .38207 m .5261 .38175 L .52607 .38171 L F
.52625 .38236 m .52617 .38202 L .52618 .38201 L F
.52621 .38239 m .52605 .38188 L .52606 .38186 L F
.52636 .38293 m .5262 .3824 L .52621 .38239 L F
.5262 .3824 m .52605 .38188 L .52621 .38239 L F
.52633 .3825 m .52629 .38257 L .52613 .38174 L F
.52631 .38232 m .52629 .38198 L p .52611 .3822 L F P
0 g
s
.52601 .38177 m .52611 .38176 L .52613 .38178 L .67 .731 .896 r
F
.52609 .3818 m .52609 .38176 L .52588 .38185 L F
.52577 .38201 m .52557 .3819 L .52607 .38179 L F
.52588 .38178 m .52586 .38171 L .52601 .38177 L F
.52586 .38171 m .52601 .38177 L .52601 .38177 L F
.52607 .38179 m .52554 .38185 L .52597 .38173 L F
.52578 .38201 m .52578 .38201 L .5258 .38135 L F
.52578 .38198 m .5259 .38207 L .52578 .38199 L F
.52587 .38192 m .5259 .38207 L .52578 .38198 L F
.52536 .38227 m .52591 .382 L .52588 .38185 L F
.52552 .38238 m .52545 .3824 L .52591 .3819 L F
.52578 .38201 m .52584 .38204 L .52584 .38196 L F
.52588 .38178 m .52606 .38171 L .52604 .38168 L F
.52554 .38185 m .52555 .38184 L .52625 .38165 L F
.52578 .38136 m .5259 .38207 L .52576 .38135 L F
.52578 .38201 m .52584 .38196 L .5258 .38135 L F
.5259 .38191 m .52563 .38192 L .52563 .38192 L F
.52584 .382 m .52593 .382 L .52601 .38183 L F
.5261 .38247 m .52593 .38187 L .52594 .38187 L F
.52591 .38193 m .52596 .3819 L .52598 .3819 L F
.52591 .38193 m .52598 .3819 L .52605 .3819 L F
.52578 .38201 m .52591 .38193 L .52605 .3819 L F
.52614 .3818 m .52611 .38174 L .52613 .38171 L F
.52611 .38246 m .52598 .38203 L .52599 .38202 L F
.5261 .38247 m .52593 .38187 L .5261 .38247 L F
.52612 .38254 m .52591 .38208 L .52601 .38215 L F
.52589 .38269 m .52601 .38259 L .52616 .38158 L F
.52603 .38193 m .52617 .38184 L .52609 .3818 L F
.52614 .3818 m .52619 .38177 L .52615 .38181 L F
.52613 .38178 m .52611 .38176 L .52663 .38186 L F
.52605 .3819 m .52619 .38177 L .52631 .3818 L F
.52629 .38198 m .52627 .38165 L p .5262 .38188 L F P
0 g
s
.52631 .3818 m .52619 .38177 L .52645 .38174 L .67 .731 .896 r
F
.52613 .38179 m .52622 .38162 L .52615 .38166 L F
.52611 .38176 m .52625 .38165 L .52611 .38176 L F
.5262 .38169 m .52617 .38171 L .52613 .38179 L F
.52611 .38176 m .52609 .38176 L .52609 .3818 L F
.5262 .38187 m .52627 .38165 L .52626 .38164 L F
.52617 .38183 m .52626 .38164 L .5262 .38169 L F
.52645 .38174 m .52613 .38178 L .52627 .38164 L F
.52608 .38181 m .52609 .38178 L .52609 .38178 L F
.52609 .38178 m .52611 .38176 L .52609 .38178 L F
.52609 .38178 m .52611 .38176 L .52609 .38177 L F
.52613 .38178 m .52611 .38176 L .52627 .38164 L F
.52656 .38168 m .52656 .38168 L .52718 .38107 L F
.52635 .38174 m .52709 .38129 L .52609 .38176 L F
.5261 .38175 m .52613 .38176 L .52611 .38176 L F
.52613 .38176 m .52663 .38184 L .52611 .38176 L F
.52613 .38176 m .52611 .38176 L .52611 .38176 L F
.52635 .38174 m .52611 .38176 L .52609 .3818 L F
.52613 .38178 m .52607 .38179 L .52611 .38176 L F
.5261 .38175 m .52605 .38169 L .52663 .38184 L F
.52617 .38184 m .52635 .38174 L .52613 .38179 L F
.52646 .38193 m .52663 .38186 L .52664 .38187 L F
.52601 .38177 m .52601 .38177 L .52666 .382 L F
.52666 .382 m .52666 .382 L .52699 .38212 L F
.52601 .38177 m .52666 .382 L .52666 .382 L F
.52666 .3819 m .5263 .38192 L .52631 .3818 L F
.52631 .3819 m .52631 .3819 L .52643 .38194 L F
.5262 .38187 m .52631 .3819 L .52631 .3819 L F
.5262 .38187 m .5262 .38187 L .52631 .3819 L F
.52611 .3822 m .52627 .38165 L .52611 .3822 L F
.52618 .38202 m .52642 .38181 L p .52559 .38223 L F P
0 g
s
.52664 .38187 m .52663 .38186 L .52666 .38187 L .67 .731 .896 r
F
.52605 .38175 m .52663 .38186 L .52663 .38186 L F
.52646 .38193 m .52666 .38187 L .52707 .38195 L F
.52683 .38195 m .52631 .3818 L .52667 .38186 L F
.52629 .38198 m .5266 .38171 L p .52647 .38178 L F P
0 g
s
.52602 .38165 m .52577 .38166 L .52577 .38166 L .67 .731 .896 r
F
.52577 .38166 m .52564 .38167 L .52577 .38166 L F
.52577 .38166 m .52564 .38167 L .52564 .38166 L F
.52475 .38095 m .52564 .38167 L .5257 .38155 L F
.52602 .38165 m .52581 .3817 L .52564 .38167 L F
.52586 .38171 m .52527 .3815 L .52584 .38164 L F
.52586 .38171 m .52527 .3815 L .52586 .38171 L F
.52576 .38133 m .52301 .3801 L .52584 .38143 L F
.52301 .3801 m .52586 .38146 L .52585 .38144 L F
.52527 .3815 m .525 .38136 L p .52482 .38092 L F P
0 g
s
.52527 .3815 m .52482 .38092 L .52476 .38077 L .67 .731 .896 r
F
.52301 .3801 m .52556 .3813 L .52556 .3813 L F
.5256 .38166 m .52491 .38193 L .5253 .38167 L F
.5253 .38167 m .5233 .38214 L .52364 .38172 L F
.52527 .38171 m .51782 .38227 L .52562 .38191 L F
.51782 .38227 m .51758 .38229 L .51778 .38228 L F
.51782 .38227 m .51778 .38228 L .52562 .38191 L F
.52611 .3822 m .52629 .38198 L .5262 .38188 L F
.52607 .38218 m .52617 .38183 L .52613 .38179 L F
.5259 .38208 m .5261 .38175 L .52589 .38207 L F
.52593 .38213 m .52602 .38209 L .52608 .38181 L F
.52588 .38178 m .52643 .38194 L .52643 .38194 L F
.52629 .38198 m .52618 .38185 L .52631 .3818 L F
.52625 .38165 m .52625 .38165 L .52627 .38164 L F
.52612 .38175 m .52616 .38158 L .52609 .38177 L F
.52663 .38183 m .52605 .38169 L .5266 .38171 L F
.5262 .38187 m .5266 .38171 L .52647 .38173 L F
.52623 .3819 m .5266 .38171 L .5262 .38187 L F
.52544 .38229 m .52623 .3819 L .5262 .38187 L F
.52513 .38246 m .52546 .38229 L .52544 .38229 L F
.52552 .38238 m .52591 .3819 L .52592 .38193 L F
.52546 .38229 m .52623 .3819 L .52544 .38229 L F
.52629 .38198 m .52626 .38195 L .52652 .38172 L F
.52673 .3819 m .52623 .38191 L .52623 .38191 L F
.52643 .38194 m .52643 .38194 L .52666 .382 L F
.52588 .38178 m .52666 .382 L .52667 .38202 L F
.52683 .38195 m .52629 .38198 L p .5263 .38192 L F P
0 g
s
.52684 .38194 m .52684 .38194 L .52626 .38195 L .67 .731 .896 r
F
.52629 .38198 m .52578 .38201 L p .52618 .38185 L F P
0 g
s
.52594 .3821 m .52608 .38181 L .5261 .38175 L .67 .731 .896 r
F
.52513 .38246 m .52629 .38198 L .52559 .38223 L F
.52593 .38213 m .52594 .3821 L .52594 .3821 L F
.52594 .3821 m .52608 .38181 L .52594 .3821 L F
.52611 .38176 m .52625 .38165 L .52627 .38164 L F
.5261 .38175 m .52616 .38158 L .5261 .38175 L F
.52607 .38171 m .5261 .38175 L .52614 .38157 L F
.52622 .38162 m .52618 .38159 L .52615 .38166 L F
.52627 .38164 m .52625 .38165 L .52626 .38164 L F
.5262 .38169 m .52626 .38164 L .52622 .38162 L F
.52582 .38141 m .52581 .38138 L .52582 .38139 L F
.52582 .38141 m .52581 .38138 L .52582 .38141 L F
.52602 .38166 m .52582 .38141 L .5258 .38132 L F
.5258 .38138 m .52607 .38171 L .52614 .38157 L F
.52627 .38165 m .52625 .38145 L p .52622 .38162 L F P
0 g
s
.5266 .38171 m .52605 .38169 L .52578 .38133 L .67 .731 .896 r
F
.52586 .38171 m .52587 .38171 L .52601 .38177 L F
.52595 .38173 m .52546 .38186 L .52586 .38171 L F
.52579 .38135 m .52576 .38133 L .52579 .38135 L F
.52552 .3813 m .52573 .38149 L .52574 .38147 L F
.52566 .38137 m .52552 .3813 L .52562 .38138 L F
.52584 .38164 m .52527 .3815 L .52571 .38128 L F
.52576 .38125 m .52578 .38136 L .52576 .38135 L F
.52577 .38124 m .52579 .38137 L .52576 .38125 L F
.52579 .38137 m .52578 .38137 L .52576 .38125 L F
.52582 .38141 m .52579 .38137 L .52576 .38117 L F
.52576 .38117 m .52577 .38124 L .52576 .38125 L F
.52569 .38128 m .5258 .38135 L .52575 .38059 L F
.52575 .38132 m .52571 .38128 L .52573 .38127 L F
.52584 .38164 m .52571 .38128 L .52575 .38132 L F
.52575 .38134 m .52578 .38201 L .5258 .38138 L F
.5257 .38137 m .52578 .38201 L .52575 .38134 L F
.52668 .38187 m .52667 .38187 L .52621 .38188 L F
.52673 .3819 m .52671 .38189 L .52623 .38191 L F
.52683 .38195 m .5263 .38192 L .52666 .3819 L F
.52715 .38208 m .52738 .38214 L .52711 .38215 L F
.52715 .38208 m .52716 .38206 L .52738 .38214 L F
.52833 .38258 m .52685 .38191 L .52842 .38291 L F
.52867 .38295 m .52842 .38291 L .52893 .38324 L F
.52833 .38258 m .52842 .38291 L .52867 .38295 L F
.5269 .38191 m .52645 .38174 L .52691 .38191 L F
.52691 .38191 m .52645 .38174 L .52716 .38165 L F
.52703 .38193 m .52699 .38192 L .52661 .38171 L F
.52699 .38192 m .52663 .38183 L .52661 .38171 L F
.52661 .38171 m .52663 .38183 L .5266 .38171 L F
.52707 .38195 m .52689 .38191 L .52703 .38193 L F
.52663 .38186 m .52689 .38191 L .52707 .38195 L F
.52703 .38194 m .52661 .38171 L .52679 .38189 L F
.52707 .38195 m .52703 .38193 L .52703 .38194 L F
.52703 .38193 m .52661 .38171 L .52703 .38194 L F
.52708 .38183 m .52716 .38165 L .52753 .3816 L F
.52691 .38191 m .52716 .38165 L .52708 .38183 L F
.52809 .38189 m .52683 .38195 L p .52753 .3816 L F P
0 g
s
.52684 .38194 m .52707 .38194 L .52684 .38194 L .67 .731 .896 r
F
.52683 .38195 m .52707 .38194 L p .52684 .38195 L F P
0 g
s
.52683 .38195 m .52667 .38186 L .52691 .38191 L .67 .731 .896 r
F
.52687 .38197 m .52721 .38197 L .52721 .38197 L F
.52716 .38197 m .52716 .38197 L .52687 .38197 L F
.52717 .38197 m .52687 .38191 L .52714 .38204 L F
.52907 .38281 m .52716 .38206 L .5272 .38198 L F
.52717 .38196 m .52714 .38204 L .5276 .38225 L F
.52844 .38265 m .52699 .38212 L .52707 .38195 L F
.52707 .38195 m .52679 .38189 L .52727 .38237 L F
.53923 .38817 m .52704 .38234 L p .52844 .38265 L F P
0 g
s
.52738 .38239 m .52727 .38237 L .52761 .3827 L .67 .731 .896 r
F
.52692 .38228 m .52749 .38231 L .52753 .38243 L F
.52692 .38228 m .52699 .38212 L .52749 .38231 L F
.52707 .38195 m .52727 .38237 L .52738 .38239 L F
.52689 .38191 m .52605 .38169 L .52703 .38193 L F
.52691 .3819 m .52692 .38189 L .5268 .38189 L F
.52682 .3819 m .5268 .38189 L .52671 .3819 L F
.52691 .3819 m .5268 .38189 L .52682 .3819 L F
.5266 .38171 m .5268 .38154 L p .52647 .38173 L F P
0 g
s
.5268 .38154 m .52629 .38198 L p .52687 .3814 L .67 .731 .896 r
F P
0 g
s
.52672 .3819 m .52671 .3819 L .52624 .38192 L .67 .731 .896 r
F
.52601 .38177 m .52586 .38171 L .5261 .38176 L F
.52607 .38175 m .52597 .38173 L .52606 .3817 L F
.52625 .38165 m .52546 .38186 L .52626 .38164 L F
.52554 .38185 m .52625 .38165 L .52625 .38165 L F
.52586 .38171 m .5261 .38175 L .52611 .38176 L F
.52566 .38137 m .52602 .38165 L .526 .38163 L F
.52552 .3813 m .5261 .38176 L .52606 .3817 L F
.52586 .38146 m .52566 .38137 L .526 .38163 L F
.52605 .38169 m .52584 .38164 L .52575 .38132 L F
.52595 .38173 m .52586 .38171 L .52602 .38165 L F
.52586 .38171 m .52586 .38171 L .52587 .38171 L F
.52586 .38171 m .52611 .38176 L .52605 .38175 L F
.52586 .38171 m .52584 .38164 L .52605 .38169 L F
.52586 .38171 m .52605 .38169 L .5261 .38175 L F
.5258 .38138 m .52584 .38196 L .52607 .38171 L F
.52601 .38182 m .52593 .38155 L .52603 .38181 L F
.52575 .38132 m .5258 .38138 L .5258 .38135 L F
.52605 .38169 m .52575 .38132 L .52573 .38127 L F
.52571 .38127 m .52598 .38161 L .52624 .38178 L F
.52593 .38155 m .52591 .38146 L .52594 .38156 L F
.52593 .38155 m .52594 .38156 L .52603 .38181 L F
.52601 .38182 m .52599 .38183 L .52591 .38148 L F
.52592 .38148 m .52591 .38148 L .52591 .38146 L F
.52601 .38182 m .52591 .38148 L .52592 .38148 L F
.52597 .3819 m .52614 .3818 L .52606 .38189 L F
.52585 .38216 m .52593 .38213 L .5261 .38175 L F
.52597 .3819 m .52606 .38189 L .52605 .3819 L F
.52596 .3819 m .52597 .3819 L .52605 .3819 L F
.52587 .38147 m .52597 .38185 L .52572 .38143 L F
.52626 .38195 m .52585 .38195 L .52585 .38195 L F
.52603 .38244 m .52609 .38219 L .52607 .38218 L F
.52634 .38196 m .52637 .38195 L .52515 .38197 L F
.52584 .38196 m .52584 .382 L .52601 .38183 L F
.52578 .38201 m .52607 .38179 L .52619 .38177 L F
.52564 .38193 m .52653 .3819 L .52563 .38192 L F
.52563 .38192 m .52693 .38188 L .52696 .38186 L F
.52597 .38185 m .526 .38198 L .52591 .3819 L F
.52617 .38184 m .52613 .38179 L .52609 .3818 L F
.52614 .3818 m .52615 .38181 L .52605 .3819 L F
.52625 .38193 m .52658 .38162 L .52626 .38195 L F
.52508 .38199 m .52508 .38199 L .52373 .382 L F
.52373 .382 m .52509 .38199 L .52508 .38199 L F
.52372 .38199 m .52517 .38198 L .52514 .38198 L F
.5263 .38198 m .52373 .382 L .52373 .382 L F
.52482 .38206 m .52357 .38213 L p .52475 .38197 L F P
0 g
s
.52367 .38212 m .52578 .38201 L p .52359 .38205 L .67 .731 .896 r
F P
0 g
s
.52525 .38196 m .52027 .38256 L .52077 .38236 L .67 .731 .896 r
F
.52624 .38192 m .52624 .38192 L .52587 .38193 L F
.52562 .38192 m .52665 .38187 L .52562 .38191 L F
.52665 .38187 m .52711 .38185 L .52665 .38187 L F
.52665 .38187 m .52665 .38187 L .52562 .38191 L F
.52598 .38161 m .5261 .38175 L .52618 .38174 L F
.5266 .38171 m .52578 .38133 L .52584 .38132 L F
.52626 .38195 m .52626 .38195 L .52585 .38195 L F
.52578 .38201 m .52577 .38201 L p .52607 .38179 L F P
0 g
s
.52691 .3819 m .52566 .38194 L .52567 .38194 L .67 .731 .896 r
F
.52558 .38195 m .52707 .38194 L .5271 .38189 L F
.52621 .38188 m .52594 .38212 L .52615 .38182 L F
.52612 .3822 m .52603 .3819 L .52604 .38188 L F
.52601 .38177 m .5261 .38176 L .52611 .38176 L F
.52629 .38198 m .52652 .38172 L .52653 .38172 L F
.5259 .38135 m .52589 .38138 L .52665 .38197 L F
.52614 .38172 m .52604 .3818 L .52586 .38082 L F
.52597 .38185 m .52591 .3819 L .52572 .38143 L F
.52604 .3818 m .52603 .38181 L .52595 .38147 L F
.52301 .3801 m .52265 .38 L .52586 .38146 L F
.52573 .38127 m .52527 .3815 L .52476 .38077 L F
.52505 .38099 m .5258 .38169 L .5261 .38175 L F
.52578 .38201 m .52629 .38198 L p .52581 .38198 L F P
0 g
s
.52574 .38198 m .52578 .38201 L .52581 .38198 L .67 .731 .896 r
F
.52578 .38201 m .52578 .38201 L .52581 .38198 L F
.52585 .382 m .52593 .38201 L .52593 .382 L F
.52612 .38243 m .52601 .38241 L .52587 .38193 L F
.52591 .3819 m .52587 .38193 L .52572 .38142 L F
.52601 .38259 m .52611 .3822 L .52609 .38219 L F
.52601 .38259 m .52611 .3822 L .52611 .3822 L F
.52612 .38243 m .52587 .38193 L .52591 .3819 L F
.52572 .38143 m .52572 .38142 L .5257 .38137 L F
.52612 .38243 m .52572 .38142 L .52572 .38143 L F
.52624 .382 m .52718 .38107 L .52718 .38107 L F
.52611 .38175 m .52709 .38129 L .52617 .38162 L F
.52657 .38158 m .52702 .38118 L .52657 .38158 L F
.52657 .38158 m .52657 .38157 L .52702 .38118 L F
.52664 .38157 m .52691 .38132 L .52667 .38158 L F
.52644 .38157 m .52731 .38121 L .52692 .38124 L F
.52606 .38178 m .52621 .38188 L .52613 .38179 L F
.5266 .38171 m .5259 .38135 L .52636 .38173 L F
.5261 .38175 m .52608 .38172 L .52611 .38173 L F
.5261 .38175 m .52611 .38173 L .52621 .38174 L F
.52606 .38178 m .52591 .3819 L .52621 .38188 L F
.52623 .38191 m .52623 .38191 L .52565 .38193 L F
.52607 .38179 m .52611 .38176 L .52611 .38176 L F
.52599 .38201 m .5261 .38175 L .52615 .38182 L F
.52584 .38196 m .52627 .38195 L .52585 .38195 L F
.52627 .38195 m .52684 .38194 L .52626 .38195 L F
.52627 .38195 m .52626 .38195 L .52585 .38195 L F
.52628 .38197 m .52629 .38198 L .52633 .38197 L F
.52574 .38198 m .52629 .38198 L .52628 .38197 L F
.526 .38208 m .52596 .3821 L .52621 .38188 L F
.5262 .38187 m .52647 .38173 L .52617 .38184 L F
.52622 .38189 m .52639 .38173 L .5264 .38173 L F
.52611 .38176 m .52663 .38186 L .52611 .38176 L F
.52647 .38173 m .5264 .38173 L .52617 .38184 L F
.52622 .38189 m .52657 .38157 L .52657 .38158 L F
.526 .38208 m .52622 .38189 L .52622 .38189 L F
.52622 .38189 m .52657 .38157 L .52622 .38189 L F
.52589 .38138 m .5262 .38174 L .52634 .38173 L F
.52573 .38127 m .52588 .38141 L .52589 .38138 L F
.52588 .38141 m .5262 .38174 L .52589 .38138 L F
.52621 .38188 m .52615 .38182 L .52642 .38151 L F
.52622 .38176 m .52624 .38178 L .52626 .38177 L F
.52622 .38176 m .52626 .38177 L .52634 .38173 L F
.5262 .38174 m .52622 .38176 L .52634 .38173 L F
.52661 .38171 m .5266 .38171 L .52665 .38197 L F
.52629 .38198 m .52659 .38165 L .52659 .38168 L F
.52658 .38162 m .52658 .38163 L .52626 .38195 L F
.526 .38208 m .52657 .38158 L .52657 .38158 L F
.5266 .38171 m .52636 .38173 L .52648 .38183 L F
.52663 .38186 m .52648 .38183 L .52665 .38197 L F
.5266 .38171 m .52648 .38183 L .52663 .38186 L F
.52615 .38182 m .5261 .38175 L .52621 .38174 L F
.5261 .38175 m .52613 .38178 L .52634 .3818 L F
.52634 .38173 m .52624 .38178 L .52646 .38182 L F
.52667 .38186 m .52663 .38186 L .52665 .38185 L F
.52661 .38171 m .52663 .38186 L .52679 .38189 L F
.5261 .38175 m .52634 .3818 L .52698 .38185 L F
.52618 .38174 m .5261 .38175 L .52624 .38178 L F
.52692 .38131 m .52702 .38119 L .52703 .38121 L F
.52571 .37913 m .52582 .38005 L .52573 .37999 L F
.52582 .38005 m .52591 .38074 L .52573 .37999 L F
.52573 .37999 m .52591 .38074 L .52576 .38117 L F
.52558 .38039 m .52578 .38063 L .52558 .37988 L F
.52578 .38063 m .52623 .38115 L .52558 .37988 L F
.52552 .37133 m .52601 .37804 L p .52571 .37913 L F P
0 g
s
.52623 .38115 m .52552 .37133 L p .52558 .37988 L .67 .731 .896 r
F P
0 g
s
.52591 .38074 m .52597 .38125 L .52576 .38117 L .67 .731 .896 r
F
.52558 .37937 m .52598 .38148 L .52547 .37944 L F
.52558 .38039 m .52559 .38047 L .52575 .38059 L F
.52573 .38127 m .52571 .38127 L .52585 .38141 L F
.52573 .38127 m .52585 .38141 L .52585 .38139 L F
.52569 .38128 m .5257 .38137 L .52575 .38134 L F
.52569 .38128 m .5258 .38138 L .52575 .38132 L F
.52582 .38139 m .52581 .38138 L .52576 .38117 L F
.52584 .38132 m .52578 .38133 L .52573 .38127 L F
.52597 .38125 m .5258 .38132 L .52576 .38117 L F
.5259 .38135 m .52573 .38127 L .52589 .38138 L F
.52547 .37944 m .52591 .38148 L .5257 .38137 L F
.52575 .38059 m .5258 .38135 L .52623 .38115 L F
.52595 .38147 m .52591 .38146 L .52547 .37944 L F
.52546 .3798 m .52558 .38112 L .52598 .38016 L F
.52531 .37987 m .52558 .38112 L .52546 .3798 L F
.52558 .38112 m .52566 .38121 L .52598 .38016 L F
.52138 .37968 m .52502 .38128 L .52498 .38123 L F
.52387 .38078 m .52414 .3809 L .52414 .3809 L F
.52414 .3809 m .52605 .38177 L .52414 .3809 L F
.52315 .38046 m .52388 .38079 L .52387 .38078 L F
.52388 .38079 m .52605 .38177 L .52387 .38078 L F
.52248 .38018 m .52605 .38177 L .52247 .38016 L F
.51269 .37632 m .51326 .37575 L p .52336 .38026 L F P
0 g
s
.52319 .38034 m .51269 .37632 L .52336 .38026 L .67 .731 .896 r
F
.51699 .37798 m .525 .38143 L .525 .38142 L F
.51699 .37798 m .52548 .38162 L .52548 .38162 L F
.52281 .38053 m .52413 .38108 L p .52275 .38046 L F P
0 g
s
.52394 .38114 m .5237 .38093 L .52515 .38144 L .67 .731 .896 r
F
.52413 .38108 m .52587 .38181 L p .5241 .38104 L F P
0 g
s
.52275 .38046 m .52413 .38108 L .5241 .38104 L .67 .731 .896 r
F
.51634 .37784 m .52281 .38053 L p .51699 .37798 L F P
0 g
s
.51699 .37798 m .52281 .38053 L .52275 .38046 L .67 .731 .896 r
F
.51699 .37798 m .52497 .3814 L .52505 .38139 L F
.52314 .38047 m .52308 .38055 L .52551 .38158 L F
.52138 .37968 m .52089 .37963 L .52308 .38055 L F
.52138 .37968 m .52308 .38055 L .52314 .38047 L F
.51269 .37632 m .51634 .37784 L p .51699 .37798 L F P
0 g
s
.52491 .38141 m .51269 .37632 L p .52472 .38109 L .67 .731 .896 r
F P
0 g
s
.51326 .37575 m .52517 .38144 L p .52475 .38095 L .67 .731 .896 r
F P
0 g
s
.52301 .3801 m .51326 .37575 L .52265 .38 L .67 .731 .896 r
F
.525 .38136 m .51326 .37575 L p .52476 .38077 L F P
0 g
s
.51389 .37521 m .5242 .38084 L p .52467 .38072 L .67 .731 .896 r
F P
0 g
s
.52217 .37913 m .51565 .37617 L .51457 .37469 L .67 .731 .896 r
F
.52558 .38112 m .52172 .37919 L .52217 .37913 L F
.52172 .37919 m .51565 .37617 L .52217 .37913 L F
.52581 .38125 m .52561 .38115 L .52558 .38112 L F
.52561 .38115 m .51761 .37715 L .52558 .38112 L F
.51761 .37715 m .51565 .37617 L .51762 .37715 L F
.51761 .37715 m .51762 .37715 L .52558 .38112 L F
.52623 .38164 m .52611 .38158 L .52599 .38105 L F
.52621 .38149 m .52598 .38016 L p .52602 .38146 L F P
0 g
s
.52663 .38173 m .52582 .38132 L .52582 .3813 L .67 .731 .896 r
F
.52614 .38172 m .52586 .38082 L .52595 .38087 L F
.52598 .38148 m .52595 .38147 L .52547 .37944 L F
.52566 .38121 m .52603 .38153 L .52598 .38016 L F
.52586 .38145 m .52572 .38143 L .5257 .38137 L F
.52591 .38148 m .52572 .38143 L .52586 .38145 L F
.52571 .38127 m .52551 .38129 L .52598 .38161 L F
.52584 .38143 m .52603 .38153 L .52566 .38121 L F
.52596 .38219 m .52687 .38133 L .52692 .38131 L F
.52609 .38219 m .52617 .38183 L .52607 .38218 L F
.52519 .38292 m .52629 .38198 L p .52513 .38246 L F P
0 g
s
.52596 .38219 m .52624 .38192 L .52596 .38219 L .67 .731 .896 r
F
.52647 .38173 m .5268 .38154 L .5264 .38173 L F
.52624 .38192 m .52687 .38133 L .52624 .38192 L F
.52624 .38192 m .52624 .38192 L .52596 .38219 L F
.52653 .3819 m .52654 .38189 L .52623 .3819 L F
.52623 .3819 m .52623 .3819 L .52563 .38192 L F
.52653 .3819 m .52623 .3819 L .52623 .3819 L F
.52605 .38169 m .52913 .38194 L .52911 .3819 L F
.54226 .38114 m .52809 .38189 L p .52753 .3816 L F P
0 g
s
.52739 .38156 m .52698 .38185 L .54226 .38114 L .67 .731 .896 r
F
.53432 .38115 m .52826 .38169 L .53403 .38106 L F
.52604 .38244 m .52617 .38183 L .52603 .38244 L F
.526 .38208 m .52621 .38188 L .52622 .38189 L F
.52497 .38336 m .52622 .3819 L .52622 .3819 L F
.52497 .38336 m .52499 .38333 L .52622 .3819 L F
.52588 .38226 m .52622 .3819 L .52624 .38192 L F
.52577 .38248 m .52576 .38248 L .52601 .38224 L F
.52578 .38201 m .52592 .38318 L .52584 .38204 L F
.52578 .38201 m .5259 .38222 L .5258 .38218 L F
.52598 .38251 m .52592 .38219 L .52592 .38218 L F
.52371 .38451 m .52593 .3823 L .52594 .3823 L F
.52597 .3823 m .5258 .38246 L p .52596 .3823 L F P
0 g
s
.52589 .38226 m .52596 .38244 L .52586 .38232 L .67 .731 .896 r
F
.52585 .38216 m .52589 .38269 L .52602 .38209 L F
.5259 .38222 m .52601 .38241 L .52588 .38227 L F
.5259 .38222 m .52588 .38227 L .5258 .38218 L F
.52593 .38215 m .52596 .3821 L .526 .38208 L F
.52322 .38453 m .52594 .38212 L .52593 .38215 L F
.5217 .38587 m .52323 .38452 L .52322 .38453 L F
.52323 .38452 m .52594 .38212 L .52322 .38453 L F
.52581 .38243 m .52628 .38197 L .52628 .38197 L F
.52371 .38451 m .52581 .38243 L .52581 .38243 L F
.52581 .38243 m .52628 .38197 L .52581 .38243 L F
.52592 .38219 m .5259 .38207 L .5259 .38208 L F
.5262 .38387 m .52592 .38219 L .52592 .38219 L F
.52592 .38219 m .5259 .38207 L .52592 .38219 L F
.52625 .38412 m .5262 .38387 L .5262 .38387 L F
.5262 .38387 m .5259 .38207 L .5262 .38387 L F
.52581 .38354 m .52597 .38279 L .52595 .38278 L F
.52598 .38251 m .52625 .38412 L .52597 .38251 L F
.52589 .38269 m .52592 .38318 L .52601 .38259 L F
.5258 .38249 m .5258 .38269 L .52587 .3825 L F
.52582 .3824 m .52629 .38442 L .52579 .38249 L F
.5258 .38218 m .52612 .383 L .52592 .38318 L F
.52625 .38412 m .5262 .38387 L .5262 .38387 L F
.52625 .38412 m .52659 .38622 L .52624 .38413 L F
.52618 .38584 m .52621 .38463 L .52621 .38463 L F
.52621 .38463 m .52629 .38198 L .52621 .38463 L F
.52615 .38267 m .52659 .38622 L .52597 .38245 L F
.52625 .38373 m .52629 .38198 L p .52624 .38372 L F P
0 g
s
.52636 .38293 m .52659 .38622 L p .52615 .38267 L .67 .731 .896 r
F P
0 g
s
.52605 .39178 m .52625 .38373 L p .52601 .39197 L .67 .731 .896 r
F P
0 g
s
.52601 .39197 m .52625 .38373 L .52624 .38372 L .67 .731 .896 r
F
.52582 .38389 m .52659 .38622 L .52585 .38496 L F
.52629 .38442 m .52659 .38622 L .52582 .38389 L F
.52601 .39197 m .52618 .38584 L .52618 .38584 L F
.5256 .38369 m .52399 .39242 L .52555 .38362 L F
.52554 .3836 m .52499 .38679 L .52551 .38356 L F
.52537 .38435 m .52503 .38634 L .52565 .38395 L F
.52503 .38634 m .52458 .38897 L .52551 .38497 L F
.52577 .38341 m .52501 .39249 L .52559 .38307 L F
.52596 .38525 m .52603 .39253 L .52559 .38453 L F
.52585 .38504 m .52597 .38645 L .52588 .38629 L F
.52585 .38496 m .52597 .38645 L .52585 .38504 L F
.52585 .38496 m .52671 .38782 L .52597 .38645 L F
.52659 .38622 m .52671 .38782 L p .52585 .38496 L F P
0 g
s
.52671 .38782 m .52705 .39252 L p .52588 .38629 L .67 .731 .896 r
F P
0 g
s
.52705 .39252 m .52636 .38293 L p .52592 .38318 L .67 .731 .896 r
F P
0 g
s
.52636 .38293 m .52624 .38237 L .52625 .38236 L .67 .731 .896 r
F
.52633 .3825 m .52636 .38293 L p .52629 .38257 L F P
0 g
s
.52636 .38293 m .52632 .38235 L p .52592 .38318 L .67 .731 .896 r
F P
0 g
s
.52612 .383 m .52614 .38305 L .52608 .38309 L .67 .731 .896 r
F
.52614 .38305 m .52641 .38376 L .52608 .38309 L F
.52608 .38309 m .52641 .38376 L .526 .38327 L F
.52612 .383 m .526 .38327 L .52592 .38318 L F
.52636 .38293 m .52615 .38267 L .52605 .38188 L F
.52577 .38239 m .52625 .38193 L .52626 .38195 L F
.52627 .3824 m .52605 .38186 L .52606 .38184 L F
.5263 .38246 m .52627 .3824 L .52627 .3824 L F
.52627 .3824 m .52605 .38186 L .52627 .3824 L F
.52628 .38239 m .52613 .38202 L .52616 .38184 L F
.5261 .38194 m .52606 .38184 L .5261 .38177 L F
.52623 .38164 m .5261 .38175 L .52698 .38185 L F
.52621 .38174 m .52611 .38173 L .52623 .38158 L F
.52623 .38164 m .52614 .38172 L .52613 .38168 L F
.52616 .38161 m .52613 .38168 L .52611 .38158 L F
.52611 .38173 m .52613 .38167 L .52623 .38158 L F
.52623 .38164 m .52613 .38168 L .52616 .38161 L F
.52611 .38173 m .52608 .38172 L .52613 .38167 L F
.52614 .38172 m .52613 .38173 L .52614 .38172 L F
.52606 .38184 m .52605 .38186 L .52604 .3818 L F
.52609 .38177 m .5261 .38175 L .5261 .38175 L F
.5261 .38175 m .52606 .38178 L .52613 .38178 L F
.52606 .38184 m .52604 .3818 L .5261 .38175 L F
.52606 .38184 m .5261 .38175 L .52614 .38172 L F
.52604 .38188 m .52601 .38182 L .52603 .38181 L F
.52605 .38186 m .52605 .38185 L .52605 .38185 L F
.52605 .38185 m .52603 .38181 L .52605 .38185 L F
.52605 .38185 m .52603 .38181 L .52604 .3818 L F
.52607 .38179 m .52597 .38173 L .52607 .38175 L F
.52589 .38176 m .52629 .38198 L p .5261 .38175 L F P
0 g
s
.52622 .38189 m .52621 .38188 L .52639 .38173 L .67 .731 .896 r
F
.52672 .3819 m .52624 .38192 L .52624 .38192 L F
.52621 .38189 m .52668 .38187 L .52621 .38188 L F
.52684 .38194 m .52626 .38195 L .52626 .38195 L F
.52629 .38198 m .52683 .38195 L p .52633 .38197 L F P
0 g
s
.52574 .38198 m .52683 .38195 L .52684 .38195 L .67 .731 .896 r
F
.52638 .38188 m .52669 .38187 L .52638 .38188 L F
.52626 .38195 m .52664 .38157 L .52667 .38158 L F
.52638 .38188 m .52638 .38188 L .52622 .38189 L F
.52624 .38192 m .52622 .3819 L .52685 .38134 L F
.52687 .38133 m .52685 .38134 L .52702 .38119 L F
.52624 .38192 m .52685 .38134 L .52687 .38133 L F
.52545 .38187 m .52541 .38185 L .52558 .38183 L F
.5263 .38198 m .5263 .38198 L .52373 .382 L F
.52577 .38201 m .52482 .38206 L p .52557 .3819 L F P
0 g
s
.52491 .38197 m .52692 .38189 L .52489 .38196 L .67 .731 .896 r
F
.52624 .38178 m .5261 .38175 L .52682 .3822 L F
.52613 .38179 m .52621 .38188 L .52665 .38186 L F
.52624 .38178 m .52682 .3822 L .52686 .3822 L F
.52575 .38175 m .52562 .38191 L .52591 .3819 L F
.52624 .38192 m .52587 .38193 L .52587 .38193 L F
.52584 .38196 m .52601 .38183 L .52607 .38171 L F
.52593 .38154 m .52612 .38243 L .52587 .38147 L F
.5257 .38137 m .52587 .38193 L .52578 .38201 L F
.52357 .38213 m .52353 .38211 L .52457 .38198 L F
.52459 .38199 m .52457 .38198 L .52607 .38179 L F
.52357 .38213 m .52457 .38198 L .52459 .38199 L F
.52525 .38196 m .52526 .38195 L .52556 .38192 L F
.52593 .38201 m .52608 .38172 L .5261 .38175 L F
.52543 .38229 m .52591 .382 L .52529 .38234 L F
.52584 .382 m .52593 .38201 L .52585 .382 L F
.52584 .382 m .52585 .38216 L .52593 .38201 L F
.52587 .38193 m .52593 .38214 L .52578 .38201 L F
.52588 .38226 m .52596 .38219 L .52596 .38219 L F
.52575 .38238 m .52625 .38193 L .52577 .38239 L F
.52629 .38198 m .52501 .38308 L p .52618 .38202 L F P
0 g
s
.52576 .38245 m .52576 .38245 L .52292 .385 L .67 .731 .896 r
F
.52292 .385 m .52576 .38245 L .52573 .38245 L F
.52554 .38265 m .52364 .38454 L .52541 .38251 L F
.52501 .38308 m .52469 .38335 L p .52502 .38306 L F P
0 g
s
.52501 .38308 m .52502 .38306 L .52618 .38202 L .67 .731 .896 r
F
.52575 .38175 m .52588 .38187 L .52602 .38177 L F
.52588 .38187 m .52591 .3819 L .52602 .38177 L F
.52602 .38177 m .52591 .3819 L .52606 .38178 L F
.5264 .38173 m .52639 .38173 L .52657 .38157 L F
.52653 .38172 m .52652 .38172 L .52659 .38165 L F
.52739 .38156 m .52623 .38164 L .52698 .38185 L F
.5261 .38175 m .52579 .38174 L .52606 .38178 L F
.52603 .38181 m .52594 .38156 L .52598 .3816 L F
.52467 .38072 m .5261 .38175 L .52598 .38161 L F
.52623 .38164 m .52576 .38168 L .5261 .38175 L F
.52531 .3823 m .52533 .3823 L .52599 .38177 L F
.52603 .38167 m .52528 .38237 L .52603 .38166 L F
.52528 .38237 m .52147 .38587 L .52529 .38234 L F
.52529 .38234 m .52539 .38228 L .52536 .38227 L F
.52526 .38235 m .52528 .38237 L .52521 .38239 L F
.52513 .38246 m .52543 .38229 L .52529 .38234 L F
.52528 .38237 m .52529 .38234 L .52603 .38166 L F
.52623 .38164 m .52621 .38153 L p .5262 .38162 L F P
0 g
s
.52687 .38098 m .52615 .38164 L .5262 .38152 L .67 .731 .896 r
F
.52651 .38147 m .52642 .38151 L .52687 .38098 L F
.52621 .38158 m .52656 .38147 L .52653 .38132 L F
.52636 .38153 m .52623 .38158 L .52652 .38131 L F
.52701 .38118 m .52682 .38135 L .52687 .38098 L F
.52682 .38135 m .52651 .38147 L .52687 .38098 L F
.52608 .38172 m .52607 .38171 L .52619 .38159 L F
.52623 .38158 m .52619 .38159 L .52687 .38098 L F
.52608 .38172 m .52619 .38159 L .52623 .38158 L F
.52603 .38166 m .52589 .38177 L .52605 .38169 L F
.52581 .3817 m .52491 .38193 L .5256 .38166 L F
.52576 .38168 m .52527 .38171 L .5261 .38175 L F
.5258 .38169 m .52589 .38176 L .52589 .38176 L F
.52589 .3817 m .52589 .38176 L .5261 .38175 L F
.5258 .38169 m .52589 .38176 L .52589 .3817 L F
.52464 .37819 m .52543 .38025 L .52457 .37822 L F
.52587 .38193 m .52587 .38193 L .52566 .38194 L F
.52585 .38195 m .52585 .38195 L .52558 .38195 L F
.5259 .38191 m .52563 .38192 L .5259 .38191 L F
.52584 .38196 m .52585 .38195 L .52558 .38195 L F
.52666 .38187 m .52666 .38187 L .52622 .38189 L F
.52537 .37925 m .52589 .38109 L .52519 .37934 L F
.5262 .38162 m .52621 .38153 L .5262 .38154 L F
.52621 .38153 m .52617 .38161 L .52634 .38155 L F
.5262 .38152 m .52617 .38161 L .52621 .38153 L F
.52621 .38174 m .52623 .38158 L .52636 .38153 L F
.52628 .38157 m .52629 .38158 L .52634 .38155 L F
.52617 .38161 m .52629 .38158 L .52628 .38157 L F
.52617 .38161 m .52616 .38164 L .52629 .38158 L F
.52634 .38155 m .52605 .38176 L .52638 .38156 L F
.52621 .38188 m .52642 .38151 L .52651 .38147 L F
.52682 .38135 m .52621 .38188 L .52651 .38147 L F
.52609 .38174 m .52607 .38171 L .5271 .38158 L F
.5271 .38158 m .5263 .38168 L .52623 .38164 L F
.52658 .38162 m .52664 .38157 L .52658 .38163 L F
.52666 .38187 m .52622 .38189 L .52622 .38189 L F
.5259 .38191 m .52622 .3819 L .5259 .38191 L F
.52622 .3819 m .52776 .38183 L .52622 .38189 L F
.52622 .3819 m .52622 .38189 L .5259 .38191 L F
.52593 .38198 m .52608 .38172 L .52593 .38201 L F
.52622 .38189 m .52638 .38188 L .52622 .38189 L F
.52634 .38196 m .52707 .38194 L .52637 .38195 L F
.52629 .38198 m .52614 .3818 L .52667 .38197 L F
.52667 .38202 m .52666 .382 L .52699 .38212 L F
.52691 .3819 m .52671 .3819 L .52672 .3819 L F
.52679 .38189 m .52665 .38197 L .52761 .3827 L F
.52668 .38205 m .52667 .38197 L .52729 .38216 L F
.52629 .38198 m .52667 .38197 L .52668 .38205 L F
.52691 .38132 m .52783 .38048 L .52687 .3814 L F
.53133 .37766 m .5268 .38154 L p .53134 .3774 L F P
0 g
s
.52879 .37949 m .52879 .37941 L .53265 .37557 L .67 .731 .896 r
F
.53218 .3762 m .52879 .37952 L p .53232 .37602 L F P
0 g
s
.52879 .37952 m .52879 .37949 L .53232 .37602 L .67 .731 .896 r
F
.52718 .38072 m .52719 .38079 L .53612 .37355 L F
.53143 .37735 m .53134 .3774 L .53145 .3773 L F
.53133 .37766 m .53134 .3774 L .53143 .37735 L F
.52487 .38195 m .52487 .38195 L .52372 .382 L F
.52359 .38205 m .52578 .38201 L .52574 .38198 L F
.52484 .38212 m .52027 .38256 L .52525 .38196 L F
.52369 .38216 m .52396 .3822 L .52553 .38205 L F
.52362 .38224 m .52397 .3822 L p .52352 .38218 L F P
0 g
s
.52352 .38218 m .52397 .3822 L .52369 .38216 L .67 .731 .896 r
F
.52563 .38192 m .52563 .38192 L .52266 .38205 L F
.52487 .38195 m .52487 .38195 L .52372 .382 L F
.52192 .38211 m .5253 .382 L .52515 .38197 L F
.52501 .38195 m .525 .38194 L .52354 .38201 L F
.52456 .38197 m .52489 .38196 L .52489 .38196 L F
.52458 .38198 m .52491 .38197 L .52456 .38197 L F
.52491 .38197 m .52489 .38196 L .52456 .38197 L F
.52493 .38199 m .51041 .38328 L .52503 .38191 L F
.52189 .38209 m .52458 .38198 L .52456 .38197 L F
.52181 .38221 m .524 .38196 L .52396 .38199 L F
.5234 .38202 m .52503 .38195 L .5234 .38202 L F
.52503 .38195 m .52501 .38195 L .52188 .38209 L F
.52371 .382 m .52487 .38195 L .52372 .382 L F
.52192 .38211 m .5246 .38199 L .52189 .38209 L F
.5246 .38199 m .52458 .38198 L .52189 .38209 L F
.52192 .38211 m .52367 .38212 L .52359 .38205 L F
.52354 .38201 m .52455 .38196 L .52454 .38196 L F
.52545 .38187 m .52181 .38221 L .52541 .38185 L F
.51516 .38295 m .52362 .38224 L .52352 .38218 L F
.52693 .38188 m .53144 .38171 L .52696 .38186 L F
.52819 .3818 m .52693 .38192 L p .52819 .3818 L F P
0 g
s
.52513 .38246 m .52549 .38226 L .52543 .38229 L .67 .731 .896 r
F
.52622 .38189 m .52622 .38189 L .525 .38194 L F
.52455 .38196 m .52487 .38195 L .52454 .38196 L F
.52487 .38195 m .52711 .38185 L .52488 .38195 L F
.52487 .38195 m .52488 .38195 L .52454 .38196 L F
.52582 .38115 m .52577 .38105 L .52578 .38104 L F
.52607 .38171 m .52605 .38169 L .52623 .38164 L F
.52615 .38164 m .52607 .38171 L .5262 .38152 L F
.52623 .38164 m .52605 .38168 L .52603 .38166 L F
.52613 .38171 m .5262 .38162 L .52617 .38161 L F
.52605 .38169 m .52608 .38173 L .52634 .38155 L F
.52629 .38198 m .52618 .38202 L .52626 .38195 L F
.5246 .38199 m .52483 .38198 L .52458 .38198 L F
.52483 .38198 m .52691 .3819 L .52485 .38197 L F
.52483 .38198 m .52485 .38197 L .52458 .38198 L F
.52654 .38345 m .52652 .38349 L .52632 .38256 L F
.54215 .38046 m .54198 .37979 L p .52726 .38152 L F P
0 g
s
.52629 .38238 m .52628 .38239 L .52614 .38172 L .67 .731 .896 r
F
.5268 .38154 m .52709 .38129 L p .5267 .38153 L F P
0 g
s
.5268 .38154 m .52687 .3814 L .53145 .3773 L .67 .731 .896 r
F
.52731 .38121 m .53199 .37769 L p .52692 .38124 L F P
0 g
s
.52784 .38081 m .52728 .38121 L .52788 .38075 L .67 .731 .896 r
F
.52659 .38168 m .52659 .38165 L .52687 .3814 L F
.52667 .38158 m .52691 .38132 L .52687 .3814 L F
.52666 .38162 m .52731 .38121 L .52644 .38157 L F
.52784 .38081 m .52675 .38164 L p .52728 .38121 L F P
0 g
s
.52601 .38176 m .52594 .38176 L .52603 .38167 L .67 .731 .896 r
F
.52607 .38171 m .52601 .38176 L .52603 .38167 L F
.52589 .38177 m .52605 .38176 L .52608 .38173 L F
.52601 .38176 m .52524 .38246 L .52594 .38176 L F
.52524 .38246 m .52515 .38254 L .52524 .38245 L F
.52539 .38228 m .52591 .382 L .52536 .38227 L F
.52524 .38246 m .52524 .38245 L .52594 .38176 L F
.51457 .37469 m .51518 .37429 L p .52514 .38074 L F P
0 g
s
.52514 .38074 m .51518 .37429 L .51571 .37449 L .67 .731 .896 r
F
.52622 .38189 m .52622 .38189 L .52487 .38195 L F
.52487 .38195 m .52666 .38187 L .52487 .38195 L F
.52489 .38196 m .52693 .38188 L .52489 .38196 L F
.52526 .37967 m .52531 .37987 L .52546 .3798 L F
.52595 .38087 m .52586 .38082 L .52524 .37759 L F
.52541 .37678 m .52612 .38095 L p .52524 .37759 L F P
0 g
s
.52612 .38095 m .52599 .38105 L .52524 .37759 L .67 .731 .896 r
F
.52524 .37759 m .52558 .37937 L .52547 .37944 L F
.52449 .37138 m .52541 .37678 L p .52524 .37759 L F P
0 g
s
.52598 .38016 m .52449 .37138 L p .52526 .37967 L .67 .731 .896 r
F P
0 g
s
.52611 .38176 m .52609 .38174 L .5271 .38158 L .67 .731 .896 r
F
.52633 .38174 m .52662 .38163 L .52627 .38174 L F
.52662 .38163 m .52666 .38162 L .52662 .38163 L F
.52662 .38163 m .52662 .38163 L .52627 .38174 L F
.52613 .38179 m .52662 .38163 L .52644 .38157 L F
.52615 .38182 m .52652 .38131 L .52653 .38138 L F
.5262 .38152 m .52638 .38156 L .52661 .38141 L F
.5266 .3813 m .52661 .38141 L .52758 .38077 L F
.5262 .38152 m .52661 .38141 L .5266 .3813 L F
.52621 .38153 m .52621 .38149 L p .5262 .38154 L F P
0 g
s
.52573 .38127 m .52467 .38072 L .52551 .38129 L .67 .731 .896 r
F
.5254 .38119 m .52549 .38115 L .52579 .3813 L F
.52567 .38131 m .52579 .3813 L .52662 .38172 L F
.5254 .38119 m .52579 .3813 L .52567 .38131 L F
.52623 .38164 m .52637 .38246 L p .52614 .38172 L F P
0 g
s
.52637 .38246 m .52634 .38253 L .52614 .38172 L .67 .731 .896 r
F
.52649 .38314 m .52647 .38315 L .52633 .38255 L F
.52634 .38253 m .52633 .38255 L .52614 .38172 L F
.52649 .38314 m .52633 .38255 L .52634 .38253 L F
.52184 .38553 m .52185 .38553 L .52393 .38361 L F
.52463 .38021 m .51598 .37465 L .51872 .37576 L F
.52438 .3832 m .52438 .3832 L .52603 .38167 L F
.52558 .38112 m .52495 .38075 L .52566 .38121 L F
.52467 .38072 m .52505 .38105 L .52505 .38099 L F
.5254 .38119 m .51565 .37617 L .52549 .38115 L F
.52569 .38125 m .52549 .38115 L .52561 .38115 L F
.52549 .38115 m .51565 .37617 L .52556 .38112 L F
.52549 .38115 m .52556 .38112 L .52561 .38115 L F
.52582 .38132 m .52569 .38125 L .52581 .38125 L F
.52569 .38125 m .52561 .38115 L .52581 .38125 L F
.52558 .38112 m .52566 .38121 L .52646 .38173 L F
.52558 .38112 m .52562 .38132 L .52566 .38121 L F
.52558 .38112 m .52578 .38118 L .52562 .38132 L F
.52519 .37934 m .52574 .38105 L .52558 .38112 L F
.52574 .38105 m .52578 .38118 L .52558 .38112 L F
.52579 .38174 m .52577 .38174 L .52606 .38178 L F
.52475 .38114 m .52589 .38176 L p .52483 .38086 L F P
0 g
s
.52467 .38072 m .52475 .38114 L .52483 .38086 L .67 .731 .896 r
F
.52505 .38105 m .5258 .38169 L .52505 .38099 L F
.5242 .38084 m .52475 .38114 L p .52467 .38072 L F P
0 g
s
.52572 .38167 m .51565 .37617 L p .52585 .38142 L .67 .731 .896 r
F P
0 g
s
.52437 .38079 m .52517 .38129 L p .52495 .38075 L .67 .731 .896 r
F P
0 g
s
.51457 .37469 m .52437 .38079 L p .52495 .38075 L .67 .731 .896 r
F P
0 g
s
.52517 .38129 m .51457 .37469 L p .52514 .38074 L .67 .731 .896 r
F P
0 g
s
.52579 .38118 m .52578 .38118 L .52576 .3811 L .67 .731 .896 r
F
.52582 .38115 m .52577 .38105 L .52582 .38115 L F
.52686 .3822 m .52682 .3822 L .52761 .3827 L F
.52753 .38243 m .52749 .38231 L .52844 .38265 L F
.52761 .3827 m .5386 .38871 L p .52744 .38214 L F P
0 g
s
.5386 .38871 m .52687 .3823 L p .52803 .38254 L .67 .731 .896 r
F P
0 g
s
.52744 .38269 m .53792 .38921 L p .52739 .38234 L .67 .731 .896 r
F P
0 g
s
.52744 .38214 m .52707 .38195 L .52761 .3827 L .67 .731 .896 r
F
.52687 .3823 m .5267 .3822 L p .52803 .38254 L F P
0 g
s
.5267 .3822 m .52729 .38216 L .52803 .38254 L .67 .731 .896 r
F
.52826 .38169 m .52672 .38183 L .52829 .38165 L F
.52601 .38178 m .52603 .38177 L .52614 .3818 L F
.5259 .38177 m .52603 .38177 L .52601 .38178 L F
.5259 .38177 m .526 .38176 L .52603 .38177 L F
.52603 .38166 m .52576 .3819 L .52572 .38191 L F
.52557 .38196 m .52584 .38196 L .52558 .38195 L F
.52589 .38177 m .52534 .38221 L .52605 .38176 L F
.52663 .38402 m .52616 .38244 L .5263 .38246 L F
.5259 .3813 m .52582 .3813 L .52581 .38125 L F
.52663 .38173 m .52582 .3813 L .5259 .3813 L F
.52591 .38193 m .52658 .38147 L .52655 .38149 L F
.52662 .38172 m .52558 .38112 L .52646 .38173 L F
.52605 .38186 m .52604 .38188 L .52603 .38181 L F
.52549 .38226 m .5262 .38187 L .52543 .38229 L F
.52575 .38229 m .52544 .38233 L .52608 .38172 L F
.52591 .38193 m .52591 .38194 L .52606 .38184 L F
.52629 .38198 m .52589 .38177 L p .52614 .3818 L F P
0 g
s
.52589 .38177 m .52608 .38173 L .52605 .38169 L .67 .731 .896 r
F
.52589 .38177 m .52589 .38176 L p .5259 .38177 L F P
0 g
s
.52589 .38177 m .5259 .38177 L .52614 .3818 L .67 .731 .896 r
F
.52634 .3818 m .52665 .38186 L .52698 .38185 L F
.52672 .38183 m .5262 .38187 L .5268 .3818 L F
.52692 .38189 m .52565 .38193 L .52565 .38193 L F
.52594 .38212 m .52599 .38201 L .52615 .38182 L F
.52603 .3819 m .52599 .38183 L .52601 .38182 L F
.52612 .3822 m .52602 .38193 L .52603 .3819 L F
.52622 .38189 m .52563 .38192 L .52622 .38189 L F
.52602 .38193 m .52599 .38183 L .52603 .3819 L F
.52591 .38193 m .52606 .38184 L .52607 .38183 L F
.52562 .38191 m .52621 .38189 L .52621 .38188 L F
.52622 .38189 m .52602 .3819 L .52602 .3819 L F
.52602 .3819 m .5259 .38191 L .52602 .3819 L F
.52602 .3819 m .5259 .38191 L .5259 .38191 L F
.52776 .38183 m .52776 .38182 L .5259 .38191 L F
.52602 .38193 m .52602 .38194 L .52599 .38183 L F
.52531 .3823 m .52513 .38246 L .52533 .3823 L F
.52576 .3819 m .52202 .38537 L .52572 .38191 L F
.52202 .38537 m .52147 .38587 L .52202 .38536 L F
.52202 .38537 m .52202 .38536 L .52572 .38191 L F
.52433 .38336 m .52607 .38171 L .52608 .38172 L F
.52397 .38369 m .52607 .38171 L .52398 .3837 L F
.52585 .38216 m .5259 .38208 L .52589 .38207 L F
.52593 .38214 m .5259 .38222 L .52578 .38201 L F
.52575 .38229 m .52593 .38198 L .52593 .38201 L F
.52603 .3819 m .52601 .38182 L .52604 .38188 L F
.5253 .382 m .52634 .38196 L .52515 .38197 L F
.526 .38198 m .52597 .38205 L .52591 .3819 L F
.52575 .38229 m .5261 .38175 L .52599 .38201 L F
.52456 .38289 m .52596 .38206 L .52606 .38184 L F
.52507 .38243 m .52147 .38587 L .52009 .38643 L F
.52572 .38191 m .52511 .38248 L .52507 .38243 L F
.52511 .38248 m .52147 .38587 L .52507 .38243 L F
.52605 .38176 m .52507 .38242 L .52608 .38175 L F
.52578 .38203 m .52484 .38212 L .52593 .3819 L F
.52479 .38206 m .5256 .38205 L .5254 .38201 L F
.52369 .38216 m .52481 .38209 L .52479 .38206 L F
.52567 .38194 m .52566 .38194 L .52458 .38198 L F
.52515 .38197 m .52557 .38196 L .52558 .38195 L F
.52593 .3819 m .52484 .38212 L .52525 .38196 L F
.52481 .38209 m .5256 .38205 L .52479 .38206 L F
.52405 .38325 m .52462 .38289 L .52456 .38289 L F
.52515 .38254 m .52438 .38324 L .52514 .38252 L F
.52462 .38289 m .52596 .38206 L .52456 .38289 L F
.52687 .38133 m .52702 .38119 L .52692 .38131 L F
.52655 .38149 m .52658 .38147 L .53199 .37769 L F
.52704 .38118 m .52702 .38118 L .53145 .3773 L F
.52703 .38121 m .52702 .38119 L .52783 .38048 L F
.53177 .37772 m .53092 .37837 L .53199 .37769 L F
.5308 .37783 m .53092 .37837 L .53177 .37772 L F
.52785 .38052 m .52783 .38048 L .53145 .3773 L F
.53145 .3773 m .52701 .38118 L .52687 .38098 L F
.5308 .37783 m .52722 .3807 L .53092 .37837 L F
.52722 .3807 m .52758 .38077 L .53199 .37769 L F
.53612 .37355 m .53133 .37766 L p .53145 .3773 L F P
0 g
s
.53199 .37769 m .53692 .37399 L p .5308 .37783 L .67 .731 .896 r
F P
0 g
s
.53362 .37631 m .52682 .38149 L .52707 .38093 L .67 .731 .896 r
F
.52682 .38149 m .52682 .38149 L .53362 .37631 L F
.52663 .38168 m .52794 .38064 L .5279 .3807 L F
.5268 .38152 m .52682 .38149 L .52794 .38064 L F
.5279 .3807 m .52794 .38064 L .53362 .37631 L F
.52725 .38123 m .52811 .38054 L .52812 .38056 L F
.52724 .38122 m .52811 .38054 L .52725 .38123 L F
.52672 .38163 m .5267 .38162 L .52811 .38054 L F
.52812 .38056 m .52811 .38054 L .53362 .37631 L F
.53353 .37653 m .52784 .38081 L p .53362 .37631 L F P
0 g
s
.52784 .38081 m .52788 .38075 L .53362 .37631 L .67 .731 .896 r
F
.52737 .38127 m .53767 .37445 L p .52675 .38128 L F P
0 g
s
.52472 .38213 m .51045 .3835 L p .52472 .38213 L .67 .731 .896 r
F P
0 g
s
.5234 .38202 m .5234 .38202 L .52188 .38209 L .67 .731 .896 r
F
.52267 .38205 m .52371 .382 L .52266 .38205 L F
.52371 .382 m .52372 .382 L .52266 .38205 L F
.52266 .38205 m .52354 .38201 L .52354 .38201 L F
.52426 .38194 m .52184 .38217 L .52471 .38176 L F
.51809 .38241 m .52209 .3822 L p .51758 .38229 L F P
0 g
s
.51758 .38229 m .52209 .3822 L .52192 .38211 L .67 .731 .896 r
F
.52461 .38183 m .51516 .38295 L .52478 .38206 L F
.52441 .38224 m .51064 .38417 L p .52453 .38184 L F P
0 g
s
.51064 .38417 m .52257 .3825 L p .52222 .38229 L .67 .731 .896 r
F P
0 g
s
.52689 .38201 m .52744 .38269 L .52739 .38234 L .67 .731 .896 r
F
.52694 .38219 m .52685 .38219 L .52761 .3827 L F
.52669 .38187 m .52668 .38187 L .52622 .38189 L F
.52646 .38182 m .52685 .38219 L .52694 .38219 L F
.52606 .38178 m .52665 .38186 L .52634 .3818 L F
.52696 .38186 m .52622 .38189 L .52622 .38189 L F
.52696 .38186 m .52696 .38186 L .52563 .38192 L F
.52646 .38182 m .52624 .38178 L .52685 .38219 L F
.52629 .38198 m .5267 .38221 L p .5261 .38175 L F P
0 g
s
.5267 .38221 m .52761 .3827 L p .52682 .3822 L .67 .731 .896 r
F P
0 g
s
.5261 .38175 m .5267 .38221 L .52682 .3822 L .67 .731 .896 r
F
.52184 .38553 m .52393 .38361 L .52393 .38361 L F
.52393 .38361 m .52393 .38361 L .52438 .3832 L F
.52393 .38361 m .52438 .3832 L .52438 .3832 L F
.52398 .3837 m .52434 .38336 L .52433 .38336 L F
.52434 .38336 m .52607 .38171 L .52433 .38336 L F
.52438 .38324 m .52336 .38416 L .52439 .3832 L F
.52336 .38416 m .52337 .38413 L .52393 .38361 L F
.52393 .38363 m .52393 .38361 L .52603 .38167 L F
.52336 .38416 m .52393 .38361 L .52393 .38363 L F
.52589 .38109 m .52583 .38114 L .52519 .37934 L F
.52579 .38101 m .52577 .38105 L .52519 .37934 L F
.52577 .38105 m .52576 .3811 L .52519 .37934 L F
.52662 .38164 m .52682 .38149 L .52682 .38149 L F
.5261 .3822 m .52617 .38183 L .5261 .38175 L F
.52632 .38235 m .52631 .38232 L p .52601 .38259 L F P
0 g
s
.52614 .38255 m .5261 .38247 L .52611 .38246 L .67 .731 .896 r
F
.52612 .38254 m .5261 .38247 L .5261 .38247 L F
.52603 .38252 m .52597 .38245 L .52612 .38254 L F
.52601 .38259 m .52631 .38232 L .52611 .3822 L F
.5263 .38246 m .52616 .38244 L .52605 .38186 L F
.52612 .3822 m .52607 .38217 L .52602 .38194 L F
.52612 .3822 m .52602 .38194 L .52602 .38193 L F
.52605 .38186 m .52612 .3822 L .52604 .38188 L F
.52612 .3822 m .52641 .38376 L .52607 .38217 L F
.52607 .3829 m .5261 .38175 L .52604 .38189 L F
.52608 .38318 m .52609 .38291 L .52607 .3829 L F
.52615 .38267 m .52603 .38252 L .52612 .38254 L F
.52614 .38255 m .52615 .38267 L .52612 .38254 L F
.52612 .38243 m .52641 .38376 L .52601 .38241 L F
.52592 .38318 m .52632 .38235 L .52601 .38259 L F
.52601 .38259 m .52604 .38244 L .52603 .38244 L F
.52602 .38244 m .52641 .38373 L .5258 .38218 L F
.52641 .38373 m .52641 .38376 L .52641 .38374 L F
.52641 .38373 m .52641 .38374 L .5258 .38218 L F
.52609 .38291 m .5261 .38175 L .52607 .3829 L F
.52605 .38186 m .5261 .38185 L .52606 .38184 L F
.52593 .38214 m .52601 .38241 L .5259 .38222 L F
.52601 .38241 m .52598 .3824 L .5258 .38218 L F
.52587 .38228 m .52588 .38226 L .52588 .38226 L F
.52588 .38226 m .52596 .38219 L .52588 .38226 L F
.52594 .38212 m .52596 .3821 L .52593 .38215 L F
.52587 .38228 m .52588 .38226 L .52588 .38226 L F
.52588 .38226 m .52622 .3819 L .52588 .38226 L F
.52588 .38226 m .52593 .38215 L .52622 .3819 L F
.52587 .38228 m .52593 .38215 L .52588 .38226 L F
.526 .38198 m .52612 .38243 L .52597 .38205 L F
.52601 .38241 m .52602 .38244 L .52598 .3824 L F
.52584 .3823 m .52606 .38328 L .52604 .38189 L F
.52606 .38328 m .52609 .38344 L .52609 .38329 L F
.52606 .38328 m .52609 .38329 L .52604 .38189 L F
.52424 .3831 m .52424 .38312 L .52456 .38289 L F
.52454 .38289 m .52456 .38289 L .52591 .38194 L F
.52424 .3831 m .52456 .38289 L .52454 .38289 L F
.52637 .38248 m .52637 .38246 L p .52611 .38292 L F P
0 g
s
.52633 .38255 m .52632 .38256 L .52628 .38239 L .67 .731 .896 r
F
.52633 .38255 m .52628 .38239 L .52629 .38238 L F
.52611 .38292 m .52637 .38246 L .52616 .38241 L F
.52608 .38318 m .52617 .38296 L .52611 .38292 L F
.52617 .38296 m .52637 .38248 L .52611 .38292 L F
.52642 .38293 m .52633 .38288 L .5261 .38218 L F
.52642 .38293 m .5261 .38218 L .52615 .3822 L F
.52637 .38246 m .52649 .38314 L p .52634 .38253 L F P
0 g
s
.52649 .38314 m .52654 .38345 L p .52647 .38315 L .67 .731 .896 r
F P
0 g
s
.52642 .38293 m .52621 .38237 L .52621 .38237 L .67 .731 .896 r
F
.52654 .38345 m .52632 .38256 L .52633 .38255 L F
.52654 .38345 m .52663 .38402 L p .52652 .38349 L F P
0 g
s
.52622 .38223 m .52642 .38293 L .52617 .38221 L .67 .731 .896 r
F
.52642 .38293 m .52703 .38506 L .52633 .38288 L F
.52608 .38318 m .52614 .3824 L .52609 .38239 L F
.5263 .38246 m .52627 .3824 L .52628 .38239 L F
.52648 .38311 m .52637 .38248 L p .52609 .38344 L F P
0 g
s
.52609 .38344 m .52637 .38248 L .52608 .38318 L .67 .731 .896 r
F
.52663 .38402 m .52807 .39246 L p .52641 .38376 L F P
0 g
s
.52641 .38376 m .52807 .39246 L .52592 .38318 L .67 .731 .896 r
F
.52807 .39246 m .52648 .38311 L p .52609 .38344 L F P
0 g
s
.52585 .38233 m .52661 .38375 L .52609 .38344 L .67 .731 .896 r
F
.52612 .38221 m .52619 .38168 L .5261 .3822 L F
.52568 .38227 m .52629 .38198 L .52625 .38193 L F
.52575 .38229 m .5218 .38574 L .52544 .38233 L F
.52464 .3829 m .52574 .38228 L .52568 .38227 L F
.52587 .38228 m .52578 .38229 L .52593 .38215 L F
.52574 .38228 m .52629 .38198 L .52568 .38227 L F
.52715 .3852 m .52703 .38506 L .52626 .38237 L F
.52464 .3829 m .52629 .38198 L .52464 .3829 L F
.52458 .38295 m .52467 .3829 L .52454 .38295 L F
.52467 .3829 m .52629 .38198 L .52464 .3829 L F
.52467 .3829 m .52464 .3829 L .52454 .38295 L F
.52438 .38324 m .52439 .3832 L .52603 .38167 L F
.52405 .38325 m .52381 .38365 L .52582 .3823 L F
.52575 .38229 m .52582 .3823 L .52629 .38198 L F
.52405 .38325 m .52582 .3823 L .52575 .38229 L F
.52583 .38224 m .52583 .38224 L .52624 .38193 L F
.52651 .38183 m .5263 .38179 L .52906 .38153 L F
.52887 .38159 m .52906 .38153 L .53403 .38106 L F
.52651 .38183 m .52906 .38153 L .52887 .38159 L F
.515 .38945 m .5143 .38896 L p .52347 .38327 L F P
0 g
s
.52614 .3818 m .52665 .38186 L .52667 .38197 L .67 .731 .896 r
F
.5261 .38175 m .52665 .38185 L .52614 .3818 L F
.52665 .38185 m .52671 .38187 L .52665 .38186 L F
.52665 .38185 m .52665 .38186 L .52614 .3818 L F
.52662 .38163 m .52666 .38162 L .52662 .38161 L F
.52638 .38156 m .52643 .38157 L .52758 .38077 L F
.52682 .38149 m .52662 .38164 L .5268 .38121 L F
.52613 .38179 m .52717 .38167 L .52614 .3818 L F
.52617 .38183 m .52619 .38168 L .5261 .38175 L F
.52606 .38184 m .52615 .38181 L .52613 .38179 L F
.52648 .38177 m .52545 .38187 L .52646 .38176 L F
.52614 .38175 m .52646 .38173 L .52665 .38183 L F
.52665 .38185 m .52665 .38185 L .5261 .38175 L F
.52589 .38176 m .52589 .38172 L .526 .38176 L F
.52571 .3818 m .52607 .38171 L .52609 .38174 L F
.5261 .38175 m .5261 .38175 L .52582 .3817 L F
.52665 .38185 m .5261 .38175 L .5261 .38175 L F
.52648 .38173 m .52675 .38164 L .52666 .38162 L F
.5268 .38219 m .52744 .38269 L .52689 .38201 L F
.52676 .38227 m .52666 .38221 L p .52774 .38246 L F P
0 g
s
.52627 .3824 m .52606 .38184 L .52628 .38239 L .67 .731 .896 r
F
.52637 .38246 m .52623 .38164 L p .52616 .38241 L F P
0 g
s
.52596 .38206 m .5261 .38185 L .52605 .38186 L .67 .731 .896 r
F
.52592 .38211 m .52601 .38195 L .52598 .38196 L F
.52601 .38195 m .52604 .38189 L .52598 .38196 L F
.52598 .38196 m .52604 .38189 L .52604 .38181 L F
.52594 .38212 m .52575 .38229 L .52599 .38201 L F
.52584 .3823 m .52604 .38181 L .52594 .38189 L F
.5262 .38187 m .52578 .38203 L .52593 .3819 L F
.52515 .38254 m .52514 .38252 L .52594 .38176 L F
.52516 .38237 m .52516 .38245 L .52612 .38178 L F
.52623 .38164 m .52607 .38171 L .52623 .38164 L F
.5263 .38168 m .52617 .3817 L .52623 .38164 L F
.52623 .38164 m .52614 .38172 L .52623 .38164 L F
.52617 .3817 m .52607 .38171 L .52623 .38164 L F
.52619 .38168 m .52623 .38164 L .5262 .38162 L F
.5261 .38292 m .52623 .38164 L .52619 .38168 L F
.52623 .38164 m .52623 .38164 L .52619 .38168 L F
.52608 .38318 m .52611 .38292 L .5261 .38292 L F
.52611 .38292 m .52623 .38164 L .5261 .38292 L F
.52611 .38177 m .52612 .38178 L .52643 .38157 L F
.52554 .38185 m .52546 .38186 L .52555 .38184 L F
.52549 .38184 m .52562 .38191 L .52575 .38175 L F
.5255 .38186 m .52558 .38183 L .52612 .38178 L F
.52516 .38237 m .52612 .38178 L .52611 .38177 L F
.52582 .3817 m .5261 .38175 L .52614 .3818 L F
.52605 .3818 m .52612 .38178 L .52613 .38179 L F
.5255 .38186 m .52607 .38179 L .52605 .3818 L F
.52591 .38193 m .52613 .38179 L .52613 .38178 L F
.52604 .38189 m .5261 .38175 L .52604 .38181 L F
.5261 .38175 m .52643 .38157 L .52638 .38156 L F
.5218 .38574 m .52147 .38587 L .52394 .38364 L F
.52397 .38369 m .52394 .38364 L .52607 .38171 L F
.5218 .38574 m .52394 .38364 L .52397 .38369 L F
.52516 .38237 m .52611 .38177 L .5261 .38175 L F
.52611 .38177 m .52643 .38157 L .5261 .38175 L F
.52607 .38183 m .52606 .38184 L .52613 .38179 L F
.52526 .38195 m .52614 .3818 L .52615 .38181 L F
.52534 .38221 m .52537 .38222 L .52605 .38176 L F
.52593 .3819 m .52558 .38193 L .52594 .38189 L F
.52585 .38139 m .52585 .38141 L .52624 .38178 L F
.52598 .3816 m .52591 .38146 L .52595 .38147 L F
.52594 .38156 m .52591 .38146 L .52598 .3816 L F
.52591 .38148 m .52593 .38154 L .52587 .38147 L F
.52584 .38143 m .52599 .38161 L .52603 .38153 L F
.526 .38163 m .52603 .38167 L .52603 .38153 L F
.52607 .38171 m .52603 .38167 L .5262 .38152 L F
.5262 .38152 m .52603 .38167 L .52603 .38166 L F
.5262 .38152 m .52603 .38166 L .52617 .38161 L F
.52603 .38166 m .52605 .38169 L .52616 .38164 L F
.52603 .38167 m .52613 .38171 L .52603 .38153 L F
.5261 .38174 m .5261 .38175 L .52582 .3817 L F
.52604 .38181 m .52609 .38174 L .52603 .38167 L F
.52609 .38174 m .52613 .38171 L .52603 .38167 L F
.52579 .38174 m .52569 .38173 L .52577 .38174 L F
.52603 .38166 m .52587 .38171 L .52576 .38168 L F
.52576 .38169 m .52582 .3817 L .52589 .38172 L F
.52587 .38171 m .52573 .38175 L .52576 .38169 L F
.52564 .38167 m .52527 .3815 L p .52586 .38171 L F P
0 g
s
.52587 .38171 m .52576 .38169 L .52576 .38168 L .67 .731 .896 r
F
.52589 .38176 m .52576 .38169 L p .52589 .38172 L F P
0 g
s
.52576 .38169 m .52572 .38167 L p .52582 .3817 L .67 .731 .896 r
F P
0 g
s
.52572 .38167 m .5261 .38174 L .52582 .3817 L .67 .731 .896 r
F
.5261 .38174 m .52665 .38185 L .5261 .38175 L F
.52603 .38166 m .52616 .38164 L .52617 .38161 L F
.52613 .38171 m .52617 .38161 L .52603 .38153 L F
.52605 .38176 m .52608 .38175 L .52611 .38174 L F
.52619 .38168 m .52613 .38171 L .5261 .38175 L F
.52612 .38171 m .52611 .38174 L .52638 .38156 L F
.52605 .38176 m .52611 .38174 L .52612 .38171 L F
.52619 .38168 m .5262 .38162 L .52613 .38171 L F
.52569 .38173 m .52568 .38175 L .52606 .38178 L F
.52589 .38176 m .526 .38176 L .5259 .38177 L F
.52611 .38176 m .52564 .38181 L .52609 .38174 L F
.5261 .38175 m .52613 .38171 L .52604 .38181 L F
.52613 .38178 m .52613 .38179 L .52658 .38147 L F
.52598 .38148 m .52605 .38186 L .52595 .38147 L F
.52606 .3817 m .52585 .38142 L .52646 .38173 L F
.52572 .38167 m .52584 .38143 L .52606 .3817 L F
.52584 .38143 m .52585 .38142 L .52606 .3817 L F
.52571 .3818 m .52581 .38174 L .52607 .38171 L F
.52581 .38174 m .52573 .38175 L .52585 .38173 L F
.52605 .38168 m .52573 .38175 L .52603 .38166 L F
.5259 .38191 m .5259 .38191 L .52501 .38195 L F
.52557 .38193 m .52556 .38192 L .52619 .38186 L F
.52572 .38178 m .52581 .38174 L .52571 .3818 L F
.52562 .38132 m .52578 .38203 L .52599 .38161 L F
.52562 .38132 m .52599 .38161 L .52584 .38143 L F
.52607 .38171 m .52581 .38174 L .52605 .38169 L F
.52581 .38174 m .52585 .38173 L .52623 .38164 L F
.52604 .38181 m .52613 .38179 L .52614 .3818 L F
.5255 .38186 m .52605 .3818 L .52604 .38181 L F
.52605 .3818 m .52613 .38179 L .52604 .38181 L F
.52578 .38203 m .52594 .38189 L .52603 .38153 L F
.52706 .38167 m .52611 .38176 L .5271 .38158 L F
.52648 .38173 m .52666 .38162 L .52633 .38174 L F
.5266 .38173 m .52675 .38164 L .52648 .38173 L F
.52675 .38164 m .52663 .38173 L p .52676 .38161 L F P
0 g
s
.52613 .38179 m .52612 .38178 L .52717 .38167 L .67 .731 .896 r
F
.52643 .38175 m .52641 .38173 L .52987 .3814 L F
.52987 .3814 m .52987 .3814 L .53098 .38129 L F
.52643 .38175 m .52987 .3814 L .52987 .3814 L F
.52748 .38282 m .52749 .38283 L p .52748 .38282 L F P
0 g
s
.52692 .38189 m .52671 .38189 L .52673 .3819 L .67 .731 .896 r
F
.52803 .38254 m .52671 .38187 L .52694 .38191 L F
.52697 .38193 m .52689 .38201 L .53792 .38921 L F
.53792 .38921 m .52676 .38227 L p .52774 .38246 L F P
0 g
s
.52774 .38246 m .52763 .38263 L .5372 .38969 L .67 .731 .896 r
F
.53018 .3844 m .5274 .38267 L .52783 .38263 L F
.52749 .38283 m .5372 .38969 L p .52763 .38263 L F P
0 g
s
.5372 .38969 m .5274 .38267 L .53018 .3844 L .67 .731 .896 r
F
.5372 .38969 m .52728 .38268 L p .5274 .38267 L F P
0 g
s
.53642 .39013 m .5372 .38969 L p .5283 .38298 L .67 .731 .896 r
F P
0 g
s
.52646 .38173 m .52662 .38172 L .52663 .38173 L .67 .731 .896 r
F
.52525 .38196 m .52681 .3818 L .5268 .3818 L F
.52622 .38189 m .5266 .38173 L .52648 .38173 L F
.5283 .38298 m .52783 .38263 L .52796 .38332 L F
.52665 .38183 m .52646 .38173 L .52663 .38173 L F
.52624 .38193 m .52662 .38164 L .52662 .38164 L F
.52726 .38152 m .52714 .38154 L .52722 .38155 L F
.52611 .38169 m .52608 .38176 L .52578 .38071 L F
.52611 .38169 m .52578 .38071 L .5258 .38071 L F
.52611 .38169 m .52569 .38039 L .52576 .38048 L F
.52656 .38146 m .52658 .38133 L .52659 .38143 L F
.52615 .38181 m .52614 .3818 L .5263 .38179 L F
.52596 .38206 m .52622 .38189 L .5261 .38185 L F
.52626 .38194 m .52578 .38203 L .5262 .38187 L F
.52622 .38189 m .52615 .38181 L .52606 .38184 L F
.52578 .38217 m .52624 .38192 L .52622 .38189 L F
.52619 .38186 m .52619 .38186 L .52681 .3818 L F
.52569 .38227 m .5266 .38173 L .52563 .38226 L F
.52567 .38227 m .52563 .38226 L .52561 .38227 L F
.52569 .38227 m .52563 .38226 L .52567 .38227 L F
.52578 .38203 m .52584 .3823 L .52594 .38189 L F
.52584 .3823 m .52593 .38211 L .52592 .38211 L F
.52578 .38203 m .52594 .3821 L .52586 .3823 L F
.52584 .3823 m .52586 .3823 L .52585 .38233 L F
.52578 .38203 m .52586 .3823 L .52584 .3823 L F
.52489 .38196 m .52564 .38193 L .52563 .38192 L F
.52565 .38193 m .52565 .38193 L .52489 .38196 L F
.52526 .38195 m .5263 .38179 L .52651 .38183 L F
.52653 .3819 m .52693 .38188 L .52654 .38189 L F
.52663 .38186 m .52665 .38197 L .52679 .38189 L F
.52665 .38186 m .52671 .38187 L .52667 .38197 L F
.52668 .38187 m .52711 .38185 L .52667 .38187 L F
.52621 .38188 m .52711 .38185 L .52712 .38184 L F
.52666 .38187 m .52696 .38186 L .52666 .38187 L F
.52692 .38189 m .52693 .38188 L .52671 .38189 L F
.52693 .38192 m .52578 .38203 L .52699 .3818 L F
.5243 .38196 m .52641 .38173 L .52643 .38175 L F
.52396 .38199 m .5243 .38196 L .5243 .38196 L F
.5243 .38196 m .52641 .38173 L .5243 .38196 L F
.52642 .38293 m .52621 .38237 L .52623 .38237 L F
.52715 .3852 m .52626 .38237 L .52632 .38239 L F
.52628 .38274 m .52661 .38375 L .52619 .38297 L F
.52628 .38274 m .52619 .38297 L .52585 .38233 L F
.52609 .38344 m .52703 .38506 L .52627 .38424 L F
.52661 .38375 m .52703 .38506 L .52609 .38344 L F
.52638 .38231 m .52715 .3852 L p .52629 .38227 L F P
0 g
s
.52715 .3852 m .52849 .3902 L p .52703 .38506 L .67 .731 .896 r
F P
0 g
s
.52627 .38424 m .52849 .3902 L .52718 .38844 L .67 .731 .896 r
F
.52703 .38506 m .52849 .3902 L .52627 .38424 L F
.52849 .3902 m .52908 .39237 L p .52718 .38844 L F P
0 g
s
.52908 .39237 m .52638 .38231 L p .52598 .38264 L .67 .731 .896 r
F P
0 g
s
.52648 .38309 m .52645 .38308 L .52632 .38278 L .67 .731 .896 r
F
.52622 .38189 m .52648 .38173 L .52615 .38181 L F
.52583 .38199 m .52629 .38198 L .52627 .38196 L F
.52584 .38214 m .5266 .38173 L .52578 .38217 L F
.52648 .38173 m .52633 .38174 L .52606 .38184 L F
.52662 .38163 m .52662 .38161 L .52644 .38157 L F
.52662 .38164 m .5265 .38173 L .52659 .38144 L F
.52672 .38183 m .52626 .38194 L .5262 .38187 L F
.52699 .3818 m .52657 .38188 L .52672 .38183 L F
.52657 .38188 m .52626 .38194 L .52672 .38183 L F
.5265 .38173 m .52607 .38206 L .52632 .38174 L F
.52607 .38206 m .52592 .38217 L .526 .38208 L F
.52667 .38197 m .52671 .38187 L .52729 .38216 L F
.52629 .38198 m .52697 .38191 L .52698 .38191 L F
.52693 .38192 m .52629 .38198 L p .52693 .38192 L F P
0 g
s
.52666 .38186 m .5268 .38219 L .52689 .38201 L .67 .731 .896 r
F
.52646 .38173 m .52653 .38183 L .52666 .38186 L F
.52625 .38193 m .5268 .38193 L .52684 .3819 L F
.52625 .38193 m .52684 .3819 L .52678 .38189 L F
.5267 .3822 m .52629 .38198 L p .52729 .38216 L F P
0 g
s
.52653 .38183 m .5268 .38219 L .52666 .38186 L .67 .731 .896 r
F
.52694 .38191 m .52665 .38183 L .52663 .38173 L F
.52671 .38187 m .52665 .38183 L .52694 .38191 L F
.52694 .38191 m .52662 .38172 L .52677 .38189 L F
.52678 .38189 m .52684 .3819 L .52686 .38188 L F
.52614 .3824 m .52619 .38168 L .52609 .38239 L F
.52621 .38237 m .52601 .38182 L .52621 .38237 L F
.52572 .38167 m .52646 .38173 L .52614 .38175 L F
.52601 .38182 m .5259 .38152 L .52601 .38182 L F
.52667 .38121 m .5261 .38172 L .52616 .38158 L F
.52919 .37829 m .52675 .38114 L .52666 .38095 L F
.52602 .38165 m .52719 .38079 L .52718 .38072 L F
.52676 .3811 m .52665 .38119 L .52687 .38098 L F
.52653 .38138 m .52665 .38119 L .52676 .3811 L F
.52653 .38138 m .52652 .38131 L .52665 .38119 L F
.52722 .3807 m .5262 .38152 L .52758 .38077 L F
.52707 .38093 m .52673 .38121 L .52667 .38121 L F
.52673 .38121 m .5261 .38172 L .52667 .38121 L F
.52562 .38132 m .52584 .38143 L .52566 .38121 L F
.52578 .38118 m .52602 .38192 L .52562 .38132 L F
.52495 .38075 m .52517 .38129 L .52561 .38126 L F
.52592 .38153 m .52517 .38129 L .52543 .38093 L F
.52603 .38153 m .52621 .38149 L .52602 .38146 L F
.5262 .38162 m .52621 .38149 L .52603 .38153 L F
.52646 .38173 m .5254 .38119 L .52662 .38172 L F
.52566 .38121 m .52622 .38174 L .52646 .38173 L F
.52495 .38075 m .52587 .38147 L .52566 .38121 L F
.52587 .38147 m .52622 .38174 L .52566 .38121 L F
.52594 .38189 m .526 .38175 L .52598 .38171 L F
.526 .38175 m .52603 .38167 L .52598 .38171 L F
.52598 .38171 m .52603 .38167 L .526 .38163 L F
.52602 .38181 m .52591 .38152 L .52603 .3818 L F
.52591 .38152 m .52576 .3811 L .52593 .38154 L F
.52591 .38152 m .52593 .38154 L .52603 .3818 L F
.52543 .38093 m .5256 .38146 L .52565 .3812 L F
.52543 .38093 m .52565 .3812 L .52572 .38083 L F
.52543 .38093 m .52517 .38129 L .52514 .38074 L F
.5259 .38151 m .52578 .38118 L .5259 .38151 L F
.5265 .38173 m .52632 .38174 L .52659 .38144 L F
.526 .38208 m .52656 .38146 L .52658 .38146 L F
.52603 .3818 m .52576 .3811 L .52577 .38105 L F
.52614 .38162 m .52611 .38169 L .52576 .38048 L F
.52463 .37578 m .52596 .38075 L p .52454 .37636 L F P
0 g
s
.52621 .38188 m .5262 .38187 L .52632 .38174 L .67 .731 .896 r
F
.52585 .38197 m .52627 .38196 L .52625 .38193 L F
.52607 .38206 m .526 .38208 L .5262 .38187 L F
.52579 .38203 m .52629 .38198 L p .52583 .38199 L F P
0 g
s
.52607 .38179 m .52612 .38178 L .52605 .3818 L .67 .731 .896 r
F
.5262 .38187 m .52593 .3819 L .52619 .38187 L F
.52593 .3819 m .52594 .38189 L .52619 .38187 L F
.52619 .38187 m .52619 .38186 L .5268 .3818 L F
.52558 .38193 m .52619 .38186 L .52619 .38187 L F
.52558 .38193 m .52557 .38193 L .52619 .38186 L F
.52557 .38193 m .52619 .38186 L .52619 .38186 L F
.52609 .38174 m .52594 .38189 L .52624 .38193 L F
.52615 .38181 m .52633 .38174 L .52613 .38179 L F
.52597 .38204 m .52642 .38152 L .52595 .3821 L F
.52586 .38196 m .52678 .38189 L .52674 .38188 L F
.52622 .38189 m .52487 .38195 L .52487 .38195 L F
.52501 .38195 m .52622 .38189 L .525 .38194 L F
.52526 .38195 m .52549 .38186 L .52614 .3818 L F
.52586 .38196 m .52675 .38189 L .52586 .38196 L F
.52675 .38189 m .52678 .38189 L .52675 .38189 L F
.52675 .38189 m .52675 .38189 L .52586 .38196 L F
.52621 .38237 m .52601 .38181 L .52623 .38237 L F
.52615 .3822 m .52615 .3822 L .52621 .38237 L F
.52586 .3823 m .52588 .38225 L .52663 .38168 L F
.52604 .38188 m .52615 .3822 L .52615 .3822 L F
.52601 .38182 m .52604 .38188 L .52604 .38188 L F
.52583 .38199 m .52627 .38196 L .52585 .38197 L F
.526 .38208 m .52595 .3821 L .52629 .38174 L F
.52631 .38174 m .52629 .38174 L .52656 .38146 L F
.526 .38208 m .52629 .38174 L .52631 .38174 L F
.52564 .38139 m .52567 .38146 L .52566 .38146 L F
.52562 .38132 m .52566 .3814 L .52564 .38139 L F
.52566 .3814 m .52594 .3821 L .52564 .38139 L F
.52517 .38129 m .52591 .38174 L p .52561 .38126 L F P
0 g
s
.52633 .38174 m .52627 .38174 L .52613 .38179 L .67 .731 .896 r
F
.52622 .38174 m .52627 .38178 L .52646 .38173 L F
.52614 .38175 m .52665 .38183 L .52665 .38185 L F
.52624 .38192 m .5266 .38173 L .52622 .38189 L F
.5262 .38187 m .52619 .38187 L .5268 .3818 L F
.52619 .38202 m .52662 .38166 L .52663 .38168 L F
.52627 .38178 m .52651 .38183 L .52646 .38173 L F
.52627 .38196 m .5268 .38193 L .52625 .38193 L F
.52597 .38204 m .5261 .38172 L .52658 .38133 L F
.5262 .38165 m .52619 .38165 L .52619 .38165 L F
.52629 .38198 m .52675 .38164 L p .52625 .38193 L F P
0 g
s
.52614 .38204 m .52662 .38166 L .52619 .38202 L .67 .731 .896 r
F
.52629 .38198 m .52679 .38229 L p .52621 .38176 L F P
0 g
s
.52629 .38198 m .5263 .38198 L .52697 .38191 L .67 .731 .896 r
F
.52629 .38198 m .5268 .38193 L p .52627 .38196 L F P
0 g
s
.52612 .38204 m .52682 .38149 L .52614 .38204 L .67 .731 .896 r
F
.52622 .38174 m .52679 .38229 L .52697 .38233 L F
.52592 .3815 m .52618 .38174 L .52622 .38174 L F
.5261 .38205 m .52651 .38173 L .52612 .38204 L F
.52662 .38172 m .52646 .38173 L .52663 .38173 L F
.52586 .3823 m .52663 .38168 L .52663 .38168 L F
.52625 .38177 m .52624 .38193 L .52651 .3819 L F
.52618 .38174 m .52621 .38176 L .52622 .38174 L F
.52621 .38176 m .52679 .38229 L .52625 .38177 L F
.52618 .38185 m .52642 .38152 L .52656 .38146 L F
.52461 .38183 m .52478 .38206 L .5248 .38206 L F
.52558 .38193 m .52525 .38196 L .52557 .38193 L F
.52525 .38196 m .52556 .38192 L .52557 .38193 L F
.52525 .38196 m .52493 .38199 L .52526 .38195 L F
.52493 .38199 m .52503 .38191 L .52549 .38186 L F
.52454 .38196 m .52562 .38192 L .52562 .38191 L F
.52493 .38199 m .52549 .38186 L .52526 .38195 L F
.52502 .38186 m .5248 .38206 L .52624 .38193 L F
.52396 .38199 m .524 .38196 L .52426 .38194 L F
.5243 .38196 m .52426 .38194 L .52641 .38173 L F
.52396 .38199 m .52426 .38194 L .5243 .38196 L F
.52651 .38173 m .52682 .38149 L .52651 .38173 L F
.52614 .38204 m .52682 .38149 L .5268 .38152 L F
.52675 .38164 m .52731 .38121 L p .52666 .38162 L F P
0 g
s
.52586 .3823 m .52724 .38122 L .52725 .38123 L .67 .731 .896 r
F
.52663 .38168 m .52663 .38168 L .5267 .38162 L F
.52726 .38152 m .52643 .38173 L .52619 .38165 L F
.52662 .38164 m .52662 .38164 L .52682 .38149 L F
.52662 .38164 m .52682 .38149 L .52662 .38164 L F
.52663 .38173 m .52661 .38173 L .52676 .38161 L F
.52675 .38164 m .52676 .38161 L .52788 .38075 L F
.52671 .3817 m .52737 .38127 L p .52652 .38166 L F P
0 g
s
.52616 .38183 m .52642 .38152 L .52618 .38185 L .67 .731 .896 r
F
.52592 .3815 m .5261 .38174 L .52618 .38174 L F
.52601 .38181 m .52576 .3811 L .52602 .38181 L F
.5259 .38151 m .5259 .38151 L .52601 .38182 L F
.52594 .38189 m .52604 .38181 L .52603 .38167 L F
.52604 .38188 m .52602 .38192 L .52578 .38118 L F
.52587 .38147 m .52591 .38152 L .52592 .3815 L F
.52591 .38152 m .52578 .38118 L .52579 .38118 L F
.52666 .38221 m .52629 .38198 L p .52703 .38219 L F P
0 g
s
.52595 .3821 m .52616 .38183 L .52618 .38185 L .67 .731 .896 r
F
.52408 .38365 m .52629 .38198 L p .52381 .38365 L F P
0 g
s
.52629 .38198 m .52586 .3823 L p .52629 .38198 L .67 .731 .896 r
F P
0 g
s
.52622 .38223 m .52617 .38221 L .52594 .38153 L .67 .731 .896 r
F
.52596 .38153 m .52594 .38153 L .52577 .38105 L F
.52622 .38223 m .52594 .38153 L .52596 .38153 L F
.52658 .38146 m .52656 .38146 L .5268 .38121 L F
.52642 .38152 m .52658 .38133 L .52656 .38146 L F
.52662 .38164 m .52659 .38144 L .5268 .38121 L F
.52682 .38149 m .5268 .38121 L .52695 .38121 L F
.52662 .38166 m .52794 .38064 L .52663 .38168 L F
.52625 .3816 m .52737 .38127 L .52675 .38128 L F
.52601 .38172 m .52599 .38176 L .52604 .38173 L F
.52613 .38163 m .52609 .38165 L .52616 .38158 L F
.52608 .38174 m .52609 .38165 L .52613 .38163 L F
.52591 .38152 m .52609 .38174 L .52592 .3815 L F
.52592 .38217 m .52592 .38217 L .52658 .38146 L F
.52658 .38145 m .52658 .38146 L .5268 .38121 L F
.52592 .38217 m .52658 .38146 L .52658 .38145 L F
.5256 .38205 m .52578 .38203 L p .5254 .38201 L F P
0 g
s
.52592 .38174 m .52525 .38235 L .52532 .38217 L .67 .731 .896 r
F
.52619 .38165 m .52619 .38165 L .52618 .38165 L F
.52607 .38171 m .52652 .38166 L .52625 .3816 L F
.52566 .38146 m .52587 .38195 L .52578 .38203 L F
.52587 .38195 m .52594 .3821 L .52579 .38203 L F
.52424 .3831 m .52591 .38194 L .52591 .38193 L F
.52587 .38195 m .52579 .38203 L .52578 .38203 L F
.52569 .38198 m .52585 .38197 L .52568 .38198 L F
.52585 .38197 m .52625 .38193 L .52586 .38196 L F
.52585 .38197 m .52586 .38196 L .52568 .38198 L F
.52629 .38198 m .52472 .38213 L p .5263 .38198 L F P
0 g
s
.5254 .38201 m .52578 .38203 L .5257 .38199 L .67 .731 .896 r
F
.52596 .38174 m .52525 .38235 L .52592 .38174 L F
.52599 .38176 m .52594 .38189 L .52607 .38171 L F
.52607 .38171 m .52594 .38189 L .52609 .38174 L F
.52609 .38174 m .52624 .38193 L .52625 .38177 L F
.52609 .38174 m .52629 .38198 L .5261 .38174 L F
.52609 .38174 m .5261 .38174 L .5261 .38174 L F
.52627 .38199 m .52621 .38202 L .52611 .38169 L F
.52609 .38174 m .5261 .38174 L .52592 .3815 L F
.52591 .38218 m .52662 .38164 L .52591 .38218 L F
.52589 .38109 m .52622 .38223 L .52583 .38114 L F
.52606 .38174 m .52592 .38174 L .52629 .38198 L F
.52608 .38174 m .52539 .3823 L .52598 .38174 L F
.52592 .38175 m .52593 .38175 L .52618 .38185 L F
.52605 .38185 m .52602 .38181 L .52603 .3818 L F
.52578 .38203 m .52578 .38203 L .5263 .38198 L F
.52604 .38187 m .52602 .38181 L .52605 .38185 L F
.52583 .38199 m .52629 .38198 L .52583 .38199 L F
.52593 .38211 m .52604 .38189 L .52592 .38211 L F
.52588 .38194 m .52602 .38192 L .52594 .3821 L F
.52574 .38231 m .5261 .38172 L .52597 .38204 L F
.52629 .38198 m .52628 .38199 L .52627 .38197 L F
.52593 .38225 m .5267 .38162 L .52672 .38163 L F
.52586 .3823 m .52593 .38225 L .52593 .38225 L F
.52593 .38225 m .5267 .38162 L .52593 .38225 L F
.52605 .38173 m .52592 .38174 L .52606 .38174 L F
.52561 .38126 m .52605 .38173 L .52587 .38147 L F
.5261 .38174 m .5261 .38174 L .52618 .38174 L F
.52629 .38227 m .52609 .38174 L .52612 .38171 L F
.52605 .38173 m .52629 .38198 L .52609 .38174 L F
.52622 .38223 m .52578 .38104 L .52579 .38103 L F
.52605 .38173 m .52609 .38174 L .52587 .38147 L F
.52603 .38167 m .52601 .38172 L .52607 .38171 L F
.52611 .38207 m .5259 .38152 L .52591 .38152 L F
.52561 .38126 m .52588 .38169 L .52605 .38173 L F
.52601 .38172 m .52604 .38173 L .52607 .38171 L F
.52608 .38174 m .52598 .38174 L .52609 .38165 L F
.52603 .38167 m .52607 .38171 L .52611 .38171 L F
.52568 .38198 m .52586 .38196 L .52586 .38196 L F
.5257 .38199 m .52583 .38199 L .52583 .38199 L F
.52578 .38203 m .52579 .38203 L p .5257 .38199 L F P
0 g
s
.5257 .38199 m .52579 .38203 L .52583 .38199 L .67 .731 .896 r
F
.52545 .38187 m .52558 .38183 L .5255 .38186 L F
.52564 .38181 m .52426 .38194 L .52581 .38174 L F
.52511 .38178 m .52502 .38186 L .52624 .38193 L F
.52598 .38185 m .52602 .38192 L .52588 .38194 L F
.52561 .38227 m .52584 .38214 L .52578 .38217 L F
.52574 .38231 m .52546 .38224 L .5261 .38172 L F
.52607 .38171 m .52609 .38174 L .52612 .38175 L F
.52618 .38174 m .5261 .38174 L .52621 .38176 L F
.52617 .38173 m .52612 .38175 L .52625 .38177 L F
.52621 .38176 m .52625 .38177 L .52622 .38174 L F
.52612 .38171 m .52625 .38177 L .52614 .38169 L F
.52592 .38175 m .52629 .38198 L p .52592 .38174 L F P
0 g
s
.52562 .38132 m .52598 .38185 L .52588 .38194 L .67 .731 .896 r
F
.52569 .38173 m .52527 .38171 L .52568 .38175 L F
.52564 .38181 m .52572 .38178 L .52571 .3818 L F
.52527 .38171 m .52549 .38184 L .52575 .38175 L F
.52573 .38175 m .52426 .38194 L .52576 .38168 L F
.52603 .38167 m .52511 .38178 L .52594 .38189 L F
.52645 .38308 m .52645 .38308 L .52602 .38214 L F
.52622 .38223 m .52582 .38115 L .52582 .38115 L F
.52616 .38158 m .52596 .38174 L .52592 .38174 L F
.5261 .38174 m .52629 .38198 L .52621 .38176 L F
.52627 .38199 m .52611 .38169 L .52614 .38162 L F
.5262 .38165 m .52606 .3817 L .5262 .38165 L F
.52606 .3817 m .52546 .38191 L .52606 .3817 L F
.5261 .38172 m .52608 .38174 L .52616 .38158 L F
.52603 .38167 m .52609 .38169 L .52611 .38168 L F
.52609 .38169 m .52612 .38171 L .52611 .38168 L F
.52611 .38168 m .52612 .38171 L .52614 .38169 L F
.52606 .3817 m .52606 .3817 L .5262 .38165 L F
.52592 .38174 m .52592 .38174 L .52606 .38174 L F
.52588 .38169 m .52591 .38174 L .52605 .38173 L F
.52592 .38174 m .52592 .38175 L .52607 .38171 L F
.52592 .38175 m .52601 .38175 L .52607 .38171 L F
.52592 .38174 m .52607 .38171 L .52605 .38169 L F
.52619 .38165 m .52603 .38167 L .52605 .38167 L F
.52616 .38158 m .52592 .38174 L .52615 .38164 L F
.52614 .38169 m .52625 .38177 L .52671 .38183 L F
.52629 .38198 m .52615 .38159 L .52616 .38157 L F
.52616 .38158 m .52615 .38164 L .52618 .38158 L F
.5262 .38165 m .52618 .38165 L .52587 .38063 L F
.5262 .38164 m .52617 .38155 L p .52616 .38162 L F P
0 g
s
.52618 .38158 m .52615 .38164 L .52625 .3816 L .67 .731 .896 r
F
.52619 .38165 m .52596 .38172 L .52603 .38167 L F
.52652 .38166 m .52665 .3816 L .52625 .3816 L F
.52665 .3816 m .52737 .38127 L .52666 .38148 L F
.52665 .3816 m .52666 .38148 L .52625 .3816 L F
.52616 .38157 m .52615 .38159 L .52454 .37636 L F
.5259 .38152 m .52578 .38118 L .52591 .38152 L F
.52596 .38075 m .5262 .38165 L p .52587 .38063 L F P
0 g
s
.52617 .38164 m .52576 .38048 L .52585 .38061 L .67 .731 .896 r
F
.52625 .38193 m .52686 .38188 L .52625 .38193 L F
.52651 .38173 m .52651 .38173 L .52612 .38204 L F
.52624 .38193 m .52624 .38193 L .52662 .38164 L F
.52591 .38218 m .52662 .38164 L .52662 .38164 L F
.52663 .38173 m .52629 .38198 L p .52661 .38173 L F P
0 g
s
.52629 .38198 m .52629 .38198 L .52676 .38161 L .67 .731 .896 r
F
.52625 .38177 m .52651 .3819 L .52663 .38186 L F
.52627 .38178 m .52665 .38208 L .52651 .38183 L F
.52639 .38193 m .52668 .38198 L .52669 .38205 L F
.52627 .38199 m .52615 .38163 L .52628 .38199 L F
.52628 .38199 m .52615 .38163 L .52617 .38164 L F
.5262 .38165 m .52629 .38198 L p .52619 .38165 L F P
0 g
s
.52629 .38198 m .52627 .38196 L .52615 .38159 L .67 .731 .896 r
F
.52629 .38198 m .5262 .38165 L p .52616 .38182 L F P
0 g
s
.5262 .38165 m .5262 .38164 L p .52619 .38166 L .67 .731 .896 r
F P
0 g
s
.52616 .38182 m .5262 .38165 L .52619 .38166 L .67 .731 .896 r
F
.52594 .38175 m .5261 .38175 L .52649 .38189 L F
.5261 .38175 m .52613 .38179 L .52616 .38163 L F
.52639 .38174 m .526 .38184 L .5262 .38165 L F
.52591 .38174 m .52608 .38175 L .52594 .38175 L F
.52629 .38198 m .52627 .38197 L .52627 .38196 L F
.52607 .38206 m .5262 .38187 L .52621 .38188 L F
.52629 .38227 m .52608 .38176 L .52609 .38174 L F
.52629 .38198 m .52592 .38175 L p .52619 .38185 L F P
0 g
s
.5254 .38201 m .52583 .38199 L .52585 .38197 L .67 .731 .896 r
F
.52616 .38158 m .52539 .3823 L .52525 .38235 L F
.52592 .38175 m .52592 .3818 L .52601 .38175 L F
.52592 .3818 m .52616 .38182 L .52607 .38171 L F
.52608 .38175 m .5261 .38175 L .52594 .38175 L F
.526 .38184 m .52599 .38173 L .5261 .38175 L F
.52596 .38172 m .52591 .38171 L .52603 .38167 L F
.52592 .38174 m .52591 .38174 L .52592 .38174 L F
.52591 .38174 m .52591 .38171 L .52608 .38175 L F
.52591 .38171 m .5259 .38162 L .52608 .38175 L F
.52592 .38174 m .52518 .38227 L .52592 .3818 L F
.52591 .38174 m .52592 .38175 L p .52592 .38174 L F P
0 g
s
.52592 .38175 m .52591 .38174 L p .52593 .38175 L .67 .731 .896 r
F P
0 g
s
.5262 .38165 m .52478 .38215 L .52619 .38165 L .67 .731 .896 r
F
.52578 .38157 m .52593 .3819 L .52609 .38176 L F
.52591 .38174 m .52517 .38129 L p .5259 .38162 L F P
0 g
s
.5256 .38146 m .52593 .3819 L .52578 .38157 L .67 .731 .896 r
F
.526 .38184 m .52556 .38195 L .52599 .38173 L F
.52518 .38227 m .52593 .38193 L .52592 .3818 L F
.52595 .38189 m .52576 .38193 L .52596 .38188 L F
.52596 .38172 m .52543 .3819 L .52591 .38171 L F
.52591 .38174 m .52645 .38191 L .52639 .38193 L F
.52592 .38175 m .52618 .38185 L .52619 .38185 L F
.52604 .38188 m .52615 .3822 L .52604 .38188 L F
.52588 .38225 m .52614 .38204 L .52619 .38202 L F
.52601 .38181 m .52602 .38181 L .52623 .38237 L F
.52583 .38224 m .52624 .38193 L .52624 .38193 L F
.52617 .38221 m .52604 .38187 L .52605 .38185 L F
.52625 .38193 m .52625 .38193 L .52568 .38198 L F
.52615 .3822 m .52602 .38192 L .52604 .38188 L F
.52609 .38176 m .52604 .38218 L .52613 .38179 L F
.52589 .38222 m .52614 .38204 L .52588 .38225 L F
.52591 .38218 m .52594 .3821 L .526 .38208 L F
.52594 .3821 m .52595 .3821 L .526 .38208 L F
.52592 .38217 m .52591 .38218 L .52592 .38217 L F
.52586 .38224 m .5261 .38205 L .52587 .38224 L F
.5261 .38205 m .52612 .38204 L .52587 .38224 L F
.52587 .38224 m .52612 .38204 L .52614 .38204 L F
.52609 .38239 m .52612 .38221 L .5261 .3822 L F
.52602 .38192 m .52628 .38274 L .52585 .38233 L F
.52604 .38218 m .52602 .38233 L .52605 .38219 L F
.52615 .3822 m .5261 .38218 L .52602 .38192 L F
.52604 .38218 m .52605 .38219 L .52613 .38179 L F
.52472 .38213 m .52472 .38213 L .52578 .38203 L F
.52472 .38213 m .52578 .38203 L .52578 .38203 L F
.52397 .3822 m .5256 .38205 L p .52553 .38205 L F P
0 g
s
.52461 .38222 m .52473 .38217 L .5256 .38197 L .67 .731 .896 r
F
.52561 .38197 m .5256 .38197 L .52646 .38177 L F
.52461 .38222 m .5256 .38197 L .52561 .38197 L F
.52632 .38278 m .52631 .38278 L .52602 .38214 L F
.52556 .38196 m .52639 .38174 L .52556 .38196 L F
.52567 .38146 m .52594 .3821 L .52566 .38146 L F
.5256 .38146 m .52578 .38204 L .52593 .3819 L F
.52609 .38176 m .52609 .38178 L .52609 .38176 L F
.52609 .38178 m .52603 .38218 L .52609 .38176 L F
.52603 .38218 m .52598 .38264 L .52604 .38218 L F
.52603 .38218 m .52604 .38218 L .52609 .38176 L F
.52556 .38196 m .52639 .38174 L .5264 .38174 L F
.52646 .38177 m .52636 .38179 L .52642 .38175 L F
.52636 .38179 m .5263 .38178 L .52642 .38175 L F
.52625 .38177 m .52663 .38186 L .52671 .38183 L F
.52643 .38181 m .52646 .38177 L .5266 .38184 L F
.52665 .38208 m .52664 .38198 L .52646 .38173 L F
.52663 .38173 m .52646 .38173 L .52663 .38185 L F
.52614 .3818 m .52714 .38168 L .5271 .3817 L F
.52712 .38165 m .52635 .38174 L .52687 .38187 L F
.52665 .38185 m .52665 .38183 L .52671 .38187 L F
.52714 .38168 m .52717 .38167 L .52712 .38169 L F
.52714 .38168 m .52712 .38169 L .5271 .3817 L F
.52665 .38186 m .52646 .38177 L .52781 .38146 L F
.5266 .38184 m .52618 .38175 L .52672 .38178 L F
.52649 .38189 m .52623 .38177 L .5266 .38184 L F
.52623 .38177 m .52618 .38175 L .5266 .38184 L F
.52591 .38174 m .52649 .38189 L .52645 .38191 L F
.52629 .38198 m .52643 .38181 L .52665 .38186 L F
.52643 .38181 m .5266 .38184 L .52665 .38186 L F
.52629 .38198 m .52619 .38185 L .52639 .38193 L F
.52621 .38237 m .52611 .38207 L .52611 .38207 L F
.52617 .38221 m .52604 .38187 L .52617 .38221 L F
.52604 .38187 m .52602 .38181 L .52604 .38187 L F
.52604 .38187 m .52604 .38187 L .52617 .38221 L F
.52576 .38231 m .52574 .38231 L .52591 .38218 L F
.5259 .38221 m .52591 .38218 L .52682 .38149 L F
.52576 .38231 m .52591 .38218 L .5259 .38221 L F
.52627 .38226 m .52608 .38176 L .52629 .38227 L F
.52598 .38264 m .52629 .38198 L .52616 .38182 L F
.52619 .38185 m .52618 .38185 L .52639 .38193 L F
.52629 .38198 m .52617 .38184 L .52646 .38177 L F
.52601 .38182 m .52601 .38182 L .52615 .3822 L F
.52599 .38197 m .52591 .38212 L .52671 .3817 L F
.52603 .38233 m .52616 .38182 L .52613 .38179 L F
.52598 .38264 m .52604 .38234 L .52603 .38233 L F
.52604 .38234 m .52616 .38182 L .52603 .38233 L F
.52574 .38231 m .52597 .38204 L .52595 .3821 L F
.52591 .38218 m .52574 .38231 L .52595 .3821 L F
.52518 .38227 m .52583 .38228 L .52599 .38197 L F
.52578 .38204 m .52585 .38225 L .52609 .38176 L F
.52611 .38207 m .5259 .38152 L .52611 .38207 L F
.52461 .38183 m .5248 .38206 L .52502 .38186 L F
.52576 .38168 m .52426 .38194 L .52471 .38176 L F
.52511 .38178 m .52461 .38183 L .52502 .38186 L F
.52352 .38218 m .52569 .38198 L .52568 .38198 L F
.52603 .38167 m .52461 .38217 L .52453 .38184 L F
.52396 .3822 m .52397 .3822 L .52553 .38205 L F
.52461 .38217 m .52441 .38224 L .52445 .38212 L F
.52461 .38217 m .52445 .38212 L .52453 .38184 L F
.5263 .38285 m .52623 .38306 L .5261 .38305 L F
.5261 .38305 m .52665 .38352 L .52619 .38331 L F
.52653 .38309 m .53008 .39223 L .52648 .38309 L F
.52663 .38291 m .53008 .39223 L p .52643 .38283 L F P
0 g
s
.52665 .38352 m .53008 .39223 L .52619 .38331 L .67 .731 .896 r
F
.52564 .38128 m .52563 .38129 L .52534 .38066 L F
.52543 .38093 m .52439 .38024 L .52559 .38113 L F
.52519 .38064 m .52458 .38077 L .52463 .38021 L F
.52439 .38024 m .525 .38107 L .52528 .38098 L F
.52439 .38024 m .52559 .38124 L .52574 .38124 L F
.5256 .38114 m .52471 .38082 L .52519 .38064 L F
.52471 .38082 m .52458 .38077 L .52519 .38064 L F
.52519 .38064 m .52526 .38061 L .52452 .37821 L F
.52519 .38064 m .52452 .37821 L .52447 .37826 L F
.52519 .38064 m .52265 .37221 L .52265 .37223 L F
.5259 .38162 m .5259 .38152 L .52592 .38153 L F
.5256 .38146 m .52588 .3815 L .52568 .38103 L F
.52588 .3815 m .52617 .38155 L .52568 .38103 L F
.52615 .38163 m .52576 .38048 L .52617 .38164 L F
.52579 .38103 m .52578 .38104 L .52579 .38101 L F
.52617 .38155 m .52583 .38027 L p .52568 .38103 L F P
0 g
s
.52622 .38151 m .52625 .38145 L .52622 .38149 L .67 .731 .896 r
F
.52666 .38175 m .52571 .38128 L .52596 .38128 L F
.52538 .38192 m .52462 .38217 L .52603 .38167 L F
.52462 .38217 m .52441 .38224 L .52461 .38217 L F
.52462 .38217 m .52461 .38217 L .52603 .38167 L F
.5259 .38162 m .52592 .38153 L .52601 .38164 L F
.52612 .38171 m .52609 .38174 L .52611 .38169 L F
.5261 .38175 m .52599 .38173 L .5262 .38165 L F
.52608 .38175 m .5259 .38162 L .52618 .38175 L F
.5259 .38162 m .52517 .38129 L .5259 .38152 L F
.5256 .38146 m .52613 .38179 L .5259 .3815 L F
.52594 .38163 m .52593 .38163 L .52586 .38146 L F
.52601 .38181 m .52593 .38163 L .52594 .38163 L F
.52601 .38181 m .52601 .38182 L .52593 .38163 L F
.52604 .38188 m .52616 .38182 L .52607 .38181 L F
.52556 .38195 m .52546 .38191 L .52599 .38173 L F
.52534 .38066 m .52592 .38192 L .52578 .38204 L F
.52591 .38212 m .52603 .38218 L .52609 .38178 L F
.52585 .38225 m .52603 .38218 L .52591 .38212 L F
.52591 .38212 m .52585 .38225 L .52629 .38198 L F
.52358 .38402 m .52589 .38222 L .52588 .38225 L F
.52583 .38228 m .52588 .38225 L p .52585 .38225 L F P
0 g
s
.52588 .38225 m .52629 .38198 L p .52585 .38225 L .67 .731 .896 r
F P
0 g
s
.52593 .38199 m .52662 .38174 L .52593 .38193 L .67 .731 .896 r
F
.5261 .38175 m .52623 .38177 L .52649 .38189 L F
.52646 .38177 m .52642 .38175 L .52726 .38152 L F
.52655 .38174 m .52671 .3817 L .52633 .38174 L F
.52613 .38179 m .5262 .38164 L .52616 .38162 L F
.5262 .38162 m .52621 .38162 L .52625 .3816 L F
.52605 .38169 m .52621 .38162 L .5262 .38162 L F
.52605 .38169 m .52607 .38171 L .52621 .38162 L F
.5259 .3815 m .5261 .38175 L .52617 .38155 L F
.5261 .38175 m .52616 .38163 L .52617 .38155 L F
.52601 .38164 m .52592 .38153 L .52657 .38174 L F
.52666 .38171 m .52673 .38166 L .52673 .38167 L F
.53112 .38134 m .52648 .38177 L .53098 .38129 L F
.52649 .38174 m .52667 .38177 L .52667 .38177 L F
.52629 .38198 m .52664 .38175 L p .52591 .38212 L F P
0 g
s
.52664 .38175 m .52671 .3817 L p .52664 .38174 L .67 .731 .896 r
F P
0 g
s
.52591 .38212 m .52664 .38175 L .52664 .38174 L .67 .731 .896 r
F
.52617 .38184 m .52616 .38183 L .5263 .38178 L F
.52649 .38174 m .52657 .38174 L .52667 .38177 L F
.52593 .38193 m .52604 .38188 L .52592 .3818 L F
.52576 .38193 m .52577 .3819 L .52704 .38158 L F
.52703 .38158 m .52704 .38158 L .52726 .38152 L F
.52576 .38193 m .52704 .38158 L .52703 .38158 L F
.52671 .38218 m .52748 .38282 L .52748 .38282 L F
.52618 .38175 m .52649 .38174 L .52672 .38178 L F
.52652 .38174 m .52655 .38174 L .52642 .38174 L F
.52652 .38174 m .52642 .38174 L .52633 .38174 L F
.52616 .38182 m .52652 .38174 L .52633 .38174 L F
.52636 .38179 m .52617 .38184 L .5263 .38178 L F
.52618 .38185 m .52664 .38172 L .52616 .38182 L F
.52735 .38156 m .52646 .38177 L .52726 .38152 L F
.52664 .38172 m .52671 .3817 L .52664 .38172 L F
.52664 .38172 m .52664 .38172 L .52616 .38182 L F
.52643 .38173 m .52639 .38174 L .5262 .38165 L F
.52633 .38174 m .52652 .38166 L .5261 .38175 L F
.52608 .38175 m .52618 .38175 L .5261 .38175 L F
.52616 .38182 m .5262 .38164 L .52613 .38179 L F
.5261 .38175 m .52618 .38175 L .52623 .38177 L F
.52616 .38182 m .52633 .38174 L .5261 .38175 L F
.52662 .38174 m .52659 .38174 L .52593 .38193 L F
.52659 .38175 m .52627 .38196 L .52608 .38173 L F
.52665 .38185 m .52671 .38187 L .52665 .38185 L F
.52662 .38172 m .52666 .38186 L .52677 .38189 L F
.52671 .38183 m .52663 .38186 L .52687 .38187 L F
.52663 .38186 m .52651 .3819 L .52674 .38188 L F
.52669 .38187 m .53149 .38166 L .52668 .38187 L F
.52663 .38186 m .52674 .38188 L .52687 .38187 L F
.52662 .38172 m .52663 .38185 L .52666 .38186 L F
.52677 .38189 m .52666 .38186 L .52689 .38201 L F
.52674 .38188 m .52686 .38188 L .52687 .38187 L F
.52678 .38189 m .52686 .38188 L .52674 .38188 L F
.52694 .38191 m .52677 .38189 L .52693 .38192 L F
.52672 .38183 m .5268 .3818 L .52829 .38165 L F
.52689 .38196 m .52956 .38193 L .52689 .38196 L F
.52669 .38197 m .52876 .38206 L .52685 .38197 L F
.53792 .38921 m .5386 .38871 L p .52694 .38191 L F P
0 g
s
.54191 .38048 m .52693 .38192 L .52699 .3818 L .67 .731 .896 r
F
.5268 .3818 m .52681 .3818 L .53403 .38106 L F
.5271 .3817 m .52717 .38167 L .53098 .38129 L F
.52826 .38169 m .52829 .38165 L .53403 .38106 L F
.53098 .38129 m .52706 .38167 L .5271 .38158 L F
.52648 .38177 m .52646 .38176 L .53098 .38129 L F
.53403 .38106 m .53112 .38134 L .53098 .38129 L F
.54191 .38048 m .53432 .38115 L .53403 .38106 L F
.54215 .38046 m .54193 .38048 L p .54191 .38048 L F P
0 g
s
.52726 .38152 m .52687 .38187 L .54215 .38046 L .67 .731 .896 r
F
.54198 .37979 m .52692 .38189 L p .52781 .38146 L F P
0 g
s
.52691 .38191 m .52649 .38189 L .5266 .38184 L .67 .731 .896 r
F
.52691 .38191 m .5266 .38184 L .52687 .38188 L F
.5268 .38193 m .52693 .38192 L p .52684 .3819 L F P
0 g
s
.52693 .38192 m .52677 .38189 L .52689 .38201 L .67 .731 .896 r
F
.52687 .38206 m .52649 .38189 L .52691 .38191 L F
.52593 .38193 m .52618 .38185 L .52616 .38182 L F
.52591 .38212 m .52609 .38178 L .52609 .38176 L F
.52591 .38212 m .52609 .38178 L .52591 .38212 L F
.52518 .38227 m .52593 .38199 L .52593 .38193 L F
.52629 .38198 m .5258 .38205 L p .52617 .38184 L F P
0 g
s
.5258 .38205 m .52471 .3822 L p .52562 .38198 L .67 .731 .896 r
F P
0 g
s
.5258 .38205 m .52562 .38198 L .52617 .38184 L .67 .731 .896 r
F
.52665 .38208 m .5268 .38219 L .52664 .38198 L F
.52629 .38198 m .52639 .38193 L .52703 .38219 L F
.5262 .38176 m .52671 .38218 L .52671 .38218 L F
.52633 .38174 m .52671 .3817 L .52652 .38166 L F
.52666 .38175 m .52592 .38153 L .52571 .38128 L F
.52594 .38157 m .52591 .38155 L .52587 .38147 L F
.52593 .38155 m .52587 .38147 L .5254 .38034 L F
.52594 .38157 m .52587 .38147 L .52593 .38155 L F
.5261 .38175 m .52652 .38166 L .52607 .38171 L F
.52618 .38175 m .5259 .38162 L .52649 .38174 L F
.52594 .38157 m .52603 .38179 L .52591 .38155 L F
.52601 .38181 m .52586 .38146 L .52587 .38147 L F
.52596 .38128 m .52571 .38128 L .52543 .38093 L F
.52543 .38093 m .52559 .38113 L .52574 .38124 L F
.52601 .3819 m .52598 .382 L .52535 .38065 L F
.5251 .37989 m .52543 .38093 L .52583 .38027 L F
.52536 .38066 m .52535 .38065 L .52532 .38058 L F
.52543 .38093 m .52574 .38124 L .52583 .38124 L F
.52601 .3819 m .52535 .38065 L .52536 .38066 L F
.52576 .38193 m .52473 .38217 L .52577 .3819 L F
.52556 .38195 m .52592 .38192 L .52555 .38195 L F
.52592 .38192 m .52661 .38185 L .52592 .38191 L F
.52592 .38192 m .52592 .38191 L .52555 .38195 L F
.52686 .3819 m .52629 .38198 L p .52687 .38188 L F P
0 g
s
.52583 .38124 m .52574 .38124 L .52655 .38183 L .67 .731 .896 r
F
.52659 .38184 m .52655 .38183 L .527 .38216 L F
.52666 .38173 m .52664 .38175 L p .52666 .38173 L F P
0 g
s
.52664 .38175 m .52629 .38198 L p .52664 .38175 L .67 .731 .896 r
F P
0 g
s
.52666 .38175 m .52664 .38173 L .52664 .38175 L .67 .731 .896 r
F
.52664 .38175 m .52664 .38175 L .52666 .38173 L F
.52662 .38174 m .52671 .3817 L .52659 .38174 L F
.52629 .38198 m .52622 .38201 L .52674 .38166 L F
.52676 .38166 m .52674 .38166 L .52767 .38104 L F
.52629 .38198 m .52674 .38166 L .52676 .38166 L F
.52473 .38217 m .52478 .38215 L .52639 .38174 L F
.52601 .38181 m .52632 .38178 L .52629 .38178 L F
.52616 .38164 m .52609 .38172 L .52566 .38075 L F
.5266 .38184 m .52654 .38183 L .52573 .3819 L F
.52632 .38239 m .52626 .38237 L .52608 .38176 L F
.52589 .38195 m .52629 .38198 L .52654 .38189 L F
.5256 .38197 m .52587 .38198 L .52589 .38195 L F
.52587 .38198 m .52629 .38198 L .52589 .38195 L F
.52589 .38223 m .52628 .38196 L .52628 .38197 L F
.52632 .38239 m .52627 .38226 L .52629 .38227 L F
.52645 .38181 m .52639 .3818 L .52599 .38184 L F
.52598 .38185 m .52599 .38184 L .52544 .38189 L F
.52617 .38184 m .52595 .38189 L .52616 .38183 L F
.52595 .38189 m .52596 .38188 L .52642 .38175 L F
.52645 .38181 m .52599 .38184 L .52598 .38185 L F
.52577 .38205 m .5258 .38205 L p .5256 .38197 L F P
0 g
s
.5258 .38205 m .52629 .38198 L p .52587 .38198 L .67 .731 .896 r
F P
0 g
s
.52586 .38198 m .5258 .38205 L .52578 .38204 L .67 .731 .896 r
F
.52592 .38192 m .5258 .38205 L .52586 .38198 L F
.5256 .38197 m .5258 .38205 L .52587 .38198 L F
.52597 .38202 m .52597 .38202 L .52592 .38192 L F
.52592 .38192 m .52592 .38192 L .52574 .38152 L F
.52597 .38202 m .52592 .38192 L .52592 .38192 L F
.52604 .38188 m .52607 .38181 L .52592 .3818 L F
.52639 .3818 m .52636 .38179 L .52542 .38189 L F
.52638 .38231 m .52627 .38199 L .52628 .38199 L F
.52623 .38237 m .52617 .38221 L .52617 .38221 L F
.52638 .38231 m .52629 .38227 L .52621 .38202 L F
.52638 .38231 m .52621 .38202 L .52627 .38199 L F
.52629 .38198 m .52638 .38231 L p .52628 .38199 L F P
0 g
s
.52638 .38231 m .52629 .38198 L p .52598 .38264 L .67 .731 .896 r
F P
0 g
s
.52602 .38233 m .52603 .38233 L .52613 .38179 L .67 .731 .896 r
F
.52599 .38184 m .52639 .3818 L .52599 .38183 L F
.52618 .38185 m .52618 .38184 L .52596 .38187 L F
.52618 .38185 m .52596 .38187 L .52595 .38188 L F
.52627 .38196 m .5259 .38221 L .52608 .38173 L F
.52643 .38249 m .52603 .38179 L .52607 .38174 L F
.52663 .38291 m .52642 .38252 L .52643 .38249 L F
.52589 .38222 m .52673 .38166 L .52589 .38223 L F
.52642 .38252 m .52603 .38179 L .52643 .38249 L F
.52628 .38197 m .5266 .38175 L .52661 .38175 L F
.52601 .38164 m .52657 .38174 L .52649 .38174 L F
.52574 .38124 m .5262 .38176 L .52655 .38183 L F
.52613 .38162 m .52612 .38162 L .52612 .38162 L F
.52568 .38124 m .5262 .38176 L .52574 .38124 L F
.5254 .38034 m .52601 .3819 L .52532 .38058 L F
.52559 .38124 m .52589 .3815 L .52568 .38124 L F
.52589 .3815 m .5262 .38176 L .52568 .38124 L F
.52607 .38174 m .52603 .38179 L .52594 .38155 L F
.52589 .3815 m .52596 .38155 L .52596 .38155 L F
.52589 .3815 m .5262 .38176 L .52589 .3815 L F
.52604 .38168 m .52594 .38155 L .52575 .38107 L F
.52607 .38174 m .52594 .38155 L .52604 .38168 L F
.52612 .38162 m .52608 .38173 L .52612 .38162 L F
.52617 .38173 m .52661 .38221 L .52662 .38211 L F
.52589 .3815 m .52613 .38173 L .52617 .38173 L F
.52624 .38192 m .52672 .38187 L .52621 .38189 L F
.52692 .38189 m .52667 .38185 L .52781 .38146 L F
.52687 .38188 m .5266 .38184 L .52672 .38178 L F
.52669 .38205 m .52668 .38198 L .52774 .38246 L F
.52695 .3821 m .52696 .38211 L .52707 .3822 L F
.52666 .38221 m .52703 .38219 L .52774 .38246 L F
.52695 .3821 m .52707 .3822 L .52763 .38263 L F
.52672 .38178 m .52695 .3821 L .52763 .38263 L F
.52672 .38187 m .52693 .38185 L .52669 .38186 L F
.52628 .38196 m .52666 .3817 L .52628 .38197 L F
.52672 .38187 m .52669 .38186 L .52621 .38189 L F
.52613 .38173 m .52614 .38174 L .52617 .38173 L F
.52573 .3819 m .52654 .38183 L .52649 .38182 L F
.52614 .38174 m .52661 .38221 L .52619 .38175 L F
.52614 .38174 m .52619 .38175 L .52617 .38173 L F
.52596 .38155 m .5262 .38176 L .52596 .38155 L F
.52589 .3815 m .52608 .38173 L .52614 .38174 L F
.52644 .38174 m .52655 .38183 L .52646 .38174 L F
.52532 .38073 m .52481 .38077 L .52526 .38114 L F
.526 .38183 m .52636 .38179 L .52601 .38181 L F
.52636 .38179 m .5277 .38166 L .52632 .38178 L F
.52636 .38179 m .52632 .38178 L .52601 .38181 L F
.52741 .38122 m .52767 .38104 L .52766 .38106 L F
.52629 .38198 m .52739 .38122 L .52741 .38122 L F
.52739 .38122 m .52767 .38104 L .52741 .38122 L F
.5277 .38166 m .52767 .38165 L .52601 .38181 L F
.52944 .38148 m .52942 .38148 L .52767 .38165 L F
.52767 .38165 m .52767 .38165 L .52601 .38181 L F
.52944 .38148 m .52767 .38165 L .52767 .38165 L F
.52663 .38291 m .52643 .38283 L .52632 .38255 L F
.52663 .38291 m .52632 .38255 L .52638 .38245 L F
.53008 .39223 m .52643 .38237 L p .52622 .38228 L F P
0 g
s
.52594 .38155 m .52594 .38157 L .52593 .38155 L .67 .731 .896 r
F
.52595 .38165 m .52596 .38157 L .52589 .3815 L F
.52599 .38184 m .52599 .38183 L .52542 .38189 L F
.52646 .38174 m .52655 .38183 L .52659 .38184 L F
.52549 .38192 m .52596 .38187 L .52544 .38189 L F
.52596 .38187 m .52659 .3818 L .52598 .38185 L F
.52596 .38187 m .52598 .38185 L .52544 .38189 L F
.52604 .38214 m .52593 .38191 L .52604 .38215 L F
.52593 .38191 m .52564 .38128 L .52593 .3819 L F
.52593 .38191 m .52593 .3819 L .52604 .38215 L F
.52542 .38189 m .526 .38183 L .52601 .38181 L F
.52602 .38214 m .52574 .38152 L .52574 .38152 L F
.52604 .38215 m .52564 .38128 L .52564 .38128 L F
.52602 .38214 m .52602 .38214 L .52592 .38192 L F
.52592 .38192 m .52592 .38192 L .52534 .38066 L F
.52602 .38214 m .52592 .38192 L .52592 .38192 L F
.52592 .38192 m .52624 .38192 L .52621 .38189 L F
.52546 .38191 m .52478 .38215 L .52546 .38191 L F
.52351 .38216 m .52589 .38195 L .52592 .38192 L F
.52351 .38216 m .52589 .38195 L .52351 .38216 L F
.52619 .3822 m .52632 .38255 L .52618 .3822 L F
.5258 .38227 m .52589 .38221 L .52581 .38228 L F
.52589 .38221 m .52627 .38196 L .52589 .38222 L F
.52585 .38225 m .52598 .38264 L .52603 .38218 L F
.52602 .38233 m .52598 .38264 L .52603 .38233 L F
.52586 .38229 m .5263 .38285 L .5261 .38305 L F
.52578 .38204 m .52589 .38221 L .52586 .38229 L F
.52589 .38221 m .5263 .38285 L .52586 .38229 L F
.52629 .38198 m .52588 .38225 L p .52622 .38201 L F P
0 g
s
.52405 .38325 m .52569 .38227 L .52561 .38227 L .67 .731 .896 r
F
.52147 .38587 m .51654 .39034 L .52009 .38643 L F
.51575 .38991 m .52358 .38402 L p .52405 .38325 L F P
0 g
s
.52574 .38231 m .51986 .38678 L .52546 .38224 L .67 .731 .896 r
F
.52454 .38295 m .52464 .3829 L .52464 .3829 L F
.52405 .38325 m .52458 .38295 L .52454 .38295 L F
.52507 .38242 m .52424 .3831 L .52512 .38248 L F
.52489 .3827 m .52352 .38381 L .52479 .38254 L F
.52424 .3831 m .52405 .38325 L .52424 .38312 L F
.52352 .38381 m .51986 .38678 L .52479 .38254 L F
.52534 .38221 m .52507 .38242 L .52537 .38222 L F
.52532 .38217 m .52525 .38235 L .52488 .38248 L F
.52488 .38248 m .52489 .3827 L .52479 .38254 L F
.52507 .38242 m .52512 .38248 L .52516 .38245 L F
.52507 .38242 m .52516 .38245 L .52516 .38237 L F
.52539 .3823 m .52489 .3827 L .52488 .38248 L F
.52479 .38254 m .51986 .38678 L .51774 .38752 L F
.51575 .38991 m .515 .38945 L p .51774 .38752 L F P
0 g
s
.51986 .38678 m .51575 .38991 L .51774 .38752 L .67 .731 .896 r
F
.515 .38945 m .52522 .38269 L p .52518 .38227 L F P
0 g
s
.52588 .38225 m .52252 .38447 L p .52589 .38223 L .67 .731 .896 r
F P
0 g
s
.52588 .38225 m .52589 .38223 L .52622 .38201 L .67 .731 .896 r
F
.52589 .38221 m .52589 .38222 L .52581 .38228 L F
.52602 .38214 m .52645 .38308 L .52589 .38221 L F
.52585 .38225 m .52591 .38212 L .52591 .38212 L F
.52594 .3821 m .52589 .38221 L .52578 .38204 L F
.52602 .38214 m .52589 .38221 L .52594 .3821 L F
.52632 .38278 m .52602 .38214 L .52602 .38214 L F
.52632 .38255 m .52631 .38256 L .52616 .38219 L F
.52632 .38255 m .52616 .38219 L .52618 .3822 L F
.52634 .38279 m .52604 .38214 L .52604 .38215 L F
.525 .38107 m .52586 .38168 L p .52528 .38098 L F P
0 g
s
.52519 .38064 m .52551 .38139 L .52532 .3808 L .67 .731 .896 r
F
.52252 .38447 m .52589 .38222 L .52589 .38223 L F
.5249 .38288 m .52489 .38288 L .52502 .38279 L F
.52522 .38269 m .52583 .38228 L p .52518 .38227 L F P
0 g
s
.52502 .3828 m .52502 .38279 L .52627 .38196 L .67 .731 .896 r
F
.5249 .38288 m .52502 .38279 L .52502 .3828 L F
.52571 .38077 m .52566 .38075 L .52543 .38025 L F
.52616 .38164 m .52566 .38075 L .52571 .38077 L F
.52564 .38128 m .52592 .38191 L .52563 .38129 L F
.52528 .38098 m .52595 .38165 L .52589 .3815 L F
.52528 .38098 m .52589 .3815 L .52589 .3815 L F
.52574 .38152 m .52574 .38152 L .52563 .38129 L F
.52528 .38098 m .52586 .38168 L .52602 .38172 L F
.52586 .38168 m .52458 .38077 L p .5256 .38114 L F P
0 g
s
.52586 .38168 m .5256 .38114 L .52594 .38155 L .67 .731 .896 r
F
.52663 .38291 m .52599 .38157 L .52604 .38159 L F
.52599 .38157 m .52575 .38107 L .52604 .38159 L F
.52596 .38128 m .52543 .38093 L .52596 .38134 L F
.52604 .38159 m .52575 .38107 L .52577 .38101 L F
.52614 .38158 m .52616 .38164 L p .52614 .38159 L F P
0 g
s
.5258 .38071 m .52578 .38071 L .52569 .38039 L .67 .731 .896 r
F
.52543 .38093 m .52572 .38083 L .52583 .38027 L F
.52614 .38158 m .52614 .38159 L .52543 .38025 L F
.52587 .38147 m .52586 .38146 L .52561 .38086 L F
.52601 .38181 m .52561 .38086 L .52562 .38086 L F
.52601 .38182 m .52599 .38184 L .5254 .38034 L F
.52594 .38155 m .52593 .38155 L .5254 .38034 L F
.52616 .38164 m .52586 .38083 L p .52559 .38142 L F P
0 g
s
.52594 .38155 m .5256 .38114 L .52609 .38131 L .67 .731 .896 r
F
.52551 .38139 m .52559 .38142 L .52544 .38094 L F
.52532 .38058 m .52535 .38066 L .52534 .38066 L F
.52532 .3808 m .52544 .38094 L .52246 .37162 L F
.52551 .38139 m .52544 .38094 L .52532 .3808 L F
.52551 .38139 m .52556 .3815 L .52594 .38155 L F
.52562 .38136 m .52571 .38154 L .52559 .38143 L F
.52589 .38195 m .52624 .38192 L .52592 .38192 L F
.52608 .38173 m .52595 .38199 L .52595 .38172 L F
.52592 .38192 m .52602 .38214 L .5258 .38205 L F
.52595 .38199 m .5258 .38227 L .52595 .38172 L F
.52592 .38191 m .52632 .38278 L .52592 .38192 L F
.52595 .38172 m .52592 .38209 L .52595 .38203 L F
.5258 .38227 m .52553 .38221 L .52595 .38172 L F
.52595 .38172 m .52504 .38278 L .52503 .38278 L F
.5253 .38213 m .52503 .38278 L .52347 .38327 L F
.52595 .38172 m .52503 .38278 L .5253 .38213 L F
.52595 .38172 m .5253 .38213 L .52592 .38209 L F
.52358 .38402 m .52408 .38365 L p .52381 .38365 L F P
0 g
s
.52012 .38659 m .52591 .38218 L .52591 .38218 L .67 .731 .896 r
F
.5159 .3898 m .52012 .38659 L .52012 .38659 L F
.52012 .38659 m .52591 .38218 L .52012 .38659 L F
.52603 .38179 m .52619 .3822 L .52602 .38181 L F
.52619 .3822 m .52618 .3822 L .52591 .38156 L F
.52591 .38156 m .52591 .38156 L .52591 .38155 L F
.52679 .38229 m .52744 .38269 L p .52697 .38233 L F P
0 g
s
.52662 .3821 m .52749 .38283 L .52663 .38192 L .67 .731 .896 r
F
.52671 .38218 m .52748 .38282 L .52671 .38218 L F
.52661 .38221 m .52748 .38282 L p .52662 .38211 L F P
0 g
s
.52655 .38183 m .52749 .38283 L .52763 .38263 L .67 .731 .896 r
F
.52728 .38268 m .52629 .38198 L p .52783 .38263 L F P
0 g
s
.52666 .3817 m .52673 .38166 L .52666 .38171 L .67 .731 .896 r
F
.52667 .38177 m .52592 .38153 L .52666 .38175 L F
.52664 .38175 m .52596 .38128 L .52648 .38174 L F
.52661 .38158 m .52659 .38175 L .52622 .38164 L F
.5264 .38174 m .52639 .38174 L .52726 .38152 L F
.52607 .38174 m .52604 .38178 L .52746 .3816 L F
.52622 .38164 m .52659 .38175 L .52608 .38173 L F
.52616 .38158 m .52625 .3816 L .52675 .38128 L F
.52583 .38124 m .52644 .38174 L .52646 .38174 L F
.52596 .38155 m .5262 .38176 L .5262 .38176 L F
.52583 .38124 m .52646 .38174 L .52648 .38174 L F
.52657 .38129 m .52616 .38158 L .52675 .38128 L F
.52659 .38143 m .52658 .38133 L .52707 .38093 L F
.52695 .38121 m .5268 .38121 L .52707 .38093 L F
.52638 .38245 m .52632 .38255 L .52603 .38179 L F
.52608 .38173 m .52629 .38198 L .52614 .38174 L F
.52612 .38177 m .52614 .3818 L .52622 .38179 L F
.52661 .38175 m .52666 .3817 L .52666 .38171 L F
.52664 .38173 m .52596 .38128 L .52664 .38175 L F
.5266 .38175 m .52666 .3817 L .52661 .38175 L F
.52612 .38177 m .52622 .38179 L .5291 .38142 L F
.52612 .38177 m .5291 .38142 L .52904 .38141 L F
.52666 .38173 m .52666 .38173 L .53018 .37936 L F
.52614 .38208 m .52591 .38156 L .52591 .38156 L F
.52603 .38179 m .52602 .38181 L .52591 .38155 L F
.52554 .37995 m .52614 .38158 L p .52543 .38025 L F P
0 g
s
.52562 .38086 m .52561 .38086 L .5254 .38034 L .67 .731 .896 r
F
.52535 .38066 m .52564 .38128 L .52534 .38066 L F
.52564 .38128 m .52564 .38128 L .52532 .38058 L F
.52577 .38101 m .52575 .38107 L .52543 .38025 L F
.52543 .38025 m .52594 .38155 L .5254 .38034 L F
.5251 .37989 m .5251 .37989 L .52509 .37986 L F
.5251 .37989 m .52583 .38027 L .52509 .37986 L F
.52596 .38075 m .52587 .38063 L .52454 .37636 L F
.52576 .38048 m .52569 .38039 L .52454 .37636 L F
.52585 .38061 m .52576 .38048 L .52454 .37636 L F
.52454 .37636 m .52537 .37925 L .52519 .37934 L F
.52347 .37148 m .52463 .37578 L p .52454 .37636 L F P
0 g
s
.52583 .38027 m .52347 .37148 L p .52509 .37986 L .67 .731 .896 r
F P
0 g
s
.52441 .37691 m .52554 .37995 L p .52419 .37705 L .67 .731 .896 r
F P
0 g
s
.52554 .37995 m .52543 .38025 L .52419 .37705 L .67 .731 .896 r
F
.52543 .38025 m .5254 .38034 L .52457 .37822 L F
.52457 .37822 m .5254 .38034 L .52532 .38058 L F
.52419 .37705 m .52464 .37819 L .52457 .37822 L F
.52246 .37162 m .52441 .37691 L p .52419 .37705 L F P
0 g
s
.52586 .38083 m .52246 .37162 L p .52559 .38142 L .67 .731 .896 r
F P
0 g
s
.52609 .38131 m .5256 .38114 L .52519 .38064 L .67 .731 .896 r
F
.52532 .38073 m .52531 .38078 L .52585 .38126 L F
.52542 .38092 m .52561 .38129 L .52537 .38086 L F
.52561 .38129 m .5256 .3813 L .52524 .38062 L F
.52528 .38071 m .52559 .38131 L .52525 .38078 L F
.52559 .38131 m .52555 .38135 L .52525 .38078 L F
.52531 .38078 m .52526 .38114 L .52567 .38123 L F
.52531 .38078 m .52567 .38123 L .52585 .38126 L F
.52526 .38061 m .52542 .38092 L .52524 .38062 L F
.52542 .38092 m .52537 .38086 L .52524 .38062 L F
.52661 .38185 m .5266 .38184 L .52555 .38195 L F
.52629 .38198 m .52661 .38221 L p .52614 .38174 L F P
0 g
s
.52629 .38198 m .52617 .38184 L .52637 .38193 L .67 .731 .896 r
F
.52543 .3819 m .52543 .3819 L .52591 .38171 L F
.52546 .38191 m .52546 .38191 L .5262 .38165 L F
.52499 .38191 m .52614 .3818 L .52612 .38177 L F
.52586 .38168 m .52591 .38171 L p .52592 .38169 L F P
0 g
s
.52612 .38162 m .52608 .38173 L .52604 .38167 L .67 .731 .896 r
F
.52595 .38165 m .52602 .38172 L .52596 .38157 L F
.52602 .38172 m .52629 .38198 L .52608 .38173 L F
.52602 .38172 m .52608 .38173 L .52596 .38157 L F
.52608 .38173 m .52481 .38187 L .52607 .38174 L F
.52615 .38165 m .52592 .38169 L .52608 .38173 L F
.52592 .38169 m .52481 .38187 L .52608 .38173 L F
.52592 .38191 m .52592 .38192 L .52563 .38129 L F
.52311 .38215 m .52429 .38201 L .5243 .382 L F
.51089 .38483 m .51064 .38417 L p .52088 .38251 L F P
0 g
s
.52634 .38279 m .52632 .38278 L .52564 .38128 L .67 .731 .896 r
F
.52601 .3819 m .52648 .38309 L .52598 .382 L F
.52595 .38228 m .52625 .38237 L .52622 .38228 L F
.52604 .38214 m .52632 .3827 L .52603 .38214 L F
.52602 .38172 m .52592 .38169 L .52629 .38198 L F
.52591 .38171 m .52629 .38198 L p .52592 .38169 L F P
0 g
s
.52629 .38198 m .52595 .38174 L p .52617 .38184 L .67 .731 .896 r
F P
0 g
s
.52604 .3818 m .52622 .38228 L .52618 .38185 L .67 .731 .896 r
F
.52616 .38164 m .52663 .38291 L p .52609 .38172 L F P
0 g
s
.52609 .38174 m .52618 .38185 L .52617 .38167 L .67 .731 .896 r
F
.52481 .38187 m .52604 .38178 L .52607 .38174 L F
.52595 .38174 m .52599 .38174 L .52616 .38182 L F
.52595 .38174 m .52616 .38182 L .52617 .38184 L F
.52541 .38188 m .52538 .38189 L .52614 .3818 L F
.52604 .3818 m .52618 .38185 L .52609 .38174 L F
.52629 .38198 m .52616 .38164 L p .52618 .38185 L F P
0 g
s
.52617 .38184 m .52616 .38182 L .52637 .38193 L .67 .731 .896 r
F
.52614 .38208 m .52591 .38156 L .52614 .38208 L F
.52618 .3822 m .52601 .38182 L .52601 .38181 L F
.5261 .38174 m .52595 .38207 L .52623 .3819 L F
.52619 .3822 m .52614 .38208 L .52614 .38208 L F
.52589 .38222 m .52627 .38196 L .52627 .38196 L F
.52581 .38228 m .52589 .38222 L .52589 .38222 L F
.52589 .38222 m .52627 .38196 L .52589 .38222 L F
.52618 .3822 m .52616 .38219 L .52603 .38187 L F
.52603 .38187 m .52603 .38187 L .52601 .38182 L F
.52618 .3822 m .52603 .38187 L .52603 .38187 L F
.52602 .38214 m .52602 .38214 L .52597 .38202 L F
.52602 .38214 m .52597 .38202 L .52597 .38202 L F
.52571 .38193 m .5266 .38184 L .52573 .3819 L F
.5259 .38221 m .5258 .38227 L .52608 .38173 L F
.52653 .38309 m .52599 .38184 L .52601 .38182 L F
.52589 .38213 m .52622 .38228 L .52605 .38183 L F
.52629 .38198 m .52582 .38207 L p .52589 .38195 L F P
0 g
s
.52595 .38172 m .52595 .38203 L .52611 .38172 L .67 .731 .896 r
F
.52607 .38177 m .52589 .38195 L .52603 .38173 L F
.52595 .38203 m .52595 .38207 L .52611 .38172 L F
.52629 .38198 m .52589 .38195 L .52607 .38177 L F
.5273 .38089 m .52608 .38173 L .52613 .38162 L F
.52609 .38174 m .52605 .38169 L .52616 .38168 L F
.52615 .38165 m .52605 .38169 L .52604 .38167 L F
.52604 .38167 m .52608 .38173 L .52595 .38172 L F
.52604 .38167 m .52595 .38172 L .52608 .38172 L F
.52605 .38169 m .52597 .38172 L .52604 .38167 L F
.52604 .38167 m .52608 .38172 L .52611 .38172 L F
.52627 .38196 m .52627 .38196 L .52768 .38102 L F
.52615 .38165 m .52607 .38174 L .52746 .3816 L F
.52609 .38174 m .52617 .38167 L .52612 .38169 L F
.52677 .38188 m .52662 .38185 L .52696 .38211 L F
.5262 .38176 m .52671 .38218 L .5262 .38176 L F
.52645 .38191 m .52668 .38198 L .52639 .38193 L F
.52645 .38191 m .52649 .38189 L .52668 .38198 L F
.52687 .38188 m .52629 .38198 L .52667 .38185 L F
.52629 .38198 m .52686 .3819 L p .52654 .38189 L F P
0 g
s
.52686 .38188 m .52684 .3819 L .53303 .38134 L .67 .731 .896 r
F
.52692 .38189 m .52686 .3819 L p .52687 .38188 L F P
0 g
s
.52672 .38178 m .52667 .38177 L .52666 .38175 L .67 .731 .896 r
F
.52672 .38178 m .52666 .38175 L .52696 .38211 L F
.52819 .3818 m .52819 .3818 L .54191 .38048 L F
.52686 .38188 m .53303 .38134 L .52687 .38187 L F
.52711 .38185 m .53149 .38166 L .52712 .38184 L F
.52686 .3819 m .52777 .38178 L p .52672 .38187 L F P
0 g
s
.52654 .38189 m .52686 .3819 L .52672 .38187 L .67 .731 .896 r
F
.5268 .38201 m .5268 .38201 L .52661 .38185 L F
.5266 .38184 m .52661 .38185 L .52648 .38174 L F
.5268 .38201 m .52661 .38185 L .5266 .38184 L F
.52659 .38184 m .5268 .38201 L .5266 .38184 L F
.52693 .38192 m .52689 .38201 L .52697 .38193 L F
.52774 .38246 m .52687 .38206 L .52691 .38191 L F
.5268 .38201 m .527 .38216 L .5268 .38201 L F
.52667 .38177 m .52667 .38177 L .52672 .38178 L F
.52666 .38175 m .52662 .38185 L .52677 .38188 L F
.52693 .38185 m .52694 .38183 L .52621 .38189 L F
.52648 .38174 m .527 .38216 L .52696 .38211 L F
.5262 .38176 m .52662 .3821 L .52655 .38183 L F
.52662 .3821 m .52663 .38192 L .52655 .38183 L F
.52696 .38211 m .527 .38216 L .52763 .38263 L F
.52774 .38246 m .52672 .38178 L .52763 .38263 L F
.52609 .38174 m .52609 .38174 L .52612 .38169 L F
.52616 .38182 m .52609 .38174 L .52682 .38186 L F
.52659 .3818 m .52639 .3818 L .52645 .38181 L F
.52659 .38184 m .5266 .38184 L .52648 .38174 L F
.52618 .38185 m .53107 .38131 L .52618 .38184 L F
.52664 .38186 m .52629 .38198 L .52615 .38165 L F
.51365 .38844 m .51305 .38789 L p .522 .38361 L F P
0 g
s
.52613 .38168 m .52611 .38172 L .52654 .38172 L .67 .731 .896 r
F
.52604 .38167 m .52611 .38172 L .52613 .38168 L F
.52616 .38168 m .52605 .38169 L .52615 .38165 L F
.52612 .38169 m .52617 .38167 L .52616 .38164 L F
.52611 .38172 m .5261 .38174 L .52654 .38172 L F
.52612 .38177 m .52612 .38177 L .53059 .38121 L F
.52612 .38177 m .53193 .38105 L .53192 .38105 L F
.52666 .38175 m .52648 .38174 L .52662 .38185 L F
.52632 .38178 m .53107 .38131 L .52629 .38178 L F
.52781 .38146 m .52735 .38156 L .52726 .38152 L F
.52702 .38151 m .52746 .3816 L .54198 .37979 L F
.52837 .38129 m .52673 .3819 L .52664 .38186 L F
.52646 .38174 m .52659 .38184 L .52648 .38174 L F
.52659 .3818 m .52654 .38178 L .52639 .3818 L F
.52666 .3817 m .52659 .38175 L .52664 .38138 L F
.52702 .38151 m .52615 .38165 L .52746 .3816 L F
.53343 .3771 m .52666 .3817 L .52664 .38138 L F
.53604 .37546 m .53399 .37683 L .53343 .3771 L F
.53399 .37683 m .52666 .3817 L .53343 .3771 L F
.5243 .382 m .52498 .38192 L .52499 .38191 L F
.52498 .38192 m .52614 .3818 L .52499 .38191 L F
.52429 .38201 m .52498 .38193 L .5243 .382 L F
.52498 .38193 m .52614 .3818 L .52498 .38192 L F
.52498 .38193 m .52498 .38192 L .5243 .382 L F
.52311 .38215 m .52538 .38189 L .52541 .38188 L F
.52453 .38207 m .5248 .38219 L .52458 .38207 L F
.52453 .38204 m .52491 .38199 L .52451 .38203 L F
.52491 .38199 m .52492 .38198 L .52451 .38203 L F
.52313 .38218 m .52493 .38198 L .52496 .38194 L F
.52456 .38205 m .52455 .38205 L .52314 .38219 L F
.52314 .38219 m .52571 .38193 L .52573 .3819 L F
.52326 .38241 m .52461 .38222 L p .52314 .3822 L F P
0 g
s
.52461 .38222 m .52441 .38224 L p .52473 .38217 L .67 .731 .896 r
F P
0 g
s
.52314 .3822 m .52461 .38222 L .52453 .38207 L .67 .731 .896 r
F
.52257 .3825 m .52326 .38241 L p .52222 .38229 L F P
0 g
s
.52222 .38229 m .52326 .38241 L .52314 .3822 L .67 .731 .896 r
F
.52428 .38235 m .51089 .38483 L p .52516 .38186 L F P
0 g
s
.52505 .38185 m .52499 .38191 L .52604 .38178 L .67 .731 .896 r
F
.52543 .3819 m .52538 .38192 L .52543 .3819 L F
.52538 .38193 m .52516 .38186 L .52604 .38167 L F
.52456 .38205 m .52556 .38195 L .52455 .38205 L F
.52478 .38215 m .52538 .38192 L .52619 .38165 L F
.52556 .38195 m .52555 .38195 L .52455 .38205 L F
.52493 .38198 m .52549 .38192 L .52496 .38194 L F
.52549 .38192 m .52544 .38189 L .52496 .38194 L F
.52496 .38194 m .52544 .38189 L .52542 .38189 L F
.52473 .38217 m .52556 .38196 L .52556 .38196 L F
.52556 .38195 m .52478 .38215 L .52546 .38191 L F
.52458 .38207 m .52577 .38205 L .5256 .38197 L F
.52473 .38217 m .52441 .38224 L .52478 .38215 L F
.52478 .38215 m .52441 .38224 L .52538 .38192 L F
.52471 .3822 m .52461 .38222 L p .52469 .3822 L F P
0 g
s
.52461 .38222 m .5248 .38219 L p .52453 .38207 L .67 .731 .896 r
F P
0 g
s
.52428 .38235 m .52516 .38186 L .52538 .38193 L .67 .731 .896 r
F
.5263 .38285 m .52645 .38308 L .52623 .38306 L F
.52645 .38308 m .52602 .38214 L .52602 .38214 L F
.52632 .38278 m .52645 .38308 L .52631 .38278 L F
.52648 .38309 m .52632 .38278 L .52634 .38279 L F
.52648 .38309 m .52665 .38352 L .52645 .38308 L F
.52645 .38308 m .52665 .38352 L .52645 .38308 L F
.52645 .38308 m .52665 .38352 L .5261 .38305 L F
.52653 .38309 m .52648 .38309 L .52599 .38184 L F
.52632 .38255 m .52653 .38309 L .52631 .38256 L F
.52595 .38228 m .53008 .39223 L .52625 .38237 L F
.52632 .3827 m .5263 .38269 L .52601 .38213 L F
.52664 .38138 m .52661 .38158 L .52622 .38164 L F
.52657 .38129 m .52675 .38128 L .53767 .37445 L F
.52734 .38089 m .52608 .38173 L .5273 .38089 L F
.52696 .3811 m .52604 .38167 L .52736 .38123 L F
.52684 .38129 m .52605 .38177 L .52685 .38124 L F
.52594 .38155 m .52609 .38174 L .52616 .38164 L F
.52827 .38131 m .52702 .38151 L .52835 .38136 L F
.52827 .38131 m .52664 .38186 L .52615 .38165 L F
.52604 .38167 m .52654 .38172 L .52618 .38163 L F
.52596 .38128 m .52596 .38134 L .52648 .38174 L F
.52625 .38145 m .52625 .38142 L p .52622 .38149 L F P
0 g
s
.52626 .38142 m .52624 .38145 L .52625 .38145 L .67 .731 .896 r
F
.52666 .38175 m .52606 .3817 L .52609 .38131 L F
.52604 .38167 m .52721 .38132 L .5271 .38132 L F
.52609 .38131 m .52585 .38126 L .52632 .38174 L F
.52774 .38256 m .52616 .38182 L .52682 .38186 L F
.52673 .3819 m .52629 .38198 L p .52664 .38186 L F P
0 g
s
.52629 .38198 m .52637 .38193 L .52783 .38263 L .67 .731 .896 r
F
.52592 .38193 m .52559 .38131 L .5256 .3813 L F
.52632 .3827 m .52592 .38193 L .52592 .38193 L F
.52571 .38152 m .52587 .38183 L .52594 .38155 L F
.52556 .3815 m .52587 .38183 L .52571 .38152 L F
.52544 .38189 m .52599 .38184 L .52542 .38189 L F
.52595 .38188 m .52596 .38187 L .52451 .38203 L F
.52578 .38205 m .5254 .38193 L .5259 .38175 L F
.5258 .38205 m .52578 .38205 L .5259 .38175 L F
.5259 .38175 m .5254 .38193 L .52591 .38172 L F
.52471 .3822 m .52469 .3822 L .52617 .38184 L F
.5248 .38219 m .52577 .38205 L p .52458 .38207 L F P
0 g
s
.52491 .38199 m .52618 .38185 L .52492 .38198 L .67 .731 .896 r
F
.5254 .38193 m .52428 .38235 L .52538 .38193 L F
.5254 .38193 m .52538 .38193 L .52591 .38172 L F
.52587 .382 m .52673 .3819 L .52675 .38187 L F
.52593 .3821 m .52605 .38177 L .52601 .38208 L F
.52595 .38207 m .52666 .38173 L .52667 .3817 L F
.52659 .3818 m .53107 .38131 L .52654 .38178 L F
.52682 .38186 m .52619 .38174 L .52666 .38175 L F
.52594 .38218 m .52629 .38198 L p .52594 .38211 L F P
0 g
s
.52595 .38207 m .52594 .38211 L .52666 .38173 L .67 .731 .896 r
F
.52601 .38213 m .526 .38213 L .5259 .38196 L F
.52596 .38203 m .52601 .38213 L .52595 .38204 L F
.52601 .38213 m .52606 .38224 L .526 .38213 L F
.52629 .38198 m .52666 .38177 L p .52594 .38211 L F P
0 g
s
.52629 .38178 m .53107 .38131 L .53151 .38112 L .67 .731 .896 r
F
.52666 .38177 m .52681 .38168 L p .52666 .38175 L F P
0 g
s
.52594 .38211 m .52666 .38177 L .52666 .38175 L .67 .731 .896 r
F
.52504 .38278 m .515 .38945 L .52347 .38327 L F
.54144 .37848 m .54107 .37784 L p .5307 .38049 L F P
0 g
s
.5253 .38213 m .52148 .3845 L .52574 .38219 L .67 .731 .896 r
F
.52498 .38243 m .52484 .38247 L .52518 .38226 L F
.52578 .38205 m .52428 .38235 L .5254 .38193 L F
.5216 .3826 m .52577 .38208 L .52572 .38206 L F
.52516 .3823 m .52518 .38226 L .52607 .38171 L F
.52498 .38243 m .52518 .38226 L .52516 .3823 L F
.52519 .38064 m .5248 .38077 L .52481 .38077 L F
.52523 .38113 m .52422 .38032 L p .52544 .38094 L F P
0 g
s
.51529 .37421 m .51606 .37376 L p .51872 .37576 L .67 .731 .896 r
F P
0 g
s
.51698 .37449 m .5196 .3766 L p .51741 .37477 L .67 .731 .896 r
F P
0 g
s
.52403 .38038 m .525 .38107 L p .52439 .38024 L .67 .731 .896 r
F P
0 g
s
.51529 .37421 m .52403 .38038 L p .52439 .38024 L .67 .731 .896 r
F P
0 g
s
.52458 .38077 m .51529 .37421 L p .52463 .38021 L .67 .731 .896 r
F P
0 g
s
.5196 .3766 m .52523 .38113 L p .51926 .37627 L .67 .731 .896 r
F P
0 g
s
.51741 .37477 m .5196 .3766 L .51926 .37627 L .67 .731 .896 r
F
.51598 .37465 m .51529 .37421 L .51872 .37576 L F
.51741 .37477 m .52523 .38113 L .52526 .38114 L F
.52681 .38168 m .5275 .38128 L p .52684 .38163 L F P
0 g
s
.52667 .3817 m .52666 .38173 L .5275 .38128 L .67 .731 .896 r
F
.52783 .38263 m .52775 .38259 L .52774 .38256 L F
.52775 .38259 m .52616 .38182 L .52774 .38256 L F
.52811 .38156 m .52673 .3819 L .52837 .38129 L F
.5266 .38184 m .52895 .38161 L .52654 .38183 L F
.52654 .38183 m .52895 .38161 L .52649 .38182 L F
.52687 .38169 m .52675 .38187 L .52794 .38166 L F
.52673 .3819 m .5268 .38189 L p .52675 .38187 L F P
0 g
s
.54198 .37979 m .54174 .37913 L p .52827 .38131 L .67 .731 .896 r
F P
0 g
s
.52827 .38131 m .52835 .38136 L .54198 .37979 L .67 .731 .896 r
F
.53002 .38129 m .528 .38167 L p .53211 .38069 L F P
0 g
s
.52661 .38185 m .52895 .38161 L .5266 .38184 L .67 .731 .896 r
F
.52621 .38189 m .52777 .38178 L .52781 .38172 L F
.52639 .3818 m .53107 .38131 L .52636 .38179 L F
.52649 .38182 m .52895 .38161 L .52902 .38154 L F
.528 .38167 m .52673 .3819 L p .52806 .3816 L F P
0 g
s
.52612 .38177 m .53059 .38121 L .53059 .38121 L .67 .731 .896 r
F
.5277 .38166 m .52944 .38148 L .52767 .38165 L F
.528 .38167 m .52806 .3816 L .53211 .38069 L F
.52783 .38263 m .52687 .3819 L .52773 .38314 L F
.52687 .3819 m .52676 .38188 L .52773 .38314 L F
.52659 .38187 m .52675 .38187 L .52664 .38185 L F
.52666 .38175 m .52663 .38191 L .52773 .38314 L F
.52783 .38263 m .52773 .38314 L .52796 .38332 L F
.52796 .38332 m .53642 .39013 L p .5283 .38298 L F P
0 g
s
.53642 .39013 m .52679 .38214 L .52684 .3819 L .67 .731 .896 r
F
.52661 .38202 m .5266 .38209 L .52773 .38314 L F
.52663 .38191 m .52661 .38202 L .52773 .38314 L F
.53642 .39013 m .52675 .38235 L p .52679 .38214 L F P
0 g
s
.53561 .39055 m .53642 .39013 L p .52734 .38232 L .67 .731 .896 r
F P
0 g
s
.52687 .3819 m .52666 .38175 L .52676 .38188 L .67 .731 .896 r
F
.52666 .38175 m .52681 .38168 L .52666 .38173 L F
.52594 .38211 m .52666 .38175 L .52666 .38173 L F
.52654 .38172 m .52595 .38207 L .5266 .38174 L F
.52666 .38177 m .52629 .38198 L p .52636 .38174 L F P
0 g
s
.52597 .38172 m .52595 .38172 L .52604 .38167 L .67 .731 .896 r
F
.52609 .38174 m .52603 .38173 L .52605 .38169 L F
.5259 .38175 m .52591 .38172 L .52593 .38172 L F
.52595 .38172 m .52593 .38172 L .52604 .38167 L F
.5259 .38175 m .52593 .38172 L .52595 .38172 L F
.52595 .38174 m .52591 .38171 L p .52599 .38174 L F P
0 g
s
.52591 .38171 m .52586 .38168 L p .52594 .38172 L .67 .731 .896 r
F P
0 g
s
.52591 .38171 m .52594 .38172 L .52599 .38174 L .67 .731 .896 r
F
.52594 .38172 m .52586 .38168 L .52682 .38186 L F
.52629 .38198 m .52623 .3819 L .52625 .38189 L F
.52623 .3819 m .52609 .38174 L .52625 .38189 L F
.52625 .38189 m .52609 .38174 L .52616 .38168 L F
.5261 .38174 m .52623 .3819 L .5265 .38175 L F
.52615 .38182 m .52659 .38187 L .52635 .38178 L F
.52616 .38182 m .52594 .38172 L .52609 .38174 L F
.52629 .38198 m .52603 .38173 L .52609 .38174 L F
.52598 .38185 m .52618 .38185 L .52615 .38182 L F
.52629 .38198 m .52621 .38189 L .52636 .38174 L F
.52618 .38185 m .52659 .38187 L .52615 .38182 L F
.52622 .38228 m .52629 .38198 L .52618 .38185 L F
.52587 .382 m .52675 .38187 L .52598 .38185 L F
.52585 .38202 m .52673 .3819 L .52587 .382 L F
.52707 .38364 m .52684 .38364 L .52599 .38194 L F
.52606 .3817 m .52586 .38168 L .52594 .38155 L F
.52597 .38172 m .5259 .38175 L .52595 .38172 L F
.52589 .38213 m .52605 .38183 L .52594 .38155 L F
.52585 .38202 m .52629 .38198 L .52627 .38196 L F
.52578 .38203 m .52579 .38206 L .5258 .38203 L F
.52578 .38203 m .5258 .38203 L .52587 .38183 L F
.52543 .38162 m .52545 .38159 L .52583 .38172 L F
.52564 .38166 m .52564 .38167 L .5256 .38166 L F
.52556 .3815 m .52578 .38203 L .52587 .38183 L F
.52579 .38206 m .5258 .38209 L .52582 .38203 L F
.52583 .38202 m .5259 .38175 L .52605 .38169 L F
.52579 .38207 m .5258 .38205 L .52583 .38202 L F
.5258 .38205 m .5259 .38175 L .52583 .38202 L F
.5258 .38209 m .52589 .38213 L .52591 .38193 L F
.5258 .38209 m .52591 .38193 L .52582 .38203 L F
.52582 .38207 m .5258 .38206 L .52605 .38169 L F
.52582 .38203 m .52591 .38193 L .52594 .38155 L F
.52579 .38206 m .52582 .38203 L .52587 .38183 L F
.52556 .3815 m .52587 .382 L .52579 .38206 L F
.52587 .382 m .52582 .38207 L .52579 .38206 L F
.52579 .38207 m .52577 .38208 L p .5258 .38205 L F P
0 g
s
.52592 .38209 m .52574 .38219 L .52585 .38221 L .67 .731 .896 r
F
.52585 .38221 m .52631 .3833 L .52589 .38213 L F
.52631 .3833 m .53008 .39223 L .5264 .38335 L F
.52631 .3833 m .5264 .38335 L .52589 .38213 L F
.52589 .38213 m .52595 .38228 L .52622 .38228 L F
.52592 .38209 m .52586 .3822 L .52594 .38216 L F
.52586 .3822 m .52583 .38225 L .52594 .38216 L F
.52589 .38221 m .52623 .38267 L .52587 .38226 L F
.52594 .38216 m .52587 .38221 L .52594 .38218 L F
.52589 .38221 m .52594 .38218 L p .52587 .38221 L F P
0 g
s
.52629 .38198 m .52589 .38221 L p .52621 .38189 L .67 .731 .896 r
F P
0 g
s
.52594 .38213 m .52592 .38212 L .52594 .38218 L .67 .731 .896 r
F
.52595 .38207 m .52592 .38212 L .52594 .38213 L F
.52595 .38207 m .52592 .38209 L .52592 .38212 L F
.52593 .3821 m .526 .38223 L .52589 .38221 L F
.526 .38223 m .52623 .38267 L .52589 .38221 L F
.52585 .38221 m .52589 .38221 L .52587 .38226 L F
.52583 .38225 m .52589 .38221 L p .52587 .38221 L F P
0 g
s
.52581 .3821 m .52587 .38218 L .52589 .38213 L .67 .731 .896 r
F
.5253 .38213 m .52574 .38219 L .52592 .38209 L F
.5258 .38209 m .52587 .38218 L .52581 .3821 L F
.5258 .38209 m .52585 .38221 L .52587 .38218 L F
.52579 .38206 m .52593 .3821 L .52589 .38221 L F
.52579 .38206 m .52589 .38221 L .52585 .38221 L F
.52627 .38198 m .52629 .38198 L p .52627 .38198 L F P
0 g
s
.52572 .38206 m .52627 .38198 L .52627 .38198 L .67 .731 .896 r
F
.52582 .38207 m .52579 .38207 L p .5258 .38206 L F P
0 g
s
.5259 .38218 m .52593 .3821 L .52601 .38208 L .67 .731 .896 r
F
.52572 .38206 m .52629 .38198 L .52569 .38204 L F
.52606 .38224 m .526 .38223 L .52587 .38199 L F
.5259 .38196 m .52587 .38199 L .52563 .38152 L F
.52595 .38203 m .52592 .38209 L .52595 .38207 L F
.52606 .38224 m .52587 .38199 L .5259 .38196 L F
.52577 .38208 m .52428 .38235 L p .5258 .38205 L F P
0 g
s
.52577 .38208 m .52582 .38207 L p .52572 .38206 L .67 .731 .896 r
F P
0 g
s
.52582 .38207 m .52627 .38198 L p .52584 .38204 L .67 .731 .896 r
F P
0 g
s
.52572 .38206 m .52582 .38207 L .52584 .38204 L .67 .731 .896 r
F
.52587 .382 m .52593 .3821 L .52582 .38207 L F
.52585 .38203 m .52629 .38198 L .52585 .38202 L F
.52638 .38272 m .52632 .3827 L .52593 .38192 L F
.52589 .38221 m .5259 .38218 L .52621 .38189 L F
.52648 .38175 m .52637 .38179 L .52655 .38183 L F
.52638 .38272 m .52593 .38192 L .52594 .38189 L F
.52589 .38221 m .52583 .38225 L p .5259 .38218 L F P
0 g
s
.52596 .38201 m .52596 .38203 L .52569 .3815 L .67 .731 .896 r
F
.52569 .38151 m .52569 .3815 L .52559 .38131 L F
.52596 .38201 m .52569 .3815 L .52569 .38151 L F
.52618 .38163 m .52654 .38172 L .52721 .38132 L F
.52666 .38175 m .52609 .38131 L .52648 .38175 L F
.52666 .38177 m .52648 .38175 L .52663 .38191 L F
.52666 .38175 m .52648 .38175 L .52666 .38177 L F
.52686 .38123 m .52607 .38171 L .52604 .38168 L F
.5261 .38174 m .52619 .38174 L .52617 .38174 L F
.52642 .38173 m .52652 .38173 L .52654 .38172 L F
.52619 .38174 m .52586 .38168 L .52666 .38175 L F
.52607 .38171 m .52607 .38172 L .52607 .38171 L F
.52594 .38189 m .52593 .38192 L .52527 .38062 L F
.52527 .38062 m .52527 .38062 L .52526 .38061 L F
.52594 .38189 m .52527 .38062 L .52527 .38062 L F
.52569 .38204 m .52585 .38203 L .52585 .38202 L F
.52601 .38187 m .52599 .38194 L .52579 .38154 L F
.52556 .3815 m .52593 .3821 L .52593 .3821 L F
.52505 .382 m .52587 .382 L .52598 .38185 L F
.52609 .38131 m .52632 .38174 L .52648 .38175 L F
.52621 .38189 m .52629 .38162 L .52647 .38164 L F
.52601 .38208 m .52616 .38183 L .52621 .38189 L F
.52616 .38183 m .52623 .38173 L .52621 .38189 L F
.5261 .38174 m .5261 .38174 L .5265 .38175 L F
.52623 .38173 m .52626 .38173 L .52621 .38189 L F
.52605 .38177 m .52609 .38172 L .52613 .38172 L F
.52604 .3818 m .52609 .38174 L .52609 .38174 L F
.52607 .38171 m .52598 .38185 L .52615 .38182 L F
.52601 .38208 m .52605 .38177 L .52629 .38162 L F
.52607 .38171 m .52615 .38182 L .52635 .38178 L F
.52594 .38155 m .52604 .3818 L .52609 .38174 L F
.52605 .38177 m .52606 .38174 L .52609 .38172 L F
.52618 .38172 m .52599 .38171 L .52673 .38233 L F
.52631 .38177 m .5266 .38209 L .52637 .38179 L F
.52637 .38179 m .5266 .38209 L .52661 .38202 L F
.52628 .38173 m .52621 .38173 L .5266 .38209 L F
.52679 .38214 m .52609 .38174 L .52636 .38178 L F
.52638 .38179 m .52637 .38179 L .52635 .38178 L F
.52659 .38187 m .52637 .38179 L .52638 .38179 L F
.52659 .38187 m .52664 .38185 L .52637 .38179 L F
.52655 .38183 m .52637 .38179 L .52661 .38202 L F
.52663 .38187 m .52629 .38198 L .52624 .38176 L F
.52648 .38175 m .52632 .38174 L .52637 .38179 L F
.52666 .38177 m .52636 .38174 L .52684 .38129 L F
.52607 .38171 m .52635 .38178 L .52687 .38169 L F
.52585 .38126 m .52631 .38177 L .52637 .38179 L F
.52644 .38179 m .52624 .38176 L .52623 .38171 L F
.52623 .38173 m .52629 .38162 L .52626 .38173 L F
.52611 .38166 m .52607 .38171 L .52687 .38169 L F
.52679 .38214 m .52673 .38208 L .52684 .3819 L F
.52666 .38173 m .52681 .38168 L .52684 .38163 L F
.52673 .38167 m .52768 .38102 L .52767 .38104 L F
.52673 .38166 m .52768 .38102 L .52673 .38167 L F
.52777 .381 m .52666 .38173 L p .52772 .38102 L F P
0 g
s
.52736 .38123 m .52654 .38172 L .5275 .38128 L .67 .731 .896 r
F
.52654 .38172 m .5266 .38174 L .5275 .38128 L F
.5271 .38132 m .52721 .38132 L .52736 .38123 L F
.52786 .38107 m .52668 .38175 L p .52753 .38087 L F P
0 g
s
.527 .38148 m .52684 .38169 L .52687 .38169 L .67 .731 .896 r
F
.52668 .38175 m .52666 .38177 L p .52684 .38129 L F P
0 g
s
.527 .38148 m .52611 .38166 L .52684 .38169 L .67 .731 .896 r
F
.52635 .38178 m .52675 .38187 L .52687 .38169 L F
.52673 .38183 m .52645 .38176 L .52684 .3817 L F
.52645 .38176 m .52623 .38171 L .52684 .3817 L F
.52684 .3817 m .52623 .38171 L .527 .38148 L F
.52629 .38198 m .52673 .3819 L p .52627 .38196 L F P
0 g
s
.52655 .38183 m .52661 .38202 L .52663 .38191 L .67 .731 .896 r
F
.52673 .38208 m .52636 .38178 L .52673 .38183 L F
.52669 .38189 m .52644 .38179 L .52673 .38183 L F
.52644 .38179 m .52623 .38171 L .52673 .38183 L F
.527 .38148 m .52643 .38165 L .52636 .38161 L F
.52643 .38165 m .52623 .38171 L .52636 .38161 L F
.52636 .38161 m .52623 .38171 L .52611 .38166 L F
.52647 .38164 m .52629 .38162 L .52684 .38129 L F
.52609 .38165 m .52641 .38173 L .52671 .38164 L F
.52675 .38154 m .52671 .38164 L .52737 .38143 L F
.52609 .38165 m .52671 .38164 L .52675 .38154 L F
.52673 .38183 m .52563 .38117 L .52673 .38183 L F
.52606 .3817 m .52594 .38155 L .52609 .38131 L F
.52585 .38126 m .52567 .38123 L .52621 .38173 L F
.52585 .38126 m .52621 .38173 L .52628 .38173 L F
.52797 .38054 m .52608 .38173 L .52784 .38055 L F
.52624 .38162 m .52621 .38163 L .52686 .38123 L F
.52609 .38172 m .52621 .38163 L .52624 .38162 L F
.52602 .38155 m .52599 .38162 L .52618 .38172 L F
.52607 .38172 m .52607 .38172 L .52607 .38171 L F
.52643 .38237 m .52629 .38198 L p .52622 .38228 L F P
0 g
s
.52629 .38198 m .52707 .38364 L p .52604 .3818 L .67 .731 .896 r
F P
0 g
s
.52607 .38171 m .52604 .3818 L .52582 .3814 L .67 .731 .896 r
F
.52629 .38198 m .52604 .3818 L .52607 .38171 L F
.52599 .38162 m .52597 .3817 L .52607 .38171 L F
.52599 .38162 m .52607 .38171 L .52618 .38172 L F
.52609 .38172 m .52607 .38171 L .52621 .38163 L F
.52585 .38105 m .52629 .38198 L p .5257 .3812 L F P
0 g
s
.52567 .38123 m .52597 .38171 L .52602 .38155 L .67 .731 .896 r
F
.52607 .38171 m .52582 .3814 L .52608 .3817 L F
.52607 .38171 m .52607 .38171 L .52604 .38168 L F
.52607 .38171 m .52607 .38171 L .52607 .38171 L F
.52608 .3817 m .52582 .3814 L .5257 .3812 L F
.52629 .38198 m .52607 .38171 L .52608 .3817 L F
.52613 .38172 m .52609 .38172 L .52685 .38124 L F
.52685 .38124 m .52685 .38124 L .52686 .38123 L F
.52605 .38177 m .52685 .38124 L .52685 .38124 L F
.52685 .38124 m .52609 .38165 L .52675 .38154 L F
.52583 .38156 m .52579 .38154 L .52565 .38125 L F
.52561 .38129 m .52574 .38155 L .5256 .3813 L F
.52574 .38155 m .52572 .38155 L .5256 .3813 L F
.52525 .38078 m .52559 .38143 L .52556 .3815 L F
.52559 .38131 m .52562 .38136 L .52555 .38135 L F
.52562 .38136 m .52559 .38143 L .52555 .38135 L F
.52567 .38123 m .52537 .38123 L .52597 .38171 L F
.5259 .38195 m .5259 .38196 L .52563 .38152 L F
.52607 .38171 m .52501 .38192 L .52598 .38185 L F
.52611 .38166 m .52597 .38169 L .52607 .38171 L F
.52607 .38171 m .52564 .38198 L .52605 .38169 L F
.52574 .38155 m .52604 .38214 L .52572 .38155 L F
.52597 .38169 m .52504 .38188 L .52607 .38171 L F
.52564 .38198 m .52519 .38226 L .52605 .38169 L F
.52596 .38203 m .52595 .38204 L .52563 .38152 L F
.52501 .38192 m .52491 .38203 L .52598 .38185 L F
.52605 .38169 m .52519 .38226 L .52604 .38168 L F
.52516 .38231 m .52607 .38171 L .52609 .38172 L F
.52498 .38243 m .52516 .3823 L .52516 .38231 L F
.52516 .3823 m .52607 .38171 L .52516 .38231 L F
.52519 .38064 m .52296 .37895 L .5248 .38077 L F
.52544 .38094 m .52449 .38021 L .52476 .38011 L F
.52532 .38073 m .52519 .38064 L .52481 .38077 L F
.5252 .38095 m .52536 .38095 L .52492 .38026 L F
.52531 .38059 m .52576 .38149 L .52526 .38061 L F
.52519 .38064 m .52532 .3808 L .52526 .38061 L F
.5257 .3812 m .52565 .38125 L .52495 .37986 L F
.52491 .37997 m .52528 .38071 L .52525 .38078 L F
.52536 .38095 m .52579 .38093 L .52492 .38026 L F
.52447 .37826 m .52452 .37821 L .52265 .37221 L F
.52495 .37986 m .52531 .38059 L .52491 .37997 L F
.52531 .38059 m .52524 .38062 L .52491 .37997 L F
.52246 .37162 m .52147 .37181 L p .52519 .38064 L F P
0 g
s
.52509 .37946 m .52585 .38105 L p .52495 .37986 L .67 .731 .896 r
F P
0 g
s
.52609 .38131 m .52532 .38073 L .52585 .38126 L .67 .731 .896 r
F
.52585 .38105 m .5257 .3812 L .52495 .37986 L F
.52476 .37875 m .52509 .37946 L p .52441 .3788 L F P
0 g
s
.52509 .37946 m .52495 .37986 L .52441 .3788 L .67 .731 .896 r
F
.52441 .3788 m .52495 .37986 L .52491 .37997 L F
.52147 .37181 m .52476 .37875 L p .52441 .3788 L F P
0 g
s
.52579 .38093 m .52147 .37181 L p .52492 .38026 L .67 .731 .896 r
F P
0 g
s
.52422 .38032 m .52449 .38021 L .52544 .38094 L .67 .731 .896 r
F
.5256 .3813 m .52559 .38131 L .52524 .38062 L F
.52607 .38171 m .52607 .38172 L .52618 .38172 L F
.52599 .38171 m .52607 .38172 L .52607 .38171 L F
.52599 .38171 m .52599 .38171 L .52607 .38172 L F
.52648 .38257 m .52565 .38125 L .5257 .3812 L F
.52707 .38364 m .52647 .38262 L .52648 .38257 L F
.52647 .38262 m .52565 .38125 L .52648 .38257 L F
.52597 .3817 m .52597 .38171 L .52599 .38171 L F
.52597 .3817 m .52599 .38171 L .52599 .38171 L F
.52593 .38174 m .52522 .38219 L .52593 .38174 L F
.5248 .38215 m .52587 .382 L .52491 .38203 L F
.52522 .38219 m .52522 .38218 L .52593 .38174 L F
.52499 .38203 m .52587 .382 L .52505 .382 L F
.52593 .38174 m .52522 .38218 L .52526 .38211 L F
.52604 .38168 m .52593 .38174 L .52593 .38174 L F
.52604 .38168 m .52528 .38209 L .52605 .38169 L F
.52618 .38163 m .52632 .38159 L .52673 .38183 L F
.52631 .38173 m .52674 .38141 L .52672 .38146 L F
.52597 .38205 m .52597 .38205 L .52596 .38203 L F
.52603 .38213 m .52597 .38205 L .52597 .38205 L F
.52603 .38213 m .52601 .38213 L .52597 .38205 L F
.52603 .38213 m .52596 .38203 L .52596 .38201 L F
.52576 .38149 m .5261 .38216 L .52526 .38061 L F
.5261 .38216 m .52638 .38272 L .52608 .38215 L F
.5261 .38216 m .52608 .38215 L .52526 .38061 L F
.52481 .38187 m .52311 .38215 L .52499 .38191 L F
.52311 .38215 m .52313 .38218 L .52538 .38189 L F
.52453 .38204 m .52451 .38203 L .52313 .38218 L F
.52508 .38183 m .5239 .38212 L .52364 .38206 L F
.52604 .38167 m .52516 .38186 L .52508 .38183 L F
.52481 .38187 m .52499 .38191 L .52499 .38191 L F
.52481 .38187 m .52499 .38191 L .52505 .38185 L F
.52516 .38186 m .5239 .38212 L .52508 .38183 L F
.52588 .38224 m .52615 .38233 L .52614 .38166 L F
.52598 .38194 m .52597 .38196 L .52622 .3819 L F
.52598 .38194 m .52622 .3819 L .52622 .38189 L F
.52599 .38171 m .52599 .38172 L .5263 .38198 L F
.52631 .38198 m .5263 .38198 L .52673 .38233 L F
.52599 .38171 m .5263 .38198 L .52631 .38198 L F
.52647 .38262 m .52599 .38194 L .52601 .38187 L F
.52645 .38267 m .52599 .38194 L .52647 .38262 L F
.52644 .38229 m .52629 .38198 L p .52615 .38275 L F P
0 g
s
.52519 .38226 m .52522 .38219 L .52604 .38168 L .67 .731 .896 r
F
.52599 .38171 m .52597 .38171 L .52599 .38172 L F
.52614 .38197 m .52615 .38168 L .52614 .38169 L F
.52623 .38171 m .5261 .38175 L .5261 .38173 L F
.52615 .38168 m .5261 .38173 L .52611 .38166 L F
.52623 .38171 m .5261 .38173 L .52615 .38168 L F
.52629 .38198 m .52598 .38174 L p .52609 .38174 L F P
0 g
s
.52599 .38172 m .52598 .38174 L .52641 .38173 L .67 .731 .896 r
F
.52598 .38174 m .52596 .38172 L p .52609 .38174 L F P
0 g
s
.52598 .38174 m .52597 .38187 L .52615 .38182 L .67 .731 .896 r
F
.52598 .38174 m .52615 .38182 L .52609 .38174 L F
.52604 .38214 m .52603 .38214 L .52572 .38155 L F
.52602 .38155 m .52673 .38233 L .5269 .38237 L F
.52615 .38168 m .52614 .38166 L p .52614 .38169 L F P
0 g
s
.52611 .38165 m .52605 .38169 L .52641 .38173 L .67 .731 .896 r
F
.52605 .38169 m .52599 .38172 L .52608 .38172 L F
.5261 .38173 m .52605 .38168 L .52611 .38166 L F
.52583 .38225 m .52605 .38177 L .5259 .38218 L F
.52585 .38217 m .52588 .38224 L .52614 .38166 L F
.5261 .38175 m .52609 .38174 L .5261 .38173 L F
.52609 .38174 m .52605 .38168 L .5261 .38173 L F
.52605 .38169 m .52608 .38172 L .52641 .38173 L F
.52598 .38174 m .52637 .38175 L .52641 .38173 L F
.5261 .38175 m .52596 .38172 L .52609 .38174 L F
.52614 .38166 m .52611 .3816 L p .526 .38184 L F P
0 g
s
.52601 .38213 m .5259 .38196 L .5259 .38195 L .67 .731 .896 r
F
.52629 .38198 m .52615 .38168 L p .52614 .38197 L F P
0 g
s
.52636 .38178 m .52632 .38175 L .52673 .38183 L .67 .731 .896 r
F
.52632 .38175 m .5265 .38175 L .52673 .38183 L F
.52663 .38187 m .52624 .38176 L .52644 .38179 L F
.52679 .38214 m .52629 .38198 L .52609 .38174 L F
.52629 .38198 m .52614 .3818 L .52623 .38171 L F
.52605 .38177 m .52498 .38243 L .52606 .38174 L F
.52528 .38209 m .52665 .3818 L .52647 .38175 L F
.52637 .38175 m .52647 .38175 L .52641 .38173 L F
.52528 .38209 m .52647 .38175 L .52637 .38175 L F
.52632 .38175 m .52618 .38163 L .5265 .38175 L F
.52583 .38225 m .52545 .38214 L .52605 .38177 L F
.52585 .38217 m .52609 .38174 L .526 .38184 L F
.52599 .38172 m .52598 .38172 L .52599 .38173 L F
.52598 .38172 m .52528 .38209 L .52599 .38173 L F
.52599 .38173 m .52528 .38209 L .52597 .38187 L F
.5261 .38175 m .52538 .38197 L .52596 .38172 L F
.52609 .38174 m .52614 .38166 L .526 .38184 L F
.52609 .38174 m .52596 .38172 L .52605 .38168 L F
.52596 .38172 m .52596 .38172 L .52597 .38172 L F
.52596 .38172 m .52597 .38172 L .52605 .38168 L F
.52609 .38174 m .52594 .3817 L .52597 .38159 L F
.52596 .38172 m .52594 .3817 L p .52609 .38174 L F P
0 g
s
.52504 .38188 m .52501 .38192 L .52607 .38171 L .67 .731 .896 r
F
.52611 .38166 m .52526 .38194 L .52504 .38188 L F
.52601 .38187 m .52579 .38154 L .52583 .38156 L F
.52476 .38011 m .52484 .38008 L .52308 .37576 L F
.52307 .37586 m .52308 .37576 L .52147 .37181 L F
.52476 .38011 m .52308 .37576 L .52307 .37586 L F
.52147 .37181 m .52049 .37203 L p .52476 .38011 L F P
0 g
s
.5245 .37961 m .5245 .37961 L .52447 .37957 L .67 .731 .896 r
F
.52482 .38008 m .5245 .37961 L .5245 .37961 L F
.52482 .38008 m .52481 .38009 L .5245 .37961 L F
.52049 .37203 m .51954 .3723 L p .52374 .37886 L F P
0 g
s
.52318 .37789 m .52385 .37882 L .52315 .37788 L .67 .731 .896 r
F
.52612 .38128 m .52563 .38117 L .52476 .38011 L F
.52535 .38077 m .5253 .38078 L .52557 .38111 L F
.52534 .38076 m .52529 .38076 L .52535 .38077 L F
.52454 .37943 m .52547 .38098 L .52447 .37957 L F
.52567 .38123 m .52526 .38114 L .52537 .38123 L F
.52597 .38159 m .52523 .38113 L .52544 .38094 L F
.52523 .38113 m .52594 .3817 L p .52526 .38114 L F P
0 g
s
.5252 .38095 m .52551 .38154 L .52579 .38093 L .67 .731 .896 r
F
.52547 .38098 m .52564 .38126 L .52532 .38079 L F
.52558 .38081 m .52476 .38011 L .52535 .38077 L F
.52449 .38021 m .51993 .37672 L .52476 .38011 L F
.52476 .38011 m .5252 .38095 L .52496 .38035 L F
.52476 .38011 m .52496 .38035 L .52484 .38008 L F
.5248 .38009 m .52525 .3808 L .52476 .38011 L F
.52476 .38011 m .52366 .37917 L .52513 .38057 L F
.52476 .38011 m .52513 .38057 L .52535 .38077 L F
.52517 .38062 m .52481 .38009 L .52482 .38008 L F
.52561 .38127 m .52513 .38057 L .52517 .38062 L F
.52513 .38057 m .52481 .38009 L .52517 .38062 L F
.52547 .38098 m .52532 .38079 L .52447 .37957 L F
.52447 .37957 m .5248 .38009 L .52476 .38011 L F
.52492 .38031 m .52512 .37997 L .52432 .37957 L F
.5257 .38079 m .52446 .37974 L .52374 .37886 L F
.52446 .37974 m .52352 .37895 L .52374 .37886 L F
.52465 .37917 m .52574 .38104 L p .52454 .37943 L F P
0 g
s
.52346 .37765 m .52454 .37943 L .52447 .37957 L .67 .731 .896 r
F
.52432 .37957 m .52512 .37997 L .52385 .37864 L F
.52561 .38127 m .52559 .38129 L .52506 .38048 L F
.52525 .3808 m .5256 .38135 L .52516 .38087 L F
.5253 .38078 m .52499 .38079 L .52557 .38111 L F
.52513 .38057 m .52506 .38048 L .52481 .38009 L F
.52561 .38127 m .52506 .38048 L .52513 .38057 L F
.51993 .37672 m .5203 .37685 L .52476 .38011 L F
.52558 .38081 m .52535 .38077 L .52582 .38122 L F
.52574 .38104 m .52564 .38126 L .52454 .37943 L F
.52559 .38129 m .52558 .38131 L .52502 .38042 L F
.52506 .38048 m .52502 .38042 L .52447 .37957 L F
.52559 .38129 m .52502 .38042 L .52506 .38048 L F
.52476 .38011 m .52525 .3808 L .52516 .38087 L F
.52468 .38013 m .52499 .38079 L .52529 .38076 L F
.52513 .38057 m .52529 .38076 L .52534 .38076 L F
.52564 .38126 m .52563 .38129 L .52447 .37957 L F
.52468 .38013 m .52529 .38076 L .52513 .38057 L F
.5245 .38019 m .52499 .38079 L .52468 .38013 L F
.51606 .37376 m .51688 .37334 L p .52145 .37727 L F P
0 g
s
.52476 .38011 m .5203 .37685 L .52145 .37727 L .67 .731 .896 r
F
.5203 .37685 m .51606 .37376 L .52145 .37727 L F
.52526 .38114 m .52594 .3817 L .52596 .3817 L F
.52594 .3817 m .52523 .38113 L p .52597 .38159 L F P
0 g
s
.52571 .38154 m .52563 .38152 L .52559 .38143 L .67 .731 .896 r
F
.52551 .38154 m .52606 .3816 L .52564 .38126 L F
.52585 .38163 m .52559 .38129 L .52561 .38127 L F
.52564 .38126 m .52598 .38182 L .52563 .38129 L F
.52499 .38079 m .52595 .38167 L p .52557 .38111 L F P
0 g
s
.52516 .38087 m .52551 .38138 L .52546 .38144 L .67 .731 .896 r
F
.52545 .38121 m .52494 .38074 L p .52538 .38109 L F P
0 g
s
.52347 .37938 m .52486 .38062 L p .52366 .37917 L .67 .731 .896 r
F P
0 g
s
.52494 .38074 m .52499 .38079 L p .52498 .38077 L .67 .731 .896 r
F P
0 g
s
.52494 .38074 m .52315 .37909 L p .52538 .38109 L .67 .731 .896 r
F P
0 g
s
.52366 .37917 m .5245 .38019 L .52468 .38013 L .67 .731 .896 r
F
.52538 .38109 m .52315 .37909 L .52486 .38023 L F
.52607 .38172 m .52461 .38262 L .52607 .38171 L F
.52461 .38262 m .52461 .38261 L .52607 .38171 L F
.52378 .38313 m .52378 .38313 L .52607 .38171 L F
.52571 .38154 m .52596 .38203 L .52563 .38152 L F
.52592 .38193 m .52559 .38131 L .52592 .38193 L F
.52559 .38143 m .52593 .3821 L .52556 .3815 L F
.52551 .38154 m .52579 .38207 L .52611 .3816 L F
.52528 .38209 m .52582 .38222 L .52598 .38194 L F
.52579 .38207 m .52585 .38217 L .526 .38184 L F
.5259 .38195 m .52594 .3818 L .52607 .38176 L F
.52604 .38168 m .52605 .38169 L .52611 .38165 L F
.52609 .38165 m .52604 .38168 L .52611 .38165 L F
.52579 .38207 m .526 .38184 L .52611 .3816 L F
.52586 .38208 m .5259 .38195 L .5261 .38175 L F
.5259 .38195 m .52607 .38176 L .5261 .38175 L F
.52586 .38208 m .5261 .38175 L .52614 .3818 L F
.52615 .38275 m .52629 .38198 L .52614 .38197 L F
.52595 .38215 m .52665 .3818 L p .52597 .38196 L F P
0 g
s
.52629 .38198 m .52586 .38208 L p .52614 .3818 L .67 .731 .896 r
F P
0 g
s
.52585 .38208 m .52629 .38198 L p .52605 .38169 L .67 .731 .896 r
F P
0 g
s
.52594 .3817 m .52672 .38233 L p .52596 .3817 L .67 .731 .896 r
F P
0 g
s
.52672 .38233 m .52796 .38332 L p .52673 .38233 L .67 .731 .896 r
F P
0 g
s
.52596 .3817 m .52672 .38233 L .52673 .38233 L .67 .731 .896 r
F
.52164 .38284 m .52577 .38208 L p .5216 .3826 L F P
0 g
s
.5143 .38896 m .51365 .38844 L p .52526 .38211 L .67 .731 .896 r
F P
0 g
s
.52461 .38262 m .52378 .38313 L .52461 .38261 L .67 .731 .896 r
F
.52148 .3845 m .5147 .38871 L .52281 .38392 L F
.52378 .38313 m .5143 .38896 L .52378 .38313 L F
.52522 .38219 m .515 .38853 L .52522 .38218 L F
.515 .38853 m .515 .38852 L .52522 .38218 L F
.52522 .38218 m .5143 .38896 L .52526 .38211 L F
.52519 .38226 m .52349 .3833 L .52522 .38219 L F
.52349 .3833 m .5143 .38896 L .52351 .38325 L F
.52349 .3833 m .52351 .38325 L .52522 .38219 L F
.52498 .38243 m .5143 .38896 L .52484 .38247 L F
.5159 .3898 m .5159 .3898 L .52583 .38224 L F
.5159 .3898 m .52583 .38224 L .52583 .38224 L F
.5217 .38586 m .52594 .38212 L .5217 .38587 L F
.52585 .38221 m .51499 .38855 L .52583 .38225 L F
.5143 .38896 m .51498 .38856 L p .51499 .38855 L F P
0 g
s
.51498 .38856 m .52583 .38225 L p .51499 .38855 L .67 .731 .896 r
F P
0 g
s
.5258 .38227 m .52504 .38278 L .52553 .38221 L .67 .731 .896 r
F
.52574 .38219 m .5143 .38896 L .52585 .38221 L F
.52148 .3845 m .52281 .38392 L .52574 .38219 L F
.5147 .38871 m .5143 .38896 L .51483 .38865 L F
.5147 .38871 m .51483 .38865 L .52574 .38219 L F
.52583 .38225 m .5143 .38896 L p .52545 .38214 L F P
0 g
s
.52528 .38209 m .51793 .3861 L .52503 .38262 L .67 .731 .896 r
F
.51365 .38844 m .5201 .38514 L p .51793 .3861 L F P
0 g
s
.5201 .38514 m .52503 .38262 L p .51793 .3861 L .67 .731 .896 r
F P
0 g
s
.53036 .38108 m .52806 .3816 L .53062 .38093 L .67 .731 .896 r
F
.52806 .3816 m .52673 .3819 L .52811 .38156 L F
.52806 .3816 m .52811 .38156 L .53062 .38093 L F
.52673 .38208 m .52673 .38183 L .52684 .3819 L F
.52666 .38181 m .52664 .38185 L .52724 .38242 L F
.52726 .3824 m .52724 .38242 L .53561 .39055 L F
.52666 .38181 m .52724 .38242 L .52726 .3824 L F
.54174 .37913 m .53002 .38129 L p .53211 .38069 L F P
0 g
s
.52904 .38141 m .5291 .38142 L .54198 .37979 L .67 .731 .896 r
F
.52753 .38158 m .52794 .38166 L .54174 .37913 L F
.52684 .38129 m .52685 .38124 L .52686 .38124 L F
.52668 .38175 m .52684 .38129 L .52753 .38087 L F
.52685 .38124 m .52675 .38154 L .52737 .38143 L F
.52701 .38148 m .52669 .38189 L .527 .38148 L F
.52666 .3818 m .52674 .38189 L .52674 .38189 L F
.52641 .38173 m .52648 .38175 L .52671 .38164 L F
.52648 .38175 m .52666 .38179 L .52667 .38175 L F
.52648 .38175 m .52667 .38175 L .52671 .38164 L F
.52684 .3819 m .52663 .38177 L .52661 .38175 L F
.52667 .38175 m .52661 .38175 L .52616 .38131 L F
.52684 .3819 m .52661 .38175 L .52667 .38175 L F
.52611 .3816 m .52579 .38093 L p .52564 .38126 L F P
0 g
s
.52663 .38177 m .52563 .38117 L .52616 .38131 L .67 .731 .896 r
F
.52616 .38131 m .52563 .38117 L .52612 .38128 L F
.52616 .38131 m .52666 .38181 L .52666 .3818 L F
.52666 .38181 m .52674 .38189 L .52666 .3818 L F
.52675 .38188 m .52669 .38189 L p .52701 .38148 L F P
0 g
s
.52837 .38129 m .52664 .38186 L .52827 .38131 L .67 .731 .896 r
F
.53062 .38093 m .52811 .38156 L .52837 .38129 L F
.53211 .38069 m .53036 .38108 L .53062 .38093 L F
.527 .38148 m .52687 .38169 L .5409 .37927 L F
.54078 .37928 m .5409 .37927 L .54174 .37913 L F
.527 .38148 m .5409 .37927 L .54078 .37928 L F
.52671 .38164 m .52666 .38179 L .52737 .38143 L F
.52745 .38139 m .52666 .38179 L p .52736 .38105 L F P
0 g
s
.52605 .38122 m .52658 .38178 L .52663 .38179 L .67 .731 .896 r
F
.52665 .3818 m .52666 .38179 L p .52641 .38173 L F P
0 g
s
.52608 .38125 m .52607 .38129 L .52664 .38185 L .67 .731 .896 r
F
.52627 .38173 m .52671 .38142 L .52631 .38173 L F
.52671 .38142 m .52674 .38141 L .52672 .38142 L F
.52671 .38142 m .52672 .38142 L .52631 .38173 L F
.52582 .3814 m .526 .38186 L .52564 .38126 L F
.52606 .3816 m .52611 .3816 L .52564 .38126 L F
.52636 .38178 m .52609 .38174 L .52563 .38117 L F
.52557 .38111 m .52605 .38169 L .52618 .38171 L F
.52607 .38161 m .52605 .38169 L .52582 .3814 L F
.52605 .38169 m .526 .38186 L .52582 .3814 L F
.52535 .38077 m .52557 .38111 L .52618 .38171 L F
.52557 .38111 m .52595 .38167 L .52605 .38169 L F
.52597 .38196 m .52585 .38217 L .52595 .38215 L F
.52582 .38222 m .5259 .38218 L p .52585 .38217 L F P
0 g
s
.5259 .38218 m .52595 .38215 L p .52585 .38217 L .67 .731 .896 r
F P
0 g
s
.52632 .3827 m .52601 .38213 L .52603 .38213 L .67 .731 .896 r
F
.52587 .38226 m .52623 .38267 L .52602 .38261 L F
.52588 .38224 m .52615 .38275 L .52615 .38233 L F
.52585 .38217 m .52635 .38263 L .52605 .38257 L F
.52586 .38208 m .52585 .38208 L p .52594 .3818 L F P
0 g
s
.52585 .38208 m .52247 .38287 L p .52539 .38197 L .67 .731 .896 r
F P
0 g
s
.52585 .38208 m .52539 .38197 L .52594 .3818 L .67 .731 .896 r
F
.52629 .38198 m .5259 .38217 L .52617 .38183 L F
.52579 .38207 m .52591 .38214 L .52585 .38217 L F
.52591 .38214 m .5259 .38218 L .52585 .38217 L F
.52503 .38262 m .52582 .38222 L p .52528 .38209 L F P
0 g
s
.5259 .38217 m .52503 .38262 L .52597 .38197 L .67 .731 .896 r
F
.5259 .38217 m .52597 .38197 L .52617 .38183 L F
.52591 .38214 m .52602 .38219 L .5259 .38218 L F
.52608 .38173 m .52603 .38176 L .52605 .38169 L F
.52551 .38154 m .52593 .38208 L .52579 .38207 L F
.52594 .38204 m .52593 .38207 L .52552 .38152 L F
.52538 .38197 m .52526 .38194 L .52605 .38168 L F
.52552 .38152 m .52635 .38263 L .52551 .38154 L F
.52615 .38216 m .52611 .38215 L .52575 .38158 L F
.52576 .38159 m .52575 .38158 L .52558 .38131 L F
.52598 .38192 m .52575 .38158 L .52598 .38191 L F
.5256 .38135 m .52598 .38194 L .52555 .38145 L F
.52614 .3818 m .5261 .38175 L .52623 .38171 L F
.52663 .38179 m .52664 .38185 L .52666 .38181 L F
.52622 .38189 m .52622 .3819 L .52665 .3818 L F
.52665 .38179 m .52629 .38198 L .52631 .38173 L F
.52658 .38178 m .52664 .38185 L .52663 .38179 L F
.52609 .38174 m .52615 .38182 L .52637 .38175 L F
.52598 .38193 m .52626 .38173 L .52598 .38193 L F
.52626 .38173 m .52674 .38139 L .52626 .38173 L F
.52626 .38173 m .52626 .38173 L .52598 .38193 L F
.52629 .38198 m .52627 .38199 L .52665 .38179 L F
.52665 .3818 m .52629 .38198 L p .52665 .38179 L F P
0 g
s
.52669 .38189 m .52629 .38198 L p .52663 .38187 L .67 .731 .896 r
F P
0 g
s
.52629 .38198 m .52617 .38183 L .52631 .38173 L .67 .731 .896 r
F
.52629 .38198 m .52675 .38188 L p .52605 .38169 L F P
0 g
s
.52675 .38235 m .52629 .38198 L p .52679 .38214 L .67 .731 .896 r
F P
0 g
s
.52618 .38171 m .52686 .38248 L .52637 .38174 L .67 .731 .896 r
F
.52686 .38248 m .52701 .38265 L .52691 .3825 L F
.52686 .38248 m .52691 .3825 L .52637 .38174 L F
.52606 .38168 m .52604 .38168 L .52585 .38208 L F
.526 .38178 m .52603 .38171 L .52605 .3817 L F
.52603 .38176 m .52605 .3817 L .52605 .38169 L F
.52618 .38163 m .52563 .38117 L .52632 .38159 L F
.52535 .38077 m .52618 .38171 L .52637 .38174 L F
.52598 .38193 m .52603 .38177 L .52614 .38171 L F
.526 .38122 m .52638 .38175 L .52657 .38178 L F
.52626 .38173 m .52614 .38171 L .52674 .38139 L F
.52598 .38193 m .52614 .38171 L .52626 .38173 L F
.52657 .38178 m .52641 .38179 L .52664 .38185 L F
.52638 .38175 m .52641 .38179 L .52657 .38178 L F
.52627 .38163 m .52608 .38173 L .52617 .38162 L F
.52608 .38173 m .52605 .38169 L .52617 .38162 L F
.52693 .38145 m .52606 .38168 L .52607 .38168 L F
.52598 .38193 m .52674 .38139 L .52674 .38141 L F
.52686 .38124 m .52685 .38124 L .52686 .38123 L F
.52686 .38123 m .52685 .38124 L .52737 .38143 L F
.52666 .38179 m .52631 .38173 L .52706 .38125 L F
.52687 .38169 m .52794 .38166 L .52753 .38158 L F
.54174 .37913 m .54144 .37848 L p .52909 .38104 L F P
0 g
s
.52909 .38104 m .527 .38148 L .52933 .38111 L .67 .731 .896 r
F
.52909 .38104 m .52933 .38111 L .54174 .37913 L F
.54144 .37848 m .52747 .38171 L p .527 .38148 L F P
0 g
s
.52737 .38143 m .52747 .38138 L p .52731 .38141 L .67 .731 .896 r
F P
0 g
s
.52747 .38138 m .5295 .38034 L p .52731 .38141 L .67 .731 .896 r
F P
0 g
s
.52767 .38104 m .52768 .38102 L .53018 .37936 L .67 .731 .896 r
F
.53002 .37951 m .52777 .381 L p .52983 .3796 L F P
0 g
s
.52777 .381 m .52772 .38102 L .52983 .3796 L .67 .731 .896 r
F
.53018 .37941 m .53002 .37951 L p .53018 .37936 L F P
0 g
s
.53002 .37951 m .52983 .3796 L .53018 .37936 L .67 .731 .896 r
F
.52766 .38106 m .52767 .38104 L .53018 .37936 L F
.53601 .37555 m .53018 .37941 L p .53604 .37546 L F P
0 g
s
.53018 .37941 m .53018 .37936 L .53604 .37546 L .67 .731 .896 r
F
.5275 .38128 m .53837 .37495 L p .52696 .3811 L F P
0 g
s
.53837 .37495 m .52786 .38107 L p .52753 .38087 L .67 .731 .896 r
F P
0 g
s
.52686 .38123 m .52731 .38141 L .5295 .38034 L .67 .731 .896 r
F
.52799 .38075 m .52745 .38139 L .52736 .38105 L F
.5295 .38034 m .53153 .37931 L p .52967 .38007 L F P
0 g
s
.52686 .38123 m .5295 .38034 L .52967 .38007 L .67 .731 .896 r
F
.52753 .38087 m .52684 .38129 L .52686 .38123 L F
.52964 .37972 m .52686 .38123 L .53153 .37931 L F
.53153 .37931 m .53902 .37548 L p .52964 .37972 L F P
0 g
s
.53902 .37548 m .52846 .38088 L p .52799 .38075 L .67 .731 .896 r
F P
0 g
s
.52846 .38088 m .52745 .38139 L p .52799 .38075 L .67 .731 .896 r
F P
0 g
s
.52702 .38143 m .52693 .38145 L .52775 .38155 L .67 .731 .896 r
F
.5307 .38049 m .52702 .38143 L .52839 .3815 L F
.52702 .38143 m .52775 .38155 L .52839 .3815 L F
.52915 .38089 m .52763 .38161 L .52693 .38145 L F
.52839 .3815 m .54144 .37848 L p .5307 .38049 L F P
0 g
s
.54107 .37784 m .52892 .38125 L p .52915 .38089 L .67 .731 .896 r
F P
0 g
s
.52892 .38125 m .52763 .38161 L p .52915 .38089 L .67 .731 .896 r
F P
0 g
s
.52717 .38125 m .52706 .38125 L .52736 .38105 L .67 .731 .896 r
F
.52666 .38179 m .52706 .38125 L .52717 .38125 L F
.52617 .38162 m .52605 .3817 L .52606 .38167 L F
.52574 .38104 m .52607 .38161 L p .52564 .38126 L F P
0 g
s
.52513 .38057 m .52553 .38105 L .52549 .38061 L .67 .731 .896 r
F
.52693 .38145 m .52607 .38168 L .52775 .38155 L F
.52579 .38207 m .52627 .38173 L .52631 .38173 L F
.52606 .38168 m .5266 .38261 L .526 .38186 L F
.52707 .38364 m .52645 .38267 L .52647 .38262 L F
.52606 .38224 m .53106 .39205 L .526 .38223 L F
.52632 .3827 m .53106 .39205 L .5263 .38269 L F
.52638 .38272 m .53106 .39205 L .52632 .3827 L F
.52623 .38267 m .53106 .39205 L .52602 .38261 L F
.52707 .38364 m .53106 .39205 L p .52684 .38364 L F P
0 g
s
.53106 .39205 m .52644 .38229 L p .52615 .38275 L .67 .731 .896 r
F P
0 g
s
.5266 .38261 m .52659 .38284 L .526 .38186 L .67 .731 .896 r
F
.52672 .38146 m .52674 .38141 L .52674 .38145 L F
.52674 .38145 m .52674 .38139 L .52736 .38105 L F
.52722 .38157 m .53296 .37901 L p .52675 .38134 L F P
0 g
s
.53296 .37901 m .53962 .37604 L p .53422 .37826 L .67 .731 .896 r
F P
0 g
s
.52675 .38134 m .53296 .37901 L .53422 .37826 L .67 .731 .896 r
F
.52606 .38168 m .52605 .38169 L .5269 .38162 L F
.52606 .38168 m .5269 .38162 L .5269 .38161 L F
.52693 .38145 m .52642 .38178 L .52605 .38169 L F
.52453 .38288 m .52331 .38323 L .5255 .38205 L F
.52503 .38262 m .52497 .38259 L .52631 .38173 L F
.5235 .38299 m .52364 .383 L .52593 .38214 L F
.52392 .38304 m .52438 .38283 L p .52364 .383 L F P
0 g
s
.52438 .38283 m .52593 .38214 L p .52364 .383 L .67 .731 .896 r
F P
0 g
s
.52661 .38254 m .53202 .39183 L p .52661 .38263 L .67 .731 .896 r
F P
0 g
s
.5266 .38261 m .53202 .39183 L .52659 .38284 L .67 .731 .896 r
F
.52662 .38294 m .52739 .38416 L .52662 .38302 L F
.52661 .38254 m .52661 .38263 L .52606 .38168 L F
.52662 .38294 m .52662 .38302 L .52595 .38203 L F
.52667 .38296 m .52655 .38283 L .52611 .38215 L F
.52667 .38296 m .52611 .38215 L .52615 .38216 L F
.52667 .38296 m .52739 .38416 L .52655 .38283 L F
.52605 .38257 m .52739 .38416 L .52638 .38319 L F
.52635 .38263 m .52739 .38416 L .52605 .38257 L F
.52739 .38416 m .53202 .39183 L .52638 .38319 L F
.53202 .39183 m .52644 .38224 L p .52614 .38262 L F P
0 g
s
.52801 .38463 m .53297 .39156 L .52796 .38459 L .67 .731 .896 r
F
.52633 .38292 m .52796 .38459 L .52652 .38321 L F
.52796 .38459 m .53297 .39156 L .52652 .38321 L F
.52618 .38171 m .52603 .38169 L .52682 .38247 L F
.52602 .38174 m .52682 .38247 L p .52603 .38169 L F P
0 g
s
.52613 .3817 m .52661 .38254 L p .52606 .38168 L .67 .731 .896 r
F P
0 g
s
.52602 .38219 m .52635 .38263 L .52585 .38217 L .67 .731 .896 r
F
.52601 .38213 m .52635 .38263 L .52597 .38211 L F
.52629 .38198 m .5259 .38218 L p .52627 .38199 L F P
0 g
s
.5259 .38218 m .52582 .38222 L p .5259 .38218 L .67 .731 .896 r
F P
0 g
s
.5259 .38218 m .5259 .38218 L .52627 .38199 L .67 .731 .896 r
F
.52598 .38182 m .526 .38186 L .52596 .38187 L F
.526 .38186 m .52667 .38296 L .52599 .38191 L F
.526 .38186 m .52599 .38191 L .52596 .38187 L F
.52582 .38222 m .52581 .38222 L .5259 .38217 L F
.5259 .38218 m .5259 .38217 L .52665 .38179 L F
.52582 .38222 m .5259 .38217 L .5259 .38218 L F
.52599 .38191 m .52558 .38131 L .52559 .38129 L F
.52615 .38216 m .52598 .38191 L .52599 .38191 L F
.52598 .38191 m .52558 .38131 L .52599 .38191 L F
.52607 .38177 m .52607 .3825 L .52629 .38198 L F
.52603 .38177 m .52603 .38176 L .52695 .38125 L F
.52603 .38176 m .526 .38178 L .52605 .3817 L F
.52603 .38169 m .52602 .38181 L .52606 .38179 L F
.52604 .38168 m .526 .3817 L .52602 .38172 L F
.526 .3817 m .52489 .38206 L .52602 .38172 L F
.52598 .38194 m .52595 .38203 L .52555 .38145 L F
.52602 .38172 m .52489 .38206 L .52585 .38208 L F
.526 .38178 m .5255 .38205 L .52603 .38171 L F
.52603 .38177 m .5255 .38205 L .52603 .38176 L F
.52604 .38168 m .5255 .38205 L .52534 .38202 L F
.52606 .38167 m .52605 .38168 L .52604 .38168 L F
.52605 .38168 m .5255 .38205 L .52604 .38168 L F
.52644 .38224 m .52629 .38198 L p .52614 .38262 L F P
0 g
s
.52643 .38218 m .52624 .38217 L .52623 .38215 L .67 .731 .896 r
F
.52561 .38154 m .52601 .38213 L .52553 .38151 L F
.52603 .38169 m .52518 .38198 L .52603 .38168 L F
.52518 .38198 m .52518 .38198 L .52603 .38168 L F
.52605 .3817 m .5255 .38205 L .52606 .38167 L F
.52603 .38169 m .52519 .38209 L .526 .38181 L F
.52603 .38169 m .526 .38181 L .52602 .38181 L F
.52603 .38169 m .52603 .38169 L .52602 .38181 L F
.52307 .38239 m .52585 .38202 L .52587 .382 L F
.5216 .3826 m .52306 .3824 L .52307 .38239 L F
.52306 .3824 m .52585 .38202 L .52307 .38239 L F
.52666 .38179 m .52665 .3818 L p .52665 .38179 L F P
0 g
s
.52675 .38188 m .52685 .38185 L p .52605 .38169 L .67 .731 .896 r
F P
0 g
s
.52679 .38186 m .52602 .38174 L .52609 .38174 L .67 .731 .896 r
F
.52646 .38131 m .52645 .3813 L .52655 .38119 L F
.52626 .38142 m .52624 .38147 L .53612 .37355 L F
.52734 .38232 m .52616 .38131 L .52727 .38239 L F
.52605 .38169 m .52685 .38185 L .5269 .38162 L F
.52685 .38182 m .52642 .38178 L .52693 .38145 L F
.52674 .38181 m .52609 .38174 L .52668 .38176 L F
.52679 .38186 m .52609 .38174 L .52674 .38181 L F
.52747 .38171 m .52675 .38188 L p .52701 .38148 L F P
0 g
s
.52685 .38185 m .52839 .3815 L p .5269 .38162 L .67 .731 .896 r
F P
0 g
s
.5269 .38161 m .5269 .38162 L .52839 .3815 L .67 .731 .896 r
F
.52763 .38161 m .52685 .38182 L p .52693 .38145 L F P
0 g
s
.52599 .38207 m .52629 .38198 L .52627 .38196 L .67 .731 .896 r
F
.52629 .38198 m .52594 .38208 L p .52628 .38197 L F P
0 g
s
.52618 .38171 m .52682 .38247 L .52688 .38249 L .67 .731 .896 r
F
.5268 .38245 m .52602 .38174 L p .52679 .38186 L F P
0 g
s
.52628 .38197 m .52622 .3819 L .52642 .38178 L .67 .731 .896 r
F
.52637 .38174 m .52691 .3825 L .52716 .3825 L F
.52674 .38181 m .52628 .38197 L .52642 .38178 L F
.52627 .38196 m .52661 .38184 L .52625 .38194 L F
.52629 .38198 m .52628 .38197 L .52671 .38184 L F
.52629 .38198 m .52661 .38184 L p .52627 .38196 L F P
0 g
s
.52625 .38194 m .52661 .38184 L .52655 .38182 L .67 .731 .896 r
F
.52661 .38184 m .52629 .38198 L p .52647 .38177 L F P
0 g
s
.52693 .38145 m .52605 .38169 L .52604 .38168 L .67 .731 .896 r
F
.52603 .38169 m .52609 .38174 L .52604 .38168 L F
.52609 .38174 m .52609 .38174 L .52604 .38168 L F
.52642 .38178 m .52602 .38173 L .52603 .38169 L F
.52693 .38145 m .52603 .38169 L .52604 .38168 L F
.52604 .38168 m .52611 .38176 L .52687 .38141 L F
.52687 .38141 m .52687 .38141 L .52688 .3814 L F
.52604 .38168 m .52687 .38141 L .52687 .38141 L F
.52603 .38169 m .52606 .38179 L .52609 .38174 L F
.52604 .38168 m .52605 .38169 L .52603 .38169 L F
.5216 .3826 m .5248 .38215 L .52491 .38203 L F
.52491 .38203 m .52499 .38203 L .52505 .382 L F
.5216 .3826 m .52572 .38206 L .52569 .38204 L F
.52526 .38194 m .52224 .38292 L .52504 .38188 L F
.52489 .38206 m .52381 .38225 L .52449 .3822 L F
.52604 .38168 m .525 .38195 L .52489 .38206 L F
.52501 .38192 m .5216 .3826 L .52491 .38203 L F
.525 .38195 m .52381 .38225 L .52489 .38206 L F
.52593 .38208 m .52593 .3821 L .52579 .38207 L F
.52575 .38213 m .52627 .38196 L .52625 .38194 L F
.5235 .38299 m .52581 .38213 L .52575 .38213 L F
.52601 .38213 m .52593 .38207 L .52594 .38204 L F
.52598 .38191 m .52575 .38158 L .52576 .38159 L F
.52573 .3821 m .5255 .38205 L .52603 .38177 L F
.52553 .38151 m .52601 .38213 L .52552 .38152 L F
.52598 .38182 m .52582 .3816 L .52585 .38163 L F
.52598 .38182 m .52596 .38187 L .52559 .38129 L F
.52247 .38287 m .52224 .38292 L p .52243 .38286 L F P
0 g
s
.52247 .38287 m .52243 .38286 L .52418 .38233 L .67 .731 .896 r
F
.5242 .38233 m .52418 .38233 L .52594 .3818 L F
.52247 .38287 m .52418 .38233 L .5242 .38233 L F
.52606 .38167 m .52613 .3817 L .52606 .38168 L F
.52607 .38161 m .52612 .38169 L p .52606 .38167 L F P
0 g
s
.52612 .38169 m .52613 .3817 L p .52606 .38167 L .67 .731 .896 r
F P
0 g
s
.527 .38125 m .52603 .38177 L .52695 .38125 L .67 .731 .896 r
F
.52695 .38125 m .52627 .38163 L .52617 .38162 L F
.52675 .38134 m .52606 .38167 L .52688 .3814 L F
.52606 .38167 m .52604 .38168 L .52606 .38168 L F
.52606 .38167 m .52606 .38168 L .52688 .3814 L F
.52604 .38168 m .52603 .38169 L .52688 .3814 L F
.52616 .38131 m .52614 .38131 L .52674 .38189 L F
.5261 .38136 m .52608 .38147 L .52641 .38179 L F
.52625 .38142 m .52623 .38115 L p .52619 .38141 L F P
0 g
s
.52658 .38175 m .52595 .38167 L .52614 .38123 L .67 .731 .896 r
F
.52656 .38119 m .52655 .38119 L .52675 .38098 L F
.53431 .3741 m .53218 .3762 L p .53441 .37395 L F P
0 g
s
.53218 .3762 m .53232 .37602 L .53441 .37395 L .67 .731 .896 r
F
.53441 .37395 m .53232 .37601 L .53265 .37557 L F
.53529 .37315 m .53431 .3741 L p .53441 .37395 L F P
0 g
s
.53612 .37355 m .53529 .37315 L p .52626 .38142 L .67 .731 .896 r
F P
0 g
s
.52658 .38175 m .52614 .38123 L .52614 .38123 L .67 .731 .896 r
F
.52668 .38176 m .52658 .38175 L .52614 .38123 L F
.52661 .38184 m .52665 .38182 L p .52655 .38182 L F P
0 g
s
.52679 .38186 m .52668 .38176 L .52665 .38182 L .67 .731 .896 r
F
.52665 .38182 m .52678 .38176 L p .52666 .38179 L F P
0 g
s
.52655 .38182 m .52665 .38182 L .52666 .38179 L .67 .731 .896 r
F
.52688 .3814 m .5262 .38172 L .52722 .38157 L F
.52665 .38182 m .52613 .38122 L .52664 .38182 L F
.52668 .38176 m .52613 .38122 L .52665 .38182 L F
.5266 .38145 m .52657 .38148 L .52609 .38166 L F
.52629 .38198 m .5256 .3808 L p .52553 .38105 L F P
0 g
s
.52609 .38166 m .52609 .38166 L .52604 .38168 L .67 .731 .896 r
F
.52611 .3813 m .52625 .38171 L .52656 .3818 L F
.52605 .38122 m .526 .38122 L .52607 .38129 L F
.52605 .38122 m .52607 .38129 L .52608 .38125 L F
.52616 .38131 m .52605 .38122 L .52614 .38131 L F
.526 .38122 m .52582 .38122 L .52608 .38147 L F
.526 .38122 m .52608 .38147 L .5261 .38136 L F
.52595 .38167 m .52545 .38121 L p .52614 .38123 L F P
0 g
s
.52605 .38123 m .52611 .38137 L .52611 .3813 L .67 .731 .896 r
F
.52611 .38137 m .52625 .38171 L .52611 .3813 L F
.5266 .38145 m .52609 .38166 L .52609 .38166 L F
.52613 .38122 m .52613 .38127 L .52663 .38185 L F
.52682 .38247 m .52701 .38265 L p .52688 .38249 L F P
0 g
s
.52691 .3825 m .52701 .38265 L .52709 .38257 L .67 .731 .896 r
F
.5269 .38237 m .52673 .38233 L .52773 .38314 L F
.52691 .3825 m .52709 .38257 L .52716 .3825 L F
.52674 .38189 m .52674 .38189 L .53561 .39055 L F
.5268 .38189 m .52998 .3813 L p .52675 .38187 L F P
0 g
s
.52664 .38185 m .52641 .38179 L .53561 .39055 L .67 .731 .896 r
F
.52701 .38265 m .53561 .39055 L p .52716 .3825 L F P
0 g
s
.53561 .39055 m .5268 .38245 L p .52679 .38186 L .67 .731 .896 r
F P
0 g
s
.52667 .38186 m .52663 .38185 L .52744 .38278 L .67 .731 .896 r
F
.52613 .38122 m .52663 .38185 L .52667 .38186 L F
.5309 .37993 m .52678 .38176 L p .53015 .37997 L F P
0 g
s
.52678 .38176 m .52722 .38157 L p .52672 .38176 L .67 .731 .896 r
F P
0 g
s
.52678 .38176 m .52678 .38175 L .53015 .37997 L .67 .731 .896 r
F
.52655 .38182 m .52678 .38176 L .52672 .38176 L F
.5262 .38172 m .52655 .38182 L .52722 .38157 L F
.52661 .38184 m .5266 .38162 L .52756 .38118 L F
.52792 .38115 m .52756 .38118 L .53015 .37997 L F
.52661 .38184 m .52756 .38118 L .52792 .38115 L F
.53216 .37981 m .52714 .38135 L .52915 .38114 L F
.52603 .38168 m .52518 .38198 L .525 .38195 L F
.52547 .38158 m .52583 .38214 L .5259 .3816 L F
.52579 .38208 m .52586 .38209 L .52583 .38214 L F
.52581 .38213 m .52584 .38212 L .52575 .38213 L F
.52584 .38212 m .52586 .38209 L .52575 .38213 L F
.52593 .38208 m .52595 .38211 L .52593 .3821 L F
.52595 .38211 m .52602 .38219 L .52579 .38207 L F
.52601 .38213 m .52597 .38211 L .52593 .38207 L F
.52583 .38214 m .52607 .3825 L .52596 .38194 L F
.52598 .38194 m .52662 .38294 L .52595 .38203 L F
.52615 .38216 m .52598 .38192 L .52598 .38191 L F
.52596 .38194 m .52607 .3825 L .52607 .38177 L F
.52584 .38212 m .52627 .38196 L .52586 .38209 L F
.52593 .38214 m .52598 .38212 L p .52591 .38214 L F P
0 g
s
.52453 .38288 m .5255 .38205 L .52573 .3821 L .67 .731 .896 r
F
.5235 .38299 m .52598 .38212 L .52599 .38207 L F
.52598 .38212 m .52593 .38214 L p .52593 .3821 L F P
0 g
s
.52628 .38197 m .52594 .38208 L .52622 .3819 L .67 .731 .896 r
F
.52607 .38177 m .52629 .38198 L .52609 .38174 L F
.52609 .38174 m .52606 .38179 L .52611 .38176 L F
.52609 .38174 m .52611 .38176 L .52609 .38174 L F
.52602 .38174 m .52602 .38173 L p .52609 .38174 L F P
0 g
s
.52629 .38176 m .52619 .38186 L .52609 .38174 L .67 .731 .896 r
F
.52642 .38178 m .52639 .3818 L .52629 .38176 L F
.5262 .38172 m .52611 .38176 L .52655 .38182 L F
.52573 .3821 m .52603 .38177 L .52598 .38193 L F
.52579 .38206 m .52627 .38173 L .52579 .38207 L F
.52573 .3821 m .52598 .38193 L .52598 .38193 L F
.52611 .38176 m .52539 .3821 L .52625 .38194 L F
.52583 .38214 m .52596 .38194 L .52595 .38189 L F
.52599 .38186 m .52549 .38203 L .52603 .38169 L F
.52585 .38202 m .52595 .38189 L .5259 .3816 L F
.52607 .38177 m .52596 .38194 L .52607 .38177 L F
.52595 .38189 m .52596 .38194 L .52607 .38177 L F
.52609 .38174 m .52594 .38208 L .52599 .38186 L F
.52609 .38174 m .52599 .38186 L .52602 .38173 L F
.5259 .3816 m .52595 .38189 L .52607 .38177 L F
.52519 .38209 m .52539 .3821 L .52602 .38181 L F
.52549 .38203 m .52525 .38199 L .52603 .38169 L F
.52595 .38167 m .52602 .38174 L p .52603 .38169 L F P
0 g
s
.52602 .38173 m .52595 .38167 L p .52609 .38174 L .67 .731 .896 r
F P
0 g
s
.52604 .38168 m .526 .3817 L .52621 .38188 L .67 .731 .896 r
F
.52597 .38181 m .52595 .38185 L .52574 .3816 L F
.5248 .38216 m .52479 .38217 L .52515 .38214 L F
.5248 .38216 m .52515 .38214 L .52585 .38208 L F
.52489 .38206 m .5248 .38216 L .52585 .38208 L F
.52538 .38197 m .52224 .38292 L .52526 .38194 L F
.52504 .38188 m .52328 .38225 L .52501 .38192 L F
.52328 .38225 m .52325 .38227 L .52607 .38171 L F
.52504 .38188 m .52224 .38292 L .52421 .38206 L F
.52371 .38258 m .52585 .38208 L p .52381 .38225 L F P
0 g
s
.52549 .38203 m .52257 .38303 L .52525 .38199 L .67 .731 .896 r
F
.52649 .38254 m .52639 .38253 L .52608 .38212 L F
.52573 .3821 m .52579 .38206 L .52579 .38207 L F
.52539 .3821 m .52575 .38213 L .52625 .38194 L F
.52619 .38186 m .52594 .38208 L .52609 .38174 L F
.5259 .38205 m .52628 .38197 L .52593 .38195 L F
.52628 .38197 m .52626 .38194 L .52593 .38195 L F
.52594 .38208 m .52663 .38189 L p .5259 .38205 L F P
0 g
s
.52583 .38214 m .52595 .38189 L .52585 .38202 L .67 .731 .896 r
F
.52594 .38208 m .52589 .38209 L p .52599 .38186 L F P
0 g
s
.52589 .38209 m .52574 .38214 L p .52579 .38208 L .67 .731 .896 r
F P
0 g
s
.52589 .38209 m .52579 .38208 L .52599 .38186 L .67 .731 .896 r
F
.5259 .38206 m .52594 .38208 L .5259 .38205 L F
.52593 .38195 m .52595 .38198 L .5259 .38209 L F
.52589 .38209 m .5259 .38209 L .52588 .38214 L F
.52593 .38195 m .5259 .38209 L .52589 .38209 L F
.52593 .38195 m .52588 .38214 L .52583 .38214 L F
.52588 .38206 m .5259 .38206 L .5259 .38205 L F
.52598 .38212 m .52622 .3819 L .52623 .38191 L F
.52629 .38198 m .52605 .38206 L .52623 .38191 L F
.52643 .38218 m .52623 .38215 L .52597 .38179 L F
.52555 .38145 m .52561 .38154 L .52553 .38151 L F
.52551 .38138 m .52555 .38145 L .52546 .38144 L F
.52555 .38145 m .52552 .38152 L .52546 .38144 L F
.52546 .38144 m .52552 .38152 L .52551 .38154 L F
.52582 .3816 m .52559 .38129 L .52585 .38163 L F
.5256 .38135 m .52555 .38145 L .52516 .38087 L F
.5248 .38053 m .52547 .38158 L .5259 .3816 L F
.52599 .3817 m .52597 .38179 L .52561 .38128 L F
.526 .3817 m .52593 .38195 L .52621 .38188 L F
.52639 .3818 m .52594 .38208 L .52629 .38176 L F
.52593 .38195 m .52626 .38194 L .52621 .38188 L F
.52593 .3821 m .52597 .38191 L .52634 .38174 L F
.52641 .38176 m .52634 .38174 L .5266 .38162 L F
.52611 .38176 m .52625 .38194 L .52655 .38182 L F
.52593 .3821 m .52634 .38174 L .52641 .38176 L F
.52629 .38198 m .52623 .38191 L .5266 .38162 L F
.52628 .38197 m .5264 .38194 L .52626 .38194 L F
.52626 .38194 m .5264 .38194 L .52621 .38188 L F
.52608 .38166 m .52647 .38217 L .5265 .38211 L F
.52567 .38122 m .52602 .38164 L .52608 .38166 L F
.52604 .38168 m .52603 .38168 L .52603 .38168 L F
.52603 .38168 m .52603 .38169 L .52603 .38168 L F
.52603 .38168 m .52603 .38169 L .52603 .38168 L F
.52609 .38174 m .52595 .38167 L .52668 .38176 L F
.52609 .38166 m .52616 .38182 L .52604 .38168 L F
.5261 .38155 m .52621 .3817 L .52625 .38171 L F
.52657 .38148 m .52628 .38172 L .52609 .38166 L F
.52628 .38172 m .52616 .38182 L .52609 .38166 L F
.52669 .38187 m .52629 .38198 L p .52671 .38184 L F P
0 g
s
.52678 .38176 m .52661 .38184 L p .52678 .38175 L .67 .731 .896 r
F P
0 g
s
.52664 .38177 m .52663 .38185 L .52835 .38139 L .67 .731 .896 r
F
.52663 .38189 m .52669 .38187 L p .52663 .38185 L F P
0 g
s
.52685 .38182 m .52669 .38187 L p .52678 .38182 L .67 .731 .896 r
F P
0 g
s
.52669 .38187 m .52671 .38184 L .52678 .38182 L .67 .731 .896 r
F
.52676 .38181 m .52672 .38183 L .52674 .38181 L F
.52678 .38182 m .52672 .38183 L .52676 .38181 L F
.52678 .38182 m .52671 .38184 L .52672 .38183 L F
.52671 .38184 m .52671 .38184 L .52678 .38182 L F
.52669 .38187 m .53045 .38082 L p .52663 .38185 L F P
0 g
s
.52663 .38185 m .52666 .38191 L .52667 .38189 L .67 .731 .896 r
F
.5266 .38181 m .52662 .38185 L .52663 .38185 L F
.52662 .38185 m .52666 .38191 L .52663 .38185 L F
.52579 .38088 m .52657 .3818 L .5266 .38181 L F
.52661 .38184 m .52647 .38177 L .52661 .38181 L F
.52657 .3818 m .5266 .38184 L .5266 .38181 L F
.52671 .38184 m .52628 .38197 L .52674 .38181 L F
.52629 .38198 m .52671 .38184 L .52671 .38184 L F
.5264 .38194 m .52663 .38189 L .52663 .38185 L F
.52656 .3818 m .52625 .38171 L .52626 .38173 L F
.5264 .38194 m .52663 .38185 L .52656 .38183 L F
.52623 .38191 m .52622 .3819 L .5266 .38162 L F
.52621 .38188 m .5264 .38194 L .52664 .38177 L F
.52656 .38183 m .52626 .38173 L .52656 .38205 L F
.52656 .3818 m .52626 .38173 L .52656 .38183 L F
.5266 .38184 m .52666 .38191 L .52662 .38185 L F
.5266 .38184 m .52662 .38185 L .5266 .38181 L F
.52656 .38183 m .52663 .38185 L .52664 .38177 L F
.52663 .38185 m .52663 .38185 L .52656 .38183 L F
.52609 .38166 m .52604 .38168 L .52609 .38167 L F
.52609 .38167 m .52604 .38168 L .5261 .38167 L F
.52602 .38164 m .52609 .38172 L .52608 .38166 L F
.52634 .38174 m .52616 .38182 L .52628 .38172 L F
.52604 .38168 m .52621 .38188 L .52651 .38181 L F
.52661 .38181 m .52647 .38177 L .5266 .38162 L F
.5266 .38162 m .52634 .38174 L .5266 .38145 L F
.52634 .38174 m .52628 .38172 L .5266 .38145 L F
.5261 .38167 m .52651 .38181 L .52915 .38114 L F
.52604 .38168 m .52651 .38181 L .5261 .38167 L F
.52598 .38212 m .52593 .3821 L .52622 .3819 L F
.52598 .38212 m .52629 .38198 L p .52599 .38207 L F P
0 g
s
.52629 .38198 m .52598 .38212 L .52605 .38206 L .67 .731 .896 r
F
.52617 .38214 m .52608 .38212 L .52596 .38197 L F
.52288 .38277 m .52371 .38258 L p .52374 .38247 L F P
0 g
s
.52381 .38225 m .52288 .38277 L .52374 .38247 L .67 .731 .896 r
F
.5216 .3826 m .51177 .38464 L .52164 .38284 L F
.51255 .38452 m .52164 .38284 L p .51177 .38464 L F P
0 g
s
.52328 .38225 m .5216 .3826 L .52325 .38227 L .67 .731 .896 r
F
.52421 .38206 m .52006 .38342 L .5216 .3826 L F
.52224 .38292 m .52006 .38342 L p .52421 .38206 L F P
0 g
s
.52006 .38342 m .5112 .38547 L p .5216 .3826 L .67 .731 .896 r
F P
0 g
s
.5112 .38547 m .52288 .38277 L p .52381 .38225 L .67 .731 .896 r
F P
0 g
s
.52609 .38167 m .52605 .38169 L .52604 .38168 L .67 .731 .896 r
F
.52607 .38177 m .52609 .38174 L .52553 .38105 L F
.52529 .38076 m .52499 .38079 L .52535 .38077 L F
.52545 .38121 m .52486 .38023 L .52554 .38106 L F
.52552 .38106 m .52553 .38105 L .52513 .38057 L F
.52607 .38177 m .52553 .38105 L .52552 .38106 L F
.52525 .38199 m .52518 .38198 L .52603 .38169 L F
.52257 .38303 m .52518 .38198 L .52525 .38199 L F
.52597 .38189 m .52596 .38197 L .52452 .38008 L F
.52579 .38208 m .52549 .38203 L .52599 .38186 L F
.52518 .38198 m .52028 .38367 L .52518 .38198 L F
.5248 .38053 m .52607 .38177 L .52513 .38057 L F
.52558 .38081 m .52582 .38122 L .526 .38122 L F
.52605 .38122 m .52558 .38081 L .526 .38122 L F
.52614 .38123 m .52545 .38121 L .5257 .38079 L F
.52532 .38088 m .52587 .38165 L .52532 .38089 L F
.52612 .38127 m .52611 .3813 L .52666 .38191 L F
.52761 .38268 m .52679 .38186 L .52744 .38278 L F
.52647 .38217 m .53476 .39092 L p .5265 .38211 L F P
0 g
s
.52656 .38205 m .52651 .38212 L .53476 .39092 L .67 .731 .896 r
F
.52666 .38191 m .52656 .38205 L .53476 .39092 L F
.52675 .38187 m .52998 .3813 L .52992 .38129 L F
.52734 .38232 m .52727 .38239 L .53561 .39055 L F
.52761 .38268 m .52744 .38278 L .53476 .39092 L F
.52714 .38135 m .52609 .38167 L .52783 .38137 L F
.52714 .38135 m .52783 .38137 L .52915 .38114 L F
.51954 .3723 m .51862 .37261 L p .52372 .37884 L F P
0 g
s
.53291 .37958 m .53216 .37981 L .53045 .38082 L .67 .731 .896 r
F
.53216 .37981 m .52915 .38114 L .53045 .38082 L F
.54107 .37784 m .54065 .37722 L p .53291 .37958 L F P
0 g
s
.53045 .38082 m .54107 .37784 L p .53291 .37958 L .67 .731 .896 r
F P
0 g
s
.54065 .37722 m .52704 .38144 L .52714 .38135 L .67 .731 .896 r
F
.53015 .37997 m .52858 .3807 L .5266 .38145 L F
.52858 .3807 m .5266 .38162 L .5266 .38147 L F
.52858 .3807 m .5266 .38147 L .5266 .38145 L F
.52704 .38144 m .52609 .38173 L .52714 .38135 L F
.52587 .38165 m .52801 .38463 L .52586 .38165 L F
.52801 .38463 m .52598 .38182 L .52598 .38182 L F
.52608 .38212 m .5261 .38216 L .52607 .38212 L F
.52649 .38254 m .52608 .38212 L .52617 .38214 L F
.52621 .38214 m .52622 .38217 L .5262 .38214 L F
.52622 .38217 m .52649 .38254 L .52619 .38216 L F
.52595 .38198 m .5261 .38216 L .52593 .38214 L F
.52595 .38198 m .52593 .38214 L .52588 .38214 L F
.52649 .38254 m .52796 .38459 L .52639 .38253 L F
.52801 .38463 m .52796 .38459 L .52622 .38217 L F
.52801 .38463 m .52622 .38217 L .52623 .38217 L F
.52574 .38214 m .52549 .38203 L .52579 .38208 L F
.52534 .38202 m .52331 .38323 L .522 .38361 L F
.52165 .38303 m .5259 .38205 L .52593 .38195 L F
.52643 .38218 m .52623 .38215 L .52643 .38218 L F
.52643 .38218 m .53297 .39156 L p .52624 .38217 L F P
0 g
s
.52519 .38209 m .52174 .38374 L .52539 .3821 L .67 .731 .896 r
F
.52574 .38214 m .52257 .38303 L p .52549 .38203 L F P
0 g
s
.5235 .38299 m .52593 .38214 L .52591 .38214 L .67 .731 .896 r
F
.52489 .38206 m .52449 .3822 L .52479 .38217 L F
.52257 .38303 m .52028 .38367 L p .52518 .38198 L F P
0 g
s
.5255 .38205 m .52331 .38323 L .52534 .38202 L .67 .731 .896 r
F
.52118 .38341 m .52594 .38208 L p .52165 .38303 L F P
0 g
s
.52165 .38303 m .52594 .38208 L .52588 .38206 L .67 .731 .896 r
F
.52453 .38288 m .51365 .38844 L p .52331 .38323 L F P
0 g
s
.52331 .38323 m .51365 .38844 L .522 .38361 L .67 .731 .896 r
F
.51305 .38789 m .52392 .38304 L p .5235 .38299 L F P
0 g
s
.52593 .3821 m .51305 .38789 L .52573 .38202 L .67 .731 .896 r
F
.52593 .38214 m .51305 .38789 L p .52593 .3821 L F P
0 g
s
.52607 .3825 m .52614 .38262 L .52619 .38241 L .67 .731 .896 r
F
.52591 .38226 m .5267 .38294 L .52633 .38292 L F
.52583 .38214 m .52591 .38221 L .52591 .38226 L F
.52591 .38221 m .5267 .38294 L .52591 .38226 L F
.52607 .3825 m .52619 .38241 L .52629 .38198 L F
.5261 .38216 m .5267 .38294 L .52583 .38214 L F
.52585 .38164 m .5256 .38129 L .5256 .38129 L F
.52801 .38463 m .52585 .38164 L .52585 .38164 L F
.52585 .38164 m .5256 .38129 L .52585 .38164 L F
.52604 .38168 m .52599 .38174 L .526 .3817 L F
.526 .3817 m .526 .3817 L .52609 .38167 L F
.52605 .38169 m .52601 .3817 L .52604 .38168 L F
.52604 .38168 m .526 .3817 L .52605 .38168 L F
.52601 .3817 m .526 .3817 L .52604 .38168 L F
.52608 .38173 m .52605 .38169 L .52609 .38167 L F
.52609 .38167 m .52605 .38169 L .52609 .38171 L F
.52616 .38182 m .52597 .38191 L .52604 .38168 L F
.52597 .38181 m .52598 .38183 L .52595 .38185 L F
.52598 .38183 m .52597 .38187 L .52595 .38185 L F
.52543 .38148 m .52593 .38195 L .52586 .38209 L F
.52511 .38101 m .52556 .38153 L .52543 .38148 L F
.52556 .38153 m .52593 .38195 L .52543 .38148 L F
.52605 .38172 m .52609 .38173 L .52607 .38171 L F
.52608 .38173 m .52609 .38173 L .52608 .38173 L F
.52609 .38173 m .52609 .38173 L .52608 .38173 L F
.52607 .38171 m .52609 .38173 L .52609 .38171 L F
.52608 .38173 m .52608 .38173 L .52605 .38169 L F
.526 .3817 m .52474 .38212 L .52586 .38196 L F
.52597 .38191 m .52599 .38174 L .52604 .38168 L F
.52643 .38218 m .52597 .38179 L .52599 .3817 L F
.52599 .38171 m .52598 .38175 L .52605 .38172 L F
.52643 .38218 m .52599 .3817 L .52609 .38174 L F
.52599 .38171 m .52605 .38172 L .52602 .38171 L F
.526 .3817 m .52573 .38202 L .52548 .38192 L F
.526 .3817 m .52527 .382 L .526 .3817 L F
.52599 .38171 m .52527 .382 L .52598 .38175 L F
.52608 .38173 m .52524 .38199 L .52601 .3817 L F
.52605 .38169 m .52599 .38171 L .52607 .38171 L F
.52602 .38171 m .52605 .38172 L .52609 .38171 L F
.52608 .38173 m .52601 .3817 L .52605 .38169 L F
.52594 .38192 m .52586 .38196 L .52593 .38195 L F
.526 .3817 m .52586 .38196 L .52594 .38192 L F
.52566 .38157 m .52608 .38212 L .52557 .38154 L F
.52597 .38191 m .52573 .38202 L .52599 .38174 L F
.52598 .38183 m .52621 .38214 L .52597 .38187 L F
.52605 .38169 m .52607 .38171 L .52609 .38171 L F
.52609 .38173 m .52608 .38173 L .52609 .38167 L F
.52607 .38171 m .52561 .38128 L .52567 .38122 L F
.52556 .38122 m .52629 .38198 L p .52567 .38122 L F P
0 g
s
.52629 .38198 m .52647 .38217 L p .52567 .38122 L .67 .731 .896 r
F P
0 g
s
.52609 .38174 m .52607 .38171 L .52569 .38119 L .67 .731 .896 r
F
.52607 .38171 m .52567 .38122 L .52569 .38119 L F
.52599 .3817 m .52561 .38128 L .52609 .38174 L F
.52629 .38198 m .52608 .38176 L p .52611 .38176 L F P
0 g
s
.52617 .38214 m .52596 .38197 L .52597 .38189 L .67 .731 .896 r
F
.52621 .38214 m .5262 .38214 L .52574 .3816 L F
.52582 .38205 m .52608 .38179 L .52609 .38173 L F
.52474 .38212 m .5245 .38231 L .52593 .38195 L F
.52593 .3821 m .52573 .38202 L .52597 .38191 L F
.52577 .38206 m .52581 .38205 L .52611 .38176 L F
.52622 .38217 m .52619 .38216 L .52573 .38159 L F
.52623 .38217 m .52622 .38217 L .5256 .38129 L F
.52581 .38205 m .52629 .38198 L .52611 .38176 L F
.52599 .38174 m .52573 .38202 L .526 .3817 L F
.52511 .38101 m .52586 .38209 L .52579 .38208 L F
.52527 .382 m .52582 .38205 L .52609 .38173 L F
.5267 .38294 m .52796 .38459 L .52633 .38292 L F
.52366 .38544 m .52368 .38538 L .52592 .3822 L F
.53297 .39156 m .52629 .38198 L p .52577 .38206 L F P
0 g
s
.52609 .38173 m .52606 .38207 L .52629 .38198 L .67 .731 .896 r
F
.52608 .38176 m .52608 .38176 L p .52611 .38176 L F P
0 g
s
.52315 .37909 m .52352 .37895 L .52446 .37974 L .67 .731 .896 r
F
.52549 .38061 m .52512 .37997 L p .52492 .38031 L F P
0 g
s
.52486 .38023 m .52446 .37974 L .5257 .38079 L .67 .731 .896 r
F
.52315 .37909 m .52446 .37974 L .52486 .38023 L F
.5248 .38053 m .52513 .38057 L .52492 .38031 L F
.52513 .38057 m .52549 .38061 L .52492 .38031 L F
.52374 .37886 m .5248 .38053 L .52393 .3788 L F
.52374 .37886 m .52393 .3788 L .52049 .37203 L F
.52598 .38182 m .52315 .37788 L .52315 .37788 L F
.52598 .38182 m .5247 .38004 L .52598 .38182 L F
.52536 .38045 m .52374 .37886 L .52506 .38043 L F
.5247 .38004 m .52315 .37788 L .52471 .38005 L F
.5247 .38004 m .52471 .38005 L .52598 .38182 L F
.5248 .38053 m .52492 .38031 L .52432 .37957 L F
.52462 .37993 m .52584 .38164 L .52452 .38008 L F
.51688 .37334 m .51773 .37295 L p .52374 .37886 L F P
0 g
s
.52352 .37895 m .51688 .37334 L .52374 .37886 L .67 .731 .896 r
F
.52531 .38087 m .52532 .38088 L .5253 .38087 L F
.52532 .38088 m .52532 .38089 L .5253 .38087 L F
.52282 .378 m .52555 .3812 L .52567 .38122 L F
.5256 .3808 m .52559 .38079 L p .52553 .38105 L F P
0 g
s
.52559 .38079 m .52549 .38061 L p .52553 .38105 L .67 .731 .896 r
F P
0 g
s
.52554 .38106 m .52486 .38023 L .5257 .38079 L .67 .731 .896 r
F
.52467 .38 m .52567 .38122 L .52582 .38124 L F
.5256 .38129 m .5256 .38129 L .52315 .37788 L F
.52531 .38087 m .5253 .38087 L .52383 .37883 L F
.52281 .37741 m .52462 .37993 L .52462 .37994 L F
.52374 .37886 m .52462 .37994 L .52452 .38008 L F
.52374 .37886 m .52467 .38 L .52506 .38043 L F
.52281 .37741 m .52462 .37994 L .52374 .37886 L F
.52374 .37886 m .52365 .37889 L .52467 .38 L F
.52282 .378 m .52567 .38122 L .52467 .38 L F
.52569 .38119 m .52561 .38128 L .52257 .37703 L F
.52555 .3812 m .52556 .38122 L p .52567 .38122 L F P
0 g
s
.52278 .37828 m .52555 .3812 L p .52282 .378 L .67 .731 .896 r
F P
0 g
s
.51688 .37334 m .52346 .37939 L p .52366 .37917 L .67 .731 .896 r
F P
0 g
s
.52315 .37909 m .51688 .37334 L p .52352 .37895 L .67 .731 .896 r
F P
0 g
s
.52239 .37787 m .52278 .37828 L p .52241 .37755 L .67 .731 .896 r
F P
0 g
s
.52241 .37755 m .52278 .37828 L .52282 .378 L .67 .731 .896 r
F
.52374 .37886 m .52241 .37755 L .52365 .37889 L F
.51773 .37295 m .52239 .37787 L p .52241 .37755 L F P
0 g
s
.52608 .38176 m .51773 .37295 L p .52372 .37884 L .67 .731 .896 r
F P
0 g
s
.52608 .38176 m .52372 .37884 L .52611 .38176 L .67 .731 .896 r
F
.52587 .38165 m .52587 .38165 L .52585 .38164 L F
.52587 .38165 m .52586 .38165 L .52585 .38164 L F
.52587 .38165 m .52585 .38164 L .52532 .38089 L F
.52601 .3817 m .52524 .38199 L .526 .3817 L F
.52518 .38095 m .52566 .38157 L .52511 .38101 L F
.52566 .38157 m .52557 .38154 L .52511 .38101 L F
.52608 .38212 m .52607 .38212 L .52511 .38101 L F
.52609 .38173 m .52559 .38206 L .52608 .38173 L F
.52539 .3821 m .5235 .38299 L .52575 .38213 L F
.52516 .38242 m .52606 .38207 L p .52527 .382 L F P
0 g
s
.52559 .38206 m .52513 .38237 L .52559 .38206 L .67 .731 .896 r
F
.52559 .38206 m .52559 .38206 L .52608 .38173 L F
.525 .38195 m .52028 .38367 L .52239 .38261 L F
.52518 .38198 m .52028 .38367 L .525 .38195 L F
.526 .3817 m .52165 .38303 L .52307 .38267 L F
.526 .3817 m .52307 .38267 L .526 .3817 L F
.52585 .38164 m .52597 .38181 L .52574 .3816 L F
.52527 .382 m .52609 .38173 L .52605 .38172 L F
.52584 .38164 m .52585 .38164 L .52573 .38159 L F
.52585 .38164 m .52574 .3816 L .52573 .38159 L F
.52584 .38164 m .52573 .38159 L .52452 .38008 L F
.52452 .38008 m .52518 .38095 L .52511 .38101 L F
.52577 .38206 m .52611 .38176 L .52372 .37884 L F
.52701 .3814 m .52687 .38154 L .54016 .37662 L F
.52613 .38175 m .52629 .38198 L p .52609 .38174 L F P
0 g
s
.52629 .38198 m .52614 .38176 L p .52611 .38176 L .67 .731 .896 r
F P
0 g
s
.52609 .38172 m .52647 .38217 L .52609 .38168 L .67 .731 .896 r
F
.52614 .38176 m .52613 .38175 L p .52611 .38176 L F P
0 g
s
.52611 .38176 m .52611 .38176 L .52613 .38175 L .67 .731 .896 r
F
.52629 .38198 m .52611 .38176 L .52616 .38176 L F
.52621 .3817 m .52651 .38212 L .52625 .38171 L F
.5261 .3816 m .52609 .38167 L .52651 .38212 L F
.52629 .38198 m .52616 .38176 L .52669 .38176 L F
.52629 .38198 m .52643 .38218 L p .52633 .38204 L F P
0 g
s
.52629 .38198 m .52633 .38204 L .52609 .38174 L .67 .731 .896 r
F
.52625 .38171 m .52651 .38212 L .52656 .38205 L F
.52608 .38176 m .52611 .38176 L .52669 .38176 L F
.5261 .3816 m .52651 .38212 L .5261 .38155 L F
.52704 .38144 m .52645 .38188 L .52609 .38173 L F
.52667 .38189 m .52666 .38191 L .52744 .38278 L F
.52679 .38186 m .52664 .38182 L .52744 .38278 L F
.52656 .3818 m .52656 .38205 L .52666 .38191 L F
.53476 .39092 m .52629 .38198 L p .52669 .38176 L F P
0 g
s
.52627 .38196 m .52626 .38195 L .52645 .38188 L .67 .731 .896 r
F
.52605 .38206 m .52645 .38188 L .5265 .38189 L F
.52605 .38207 m .52606 .38207 L .52608 .38179 L F
.52645 .38188 m .52606 .38202 L .52609 .38173 L F
.52652 .3819 m .52605 .38206 L p .5265 .38189 L F P
0 g
s
.52629 .38198 m .52652 .38189 L p .52609 .38173 L .67 .731 .896 r
F P
0 g
s
.52606 .38206 m .52606 .38202 L .52626 .38195 L .67 .731 .896 r
F
.52582 .38205 m .52605 .38207 L .52608 .38179 L F
.52615 .38206 m .52616 .38206 L .52577 .38206 L F
.52605 .38206 m .52605 .38206 L .52606 .38206 L F
.52605 .38206 m .52606 .38202 L .52606 .38206 L F
.52635 .38206 m .52616 .38206 L .52615 .38206 L F
.52605 .38206 m .52626 .38195 L .52627 .38196 L F
.52606 .38206 m .52652 .38191 L p .52582 .38176 L F P
0 g
s
.52607 .38207 m .52629 .38198 L p .52606 .38207 L .67 .731 .896 r
F P
0 g
s
.52667 .3818 m .52666 .3818 L .52982 .38594 L .67 .731 .896 r
F
.52667 .3818 m .52982 .38594 L .52987 .386 L F
.52665 .38178 m .52666 .3818 L .52667 .3818 L F
.52665 .38178 m .52665 .38179 L .52666 .3818 L F
.52671 .38178 m .52669 .38176 L .52671 .38178 L F
.52613 .38175 m .52616 .38176 L .52618 .3817 L F
.52616 .38176 m .52627 .38176 L .52618 .3817 L F
.52609 .38173 m .52613 .38175 L .52618 .3817 L F
.52629 .38161 m .52609 .38173 L .52609 .38167 L F
.52619 .38169 m .52609 .38173 L .52629 .38161 L F
.52604 .38168 m .52605 .38168 L .52609 .38167 L F
.52609 .38172 m .52609 .38168 L .52608 .38167 L F
.52609 .38172 m .52608 .38167 L .52608 .38166 L F
.52577 .38206 m .52606 .38206 L .52579 .38208 L F
.52606 .38202 m .52513 .38237 L .52609 .38173 L F
.52627 .3816 m .52607 .38207 L .52582 .38176 L F
.52671 .38178 m .52671 .38178 L .53026 .38647 L F
.52671 .38178 m .53026 .38647 L .53028 .3865 L F
.53388 .39126 m .53476 .39092 L p .52671 .38178 L F P
0 g
s
.52669 .38176 m .52668 .38176 L .53388 .39126 L .67 .731 .896 r
F
.52662 .38182 m .52645 .38188 L .52704 .38144 L F
.52667 .38174 m .52664 .38177 L .52665 .38178 L F
.52668 .38176 m .52665 .38178 L .53388 .39126 L F
.52667 .38174 m .52665 .38178 L .52668 .38176 L F
.5265 .38189 m .52645 .38188 L .52662 .38182 L F
.5265 .38189 m .52662 .38182 L .52656 .38187 L F
.52652 .3819 m .5265 .38189 L .52656 .38187 L F
.52635 .38206 m .53388 .39126 L p .52664 .38177 L F P
0 g
s
.52656 .38187 m .52662 .38182 L .53083 .38026 L .67 .731 .896 r
F
.52609 .38167 m .5261 .38167 L .52915 .38114 L F
.53083 .38026 m .52662 .38182 L .52704 .38144 L F
.52618 .3817 m .52627 .38176 L .52687 .38154 L F
.53083 .38026 m .52609 .38173 L .52609 .38173 L F
.52695 .38173 m .54016 .37662 L p .52627 .38176 L F P
0 g
s
.52714 .38135 m .52619 .38169 L .52629 .38161 L .67 .731 .896 r
F
.52609 .38166 m .52609 .38171 L .52704 .38136 L F
.5271 .3813 m .52704 .38136 L .54016 .37662 L F
.52609 .38166 m .52704 .38136 L .5271 .3813 L F
.52582 .38124 m .52567 .38122 L .52609 .38167 L F
.52613 .38175 m .52609 .38174 L .52257 .37703 L F
.52531 .38087 m .52383 .37883 L .52384 .37883 L F
.52385 .37882 m .52531 .38087 L .52384 .37883 L F
.52372 .37884 m .52613 .38175 L .52493 .38003 L F
.52378 .37768 m .52465 .37917 L p .52346 .37765 L F P
0 g
s
.52465 .37917 m .52454 .37943 L .52346 .37765 L .67 .731 .896 r
F
.52049 .37203 m .52378 .37768 L p .52346 .37765 L F P
0 g
s
.52512 .37997 m .52049 .37203 L p .52385 .37864 L .67 .731 .896 r
F P
0 g
s
.51954 .3723 m .52294 .37717 L p .52257 .37703 L .67 .731 .896 r
F P
0 g
s
.52405 .37876 m .51954 .3723 L p .52268 .37721 L .67 .731 .896 r
F P
0 g
s
.52662 .38174 m .52647 .38154 L .52667 .38174 L .67 .731 .896 r
F
.52649 .38157 m .5265 .38158 L .52701 .3814 L F
.52609 .38171 m .5265 .38158 L .52649 .38157 L F
.52605 .38123 m .5258 .38122 L .52625 .38171 L F
.52609 .38171 m .52609 .38173 L .5265 .38158 L F
.52611 .38176 m .52647 .38154 L .52662 .38174 L F
.52611 .38176 m .52613 .38175 L .52372 .37884 L F
.52608 .38166 m .52608 .38167 L .52608 .38166 L F
.52579 .38088 m .52573 .38088 L .52611 .3813 L F
.52579 .38088 m .52611 .3813 L .52612 .38127 L F
.53962 .37604 m .5309 .37993 L p .53015 .37997 L F P
0 g
s
.54016 .37662 m .53962 .37604 L p .52609 .38166 L .67 .731 .896 r
F P
0 g
s
.52613 .38122 m .52579 .38088 L .52613 .38127 L .67 .731 .896 r
F
.52582 .38124 m .5261 .3816 L .5261 .38155 L F
.52582 .38124 m .52609 .38167 L .5261 .3816 L F
.52294 .37717 m .52613 .38175 L p .52257 .37703 L F P
0 g
s
.52536 .38045 m .52506 .38043 L .5258 .38122 L .67 .731 .896 r
F
.52536 .38045 m .5258 .38122 L .52605 .38123 L F
.52579 .38088 m .52536 .38045 L .52573 .38088 L F
.52611 .38176 m .52372 .37884 L .52647 .38154 L F
.5263 .38132 m .52664 .38177 L .52664 .38177 L F
.52609 .38171 m .52701 .3814 L .52704 .38136 L F
.52315 .37788 m .52315 .37788 L .52281 .37741 L F
.52384 .37883 m .52383 .37883 L .52281 .37741 L F
.52385 .37882 m .52384 .37883 L .52315 .37788 L F
.52669 .38176 m .52372 .37884 L .52055 .37497 L F
.5263 .38132 m .52646 .38153 L .52646 .38153 L F
.52618 .3817 m .52687 .38154 L .52701 .3814 L F
.52646 .38153 m .52664 .38177 L .52646 .38153 L F
.52646 .38153 m .52664 .38177 L .52664 .38177 L F
.52611 .38176 m .52667 .38174 L .52669 .38176 L F
.52667 .38174 m .5263 .38132 L .52664 .38177 L F
.5263 .38132 m .52632 .38166 L .52664 .38177 L F
.52616 .38176 m .52652 .38189 L .52627 .38176 L F
.52651 .3819 m .52607 .38207 L p .52627 .3816 L F P
0 g
s
.52582 .38176 m .52652 .38191 L .52629 .38162 L .67 .731 .896 r
F
.52632 .38166 m .52635 .38206 L .52651 .3819 L F
.52664 .38177 m .52664 .38177 L .52665 .38179 L F
.52664 .38177 m .52665 .38179 L .52665 .38178 L F
.52664 .38177 m .52665 .38179 L .52664 .38177 L F
.52669 .38176 m .52667 .38174 L .52668 .38176 L F
.52652 .38189 m .52695 .38173 L p .52627 .38176 L F P
0 g
s
.52632 .38166 m .52651 .3819 L .52664 .38177 L .67 .731 .896 r
F
.52285 .37743 m .52318 .37789 L .52281 .37741 L F
.52318 .37789 m .52315 .37788 L .52281 .37741 L F
.52257 .37703 m .52285 .37743 L .52281 .37741 L F
.52669 .38176 m .52055 .37497 L .5227 .37724 L F
.52704 .38136 m .52701 .3814 L .54016 .37662 L F
.54065 .37722 m .54016 .37662 L p .52627 .3816 L F P
0 g
s
.52627 .3816 m .52582 .38176 L .52629 .38162 L .67 .731 .896 r
F
.52627 .3816 m .52629 .38162 L .54065 .37722 L F
.52669 .38145 m .52651 .3819 L .52627 .3816 L F
.54016 .37662 m .52695 .38173 L p .52669 .38145 L F P
0 g
s
.52695 .38173 m .52651 .3819 L p .52669 .38145 L .67 .731 .896 r
F P
0 g
s
.5227 .37724 m .52055 .37497 L .51862 .37261 L .67 .731 .896 r
F
.5263 .38132 m .5263 .38132 L .52664 .38177 L F
.53028 .3865 m .53026 .38647 L .53388 .39126 L F
.52635 .38206 m .52615 .38206 L .52541 .38157 L F
.52652 .3819 m .52652 .3819 L .52692 .38175 L F
.52692 .38175 m .52692 .38175 L .53083 .38026 L F
.52652 .3819 m .52692 .38175 L .52692 .38175 L F
.52652 .3819 m .52656 .38187 L .53083 .38026 L F
.53 .38075 m .52652 .3819 L p .53083 .38026 L F P
0 g
s
.54065 .37722 m .53 .38075 L p .53083 .38026 L .67 .731 .896 r
F P
0 g
s
.52652 .38191 m .54065 .37722 L p .52629 .38162 L .67 .731 .896 r
F P
0 g
s
.52987 .386 m .52982 .38594 L .53388 .39126 L .67 .731 .896 r
F
.52606 .38206 m .52607 .38207 L .52579 .38208 L F
.52174 .38374 m .51305 .38789 L .52265 .38338 L F
.52174 .38374 m .52265 .38338 L .52539 .3821 L F
.52573 .38202 m .51305 .38789 L .52548 .38192 L F
.52608 .38173 m .52513 .38237 L .52524 .38199 L F
.52541 .38157 m .52615 .38206 L .52577 .38206 L F
.51773 .37295 m .51862 .37261 L p .52372 .37884 L F P
0 g
s
.52296 .37895 m .51872 .37576 L .5241 .38018 L .67 .731 .896 r
F
.52296 .37895 m .5241 .38018 L .5248 .38077 L F
.51872 .37576 m .51741 .37477 L .51923 .37625 L F
.51872 .37576 m .51923 .37625 L .5248 .38077 L F
.51606 .37376 m .51698 .37449 L p .51741 .37477 L F P
0 g
s
.52422 .38032 m .51606 .37376 L p .52449 .38021 L .67 .731 .896 r
F P
0 g
s
.52055 .37497 m .52577 .38206 L .52372 .37884 L .67 .731 .896 r
F
.51862 .37261 m .52225 .3774 L .52055 .37497 L F
.52225 .3774 m .52577 .38206 L .52055 .37497 L F
.52582 .38176 m .5254 .38192 L .52606 .38206 L F
.52474 .38212 m .52307 .38267 L .5245 .38231 L F
.51305 .38789 m .5125 .38731 L p .52548 .38192 L F P
0 g
s
.5125 .38731 m .52516 .38242 L p .52527 .382 L .67 .731 .896 r
F P
0 g
s
.52028 .38367 m .51157 .38611 L p .52239 .38261 L .67 .731 .896 r
F P
0 g
s
.51157 .38611 m .52118 .38341 L p .52165 .38303 L .67 .731 .896 r
F P
0 g
s
.52513 .38237 m .51201 .38672 L p .52527 .38192 L .67 .731 .896 r
F P
0 g
s
.51201 .38672 m .5256 .38221 L p .5254 .38192 L .67 .731 .896 r
F P
0 g
s
.52605 .38206 m .52513 .38237 L p .52606 .38202 L .67 .731 .896 r
F P
0 g
s
.5256 .38221 m .52606 .38206 L p .5254 .38192 L .67 .731 .896 r
F P
0 g
s
.52606 .38206 m .52616 .38206 L .52607 .38207 L .67 .731 .896 r
F
.52574 .38131 m .52611 .38176 L p .52544 .38154 L F P
0 g
s
.52611 .38176 m .52635 .38206 L p .52544 .38154 L .67 .731 .896 r
F P
0 g
s
.52544 .38154 m .52635 .38206 L .52541 .38157 L .67 .731 .896 r
F
.52635 .38206 m .52658 .38233 L p .52616 .38206 L F P
0 g
s
.52616 .38206 m .52658 .38233 L .52579 .38208 L .67 .731 .896 r
F
.52606 .38207 m .52607 .38207 L p .52606 .38207 L F P
0 g
s
.5125 .38731 m .51201 .38672 L p .52582 .38176 L .67 .731 .896 r
F P
0 g
s
.52605 .38207 m .52606 .38207 L .52606 .38207 L .67 .731 .896 r
F
.52607 .38207 m .5125 .38731 L p .52582 .38176 L F P
0 g
s
.52579 .38208 m .52618 .3822 L .52607 .38245 L .67 .731 .896 r
F
.52618 .3822 m .52658 .38233 L .52633 .38239 L F
.52618 .3822 m .52633 .38239 L .52607 .38245 L F
.51862 .37261 m .52574 .38131 L p .52541 .38157 L F P
0 g
s
.52574 .38131 m .52635 .38206 L p .5263 .38132 L .67 .731 .896 r
F P
0 g
s
.52625 .38127 m .52574 .38131 L .5263 .38132 L .67 .731 .896 r
F
.5282 .38138 m .52835 .38139 L .53045 .38082 L F
.52664 .38177 m .52835 .38139 L .5282 .38138 L F
.52623 .38129 m .5263 .38131 L .52631 .38089 L F
.5263 .38132 m .52625 .38127 L .5263 .38132 L F
.51862 .37261 m .52574 .38131 L p .52625 .38127 L F P
0 g
s
.53388 .39126 m .53297 .39156 L p .52607 .38245 L .67 .731 .896 r
F P
0 g
s
.52658 .38233 m .53388 .39126 L p .52607 .38245 L .67 .731 .896 r
F P
0 g
s
.52604 .38168 m .52524 .38199 L .52527 .38192 L .67 .731 .896 r
F
.51201 .38672 m .51157 .38611 L p .52527 .38192 L F P
0 g
s
.52736 .38105 m .527 .38125 L .52695 .38125 L .67 .731 .896 r
F
.515 .38853 m .5143 .38896 L .515 .38852 L F
.51993 .37672 m .51606 .37376 L .5203 .37685 L F
.53962 .37604 m .53902 .37548 L p .52675 .38134 L F P
0 g
s
.52582 .38222 m .52453 .38288 L p .52581 .38222 L .67 .731 .896 r
F P
0 g
s
.52503 .38262 m .52453 .38288 L .52497 .38259 L .67 .731 .896 r
F
.52998 .3813 m .54174 .37913 L p .52992 .38129 L F P
0 g
s
.51157 .38611 m .5112 .38547 L p .52239 .38261 L .67 .731 .896 r
F P
0 g
s
.53476 .39092 m .53561 .39055 L p .52761 .38268 L .67 .731 .896 r
F P
0 g
s
.52311 .38215 m .52222 .38229 L .52313 .38218 L .67 .731 .896 r
F
.52222 .38229 m .52314 .38219 L .52313 .38218 L F
.52222 .38229 m .52314 .3822 L .52314 .38219 L F
.52364 .38206 m .52172 .38257 L .52088 .38251 L F
.52314 .3822 m .52351 .38216 L .52351 .38216 L F
.52314 .38219 m .52453 .38204 L .52313 .38218 L F
.52314 .3822 m .52456 .38205 L .52314 .38219 L F
.5239 .38212 m .52172 .38257 L .52364 .38206 L F
.52172 .38257 m .51089 .38483 L .52088 .38251 L F
.53059 .38121 m .53059 .38121 L .53193 .38105 L F
.53192 .38105 m .53193 .38105 L .54198 .37979 L F
.52784 .38055 m .52734 .38089 L .5273 .38089 L F
.53604 .37546 m .52797 .38054 L .52784 .38055 L F
.53297 .39156 m .53202 .39183 L p .52652 .38321 L F P
0 g
s
.52944 .38148 m .53107 .38131 L .52942 .38148 L .67 .731 .896 r
F
.52693 .38185 m .52777 .38178 L .52694 .38183 L F
.52265 .37223 m .52265 .37221 L .52246 .37162 L F
.53106 .39205 m .53008 .39223 L p .52602 .38261 L F P
0 g
s
.52252 .38447 m .5258 .38227 L .52581 .38228 L .67 .731 .896 r
F
.53767 .37445 m .53601 .37555 L p .53604 .37546 L F P
0 g
s
.53837 .37495 m .53767 .37445 L p .52696 .3811 L .67 .731 .896 r
F P
0 g
s
.52252 .38447 m .5225 .38446 L .52489 .38288 L .67 .731 .896 r
F
.52252 .38447 m .52489 .38288 L .5249 .38288 L F
.51089 .38483 m .51255 .38452 L p .51177 .38464 L F P
0 g
s
.52694 .38191 m .52693 .38192 L .52697 .38193 L .67 .731 .896 r
F
.52698 .38191 m .52697 .38191 L .54191 .38048 L F
.52707 .38194 m .53144 .38171 L p .5271 .38189 L F P
0 g
s
.52693 .38192 m .52693 .38192 L .52819 .3818 L .67 .731 .896 r
F
.52693 .38192 m .53303 .38134 L p .52684 .3819 L F P
0 g
s
.52777 .38178 m .52895 .38161 L p .52781 .38172 L .67 .731 .896 r
F P
0 g
s
.5218 .38574 m .52397 .38369 L .52398 .3837 L .67 .731 .896 r
F
.51518 .37429 m .51529 .37421 L p .51571 .37449 L F P
0 g
s
.54193 .38048 m .52819 .3818 L p .54191 .38048 L .67 .731 .896 r
F P
0 g
s
.5112 .38547 m .51089 .38483 L p .5216 .3826 L .67 .731 .896 r
F P
0 g
s
.52336 .38416 m .52184 .38553 L .52337 .38413 L .67 .731 .896 r
F
.52184 .38553 m .52147 .38587 L .52185 .38553 L F
.52358 .38402 m .52586 .38224 L .52587 .38224 L F
.52687 .38187 m .53303 .38134 L .53305 .3813 L F
.52408 .38363 m .52412 .38354 L .52574 .38231 L F
.52408 .38363 m .52574 .38231 L .52576 .38231 L F
.52358 .38402 m .52351 .384 L .52412 .38354 L F
.52358 .38402 m .52412 .38354 L .52408 .38363 L F
.51925 .38802 m .5217 .38586 L .5217 .38587 L F
.5372 .38969 m .53792 .38921 L p .52774 .38246 L F P
0 g
s
.53353 .37653 m .53353 .37653 L p .53362 .37631 L .67 .731 .896 r
F P
0 g
s
.53353 .37653 m .53362 .37631 L .53362 .37631 L .67 .731 .896 r
F
.53692 .37399 m .53353 .37653 L p .53362 .37631 L F P
0 g
s
.53767 .37445 m .53692 .37399 L p .52657 .38129 L .67 .731 .896 r
F P
0 g
s
.53202 .39183 m .53106 .39205 L p .52638 .38319 L .67 .731 .896 r
F P
0 g
s
.53902 .37548 m .53837 .37495 L p .52964 .37972 L .67 .731 .896 r
F P
0 g
s
.52181 .38221 m .51041 .38328 L .52184 .38217 L .67 .731 .896 r
F
.51045 .3835 m .51041 .38328 L p .52077 .38236 L F P
0 g
s
.51045 .3835 m .51548 .38302 L p .51516 .38295 L .67 .731 .896 r
F P
0 g
s
.51064 .38417 m .51045 .3835 L p .52453 .38184 L .67 .731 .896 r
F P
0 g
s
.52469 .38335 m .52575 .38238 L .52577 .38239 L .67 .731 .896 r
F
.52776 .38183 m .53149 .38166 L .52776 .38182 L F
.52189 .38209 m .5234 .38202 L .52188 .38209 L F
.52696 .38186 m .53149 .38166 L .52696 .38186 L F
.52911 .3819 m .52913 .38194 L .52956 .38193 L F
.51925 .38802 m .51911 .38809 L .52425 .3836 L F
.51925 .38802 m .52425 .3836 L .52424 .38362 L F
.5271 .38196 m .52722 .38196 L .52709 .38196 L F
.52469 .38335 m .52458 .38334 L .52578 .38229 L F
.52469 .38335 m .52578 .38229 L .52587 .38228 L F
.53008 .39223 m .52908 .39237 L p .52619 .38331 L F P
0 g
s
.52692 .38189 m .53144 .38171 L .52693 .38188 L .67 .731 .896 r
F
.52696 .38186 m .53144 .38171 L .53149 .38166 L F
.52691 .3819 m .53144 .38171 L .52692 .38189 L F
.52188 .38209 m .52267 .38205 L .52266 .38205 L F
.52471 .38176 m .52184 .38217 L .522 .38196 L F
.52575 .38248 m .52585 .38234 L .52583 .3824 L F
.52895 .38161 m .53107 .38131 L p .52902 .38154 L F P
0 g
s
.52549 .38277 m .52576 .38248 L .52577 .38248 L .67 .731 .896 r
F
.53107 .38131 m .54198 .37979 L p .53151 .38112 L F P
0 g
s
.51758 .38229 m .52192 .38211 L .52189 .38209 L .67 .731 .896 r
F
.52489 .38346 m .52506 .38326 L .52506 .38327 L F
.52575 .38248 m .52193 .38624 L .52571 .38248 L F
.5258 .38269 m .52581 .38354 L .52594 .38277 L F
.52712 .38184 m .53149 .38166 L .5315 .38164 L F
.52504 .3833 m .52504 .38329 L .52506 .38327 L F
.52498 .38342 m .52504 .38329 L .52504 .3833 L F
.52498 .38342 m .52489 .38346 L .52504 .38329 L F
.52498 .38342 m .52506 .38327 L .52509 .38329 L F
.52586 .3823 m .52358 .38402 L p .52588 .38225 L F P
0 g
s
.52358 .38402 m .5159 .3898 L p .52351 .384 L .67 .731 .896 r
F P
0 g
s
.52252 .38447 m .515 .38945 L p .5225 .38446 L .67 .731 .896 r
F P
0 g
s
.52721 .38197 m .52757 .38197 L p .52721 .38197 L .67 .731 .896 r
F P
0 g
s
.52721 .38197 m .52757 .38197 L .52721 .38197 L .67 .731 .896 r
F
.5386 .38871 m .53923 .38817 L p .52744 .38214 L F P
0 g
s
.52857 .38195 m .52857 .38197 L .52897 .382 L .67 .731 .896 r
F
.52512 .38311 m .52593 .3823 L .52593 .3823 L F
.52722 .38196 m .52757 .38195 L .52757 .38195 L F
.52757 .38195 m .52777 .38195 L .52757 .38195 L F
.52757 .38195 m .52777 .38195 L .52777 .38195 L F
.52722 .38196 m .52777 .38195 L .52722 .38196 L F
.52725 .38199 m .52737 .382 L .52722 .38198 L F
.52569 .38262 m .52572 .38259 L .52572 .38259 L F
.52371 .38451 m .52368 .38453 L .52593 .3823 L F
.52572 .38259 m .52571 .38257 L .5258 .38246 L F
.52572 .38259 m .5258 .38246 L .52577 .38253 L F
.52569 .38262 m .52571 .38257 L .52572 .38259 L F
.5258 .38246 m .52549 .38277 L p .5258 .38245 L F P
0 g
s
.52579 .38249 m .52629 .38442 L .52582 .38389 L .67 .731 .896 r
F
.52543 .38162 m .52491 .38141 L p .52545 .38159 L F P
0 g
s
.52631 .38131 m .52632 .3809 L p .5263 .38131 L .67 .731 .896 r
F P
0 g
s
.52716 .38197 m .52757 .38197 L .52716 .38197 L .67 .731 .896 r
F
.52498 .38342 m .52569 .38256 L .5257 .38256 L F
.51758 .38229 m .52189 .38209 L .52188 .38209 L F
.51553 .38207 m .51757 .38205 L .51549 .38206 L F
.51757 .38205 m .51756 .38205 L .51549 .38206 L F
.51549 .38206 m .51756 .38205 L .51755 .38205 L F
.51176 .3821 m .51553 .38207 L .51549 .38206 L F
.51028 .38215 m .512 .38213 L p .51176 .3821 L F P
0 g
s
.51033 .38283 m .51028 .38215 L p .52364 .38172 L .67 .731 .896 r
F P
0 g
s
.5315 .38164 m .53782 .38137 L .53798 .38134 L .67 .731 .896 r
F
.53149 .38166 m .53782 .38137 L .5315 .38164 L F
.52777 .38195 m .52956 .38193 L .52956 .38193 L F
.52777 .38195 m .52956 .38193 L .52777 .38195 L F
.52569 .38262 m .52572 .38259 L .52572 .38259 L F
.52549 .38277 m .52371 .38451 L p .52546 .38278 L F P
0 g
s
.52498 .38342 m .5257 .38257 L .5257 .38257 L .67 .731 .896 r
F
.52498 .38342 m .5257 .38257 L .52571 .38257 L F
.53041 .38218 m .53063 .38224 L .53088 .38222 L F
.52956 .38193 m .54117 .38183 L .52956 .38193 L F
.53144 .38171 m .53782 .38137 L p .53149 .38166 L F P
0 g
s
.53152 .38364 m .53015 .38317 L .53016 .38315 L .67 .731 .896 r
F
.53278 .3841 m .53151 .38366 L .53152 .38364 L F
.53303 .38134 m .54215 .38046 L p .53305 .3813 L F P
0 g
s
.52512 .38311 m .52512 .38311 L .52593 .3823 L .67 .731 .896 r
F
.52512 .38311 m .52593 .3823 L .52593 .3823 L F
.52526 .38156 m .52557 .38166 L .52528 .38159 L F
.52738 .38202 m .52876 .38206 L p .52729 .382 L F P
0 g
s
.52754 .38213 m .52717 .38196 L .5276 .38225 L .67 .731 .896 r
F
.53197 .38411 m .52754 .38213 L .53225 .38435 L F
.52754 .38213 m .5276 .38225 L .53225 .38435 L F
.51801 .39011 m .518 .39012 L .52512 .38311 L F
.51801 .39011 m .52512 .38311 L .52512 .38311 L F
.5391 .3873 m .53197 .38411 L .53969 .38772 L F
.53197 .38411 m .53225 .38435 L .53969 .38772 L F
.52632 .3809 m .52648 .37419 L p .52631 .38089 L F P
0 g
s
.52807 .39246 m .52705 .39252 L p .52592 .38318 L .67 .731 .896 r
F P
0 g
s
.52637 .38118 m .52636 .38119 L .5264 .38113 L .67 .731 .896 r
F
.52632 .38126 m .52636 .38119 L .52637 .38118 L F
.52632 .38126 m .52632 .38125 L .52636 .38119 L F
.52631 .38124 m .52636 .38123 L .52639 .38116 L F
.52635 .38122 m .52636 .38123 L .52639 .38113 L F
.52636 .38123 m .52638 .38118 L .52639 .38113 L F
.53121 .37616 m .52912 .37857 L .52919 .37829 L F
.53442 .37278 m .52666 .38095 L .52789 .37984 L F
.53093 .37673 m .52904 .37887 L p .53121 .37616 L F P
0 g
s
.52904 .37887 m .52912 .37857 L .53121 .37616 L .67 .731 .896 r
F
.53442 .37278 m .53093 .37673 L p .53121 .37616 L F P
0 g
s
.53442 .37278 m .52789 .37984 L .53529 .37315 L .67 .731 .896 r
F
.52666 .38095 m .52694 .38085 L .53529 .37315 L F
.52318 .38569 m .51914 .39141 L .52318 .38569 L F
.51033 .38283 m .51809 .38241 L p .51758 .38229 L F P
0 g
s
.522 .38196 m .51041 .38328 L .512 .3827 L .67 .731 .896 r
F
.52184 .38217 m .51041 .38328 L .522 .38196 L F
.53923 .38817 m .53969 .38772 L p .52833 .38258 L F P
0 g
s
.52516 .38157 m .52394 .38114 L p .52516 .38155 L .67 .731 .896 r
F P
0 g
s
.52366 .38544 m .52323 .38602 L p .52368 .38538 L .67 .731 .896 r
F P
0 g
s
.52469 .38335 m .51925 .38802 L p .52458 .38334 L .67 .731 .896 r
F P
0 g
s
.53692 .37399 m .53612 .37355 L p .5308 .37783 L .67 .731 .896 r
F P
0 g
s
.52644 .37832 m .52642 .37832 L .52645 .37802 L .67 .731 .896 r
F
.52394 .38114 m .52526 .38156 L .52528 .38159 L F
.52814 .38195 m .52805 .38197 L .52897 .382 L F
.53392 .38459 m .53412 .38472 L .54033 .38703 L F
.54033 .38703 m .53161 .38389 L p .53278 .3841 L F P
0 g
s
.53605 .38537 m .53016 .38309 L .53879 .38717 L .67 .731 .896 r
F
.53016 .38309 m .53033 .38337 L .53879 .38717 L F
.52717 .38198 m .52775 .38209 L .52758 .38206 L F
.52745 .38203 m .52776 .38217 L .5276 .38206 L F
.52775 .38209 m .52779 .38209 L p .52758 .38206 L F P
0 g
s
.52779 .38209 m .53022 .38228 L p .52784 .38205 L .67 .731 .896 r
F P
0 g
s
.52717 .38198 m .52779 .38209 L .52784 .38205 L .67 .731 .896 r
F
.52805 .38219 m .52775 .38213 L .52776 .38212 L F
.52776 .38212 m .52776 .38217 L .53338 .38423 L F
.52655 .38079 m .52654 .38081 L .5265 .38082 L F
.52647 .38104 m .52655 .38078 L .52654 .38075 L F
.52908 .39237 m .52807 .39246 L p .52718 .38844 L F P
0 g
s
.52467 .38148 m .52463 .38147 L p .52467 .38148 L .67 .731 .896 r
F P
0 g
s
.52371 .38451 m .51801 .39011 L p .52368 .38453 L .67 .731 .896 r
F P
0 g
s
.52394 .38114 m .52515 .38144 L .52526 .38156 L .67 .731 .896 r
F
.53163 .38215 m .53067 .38212 L p .52959 .38196 L F P
0 g
s
.53538 .38213 m .53264 .38198 L .53457 .38221 L .67 .731 .896 r
F
.52489 .38346 m .52485 .38348 L .52499 .38333 L F
.52489 .38346 m .52499 .38333 L .52497 .38336 L F
.51983 .39047 m .5244 .38398 L .5244 .38398 L F
.52733 .38194 m .52893 .38201 L .52897 .382 L F
.52734 .38195 m .52893 .38201 L .52733 .38194 L F
.52897 .382 m .53734 .38234 L .53746 .38232 L F
.52893 .38201 m .53734 .38234 L .52897 .382 L F
.51801 .39011 m .51737 .39073 L p .518 .39012 L F P
0 g
s
.51041 .38328 m .51033 .38283 L p .512 .3827 L .67 .731 .896 r
F P
0 g
s
.52072 .38828 m .52063 .38834 L .52485 .38348 L .67 .731 .896 r
F
.52072 .38828 m .52485 .38348 L .52489 .38346 L F
.52364 .38454 m .52193 .38624 L .52338 .38466 L F
.52734 .38195 m .52876 .38206 L .52893 .38201 L F
.5252 .38559 m .52499 .38679 L .52519 .38561 L F
.5325 .38367 m .52778 .3821 L .53338 .38423 L F
.52778 .3821 m .5276 .38206 L .53338 .38423 L F
.51925 .38802 m .51654 .39034 L p .51911 .38809 L F P
0 g
s
.52654 .38075 m .52654 .38074 L .5264 .38128 L .67 .731 .896 r
F
.53969 .38772 m .53981 .38761 L p .5391 .3873 L F P
0 g
s
.52015 .38131 m .52191 .38148 L .52163 .38144 L .67 .731 .896 r
F
.52624 .38107 m .52635 .38122 L .52639 .38113 L F
.52404 .38453 m .52388 .38462 L .52489 .38346 L F
.52404 .38453 m .52489 .38346 L .52498 .38342 L F
.52889 .382 m .53088 .38222 L .53113 .38219 L F
.52504 .38339 m .52498 .38342 L .52566 .38262 L F
.52504 .38339 m .52566 .38262 L .52569 .38262 L F
.52572 .38263 m .52504 .38339 L p .52569 .38262 L F P
0 g
s
.52504 .38339 m .52404 .38453 L p .52498 .38342 L .67 .731 .896 r
F P
0 g
s
.52262 .38144 m .52403 .38158 L .52401 .38157 L .67 .731 .896 r
F
.52262 .38144 m .52287 .38154 L .52417 .38165 L F
.52262 .38144 m .52417 .38165 L .52403 .38158 L F
.52497 .38561 m .52527 .38518 L .52513 .38515 L F
.52539 .38337 m .52499 .38679 L .52499 .38486 L F
.52551 .38356 m .52499 .38679 L .52539 .38337 L F
.53782 .38137 m .54226 .38114 L p .53798 .38134 L F P
0 g
s
.52603 .39253 m .52605 .39178 L p .52601 .39197 L .67 .731 .896 r
F P
0 g
s
.52705 .39252 m .52603 .39253 L p .52588 .38629 L .67 .731 .896 r
F P
0 g
s
.52394 .38114 m .51218 .37691 L p .5237 .38093 L .67 .731 .896 r
F P
0 g
s
.52876 .38206 m .53734 .38234 L p .52893 .38201 L .67 .731 .896 r
F P
0 g
s
.51029 .38147 m .51713 .38169 L p .51627 .38153 L .67 .731 .896 r
F P
0 g
s
.51028 .38215 m .51029 .38147 L p .52005 .38157 L .67 .731 .896 r
F P
0 g
s
.52404 .38453 m .52072 .38828 L p .52388 .38462 L .67 .731 .896 r
F P
0 g
s
.53442 .37278 m .53351 .37245 L p .52631 .38124 L .67 .731 .896 r
F P
0 g
s
.52323 .38602 m .51914 .39141 L p .52295 .3862 L .67 .731 .896 r
F P
0 g
s
.52299 .3923 m .52517 .38548 L p .52497 .38561 L .67 .731 .896 r
F P
0 g
s
.52072 .38828 m .51824 .39109 L p .52063 .38834 L .67 .731 .896 r
F P
0 g
s
.5218 .38574 m .51654 .39034 L .52147 .38587 L .67 .731 .896 r
F
.53981 .38761 m .54033 .38703 L p .53605 .38537 L F P
0 g
s
.53605 .38537 m .53879 .38717 L .53981 .38761 L .67 .731 .896 r
F
.54079 .38642 m .53447 .38449 L p .53609 .38486 L F P
0 g
s
.53609 .38486 m .5325 .38367 L .54048 .38682 L .67 .731 .896 r
F
.5325 .38367 m .53338 .38423 L .54048 .38682 L F
.5159 .3898 m .51575 .38991 L p .5159 .3898 L F P
0 g
s
.53338 .38423 m .53003 .38301 L .53392 .38459 L .67 .731 .896 r
F
.52757 .38197 m .54117 .38183 L p .52756 .38195 L F P
0 g
s
.53246 .38356 m .53246 .38356 L .54117 .38579 L .67 .731 .896 r
F
.54117 .38183 m .54231 .38182 L p .54117 .38183 L F P
0 g
s
.5412 .3858 m .5411 .38578 L p .54117 .38579 L .67 .731 .896 r
F P
0 g
s
.54079 .38642 m .5412 .3858 L p .52854 .38224 L .67 .731 .896 r
F P
0 g
s
.52854 .38224 m .52869 .3824 L .54079 .38642 L .67 .731 .896 r
F
.53338 .38423 m .53392 .38459 L .54033 .38703 L F
.52603 .39253 m .52501 .39249 L p .52559 .38453 L F P
0 g
s
.52323 .38134 m .52361 .38143 L .52368 .38143 L .67 .731 .896 r
F
.51565 .37617 m .51389 .37521 L .51429 .3749 L p F P
0 g
s
.51429 .3749 m .51457 .37469 L p .51565 .37617 L .67 .731 .896 r
F P
0 g
s
.52532 .38353 m .52453 .38531 L .52453 .3853 L .67 .731 .896 r
F
.52453 .38531 m .52452 .38533 L p .52575 .38259 L F P
0 g
s
.52532 .38353 m .52302 .39216 L .52453 .38531 L .67 .731 .896 r
F
.52837 .37819 m .52828 .37872 L .53351 .37245 L F
.53351 .37245 m .53258 .37216 L p .52837 .37819 L F P
0 g
s
.52651 .3809 m .52654 .38075 L .5265 .38091 L .67 .731 .896 r
F
.52678 .37975 m .52655 .38078 L p .52622 .38032 L F P
0 g
s
.52654 .38075 m .52678 .37975 L .52654 .38074 L .67 .731 .896 r
F
.52438 .38154 m .52169 .38164 L .52262 .38144 L F
.52476 .38156 m .52169 .38164 L .52438 .38154 L F
.52639 .3812 m .52654 .38074 L .52651 .38068 L F
.53734 .38234 m .54228 .3825 L p .53746 .38232 L F P
0 g
s
.52651 .38068 m .52678 .37975 L .52676 .37962 L .67 .731 .896 r
F
.52654 .38074 m .52678 .37975 L .52651 .38068 L F
.52408 .38465 m .51983 .39047 L .52373 .38492 L F
.52262 .38144 m .52015 .38131 L .52287 .38154 L F
.51029 .38147 m .51036 .38079 L p .52262 .38144 L F P
0 g
s
.52464 .38148 m .52323 .38134 L .52466 .38153 L .67 .731 .896 r
F
.51036 .38079 m .51051 .38011 L p .52463 .38148 L F P
0 g
s
.51983 .39047 m .51914 .39141 L .51973 .39058 L .67 .731 .896 r
F
.52648 .37419 m .52656 .37131 L .52576 .37132 L p F P
0 g
s
.52576 .37132 m .52552 .37133 L p .52648 .37419 L .67 .731 .896 r
F P
0 g
s
.53113 .38219 m .53088 .38222 L .54219 .38317 L .67 .731 .896 r
F
.53022 .38228 m .54219 .38317 L p .53088 .38222 L F P
0 g
s
.52655 .38078 m .52678 .37975 L p .52654 .38075 L .67 .731 .896 r
F P
0 g
s
.52678 .37975 m .52776 .37531 L p .52676 .37962 L .67 .731 .896 r
F P
0 g
s
.52399 .39242 m .52499 .38788 L p .52458 .38897 L .67 .731 .896 r
F P
0 g
s
.52501 .39249 m .52399 .39242 L p .52559 .38307 L .67 .731 .896 r
F P
0 g
s
.52331 .38121 m .51071 .37945 L .52339 .38123 L .67 .731 .896 r
F
.54048 .38682 m .54079 .38642 L p .53609 .38486 L F P
0 g
s
.52299 .39228 m .52299 .3923 L .523 .39227 L .67 .731 .896 r
F
.52856 .37595 m .52837 .37674 L .53063 .37171 L F
.53258 .37216 m .53161 .37192 L p .52696 .37989 L F P
0 g
s
.52452 .38533 m .52102 .39194 L p .5237 .38649 L .67 .731 .896 r
F P
0 g
s
.53146 .38282 m .541 .38575 L .5412 .3858 L .67 .731 .896 r
F
.52776 .37531 m .52861 .37143 L .52805 .37138 L p F P
0 g
s
.52805 .37138 m .52759 .37135 L p .52776 .37531 L .67 .731 .896 r
F P
0 g
s
.5315 .38283 m .54182 .38451 L p .53342 .38301 L .67 .731 .896 r
F P
0 g
s
.52399 .39242 m .52299 .3923 L p .52499 .38486 L .67 .731 .896 r
F P
0 g
s
.52499 .38679 m .52399 .39242 L .52499 .38486 L .67 .731 .896 r
F
.51051 .38011 m .51071 .37945 L p .52342 .38123 L F P
0 g
s
.52299 .3923 m .522 .39214 L p .52453 .3853 L .67 .731 .896 r
F P
0 g
s
.52302 .39216 m .52299 .3923 L .52453 .3853 L .67 .731 .896 r
F
.51707 .37916 m .51172 .37752 L .51197 .37718 L p F P
0 g
s
.51197 .37718 m .51218 .37691 L p .51707 .37916 L .67 .731 .896 r
F P
0 g
s
.62563 .80148 m .63114 .84788 L .61493 .85588 L p .572 .42 .637 r
F P
0 g
s
.63114 .84788 m .62563 .80148 L .64043 .79463 L p .583 .432 .642 r
F P
0 g
s
.69377 .71026 m .69946 .74307 L .72048 .74274 L p .673 .468 .6 r
F P
0 g
s
.72048 .74274 m .71464 .70914 L .69377 .71026 L p .673 .468 .6 r
F P
0 g
s
.38746 .33989 m .43541 .35493 L .43516 .35892 L p .591 .649 .876 r
F P
0 g
s
.47583 .37251 m .43516 .35892 L .43541 .35493 L p .562 .628 .875 r
F P
0 g
s
.43516 .35892 m .47583 .37251 L .47584 .37468 L p .557 .63 .88 r
F P
0 g
s
.33497 .32217 m .3882 .33366 L .38746 .33989 L p .648 .692 .878 r
F P
0 g
s
.38746 .33989 m .33438 .33104 L .33497 .32217 L p .648 .692 .878 r
F P
0 g
s
.43541 .35493 m .38746 .33989 L .3882 .33366 L p .593 .647 .873 r
F P
0 g
s
.51045 .3835 m .47647 .37898 L .47605 .37684 L p .576 .662 .897 r
F P
0 g
s
.47647 .37898 m .51045 .3835 L .51064 .38417 L p .572 .666 .901 r
F P
0 g
s
.22403 .52921 m .22348 .49073 L .2365 .50438 L p .902 .604 .472 r
F P
0 g
s
.2365 .50438 m .23933 .54209 L .22403 .52921 L p .902 .604 .472 r
F P
0 g
s
.59819 .8649 m .59919 .9093 L .58092 .91761 L p .567 .363 .563 r
F P
0 g
s
.59919 .9093 m .59819 .8649 L .61493 .85588 L p .566 .371 .576 r
F P
0 g
s
.28099 .3212 m .33497 .32217 L .33438 .33104 L p .718 .746 .874 r
F P
0 g
s
.33438 .33104 m .28094 .33284 L .28099 .3212 L p .718 .746 .874 r
F P
0 g
s
.87072 .47234 m .88425 .51307 L .88484 .50008 L p 0 0 .496 r
F P
0 g
s
.88484 .50008 m .8725 .45974 L .87072 .47234 L p 0 0 .496 r
F P
0 g
s
.57635 .3779 m .54219 .38317 L .54204 .38384 L p .746 .806 .901 r
F P
0 g
s
.54219 .38317 m .57635 .3779 L .57666 .37577 L p .747 .801 .896 r
F P
0 g
s
.19987 .38996 m .23563 .36169 L .23999 .37608 L p .876 .784 .756 r
F P
0 g
s
.23999 .37608 m .20662 .40626 L .19987 .38996 L p .876 .784 .756 r
F P
0 g
s
.71464 .70914 m .72048 .74274 L .74323 .74239 L p .669 .46 .593 r
F P
0 g
s
.74323 .74239 m .73737 .70781 L .71464 .70914 L p .669 .46 .593 r
F P
0 g
s
.64789 .74919 m .65571 .78948 L .64043 .79463 L p .595 .453 .659 r
F P
0 g
s
.64789 .74919 m .65571 .78948 L .67198 .786 L p .621 .469 .655 r
F P
0 g
s
.67198 .786 m .66332 .74585 L .64789 .74919 L p .621 .469 .655 r
F P
0 g
s
.61725 .35722 m .57667 .37149 L .57677 .37363 L p .772 .809 .883 r
F P
0 g
s
.57667 .37149 m .61725 .35722 L .61674 .35342 L p .772 .802 .877 r
F P
0 g
s
.66401 .33833 m .61674 .35342 L .61725 .35722 L p .748 .79 .887 r
F P
0 g
s
.51033 .38283 m .47605 .37684 L .47584 .37468 L p .58 .659 .892 r
F P
0 g
s
.47605 .37684 m .51033 .38283 L .51045 .3835 L p .576 .662 .897 r
F P
0 g
s
.30598 .6394 m .29795 .61333 L .30548 .62207 L p .917 .538 .121 r
F P
0 g
s
.30548 .62207 m .31276 .64816 L .30598 .6394 L p .917 .538 .121 r
F P
0 g
s
.31558 .7292 m .32228 .69617 L .32658 .70844 L p .998 .815 .528 r
F P
0 g
s
.32658 .70844 m .32071 .7425 L .31558 .7292 L p .998 .815 .528 r
F P
0 g
s
.57666 .37577 m .54228 .3825 L .54219 .38317 L p .747 .801 .896 r
F P
0 g
s
.54228 .3825 m .57666 .37577 L .57677 .37363 L p .749 .796 .891 r
F P
0 g
s
.86515 .59379 m .86836 .63289 L .88151 .62034 L p .293 .159 .522 r
F P
0 g
s
.88151 .62034 m .87786 .58077 L .86515 .59379 L p .293 .159 .522 r
F P
0 g
s
.61674 .35342 m .66401 .33833 L .66267 .33273 L p .747 .784 .883 r
F P
0 g
s
.66401 .33833 m .71542 .33021 L .71344 .32286 L p .689 .755 .902 r
F P
0 g
s
.71344 .32286 m .66267 .33273 L .66401 .33833 L p .689 .755 .902 r
F P
0 g
s
.3882 .33366 m .43604 .35096 L .43541 .35493 L p .593 .647 .873 r
F P
0 g
s
.47603 .37035 m .43541 .35493 L .43604 .35096 L p .567 .626 .87 r
F P
0 g
s
.43541 .35493 m .47603 .37035 L .47583 .37251 L p .562 .628 .875 r
F P
0 g
s
.73737 .70781 m .74323 .74239 L .76726 .74142 L p .656 .446 .587 r
F P
0 g
s
.76726 .74142 m .76144 .70573 L .73737 .70781 L p .656 .446 .587 r
F P
0 g
s
.31144 .78279 m .32071 .7425 L .32682 .75653 L p .972 .781 .588 r
F P
0 g
s
.32682 .75653 m .31925 .79727 L .31144 .78279 L p .972 .781 .588 r
F P
0 g
s
.51028 .38215 m .47584 .37468 L .47583 .37251 L p .584 .657 .887 r
F P
0 g
s
.47584 .37468 m .51028 .38215 L .51033 .38283 L p .58 .659 .892 r
F P
0 g
s
.83084 .65396 m .83375 .69092 L .85462 .68234 L p .505 .314 .555 r
F P
0 g
s
.85462 .68234 m .85119 .64418 L .83084 .65396 L p .505 .314 .555 r
F P
0 g
s
.57677 .37363 m .54231 .38182 L .54228 .3825 L p .749 .796 .891 r
F P
0 g
s
.54231 .38182 m .57677 .37363 L .57667 .37149 L p .75 .791 .887 r
F P
0 g
s
.76756 .34248 m .81143 .36021 L .80805 .35055 L p .401 .575 .908 r
F P
0 g
s
.80805 .35055 m .76554 .33367 L .76756 .34248 L p .401 .575 .908 r
F P
0 g
s
.33653 .31351 m .38957 .32754 L .3882 .33366 L p .645 .693 .88 r
F P
0 g
s
.3882 .33366 m .33497 .32217 L .33653 .31351 L p .645 .693 .88 r
F P
0 g
s
.43604 .35096 m .3882 .33366 L .38957 .32754 L p .595 .646 .871 r
F P
0 g
s
.61674 .35342 m .57636 .36936 L .57667 .37149 L p .772 .802 .877 r
F P
0 g
s
.57636 .36936 m .61674 .35342 L .61586 .34964 L p .771 .794 .872 r
F P
0 g
s
.66267 .33273 m .61586 .34964 L .61674 .35342 L p .747 .784 .883 r
F P
0 g
s
.64043 .79463 m .64723 .8412 L .63114 .84788 L p .583 .432 .642 r
F P
0 g
s
.64723 .8412 m .64043 .79463 L .65571 .78948 L p .595 .442 .644 r
F P
0 g
s
.66332 .74585 m .67198 .786 L .68965 .78402 L p .645 .481 .646 r
F P
0 g
s
.68965 .78402 m .68042 .74394 L .66332 .74585 L p .645 .481 .646 r
F P
0 g
s
.71542 .33021 m .76554 .33367 L .76258 .32494 L p .583 .696 .92 r
F P
0 g
s
.76258 .32494 m .71344 .32286 L .71542 .33021 L p .583 .696 .92 r
F P
0 g
s
.51029 .38147 m .47583 .37251 L .47603 .37035 L p .588 .655 .883 r
F P
0 g
s
.47583 .37251 m .51029 .38147 L .51028 .38215 L p .584 .657 .887 r
F P
0 g
s
.76144 .70573 m .76726 .74142 L .79185 .73932 L p .636 .427 .583 r
F P
0 g
s
.79185 .73932 m .78615 .70245 L .76144 .70573 L p .636 .427 .583 r
F P
0 g
s
.8135 .37014 m .84709 .39973 L .84321 .38937 L p .098 .333 .806 r
F P
0 g
s
.84321 .38937 m .81143 .36021 L .8135 .37014 L p .098 .333 .806 r
F P
0 g
s
.61493 .85588 m .61676 .90137 L .59919 .9093 L p .566 .371 .576 r
F P
0 g
s
.61676 .90137 m .61493 .85588 L .63114 .84788 L p .569 .38 .585 r
F P
0 g
s
.38957 .32754 m .43707 .34705 L .43604 .35096 L p .595 .646 .871 r
F P
0 g
s
.47644 .3682 m .43604 .35096 L .43707 .34705 L p .572 .625 .866 r
F P
0 g
s
.43604 .35096 m .47644 .3682 L .47603 .37035 L p .567 .626 .87 r
F P
0 g
s
.57667 .37149 m .54226 .38114 L .54231 .38182 L p .75 .791 .887 r
F P
0 g
s
.54226 .38114 m .57667 .37149 L .57636 .36936 L p .75 .786 .882 r
F P
0 g
s
.26349 .58624 m .25363 .55378 L .26653 .56444 L p .887 .512 .322 r
F P
0 g
s
.26653 .56444 m .27716 .59571 L .26349 .58624 L p .887 .512 .322 r
F P
0 g
s
.33932 .91049 m .3372 .86959 L .35221 .88213 L p .89 .575 .446 r
F P
0 g
s
.35221 .88213 m .35517 .92177 L .33932 .91049 L p .89 .575 .446 r
F P
0 g
s
.45959 .97622 m .45503 .95003 L .47719 .94882 L p .641 .264 .314 r
F P
0 g
s
.47719 .94882 m .48022 .97557 L .45959 .97622 L p .641 .264 .314 r
F P
0 g
s
.48022 .97557 m .47719 .94882 L .49924 .94546 L p .612 .253 .337 r
F P
0 g
s
.49924 .94546 m .50081 .97319 L .48022 .97557 L p .612 .253 .337 r
F P
0 g
s
.50081 .97319 m .49924 .94546 L .52084 .94025 L p .587 .247 .361 r
F P
0 g
s
.31291 .84183 m .31925 .79727 L .32864 .81188 L p .944 .711 .554 r
F P
0 g
s
.32864 .81188 m .32417 .85597 L .31291 .84183 L p .944 .711 .554 r
F P
0 g
s
.87971 .52649 m .88636 .56724 L .89031 .55358 L p 0 0 .431 r
F P
0 g
s
.89031 .55358 m .88425 .51307 L .87971 .52649 L p 0 0 .431 r
F P
0 g
s
.23193 .33309 m .28099 .3212 L .28094 .33284 L p .798 .8 .854 r
F P
0 g
s
.28094 .33284 m .23288 .34728 L .23193 .33309 L p .798 .8 .854 r
F P
0 g
s
.51036 .38079 m .47603 .37035 L .47644 .3682 L p .592 .653 .879 r
F P
0 g
s
.47603 .37035 m .51036 .38079 L .51029 .38147 L p .588 .655 .883 r
F P
0 g
s
.28244 .30989 m .33653 .31351 L .33497 .32217 L p .712 .753 .884 r
F P
0 g
s
.33497 .32217 m .28099 .3212 L .28244 .30989 L p .712 .753 .884 r
F P
0 g
s
.18668 .44341 m .20662 .40626 L .21496 .42217 L p .918 .736 .64 r
F P
0 g
s
.21496 .42217 m .19798 .46011 L .18668 .44341 L p .918 .736 .64 r
F P
0 g
s
.52084 .94025 m .52113 .9693 L .50081 .97319 L p .587 .247 .361 r
F P
0 g
s
.52113 .9693 m .52084 .94025 L .54174 .93357 L p .567 .246 .385 r
F P
0 g
s
.43918 .97499 m .43312 .94891 L .45503 .95003 L p .674 .28 .291 r
F P
0 g
s
.45503 .95003 m .45959 .97622 L .43918 .97499 L p .674 .28 .291 r
F P
0 g
s
.61586 .34964 m .66267 .33273 L .66079 .32716 L p .746 .778 .879 r
F P
0 g
s
.66267 .33273 m .71344 .32286 L .71074 .31551 L p .687 .751 .9 r
F P
0 g
s
.71074 .31551 m .66079 .32716 L .66267 .33273 L p .687 .751 .9 r
F P
0 g
s
.61586 .34964 m .57585 .36725 L .57636 .36936 L p .771 .794 .872 r
F P
0 g
s
.57585 .36725 m .61586 .34964 L .61461 .34589 L p .77 .787 .867 r
F P
0 g
s
.66079 .32716 m .61461 .34589 L .61586 .34964 L p .746 .778 .879 r
F P
0 g
s
.57636 .36936 m .54215 .38046 L .54226 .38114 L p .75 .786 .882 r
F P
0 g
s
.54215 .38046 m .57636 .36936 L .57585 .36725 L p .75 .781 .878 r
F P
0 g
s
.68042 .74394 m .68965 .78402 L .70895 .78315 L p .66 .483 .634 r
F P
0 g
s
.70895 .78315 m .69946 .74307 L .68042 .74394 L p .66 .483 .634 r
F P
0 g
s
.20832 .51506 m .21045 .47595 L .22348 .49073 L p .907 .624 .496 r
F P
0 g
s
.22348 .49073 m .22403 .52921 L .20832 .51506 L p .907 .624 .496 r
F P
0 g
s
.43707 .34705 m .47705 .36607 L .47644 .3682 L p .572 .625 .866 r
F P
0 g
s
.51051 .38011 m .47644 .3682 L .47705 .36607 L p .596 .651 .875 r
F P
0 g
s
.47644 .3682 m .51051 .38011 L .51036 .38079 L p .592 .653 .879 r
F P
0 g
s
.81143 .36021 m .84321 .38937 L .83778 .37947 L p 0 .257 .767 r
F P
0 g
s
.83778 .37947 m .84321 .38937 L p .84517 .39497 L .757 .385 0 r
F P
0 g
s
.84907 .41064 m .86729 .44121 L p .86053 .42709 L 0 0 .557 r
F P
0 g
s
.86718 .43662 m .84709 .39973 L .84907 .41064 L p 0 0 .557 r
F P
0 g
s
.85272 .41649 m .83788 .37973 L p .84517 .39497 L .757 .385 0 r
F P
0 g
s
.83788 .37973 m .83778 .37947 L p .84517 .39497 L .757 .385 0 r
F P
0 g
s
.87122 .4478 m .86718 .43662 L p .86053 .42709 L 0 0 .557 r
F P
0 g
s
.86729 .44121 m .87122 .4478 L p .86053 .42709 L 0 0 .557 r
F P
0 g
s
.39157 .32158 m .43847 .34321 L .43707 .34705 L p .597 .645 .869 r
F P
0 g
s
.43707 .34705 m .38957 .32754 L .39157 .32158 L p .597 .645 .869 r
F P
0 g
s
.47705 .36607 m .43707 .34705 L .43847 .34321 L p .577 .624 .862 r
F P
0 g
s
.57585 .36725 m .54198 .37979 L .54215 .38046 L p .75 .781 .878 r
F P
0 g
s
.33906 .30513 m .39157 .32158 L .38957 .32754 L p .642 .694 .883 r
F P
0 g
s
.38957 .32754 m .33653 .31351 L .33906 .30513 L p .642 .694 .883 r
F P
0 g
s
.78615 .70245 m .79185 .73932 L .81617 .73564 L p .607 .403 .579 r
F P
0 g
s
.81617 .73564 m .81058 .69759 L .78615 .70245 L p .607 .403 .579 r
F P
0 g
s
.47705 .36607 m .51071 .37945 L .51051 .38011 L p .596 .651 .875 r
F P
0 g
s
.54198 .37979 m .57585 .36725 L .57513 .36515 L p .75 .775 .874 r
F P
0 g
s
.61461 .34589 m .57513 .36515 L .57585 .36725 L p .77 .787 .867 r
F P
0 g
s
.54174 .93357 m .54099 .9642 L .52113 .9693 L p .567 .246 .385 r
F P
0 g
s
.54099 .9642 m .54174 .93357 L .56179 .92586 L p .552 .249 .408 r
F P
0 g
s
.65571 .78948 m .66362 .83602 L .64723 .8412 L p .595 .442 .644 r
F P
0 g
s
.65571 .78948 m .66362 .83602 L .68072 .83235 L p .612 .452 .641 r
F P
0 g
s
.68072 .83235 m .67198 .786 L .65571 .78948 L p .612 .452 .641 r
F P
0 g
s
.57513 .36515 m .54174 .37913 L .54198 .37979 L p .75 .775 .874 r
F P
0 g
s
.19514 .37356 m .23288 .34728 L .23563 .36169 L p .879 .811 .778 r
F P
0 g
s
.23563 .36169 m .19987 .38996 L .19514 .37356 L p .879 .811 .778 r
F P
0 g
s
.41928 .97184 m .41186 .9454 L .43312 .94891 L p .71 .301 .27 r
F P
0 g
s
.43312 .94891 m .43918 .97499 L .41928 .97184 L p .71 .301 .27 r
F P
0 g
s
.47788 .36398 m .51099 .37879 L .51071 .37945 L p .6 .65 .871 r
F P
0 g
s
.51071 .37945 m .47705 .36607 L .47788 .36398 L p .6 .65 .871 r
F P
0 g
s
.31307 .67472 m .31276 .64816 L .318 .65764 L p .985 .725 .341 r
F P
0 g
s
.318 .65764 m .31808 .68488 L .31307 .67472 L p .985 .725 .341 r
F P
0 g
s
.54174 .37913 m .57513 .36515 L .57421 .36309 L p .749 .77 .87 r
F P
0 g
s
.57421 .36309 m .54144 .37848 L .54174 .37913 L p .749 .77 .87 r
F P
0 g
s
.43847 .34321 m .47788 .36398 L .47705 .36607 L p .577 .624 .862 r
F P
0 g
s
.4789 .36193 m .51132 .37815 L .51099 .37879 L p .604 .649 .868 r
F P
0 g
s
.51099 .37879 m .47788 .36398 L .4789 .36193 L p .604 .649 .868 r
F P
0 g
s
.69946 .74307 m .70895 .78315 L .72989 .78293 L p .665 .478 .623 r
F P
0 g
s
.72989 .78293 m .72048 .74274 L .69946 .74307 L p .665 .478 .623 r
F P
0 g
s
.54144 .37848 m .57421 .36309 L .57308 .36106 L p .748 .765 .866 r
F P
0 g
s
.57308 .36106 m .54107 .37784 L .54144 .37848 L p .748 .765 .866 r
F P
0 g
s
.57513 .36515 m .61461 .34589 L .61299 .34218 L p .769 .78 .862 r
F P
0 g
s
.61461 .34589 m .66079 .32716 L .65836 .3216 L p .745 .772 .874 r
F P
0 g
s
.65836 .3216 m .61299 .34218 L .61461 .34589 L p .745 .772 .874 r
F P
0 g
s
.29702 .63114 m .28862 .60464 L .29795 .61333 L p .921 .531 .221 r
F P
0 g
s
.29795 .61333 m .30598 .6394 L .29702 .63114 L p .921 .531 .221 r
F P
0 g
s
.48013 .35993 m .51172 .37752 L .51132 .37815 L p .609 .648 .864 r
F P
0 g
s
.51132 .37815 m .4789 .36193 L .48013 .35993 L p .609 .648 .864 r
F P
0 g
s
.63114 .84788 m .63387 .89419 L .61676 .90137 L p .569 .38 .585 r
F P
0 g
s
.63387 .89419 m .63114 .84788 L .64723 .8412 L p .574 .388 .592 r
F P
0 g
s
.61299 .34218 m .57421 .36309 L .57513 .36515 L p .769 .78 .862 r
F P
0 g
s
.54107 .37784 m .57308 .36106 L .57177 .35908 L p .747 .759 .862 r
F P
0 g
s
.57177 .35908 m .54065 .37722 L .54107 .37784 L p .747 .759 .862 r
F P
0 g
s
.48154 .35798 m .51218 .37691 L .51172 .37752 L p .613 .648 .861 r
F P
0 g
s
.51172 .37752 m .48013 .35993 L .48154 .35798 L p .613 .648 .861 r
F P
0 g
s
.54065 .37722 m .57177 .35908 L .57026 .35716 L p .746 .754 .859 r
F P
0 g
s
.57026 .35716 m .54016 .37662 L .54065 .37722 L p .746 .754 .859 r
F P
0 g
s
.71344 .32286 m .76258 .32494 L .75878 .31619 L p .576 .693 .921 r
F P
0 g
s
.75878 .31619 m .71074 .31551 L .71344 .32286 L p .576 .693 .921 r
F P
0 g
s
.44026 .33946 m .4789 .36193 L .47788 .36398 L p .582 .623 .858 r
F P
0 g
s
.47788 .36398 m .43847 .34321 L .44026 .33946 L p .582 .623 .858 r
F P
0 g
s
.48315 .3561 m .51269 .37632 L .51218 .37691 L p .618 .648 .858 r
F P
0 g
s
.51218 .37691 m .48154 .35798 L .48315 .3561 L p .618 .648 .858 r
F P
0 g
s
.85119 .64418 m .85462 .68234 L .87219 .67191 L p .427 .259 .548 r
F P
0 g
s
.87219 .67191 m .86836 .63289 L .85119 .64418 L p .427 .259 .548 r
F P
0 g
s
.39421 .3158 m .44026 .33946 L .43847 .34321 L p .599 .645 .867 r
F P
0 g
s
.43847 .34321 m .39157 .32158 L .39421 .3158 L p .599 .645 .867 r
F P
0 g
s
.54016 .37662 m .57026 .35716 L .56856 .3553 L p .744 .748 .856 r
F P
0 g
s
.56856 .3553 m .53962 .37604 L .54016 .37662 L p .744 .748 .856 r
F P
0 g
s
.56179 .92586 m .56027 .95822 L .54099 .9642 L p .552 .249 .408 r
F P
0 g
s
.56027 .95822 m .56179 .92586 L .58092 .91761 L p .542 .255 .429 r
F P
0 g
s
.66079 .32716 m .71074 .31551 L .70736 .30814 L p .686 .747 .897 r
F P
0 g
s
.70736 .30814 m .65836 .3216 L .66079 .32716 L p .686 .747 .897 r
F P
0 g
s
.48494 .3543 m .51326 .37575 L .51269 .37632 L p .623 .648 .854 r
F P
0 g
s
.51269 .37632 m .48315 .3561 L .48494 .3543 L p .623 .648 .854 r
F P
0 g
s
.53962 .37604 m .56856 .3553 L .56669 .35351 L p .742 .743 .852 r
F P
0 g
s
.56669 .35351 m .53902 .37548 L .53962 .37604 L p .742 .743 .852 r
F P
0 g
s
.57421 .36309 m .61299 .34218 L .61102 .33851 L p .767 .772 .857 r
F P
0 g
s
.61102 .33851 m .57308 .36106 L .57421 .36309 L p .767 .772 .857 r
F P
0 g
s
.48691 .35257 m .51389 .37521 L .51326 .37575 L p .627 .648 .852 r
F P
0 g
s
.51326 .37575 m .48494 .3543 L .48691 .35257 L p .627 .648 .852 r
F P
0 g
s
.53902 .37548 m .56669 .35351 L .56465 .3518 L p .74 .738 .849 r
F P
0 g
s
.56465 .3518 m .53837 .37495 L .53902 .37548 L p .74 .738 .849 r
F P
0 g
s
.72048 .74274 m .72989 .78293 L .75228 .78281 L p .661 .467 .611 r
F P
0 g
s
.75228 .78281 m .74323 .74239 L .72048 .74274 L p .661 .467 .611 r
F P
0 g
s
.76554 .33367 m .80805 .35055 L .80359 .34104 L p .366 .563 .911 r
F P
0 g
s
.80359 .34104 m .76258 .32494 L .76554 .33367 L p .366 .563 .911 r
F P
0 g
s
.28536 .29905 m .33906 .30513 L .33653 .31351 L p .705 .759 .895 r
F P
0 g
s
.33653 .31351 m .28244 .30989 L .28536 .29905 L p .705 .759 .895 r
F P
0 g
s
.48904 .35094 m .51457 .37469 L .51389 .37521 L p .632 .649 .849 r
F P
0 g
s
.51389 .37521 m .48691 .35257 L .48904 .35094 L p .632 .649 .849 r
F P
0 g
s
.24783 .57591 m .23933 .54209 L .25363 .55378 L p .879 .524 .37 r
F P
0 g
s
.25363 .55378 m .26349 .58624 L .24783 .57591 L p .879 .524 .37 r
F P
0 g
s
.53837 .37495 m .56465 .3518 L .56245 .35018 L p .738 .733 .847 r
F P
0 g
s
.56245 .35018 m .53767 .37445 L .53837 .37495 L p .738 .733 .847 r
F P
0 g
s
.31059 .71701 m .31808 .68488 L .32228 .69617 L p .995 .819 .555 r
F P
0 g
s
.32228 .69617 m .31558 .7292 L .31059 .71701 L p .995 .819 .555 r
F P
0 g
s
.40014 .96682 m .39159 .93957 L .41186 .9454 L p .746 .326 .252 r
F P
0 g
s
.41186 .9454 m .41928 .97184 L .40014 .96682 L p .746 .326 .252 r
F P
0 g
s
.44243 .33581 m .48013 .35993 L .4789 .36193 L p .588 .623 .854 r
F P
0 g
s
.4789 .36193 m .44026 .33946 L .44243 .33581 L p .588 .623 .854 r
F P
0 g
s
.67198 .786 m .68072 .83235 L .69883 .83002 L p .63 .46 .634 r
F P
0 g
s
.69883 .83002 m .68965 .78402 L .67198 .786 L p .63 .46 .634 r
F P
0 g
s
.49133 .34939 m .51529 .37421 L .51457 .37469 L p .637 .65 .846 r
F P
0 g
s
.51457 .37469 m .48904 .35094 L .49133 .34939 L p .637 .65 .846 r
F P
0 g
s
.34257 .2971 m .39421 .3158 L .39157 .32158 L p .639 .695 .886 r
F P
0 g
s
.39157 .32158 m .33906 .30513 L .34257 .2971 L p .639 .695 .886 r
F P
0 g
s
.61299 .34218 m .65836 .3216 L .65542 .31607 L p .744 .765 .87 r
F P
0 g
s
.65542 .31607 m .61102 .33851 L .61299 .34218 L p .744 .765 .87 r
F P
0 g
s
.8817 .4878 m .87122 .4478 L .8725 .45974 L p 0 0 .298 r
F P
0 g
s
.86718 .43662 m .87122 .4478 L p .87255 .45733 L .818 .531 0 r
F P
0 g
s
.8725 .45974 m .88144 .48896 L p .87763 .47539 L 0 0 .298 r
F P
0 g
s
.87523 .47642 m .86832 .44225 L p .87255 .45733 L .818 .531 0 r
F P
0 g
s
.86832 .44225 m .86718 .43662 L p .87255 .45733 L .818 .531 0 r
F P
0 g
s
.88484 .50008 m .8817 .4878 L p .87763 .47539 L 0 0 .298 r
F P
0 g
s
.88144 .48896 m .88484 .50008 L p .87763 .47539 L 0 0 .298 r
F P
0 g
s
.87786 .58077 m .88151 .62034 L .89002 .60689 L p .095 .019 .471 r
F P
0 g
s
.89002 .60689 m .88636 .56724 L .87786 .58077 L p .095 .019 .471 r
F P
0 g
s
.53767 .37445 m .56245 .35018 L .56009 .34865 L p .735 .728 .844 r
F P
0 g
s
.56009 .34865 m .53692 .37399 L .53767 .37445 L p .735 .728 .844 r
F P
0 g
s
.49377 .34795 m .51606 .37376 L .51529 .37421 L p .642 .651 .844 r
F P
0 g
s
.51529 .37421 m .49133 .34939 L .49377 .34795 L p .642 .651 .844 r
F P
0 g
s
.53692 .37399 m .56009 .34865 L .55758 .34722 L p .733 .723 .842 r
F P
0 g
s
.55758 .34722 m .53612 .37355 L .53692 .37399 L p .733 .723 .842 r
F P
0 g
s
.57308 .36106 m .61102 .33851 L .60869 .33491 L p .765 .765 .853 r
F P
0 g
s
.60869 .33491 m .57177 .35908 L .57308 .36106 L p .765 .765 .853 r
F P
0 g
s
.49635 .34661 m .51688 .37334 L .51606 .37376 L p .647 .653 .841 r
F P
0 g
s
.51606 .37376 m .49377 .34795 L .49635 .34661 L p .647 .653 .841 r
F P
0 g
s
.30458 .76899 m .31558 .7292 L .32071 .7425 L p .972 .797 .608 r
F P
0 g
s
.32071 .7425 m .31144 .78279 L .30458 .76899 L p .972 .797 .608 r
F P
0 g
s
.81058 .69759 m .81617 .73564 L .83923 .73007 L p .569 .372 .575 r
F P
0 g
s
.83923 .73007 m .83375 .69092 L .81058 .69759 L p .569 .372 .575 r
F P
0 g
s
.53612 .37355 m .55758 .34722 L .55494 .34591 L p .73 .718 .84 r
F P
0 g
s
.55494 .34591 m .53529 .37315 L .53612 .37355 L p .73 .718 .84 r
F P
0 g
s
.23296 .31936 m .28244 .30989 L .28099 .3212 L p .792 .818 .873 r
F P
0 g
s
.28099 .3212 m .23193 .33309 L .23296 .31936 L p .792 .818 .873 r
F P
0 g
s
.32508 .89818 m .32417 .85597 L .3372 .86959 L p .915 .61 .454 r
F P
0 g
s
.3372 .86959 m .33932 .91049 L .32508 .89818 L p .915 .61 .454 r
F P
0 g
s
.49905 .34537 m .51773 .37295 L .51688 .37334 L p .652 .654 .839 r
F P
0 g
s
.51688 .37334 m .49635 .34661 L .49905 .34537 L p .652 .654 .839 r
F P
0 g
s
.53529 .37315 m .55494 .34591 L .55218 .34471 L p .727 .713 .838 r
F P
0 g
s
.55218 .34471 m .53442 .37278 L .53529 .37315 L p .727 .713 .838 r
F P
0 g
s
.39746 .31023 m .44243 .33581 L .44026 .33946 L p .602 .645 .865 r
F P
0 g
s
.44026 .33946 m .39421 .3158 L .39746 .31023 L p .602 .645 .865 r
F P
0 g
s
.50187 .34426 m .51862 .37261 L .51773 .37295 L p .657 .656 .837 r
F P
0 g
s
.51773 .37295 m .49905 .34537 L .50187 .34426 L p .657 .656 .837 r
F P
0 g
s
.44496 .33229 m .48154 .35798 L .48013 .35993 L p .593 .623 .851 r
F P
0 g
s
.48013 .35993 m .44243 .33581 L .44496 .33229 L p .593 .623 .851 r
F P
0 g
s
.53442 .37278 m .55218 .34471 L .54931 .34364 L p .723 .709 .836 r
F P
0 g
s
.54931 .34364 m .53351 .37245 L .53442 .37278 L p .723 .709 .836 r
F P
0 g
s
.50187 .34426 m .51862 .37261 L .51954 .3723 L p .662 .658 .836 r
F P
0 g
s
.53351 .37245 m .54931 .34364 L .54633 .3427 L p .72 .704 .834 r
F P
0 g
s
.54633 .3427 m .53258 .37216 L .53351 .37245 L p .72 .704 .834 r
F P
0 g
s
.5048 .34326 m .51954 .3723 L .52049 .37203 L p .667 .66 .834 r
F P
0 g
s
.51954 .3723 m .5048 .34326 L .50187 .34426 L p .662 .658 .836 r
F P
0 g
s
.53258 .37216 m .54633 .3427 L .54327 .34189 L p .717 .7 .833 r
F P
0 g
s
.54327 .34189 m .53161 .37192 L .53258 .37216 L p .717 .7 .833 r
F P
0 g
s
.50782 .34239 m .52049 .37203 L .52147 .37181 L p .671 .663 .833 r
F P
0 g
s
.52049 .37203 m .50782 .34239 L .5048 .34326 L p .667 .66 .834 r
F P
0 g
s
.58092 .91761 m .57891 .95172 L .56027 .95822 L p .542 .255 .429 r
F P
0 g
s
.57891 .95172 m .58092 .91761 L .59919 .9093 L p .536 .263 .448 r
F P
0 g
s
.57177 .35908 m .60869 .33491 L .60603 .33138 L p .763 .758 .848 r
F P
0 g
s
.60603 .33138 m .57026 .35716 L .57177 .35908 L p .763 .758 .848 r
F P
0 g
s
.53161 .37192 m .54327 .34189 L .54014 .34122 L p .713 .695 .832 r
F P
0 g
s
.54014 .34122 m .53063 .37171 L .53161 .37192 L p .713 .695 .832 r
F P
0 g
s
.64723 .8412 m .6508 .88803 L .63387 .89419 L p .574 .388 .592 r
F P
0 g
s
.6508 .88803 m .64723 .8412 L .66362 .83602 L p .581 .394 .594 r
F P
0 g
s
.51092 .34164 m .52147 .37181 L .52246 .37162 L p .676 .665 .832 r
F P
0 g
s
.52147 .37181 m .51092 .34164 L .50782 .34239 L p .671 .663 .833 r
F P
0 g
s
.74323 .74239 m .75228 .78281 L .7757 .78221 L p .649 .45 .601 r
F P
0 g
s
.7757 .78221 m .76726 .74142 L .74323 .74239 L p .649 .45 .601 r
F P
0 g
s
.17721 .42613 m .19987 .38996 L .20662 .40626 L p .929 .769 .661 r
F P
0 g
s
.20662 .40626 m .18668 .44341 L .17721 .42613 L p .929 .769 .661 r
F P
0 g
s
.53063 .37171 m .54014 .34122 L .53694 .34069 L p .709 .691 .831 r
F P
0 g
s
.53694 .34069 m .52963 .37155 L .53063 .37171 L p .709 .691 .831 r
F P
0 g
s
.51408 .34103 m .52246 .37162 L .52347 .37148 L p .68 .668 .831 r
F P
0 g
s
.52246 .37162 m .51408 .34103 L .51092 .34164 L p .676 .665 .832 r
F P
0 g
s
.52963 .37155 m .53694 .34069 L .5337 .34031 L p .705 .687 .83 r
F P
0 g
s
.5337 .34031 m .52861 .37143 L .52963 .37155 L p .705 .687 .83 r
F P
0 g
s
.5173 .34056 m .52347 .37148 L .52449 .37138 L p .684 .671 .831 r
F P
0 g
s
.52347 .37148 m .5173 .34056 L .51408 .34103 L p .68 .668 .831 r
F P
0 g
s
.52861 .37143 m .5337 .34031 L .53043 .34007 L p .701 .684 .83 r
F P
0 g
s
.53043 .34007 m .52759 .37135 L .52861 .37143 L p .701 .684 .83 r
F P
0 g
s
.52056 .34022 m .52449 .37138 L .52552 .37133 L p .689 .674 .83 r
F P
0 g
s
.52449 .37138 m .52056 .34022 L .5173 .34056 L p .684 .671 .831 r
F P
0 g
s
.52759 .37135 m .53043 .34007 L .52714 .33997 L p .697 .68 .83 r
F P
0 g
s
.52714 .33997 m .52656 .37131 L .52759 .37135 L p .697 .68 .83 r
F P
0 g
s
.52384 .34002 m .52552 .37133 L .52656 .37131 L p .693 .677 .83 r
F P
0 g
s
.52552 .37133 m .52384 .34002 L .52056 .34022 L p .689 .674 .83 r
F P
0 g
s
.52656 .37131 m .52714 .33997 L .52384 .34002 L p .693 .677 .83 r
F P
0 g
s
.19292 .49968 m .19798 .46011 L .21045 .47595 L p .917 .65 .517 r
F P
0 g
s
.21045 .47595 m .20832 .51506 L .19292 .49968 L p .917 .65 .517 r
F P
0 g
s
.83778 .37947 m .80805 .35055 L .81143 .36021 L p 0 .257 .767 r
F P
0 g
s
.44784 .32891 m .48315 .3561 L .48154 .35798 L p .599 .623 .847 r
F P
0 g
s
.48154 .35798 m .44496 .33229 L .44784 .32891 L p .599 .623 .847 r
F P
0 g
s
.61102 .33851 m .65542 .31607 L .65197 .31057 L p .742 .759 .866 r
F P
0 g
s
.65197 .31057 m .60869 .33491 L .61102 .33851 L p .742 .759 .866 r
F P
0 g
s
.30306 .82772 m .31144 .78279 L .31925 .79727 L p .953 .736 .572 r
F P
0 g
s
.31925 .79727 m .31291 .84183 L .30306 .82772 L p .953 .736 .572 r
F P
0 g
s
.65836 .3216 m .70736 .30814 L .70334 .30072 L p .685 .742 .895 r
F P
0 g
s
.70334 .30072 m .65542 .31607 L .65836 .3216 L p .685 .742 .895 r
F P
0 g
s
.57026 .35716 m .60603 .33138 L .60303 .32793 L p .76 .751 .844 r
F P
0 g
s
.60303 .32793 m .56856 .3553 L .57026 .35716 L p .76 .751 .844 r
F P
0 g
s
.68965 .78402 m .69883 .83002 L .71813 .82873 L p .641 .461 .624 r
F P
0 g
s
.71813 .82873 m .70895 .78315 L .68965 .78402 L p .641 .461 .624 r
F P
0 g
s
.4013 .30491 m .44496 .33229 L .44243 .33581 L p .605 .645 .864 r
F P
0 g
s
.44243 .33581 m .39746 .31023 L .4013 .30491 L p .605 .645 .864 r
F P
0 g
s
.45107 .32566 m .48494 .3543 L .48315 .3561 L p .605 .624 .844 r
F P
0 g
s
.48315 .3561 m .44784 .32891 L .45107 .32566 L p .605 .624 .844 r
F P
0 g
s
.34704 .28947 m .39746 .31023 L .39421 .3158 L p .637 .696 .888 r
F P
0 g
s
.39421 .3158 m .34257 .2971 L .34704 .28947 L p .637 .696 .888 r
F P
0 g
s
.38197 .96005 m .37262 .93159 L .39159 .93957 L p .782 .356 .237 r
F P
0 g
s
.39159 .93957 m .40014 .96682 L .38197 .96005 L p .782 .356 .237 r
F P
0 g
s
.71074 .31551 m .75878 .31619 L .75424 .30735 L p .571 .691 .922 r
F P
0 g
s
.75424 .30735 m .70736 .30814 L .71074 .31551 L p .571 .691 .922 r
F P
0 g
s
.2855 .62309 m .27716 .59571 L .28862 .60464 L p .899 .521 .307 r
F P
0 g
s
.28862 .60464 m .29702 .63114 L .2855 .62309 L p .899 .521 .307 r
F P
0 g
s
.19278 .35738 m .23193 .33309 L .23288 .34728 L p .882 .844 .803 r
F P
0 g
s
.23288 .34728 m .19514 .37356 L .19278 .35738 L p .882 .844 .803 r
F P
0 g
s
.56856 .3553 m .60303 .32793 L .5997 .32458 L p .758 .744 .84 r
F P
0 g
s
.5997 .32458 m .56669 .35351 L .56856 .3553 L p .758 .744 .84 r
F P
0 g
s
.60869 .33491 m .65197 .31057 L .64802 .30511 L p .741 .752 .862 r
F P
0 g
s
.64802 .30511 m .60603 .33138 L .60869 .33491 L p .741 .752 .862 r
F P
0 g
s
.45462 .32257 m .48691 .35257 L .48494 .3543 L p .612 .625 .84 r
F P
0 g
s
.48494 .3543 m .45107 .32566 L .45462 .32257 L p .612 .625 .84 r
F P
0 g
s
.28973 .2888 m .34257 .2971 L .33906 .30513 L p .697 .766 .905 r
F P
0 g
s
.33906 .30513 m .28536 .29905 L .28973 .2888 L p .697 .766 .905 r
F P
0 g
s
.8847 .52746 m .8817 .4878 L .88341 .49448 L p .855 .626 .087 r
F P
0 g
s
.88967 .5402 m .88484 .50008 L .88425 .51307 L p 0 0 .219 r
F P
0 g
s
.88341 .49448 m .88484 .50008 L p .88481 .50595 L .855 .626 .087 r
F P
0 g
s
.88425 .51307 m .89031 .55358 L .89009 .54906 L p 0 0 .219 r
F P
0 g
s
.88796 .53163 m .88425 .51307 L .89009 .54906 L 0 0 .219 r
F
.8847 .52746 m .88341 .49448 L .88481 .50595 L .855 .626 .087 r
F
.89009 .54906 m .88967 .5402 L p .88796 .53163 L 0 0 .219 r
F P
0 g
s
.30643 .66568 m .30598 .6394 L .31276 .64816 L p .982 .703 .408 r
F P
0 g
s
.31276 .64816 m .31307 .67472 L .30643 .66568 L p .982 .703 .408 r
F P
0 g
s
.76726 .74142 m .7757 .78221 L .79954 .78059 L p .628 .428 .592 r
F P
0 g
s
.79954 .78059 m .79185 .73932 L .76726 .74142 L p .628 .428 .592 r
F P
0 g
s
.59919 .9093 m .59693 .94507 L .57891 .95172 L p .536 .263 .448 r
F P
0 g
s
.59693 .94507 m .59919 .9093 L .61676 .90137 L p .535 .273 .464 r
F P
0 g
s
.56669 .35351 m .5997 .32458 L .59606 .32136 L p .755 .737 .836 r
F P
0 g
s
.59606 .32136 m .56465 .3518 L .56669 .35351 L p .755 .737 .836 r
F P
0 g
s
.23065 .56446 m .22403 .52921 L .23933 .54209 L p .879 .542 .407 r
F P
0 g
s
.23933 .54209 m .24783 .57591 L .23065 .56446 L p .879 .542 .407 r
F P
0 g
s
.40573 .29983 m .44784 .32891 L .44496 .33229 L p .608 .645 .862 r
F P
0 g
s
.44496 .33229 m .4013 .30491 L .40573 .29983 L p .608 .645 .862 r
F P
0 g
s
.66362 .83602 m .66786 .88304 L .68531 .87922 L p .592 .401 .592 r
F P
0 g
s
.68531 .87922 m .68072 .83235 L .66362 .83602 L p .592 .401 .592 r
F P
0 g
s
.66362 .83602 m .66786 .88304 L .6508 .88803 L p .581 .394 .594 r
F P
0 g
s
.45848 .31964 m .48904 .35094 L .48691 .35257 L p .618 .627 .837 r
F P
0 g
s
.48691 .35257 m .45462 .32257 L .45848 .31964 L p .618 .627 .837 r
F P
0 g
s
.70895 .78315 m .71813 .82873 L .73864 .82807 L p .644 .454 .612 r
F P
0 g
s
.73864 .82807 m .72989 .78293 L .70895 .78315 L p .644 .454 .612 r
F P
0 g
s
.84709 .39973 m .86718 .43662 L .86083 .42621 L p 0 0 .376 r
F P
0 g
s
.86083 .42621 m .84321 .38937 L .84709 .39973 L p 0 0 .376 r
F P
0 g
s
.65542 .31607 m .70334 .30072 L .6987 .29322 L p .684 .738 .891 r
F P
0 g
s
.6987 .29322 m .65197 .31057 L .65542 .31607 L p .684 .738 .891 r
F P
0 g
s
.83375 .69092 m .83923 .73007 L .86004 .72242 L p .515 .331 .57 r
F P
0 g
s
.86004 .72242 m .85462 .68234 L .83375 .69092 L p .515 .331 .57 r
F P
0 g
s
.56465 .3518 m .59606 .32136 L .59212 .31827 L p .752 .731 .833 r
F P
0 g
s
.59212 .31827 m .56245 .35018 L .56465 .3518 L p .752 .731 .833 r
F P
0 g
s
.86836 .63289 m .87219 .67191 L .88561 .65983 L p .307 .173 .53 r
F P
0 g
s
.88561 .65983 m .88151 .62034 L .86836 .63289 L p .307 .173 .53 r
F P
0 g
s
.76258 .32494 m .80359 .34104 L .79827 .33154 L p .334 .55 .912 r
F P
0 g
s
.79827 .33154 m .75878 .31619 L .76258 .32494 L p .334 .55 .912 r
F P
0 g
s
.46263 .31687 m .49133 .34939 L .48904 .35094 L p .625 .628 .834 r
F P
0 g
s
.48904 .35094 m .45848 .31964 L .46263 .31687 L p .625 .628 .834 r
F P
0 g
s
.60603 .33138 m .64802 .30511 L .64358 .2997 L p .739 .746 .857 r
F P
0 g
s
.64358 .2997 m .60303 .32793 L .60603 .33138 L p .739 .746 .857 r
F P
0 g
s
.35242 .28228 m .4013 .30491 L .39746 .31023 L p .635 .697 .891 r
F P
0 g
s
.39746 .31023 m .34704 .28947 L .35242 .28228 L p .635 .697 .891 r
F P
0 g
s
.23606 .30632 m .28536 .29905 L .28244 .30989 L p .783 .838 .894 r
F P
0 g
s
.28244 .30989 m .23296 .31936 L .23606 .30632 L p .783 .838 .894 r
F P
0 g
s
.56245 .35018 m .59212 .31827 L .58789 .31535 L p .749 .724 .83 r
F P
0 g
s
.58789 .31535 m .56009 .34865 L .56245 .35018 L p .749 .724 .83 r
F P
0 g
s
.41069 .29501 m .45107 .32566 L .44784 .32891 L p .612 .646 .86 r
F P
0 g
s
.44784 .32891 m .40573 .29983 L .41069 .29501 L p .612 .646 .86 r
F P
0 g
s
.46705 .31427 m .49377 .34795 L .49133 .34939 L p .632 .631 .831 r
F P
0 g
s
.49133 .34939 m .46263 .31687 L .46705 .31427 L p .632 .631 .831 r
F P
0 g
s
.31228 .88533 m .31291 .84183 L .32417 .85597 L p .933 .642 .468 r
F P
0 g
s
.32417 .85597 m .32508 .89818 L .31228 .88533 L p .933 .642 .468 r
F P
0 g
s
.30488 .70615 m .31307 .67472 L .31808 .68488 L p .982 .805 .59 r
F P
0 g
s
.31808 .68488 m .31059 .71701 L .30488 .70615 L p .982 .805 .59 r
F P
0 g
s
.61676 .90137 m .61443 .9386 L .59693 .94507 L p .535 .273 .464 r
F P
0 g
s
.61443 .9386 m .61676 .90137 L .63387 .89419 L p .536 .282 .477 r
F P
0 g
s
.56009 .34865 m .58789 .31535 L .58338 .3126 L p .745 .718 .827 r
F P
0 g
s
.58338 .3126 m .55758 .34722 L .56009 .34865 L p .745 .718 .827 r
F P
0 g
s
.36492 .95177 m .35517 .92177 L .37262 .93159 L p .816 .388 .227 r
F P
0 g
s
.37262 .93159 m .38197 .96005 L .36492 .95177 L p .816 .388 .227 r
F P
0 g
s
.79185 .73932 m .79954 .78059 L .82303 .77747 L p .6 .401 .584 r
F P
0 g
s
.82303 .77747 m .81617 .73564 L .79185 .73932 L p .6 .401 .584 r
F P
0 g
s
.47173 .31184 m .49635 .34661 L .49377 .34795 L p .639 .633 .828 r
F P
0 g
s
.49377 .34795 m .46705 .31427 L .47173 .31184 L p .639 .633 .828 r
F P
0 g
s
.70736 .30814 m .75424 .30735 L .74905 .29834 L p .568 .688 .921 r
F P
0 g
s
.74905 .29834 m .70334 .30072 L .70736 .30814 L p .568 .688 .921 r
F P
0 g
s
.72989 .78293 m .73864 .82807 L .76018 .82755 L p .639 .442 .599 r
F P
0 g
s
.76018 .82755 m .75228 .78281 L .72989 .78293 L p .639 .442 .599 r
F P
0 g
s
.60303 .32793 m .64358 .2997 L .63866 .29438 L p .737 .74 .853 r
F P
0 g
s
.63866 .29438 m .5997 .32458 L .60303 .32793 L p .737 .74 .853 r
F P
0 g
s
.17869 .48323 m .18668 .44341 L .19798 .46011 L p .932 .682 .537 r
F P
0 g
s
.19798 .46011 m .19292 .49968 L .17869 .48323 L p .932 .682 .537 r
F P
0 g
s
.55758 .34722 m .58338 .3126 L .57862 .31006 L p .742 .712 .824 r
F P
0 g
s
.57862 .31006 m .55494 .34591 L .55758 .34722 L p .742 .712 .824 r
F P
0 g
s
.29796 .75628 m .31059 .71701 L .31558 .7292 L p .963 .801 .633 r
F P
0 g
s
.31558 .7292 m .30458 .76899 L .29796 .75628 L p .963 .801 .633 r
F P
0 g
s
.68072 .83235 m .68531 .87922 L .70338 .87647 L p .605 .407 .586 r
F P
0 g
s
.70338 .87647 m .69883 .83002 L .68072 .83235 L p .605 .407 .586 r
F P
0 g
s
.17018 .4086 m .19514 .37356 L .19987 .38996 L p .943 .809 .683 r
F P
0 g
s
.19987 .38996 m .17721 .42613 L .17018 .4086 L p .943 .809 .683 r
F P
0 g
s
.47664 .30959 m .49905 .34537 L .49635 .34661 L p .646 .636 .826 r
F P
0 g
s
.49635 .34661 m .47173 .31184 L .47664 .30959 L p .646 .636 .826 r
F P
0 g
s
.65197 .31057 m .6987 .29322 L .69346 .28565 L p .684 .733 .888 r
F P
0 g
s
.69346 .28565 m .64802 .30511 L .65197 .31057 L p .684 .733 .888 r
F P
0 g
s
.29552 .27922 m .34704 .28947 L .34257 .2971 L p .688 .773 .916 r
F P
0 g
s
.34257 .2971 m .28973 .2888 L .29552 .27922 L p .688 .773 .916 r
F P
0 g
s
.27134 .61486 m .26349 .58624 L .27716 .59571 L p .875 .517 .368 r
F P
0 g
s
.27716 .59571 m .2855 .62309 L .27134 .61486 L p .875 .517 .368 r
F P
0 g
s
.88636 .56724 m .89002 .60689 L .89352 .59298 L p 0 0 .335 r
F P
0 g
s
.89352 .59298 m .89031 .55358 L .88636 .56724 L p 0 0 .335 r
F P
0 g
s
.41617 .29044 m .45462 .32257 L .45107 .32566 L p .617 .647 .857 r
F P
0 g
s
.45107 .32566 m .41069 .29501 L .41617 .29044 L p .617 .647 .857 r
F P
0 g
s
.55494 .34591 m .57862 .31006 L .57362 .30775 L p .738 .706 .821 r
F P
0 g
s
.57362 .30775 m .55218 .34471 L .55494 .34591 L p .738 .706 .821 r
F P
0 g
s
.48177 .30753 m .50187 .34426 L .49905 .34537 L p .653 .638 .823 r
F P
0 g
s
.49905 .34537 m .47664 .30959 L .48177 .30753 L p .653 .638 .823 r
F P
0 g
s
.87122 .4478 m .8817 .4878 L .87523 .47642 L p .818 .531 0 r
F P
0 g
s
.80805 .35055 m .83778 .37947 L .8312 .36987 L p 0 .17 .706 r
F P
0 g
s
.8312 .36987 m .80359 .34104 L .80805 .35055 L p 0 .17 .706 r
F P
0 g
s
.55218 .34471 m .57362 .30775 L .56839 .30567 L p .734 .701 .819 r
F P
0 g
s
.56839 .30567 m .54931 .34364 L .55218 .34471 L p .734 .701 .819 r
F P
0 g
s
.29411 .81414 m .30458 .76899 L .31144 .78279 L p .954 .754 .594 r
F P
0 g
s
.31144 .78279 m .30306 .82772 L .29411 .81414 L p .954 .754 .594 r
F P
0 g
s
.35867 .27552 m .40573 .29983 L .4013 .30491 L p .633 .699 .893 r
F P
0 g
s
.4013 .30491 m .35242 .28228 L .35867 .27552 L p .633 .699 .893 r
F P
0 g
s
.5997 .32458 m .63866 .29438 L .63326 .28917 L p .735 .734 .849 r
F P
0 g
s
.63326 .28917 m .59606 .32136 L .5997 .32458 L p .735 .734 .849 r
F P
0 g
s
.48177 .30753 m .50187 .34426 L .5048 .34326 L p .659 .641 .821 r
F P
0 g
s
.54931 .34364 m .56839 .30567 L .56298 .30385 L p .73 .695 .817 r
F P
0 g
s
.56298 .30385 m .54633 .3427 L .54931 .34364 L p .73 .695 .817 r
F P
0 g
s
.21266 .55173 m .20832 .51506 L .22403 .52921 L p .887 .566 .435 r
F P
0 g
s
.22403 .52921 m .23065 .56446 L .21266 .55173 L p .887 .566 .435 r
F P
0 g
s
.29749 .65758 m .29702 .63114 L .30598 .6394 L p .947 .661 .463 r
F P
0 g
s
.30598 .6394 m .30643 .66568 L .29749 .65758 L p .947 .661 .463 r
F P
0 g
s
.48708 .30566 m .5048 .34326 L .50782 .34239 L p .665 .644 .82 r
F P
0 g
s
.5048 .34326 m .48708 .30566 L .48177 .30753 L p .659 .641 .821 r
F P
0 g
s
.19307 .34178 m .23296 .31936 L .23193 .33309 L p .881 .881 .83 r
F P
0 g
s
.23193 .33309 m .19278 .35738 L .19307 .34178 L p .881 .881 .83 r
F P
0 g
s
.63387 .89419 m .63154 .93258 L .61443 .9386 L p .536 .282 .477 r
F P
0 g
s
.63154 .93258 m .63387 .89419 L .6508 .88803 L p .539 .289 .485 r
F P
0 g
s
.42212 .28612 m .45848 .31964 L .45462 .32257 L p .623 .649 .855 r
F P
0 g
s
.45462 .32257 m .41617 .29044 L .42212 .28612 L p .623 .649 .855 r
F P
0 g
s
.54633 .3427 m .56298 .30385 L .55739 .30231 L p .726 .69 .816 r
F P
0 g
s
.55739 .30231 m .54327 .34189 L .54633 .3427 L p .726 .69 .816 r
F P
0 g
s
.49257 .304 m .50782 .34239 L .51092 .34164 L p .671 .647 .818 r
F P
0 g
s
.50782 .34239 m .49257 .304 L .48708 .30566 L p .665 .644 .82 r
F P
0 g
s
.54327 .34189 m .55739 .30231 L .55166 .30105 L p .721 .685 .814 r
F P
0 g
s
.55166 .30105 m .54014 .34122 L .54327 .34189 L p .721 .685 .814 r
F P
0 g
s
.75228 .78281 m .76018 .82755 L .78242 .82665 L p .627 .423 .587 r
F P
0 g
s
.78242 .82665 m .7757 .78221 L .75228 .78281 L p .627 .423 .587 r
F P
0 g
s
.49821 .30255 m .51092 .34164 L .51408 .34103 L p .676 .65 .817 r
F P
0 g
s
.51092 .34164 m .49821 .30255 L .49257 .304 L p .671 .647 .818 r
F P
0 g
s
.54014 .34122 m .55166 .30105 L .54581 .30008 L p .717 .68 .814 r
F P
0 g
s
.54581 .30008 m .53694 .34069 L .54014 .34122 L p .717 .68 .814 r
F P
0 g
s
.59606 .32136 m .63326 .28917 L .6274 .28412 L p .733 .728 .846 r
F P
0 g
s
.6274 .28412 m .59212 .31827 L .59606 .32136 L p .733 .728 .846 r
F P
0 g
s
.69883 .83002 m .70338 .87647 L .72217 .87455 L p .612 .405 .577 r
F P
0 g
s
.72217 .87455 m .71813 .82873 L .69883 .83002 L p .612 .405 .577 r
F P
0 g
s
.64802 .30511 m .69346 .28565 L .68761 .27802 L p .684 .729 .884 r
F P
0 g
s
.68761 .27802 m .64358 .2997 L .64802 .30511 L p .684 .729 .884 r
F P
0 g
s
.85462 .68234 m .86004 .72242 L .87763 .71269 L p .439 .276 .562 r
F P
0 g
s
.87763 .71269 m .87219 .67191 L .85462 .68234 L p .439 .276 .562 r
F P
0 g
s
.50398 .30132 m .51408 .34103 L .5173 .34056 L p .682 .653 .815 r
F P
0 g
s
.51408 .34103 m .50398 .30132 L .49821 .30255 L p .676 .65 .817 r
F P
0 g
s
.53694 .34069 m .54581 .30008 L .53987 .29941 L p .712 .676 .813 r
F P
0 g
s
.53987 .29941 m .5337 .34031 L .53694 .34069 L p .712 .676 .813 r
F P
0 g
s
.75878 .31619 m .79827 .33154 L .7923 .32188 L p .308 .538 .911 r
F P
0 g
s
.7923 .32188 m .75424 .30735 L .75878 .31619 L p .308 .538 .911 r
F P
0 g
s
.50986 .30034 m .5173 .34056 L .52056 .34022 L p .687 .657 .814 r
F P
0 g
s
.5173 .34056 m .50986 .30034 L .50398 .30132 L p .682 .653 .815 r
F P
0 g
s
.5337 .34031 m .53987 .29941 L .53387 .29903 L p .707 .672 .813 r
F P
0 g
s
.53387 .29903 m .53043 .34007 L .5337 .34031 L p .707 .672 .813 r
F P
0 g
s
.51581 .29961 m .52056 .34022 L .52384 .34002 L p .692 .66 .814 r
F P
0 g
s
.52056 .34022 m .51581 .29961 L .50986 .30034 L p .687 .657 .814 r
F P
0 g
s
.53043 .34007 m .53387 .29903 L .52784 .29894 L p .702 .668 .813 r
F P
0 g
s
.52784 .29894 m .52714 .33997 L .53043 .34007 L p .702 .668 .813 r
F P
0 g
s
.52181 .29914 m .52384 .34002 L .52714 .33997 L p .697 .664 .813 r
F P
0 g
s
.52384 .34002 m .52181 .29914 L .51581 .29961 L p .692 .66 .814 r
F P
0 g
s
.52714 .33997 m .52784 .29894 L .52181 .29914 L p .697 .664 .813 r
F P
0 g
s
.3491 .94227 m .33932 .91049 L .35517 .92177 L p .847 .424 .225 r
F P
0 g
s
.35517 .92177 m .36492 .95177 L .3491 .94227 L p .847 .424 .225 r
F P
0 g
s
.81617 .73564 m .82303 .77747 L .84531 .77249 L p .56 .367 .576 r
F P
0 g
s
.84531 .77249 m .83923 .73007 L .81617 .73564 L p .56 .367 .576 r
F P
0 g
s
.42852 .28205 m .46263 .31687 L .45848 .31964 L p .629 .65 .852 r
F P
0 g
s
.45848 .31964 m .42212 .28612 L .42852 .28205 L p .629 .65 .852 r
F P
0 g
s
.24124 .29416 m .28973 .2888 L .28536 .29905 L p .769 .858 .916 r
F P
0 g
s
.28536 .29905 m .23606 .30632 L .24124 .29416 L p .769 .858 .916 r
F P
0 g
s
.70334 .30072 m .74905 .29834 L .74325 .28907 L p .567 .685 .92 r
F P
0 g
s
.74325 .28907 m .6987 .29322 L .70334 .30072 L p .567 .685 .92 r
F P
0 g
s
.36572 .2692 m .41069 .29501 L .40573 .29983 L p .633 .7 .894 r
F P
0 g
s
.40573 .29983 m .35867 .27552 L .36572 .2692 L p .633 .7 .894 r
F P
0 g
s
.59212 .31827 m .6274 .28412 L .62107 .27928 L p .731 .722 .842 r
F P
0 g
s
.62107 .27928 m .58789 .31535 L .59212 .31827 L p .731 .722 .842 r
F P
0 g
s
.30265 .27036 m .35242 .28228 L .34704 .28947 L p .678 .779 .926 r
F P
0 g
s
.34704 .28947 m .29552 .27922 L .30265 .27036 L p .678 .779 .926 r
F P
0 g
s
.25477 .60606 m .24783 .57591 L .26349 .58624 L p .862 .522 .408 r
F P
0 g
s
.26349 .58624 m .27134 .61486 L .25477 .60606 L p .862 .522 .408 r
F P
0 g
s
.88151 .62034 m .88561 .65983 L .89423 .64646 L p .101 .029 .48 r
F P
0 g
s
.89423 .64646 m .89002 .60689 L .88151 .62034 L p .101 .029 .48 r
F P
0 g
s
.88484 .50008 m .88967 .5402 L .8847 .52746 L p .855 .626 .087 r
F P
0 g
s
.6508 .88803 m .64843 .92721 L .63154 .93258 L p .539 .289 .485 r
F P
0 g
s
.64843 .92721 m .6508 .88803 L .66786 .88304 L p .542 .293 .488 r
F P
0 g
s
.30068 .8724 m .30306 .82772 L .31291 .84183 L p .944 .67 .487 r
F P
0 g
s
.31291 .84183 m .31228 .88533 L .30068 .8724 L p .944 .67 .487 r
F P
0 g
s
.43533 .2782 m .46705 .31427 L .46263 .31687 L p .636 .653 .85 r
F P
0 g
s
.46263 .31687 m .42852 .28205 L .43533 .2782 L p .636 .653 .85 r
F P
0 g
s
.29767 .69665 m .30643 .66568 L .31307 .67472 L p .955 .772 .616 r
F P
0 g
s
.31307 .67472 m .30488 .70615 L .29767 .69665 L p .955 .772 .616 r
F P
0 g
s
.84321 .38937 m .86083 .42621 L .85272 .41649 L p .757 .385 0 r
F P
0 g
s
.64358 .2997 m .68761 .27802 L .68116 .27036 L p .684 .725 .881 r
F P
0 g
s
.68116 .27036 m .63866 .29438 L .64358 .2997 L p .684 .725 .881 r
F P
0 g
s
.58789 .31535 m .62107 .27928 L .6143 .27469 L p .729 .717 .839 r
F P
0 g
s
.6143 .27469 m .58338 .3126 L .58789 .31535 L p .729 .717 .839 r
F P
0 g
s
.7757 .78221 m .78242 .82665 L .80484 .82486 L p .605 .398 .574 r
F P
0 g
s
.80484 .82486 m .79954 .78059 L .7757 .78221 L p .605 .398 .574 r
F P
0 g
s
.16647 .46596 m .17721 .42613 L .18668 .44341 L p .952 .723 .554 r
F P
0 g
s
.18668 .44341 m .17869 .48323 L .16647 .46596 L p .952 .723 .554 r
F P
0 g
s
.71813 .82873 m .72217 .87455 L .74168 .87314 L p .613 .398 .565 r
F P
0 g
s
.74168 .87314 m .73864 .82807 L .71813 .82873 L p .613 .398 .565 r
F P
0 g
s
.29082 .7449 m .30488 .70615 L .31059 .71701 L p .947 .791 .655 r
F P
0 g
s
.31059 .71701 m .29796 .75628 L .29082 .7449 L p .947 .791 .655 r
F P
0 g
s
.44251 .27457 m .47173 .31184 L .46705 .31427 L p .643 .655 .847 r
F P
0 g
s
.46705 .31427 m .43533 .2782 L .44251 .27457 L p .643 .655 .847 r
F P
0 g
s
.37349 .26328 m .41617 .29044 L .41069 .29501 L p .634 .702 .894 r
F P
0 g
s
.41069 .29501 m .36572 .2692 L .37349 .26328 L p .634 .702 .894 r
F P
0 g
s
.28586 .65011 m .2855 .62309 L .29702 .63114 L p .904 .619 .494 r
F P
0 g
s
.29702 .63114 m .29749 .65758 L .28586 .65011 L p .904 .619 .494 r
F P
0 g
s
.16613 .39125 m .19278 .35738 L .19514 .37356 L p .955 .859 .706 r
F P
0 g
s
.19514 .37356 m .17018 .4086 L .16613 .39125 L p .955 .859 .706 r
F P
0 g
s
.19477 .53765 m .19292 .49968 L .20832 .51506 L p .902 .595 .457 r
F P
0 g
s
.20832 .51506 m .21266 .55173 L .19477 .53765 L p .902 .595 .457 r
F P
0 g
s
.58338 .3126 m .6143 .27469 L .6071 .27041 L p .727 .712 .837 r
F P
0 g
s
.6071 .27041 m .57862 .31006 L .58338 .3126 L p .727 .712 .837 r
F P
0 g
s
.6987 .29322 m .74325 .28907 L .73687 .27952 L p .568 .683 .918 r
F P
0 g
s
.73687 .27952 m .69346 .28565 L .6987 .29322 L p .568 .683 .918 r
F P
0 g
s
.28551 .80149 m .29796 .75628 L .30458 .76899 L p .949 .762 .616 r
F P
0 g
s
.30458 .76899 m .29411 .81414 L .28551 .80149 L p .949 .762 .616 r
F P
0 g
s
.48022 .97557 m .50081 .97319 L p .48583 .98565 L .401 0 0 r
F P
0 g
s
.50081 .97319 m .50356 .9847 L .48531 .98608 L p .401 0 0 r
F P
0 g
s
.50081 .97319 m .52113 .9693 L p .5043 .98405 L .393 0 0 r
F P
0 g
s
.50356 .9847 m .50343 .98416 L p .5043 .98405 L .393 0 0 r
F P
0 g
s
.50343 .98416 m .50081 .97319 L p .5043 .98405 L .393 0 0 r
F P
0 g
s
.52113 .9693 m .52167 .98217 L .50356 .9847 L p .393 0 0 r
F P
0 g
s
.52167 .98217 m .52113 .9693 L .54099 .9642 L p .387 0 0 r
F P
0 g
s
.52242 .97548 m .50731 .97683 L p .5209 .98189 L .342 .807 .927 r
F P
0 g
s
.52167 .98217 m .52171 .98178 L p .5209 .98189 L .342 .807 .927 r
F P
0 g
s
.52171 .98178 m .52242 .97548 L p .5209 .98189 L .342 .807 .927 r
F P
0 g
s
.50731 .97683 m .49216 .9774 L p .50308 .98439 L .348 .8 .948 r
F P
0 g
s
.50356 .9847 m .50373 .98434 L p .50308 .98439 L .348 .8 .948 r
F P
0 g
s
.50373 .98434 m .50731 .97683 L p .50308 .98439 L .348 .8 .948 r
F P
0 g
s
.48531 .98608 m .48513 .98571 L p .48583 .98565 L .401 0 0 r
F P
0 g
s
.48513 .98571 m .48022 .97557 L p .48583 .98565 L .401 0 0 r
F P
0 g
s
.45003 .27116 m .47664 .30959 L .47173 .31184 L p .65 .658 .844 r
F P
0 g
s
.47173 .31184 m .44251 .27457 L .45003 .27116 L p .65 .658 .844 r
F P
0 g
s
.80359 .34104 m .8312 .36987 L .82387 .36034 L p 0 .082 .634 r
F P
0 g
s
.82387 .36034 m .79827 .33154 L .80359 .34104 L p 0 .082 .634 r
F P
0 g
s
.45959 .97622 m .48022 .97557 L p .46738 .98595 L .414 0 0 r
F P
0 g
s
.48022 .97557 m .48531 .98608 L .46709 .98618 L p .414 0 0 r
F P
0 g
s
.49216 .9774 m .47708 .97708 L p .48508 .98583 L .35 .788 .963 r
F P
0 g
s
.48531 .98608 m .48551 .98583 L p .48508 .98583 L .35 .788 .963 r
F P
0 g
s
.48551 .98583 m .49216 .9774 L p .48508 .98583 L .35 .788 .963 r
F P
0 g
s
.46709 .98618 m .46691 .98595 L p .46738 .98595 L .414 0 0 r
F P
0 g
s
.46691 .98595 m .45959 .97622 L p .46738 .98595 L .414 0 0 r
F P
0 g
s
.66786 .88304 m .66528 .92262 L .68226 .91882 L p .55 .298 .487 r
F P
0 g
s
.68226 .91882 m .68531 .87922 L .66786 .88304 L p .55 .298 .487 r
F P
0 g
s
.66786 .88304 m .66528 .92262 L .64843 .92721 L p .542 .293 .488 r
F P
0 g
s
.63866 .29438 m .68116 .27036 L .67408 .26272 L p .684 .721 .877 r
F P
0 g
s
.67408 .26272 m .63326 .28917 L .63866 .29438 L p .684 .721 .877 r
F P
0 g
s
.19617 .32707 m .23606 .30632 L .23296 .31936 L p .872 .922 .857 r
F P
0 g
s
.23296 .31936 m .19307 .34178 L .19617 .32707 L p .872 .922 .857 r
F P
0 g
s
.57862 .31006 m .6071 .27041 L .59949 .26649 L p .725 .708 .834 r
F P
0 g
s
.59949 .26649 m .57362 .30775 L .57862 .31006 L p .725 .708 .834 r
F P
0 g
s
.33449 .93187 m .32508 .89818 L .33932 .91049 L p .874 .46 .232 r
F P
0 g
s
.33932 .91049 m .3491 .94227 L .33449 .93187 L p .874 .46 .232 r
F P
0 g
s
.31101 .26222 m .35867 .27552 L .35242 .28228 L p .668 .784 .935 r
F P
0 g
s
.35242 .28228 m .30265 .27036 L .31101 .26222 L p .668 .784 .935 r
F P
0 g
s
.75424 .30735 m .7923 .32188 L .78583 .31189 L p .29 .529 .909 r
F P
0 g
s
.78583 .31189 m .74905 .29834 L .75424 .30735 L p .29 .529 .909 r
F P
0 g
s
.54099 .9642 m .53952 .9787 L .52167 .98217 L p .387 0 0 r
F P
0 g
s
.53952 .9787 m .54099 .9642 L .56027 .95822 L p .386 0 .042 r
F P
0 g
s
.83923 .73007 m .84531 .77249 L .86547 .76543 L p .505 .322 .567 r
F P
0 g
s
.86547 .76543 m .86004 .72242 L .83923 .73007 L p .505 .322 .567 r
F P
0 g
s
.45787 .26797 m .48177 .30753 L .47664 .30959 L p .657 .661 .842 r
F P
0 g
s
.47664 .30959 m .45003 .27116 L .45787 .26797 L p .657 .661 .842 r
F P
0 g
s
.89031 .55358 m .89352 .59298 L .89199 .57905 L p 0 0 .052 r
F P
0 g
s
.89199 .57905 m .88967 .5402 L .89031 .55358 L p 0 0 .052 r
F P
0 g
s
.24844 .28301 m .29552 .27922 L .28973 .2888 L p .751 .877 .937 r
F P
0 g
s
.28973 .2888 m .24124 .29416 L .24844 .28301 L p .751 .877 .937 r
F P
0 g
s
.44906 .9849 m .43918 .97499 L .45959 .97622 L p .428 0 0 r
F P
0 g
s
.45959 .97622 m .46709 .98618 L .44906 .9849 L p .428 0 0 r
F P
0 g
s
.38191 .25773 m .42212 .28612 L .41617 .29044 L p .637 .703 .894 r
F P
0 g
s
.41617 .29044 m .37349 .26328 L .38191 .25773 L p .637 .703 .894 r
F P
0 g
s
.23631 .59633 m .23065 .56446 L .24783 .57591 L p .86 .535 .436 r
F P
0 g
s
.24783 .57591 m .25477 .60606 L .23631 .59633 L p .86 .535 .436 r
F P
0 g
s
.57362 .30775 m .59949 .26649 L .59151 .26299 L p .722 .704 .832 r
F P
0 g
s
.59151 .26299 m .56839 .30567 L .57362 .30775 L p .722 .704 .832 r
F P
0 g
s
.73864 .82807 m .74168 .87314 L .76178 .87184 L p .606 .383 .551 r
F P
0 g
s
.76178 .87184 m .76018 .82755 L .73864 .82807 L p .606 .383 .551 r
F P
0 g
s
.87219 .67191 m .87763 .71269 L .89117 .70102 L p .321 .192 .545 r
F P
0 g
s
.89117 .70102 m .88561 .65983 L .87219 .67191 L p .321 .192 .545 r
F P
0 g
s
.86718 .43662 m .87523 .47642 L .86608 .46601 L p .951 .647 .21 r
F P
0 g
s
.86608 .46601 m .86083 .42621 L .86718 .43662 L p .951 .647 .21 r
F P
0 g
s
.56027 .95822 m .55701 .97452 L .53952 .9787 L p .386 0 .042 r
F P
0 g
s
.55701 .97452 m .56027 .95822 L .57891 .95172 L p .388 0 .088 r
F P
0 g
s
.45787 .26797 m .48177 .30753 L .48708 .30566 L p .664 .663 .84 r
F P
0 g
s
.79954 .78059 m .80484 .82486 L .82683 .82174 L p .575 .367 .561 r
F P
0 g
s
.82683 .82174 m .82303 .77747 L .79954 .78059 L p .575 .367 .561 r
F P
0 g
s
.56839 .30567 m .59151 .26299 L .58318 .25995 L p .72 .7 .831 r
F P
0 g
s
.58318 .25995 m .56298 .30385 L .56839 .30567 L p .72 .7 .831 r
F P
0 g
s
.63326 .28917 m .67408 .26272 L .66635 .25517 L p .685 .718 .874 r
F P
0 g
s
.66635 .25517 m .6274 .28412 L .63326 .28917 L p .685 .718 .874 r
F P
0 g
s
.28832 .68839 m .29749 .65758 L .30643 .66568 L p .92 .729 .628 r
F P
0 g
s
.30643 .66568 m .29767 .69665 L .28832 .68839 L p .92 .729 .628 r
F P
0 g
s
.43142 .9822 m .41928 .97184 L .43918 .97499 L p .445 0 0 r
F P
0 g
s
.43918 .97499 m .44906 .9849 L .43142 .9822 L p .445 0 0 r
F P
0 g
s
.46601 .265 m .48708 .30566 L .49257 .304 L p .669 .666 .838 r
F P
0 g
s
.48708 .30566 m .46601 .265 L .45787 .26797 L p .664 .663 .84 r
F P
0 g
s
.56298 .30385 m .58318 .25995 L .57455 .25741 L p .717 .696 .829 r
F P
0 g
s
.57455 .25741 m .55739 .30231 L .56298 .30385 L p .717 .696 .829 r
F P
0 g
s
.28993 .8598 m .29411 .81414 L .30306 .82772 L p .95 .691 .51 r
F P
0 g
s
.30306 .82772 m .30068 .8724 L .28993 .8598 L p .95 .691 .51 r
F P
0 g
s
.68531 .87922 m .68226 .91882 L .69949 .91573 L p .56 .302 .481 r
F P
0 g
s
.69949 .91573 m .70338 .87647 L .68531 .87922 L p .56 .302 .481 r
F P
0 g
s
.57891 .95172 m .5741 .96987 L .55701 .97452 L p .388 0 .088 r
F P
0 g
s
.5741 .96987 m .57891 .95172 L .59693 .94507 L p .393 0 .128 r
F P
0 g
s
.27144 .64285 m .27134 .61486 L .2855 .62309 L p .872 .592 .511 r
F P
0 g
s
.2855 .62309 m .28586 .65011 L .27144 .64285 L p .872 .592 .511 r
F P
0 g
s
.69346 .28565 m .73687 .27952 L .72988 .26966 L p .571 .682 .915 r
F P
0 g
s
.72988 .26966 m .68761 .27802 L .69346 .28565 L p .571 .682 .915 r
F P
0 g
s
.39092 .2525 m .42852 .28205 L .42212 .28612 L p .641 .705 .894 r
F P
0 g
s
.42212 .28612 m .38191 .25773 L .39092 .2525 L p .641 .705 .894 r
F P
0 g
s
.4744 .26227 m .49257 .304 L .49821 .30255 L p .675 .668 .836 r
F P
0 g
s
.49257 .304 m .4744 .26227 L .46601 .265 L p .669 .666 .838 r
F P
0 g
s
.55739 .30231 m .57455 .25741 L .56567 .25539 L p .714 .693 .829 r
F P
0 g
s
.56567 .25539 m .55166 .30105 L .55739 .30231 L p .714 .693 .829 r
F P
0 g
s
.32047 .25478 m .36572 .2692 L .35867 .27552 L p .659 .789 .943 r
F P
0 g
s
.35867 .27552 m .31101 .26222 L .32047 .25478 L p .659 .789 .943 r
F P
0 g
s
.48304 .25981 m .49821 .30255 L .50398 .30132 L p .68 .671 .834 r
F P
0 g
s
.49821 .30255 m .48304 .25981 L .4744 .26227 L p .675 .668 .836 r
F P
0 g
s
.28249 .73496 m .29767 .69665 L .30488 .70615 L p .926 .77 .668 r
F P
0 g
s
.30488 .70615 m .29082 .7449 L .28249 .73496 L p .926 .77 .668 r
F P
0 g
s
.55166 .30105 m .56567 .25539 L .55659 .25391 L p .711 .69 .828 r
F P
0 g
s
.55659 .25391 m .54581 .30008 L .55166 .30105 L p .711 .69 .828 r
F P
0 g
s
.178 .52231 m .17869 .48323 L .19292 .49968 L p .923 .631 .472 r
F P
0 g
s
.19292 .49968 m .19477 .53765 L .178 .52231 L p .923 .631 .472 r
F P
0 g
s
.1571 .44826 m .17018 .4086 L .17721 .42613 L p .975 .772 .566 r
F P
0 g
s
.17721 .42613 m .16647 .46596 L .1571 .44826 L p .975 .772 .566 r
F P
0 g
s
.6274 .28412 m .66635 .25517 L .65797 .24782 L p .686 .715 .871 r
F P
0 g
s
.65797 .24782 m .62107 .27928 L .6274 .28412 L p .686 .715 .871 r
F P
0 g
s
.41431 .97811 m .40014 .96682 L .41928 .97184 L p .464 0 0 r
F P
0 g
s
.41928 .97184 m .43142 .9822 L .41431 .97811 L p .464 0 0 r
F P
0 g
s
.49188 .25764 m .50398 .30132 L .50986 .30034 L p .684 .673 .833 r
F P
0 g
s
.50398 .30132 m .49188 .25764 L .48304 .25981 L p .68 .671 .834 r
F P
0 g
s
.89002 .60689 m .89423 .64646 L .89765 .63221 L p 0 0 .344 r
F P
0 g
s
.89765 .63221 m .89352 .59298 L .89002 .60689 L p 0 0 .344 r
F P
0 g
s
.83778 .37947 m .85272 .41649 L .84348 .40727 L p .873 .499 .017 r
F P
0 g
s
.84348 .40727 m .8312 .36987 L .83778 .37947 L p .873 .499 .017 r
F P
0 g
s
.54581 .30008 m .55659 .25391 L .54737 .25297 L p .708 .687 .828 r
F P
0 g
s
.54737 .25297 m .53987 .29941 L .54581 .30008 L p .708 .687 .828 r
F P
0 g
s
.76018 .82755 m .76178 .87184 L .78221 .87022 L p .591 .36 .535 r
F P
0 g
s
.78221 .87022 m .78242 .82665 L .76018 .82755 L p .591 .36 .535 r
F P
0 g
s
.59693 .94507 m .59077 .96499 L .5741 .96987 L p .393 0 .128 r
F P
0 g
s
.59077 .96499 m .59693 .94507 L .61443 .9386 L p .399 0 .16 r
F P
0 g
s
.50091 .2558 m .50986 .30034 L .51581 .29961 L p .689 .675 .831 r
F P
0 g
s
.50986 .30034 m .50091 .2558 L .49188 .25764 L p .684 .673 .833 r
F P
0 g
s
.53987 .29941 m .54737 .25297 L .53805 .25257 L p .705 .685 .828 r
F P
0 g
s
.53805 .25257 m .53387 .29903 L .53987 .29941 L p .705 .685 .828 r
F P
0 g
s
.32102 .92094 m .31228 .88533 L .32508 .89818 L p .896 .497 .248 r
F P
0 g
s
.32508 .89818 m .33449 .93187 L .32102 .92094 L p .896 .497 .248 r
F P
0 g
s
.51008 .25434 m .51581 .29961 L .52181 .29914 L p .693 .678 .83 r
F P
0 g
s
.51581 .29961 m .51008 .25434 L .50091 .2558 L p .689 .675 .831 r
F P
0 g
s
.74905 .29834 m .78583 .31189 L .77896 .30142 L p .281 .524 .908 r
F P
0 g
s
.77896 .30142 m .74325 .28907 L .74905 .29834 L p .281 .524 .908 r
F P
0 g
s
.53387 .29903 m .53805 .25257 L .52869 .25268 L p .701 .682 .829 r
F P
0 g
s
.52869 .25268 m .52784 .29894 L .53387 .29903 L p .701 .682 .829 r
F P
0 g
s
.51936 .25328 m .52181 .29914 L .52784 .29894 L p .697 .68 .829 r
F P
0 g
s
.52181 .29914 m .51936 .25328 L .51008 .25434 L p .693 .678 .83 r
F P
0 g
s
.52784 .29894 m .52869 .25268 L .51936 .25328 L p .697 .68 .829 r
F P
0 g
s
.16548 .3745 m .19307 .34178 L .19278 .35738 L p .959 .915 .724 r
F P
0 g
s
.19278 .35738 m .16613 .39125 L .16548 .3745 L p .959 .915 .724 r
F P
0 g
s
.27668 .79002 m .29082 .7449 L .29796 .75628 L p .938 .76 .634 r
F P
0 g
s
.29796 .75628 m .28551 .80149 L .27668 .79002 L p .938 .76 .634 r
F P
0 g
s
.40045 .24753 m .43533 .2782 L .42852 .28205 L p .646 .708 .892 r
F P
0 g
s
.42852 .28205 m .39092 .2525 L .40045 .24753 L p .646 .708 .892 r
F P
0 g
s
.8817 .4878 m .8847 .52746 L .87593 .51564 L p .98 .718 .32 r
F P
0 g
s
.87593 .51564 m .87523 .47642 L .8817 .4878 L p .98 .718 .32 r
F P
0 g
s
.21677 .58539 m .21266 .55173 L .23065 .56446 L p .868 .555 .455 r
F P
0 g
s
.23065 .56446 m .23631 .59633 L .21677 .58539 L p .868 .555 .455 r
F P
0 g
s
.25752 .27297 m .30265 .27036 L .29552 .27922 L p .725 .895 .956 r
F P
0 g
s
.29552 .27922 m .24844 .28301 L .25752 .27297 L p .725 .895 .956 r
F P
0 g
s
.79827 .33154 m .82387 .36034 L .81614 .35062 L p 0 .009 .565 r
F P
0 g
s
.81614 .35062 m .7923 .32188 L .79827 .33154 L p 0 .009 .565 r
F P
0 g
s
.70338 .87647 m .69949 .91573 L .71702 .91321 L p .564 .298 .471 r
F P
0 g
s
.71702 .91321 m .72217 .87455 L .70338 .87647 L p .564 .298 .471 r
F P
0 g
s
.20212 .31355 m .24124 .29416 L .23606 .30632 L p .847 .962 .881 r
F P
0 g
s
.23606 .30632 m .19617 .32707 L .20212 .31355 L p .847 .962 .881 r
F P
0 g
s
.86004 .72242 m .86547 .76543 L .88265 .7562 L p .427 .263 .554 r
F P
0 g
s
.88265 .7562 m .87763 .71269 L .86004 .72242 L p .427 .263 .554 r
F P
0 g
s
.62107 .27928 m .65797 .24782 L .64892 .24077 L p .686 .713 .869 r
F P
0 g
s
.64892 .24077 m .6143 .27469 L .62107 .27928 L p .686 .713 .869 r
F P
0 g
s
.82303 .77747 m .82683 .82174 L .84765 .81692 L p .532 .326 .547 r
F P
0 g
s
.84765 .81692 m .84531 .77249 L .82303 .77747 L p .532 .326 .547 r
F P
0 g
s
.68761 .27802 m .72988 .26966 L .72225 .25952 L p .574 .682 .913 r
F P
0 g
s
.72225 .25952 m .68116 .27036 L .68761 .27802 L p .574 .682 .913 r
F P
0 g
s
.61443 .9386 m .60707 .9601 L .59077 .96499 L p .399 0 .16 r
F P
0 g
s
.60707 .9601 m .61443 .9386 L .63154 .93258 L p .406 .017 .184 r
F P
0 g
s
.3979 .97273 m .38197 .96005 L .40014 .96682 L p .484 0 0 r
F P
0 g
s
.40014 .96682 m .41431 .97811 L .3979 .97273 L p .484 0 0 r
F P
0 g
s
.27647 .68108 m .28586 .65011 L .29749 .65758 L p .889 .69 .627 r
F P
0 g
s
.29749 .65758 m .28832 .68839 L .27647 .68108 L p .889 .69 .627 r
F P
0 g
s
.25447 .63535 m .25477 .60606 L .27134 .61486 L p .856 .58 .52 r
F P
0 g
s
.27134 .61486 m .27144 .64285 L .25447 .63535 L p .856 .58 .52 r
F P
0 g
s
.41044 .24278 m .44251 .27457 L .43533 .2782 L p .652 .71 .89 r
F P
0 g
s
.43533 .2782 m .40045 .24753 L .41044 .24278 L p .652 .71 .89 r
F P
0 g
s
.33088 .24796 m .37349 .26328 L .36572 .2692 L p .652 .793 .95 r
F P
0 g
s
.36572 .2692 m .32047 .25478 L .33088 .24796 L p .652 .793 .95 r
F P
0 g
s
.6143 .27469 m .64892 .24077 L .6392 .23413 L p .687 .712 .867 r
F P
0 g
s
.6392 .23413 m .6071 .27041 L .6143 .27469 L p .687 .712 .867 r
F P
0 g
s
.88561 .65983 m .89117 .70102 L .90001 .68769 L p .123 .058 .504 r
F P
0 g
s
.90001 .68769 m .89423 .64646 L .88561 .65983 L p .123 .058 .504 r
F P
0 g
s
.27964 .8479 m .28551 .80149 L .29411 .81414 L p .95 .705 .534 r
F P
0 g
s
.29411 .81414 m .28993 .8598 L .27964 .8479 L p .95 .705 .534 r
F P
0 g
s
.78242 .82665 m .78221 .87022 L .80257 .86786 L p .566 .33 .516 r
F P
0 g
s
.80257 .86786 m .80484 .82486 L .78242 .82665 L p .566 .33 .516 r
F P
0 g
s
.88967 .5402 m .89199 .57905 L .8857 .56556 L p .95 .704 .243 r
F P
0 g
s
.8857 .56556 m .8847 .52746 L .88967 .5402 L p .95 .704 .243 r
F P
0 g
s
.27244 .72636 m .28832 .68839 L .29767 .69665 L p .905 .744 .672 r
F P
0 g
s
.29767 .69665 m .28249 .73496 L .27244 .72636 L p .905 .744 .672 r
F P
0 g
s
.63154 .93258 m .62305 .95539 L .60707 .9601 L p .406 .017 .184 r
F P
0 g
s
.62305 .95539 m .63154 .93258 L .64843 .92721 L p .411 .028 .199 r
F P
0 g
s
.42086 .23821 m .45003 .27116 L .44251 .27457 L p .659 .713 .888 r
F P
0 g
s
.44251 .27457 m .41044 .24278 L .42086 .23821 L p .659 .713 .888 r
F P
0 g
s
.86083 .42621 m .86608 .46601 L .85501 .45651 L p .981 .691 .355 r
F P
0 g
s
.85501 .45651 m .85272 .41649 L .86083 .42621 L p .981 .691 .355 r
F P
0 g
s
.72217 .87455 m .71702 .91321 L .73484 .911 L p .561 .286 .456 r
F P
0 g
s
.73484 .911 m .74168 .87314 L .72217 .87455 L p .561 .286 .456 r
F P
0 g
s
.68116 .27036 m .72225 .25952 L .71391 .24919 L p .579 .682 .911 r
F P
0 g
s
.71391 .24919 m .67408 .26272 L .68116 .27036 L p .579 .682 .911 r
F P
0 g
s
.74325 .28907 m .77896 .30142 L .77172 .29035 L p .282 .524 .907 r
F P
0 g
s
.77172 .29035 m .73687 .27952 L .74325 .28907 L p .282 .524 .907 r
F P
0 g
s
.6071 .27041 m .6392 .23413 L .62883 .22803 L p .688 .711 .866 r
F P
0 g
s
.62883 .22803 m .59949 .26649 L .6071 .27041 L p .688 .711 .866 r
F P
0 g
s
.38229 .9662 m .36492 .95177 L .38197 .96005 L p .506 0 0 r
F P
0 g
s
.38197 .96005 m .3979 .97273 L .38229 .9662 L p .506 0 0 r
F P
0 g
s
.30854 .90983 m .30068 .8724 L .31228 .88533 L p .914 .531 .273 r
F P
0 g
s
.31228 .88533 m .32102 .92094 L .30854 .90983 L p .914 .531 .273 r
F P
0 g
s
.1634 .50593 m .16647 .46596 L .17869 .48323 L p .949 .673 .48 r
F P
0 g
s
.17869 .48323 m .178 .52231 L .1634 .50593 L p .949 .673 .48 r
F P
0 g
s
.19717 .57308 m .19477 .53765 L .21266 .55173 L p .884 .581 .468 r
F P
0 g
s
.21266 .55173 m .21677 .58539 L .19717 .57308 L p .884 .581 .468 r
F P
0 g
s
.26827 .26402 m .31101 .26222 L .30265 .27036 L p .692 .908 .971 r
F P
0 g
s
.30265 .27036 m .25752 .27297 L .26827 .26402 L p .692 .908 .971 r
F P
0 g
s
.34209 .24165 m .38191 .25773 L .37349 .26328 L p .647 .797 .955 r
F P
0 g
s
.37349 .26328 m .33088 .24796 L .34209 .24165 L p .647 .797 .955 r
F P
0 g
s
.26707 .77988 m .28249 .73496 L .29082 .7449 L p .925 .751 .647 r
F P
0 g
s
.29082 .7449 m .27668 .79002 L .26707 .77988 L p .925 .751 .647 r
F P
0 g
s
.43167 .2338 m .45787 .26797 L .45003 .27116 L p .667 .716 .885 r
F P
0 g
s
.45003 .27116 m .42086 .23821 L .43167 .2338 L p .667 .716 .885 r
F P
0 g
s
.15131 .43058 m .16613 .39125 L .17018 .4086 L p .994 .829 .569 r
F P
0 g
s
.17018 .4086 m .1571 .44826 L .15131 .43058 L p .994 .829 .569 r
F P
0 g
s
.23549 .62719 m .23631 .59633 L .25477 .60606 L p .853 .58 .525 r
F P
0 g
s
.25477 .60606 m .25447 .63535 L .23549 .62719 L p .853 .58 .525 r
F P
0 g
s
.26202 .67432 m .27144 .64285 L .28586 .65011 L p .867 .661 .621 r
F P
0 g
s
.28586 .65011 m .27647 .68108 L .26202 .67432 L p .867 .661 .621 r
F P
0 g
s
.59949 .26649 m .62883 .22803 L .61785 .22258 L p .689 .711 .865 r
F P
0 g
s
.61785 .22258 m .59151 .26299 L .59949 .26649 L p .689 .711 .865 r
F P
0 g
s
.8312 .36987 m .84348 .40727 L .83371 .39825 L p .927 .566 .142 r
F P
0 g
s
.83371 .39825 m .82387 .36034 L .8312 .36987 L p .927 .566 .142 r
F P
0 g
s
.7923 .32188 m .81596 .35041 L p .80828 .34044 L 0 0 .516 r
F P
0 g
s
.80828 .34044 m .78583 .31189 L .7923 .32188 L p 0 0 .516 r
F P
0 g
s
.78583 .31189 m .80794 .34001 L p .80046 .32954 L 0 0 .492 r
F P
0 g
s
.80794 .34001 m .80828 .34044 L .80046 .32954 L p 0 0 .492 r
F P
0 g
s
.80046 .32954 m .77896 .30142 L .78583 .31189 L p 0 0 .492 r
F P
0 g
s
.77896 .30142 m .8001 .32907 L p .79273 .3177 L 0 0 .496 r
F P
0 g
s
.8001 .32907 m .80046 .32954 L .79273 .3177 L p 0 0 .496 r
F P
0 g
s
.79273 .3177 m .77172 .29035 L .77896 .30142 L p 0 0 .496 r
F P
0 g
s
.77172 .29035 m .7925 .3174 L p .78502 .30479 L 0 0 .522 r
F P
0 g
s
.7925 .3174 m .79273 .3177 L .78502 .30479 L p 0 0 .522 r
F P
0 g
s
.78502 .30479 m .76407 .27863 L .77172 .29035 L p 0 0 .522 r
F P
0 g
s
.76407 .27863 m .78502 .30479 L .77713 .29077 L p 0 .007 .564 r
F P
0 g
s
.78412 .3288 m .77732 .29182 L p .78502 .30479 L .941 .6 .177 r
F P
0 g
s
.77732 .29182 m .77713 .29077 L .78502 .30479 L p .941 .6 .177 r
F P
0 g
s
.79098 .34365 m .78522 .30611 L p .79273 .3177 L .957 .627 .231 r
F P
0 g
s
.78522 .30611 m .78502 .30479 L .79273 .3177 L p .957 .627 .231 r
F P
0 g
s
.79818 .35694 m .79291 .31896 L p .80046 .32954 L .964 .639 .265 r
F P
0 g
s
.79291 .31896 m .79273 .3177 L .80046 .32954 L p .964 .639 .265 r
F P
0 g
s
.80603 .36877 m .80059 .33047 L p .80828 .34044 L .965 .638 .276 r
F P
0 g
s
.80059 .33047 m .80046 .32954 L .80828 .34044 L p .965 .638 .276 r
F P
0 g
s
.81596 .35041 m .81614 .35062 L .80828 .34044 L p 0 0 .516 r
F P
0 g
s
.65437 .94699 m .63879 .95099 L p .63926 .95048 L .414 .033 .204 r
F P
0 g
s
.66528 .92262 m .65437 .94699 L p .63926 .95048 L .414 .033 .204 r
F P
0 g
s
.66528 .92262 m .65437 .94699 L .66987 .9434 L p .421 .038 .204 r
F P
0 g
s
.64888 .94792 m .66984 .94341 L p .65437 .94699 L .172 .703 .704 r
F P
0 g
s
.66984 .94341 m .66987 .9434 L .65437 .94699 L p .172 .703 .704 r
F P
0 g
s
.63879 .95099 m .65437 .94699 L p .65437 .94699 L .188 .714 .708 r
F P
0 g
s
.64843 .92721 m .63879 .95099 L p .62347 .95492 L .411 .028 .199 r
F P
0 g
s
.63879 .95099 m .64843 .92721 L .66528 .92262 L p .414 .033 .204 r
F P
0 g
s
.62242 .95438 m .63879 .95099 L p .65437 .94699 L .188 .714 .708 r
F P
0 g
s
.63879 .95099 m .62305 .95539 L p .62347 .95492 L .411 .028 .199 r
F P
0 g
s
.84531 .77249 m .84765 .81692 L .86656 .81014 L p .471 .273 .529 r
F P
0 g
s
.86656 .81014 m .86547 .76543 L .84531 .77249 L p .471 .273 .529 r
F P
0 g
s
.16846 .35879 m .19617 .32707 L .19307 .34178 L p .935 .968 .724 r
F P
0 g
s
.19307 .34178 m .16548 .3745 L .16846 .35879 L p .935 .968 .724 r
F P
0 g
s
.21081 .30142 m .24844 .28301 L .24124 .29416 L p .791 .989 .887 r
F P
0 g
s
.24124 .29416 m .20212 .31355 L .21081 .30142 L p .791 .989 .887 r
F P
0 g
s
.43167 .2338 m .45787 .26797 L .46601 .265 L p .673 .718 .883 r
F P
0 g
s
.89352 .59298 m .89765 .63221 L .89584 .61758 L p .715 .524 0 r
F P
0 g
s
.89584 .61758 m .89199 .57905 L .89352 .59298 L p .715 .524 0 r
F P
0 g
s
.67408 .26272 m .71391 .24919 L .70478 .23877 L p .585 .684 .909 r
F P
0 g
s
.70478 .23877 m .66635 .25517 L .67408 .26272 L p .585 .684 .909 r
F P
0 g
s
.87763 .71269 m .88265 .7562 L .89609 .74487 L p .307 .176 .533 r
F P
0 g
s
.89609 .74487 m .89117 .70102 L .87763 .71269 L p .307 .176 .533 r
F P
0 g
s
.59151 .26299 m .61785 .22258 L .60629 .21789 L p .691 .711 .864 r
F P
0 g
s
.60629 .21789 m .58318 .25995 L .59151 .26299 L p .691 .711 .864 r
F P
0 g
s
.74168 .87314 m .73484 .911 L .75283 .90882 L p .55 .265 .436 r
F P
0 g
s
.75283 .90882 m .76178 .87184 L .74168 .87314 L p .55 .265 .436 r
F P
0 g
s
.80484 .82486 m .80257 .86786 L .82238 .86436 L p .53 .289 .494 r
F P
0 g
s
.82238 .86436 m .82683 .82174 L .80484 .82486 L p .53 .289 .494 r
F P
0 g
s
.36755 .95872 m .3491 .94227 L .36492 .95177 L p .53 0 0 r
F P
0 g
s
.36492 .95177 m .38229 .9662 L .36755 .95872 L p .53 0 0 r
F P
0 g
s
.87523 .47642 m .87593 .51564 L .86415 .5049 L p .986 .728 .447 r
F P
0 g
s
.86415 .5049 m .86608 .46601 L .87523 .47642 L p .986 .728 .447 r
F P
0 g
s
.44284 .22954 m .46601 .265 L .4744 .26227 L p .677 .72 .881 r
F P
0 g
s
.46601 .265 m .44284 .22954 L .43167 .2338 L p .673 .718 .883 r
F P
0 g
s
.26033 .71889 m .27647 .68108 L .28832 .68839 L p .886 .719 .669 r
F P
0 g
s
.28832 .68839 m .27244 .72636 L .26033 .71889 L p .886 .719 .669 r
F P
0 g
s
.58318 .25995 m .60629 .21789 L .59424 .21404 L p .692 .712 .864 r
F P
0 g
s
.59424 .21404 m .57455 .25741 L .58318 .25995 L p .692 .712 .864 r
F P
0 g
s
.35397 .23574 m .39092 .2525 L .38191 .25773 L p .645 .801 .958 r
F P
0 g
s
.38191 .25773 m .34209 .24165 L .35397 .23574 L p .645 .801 .958 r
F P
0 g
s
.2694 .83692 m .27668 .79002 L .28551 .80149 L p .945 .712 .554 r
F P
0 g
s
.28551 .80149 m .27964 .8479 L .2694 .83692 L p .945 .712 .554 r
F P
0 g
s
.73687 .27952 m .77172 .29035 L .76407 .27863 L p .292 .528 .908 r
F P
0 g
s
.76407 .27863 m .72988 .26966 L .73687 .27952 L p .292 .528 .908 r
F P
0 g
s
.66987 .9434 m .68226 .91882 L .66528 .92262 L p .421 .038 .204 r
F P
0 g
s
.45437 .22546 m .4744 .26227 L .48304 .25981 L p .681 .721 .879 r
F P
0 g
s
.4744 .26227 m .45437 .22546 L .44284 .22954 L p .677 .72 .881 r
F P
0 g
s
.57455 .25741 m .59424 .21404 L .58176 .2111 L p .693 .713 .864 r
F P
0 g
s
.58176 .2111 m .56567 .25539 L .57455 .25741 L p .693 .713 .864 r
F P
0 g
s
.29683 .89886 m .28993 .8598 L .30068 .8724 L p .928 .561 .302 r
F P
0 g
s
.30068 .8724 m .30854 .90983 L .29683 .89886 L p .928 .561 .302 r
F P
0 g
s
.28045 .25612 m .32047 .25478 L .31101 .26222 L p .651 .915 .979 r
F P
0 g
s
.31101 .26222 m .26827 .26402 L .28045 .25612 L p .651 .915 .979 r
F P
0 g
s
.66635 .25517 m .70478 .23877 L .69479 .22844 L p .591 .687 .909 r
F P
0 g
s
.69479 .22844 m .65797 .24782 L .66635 .25517 L p .591 .687 .909 r
F P
0 g
s
.24518 .66765 m .25447 .63535 L .27144 .64285 L p .857 .643 .613 r
F P
0 g
s
.27144 .64285 m .26202 .67432 L .24518 .66765 L p .857 .643 .613 r
F P
0 g
s
.21534 .61798 m .21677 .58539 L .23631 .59633 L p .86 .59 .528 r
F P
0 g
s
.23631 .59633 m .23549 .62719 L .21534 .61798 L p .86 .59 .528 r
F P
0 g
s
.17864 .55939 m .178 .52231 L .19477 .53765 L p .908 .613 .475 r
F P
0 g
s
.19477 .53765 m .19717 .57308 L .17864 .55939 L p .908 .613 .475 r
F P
0 g
s
.46624 .2216 m .48304 .25981 L .49188 .25764 L p .685 .721 .877 r
F P
0 g
s
.48304 .25981 m .46624 .2216 L .45437 .22546 L p .681 .721 .879 r
F P
0 g
s
.56567 .25539 m .58176 .2111 L .56897 .20908 L p .693 .714 .865 r
F P
0 g
s
.56897 .20908 m .55659 .25391 L .56567 .25539 L p .693 .714 .865 r
F P
0 g
s
.89423 .64646 m .90001 .68769 L .90379 .67311 L p 0 0 .392 r
F P
0 g
s
.90379 .67311 m .89765 .63221 L .89423 .64646 L p 0 0 .392 r
F P
0 g
s
.25629 .77101 m .27244 .72636 L .28249 .73496 L p .912 .738 .653 r
F P
0 g
s
.28249 .73496 m .26707 .77988 L .25629 .77101 L p .912 .738 .653 r
F P
0 g
s
.15198 .48886 m .1571 .44826 L .16647 .46596 L p .978 .722 .478 r
F P
0 g
s
.16647 .46596 m .1634 .50593 L .15198 .48886 L p .978 .722 .478 r
F P
0 g
s
.47842 .21804 m .49188 .25764 L .50091 .2558 L p .688 .722 .875 r
F P
0 g
s
.49188 .25764 m .47842 .21804 L .46624 .2216 L p .685 .721 .877 r
F P
0 g
s
.55659 .25391 m .56897 .20908 L .55596 .20801 L p .694 .715 .865 r
F P
0 g
s
.55596 .20801 m .54737 .25297 L .55659 .25391 L p .694 .715 .865 r
F P
0 g
s
.85272 .41649 m .85501 .45651 L .84288 .44773 L p .979 .707 .441 r
F P
0 g
s
.84288 .44773 m .84348 .40727 L .85272 .41649 L p .979 .707 .441 r
F P
0 g
s
.3664 .23009 m .40045 .24753 L .39092 .2525 L p .647 .806 .959 r
F P
0 g
s
.39092 .2525 m .35397 .23574 L .3664 .23009 L p .647 .806 .959 r
F P
0 g
s
.4909 .21484 m .50091 .2558 L .51008 .25434 L p .69 .721 .873 r
F P
0 g
s
.50091 .2558 m .4909 .21484 L .47842 .21804 L p .688 .722 .875 r
F P
0 g
s
.54737 .25297 m .55596 .20801 L .54282 .20784 L p .694 .717 .867 r
F P
0 g
s
.54282 .20784 m .53805 .25257 L .54737 .25297 L p .694 .717 .867 r
F P
0 g
s
.76178 .87184 m .75283 .90882 L .77082 .90636 L p .527 .232 .41 r
F P
0 g
s
.77082 .90636 m .78221 .87022 L .76178 .87184 L p .527 .232 .41 r
F P
0 g
s
.35369 .95052 m .33449 .93187 L .3491 .94227 L p .559 0 0 r
F P
0 g
s
.3491 .94227 m .36755 .95872 L .35369 .95052 L p .559 0 0 r
F P
0 g
s
.8847 .52746 m .8857 .56556 L .87528 .55288 L p .989 .724 .409 r
F P
0 g
s
.87528 .55288 m .87593 .51564 L .8847 .52746 L p .989 .724 .409 r
F P
0 g
s
.68226 .91882 m .66987 .9434 L .68535 .94019 L p .431 .042 .198 r
F P
0 g
s
.68535 .94019 m .69949 .91573 L .68226 .91882 L p .431 .042 .198 r
F P
0 g
s
.50363 .21212 m .51008 .25434 L .51936 .25328 L p .692 .72 .871 r
F P
0 g
s
.51008 .25434 m .50363 .21212 L .4909 .21484 L p .69 .721 .873 r
F P
0 g
s
.53805 .25257 m .54282 .20784 L .52967 .20852 L p .694 .718 .868 r
F P
0 g
s
.52967 .20852 m .52869 .25268 L .53805 .25257 L p .694 .718 .868 r
F P
0 g
s
.51658 .20998 m .51936 .25328 L .52869 .25268 L p .693 .719 .869 r
F P
0 g
s
.51936 .25328 m .51658 .20998 L .50363 .21212 L p .692 .72 .871 r
F P
0 g
s
.52869 .25268 m .52967 .20852 L .51658 .20998 L p .693 .719 .869 r
F P
0 g
s
.86547 .76543 m .86656 .81014 L .88284 .80128 L p .383 .2 .505 r
F P
0 g
s
.88284 .80128 m .88265 .7562 L .86547 .76543 L p .383 .2 .505 r
F P
0 g
s
.14965 .41343 m .16548 .3745 L .16613 .39125 L p .987 .883 .543 r
F P
0 g
s
.16613 .39125 m .15131 .43058 L .14965 .41343 L p .987 .883 .543 r
F P
0 g
s
.22201 .29081 m .25752 .27297 L .24844 .28301 L p .683 .979 .854 r
F P
0 g
s
.24844 .28301 m .21081 .30142 L .22201 .29081 L p .683 .979 .854 r
F P
0 g
s
.82387 .36034 m .83371 .39825 L .82396 .38908 L p .951 .604 .221 r
F P
0 g
s
.82396 .38908 m .81614 .35062 L .82387 .36034 L p .951 .604 .221 r
F P
0 g
s
.65797 .24782 m .69479 .22844 L .68387 .21838 L p .598 .692 .908 r
F P
0 g
s
.68387 .21838 m .64892 .24077 L .65797 .24782 L p .598 .692 .908 r
F P
0 g
s
.72988 .26966 m .76407 .27863 L .7559 .26625 L p .307 .537 .911 r
F P
0 g
s
.7559 .26625 m .72225 .25952 L .72988 .26966 L p .307 .537 .911 r
F P
0 g
s
.82683 .82174 m .82238 .86436 L .8411 .85942 L p .477 .235 .467 r
F P
0 g
s
.8411 .85942 m .84765 .81692 L .82683 .82174 L p .477 .235 .467 r
F P
0 g
s
.24608 .71217 m .26202 .67432 L .27647 .68108 L p .874 .699 .661 r
F P
0 g
s
.27647 .68108 m .26033 .71889 L .24608 .71217 L p .874 .699 .661 r
F P
0 g
s
.17514 .34452 m .20212 .31355 L .19617 .32707 L p .831 .974 .668 r
F P
0 g
s
.19617 .32707 m .16846 .35879 L .17514 .34452 L p .831 .974 .668 r
F P
0 g
s
.25883 .82699 m .26707 .77988 L .27668 .79002 L p .939 .712 .569 r
F P
0 g
s
.27668 .79002 m .2694 .83692 L .25883 .82699 L p .939 .712 .569 r
F P
0 g
s
.37929 .22457 m .41044 .24278 L .40045 .24753 L p .652 .81 .959 r
F P
0 g
s
.40045 .24753 m .3664 .23009 L .37929 .22457 L p .652 .81 .959 r
F P
0 g
s
.29378 .24911 m .33088 .24796 L .32047 .25478 L p .606 .915 .978 r
F P
0 g
s
.32047 .25478 m .28045 .25612 L .29378 .24911 L p .606 .915 .978 r
F P
0 g
s
.89117 .70102 m .89609 .74487 L .90521 .73168 L p .111 .041 .489 r
F P
0 g
s
.90521 .73168 m .90001 .68769 L .89117 .70102 L p .111 .041 .489 r
F P
0 g
s
.22648 .66059 m .23549 .62719 L .25447 .63535 L p .856 .636 .604 r
F P
0 g
s
.25447 .63535 m .24518 .66765 L .22648 .66059 L p .856 .636 .604 r
F P
0 g
s
.50731 .97683 m .50356 .9847 L .52167 .98217 L p .342 .807 .927 r
F P
0 g
s
.52242 .97548 m .52167 .98217 L .53952 .9787 L p .33 .807 .9 r
F P
0 g
s
.28566 .88832 m .27964 .8479 L .28993 .8598 L p .936 .586 .333 r
F P
0 g
s
.28993 .8598 m .29683 .89886 L .28566 .88832 L p .936 .586 .333 r
F P
0 g
s
.49216 .9774 m .48531 .98608 L .50356 .9847 L p .348 .8 .948 r
F P
0 g
s
.89199 .57905 m .89584 .61758 L .88912 .60307 L p .95 .67 .219 r
F P
0 g
s
.88912 .60307 m .8857 .56556 L .89199 .57905 L p .95 .67 .219 r
F P
0 g
s
.53952 .9787 m .5374 .97344 L .52242 .97548 L p .33 .807 .9 r
F P
0 g
s
.5374 .97344 m .53952 .9787 L .55701 .97452 L p .313 .802 .869 r
F P
0 g
s
.69949 .91573 m .68535 .94019 L .70081 .93725 L p .432 .033 .182 r
F P
0 g
s
.70081 .93725 m .71702 .91321 L .69949 .91573 L p .432 .033 .182 r
F P
0 g
s
.64892 .24077 m .68387 .21838 L .67197 .20881 L p .604 .697 .909 r
F P
0 g
s
.67197 .20881 m .6392 .23413 L .64892 .24077 L p .604 .697 .909 r
F P
0 g
s
.19504 .60748 m .19717 .57308 L .21677 .58539 L p .876 .608 .528 r
F P
0 g
s
.21677 .58539 m .21534 .61798 L .19504 .60748 L p .876 .608 .528 r
F P
0 g
s
.47708 .97708 m .46709 .98618 L .48531 .98608 L p .35 .788 .963 r
F P
0 g
s
.24406 .76325 m .26033 .71889 L .27244 .72636 L p .901 .723 .652 r
F P
0 g
s
.27244 .72636 m .25629 .77101 L .24406 .76325 L p .901 .723 .652 r
F P
0 g
s
.55701 .97452 m .5522 .97086 L .5374 .97344 L p .313 .802 .869 r
F P
0 g
s
.5522 .97086 m .55701 .97452 L .5741 .96987 L p .292 .79 .835 r
F P
0 g
s
.3407 .94184 m .32102 .92094 L .33449 .93187 L p .591 .035 0 r
F P
0 g
s
.33449 .93187 m .35369 .95052 L .3407 .94184 L p .591 .035 0 r
F P
0 g
s
.86608 .46601 m .86415 .5049 L .85036 .49523 L p .965 .721 .518 r
F P
0 g
s
.85036 .49523 m .85501 .45651 L .86608 .46601 L p .965 .721 .518 r
F P
0 g
s
.78221 .87022 m .77082 .90636 L .78851 .90329 L p .492 .186 .375 r
F P
0 g
s
.78851 .90329 m .80257 .86786 L .78221 .87022 L p .492 .186 .375 r
F P
0 g
s
.16237 .54445 m .1634 .50593 L .178 .52231 L p .937 .652 .475 r
F P
0 g
s
.178 .52231 m .17864 .55939 L .16237 .54445 L p .937 .652 .475 r
F P
0 g
s
.46215 .97583 m .44906 .9849 L .46709 .98618 L p .347 .772 .974 r
F P
0 g
s
.46709 .98618 m .47708 .97708 L .46215 .97583 L p .347 .772 .974 r
F P
0 g
s
.3926 .21909 m .42086 .23821 L .41044 .24278 L p .659 .814 .958 r
F P
0 g
s
.41044 .24278 m .37929 .22457 L .3926 .21909 L p .659 .814 .958 r
F P
0 g
s
.5741 .96987 m .56676 .96787 L .5522 .97086 L p .292 .79 .835 r
F P
0 g
s
.56676 .96787 m .5741 .96987 L .59077 .96499 L p .268 .775 .799 r
F P
0 g
s
.72225 .25952 m .7559 .26625 L .74708 .25332 L p .325 .55 .915 r
F P
0 g
s
.74708 .25332 m .71391 .24919 L .72225 .25952 L p .325 .55 .915 r
F P
0 g
s
.6392 .23413 m .67197 .20881 L .65908 .19997 L p .612 .704 .91 r
F P
0 g
s
.65908 .19997 m .62883 .22803 L .6392 .23413 L p .612 .704 .91 r
F P
0 g
s
.22988 .70579 m .24518 .66765 L .26202 .67432 L p .869 .684 .649 r
F P
0 g
s
.26202 .67432 m .24608 .71217 L .22988 .70579 L p .869 .684 .649 r
F P
0 g
s
.4475 .97363 m .43142 .9822 L .44906 .9849 L p .34 .753 .98 r
F P
0 g
s
.44906 .9849 m .46215 .97583 L .4475 .97363 L p .34 .753 .98 r
F P
0 g
s
.14465 .47158 m .15131 .43058 L .1571 .44826 L p .998 .776 .45 r
F P
0 g
s
.1571 .44826 m .15198 .48886 L .14465 .47158 L p .998 .776 .45 r
F P
0 g
s
.59077 .96499 m .58106 .96461 L .56676 .96787 L p .268 .775 .799 r
F P
0 g
s
.58106 .96461 m .59077 .96499 L .60707 .9601 L p .242 .756 .766 r
F P
0 g
s
.23539 .28174 m .26827 .26402 L .25752 .27297 L p .509 .901 .755 r
F P
0 g
s
.25752 .27297 m .22201 .29081 L .23539 .28174 L p .509 .901 .755 r
F P
0 g
s
.89765 .63221 m .90379 .67311 L .90245 .65777 L p 0 0 .152 r
F P
0 g
s
.90245 .65777 m .89584 .61758 L .89765 .63221 L p 0 0 .152 r
F P
0 g
s
.84348 .40727 m .84288 .44773 L .83053 .43933 L p .97 .716 .494 r
F P
0 g
s
.83053 .43933 m .83371 .39825 L .84348 .40727 L p .97 .716 .494 r
F P
0 g
s
.308 .2428 m .34209 .24165 L .33088 .24796 L p .56 .909 .969 r
F P
0 g
s
.33088 .24796 m .29378 .24911 L .308 .2428 L p .56 .909 .969 r
F P
0 g
s
.71702 .91321 m .70081 .93725 L .71622 .93443 L p .42 .011 .154 r
F P
0 g
s
.71622 .93443 m .73484 .911 L .71702 .91321 L p .42 .011 .154 r
F P
0 g
s
.84765 .81692 m .8411 .85942 L .85815 .85277 L p .401 .16 .43 r
F P
0 g
s
.85815 .85277 m .86656 .81014 L .84765 .81692 L p .401 .16 .43 r
F P
0 g
s
.81614 .35062 m .82396 .38908 L .81465 .37938 L p .961 .627 .263 r
F P
0 g
s
.81465 .37938 m .80828 .34044 L .81614 .35062 L p .961 .627 .263 r
F P
0 g
s
.40628 .21357 m .43167 .2338 L .42086 .23821 L p .668 .818 .955 r
F P
0 g
s
.42086 .23821 m .3926 .21909 L .40628 .21357 L p .668 .818 .955 r
F P
0 g
s
.88265 .7562 m .88284 .80128 L .89585 .79037 L p .247 .094 .467 r
F P
0 g
s
.89585 .79037 m .89609 .74487 L .88265 .7562 L p .247 .094 .467 r
F P
0 g
s
.20669 .65271 m .21534 .61798 L .23549 .62719 L p .864 .639 .595 r
F P
0 g
s
.23549 .62719 m .22648 .66059 L .20669 .65271 L p .864 .639 .595 r
F P
0 g
s
.24765 .81813 m .25629 .77101 L .26707 .77988 L p .932 .708 .578 r
F P
0 g
s
.26707 .77988 m .25883 .82699 L .24765 .81813 L p .932 .708 .578 r
F P
0 g
s
.43323 .9705 m .41431 .97811 L .43142 .9822 L p .33 .731 .981 r
F P
0 g
s
.43142 .9822 m .4475 .97363 L .43323 .9705 L p .33 .731 .981 r
F P
0 g
s
.15246 .39735 m .16846 .35879 L .16548 .3745 L p .876 .876 .438 r
F P
0 g
s
.16548 .3745 m .14965 .41343 L .15246 .39735 L p .876 .876 .438 r
F P
0 g
s
.62883 .22803 m .65908 .19997 L .64522 .19209 L p .619 .712 .912 r
F P
0 g
s
.64522 .19209 m .61785 .22258 L .62883 .22803 L p .619 .712 .912 r
F P
0 g
s
.60707 .9601 m .59509 .9612 L .58106 .96461 L p .242 .756 .766 r
F P
0 g
s
.59509 .9612 m .60707 .9601 L .62305 .95539 L p .219 .738 .737 r
F P
0 g
s
.87593 .51564 m .87528 .55288 L .86167 .54124 L p .965 .705 .491 r
F P
0 g
s
.86167 .54124 m .86415 .5049 L .87593 .51564 L p .965 .705 .491 r
F P
0 g
s
.18536 .33198 m .21081 .30142 L .20212 .31355 L p .579 .845 .496 r
F P
0 g
s
.20212 .31355 m .17514 .34452 L .18536 .33198 L p .579 .845 .496 r
F P
0 g
s
.27478 .87839 m .2694 .83692 L .27964 .8479 L p .941 .603 .36 r
F P
0 g
s
.27964 .8479 m .28566 .88832 L .27478 .87839 L p .941 .603 .36 r
F P
0 g
s
.3285 .93293 m .30854 .90983 L .32102 .92094 L p .627 .083 0 r
F P
0 g
s
.32102 .92094 m .3407 .94184 L .3285 .93293 L p .627 .083 0 r
F P
0 g
s
.71391 .24919 m .74708 .25332 L .7374 .23998 L p .346 .565 .92 r
F P
0 g
s
.7374 .23998 m .70478 .23877 L .71391 .24919 L p .346 .565 .92 r
F P
0 g
s
.23033 .75631 m .24608 .71217 L .26033 .71889 L p .895 .711 .645 r
F P
0 g
s
.26033 .71889 m .24406 .76325 L .23033 .75631 L p .895 .711 .645 r
F P
0 g
s
.1758 .59554 m .17864 .55939 L .19717 .57308 L p .899 .633 .526 r
F P
0 g
s
.19717 .57308 m .19504 .60748 L .1758 .59554 L p .899 .633 .526 r
F P
0 g
s
.40628 .21357 m .43167 .2338 L .44284 .22954 L p .675 .82 .953 r
F P
0 g
s
.80257 .86786 m .78851 .90329 L .80557 .89932 L p .439 .122 .33 r
F P
0 g
s
.80557 .89932 m .82238 .86436 L .80257 .86786 L p .439 .122 .33 r
F P
0 g
s
.62305 .95539 m .60887 .95777 L .59509 .9612 L p .219 .738 .737 r
F P
0 g
s
.60887 .95777 m .62305 .95539 L .63879 .95099 L p .2 .723 .717 r
F P
0 g
s
.61785 .22258 m .64522 .19209 L .63046 .18535 L p .627 .721 .914 r
F P
0 g
s
.63046 .18535 m .60629 .21789 L .61785 .22258 L p .627 .721 .914 r
F P
0 g
s
.41943 .96648 m .3979 .97273 L .41431 .97811 L p .317 .708 .98 r
F P
0 g
s
.41431 .97811 m .43323 .9705 L .41943 .96648 L p .317 .708 .98 r
F P
0 g
s
.90001 .68769 m .90521 .73168 L .90967 .71697 L p 0 0 .385 r
F P
0 g
s
.90967 .71697 m .90379 .67311 L .90001 .68769 L p 0 0 .385 r
F P
0 g
s
.32285 .23697 m .35397 .23574 L .34209 .24165 L p .519 .901 .954 r
F P
0 g
s
.34209 .24165 m .308 .2428 L .32285 .23697 L p .519 .901 .954 r
F P
0 g
s
.73484 .911 m .71622 .93443 L .7315 .93155 L p .395 0 .112 r
F P
0 g
s
.7315 .93155 m .75283 .90882 L .73484 .911 L p .395 0 .112 r
F P
0 g
s
.21219 .69927 m .22648 .66059 L .24518 .66765 L p .871 .677 .637 r
F P
0 g
s
.24518 .66765 m .22988 .70579 L .21219 .69927 L p .871 .677 .637 r
F P
0 g
s
.42035 .20798 m .44284 .22954 L .45437 .22546 L p .678 .82 .952 r
F P
0 g
s
.44284 .22954 m .42035 .20798 L .40628 .21357 L p .675 .82 .953 r
F P
0 g
s
.14953 .52856 m .15198 .48886 L .1634 .50593 L p .971 .699 .46 r
F P
0 g
s
.1634 .50593 m .16237 .54445 L .14953 .52856 L p .971 .699 .46 r
F P
0 g
s
.8857 .56556 m .88912 .60307 L .87814 .58912 L p .976 .676 .368 r
F P
0 g
s
.87814 .58912 m .87528 .55288 L .8857 .56556 L p .976 .676 .368 r
F P
0 g
s
.60629 .21789 m .63046 .18535 L .6149 .17993 L p .634 .73 .917 r
F P
0 g
s
.6149 .17993 m .59424 .21404 L .60629 .21789 L p .634 .73 .917 r
F P
0 g
s
.85501 .45651 m .85036 .49523 L .83563 .48648 L p .945 .716 .561 r
F P
0 g
s
.83563 .48648 m .84288 .44773 L .85501 .45651 L p .945 .716 .561 r
F P
0 g
s
.63879 .95099 m .62242 .95438 L .60887 .95777 L p .2 .723 .717 r
F P
0 g
s
.26827 .26402 m .23539 .28174 L .25052 .2741 L p 0 0 0 r
F P
0 g
s
.25052 .2741 m .28045 .25612 L .26827 .26402 L p 0 0 0 r
F P
0 g
s
.40617 .96168 m .38229 .9662 L .3979 .97273 L p .302 .685 .976 r
F P
0 g
s
.3979 .97273 m .41943 .96648 L .40617 .96168 L p .302 .685 .976 r
F P
0 g
s
.70478 .23877 m .7374 .23998 L .72668 .22649 L p .366 .583 .926 r
F P
0 g
s
.72668 .22649 m .69479 .22844 L .70478 .23877 L p .366 .583 .926 r
F P
0 g
s
.43482 .20234 m .45437 .22546 L .46624 .2216 L p .68 .819 .95 r
F P
0 g
s
.45437 .22546 m .43482 .20234 L .42035 .20798 L p .678 .82 .952 r
F P
0 g
s
.31698 .924 m .29683 .89886 L .30854 .90983 L p .665 .132 0 r
F P
0 g
s
.30854 .90983 m .3285 .93293 L .31698 .924 L p .665 .132 0 r
F P
0 g
s
.18683 .64369 m .19504 .60748 L .21534 .61798 L p .879 .649 .586 r
F P
0 g
s
.21534 .61798 m .20669 .65271 L .18683 .64369 L p .879 .649 .586 r
F P
0 g
s
.59424 .21404 m .6149 .17993 L .59868 .17596 L p .642 .74 .92 r
F P
0 g
s
.59868 .17596 m .58176 .2111 L .59424 .21404 L p .642 .74 .92 r
F P
0 g
s
.23568 .81023 m .24406 .76325 L .25629 .77101 L p .926 .702 .579 r
F P
0 g
s
.25629 .77101 m .24765 .81813 L .23568 .81023 L p .926 .702 .579 r
F P
0 g
s
.80828 .34044 m .81465 .37938 L .80603 .36877 L p .965 .638 .276 r
F P
0 g
s
.83371 .39825 m .83053 .43933 L .81872 .43091 L p .965 .726 .527 r
F P
0 g
s
.81872 .43091 m .82396 .38908 L .83371 .39825 L p .965 .726 .527 r
F P
0 g
s
.86656 .81014 m .85815 .85277 L .87298 .8443 L p .286 .054 .377 r
F P
0 g
s
.87298 .8443 m .88284 .80128 L .86656 .81014 L p .286 .054 .377 r
F P
0 g
s
.1421 .45464 m .14965 .41343 L .15131 .43058 L p .958 .802 .361 r
F P
0 g
s
.15131 .43058 m .14465 .47158 L .1421 .45464 L p .958 .802 .361 r
F P
0 g
s
.26396 .8692 m .25883 .82699 L .2694 .83692 L p .942 .614 .382 r
F P
0 g
s
.2694 .83692 m .27478 .87839 L .26396 .8692 L p .942 .614 .382 r
F P
0 g
s
.44972 .19674 m .46624 .2216 L .47842 .21804 L p .682 .816 .947 r
F P
0 g
s
.46624 .2216 m .44972 .19674 L .43482 .20234 L p .68 .819 .95 r
F P
0 g
s
.58176 .2111 m .59868 .17596 L .58197 .17349 L p .649 .75 .923 r
F P
0 g
s
.58197 .17349 m .56897 .20908 L .58176 .2111 L p .649 .75 .923 r
F P
0 g
s
.21525 .74984 m .22988 .70579 L .24608 .71217 L p .894 .701 .635 r
F P
0 g
s
.24608 .71217 m .23033 .75631 L .21525 .74984 L p .894 .701 .635 r
F P
0 g
s
.89584 .61758 m .90245 .65777 L .8963 .64219 L p .909 .599 .112 r
F P
0 g
s
.8963 .64219 m .88912 .60307 L .89584 .61758 L p .909 .599 .112 r
F P
0 g
s
.33815 .23135 m .3664 .23009 L .35397 .23574 L p .491 .893 .937 r
F P
0 g
s
.35397 .23574 m .32285 .23697 L .33815 .23135 L p .491 .893 .937 r
F P
0 g
s
.65437 .94699 m .63575 .95109 L .64888 .94792 L p .172 .703 .704 r
F P
0 g
s
.65437 .94699 m .63575 .95109 L .62242 .95438 L p .188 .714 .708 r
F P
0 g
s
.89609 .74487 m .89585 .79037 L .90511 .77755 L p .03 0 .397 r
F P
0 g
s
.90511 .77755 m .90521 .73168 L .89609 .74487 L p .03 0 .397 r
F P
0 g
s
.19878 .32135 m .22201 .29081 L .21081 .30142 L p 0 0 0 r
F P
0 g
s
.21081 .30142 m .18536 .33198 L .19878 .32135 L p 0 0 0 r
F P
0 g
s
.75283 .90882 m .7315 .93155 L .74652 .9284 L p .35 0 .052 r
F P
0 g
s
.74652 .9284 m .77082 .90636 L .75283 .90882 L p .35 0 .052 r
F P
0 g
s
.46507 .19129 m .47842 .21804 L .4909 .21484 L p .682 .811 .944 r
F P
0 g
s
.47842 .21804 m .46507 .19129 L .44972 .19674 L p .682 .816 .947 r
F P
0 g
s
.82238 .86436 m .80557 .89932 L .82162 .89419 L p .36 .033 .268 r
F P
0 g
s
.82162 .89419 m .8411 .85942 L .82238 .86436 L p .36 .033 .268 r
F P
0 g
s
.15981 .38282 m .17514 .34452 L .16846 .35879 L p 0 0 0 r
F P
0 g
s
.16846 .35879 m .15246 .39735 L .15981 .38282 L p 0 0 0 r
F P
0 g
s
.77713 .29077 m .7559 .26625 L .76407 .27863 L p 0 .007 .564 r
F P
0 g
s
.3935 .9562 m .36755 .95872 L .38229 .9662 L p .284 .661 .97 r
F P
0 g
s
.38229 .9662 m .40617 .96168 L .3935 .9562 L p .284 .661 .97 r
F P
0 g
s
.56897 .20908 m .58197 .17349 L .56495 .17251 L p .657 .761 .926 r
F P
0 g
s
.56495 .17251 m .55596 .20801 L .56897 .20908 L p .657 .761 .926 r
F P
0 g
s
.15886 .58222 m .16237 .54445 L .17864 .55939 L p .93 .667 .518 r
F P
0 g
s
.17864 .55939 m .1758 .59554 L .15886 .58222 L p .93 .667 .518 r
F P
0 g
s
.86415 .5049 m .86167 .54124 L .84597 .53076 L p .936 .687 .536 r
F P
0 g
s
.84597 .53076 m .85036 .49523 L .86415 .5049 L p .936 .687 .536 r
F P
0 g
s
.48087 .18616 m .4909 .21484 L .50363 .21212 L p .681 .805 .942 r
F P
0 g
s
.4909 .21484 m .48087 .18616 L .46507 .19129 L p .682 .811 .944 r
F P
0 g
s
.69479 .22844 m .72668 .22649 L .71475 .21316 L p .386 .603 .934 r
F P
0 g
s
.71475 .21316 m .68387 .21838 L .69479 .22844 L p .386 .603 .934 r
F P
0 g
s
.55596 .20801 m .56495 .17251 L .54779 .17297 L p .663 .771 .93 r
F P
0 g
s
.54779 .17297 m .54282 .20784 L .55596 .20801 L p .663 .771 .93 r
F P
0 g
s
.19369 .69218 m .20669 .65271 L .22648 .66059 L p .88 .677 .624 r
F P
0 g
s
.22648 .66059 m .21219 .69927 L .19369 .69218 L p .88 .677 .624 r
F P
0 g
s
.49711 .18155 m .50363 .21212 L .51658 .20998 L p .678 .798 .939 r
F P
0 g
s
.50363 .21212 m .49711 .18155 L .48087 .18616 L p .681 .805 .942 r
F P
0 g
s
.54282 .20784 m .54779 .17297 L .53067 .17475 L p .669 .78 .933 r
F P
0 g
s
.53067 .17475 m .52967 .20852 L .54282 .20784 L p .669 .78 .933 r
F P
0 g
s
.51373 .17767 m .51658 .20998 L .52967 .20852 L p .674 .79 .936 r
F P
0 g
s
.51658 .20998 m .51373 .17767 L .49711 .18155 L p .678 .798 .939 r
F P
0 g
s
.52967 .20852 m .53067 .17475 L .51373 .17767 L p .674 .79 .936 r
F P
0 g
s
.66987 .9434 m .64888 .94792 L .66182 .94484 L p .152 .69 .702 r
F P
0 g
s
.66182 .94484 m .68535 .94019 L .66987 .9434 L p .152 .69 .702 r
F P
0 g
s
.26697 .2677 m .29378 .24911 L .28045 .25612 L p 0 0 0 r
F P
0 g
s
.28045 .25612 m .25052 .2741 L .26697 .2677 L p 0 0 0 r
F P
0 g
s
.30604 .91524 m .28566 .88832 L .29683 .89886 L p .7 .178 0 r
F P
0 g
s
.29683 .89886 m .31698 .924 L .30604 .91524 L p .7 .178 0 r
F P
0 g
s
.35376 .2257 m .37929 .22457 L .3664 .23009 L p .477 .89 .923 r
F P
0 g
s
.3664 .23009 m .33815 .23135 L .35376 .2257 L p .477 .89 .923 r
F P
0 g
s
.90379 .67311 m .90967 .71697 L .90941 .70119 L p 0 0 .18 r
F P
0 g
s
.90941 .70119 m .90245 .65777 L .90379 .67311 L p 0 0 .18 r
F P
0 g
s
.14112 .51215 m .14465 .47158 L .15198 .48886 L p .994 .749 .415 r
F P
0 g
s
.15198 .48886 m .14953 .52856 L .14112 .51215 L p .994 .749 .415 r
F P
0 g
s
.38146 .95018 m .35369 .95052 L .36755 .95872 L p .263 .638 .964 r
F P
0 g
s
.36755 .95872 m .3935 .9562 L .38146 .95018 L p .263 .638 .964 r
F P
0 g
s
.84288 .44773 m .83563 .48648 L .821 .47834 L p .931 .717 .591 r
F P
0 g
s
.821 .47834 m .83053 .43933 L .84288 .44773 L p .931 .717 .591 r
F P
0 g
s
.22288 .80307 m .23033 .75631 L .24406 .76325 L p .923 .694 .574 r
F P
0 g
s
.24406 .76325 m .23568 .81023 L .22288 .80307 L p .923 .694 .574 r
F P
0 g
s
.80046 .32954 m .80603 .36877 L .79818 .35694 L p .964 .639 .265 r
F P
0 g
s
.87528 .55288 m .87814 .58912 L .86387 .57609 L p .949 .651 .438 r
F P
0 g
s
.86387 .57609 m .86167 .54124 L .87528 .55288 L p .949 .651 .438 r
F P
0 g
s
.16803 .63328 m .1758 .59554 L .19504 .60748 L p .902 .669 .576 r
F P
0 g
s
.19504 .60748 m .18683 .64369 L .16803 .63328 L p .902 .669 .576 r
F P
0 g
s
.25302 .86077 m .24765 .81813 L .25883 .82699 L p .941 .617 .395 r
F P
0 g
s
.25883 .82699 m .26396 .8692 L .25302 .86077 L p .941 .617 .395 r
F P
0 g
s
.68387 .21838 m .71475 .21316 L .70147 .20035 L p .406 .625 .942 r
F P
0 g
s
.70147 .20035 m .67197 .20881 L .68387 .21838 L p .406 .625 .942 r
F P
0 g
s
.82396 .38908 m .81872 .43091 L .80802 .422 L p .964 .737 .546 r
F P
0 g
s
.80802 .422 m .81465 .37938 L .82396 .38908 L p .964 .737 .546 r
F P
0 g
s
.77082 .90636 m .74652 .9284 L .7611 .92478 L p .279 0 0 r
F P
0 g
s
.7611 .92478 m .78851 .90329 L .77082 .90636 L p .279 0 0 r
F P
0 g
s
.7559 .26625 m .77713 .29077 L .76879 .27572 L p 0 .061 .612 r
F P
0 g
s
.76879 .27572 m .74708 .25332 L .7559 .26625 L p 0 .061 .612 r
F P
0 g
s
.1992 .74341 m .21219 .69927 L .22988 .70579 L p .898 .696 .622 r
F P
0 g
s
.22988 .70579 m .21525 .74984 L .1992 .74341 L p .898 .696 .622 r
F P
0 g
s
.68535 .94019 m .66182 .94484 L .67454 .94181 L p .147 .688 .713 r
F P
0 g
s
.67454 .94181 m .70081 .93725 L .68535 .94019 L p .147 .688 .713 r
F P
0 g
s
.88284 .80128 m .87298 .8443 L .88511 .83398 L p .107 0 .292 r
F P
0 g
s
.88511 .83398 m .89585 .79037 L .88284 .80128 L p .107 0 .292 r
F P
0 g
s
.3696 .21981 m .3926 .21909 L .37929 .22457 L p .48 .894 .913 r
F P
0 g
s
.37929 .22457 m .35379 .2257 L p .3696 .21981 L .48 .894 .913 r
F P
0 g
s
.3926 .21909 m .36968 .21981 L p .38567 .21353 L .495 .902 .909 r
F P
0 g
s
.36968 .21981 m .3696 .21981 L .38567 .21353 L p .495 .902 .909 r
F P
0 g
s
.40201 .20678 m .38567 .21353 L p .38572 .21352 L .506 .908 .908 r
F P
0 g
s
.42035 .20798 m .40201 .20678 L p .38572 .21352 L .506 .908 .908 r
F P
0 g
s
.43482 .20234 m .41873 .19957 L .40201 .20678 L p .511 .91 .912 r
F P
0 g
s
.40201 .20678 m .41873 .19957 L p .41824 .20007 L .24 0 .041 r
F P
0 g
s
.38567 .21353 m .40628 .21357 L .3926 .21909 L p .495 .902 .909 r
F P
0 g
s
.38567 .21353 m .40628 .21357 L .42035 .20798 L p .506 .908 .908 r
F P
0 g
s
.40201 .20678 m .42035 .20798 L .43482 .20234 L p .511 .91 .912 r
F P
0 g
s
.39078 .22772 m .40201 .20678 L p .41824 .20007 L .24 0 .041 r
F P
0 g
s
.38567 .21353 m .40201 .20678 L p .40145 .20733 L .249 0 .053 r
F P
0 g
s
.37315 .23525 m .38567 .21353 L p .40145 .20733 L .249 0 .053 r
F P
0 g
s
.37315 .23525 m .38545 .21391 L p .3696 .21981 L .262 0 .053 r
F P
0 g
s
.38545 .21391 m .38567 .21353 L .3696 .21981 L p .262 0 .053 r
F P
0 g
s
.35379 .2257 m .35376 .2257 L .3696 .21981 L p .48 .894 .913 r
F P
0 g
s
.14474 .43862 m .15246 .39735 L .14965 .41343 L p .718 .686 .144 r
F P
0 g
s
.14965 .41343 m .1421 .45464 L .14474 .43862 L p .718 .686 .144 r
F P
0 g
s
.8411 .85942 m .82162 .89419 L .83627 .8877 L p .241 0 .178 r
F P
0 g
s
.83627 .8877 m .85815 .85277 L .8411 .85942 L p .241 0 .178 r
F P
0 g
s
.21489 .31269 m .23539 .28174 L .22201 .29081 L p .072 0 0 r
F P
0 g
s
.22201 .29081 m .19878 .32135 L .21489 .31269 L p .072 0 0 r
F P
0 g
s
.37006 .94376 m .3407 .94184 L .35369 .95052 L p .239 .616 .956 r
F P
0 g
s
.35369 .95052 m .38146 .95018 L .37006 .94376 L p .239 .616 .956 r
F P
0 g
s
.88912 .60307 m .8963 .64219 L .88597 .62687 L p .957 .616 .264 r
F P
0 g
s
.88597 .62687 m .87814 .58912 L .88912 .60307 L p .957 .616 .264 r
F P
0 g
s
.28427 .26221 m .308 .2428 L .29378 .24911 L p .074 0 0 r
F P
0 g
s
.29378 .24911 m .26697 .2677 L .28427 .26221 L p .074 0 0 r
F P
0 g
s
.67197 .20881 m .70147 .20035 L .68675 .18842 L p .424 .648 .951 r
F P
0 g
s
.68675 .18842 m .65908 .19997 L .67197 .20881 L p .424 .648 .951 r
F P
0 g
s
.90521 .73168 m .90511 .77755 L .91033 .76312 L p 0 0 .263 r
F P
0 g
s
.91033 .76312 m .90967 .71697 L .90521 .73168 L p 0 0 .263 r
F P
0 g
s
.1715 .37024 m .18536 .33198 L .17514 .34452 L p 0 0 .073 r
F P
0 g
s
.17514 .34452 m .15981 .38282 L .1715 .37024 L p 0 0 .073 r
F P
0 g
s
.14543 .56771 m .14953 .52856 L .16237 .54445 L p .966 .711 .499 r
F P
0 g
s
.16237 .54445 m .15886 .58222 L .14543 .56771 L p .966 .711 .499 r
F P
0 g
s
.17528 .68413 m .18683 .64369 L .20669 .65271 L p .896 .684 .609 r
F P
0 g
s
.20669 .65271 m .19369 .69218 L .17528 .68413 L p .896 .684 .609 r
F P
0 g
s
.29553 .90681 m .27478 .87839 L .28566 .88832 L p .729 .216 0 r
F P
0 g
s
.28566 .88832 m .30604 .91524 L .29553 .90681 L p .729 .216 0 r
F P
0 g
s
.85036 .49523 m .84597 .53076 L .82943 .52136 L p .914 .677 .565 r
F P
0 g
s
.82943 .52136 m .83563 .48648 L .85036 .49523 L p .914 .677 .565 r
F P
0 g
s
.51164 .95093 m .50731 .97683 L .52242 .97548 L p .641 .806 .962 r
F P
0 g
s
.52242 .97548 m .5233 .9504 L .51164 .95093 L p .641 .806 .962 r
F P
0 g
s
.5233 .9504 m .52242 .97548 L .5374 .97344 L p .641 .812 .965 r
F P
0 g
s
.70081 .93725 m .67454 .94181 L .68702 .93874 L p .161 .699 .736 r
F P
0 g
s
.68702 .93874 m .71622 .93443 L .70081 .93725 L p .161 .699 .736 r
F P
0 g
s
.5374 .97344 m .53491 .94941 L .5233 .9504 L p .641 .812 .965 r
F P
0 g
s
.53491 .94941 m .5374 .97344 L .5522 .97086 L p .64 .818 .968 r
F P
0 g
s
.5 .95095 m .49216 .9774 L .50731 .97683 L p .639 .799 .959 r
F P
0 g
s
.50731 .97683 m .51164 .95093 L .5 .95095 L p .639 .799 .959 r
F P
0 g
s
.5522 .97086 m .54643 .94802 L .53491 .94941 L p .64 .818 .968 r
F P
0 g
s
.54643 .94802 m .5522 .97086 L .56676 .96787 L p .638 .822 .971 r
F P
0 g
s
.79273 .3177 m .79818 .35694 L .79098 .34365 L p .957 .627 .231 r
F P
0 g
s
.48843 .95042 m .47708 .97708 L .49216 .9774 L p .636 .791 .957 r
F P
0 g
s
.49216 .9774 m .5 .95095 L .48843 .95042 L p .636 .791 .957 r
F P
0 g
s
.2094 .79638 m .21525 .74984 L .23033 .75631 L p .924 .688 .562 r
F P
0 g
s
.23033 .75631 m .22288 .80307 L .2094 .79638 L p .924 .688 .562 r
F P
0 g
s
.74708 .25332 m .76879 .27572 L .75966 .25985 L p 0 .121 .66 r
F P
0 g
s
.75966 .25985 m .7374 .23998 L .74708 .25332 L p 0 .121 .66 r
F P
0 g
s
.24188 .85304 m .23568 .81023 L .24765 .81813 L p .939 .616 .397 r
F P
0 g
s
.24765 .81813 m .25302 .86077 L .24188 .85304 L p .939 .616 .397 r
F P
0 g
s
.56676 .96787 m .55782 .94631 L .54643 .94802 L p .638 .822 .971 r
F P
0 g
s
.55782 .94631 m .56676 .96787 L .58106 .96461 L p .634 .826 .974 r
F P
0 g
s
.78851 .90329 m .7611 .92478 L .77501 .92047 L p .174 0 0 r
F P
0 g
s
.77501 .92047 m .80557 .89932 L .78851 .90329 L p .174 0 0 r
F P
0 g
s
.83053 .43933 m .821 .47834 L .80741 .47038 L p .926 .725 .612 r
F P
0 g
s
.80741 .47038 m .81872 .43091 L .83053 .43933 L p .926 .725 .612 r
F P
0 g
s
.65908 .19997 m .68675 .18842 L .67059 .17778 L p .443 .673 .961 r
F P
0 g
s
.67059 .17778 m .64522 .19209 L .65908 .19997 L p .443 .673 .961 r
F P
0 g
s
.47699 .94931 m .46215 .97583 L .47708 .97708 L p .632 .784 .954 r
F P
0 g
s
.47708 .97708 m .48843 .95042 L .47699 .94931 L p .632 .784 .954 r
F P
0 g
s
.35926 .93709 m .3285 .93293 L .3407 .94184 L p .213 .594 .947 r
F P
0 g
s
.3407 .94184 m .37006 .94376 L .35926 .93709 L p .213 .594 .947 r
F P
0 g
s
.90245 .65777 m .90941 .70119 L .9047 .68483 L p .871 .568 .048 r
F P
0 g
s
.9047 .68483 m .8963 .64219 L .90245 .65777 L p .871 .568 .048 r
F P
0 g
s
.81465 .37938 m .80802 .422 L .79878 .41212 L p .969 .75 .552 r
F P
0 g
s
.79878 .41212 m .80603 .36877 L .81465 .37938 L p .969 .75 .552 r
F P
0 g
s
.58106 .96461 m .56906 .94433 L .55782 .94631 L p .634 .826 .974 r
F P
0 g
s
.56906 .94433 m .58106 .96461 L .59509 .9612 L p .629 .828 .977 r
F P
0 g
s
.1515 .62144 m .15886 .58222 L .1758 .59554 L p .932 .698 .562 r
F P
0 g
s
.1758 .59554 m .16803 .63328 L .1515 .62144 L p .932 .698 .562 r
F P
0 g
s
.86167 .54124 m .86387 .57609 L .84751 .56417 L p .92 .628 .475 r
F P
0 g
s
.84751 .56417 m .84597 .53076 L .86167 .54124 L p .92 .628 .475 r
F P
0 g
s
.13793 .49576 m .1421 .45464 L .14465 .47158 L p .94 .759 .289 r
F P
0 g
s
.14465 .47158 m .14112 .51215 L .13793 .49576 L p .94 .759 .289 r
F P
0 g
s
.18275 .73661 m .19369 .69218 L .21219 .69927 L p .907 .696 .605 r
F P
0 g
s
.21219 .69927 m .1992 .74341 L .18275 .73661 L p .907 .696 .605 r
F P
0 g
s
.46574 .94763 m .4475 .97363 L .46215 .97583 L p .628 .777 .952 r
F P
0 g
s
.46215 .97583 m .47699 .94931 L .46574 .94763 L p .628 .777 .952 r
F P
0 g
s
.30204 .25727 m .32285 .23697 L .308 .2428 L p .18 0 0 r
F P
0 g
s
.308 .2428 m .28427 .26221 L .30204 .25727 L p .18 0 0 r
F P
0 g
s
.59509 .9612 m .58012 .94215 L .56906 .94433 L p .629 .828 .977 r
F P
0 g
s
.58012 .94215 m .59509 .9612 L .60887 .95777 L p .623 .829 .98 r
F P
0 g
s
.23307 .30586 m .25052 .2741 L .23539 .28174 L p .265 0 .159 r
F P
0 g
s
.23539 .28174 m .21489 .31269 L .23307 .30586 L p .265 0 .159 r
F P
0 g
s
.71622 .93443 m .68702 .93874 L .6992 .93553 L p .194 .724 .772 r
F P
0 g
s
.6992 .93553 m .7315 .93155 L .71622 .93443 L p .194 .724 .772 r
F P
0 g
s
.28536 .89879 m .26396 .8692 L .27478 .87839 L p .751 .245 0 r
F P
0 g
s
.27478 .87839 m .29515 .90629 L p .28536 .89879 L .751 .245 0 r
F P
0 g
s
.26396 .8692 m .28498 .89826 L p .27544 .89122 L .763 .26 0 r
F P
0 g
s
.28498 .89826 m .28536 .89879 L .27544 .89122 L p .763 .26 0 r
F P
0 g
s
.27544 .89122 m .25302 .86077 L .26396 .8692 L p .763 .26 0 r
F P
0 g
s
.25302 .86077 m .27544 .89122 L .26574 .88407 L p .763 .261 0 r
F P
0 g
s
.30547 .89765 m .26579 .88408 L p .27544 .89122 L .082 .513 .902 r
F P
0 g
s
.26579 .88408 m .26574 .88407 L .27544 .89122 L p .082 .513 .902 r
F P
0 g
s
.31327 .90385 m .2755 .89124 L p .28536 .89879 L .087 .515 .904 r
F P
0 g
s
.2755 .89124 m .27544 .89122 L .28536 .89879 L p .087 .515 .904 r
F P
0 g
s
.29515 .90629 m .29553 .90681 L .28536 .89879 L p .751 .245 0 r
F P
0 g
s
.64522 .19209 m .67059 .17778 L .65308 .16876 L p .46 .7 .971 r
F P
0 g
s
.65308 .16876 m .63046 .18535 L .64522 .19209 L p .46 .7 .971 r
F P
0 g
s
.85815 .85277 m .83627 .8877 L .84912 .87975 L p .059 0 .046 r
F P
0 g
s
.84912 .87975 m .87298 .8443 L .85815 .85277 L p .059 0 .046 r
F P
0 g
s
.45474 .94537 m .43323 .9705 L .4475 .97363 L p .623 .77 .951 r
F P
0 g
s
.4475 .97363 m .46574 .94763 L .45474 .94537 L p .623 .77 .951 r
F P
0 g
s
.89585 .79037 m .88511 .83398 L .89416 .82192 L p 0 0 .154 r
F P
0 g
s
.89416 .82192 m .90511 .77755 L .89585 .79037 L p 0 0 .154 r
F P
0 g
s
.60887 .95777 m .59098 .93981 L .58012 .94215 L p .623 .829 .98 r
F P
0 g
s
.59098 .93981 m .60887 .95777 L .62242 .95438 L p .615 .828 .982 r
F P
0 g
s
.15266 .42408 m .15981 .38282 L .15246 .39735 L p 0 0 .143 r
F P
0 g
s
.15246 .39735 m .14474 .43862 L .15266 .42408 L p 0 0 .143 r
F P
0 g
s
.7374 .23998 m .75966 .25985 L .74937 .24348 L p 0 .181 .705 r
F P
0 g
s
.74937 .24348 m .72668 .22649 L .7374 .23998 L p 0 .181 .705 r
F P
0 g
s
.83563 .48648 m .82943 .52136 L .81324 .51278 L p .902 .677 .587 r
F P
0 g
s
.81324 .51278 m .821 .47834 L .83563 .48648 L p .902 .677 .587 r
F P
0 g
s
.15798 .67484 m .16803 .63328 L .18683 .64369 L p .918 .7 .593 r
F P
0 g
s
.18683 .64369 m .17528 .68413 L .15798 .67484 L p .918 .7 .593 r
F P
0 g
s
.87814 .58912 m .88597 .62687 L .87241 .61221 L p .939 .592 .334 r
F P
0 g
s
.87241 .61221 m .86387 .57609 L .87814 .58912 L p .939 .592 .334 r
F P
0 g
s
.34905 .93029 m .31698 .924 L .3285 .93293 L p .184 .573 .938 r
F P
0 g
s
.3285 .93293 m .35926 .93709 L .34905 .93029 L p .184 .573 .938 r
F P
0 g
s
.18707 .35985 m .19878 .32135 L .18536 .33198 L p .174 0 .256 r
F P
0 g
s
.18536 .33198 m .1715 .37024 L .18707 .35985 L p .174 0 .256 r
F P
0 g
s
.44406 .94257 m .41943 .96648 L .43323 .9705 L p .618 .764 .95 r
F P
0 g
s
.43323 .9705 m .45474 .94537 L .44406 .94257 L p .618 .764 .95 r
F P
0 g
s
.78502 .30479 m .79098 .34365 L .78412 .3288 L p .941 .6 .177 r
F P
0 g
s
.13658 .55236 m .14112 .51215 L .14953 .52856 L p .995 .761 .451 r
F P
0 g
s
.14953 .52856 m .14543 .56771 L .13658 .55236 L p .995 .761 .451 r
F P
0 g
s
.63046 .18535 m .65308 .16876 L .63435 .16165 L p .478 .727 .98 r
F P
0 g
s
.63435 .16165 m .6149 .17993 L .63046 .18535 L p .478 .727 .98 r
F P
0 g
s
.90967 .71697 m .91033 .76312 L .91146 .74744 L p 0 0 .058 r
F P
0 g
s
.91146 .74744 m .90941 .70119 L .90967 .71697 L p 0 0 .058 r
F P
0 g
s
.62242 .95438 m .60164 .93737 L .59098 .93981 L p .615 .828 .982 r
F P
0 g
s
.60164 .93737 m .62242 .95438 L .63575 .95109 L p .607 .826 .984 r
F P
0 g
s
.80557 .89932 m .77501 .92047 L .78803 .91531 L p .024 0 0 r
F P
0 g
s
.78803 .91531 m .82162 .89419 L .80557 .89932 L p .024 0 0 r
F P
0 g
s
.23052 .84589 m .22288 .80307 L .23568 .81023 L p .937 .61 .389 r
F P
0 g
s
.23568 .81023 m .24188 .85304 L .23052 .84589 L p .937 .61 .389 r
F P
0 g
s
.19551 .78982 m .1992 .74341 L .21525 .74984 L p .929 .683 .544 r
F P
0 g
s
.21525 .74984 m .2094 .79638 L .19551 .78982 L p .929 .683 .544 r
F P
0 g
s
.41873 .19957 m .43482 .20234 L .44972 .19674 L p .522 .913 .923 r
F P
0 g
s
.81872 .43091 m .80741 .47038 L .79557 .4621 L p .929 .74 .627 r
F P
0 g
s
.79557 .4621 m .80802 .422 L .81872 .43091 L p .929 .74 .627 r
F P
0 g
s
.31996 .25247 m .33815 .23135 L .32285 .23697 L p .243 0 0 r
F P
0 g
s
.32285 .23697 m .30204 .25727 L .31996 .25247 L p .243 0 0 r
F P
0 g
s
.7315 .93155 m .6992 .93553 L .71098 .93207 L p .247 .761 .818 r
F P
0 g
s
.71098 .93207 m .74652 .9284 L .7315 .93155 L p .247 .761 .818 r
F P
0 g
s
.80603 .36877 m .79878 .41212 L .79109 .40086 L p .977 .761 .545 r
F P
0 g
s
.79109 .40086 m .79818 .35694 L .80603 .36877 L p .977 .761 .545 r
F P
0 g
s
.43373 .93927 m .40617 .96168 L .41943 .96648 L p .612 .759 .949 r
F P
0 g
s
.41943 .96648 m .44406 .94257 L .43373 .93927 L p .612 .759 .949 r
F P
0 g
s
.6149 .17993 m .63435 .16165 L .61463 .15666 L p .495 .755 .988 r
F P
0 g
s
.61463 .15666 m .59868 .17596 L .6149 .17993 L p .495 .755 .988 r
F P
0 g
s
.84597 .53076 m .84751 .56417 L .83033 .5534 L p .898 .613 .495 r
F P
0 g
s
.83033 .5534 m .82943 .52136 L .84597 .53076 L p .898 .613 .495 r
F P
0 g
s
.63575 .95109 m .61207 .93484 L .62228 .93224 L p .596 .822 .986 r
F P
0 g
s
.62228 .93224 m .64888 .94792 L .63575 .95109 L p .596 .822 .986 r
F P
0 g
s
.63575 .95109 m .61207 .93484 L .60164 .93737 L p .607 .826 .984 r
F P
0 g
s
.43593 .19202 m .44972 .19674 L .46507 .19129 L p .534 .914 .937 r
F P
0 g
s
.44972 .19674 m .43593 .19202 L .41873 .19957 L p .522 .913 .923 r
F P
0 g
s
.16663 .72908 m .17528 .68413 L .19369 .69218 L p .923 .701 .584 r
F P
0 g
s
.19369 .69218 m .18275 .73661 L .16663 .72908 L p .923 .701 .584 r
F P
0 g
s
.25264 .30059 m .26697 .2677 L .25052 .2741 L p .383 .045 .263 r
F P
0 g
s
.25052 .2741 m .23307 .30586 L .25264 .30059 L p .383 .045 .263 r
F P
0 g
s
.72668 .22649 m .74937 .24348 L .73759 .22705 L p 0 .239 .744 r
F P
0 g
s
.73759 .22705 m .71475 .21316 L .72668 .22649 L p 0 .239 .744 r
F P
0 g
s
.8963 .64219 m .9047 .68483 L .8961 .66841 L p .942 .59 .188 r
F P
0 g
s
.8961 .66841 m .88597 .62687 L .8963 .64219 L p .942 .59 .188 r
F P
0 g
s
.13841 .60824 m .14543 .56771 L .15886 .58222 L p .967 .738 .538 r
F P
0 g
s
.15886 .58222 m .1515 .62144 L .13841 .60824 L p .967 .738 .538 r
F P
0 g
s
.33938 .92349 m .30604 .91524 L .31698 .924 L p .155 .553 .928 r
F P
0 g
s
.31698 .924 m .34905 .93029 L .33938 .92349 L p .155 .553 .928 r
F P
0 g
s
.59868 .17596 m .61463 .15666 L .5942 .1539 L p .511 .784 .994 r
F P
0 g
s
.5942 .1539 m .58197 .17349 L .59868 .17596 L p .511 .784 .994 r
F P
0 g
s
.14044 .48 m .14474 .43862 L .1421 .45464 L p 0 0 0 r
F P
0 g
s
.1421 .45464 m .13793 .49576 L .14044 .48 L p 0 0 0 r
F P
0 g
s
.4238 .93553 m .3935 .9562 L .40617 .96168 L p .606 .754 .949 r
F P
0 g
s
.40617 .96168 m .43373 .93927 L .4238 .93553 L p .606 .754 .949 r
F P
0 g
s
.45372 .18431 m .46507 .19129 L .48087 .18616 L p .545 .913 .953 r
F P
0 g
s
.46507 .19129 m .45372 .18431 L .43593 .19202 L p .534 .914 .937 r
F P
0 g
s
.87298 .8443 m .84912 .87975 L .85985 .8703 L p 0 0 0 r
F P
0 g
s
.85985 .8703 m .88511 .83398 L .87298 .8443 L p 0 0 0 r
F P
0 g
s
.821 .47834 m .81324 .51278 L .79845 .50463 L p .901 .687 .604 r
F P
0 g
s
.79845 .50463 m .80741 .47038 L .821 .47834 L p .901 .687 .604 r
F P
0 g
s
.64888 .94792 m .62228 .93224 L .63223 .92957 L p .581 .815 .988 r
F P
0 g
s
.63223 .92957 m .66182 .94484 L .64888 .94792 L p .581 .815 .988 r
F P
0 g
s
.77713 .29077 m .78412 .3288 L .77718 .31246 L p .916 .56 .109 r
F P
0 g
s
.77718 .31246 m .76879 .27572 L .77713 .29077 L p .916 .56 .109 r
F P
0 g
s
.33782 .24742 m .35376 .2257 L .33815 .23135 L p .273 0 .012 r
F P
0 g
s
.33815 .23135 m .31996 .25247 L .33782 .24742 L p .273 0 .012 r
F P
0 g
s
.58197 .17349 m .5942 .1539 L .57335 .15335 L p .525 .811 .998 r
F P
0 g
s
.57335 .15335 m .56495 .17251 L .58197 .17349 L p .525 .811 .998 r
F P
0 g
s
.47218 .17674 m .48087 .18616 L .49711 .18155 L p .552 .907 .968 r
F P
0 g
s
.48087 .18616 m .47218 .17674 L .45372 .18431 L p .545 .913 .953 r
F P
0 g
s
.90511 .77755 m .89416 .82192 L .89991 .80831 L p 0 0 0 r
F P
0 g
s
.89991 .80831 m .91033 .76312 L .90511 .77755 L p 0 0 0 r
F P
0 g
s
.74652 .9284 m .71098 .93207 L .72227 .92825 L p .317 .804 .868 r
F P
0 g
s
.72227 .92825 m .7611 .92478 L .74652 .9284 L p .317 .804 .868 r
F P
0 g
s
.56495 .17251 m .57335 .15335 L .55239 .15491 L p .538 .837 .999 r
F P
0 g
s
.55239 .15491 m .54779 .17297 L .56495 .17251 L p .538 .837 .999 r
F P
0 g
s
.49135 .16964 m .49711 .18155 L .51373 .17767 L p .555 .896 .981 r
F P
0 g
s
.49711 .18155 m .49135 .16964 L .47218 .17674 L p .552 .907 .968 r
F P
0 g
s
.86387 .57609 m .87241 .61221 L .85674 .59854 L p .913 .563 .363 r
F P
0 g
s
.85674 .59854 m .84751 .56417 L .86387 .57609 L p .913 .563 .363 r
F P
0 g
s
.2058 .35174 m .21489 .31269 L .19878 .32135 L p .352 .086 .363 r
F P
0 g
s
.19878 .32135 m .18707 .35985 L .2058 .35174 L p .352 .086 .363 r
F P
0 g
s
.16561 .41151 m .1715 .37024 L .15981 .38282 L p .113 0 .331 r
F P
0 g
s
.15981 .38282 m .15266 .42408 L .16561 .41151 L p .113 0 .331 r
F P
0 g
s
.82162 .89419 m .78803 .91531 L .7999 .90917 L p 0 0 0 r
F P
0 g
s
.7999 .90917 m .83627 .8877 L .82162 .89419 L p 0 0 0 r
F P
0 g
s
.41429 .93141 m .38146 .95018 L .3935 .9562 L p .599 .751 .95 r
F P
0 g
s
.3935 .9562 m .4238 .93553 L .41429 .93141 L p .599 .751 .95 r
F P
0 g
s
.54779 .17297 m .55239 .15491 L .53158 .15836 L p .548 .86 .997 r
F P
0 g
s
.53158 .15836 m .53067 .17475 L .54779 .17297 L p .548 .86 .997 r
F P
0 g
s
.51118 .16338 m .51373 .17767 L .53067 .17475 L p .554 .88 .991 r
F P
0 g
s
.51373 .17767 m .51118 .16338 L .49135 .16964 L p .555 .896 .981 r
F P
0 g
s
.80802 .422 m .79557 .4621 L .78589 .45296 L p .94 .761 .633 r
F P
0 g
s
.78589 .45296 m .79878 .41212 L .80802 .422 L p .94 .761 .633 r
F P
0 g
s
.21906 .8391 m .2094 .79638 L .22288 .80307 L p .937 .6 .367 r
F P
0 g
s
.22288 .80307 m .23052 .84589 L .21906 .8391 L p .937 .6 .367 r
F P
0 g
s
.14287 .66417 m .1515 .62144 L .16803 .63328 L p .946 .725 .571 r
F P
0 g
s
.16803 .63328 m .15798 .67484 L .14287 .66417 L p .946 .725 .571 r
F P
0 g
s
.53067 .17475 m .53158 .15836 L .51118 .16338 L p .554 .88 .991 r
F P
0 g
s
.79818 .35694 m .79109 .40086 L .78478 .3879 L p .987 .769 .523 r
F P
0 g
s
.78478 .3879 m .79098 .34365 L .79818 .35694 L p .987 .769 .523 r
F P
0 g
s
.71475 .21316 m .73759 .22705 L .72405 .21107 L p 0 .294 .778 r
F P
0 g
s
.72405 .21107 m .70147 .20035 L .71475 .21316 L p 0 .294 .778 r
F P
0 g
s
.18165 .78305 m .18275 .73661 L .1992 .74341 L p .939 .679 .518 r
F P
0 g
s
.1992 .74341 m .19551 .78982 L .18165 .78305 L p .939 .679 .518 r
F P
0 g
s
.66182 .94484 m .63223 .92957 L .6419 .9268 L p .568 .809 .99 r
F P
0 g
s
.6419 .9268 m .67454 .94181 L .66182 .94484 L p .568 .809 .99 r
F P
0 g
s
.90941 .70119 m .91146 .74744 L .90869 .73096 L p .895 .643 .13 r
F P
0 g
s
.90869 .73096 m .9047 .68483 L .90941 .70119 L p .895 .643 .13 r
F P
0 g
s
.33022 .91678 m .29553 .90681 L .30604 .91524 L p .127 .536 .918 r
F P
0 g
s
.30604 .91524 m .33938 .92349 L .33022 .91678 L p .127 .536 .918 r
F P
0 g
s
.13313 .53666 m .13793 .49576 L .14112 .51215 L p .954 .777 .325 r
F P
0 g
s
.14112 .51215 m .13658 .55236 L .13313 .53666 L p .954 .777 .325 r
F P
0 g
s
.26574 .88407 m .24188 .85304 L .25302 .86077 L p .763 .261 0 r
F P
0 g
s
.82943 .52136 m .83033 .5534 L .81357 .54362 L p .888 .608 .506 r
F P
0 g
s
.81357 .54362 m .81324 .51278 L .82943 .52136 L p .888 .608 .506 r
F P
0 g
s
.27293 .29647 m .28427 .26221 L .26697 .2677 L p .455 .135 .333 r
F P
0 g
s
.26697 .2677 m .25264 .30059 L .27293 .29647 L p .455 .135 .333 r
F P
0 g
s
.35554 .24177 m .3696 .21981 L .35376 .2257 L p .277 0 .043 r
F P
0 g
s
.35376 .2257 m .33782 .24742 L .35554 .24177 L p .277 0 .043 r
F P
0 g
s
.40524 .92699 m .37006 .94376 L .38146 .95018 L p .593 .749 .952 r
F P
0 g
s
.38146 .95018 m .41429 .93141 L .40524 .92699 L p .593 .749 .952 r
F P
0 g
s
.76879 .27572 m .77718 .31246 L .76963 .29483 L p .883 .507 .036 r
F P
0 g
s
.76963 .29483 m .75966 .25985 L .76879 .27572 L p .883 .507 .036 r
F P
0 g
s
.88597 .62687 m .8961 .66841 L .88442 .65239 L p .937 .566 .251 r
F P
0 g
s
.88442 .65239 m .87241 .61221 L .88597 .62687 L p .937 .566 .251 r
F P
0 g
s
.80741 .47038 m .79845 .50463 L .78585 .49644 L p .91 .708 .617 r
F P
0 g
s
.78585 .49644 m .79557 .4621 L .80741 .47038 L p .91 .708 .617 r
F P
0 g
s
.15167 .72051 m .15798 .67484 L .17528 .68413 L p .944 .712 .557 r
F P
0 g
s
.17528 .68413 m .16663 .72908 L .15167 .72051 L p .944 .712 .557 r
F P
0 g
s
.67454 .94181 m .6419 .9268 L .65126 .9239 L p .558 .803 .99 r
F P
0 g
s
.65126 .9239 m .68702 .93874 L .67454 .94181 L p .558 .803 .99 r
F P
0 g
s
.7611 .92478 m .72227 .92825 L .73293 .92395 L p .396 .846 .915 r
F P
0 g
s
.73293 .92395 m .77501 .92047 L .7611 .92478 L p .396 .846 .915 r
F P
0 g
s
.70147 .20035 m .72405 .21107 L .70855 .1961 L p 0 .347 .804 r
F P
0 g
s
.70855 .1961 m .68675 .18842 L .70147 .20035 L p 0 .347 .804 r
F P
0 g
s
.12981 .59394 m .13658 .55236 L .14543 .56771 L p .997 .785 .489 r
F P
0 g
s
.14543 .56771 m .13841 .60824 L .12981 .59394 L p .997 .785 .489 r
F P
0 g
s
.14876 .46546 m .15266 .42408 L .14474 .43862 L p 0 0 .26 r
F P
0 g
s
.14474 .43862 m .14044 .48 L .14876 .46546 L p 0 0 .26 r
F P
0 g
s
.3696 .21981 m .35554 .24177 L .37315 .23525 L p .262 0 .053 r
F P
0 g
s
.88511 .83398 m .85985 .8703 L .8682 .8594 L p 0 0 0 r
F P
0 g
s
.8682 .8594 m .89416 .82192 L .88511 .83398 L p 0 0 0 r
F P
0 g
s
.84751 .56417 m .85674 .59854 L .84019 .58597 L p .892 .538 .369 r
F P
0 g
s
.84019 .58597 m .83033 .5534 L .84751 .56417 L p .892 .538 .369 r
F P
0 g
s
.79878 .41212 m .78589 .45296 L .7785 .44247 L p .956 .786 .63 r
F P
0 g
s
.7785 .44247 m .79109 .40086 L .79878 .41212 L p .956 .786 .63 r
F P
0 g
s
.516 .91308 m .51164 .95093 L .5233 .9504 L p .687 .732 .885 r
F P
0 g
s
.5233 .9504 m .52418 .91299 L .516 .91308 L p .687 .732 .885 r
F P
0 g
s
.52418 .91299 m .5233 .9504 L .53491 .94941 L p .683 .731 .887 r
F P
0 g
s
.39664 .92233 m .35926 .93709 L .37006 .94376 L p .586 .747 .954 r
F P
0 g
s
.37006 .94376 m .40524 .92699 L .39664 .92233 L p .586 .747 .954 r
F P
0 g
s
.53491 .94941 m .53236 .91262 L .52418 .91299 L p .683 .731 .887 r
F P
0 g
s
.53236 .91262 m .53491 .94941 L .54643 .94802 L p .679 .73 .889 r
F P
0 g
s
.32152 .91023 m .28536 .89879 L .29553 .90681 L p .104 .523 .91 r
F P
0 g
s
.29553 .90681 m .33022 .91678 L .32152 .91023 L p .104 .523 .91 r
F P
0 g
s
.22686 .34579 m .23307 .30586 L .21489 .31269 L p .458 .196 .428 r
F P
0 g
s
.21489 .31269 m .2058 .35174 L .22686 .34579 L p .458 .196 .428 r
F P
0 g
s
.50785 .91286 m .5 .95095 L .51164 .95093 L p .69 .734 .884 r
F P
0 g
s
.51164 .95093 m .516 .91308 L .50785 .91286 L p .69 .734 .884 r
F P
0 g
s
.54643 .94802 m .5405 .91198 L .53236 .91262 L p .679 .73 .889 r
F P
0 g
s
.5405 .91198 m .54643 .94802 L .55782 .94631 L p .674 .729 .891 r
F P
0 g
s
.83627 .8877 m .7999 .90917 L .81039 .90195 L p .401 .824 .649 r
F P
0 g
s
.81039 .90195 m .84912 .87975 L .83627 .8877 L p .401 .824 .649 r
F P
0 g
s
.79098 .34365 m .78478 .3879 L .77944 .37306 L p .993 .768 .487 r
F P
0 g
s
.77944 .37306 m .78412 .3288 L .79098 .34365 L p .993 .768 .487 r
F P
0 g
s
.49975 .91232 m .48843 .95042 L .5 .95095 L p .693 .735 .883 r
F P
0 g
s
.5 .95095 m .50785 .91286 L .49975 .91232 L p .693 .735 .883 r
F P
0 g
s
.55782 .94631 m .54857 .9111 L .5405 .91198 L p .674 .729 .891 r
F P
0 g
s
.54857 .9111 m .55782 .94631 L .56906 .94433 L p .669 .727 .893 r
F P
0 g
s
.29335 .29297 m .30204 .25727 L .28427 .26221 L p .497 .194 .382 r
F P
0 g
s
.28427 .26221 m .27293 .29647 L .29335 .29297 L p .497 .194 .382 r
F P
0 g
s
.2077 .83245 m .19551 .78982 L .2094 .79638 L p .937 .586 .331 r
F P
0 g
s
.2094 .79638 m .21906 .8391 L .2077 .83245 L p .937 .586 .331 r
F P
0 g
s
.91033 .76312 m .89991 .80831 L .90231 .79347 L p .83 .762 .249 r
F P
0 g
s
.90231 .79347 m .91146 .74744 L .91033 .76312 L p .83 .762 .249 r
F P
0 g
s
.18299 .40121 m .18707 .35985 L .1715 .37024 L p .33 .115 .428 r
F P
0 g
s
.1715 .37024 m .16561 .41151 L .18299 .40121 L p .33 .115 .428 r
F P
0 g
s
.49175 .91145 m .47699 .94931 L .48843 .95042 L p .695 .736 .883 r
F P
0 g
s
.48843 .95042 m .49975 .91232 L .49175 .91145 L p .695 .736 .883 r
F P
0 g
s
.81324 .51278 m .81357 .54362 L .79833 .53455 L p .891 .614 .51 r
F P
0 g
s
.79833 .53455 m .79845 .50463 L .81324 .51278 L p .891 .614 .51 r
F P
0 g
s
.68702 .93874 m .65126 .9239 L .66028 .92083 L p .552 .798 .99 r
F P
0 g
s
.66028 .92083 m .6992 .93553 L .68702 .93874 L p .552 .798 .99 r
F P
0 g
s
.56906 .94433 m .55654 .91 L .54857 .9111 L p .669 .727 .893 r
F P
0 g
s
.55654 .91 m .56906 .94433 L .58012 .94215 L p .663 .726 .896 r
F P
0 g
s
.25628 .87727 m .23052 .84589 L .24188 .85304 L p .752 .245 0 r
F P
0 g
s
.24188 .85304 m .26574 .88407 L .25628 .87727 L p .752 .245 0 r
F P
0 g
s
.48389 .91026 m .46574 .94763 L .47699 .94931 L p .697 .738 .883 r
F P
0 g
s
.47699 .94931 m .49175 .91145 L .48389 .91026 L p .697 .738 .883 r
F P
0 g
s
.58012 .94215 m .5644 .9087 L .55654 .91 L p .663 .726 .896 r
F P
0 g
s
.5644 .9087 m .58012 .94215 L .59098 .93981 L p .656 .723 .898 r
F P
0 g
s
.131 .65209 m .13841 .60824 L .1515 .62144 L p .979 .759 .536 r
F P
0 g
s
.1515 .62144 m .14287 .66417 L .131 .65209 L p .979 .759 .536 r
F P
0 g
s
.68675 .18842 m .70855 .1961 L .69104 .18271 L p 0 .397 .822 r
F P
0 g
s
.69104 .18271 m .67059 .17778 L .68675 .18842 L p 0 .397 .822 r
F P
0 g
s
.16838 .77574 m .16663 .72908 L .18275 .73661 L p .952 .678 .481 r
F P
0 g
s
.18275 .73661 m .18165 .78305 L .16838 .77574 L p .952 .678 .481 r
F P
0 g
s
.9047 .68483 m .90869 .73096 L .90246 .71416 L p .959 .649 .235 r
F P
0 g
s
.90246 .71416 m .8961 .66841 L .9047 .68483 L p .959 .649 .235 r
F P
0 g
s
.75966 .25985 m .76963 .29483 L .76089 .27631 L p .849 .447 0 r
F P
0 g
s
.76089 .27631 m .74937 .24348 L .75966 .25985 L p .849 .447 0 r
F P
0 g
s
.3885 .91751 m .34905 .93029 L .35926 .93709 L p .579 .747 .957 r
F P
0 g
s
.35926 .93709 m .39664 .92233 L .3885 .91751 L p .579 .747 .957 r
F P
0 g
s
.79557 .4621 m .78585 .49644 L .77591 .48765 L p .932 .741 .623 r
F P
0 g
s
.77591 .48765 m .78589 .45296 L .79557 .4621 L p .932 .741 .623 r
F P
0 g
s
.47618 .90875 m .45474 .94537 L .46574 .94763 L p .698 .74 .883 r
F P
0 g
s
.46574 .94763 m .48389 .91026 L .47618 .90875 L p .698 .74 .883 r
F P
0 g
s
.77501 .92047 m .73293 .92395 L .74284 .91907 L p .478 .88 .952 r
F P
0 g
s
.74284 .91907 m .78803 .91531 L .77501 .92047 L p .478 .88 .952 r
F P
0 g
s
.59098 .93981 m .57212 .90722 L .5644 .9087 L p .656 .723 .898 r
F P
0 g
s
.57212 .90722 m .59098 .93981 L .60164 .93737 L p .649 .721 .901 r
F P
0 g
s
.13559 .52118 m .14044 .48 L .13793 .49576 L p 0 0 0 r
F P
0 g
s
.13793 .49576 m .13313 .53666 L .13559 .52118 L p 0 0 0 r
F P
0 g
s
.87241 .61221 m .88442 .65239 L .87066 .63711 L p .915 .532 .271 r
F P
0 g
s
.87066 .63711 m .85674 .59854 L .87241 .61221 L p .915 .532 .271 r
F P
0 g
s
.46868 .90693 m .44406 .94257 L .45474 .94537 L p .7 .742 .884 r
F P
0 g
s
.45474 .94537 m .47618 .90875 L .46868 .90693 L p .7 .742 .884 r
F P
0 g
s
.28536 .89879 m .32152 .91023 L .31327 .90385 L p .087 .515 .904 r
F P
0 g
s
.6992 .93553 m .66028 .92083 L .66889 .91754 L p .551 .794 .989 r
F P
0 g
s
.66889 .91754 m .71098 .93207 L .6992 .93553 L p .551 .794 .989 r
F P
0 g
s
.60164 .93737 m .57968 .90558 L .57212 .90722 L p .649 .721 .901 r
F P
0 g
s
.57968 .90558 m .60164 .93737 L .61207 .93484 L p .641 .718 .903 r
F P
0 g
s
.83033 .5534 m .84019 .58597 L .82396 .57451 L p .88 .519 .358 r
F P
0 g
s
.82396 .57451 m .81357 .54362 L .83033 .5534 L p .88 .519 .358 r
F P
0 g
s
.31345 .28956 m .31996 .25247 L .30204 .25727 L p .519 .231 .417 r
F P
0 g
s
.30204 .25727 m .29335 .29297 L .31345 .28956 L p .519 .231 .417 r
F P
0 g
s
.79109 .40086 m .7785 .44247 L .77315 .43025 L p .975 .809 .612 r
F P
0 g
s
.77315 .43025 m .78478 .3879 L .79109 .40086 L p .975 .809 .612 r
F P
0 g
s
.40201 .20678 m .39078 .22772 L .37315 .23525 L p .249 0 .053 r
F P
0 g
s
.67059 .17778 m .69104 .18271 L .6716 .17143 L p 0 .444 .829 r
F P
0 g
s
.6716 .17143 m .65308 .16876 L .67059 .17778 L p 0 .444 .829 r
F P
0 g
s
.24931 .34167 m .25264 .30059 L .23307 .30586 L p .524 .27 .472 r
F P
0 g
s
.23307 .30586 m .22686 .34579 L .24931 .34167 L p .524 .27 .472 r
F P
0 g
s
.78412 .3288 m .77944 .37306 L .77447 .35635 L p .995 .755 .438 r
F P
0 g
s
.77447 .35635 m .77718 .31246 L .78412 .3288 L p .995 .755 .438 r
F P
0 g
s
.13878 .71069 m .14287 .66417 L .15798 .67484 L p .97 .73 .518 r
F P
0 g
s
.15798 .67484 m .15167 .72051 L .13878 .71069 L p .97 .73 .518 r
F P
0 g
s
.4614 .90481 m .43373 .93927 L .44406 .94257 L p .701 .745 .886 r
F P
0 g
s
.44406 .94257 m .46868 .90693 L .4614 .90481 L p .701 .745 .886 r
F P
0 g
s
.79845 .50463 m .79833 .53455 L .78543 .52575 L p .91 .634 .506 r
F P
0 g
s
.78543 .52575 m .78585 .49644 L .79845 .50463 L p .91 .634 .506 r
F P
0 g
s
.38084 .91258 m .33938 .92349 L .34905 .93029 L p .573 .748 .96 r
F P
0 g
s
.34905 .93029 m .3885 .91751 L .38084 .91258 L p .573 .748 .96 r
F P
0 g
s
.61207 .93484 m .58706 .90379 L .59423 .90186 L p .632 .714 .906 r
F P
0 g
s
.59423 .90186 m .62228 .93224 L .61207 .93484 L p .632 .714 .906 r
F P
0 g
s
.61207 .93484 m .58706 .90379 L .57968 .90558 L p .641 .718 .903 r
F P
0 g
s
.84912 .87975 m .81039 .90195 L .81928 .89365 L p .606 .947 .785 r
F P
0 g
s
.81928 .89365 m .85985 .8703 L .84912 .87975 L p .606 .947 .785 r
F P
0 g
s
.16259 .45267 m .16561 .41151 L .15266 .42408 L p .197 .024 .407 r
F P
0 g
s
.15266 .42408 m .14876 .46546 L .16259 .45267 L p .197 .024 .407 r
F P
0 g
s
.89416 .82192 m .8682 .8594 L .874 .84721 L p .796 .924 .546 r
F P
0 g
s
.874 .84721 m .89991 .80831 L .89416 .82192 L p .796 .924 .546 r
F P
0 g
s
.12652 .57892 m .13313 .53666 L .13658 .55236 L p .963 .803 .368 r
F P
0 g
s
.13658 .55236 m .12981 .59394 L .12652 .57892 L p .963 .803 .368 r
F P
0 g
s
.24713 .8707 m .21906 .8391 L .23052 .84589 L p .725 .212 0 r
F P
0 g
s
.23052 .84589 m .25628 .87727 L .24713 .8707 L p .725 .212 0 r
F P
0 g
s
.40865 .21916 m .41873 .19957 L .43593 .19202 L p .223 0 .011 r
F P
0 g
s
.41873 .19957 m .40865 .21916 L .39078 .22772 L p .24 0 .041 r
F P
0 g
s
.20395 .39334 m .2058 .35174 L .18707 .35985 L p .455 .229 .481 r
F P
0 g
s
.18707 .35985 m .18299 .40121 L .20395 .39334 L p .455 .229 .481 r
F P
0 g
s
.45438 .90243 m .4238 .93553 L .43373 .93927 L p .702 .749 .889 r
F P
0 g
s
.43373 .93927 m .4614 .90481 L .45438 .90243 L p .702 .749 .889 r
F P
0 g
s
.19674 .82569 m .18165 .78305 L .19551 .78982 L p .934 .565 .274 r
F P
0 g
s
.19551 .78982 m .2077 .83245 L .19674 .82569 L p .934 .565 .274 r
F P
0 g
s
.74937 .24348 m .76089 .27631 L .75043 .25744 L p .818 .387 0 r
F P
0 g
s
.75043 .25744 m .73759 .22705 L .74937 .24348 L p .818 .387 0 r
F P
0 g
s
.78589 .45296 m .77591 .48765 L .76874 .47776 L p .961 .782 .616 r
F P
0 g
s
.76874 .47776 m .7785 .44247 L .78589 .45296 L p .961 .782 .616 r
F P
0 g
s
.62228 .93224 m .59423 .90186 L .60117 .8998 L p .621 .71 .91 r
F P
0 g
s
.60117 .8998 m .63223 .92957 L .62228 .93224 L p .621 .71 .91 r
F P
0 g
s
.91146 .74744 m .90231 .79347 L .90149 .77775 L p .965 .802 .37 r
F P
0 g
s
.90149 .77775 m .90869 .73096 L .91146 .74744 L p .965 .802 .37 r
F P
0 g
s
.71098 .93207 m .66889 .91754 L .67703 .91399 L p .555 .791 .987 r
F P
0 g
s
.67703 .91399 m .72227 .92825 L .71098 .93207 L p .555 .791 .987 r
F P
0 g
s
.65308 .16876 m .6716 .17143 L .65043 .16271 L p 0 .484 .821 r
F P
0 g
s
.65043 .16271 m .63435 .16165 L .65308 .16876 L p 0 .484 .821 r
F P
0 g
s
.78803 .91531 m .74284 .91907 L .75185 .91355 L p .553 .902 .974 r
F P
0 g
s
.75185 .91355 m .7999 .90917 L .78803 .91531 L p .553 .902 .974 r
F P
0 g
s
.33294 .28565 m .33782 .24742 L .31996 .25247 L p .525 .25 .441 r
F P
0 g
s
.31996 .25247 m .31345 .28956 L .33294 .28565 L p .525 .25 .441 r
F P
0 g
s
.8961 .66841 m .90246 .71416 L .89344 .69747 L p .958 .617 .277 r
F P
0 g
s
.89344 .69747 m .88442 .65239 L .8961 .66841 L p .958 .617 .277 r
F P
0 g
s
.44765 .89981 m .41429 .93141 L .4238 .93553 L p .702 .753 .891 r
F P
0 g
s
.4238 .93553 m .45438 .90243 L .44765 .89981 L p .702 .753 .891 r
F P
0 g
s
.27544 .89122 m .31327 .90385 L .30547 .89765 L p .082 .513 .902 r
F P
0 g
s
.42701 .20971 m .43593 .19202 L .45372 .18431 L p .2 0 0 r
F P
0 g
s
.43593 .19202 m .42701 .20971 L .40865 .21916 L p .223 0 .011 r
F P
0 g
s
.81357 .54362 m .82396 .57451 L .8091 .56395 L p .88 .505 .327 r
F P
0 g
s
.8091 .56395 m .79833 .53455 L .81357 .54362 L p .88 .505 .327 r
F P
0 g
s
.85674 .59854 m .87066 .63711 L .85589 .62283 L p .894 .498 .261 r
F P
0 g
s
.85589 .62283 m .84019 .58597 L .85674 .59854 L p .894 .498 .261 r
F P
0 g
s
.37364 .90761 m .33022 .91678 L .33938 .92349 L p .566 .75 .964 r
F P
0 g
s
.33938 .92349 m .38084 .91258 L .37364 .90761 L p .566 .75 .964 r
F P
0 g
s
.15633 .76762 m .15167 .72051 L .16663 .72908 L p .967 .677 .427 r
F P
0 g
s
.16663 .72908 m .16838 .77574 L .15633 .76762 L p .967 .677 .427 r
F P
0 g
s
.63223 .92957 m .60117 .8998 L .60787 .89759 L p .609 .706 .913 r
F P
0 g
s
.60787 .89759 m .6419 .9268 L .63223 .92957 L p .609 .706 .913 r
F P
0 g
s
.78585 .49644 m .78543 .52575 L .77535 .51675 L p .945 .671 .487 r
F P
0 g
s
.77535 .51675 m .77591 .48765 L .78585 .49644 L p .945 .671 .487 r
F P
0 g
s
.78478 .3879 m .77315 .43025 L .76935 .41604 L p .991 .822 .578 r
F P
0 g
s
.76935 .41604 m .77944 .37306 L .78478 .3879 L p .991 .822 .578 r
F P
0 g
s
.27225 .3389 m .27293 .29647 L .25264 .30059 L p .565 .321 .505 r
F P
0 g
s
.25264 .30059 m .24931 .34167 L .27225 .3389 L p .565 .321 .505 r
F P
0 g
s
.12332 .63874 m .12981 .59394 L .13841 .60824 L p .999 .795 .47 r
F P
0 g
s
.13841 .60824 m .131 .65209 L .12332 .63874 L p .999 .795 .47 r
F P
0 g
s
.63435 .16165 m .65043 .16271 L .62785 .15686 L p 0 .516 .794 r
F P
0 g
s
.62785 .15686 m .61463 .15666 L .63435 .16165 L p 0 .516 .794 r
F P
0 g
s
.77718 .31246 m .77447 .35635 L .76914 .33798 L p .99 .73 .384 r
F P
0 g
s
.76914 .33798 m .76963 .29483 L .77718 .31246 L p .99 .73 .384 r
F P
0 g
s
.14408 .5065 m .14876 .46546 L .14044 .48 L p 0 0 .246 r
F P
0 g
s
.14044 .48 m .13559 .52118 L .14408 .5065 L p 0 0 .246 r
F P
0 g
s
.44121 .89697 m .40524 .92699 L .41429 .93141 L p .703 .758 .895 r
F P
0 g
s
.41429 .93141 m .44765 .89981 L .44121 .89697 L p .703 .758 .895 r
F P
0 g
s
.44608 .19966 m .45372 .18431 L .47218 .17674 L p .173 0 0 r
F P
0 g
s
.45372 .18431 m .44608 .19966 L .42701 .20971 L p .2 0 0 r
F P
0 g
s
.72227 .92825 m .67703 .91399 L .68466 .91012 L p .563 .789 .984 r
F P
0 g
s
.68466 .91012 m .73293 .92395 L .72227 .92825 L p .563 .789 .984 r
F P
0 g
s
.6419 .9268 m .60787 .89759 L .61429 .89523 L p .599 .702 .916 r
F P
0 g
s
.61429 .89523 m .65126 .9239 L .6419 .9268 L p .599 .702 .916 r
F P
0 g
s
.35174 .28077 m .35554 .24177 L .33782 .24742 L p .518 .256 .457 r
F P
0 g
s
.33782 .24742 m .33294 .28565 L .35174 .28077 L p .518 .256 .457 r
F P
0 g
s
.73759 .22705 m .75043 .25744 L .73778 .23888 L p .791 .329 0 r
F P
0 g
s
.73778 .23888 m .72405 .21107 L .73759 .22705 L p .791 .329 0 r
F P
0 g
s
.61463 .15666 m .62785 .15686 L .60429 .15405 L p 0 .535 .747 r
F P
0 g
s
.60429 .15405 m .5942 .1539 L .61463 .15666 L p 0 .535 .747 r
F P
0 g
s
.7785 .44247 m .76874 .47776 L .76408 .46634 L p .988 .821 .587 r
F P
0 g
s
.76408 .46634 m .77315 .43025 L .7785 .44247 L p .988 .821 .587 r
F P
0 g
s
.46609 .18941 m .47218 .17674 L .49135 .16964 L p .145 0 0 r
F P
0 g
s
.47218 .17674 m .46609 .18941 L .44608 .19966 L p .173 0 0 r
F P
0 g
s
.85985 .8703 m .81928 .89365 L .82643 .88429 L p .75 .994 .854 r
F P
0 g
s
.82643 .88429 m .8682 .8594 L .85985 .8703 L p .75 .994 .854 r
F P
0 g
s
.2274 .3878 m .22686 .34579 L .2058 .35174 L p .533 .305 .515 r
F P
0 g
s
.2058 .35174 m .20395 .39334 L .2274 .3878 L p .533 .305 .515 r
F P
0 g
s
.36691 .90261 m .32152 .91023 L .33022 .91678 L p .561 .753 .968 r
F P
0 g
s
.33022 .91678 m .37364 .90761 L .36691 .90261 L p .561 .753 .968 r
F P
0 g
s
.18125 .44203 m .18299 .40121 L .16561 .41151 L p .384 .179 .474 r
F P
0 g
s
.16561 .41151 m .16259 .45267 L .18125 .44203 L p .384 .179 .474 r
F P
0 g
s
.23843 .86422 m .2077 .83245 L .21906 .8391 L p .677 .158 0 r
F P
0 g
s
.21906 .8391 m .24713 .8707 L .23843 .86422 L p .677 .158 0 r
F P
0 g
s
.4351 .89395 m .39664 .92233 L .40524 .92699 L p .703 .764 .899 r
F P
0 g
s
.40524 .92699 m .44121 .89697 L .4351 .89395 L p .703 .764 .899 r
F P
0 g
s
.7999 .90917 m .75185 .91355 L .75984 .90734 L p .617 .91 .982 r
F P
0 g
s
.75984 .90734 m .81039 .90195 L .7999 .90917 L p .617 .91 .982 r
F P
0 g
s
.79833 .53455 m .8091 .56395 L .79637 .55399 L p .891 .496 .266 r
F P
0 g
s
.79637 .55399 m .78543 .52575 L .79833 .53455 L p .891 .496 .266 r
F P
0 g
s
.89991 .80831 m .874 .84721 L .87721 .83394 L p .931 .954 .632 r
F P
0 g
s
.87721 .83394 m .90231 .79347 L .89991 .80831 L p .931 .954 .632 r
F P
0 g
s
.12883 .69954 m .131 .65209 L .14287 .66417 L p .992 .749 .454 r
F P
0 g
s
.14287 .66417 m .13878 .71069 L .12883 .69954 L p .992 .749 .454 r
F P
0 g
s
.5942 .1539 m .60429 .15405 L .58021 .15426 L p .049 0 0 r
F P
0 g
s
.58021 .15426 m .57335 .15335 L .5942 .1539 L p .049 0 0 r
F P
0 g
s
.48714 .17948 m .49135 .16964 L .51118 .16338 L p .118 0 0 r
F P
0 g
s
.49135 .16964 m .48714 .17948 L .46609 .18941 L p .145 0 0 r
F P
0 g
s
.51994 .87236 m .516 .91308 L .52418 .91299 L p .697 .696 .845 r
F P
0 g
s
.52418 .91299 m .52499 .87242 L .51994 .87236 L p .697 .696 .845 r
F P
0 g
s
.52499 .87242 m .52418 .91299 L .53236 .91262 L p .691 .691 .845 r
F P
0 g
s
.53236 .91262 m .53004 .87232 L .52499 .87242 L p .691 .691 .845 r
F P
0 g
s
.53004 .87232 m .53236 .91262 L .5405 .91198 L p .685 .687 .846 r
F P
0 g
s
.29814 .89161 m .25628 .87727 L .26574 .88407 L p .09 .52 .905 r
F P
0 g
s
.26574 .88407 m .30547 .89765 L .29814 .89161 L p .09 .52 .905 r
F P
0 g
s
.51491 .87212 m .50785 .91286 L .516 .91308 L p .703 .7 .844 r
F P
0 g
s
.516 .91308 m .51994 .87236 L .51491 .87212 L p .703 .7 .844 r
F P
0 g
s
.5405 .91198 m .53508 .87205 L .53004 .87232 L p .685 .687 .846 r
F P
0 g
s
.53508 .87205 m .5405 .91198 L .54857 .9111 L p .678 .683 .848 r
F P
0 g
s
.84019 .58597 m .85589 .62283 L .84118 .60964 L p .877 .463 .227 r
F P
0 g
s
.84118 .60964 m .82396 .57451 L .84019 .58597 L p .877 .463 .227 r
F P
0 g
s
.65126 .9239 m .61429 .89523 L .62041 .89271 L p .589 .698 .918 r
F P
0 g
s
.62041 .89271 m .66028 .92083 L .65126 .9239 L p .589 .698 .918 r
F P
0 g
s
.18657 .81855 m .16838 .77574 L .18165 .78305 L p .923 .532 .189 r
F P
0 g
s
.18165 .78305 m .19674 .82569 L .18657 .81855 L p .923 .532 .189 r
F P
0 g
s
.50993 .87172 m .49975 .91232 L .50785 .91286 L p .709 .705 .844 r
F P
0 g
s
.50785 .91286 m .51491 .87212 L .50993 .87172 L p .709 .705 .844 r
F P
0 g
s
.29489 .33685 m .29335 .29297 L .27293 .29647 L p .589 .356 .53 r
F P
0 g
s
.27293 .29647 m .27225 .3389 L .29489 .33685 L p .589 .356 .53 r
F P
0 g
s
.54857 .9111 m .54008 .87163 L .53508 .87205 L p .678 .683 .848 r
F P
0 g
s
.54008 .87163 m .54857 .9111 L .55654 .91 L p .672 .68 .849 r
F P
0 g
s
.77591 .48765 m .77535 .51675 L .7682 .50705 L p .984 .716 .434 r
F P
0 g
s
.7682 .50705 m .76874 .47776 L .77591 .48765 L p .984 .716 .434 r
F P
0 g
s
.90869 .73096 m .90149 .77775 L .89777 .76155 L p .996 .773 .418 r
F P
0 g
s
.89777 .76155 m .90246 .71416 L .90869 .73096 L p .996 .773 .418 r
F P
0 g
s
.57335 .15335 m .58021 .15426 L .55607 .15731 L p .058 0 0 r
F P
0 g
s
.55607 .15731 m .55239 .15491 L .57335 .15335 L p .058 0 0 r
F P
0 g
s
.50924 .17043 m .51118 .16338 L .53158 .15836 L p .093 0 0 r
F P
0 g
s
.51118 .16338 m .50924 .17043 L .48714 .17948 L p .118 0 0 r
F P
0 g
s
.12901 .56368 m .13559 .52118 L .13313 .53666 L p 0 0 0 r
F P
0 g
s
.13313 .53666 m .12652 .57892 L .12901 .56368 L p 0 0 0 r
F P
0 g
s
.505 .87114 m .49175 .91145 L .49975 .91232 L p .714 .71 .845 r
F P
0 g
s
.49975 .91232 m .50993 .87172 L .505 .87114 L p .714 .71 .845 r
F P
0 g
s
.88442 .65239 m .89344 .69747 L .8824 .6813 L p .94 .579 .283 r
F P
0 g
s
.8824 .6813 m .87066 .63711 L .88442 .65239 L p .94 .579 .283 r
F P
0 g
s
.55654 .91 m .54503 .87106 L .54008 .87163 L p .672 .68 .849 r
F P
0 g
s
.54503 .87106 m .55654 .91 L .5644 .9087 L p .665 .676 .851 r
F P
0 g
s
.5323 .16286 m .53158 .15836 L .55239 .15491 L p .073 0 0 r
F P
0 g
s
.53158 .15836 m .5323 .16286 L .50924 .17043 L p .093 0 0 r
F P
0 g
s
.55239 .15491 m .55607 .15731 L .5323 .16286 L p .073 0 0 r
F P
0 g
s
.36993 .27452 m .37315 .23525 L .35554 .24177 L p .501 .249 .464 r
F P
0 g
s
.35554 .24177 m .35174 .28077 L .36993 .27452 L p .501 .249 .464 r
F P
0 g
s
.50016 .8704 m .48389 .91026 L .49175 .91145 L p .719 .715 .846 r
F P
0 g
s
.49175 .91145 m .505 .87114 L .50016 .8704 L p .719 .715 .846 r
F P
0 g
s
.42933 .89078 m .3885 .91751 L .39664 .92233 L p .704 .77 .903 r
F P
0 g
s
.39664 .92233 m .4351 .89395 L .42933 .89078 L p .704 .77 .903 r
F P
0 g
s
.5644 .9087 m .5499 .87034 L .54503 .87106 L p .665 .676 .851 r
F P
0 g
s
.5499 .87034 m .5644 .9087 L .57212 .90722 L p .657 .672 .853 r
F P
0 g
s
.77944 .37306 m .76935 .41604 L .76635 .39981 L p .999 .822 .53 r
F P
0 g
s
.76635 .39981 m .77447 .35635 L .77944 .37306 L p .999 .822 .53 r
F P
0 g
s
.73293 .92395 m .68466 .91012 L .69169 .90591 L p .574 .787 .98 r
F P
0 g
s
.69169 .90591 m .74284 .91907 L .73293 .92395 L p .574 .787 .98 r
F P
0 g
s
.49542 .86948 m .47618 .90875 L .48389 .91026 L p .724 .721 .847 r
F P
0 g
s
.48389 .91026 m .50016 .8704 L .49542 .86948 L p .724 .721 .847 r
F P
0 g
s
.76963 .29483 m .76914 .33798 L .76266 .31836 L p .981 .695 .333 r
F P
0 g
s
.76266 .31836 m .76089 .27631 L .76963 .29483 L p .981 .695 .333 r
F P
0 g
s
.57212 .90722 m .55469 .86949 L .5499 .87034 L p .657 .672 .853 r
F P
0 g
s
.55469 .86949 m .57212 .90722 L .57968 .90558 L p .649 .669 .855 r
F P
0 g
s
.72405 .21107 m .73778 .23888 L .72263 .22136 L p .769 .276 0 r
F P
0 g
s
.72263 .22136 m .70855 .1961 L .72405 .21107 L p .769 .276 0 r
F P
0 g
s
.36067 .89763 m .31327 .90385 L .32152 .91023 L p .556 .757 .971 r
F P
0 g
s
.32152 .91023 m .36691 .90261 L .36067 .89763 L p .556 .757 .971 r
F P
0 g
s
.66028 .92083 m .62041 .89271 L .6262 .89003 L p .581 .695 .92 r
F P
0 g
s
.6262 .89003 m .66889 .91754 L .66028 .92083 L p .581 .695 .92 r
F P
0 g
s
.4908 .8684 m .46868 .90693 L .47618 .90875 L p .728 .727 .849 r
F P
0 g
s
.47618 .90875 m .49542 .86948 L .4908 .8684 L p .728 .727 .849 r
F P
0 g
s
.57968 .90558 m .55937 .8685 L .55469 .86949 L p .649 .669 .855 r
F P
0 g
s
.55937 .8685 m .57968 .90558 L .58706 .90379 L p .641 .665 .857 r
F P
0 g
s
.14617 .75847 m .13878 .71069 L .15167 .72051 L p .975 .67 .343 r
F P
0 g
s
.15167 .72051 m .15633 .76762 L .14617 .75847 L p .975 .67 .343 r
F P
0 g
s
.78543 .52575 m .79637 .55399 L .78625 .54424 L p .9 .484 .154 r
F P
0 g
s
.78625 .54424 m .77535 .51675 L .78543 .52575 L p .9 .484 .154 r
F P
0 g
s
.77315 .43025 m .76408 .46634 L .76137 .45309 L p .999 .84 .529 r
F P
0 g
s
.76137 .45309 m .76935 .41604 L .77315 .43025 L p .999 .84 .529 r
F P
0 g
s
.25221 .38426 m .24931 .34167 L .22686 .34579 L p .582 .357 .54 r
F P
0 g
s
.22686 .34579 m .2274 .3878 L .25221 .38426 L p .582 .357 .54 r
F P
0 g
s
.15829 .49318 m .16259 .45267 L .14876 .46546 L p .193 .014 .395 r
F P
0 g
s
.14876 .46546 m .14408 .5065 L .15829 .49318 L p .193 .014 .395 r
F P
0 g
s
.42391 .88748 m .38084 .91258 L .3885 .91751 L p .704 .776 .908 r
F P
0 g
s
.3885 .91751 m .42933 .89078 L .42391 .88748 L p .704 .776 .908 r
F P
0 g
s
.48631 .86717 m .4614 .90481 L .46868 .90693 L p .732 .733 .851 r
F P
0 g
s
.46868 .90693 m .4908 .8684 L .48631 .86717 L p .732 .733 .851 r
F P
0 g
s
.31663 .33485 m .31345 .28956 L .29335 .29297 L p .6 .378 .552 r
F P
0 g
s
.29335 .29297 m .29489 .33685 L .31663 .33485 L p .6 .378 .552 r
F P
0 g
s
.36993 .27452 m .37315 .23525 L .39078 .22772 L p .487 .24 .465 r
F P
0 g
s
.12056 .62441 m .12652 .57892 L .12981 .59394 L p .94 .788 .326 r
F P
0 g
s
.12981 .59394 m .12332 .63874 L .12056 .62441 L p .94 .788 .326 r
F P
0 g
s
.58706 .90379 m .56392 .86738 L .56833 .86613 L p .632 .661 .86 r
F P
0 g
s
.56833 .86613 m .59423 .90186 L .58706 .90379 L p .632 .661 .86 r
F P
0 g
s
.58706 .90379 m .56392 .86738 L .55937 .8685 L p .641 .665 .857 r
F P
0 g
s
.82396 .57451 m .84118 .60964 L .82743 .59747 L p .864 .427 .162 r
F P
0 g
s
.82743 .59747 m .8091 .56395 L .82396 .57451 L p .864 .427 .162 r
F P
0 g
s
.81039 .90195 m .75984 .90734 L .76669 .90043 L p .668 .908 .978 r
F P
0 g
s
.76669 .90043 m .81928 .89365 L .81039 .90195 L p .668 .908 .978 r
F P
0 g
s
.20374 .43373 m .20395 .39334 L .18299 .40121 L p .493 .274 .509 r
F P
0 g
s
.18299 .40121 m .18125 .44203 L .20374 .43373 L p .493 .274 .509 r
F P
0 g
s
.48198 .86578 m .45438 .90243 L .4614 .90481 L p .736 .74 .854 r
F P
0 g
s
.4614 .90481 m .48631 .86717 L .48198 .86578 L p .736 .74 .854 r
F P
0 g
s
.76874 .47776 m .7682 .50705 L .7637 .49621 L p .98 .735 .327 r
F P
0 g
s
.7637 .49621 m .76408 .46634 L .76874 .47776 L p .98 .735 .327 r
F P
0 g
s
.8682 .8594 m .82643 .88429 L .83172 .87397 L p .831 .987 .87 r
F P
0 g
s
.83172 .87397 m .874 .84721 L .8682 .8594 L p .831 .987 .87 r
F P
0 g
s
.29134 .88565 m .24713 .8707 L .25628 .87727 L p .111 .533 .914 r
F P
0 g
s
.25628 .87727 m .29814 .89161 L .29134 .88565 L p .111 .533 .914 r
F P
0 g
s
.66889 .91754 m .6262 .89003 L .63163 .88717 L p .574 .693 .922 r
F P
0 g
s
.63163 .88717 m .67703 .91399 L .66889 .91754 L p .574 .693 .922 r
F P
0 g
s
.59423 .90186 m .56833 .86613 L .57259 .86477 L p .622 .657 .863 r
F P
0 g
s
.57259 .86477 m .60117 .8998 L .59423 .90186 L p .622 .657 .863 r
F P
0 g
s
.23037 .85766 m .19674 .82569 L .2077 .83245 L p .601 .081 0 r
F P
0 g
s
.2077 .83245 m .23843 .86422 L .23037 .85766 L p .601 .081 0 r
F P
0 g
s
.74284 .91907 m .69169 .90591 L .69806 .90131 L p .586 .785 .974 r
F P
0 g
s
.69806 .90131 m .75185 .91355 L .74284 .91907 L p .586 .785 .974 r
F P
0 g
s
.87066 .63711 m .8824 .6813 L .87022 .66592 L p .922 .541 .266 r
F P
0 g
s
.87022 .66592 m .85589 .62283 L .87066 .63711 L p .922 .541 .266 r
F P
0 g
s
.90231 .79347 m .87721 .83394 L .87792 .81985 L p .976 .921 .654 r
F P
0 g
s
.87792 .81985 m .90149 .77775 L .90231 .79347 L p .976 .921 .654 r
F P
0 g
s
.47783 .86426 m .44765 .89981 L .45438 .90243 L p .74 .747 .857 r
F P
0 g
s
.45438 .90243 m .48198 .86578 L .47783 .86426 L p .74 .747 .857 r
F P
0 g
s
.41886 .88407 m .37364 .90761 L .38084 .91258 L p .704 .783 .913 r
F P
0 g
s
.38084 .91258 m .42391 .88748 L .41886 .88407 L p .704 .783 .913 r
F P
0 g
s
.70855 .1961 m .72263 .22136 L .70483 .20565 L p .746 .229 0 r
F P
0 g
s
.70483 .20565 m .69104 .18271 L .70855 .1961 L p .746 .229 0 r
F P
0 g
s
.35492 .89266 m .30547 .89765 L .31327 .90385 L p .553 .761 .974 r
F P
0 g
s
.31327 .90385 m .36067 .89763 L .35492 .89266 L p .553 .761 .974 r
F P
0 g
s
.60117 .8998 m .57259 .86477 L .57667 .86329 L p .612 .653 .867 r
F P
0 g
s
.57667 .86329 m .60787 .89759 L .60117 .8998 L p .612 .653 .867 r
F P
0 g
s
.90246 .71416 m .89777 .76155 L .89161 .74526 L p .989 .73 .429 r
F P
0 g
s
.89161 .74526 m .89344 .69747 L .90246 .71416 L p .989 .73 .429 r
F P
0 g
s
.38775 .26668 m .39078 .22772 L .40865 .21916 L p .479 .23 .459 r
F P
0 g
s
.39078 .22772 m .38775 .26668 L .36993 .27452 L p .487 .24 .465 r
F P
0 g
s
.77447 .35635 m .76635 .39981 L .76325 .3817 L p 1 .805 .477 r
F P
0 g
s
.76325 .3817 m .76914 .33798 L .77447 .35635 L p 1 .805 .477 r
F P
0 g
s
.33713 .33219 m .33294 .28565 L .31345 .28956 L p .599 .39 .569 r
F P
0 g
s
.31345 .28956 m .31663 .33485 L .33713 .33219 L p .599 .39 .569 r
F P
0 g
s
.76089 .27631 m .76266 .31836 L .75428 .2981 L p .97 .654 .294 r
F P
0 g
s
.75428 .2981 m .75043 .25744 L .76089 .27631 L p .97 .654 .294 r
F P
0 g
s
.17762 .81082 m .15633 .76762 L .16838 .77574 L p .889 .476 .062 r
F P
0 g
s
.16838 .77574 m .18657 .81855 L .17762 .81082 L p .889 .476 .062 r
F P
0 g
s
.47386 .8626 m .44121 .89697 L .44765 .89981 L p .744 .755 .861 r
F P
0 g
s
.44765 .89981 m .47783 .86426 L .47386 .8626 L p .744 .755 .861 r
F P
0 g
s
.12259 .68711 m .12332 .63874 L .131 .65209 L p .979 .75 .337 r
F P
0 g
s
.131 .65209 m .12883 .69954 L .12259 .68711 L p .979 .75 .337 r
F P
0 g
s
.77535 .51675 m .78625 .54424 L .77884 .53428 L p .852 .444 0 r
F P
0 g
s
.77884 .53428 m .7682 .50705 L .77535 .51675 L p .852 .444 0 r
F P
0 g
s
.27724 .38222 m .27225 .3389 L .24931 .34167 L p .614 .395 .561 r
F P
0 g
s
.24931 .34167 m .25221 .38426 L .27724 .38222 L p .614 .395 .561 r
F P
0 g
s
.13743 .54876 m .14408 .5065 L .13559 .52118 L p 0 0 .193 r
F P
0 g
s
.13559 .52118 m .12901 .56368 L .13743 .54876 L p 0 0 .193 r
F P
0 g
s
.67703 .91399 m .63163 .88717 L .63666 .88412 L p .569 .691 .923 r
F P
0 g
s
.63666 .88412 m .68466 .91012 L .67703 .91399 L p .569 .691 .923 r
F P
0 g
s
.60787 .89759 m .57667 .86329 L .58056 .86169 L p .601 .65 .87 r
F P
0 g
s
.58056 .86169 m .61429 .89523 L .60787 .89759 L p .601 .65 .87 r
F P
0 g
s
.8091 .56395 m .82743 .59747 L .81534 .58615 L p .846 .383 .055 r
F P
0 g
s
.81534 .58615 m .79637 .55399 L .8091 .56395 L p .846 .383 .055 r
F P
0 g
s
.76935 .41604 m .76137 .45309 L .75975 .43789 L p .989 .832 .454 r
F P
0 g
s
.75975 .43789 m .76635 .39981 L .76935 .41604 L p .989 .832 .454 r
F P
0 g
s
.47009 .86082 m .4351 .89395 L .44121 .89697 L p .747 .762 .865 r
F P
0 g
s
.44121 .89697 m .47386 .8626 L .47009 .86082 L p .747 .762 .865 r
F P
0 g
s
.4142 .88058 m .36691 .90261 L .37364 .90761 L p .704 .791 .918 r
F P
0 g
s
.37364 .90761 m .41886 .88407 L .4142 .88058 L p .704 .791 .918 r
F P
0 g
s
.40557 .2572 m .40865 .21916 L .42701 .20971 L p .469 .215 .445 r
F P
0 g
s
.40865 .21916 m .40557 .2572 L .38775 .26668 L p .479 .23 .459 r
F P
0 g
s
.61429 .89523 m .58056 .86169 L .58425 .85998 L p .591 .646 .874 r
F P
0 g
s
.58425 .85998 m .62041 .89271 L .61429 .89523 L p .591 .646 .874 r
F P
0 g
s
.22884 .42775 m .2274 .3878 L .20395 .39334 L p .561 .337 .532 r
F P
0 g
s
.20395 .39334 m .20374 .43373 L .22884 .42775 L p .561 .337 .532 r
F P
0 g
s
.75185 .91355 m .69806 .90131 L .70371 .89632 L p .6 .782 .968 r
F P
0 g
s
.70371 .89632 m .75984 .90734 L .75185 .91355 L p .6 .782 .968 r
F P
0 g
s
.76408 .46634 m .7637 .49621 L .76127 .48391 L p .902 .696 .188 r
F P
0 g
s
.76127 .48391 m .76137 .45309 L .76408 .46634 L p .902 .696 .188 r
F P
0 g
s
.1775 .48165 m .18125 .44203 L .16259 .45267 L p .381 .167 .459 r
F P
0 g
s
.16259 .45267 m .15829 .49318 L .1775 .48165 L p .381 .167 .459 r
F P
0 g
s
.81928 .89365 m .76669 .90043 L .77232 .89283 L p .706 .897 .965 r
F P
0 g
s
.77232 .89283 m .82643 .88429 L .81928 .89365 L p .706 .897 .965 r
F P
0 g
s
.69104 .18271 m .70483 .20565 L .68445 .19248 L p .72 .187 0 r
F P
0 g
s
.68445 .19248 m .6716 .17143 L .69104 .18271 L p .72 .187 0 r
F P
0 g
s
.28516 .87972 m .23843 .86422 L .24713 .8707 L p .146 .553 .926 r
F P
0 g
s
.24713 .8707 m .29134 .88565 L .28516 .87972 L p .146 .553 .926 r
F P
0 g
s
.5233 .83739 m .51994 .87236 L .52499 .87242 L p .696 .692 .843 r
F P
0 g
s
.52499 .87242 m .52568 .83744 L .5233 .83739 L p .696 .692 .843 r
F P
0 g
s
.52568 .83744 m .52499 .87242 L .53004 .87232 L p .689 .687 .843 r
F P
0 g
s
.53004 .87232 m .52806 .83742 L .52568 .83744 L p .689 .687 .843 r
F P
0 g
s
.52806 .83742 m .53004 .87232 L .53508 .87205 L p .683 .683 .844 r
F P
0 g
s
.52094 .83725 m .51491 .87212 L .51994 .87236 L p .702 .698 .843 r
F P
0 g
s
.51994 .87236 m .5233 .83739 L .52094 .83725 L p .702 .698 .843 r
F P
0 g
s
.35627 .32828 m .35174 .28077 L .33294 .28565 L p .587 .391 .582 r
F P
0 g
s
.33294 .28565 m .33713 .33219 L .35627 .32828 L p .587 .391 .582 r
F P
0 g
s
.53508 .87205 m .53043 .83732 L .52806 .83742 L p .683 .683 .844 r
F P
0 g
s
.53043 .83732 m .53508 .87205 L .54008 .87163 L p .676 .678 .844 r
F P
0 g
s
.34969 .8877 m .29814 .89161 L .30547 .89765 L p .552 .765 .977 r
F P
0 g
s
.30547 .89765 m .35492 .89266 L .34969 .8877 L p .552 .765 .977 r
F P
0 g
s
.46655 .85893 m .42933 .89078 L .4351 .89395 L p .75 .771 .87 r
F P
0 g
s
.4351 .89395 m .47009 .86082 L .46655 .85893 L p .75 .771 .87 r
F P
0 g
s
.51859 .83705 m .50993 .87172 L .51491 .87212 L p .708 .703 .843 r
F P
0 g
s
.51491 .87212 m .52094 .83725 L .51859 .83705 L p .708 .703 .843 r
F P
0 g
s
.54008 .87163 m .53278 .83714 L .53043 .83732 L p .676 .678 .844 r
F P
0 g
s
.53278 .83714 m .54008 .87163 L .54503 .87106 L p .67 .674 .845 r
F P
0 g
s
.85589 .62283 m .87022 .66592 L .85774 .65152 L p .906 .505 .227 r
F P
0 g
s
.85774 .65152 m .84118 .60964 L .85589 .62283 L p .906 .505 .227 r
F P
0 g
s
.51628 .83676 m .505 .87114 L .50993 .87172 L p .714 .709 .844 r
F P
0 g
s
.50993 .87172 m .51859 .83705 L .51628 .83676 L p .714 .709 .844 r
F P
0 g
s
.54503 .87106 m .53511 .83689 L .53278 .83714 L p .67 .674 .845 r
F P
0 g
s
.53511 .83689 m .54503 .87106 L .5499 .87034 L p .663 .67 .847 r
F P
0 g
s
.68466 .91012 m .63666 .88412 L .64128 .88087 L p .566 .689 .924 r
F P
0 g
s
.64128 .88087 m .69169 .90591 L .68466 .91012 L p .566 .689 .924 r
F P
0 g
s
.874 .84721 m .83172 .87397 L .83513 .86283 L p .871 .957 .859 r
F P
0 g
s
.83513 .86283 m .87721 .83394 L .874 .84721 L p .871 .957 .859 r
F P
0 g
s
.30154 .38101 m .29489 .33685 L .27225 .3389 L p .633 .422 .579 r
F P
0 g
s
.27225 .3389 m .27724 .38222 L .30154 .38101 L p .633 .422 .579 r
F P
0 g
s
.514 .8364 m .50016 .8704 L .505 .87114 L p .719 .715 .845 r
F P
0 g
s
.505 .87114 m .51628 .83676 L .514 .8364 L p .719 .715 .845 r
F P
0 g
s
.13856 .74818 m .12883 .69954 L .13878 .71069 L p .95 .638 .205 r
F P
0 g
s
.13878 .71069 m .14617 .75847 L .13856 .74818 L p .95 .638 .205 r
F P
0 g
s
.5499 .87034 m .53741 .83657 L .53511 .83689 L p .663 .67 .847 r
F P
0 g
s
.53741 .83657 m .5499 .87034 L .55469 .86949 L p .655 .666 .848 r
F P
0 g
s
.62041 .89271 m .58425 .85998 L .58771 .85816 L p .581 .644 .877 r
F P
0 g
s
.58771 .85816 m .6262 .89003 L .62041 .89271 L p .581 .644 .877 r
F P
0 g
s
.51178 .83597 m .49542 .86948 L .50016 .8704 L p .724 .721 .847 r
F P
0 g
s
.50016 .8704 m .514 .8364 L .51178 .83597 L p .724 .721 .847 r
F P
0 g
s
.55469 .86949 m .53966 .83617 L .53741 .83657 L p .655 .666 .848 r
F P
0 g
s
.53966 .83617 m .55469 .86949 L .55937 .8685 L p .648 .662 .85 r
F P
0 g
s
.2232 .85086 m .18657 .81855 L .19674 .82569 L p .488 0 0 r
F P
0 g
s
.17762 .81082 m .18657 .81855 L p .20582 .83435 L 0 .137 .643 r
F P
0 g
s
.19674 .82569 m .20977 .83808 L p .20871 .83708 L .488 0 0 r
F P
0 g
s
.21716 .84366 m .20484 .83343 L p .20582 .83435 L 0 .137 .643 r
F P
0 g
s
.20484 .83343 m .17762 .81082 L p .20582 .83435 L 0 .137 .643 r
F P
0 g
s
.23037 .85766 m .2232 .85086 L p .20871 .83708 L .488 0 0 r
F P
0 g
s
.20977 .83808 m .23037 .85766 L p .20871 .83708 L .488 0 0 r
F P
0 g
s
.42381 .24623 m .42701 .20971 L .44608 .19966 L p .461 .195 .423 r
F P
0 g
s
.42701 .20971 m .42381 .24623 L .40557 .2572 L p .469 .215 .445 r
F P
0 g
s
.12317 .60947 m .12901 .56368 L .12652 .57892 L p 0 0 0 r
F P
0 g
s
.12652 .57892 m .12056 .62441 L .12317 .60947 L p 0 0 0 r
F P
0 g
s
.40994 .87702 m .36067 .89763 L .36691 .90261 L p .704 .798 .923 r
F P
0 g
s
.36691 .90261 m .4142 .88058 L .40994 .87702 L p .704 .798 .923 r
F P
0 g
s
.7682 .50705 m .77884 .53428 L .7739 .52369 L p .698 .36 0 r
F P
0 g
s
.7739 .52369 m .7637 .49621 L .7682 .50705 L p .698 .36 0 r
F P
0 g
s
.50961 .83547 m .4908 .8684 L .49542 .86948 L p .73 .728 .849 r
F P
0 g
s
.49542 .86948 m .51178 .83597 L .50961 .83547 L p .73 .728 .849 r
F P
0 g
s
.46323 .85695 m .42391 .88748 L .42933 .89078 L p .753 .779 .874 r
F P
0 g
s
.42933 .89078 m .46655 .85893 L .46323 .85695 L p .753 .779 .874 r
F P
0 g
s
.90149 .77775 m .87792 .81985 L .87631 .80527 L p .982 .873 .648 r
F P
0 g
s
.87631 .80527 m .89777 .76155 L .90149 .77775 L p .982 .873 .648 r
F P
0 g
s
.89344 .69747 m .89161 .74526 L .88358 .72926 L p .974 .689 .421 r
F P
0 g
s
.88358 .72926 m .8824 .6813 L .89344 .69747 L p .974 .689 .421 r
F P
0 g
s
.55937 .8685 m .54186 .83571 L .53966 .83617 L p .648 .662 .85 r
F P
0 g
s
.54186 .83571 m .55937 .8685 L .56392 .86738 L p .641 .659 .852 r
F P
0 g
s
.79637 .55399 m .81534 .58615 L .80533 .5754 L p .797 .321 0 r
F P
0 g
s
.80533 .5754 m .78625 .54424 L .79637 .55399 L p .797 .321 0 r
F P
0 g
s
.75043 .25744 m .75428 .2981 L .74334 .27795 L p .956 .61 .27 r
F P
0 g
s
.74334 .27795 m .73778 .23888 L .75043 .25744 L p .956 .61 .27 r
F P
0 g
s
.76914 .33798 m .76325 .3817 L .75907 .36212 L p .997 .778 .432 r
F P
0 g
s
.75907 .36212 m .76266 .31836 L .76914 .33798 L p .997 .778 .432 r
F P
0 g
s
.50751 .8349 m .48631 .86717 L .4908 .8684 L p .735 .735 .851 r
F P
0 g
s
.4908 .8684 m .50961 .83547 L .50751 .8349 L p .735 .735 .851 r
F P
0 g
s
.56392 .86738 m .54399 .83517 L .54606 .83457 L p .633 .655 .855 r
F P
0 g
s
.54606 .83457 m .56833 .86613 L .56392 .86738 L p .633 .655 .855 r
F P
0 g
s
.56392 .86738 m .54399 .83517 L .54186 .83571 L p .641 .659 .852 r
F P
0 g
s
.6262 .89003 m .58771 .85816 L .59094 .85623 L p .572 .641 .881 r
F P
0 g
s
.59094 .85623 m .63163 .88717 L .6262 .89003 L p .572 .641 .881 r
F P
0 g
s
.6716 .17143 m .68445 .19248 L .66176 .18244 L p .686 .153 0 r
F P
0 g
s
.66176 .18244 m .65043 .16271 L .6716 .17143 L p .686 .153 0 r
F P
0 g
s
.37423 .32261 m .36993 .27452 L .35174 .28077 L p .566 .381 .59 r
F P
0 g
s
.35174 .28077 m .35627 .32828 L .37423 .32261 L p .566 .381 .59 r
F P
0 g
s
.50548 .83426 m .48198 .86578 L .48631 .86717 L p .739 .742 .854 r
F P
0 g
s
.48631 .86717 m .50751 .8349 L .50548 .83426 L p .739 .742 .854 r
F P
0 g
s
.56833 .86613 m .54606 .83457 L .54805 .8339 L p .624 .652 .857 r
F P
0 g
s
.54805 .8339 m .57259 .86477 L .56833 .86613 L p .624 .652 .857 r
F P
0 g
s
.25524 .42382 m .25221 .38426 L .2274 .3878 L p .607 .381 .549 r
F P
0 g
s
.2274 .3878 m .22884 .42775 L .25524 .42382 L p .607 .381 .549 r
F P
0 g
s
.46015 .85487 m .41886 .88407 L .42391 .88748 L p .756 .788 .879 r
F P
0 g
s
.42391 .88748 m .46323 .85695 L .46015 .85487 L p .756 .788 .879 r
F P
0 g
s
.69169 .90591 m .64128 .88087 L .64544 .87742 L p .563 .688 .924 r
F P
0 g
s
.64544 .87742 m .69806 .90131 L .69169 .90591 L p .563 .688 .924 r
F P
0 g
s
.44288 .23414 m .44608 .19966 L .46609 .18941 L p .455 .173 .394 r
F P
0 g
s
.44608 .19966 m .44288 .23414 L .42381 .24623 L p .461 .195 .423 r
F P
0 g
s
.75984 .90734 m .70371 .89632 L .70858 .89094 L p .613 .779 .96 r
F P
0 g
s
.70858 .89094 m .76669 .90043 L .75984 .90734 L p .613 .779 .96 r
F P
0 g
s
.50354 .83355 m .47783 .86426 L .48198 .86578 L p .744 .749 .857 r
F P
0 g
s
.48198 .86578 m .50548 .83426 L .50354 .83355 L p .744 .749 .857 r
F P
0 g
s
.3244 .37987 m .31663 .33485 L .29489 .33685 L p .64 .44 .596 r
F P
0 g
s
.29489 .33685 m .30154 .38101 L .3244 .37987 L p .64 .44 .596 r
F P
0 g
s
.57259 .86477 m .54805 .8339 L .54995 .83317 L p .615 .649 .86 r
F P
0 g
s
.54995 .83317 m .57667 .86329 L .57259 .86477 L p .615 .649 .86 r
F P
0 g
s
.76635 .39981 m .75975 .43789 L .75822 .42083 L p .975 .807 .39 r
F P
0 g
s
.75822 .42083 m .76325 .3817 L .76635 .39981 L p .975 .807 .39 r
F P
0 g
s
.15147 .53469 m .15829 .49318 L .14408 .5065 L p .144 0 .353 r
F P
0 g
s
.14408 .5065 m .13743 .54876 L .15147 .53469 L p .144 0 .353 r
F P
0 g
s
.34501 .88273 m .29134 .88565 L .29814 .89161 L p .552 .77 .979 r
F P
0 g
s
.29814 .89161 m .34969 .8877 L .34501 .88273 L p .552 .77 .979 r
F P
0 g
s
.40609 .8734 m .35492 .89266 L .36067 .89763 L p .704 .806 .928 r
F P
0 g
s
.36067 .89763 m .40994 .87702 L .40609 .8734 L p .704 .806 .928 r
F P
0 g
s
.17034 .80232 m .14617 .75847 L .15633 .76762 L p .8 .379 0 r
F P
0 g
s
.15633 .76762 m .17762 .81082 L .17034 .80232 L p .8 .379 0 r
F P
0 g
s
.50169 .83278 m .47386 .8626 L .47783 .86426 L p .748 .757 .86 r
F P
0 g
s
.47783 .86426 m .50354 .83355 L .50169 .83278 L p .748 .757 .86 r
F P
0 g
s
.84118 .60964 m .85774 .65152 L .84569 .63816 L p .892 .47 .165 r
F P
0 g
s
.84569 .63816 m .82743 .59747 L .84118 .60964 L p .892 .47 .165 r
F P
0 g
s
.63163 .88717 m .59094 .85623 L .59392 .85419 L p .563 .639 .884 r
F P
0 g
s
.59392 .85419 m .63666 .88412 L .63163 .88717 L p .563 .639 .884 r
F P
0 g
s
.20066 .4722 m .20374 .43373 L .18125 .44203 L p .489 .258 .491 r
F P
0 g
s
.18125 .44203 m .1775 .48165 L .20066 .4722 L p .489 .258 .491 r
F P
0 g
s
.82643 .88429 m .77232 .89283 L .77666 .88462 L p .734 .882 .949 r
F P
0 g
s
.77666 .88462 m .83172 .87397 L .82643 .88429 L p .734 .882 .949 r
F P
0 g
s
.76137 .45309 m .76127 .48391 L .76004 .46998 L p .814 .639 .085 r
F P
0 g
s
.76004 .46998 m .75975 .43789 L .76137 .45309 L p .814 .639 .085 r
F P
0 g
s
.57667 .86329 m .54995 .83317 L .55176 .83239 L p .606 .646 .864 r
F P
0 g
s
.55176 .83239 m .58056 .86169 L .57667 .86329 L p .606 .646 .864 r
F P
0 g
s
.12067 .67355 m .12056 .62441 L .12332 .63874 L p .837 .666 .124 r
F P
0 g
s
.12332 .63874 m .12259 .68711 L .12074 .67408 L p .837 .666 .124 r
F P
0 g
s
.12332 .63874 m .12074 .67408 L .12075 .67246 L .837 .666 .124 r
F
.12346 .65916 m .12317 .60947 L .12105 .62159 L p 0 0 .152 r
F P
0 g
s
.12105 .62159 m .12056 .62441 L p .121 .62974 L 0 0 .152 r
F P
0 g
s
.121 .62974 m .12346 .65916 L .12105 .62159 L 0 0 .152 r
F
.12074 .67408 m .12067 .67355 L p .12075 .67246 L .837 .666 .124 r
F P
0 g
s
.27969 .87371 m .23037 .85766 L .23843 .86422 L p .191 .576 .94 r
F P
0 g
s
.23843 .86422 m .28516 .87972 L .27969 .87371 L p .191 .576 .94 r
F P
0 g
s
.45733 .85271 m .4142 .88058 L .41886 .88407 L p .758 .797 .884 r
F P
0 g
s
.41886 .88407 m .46015 .85487 L .45733 .85271 L p .758 .797 .884 r
F P
0 g
s
.49993 .83196 m .47009 .86082 L .47386 .8626 L p .752 .765 .864 r
F P
0 g
s
.47386 .8626 m .50169 .83278 L .49993 .83196 L p .752 .765 .864 r
F P
0 g
s
.65043 .16271 m .66176 .18244 L .6372 .17598 L p .647 .126 0 r
F P
0 g
s
.6372 .17598 m .62785 .15686 L .65043 .16271 L p .647 .126 0 r
F P
0 g
s
.46316 .22144 m .46609 .18941 L .48714 .17948 L p .455 .15 .358 r
F P
0 g
s
.46609 .18941 m .46316 .22144 L .44288 .23414 L p .455 .173 .394 r
F P
0 g
s
.37423 .32261 m .36993 .27452 L .38775 .26668 L p .547 .369 .592 r
F P
0 g
s
.58056 .86169 m .55176 .83239 L .55346 .83154 L p .597 .643 .867 r
F P
0 g
s
.55346 .83154 m .58425 .85998 L .58056 .86169 L p .597 .643 .867 r
F P
0 g
s
.78625 .54424 m .80533 .5754 L .79749 .5649 L p .683 .24 0 r
F P
0 g
s
.79749 .5649 m .77884 .53428 L .78625 .54424 L p .683 .24 0 r
F P
0 g
s
.34541 .37806 m .33713 .33219 L .31663 .33485 L p .635 .448 .612 r
F P
0 g
s
.31663 .33485 m .3244 .37987 L .34541 .37806 L p .635 .448 .612 r
F P
0 g
s
.49828 .83108 m .46655 .85893 L .47009 .86082 L p .755 .773 .867 r
F P
0 g
s
.47009 .86082 m .49993 .83196 L .49828 .83108 L p .755 .773 .867 r
F P
0 g
s
.63666 .88412 m .59392 .85419 L .59663 .85205 L p .554 .637 .888 r
F P
0 g
s
.59663 .85205 m .64128 .88087 L .63666 .88412 L p .554 .637 .888 r
F P
0 g
s
.7637 .49621 m .7739 .52369 L .77085 .51215 L p 0 0 .317 r
F P
0 g
s
.77085 .51215 m .76127 .48391 L .7637 .49621 L p 0 0 .317 r
F P
0 g
s
.28167 .42147 m .27724 .38222 L .25221 .38426 L p .636 .414 .563 r
F P
0 g
s
.25221 .38426 m .25524 .42382 L .28167 .42147 L p .636 .414 .563 r
F P
0 g
s
.87721 .83394 m .83513 .86283 L .83668 .85105 L p .889 .92 .838 r
F P
0 g
s
.83668 .85105 m .87792 .81985 L .87721 .83394 L p .889 .92 .838 r
F P
0 g
s
.69806 .90131 m .64544 .87742 L .64912 .87377 L p .562 .688 .924 r
F P
0 g
s
.64912 .87377 m .70371 .89632 L .69806 .90131 L p .562 .688 .924 r
F P
0 g
s
.58425 .85998 m .55346 .83154 L .55506 .83064 L p .587 .641 .871 r
F P
0 g
s
.55506 .83064 m .58771 .85816 L .58425 .85998 L p .587 .641 .871 r
F P
0 g
s
.8824 .6813 m .88358 .72926 L .8743 .71383 L p .961 .655 .401 r
F P
0 g
s
.8743 .71383 m .87022 .66592 L .8824 .6813 L p .961 .655 .401 r
F P
0 g
s
.73778 .23888 m .74334 .27795 L .72937 .2588 L p .935 .564 .264 r
F P
0 g
s
.72937 .2588 m .72263 .22136 L .73778 .23888 L p .935 .564 .264 r
F P
0 g
s
.48487 .20882 m .48714 .17948 L .50924 .17043 L p .461 .129 .317 r
F P
0 g
s
.48714 .17948 m .48487 .20882 L .46316 .22144 L p .455 .15 .358 r
F P
0 g
s
.45478 .85047 m .40994 .87702 L .4142 .88058 L p .76 .807 .89 r
F P
0 g
s
.4142 .88058 m .45733 .85271 L .45478 .85047 L p .76 .807 .89 r
F P
0 g
s
.40267 .86973 m .34969 .8877 L .35492 .89266 L p .704 .813 .933 r
F P
0 g
s
.35492 .89266 m .40609 .8734 L .40267 .86973 L p .704 .813 .933 r
F P
0 g
s
.49674 .83015 m .46323 .85695 L .46655 .85893 L p .759 .781 .872 r
F P
0 g
s
.46655 .85893 m .49828 .83108 L .49674 .83015 L p .759 .781 .872 r
F P
0 g
s
.62785 .15686 m .6372 .17598 L .61137 .17334 L p .604 .107 .046 r
F P
0 g
s
.61137 .17334 m .60429 .15405 L .62785 .15686 L p .604 .107 .046 r
F P
0 g
s
.89777 .76155 m .87631 .80527 L .87268 .79049 L p .976 .829 .632 r
F P
0 g
s
.87268 .79049 m .89161 .74526 L .89777 .76155 L p .976 .829 .632 r
F P
0 g
s
.76669 .90043 m .70858 .89094 L .71263 .88518 L p .626 .776 .953 r
F P
0 g
s
.71263 .88518 m .77232 .89283 L .76669 .90043 L p .626 .776 .953 r
F P
0 g
s
.58771 .85816 m .55506 .83064 L .55654 .8297 L p .578 .639 .875 r
F P
0 g
s
.55654 .8297 m .59094 .85623 L .58771 .85816 L p .578 .639 .875 r
F P
0 g
s
.18657 .81855 m .2232 .85086 L .21716 .84366 L p 0 .137 .643 r
F P
0 g
s
.76266 .31836 m .75907 .36212 L .75287 .34166 L p .993 .745 .404 r
F P
0 g
s
.75287 .34166 m .75428 .2981 L .76266 .31836 L p .993 .745 .404 r
F P
0 g
s
.52568 .83744 m .52629 .81312 L .5233 .83739 L closepath p .672 .736 .898 r
F P
0 g
s
.52806 .83742 m .52629 .81312 L .52568 .83744 L closepath p .669 .733 .898 r
F P
0 g
s
.39137 .31489 m .38775 .26668 L .40557 .2572 L p .534 .357 .588 r
F P
0 g
s
.38775 .26668 m .39137 .31489 L .37423 .32261 L p .547 .369 .592 r
F P
0 g
s
.53043 .83732 m .52629 .81312 L .52806 .83742 L closepath p .665 .73 .898 r
F P
0 g
s
.49532 .82917 m .46015 .85487 L .46323 .85695 L p .762 .79 .876 r
F P
0 g
s
.46323 .85695 m .49674 .83015 L .49532 .82917 L p .762 .79 .876 r
F P
0 g
s
.34093 .87773 m .28516 .87972 L .29134 .88565 L p .556 .774 .98 r
F P
0 g
s
.29134 .88565 m .34501 .88273 L .34093 .87773 L p .556 .774 .98 r
F P
0 g
s
.5233 .83739 m .52629 .81312 L .52094 .83725 L closepath p .675 .739 .898 r
F P
0 g
s
.53278 .83714 m .52629 .81312 L .53043 .83732 L closepath p .661 .728 .899 r
F P
0 g
s
.52094 .83725 m .52629 .81312 L .51859 .83705 L closepath p .678 .742 .899 r
F P
0 g
s
.64128 .88087 m .59663 .85205 L .59906 .84982 L p .546 .636 .891 r
F P
0 g
s
.59906 .84982 m .64544 .87742 L .64128 .88087 L p .546 .636 .891 r
F P
0 g
s
.13127 .59439 m .13743 .54876 L .12901 .56368 L p 0 0 .21 r
F P
0 g
s
.12901 .56368 m .12317 .60947 L .13127 .59439 L p 0 0 .21 r
F P
0 g
s
.53511 .83689 m .52629 .81312 L .53278 .83714 L closepath p .658 .725 .899 r
F P
0 g
s
.82743 .59747 m .84569 .63816 L .83466 .62575 L p .873 .432 .075 r
F P
0 g
s
.83466 .62575 m .81534 .58615 L .82743 .59747 L p .873 .432 .075 r
F P
0 g
s
.5081 .19704 m .50924 .17043 L .5323 .16286 L p .475 .112 .27 r
F P
0 g
s
.50924 .17043 m .5081 .19704 L .48487 .20882 L p .461 .129 .317 r
F P
0 g
s
.51859 .83705 m .52629 .81312 L .51628 .83676 L closepath p .681 .745 .899 r
F P
0 g
s
.13408 .73672 m .12259 .68711 L .12883 .69954 L p .824 .537 0 r
F P
0 g
s
.12883 .69954 m .13856 .74818 L .13532 .7399 L p .824 .537 0 r
F P
0 g
s
.12883 .69954 m .13532 .7399 L .13327 .73099 L .824 .537 0 r
F
.1332 .72417 m .12067 .67355 L .12166 .68054 L p 0 0 .273 r
F P
0 g
s
.12166 .68054 m .12259 .68711 L p .12556 .69751 L 0 0 .273 r
F P
0 g
s
.12556 .69751 m .1332 .72417 L .12166 .68054 L 0 0 .273 r
F
.13532 .7399 m .13408 .73672 L p .13327 .73099 L .824 .537 0 r
F P
0 g
s
.53741 .83657 m .52629 .81312 L .53511 .83689 L closepath p .654 .723 .9 r
F P
0 g
s
.36447 .37489 m .35627 .32828 L .33713 .33219 L p .619 .446 .626 r
F P
0 g
s
.33713 .33219 m .34541 .37806 L .36447 .37489 L p .619 .446 .626 r
F P
0 g
s
.51628 .83676 m .52629 .81312 L .514 .8364 L closepath p .684 .748 .9 r
F P
0 g
s
.53966 .83617 m .52629 .81312 L .53741 .83657 L closepath p .649 .721 .901 r
F P
0 g
s
.60429 .15405 m .61137 .17334 L .58491 .17448 L p .563 .097 .106 r
F P
0 g
s
.58491 .17448 m .58021 .15426 L .60429 .15405 L p .563 .097 .106 r
F P
0 g
s
.22649 .46487 m .22884 .42775 L .20374 .43373 L p .557 .318 .508 r
F P
0 g
s
.20374 .43373 m .20066 .4722 L .22649 .46487 L p .557 .318 .508 r
F P
0 g
s
.514 .8364 m .52629 .81312 L .51178 .83597 L closepath p .687 .752 .901 r
F P
0 g
s
.59094 .85623 m .55654 .8297 L .5579 .8287 L p .569 .638 .879 r
F P
0 g
s
.5579 .8287 m .59392 .85419 L .59094 .85623 L p .569 .638 .879 r
F P
0 g
s
.54186 .83571 m .52629 .81312 L .53966 .83617 L closepath p .645 .719 .902 r
F P
0 g
s
.30706 .42006 m .30154 .38101 L .27724 .38222 L p .654 .437 .577 r
F P
0 g
s
.27724 .38222 m .28167 .42147 L .30706 .42006 L p .654 .437 .577 r
F P
0 g
s
.51178 .83597 m .52629 .81312 L .50961 .83547 L closepath p .689 .755 .902 r
F P
0 g
s
.45251 .84818 m .40609 .8734 L .40994 .87702 L p .762 .816 .895 r
F P
0 g
s
.40994 .87702 m .45478 .85047 L .45251 .84818 L p .762 .816 .895 r
F P
0 g
s
.54399 .83517 m .52629 .81312 L .54186 .83571 L closepath p .641 .717 .903 r
F P
0 g
s
.50961 .83547 m .52629 .81312 L .50751 .8349 L closepath p .692 .759 .903 r
F P
0 g
s
.53275 .1869 m .5323 .16286 L .55607 .15731 L p .497 .101 .219 r
F P
0 g
s
.5323 .16286 m .53275 .1869 L .5081 .19704 L p .475 .112 .27 r
F P
0 g
s
.49403 .82815 m .45733 .85271 L .46015 .85487 L p .764 .798 .881 r
F P
0 g
s
.46015 .85487 m .49532 .82917 L .49403 .82815 L p .764 .798 .881 r
F P
0 g
s
.52629 .81312 m .54606 .83457 L .54399 .83517 L closepath p .636 .715 .904 r
F P
0 g
s
.58021 .15426 m .58491 .17448 L .55851 .17917 L p .527 .095 .164 r
F P
0 g
s
.55851 .17917 m .55607 .15731 L .58021 .15426 L p .527 .095 .164 r
F P
0 g
s
.70371 .89632 m .64912 .87377 L .65229 .86993 L p .562 .687 .924 r
F P
0 g
s
.65229 .86993 m .70858 .89094 L .70371 .89632 L p .562 .687 .924 r
F P
0 g
s
.50751 .8349 m .52629 .81312 L .50548 .83426 L closepath p .694 .763 .905 r
F P
0 g
s
.55607 .15731 m .55851 .17917 L .53275 .1869 L p .497 .101 .219 r
F P
0 g
s
.17044 .52193 m .1775 .48165 L .15829 .49318 L p .34 .116 .422 r
F P
0 g
s
.15829 .49318 m .15147 .53469 L .17044 .52193 L p .34 .116 .422 r
F P
0 g
s
.52629 .81312 m .54805 .8339 L .54606 .83457 L closepath p .632 .714 .906 r
F P
0 g
s
.83172 .87397 m .77666 .88462 L .77969 .87587 L p .753 .866 .931 r
F P
0 g
s
.77969 .87587 m .83513 .86283 L .83172 .87397 L p .753 .866 .931 r
F P
0 g
s
.50548 .83426 m .52629 .81312 L .50354 .83355 L closepath p .696 .767 .906 r
F P
0 g
s
.59392 .85419 m .5579 .8287 L .55914 .82766 L p .56 .636 .884 r
F P
0 g
s
.55914 .82766 m .59663 .85205 L .59392 .85419 L p .56 .636 .884 r
F P
0 g
s
.76325 .3817 m .75822 .42083 L .75568 .40225 L p .973 .781 .354 r
F P
0 g
s
.75568 .40225 m .75907 .36212 L .76325 .3817 L p .973 .781 .354 r
F P
0 g
s
.52629 .81312 m .54995 .83317 L .54805 .8339 L closepath p .627 .713 .908 r
F P
0 g
s
.3997 .86601 m .34501 .88273 L .34969 .8877 L p .704 .821 .938 r
F P
0 g
s
.34969 .8877 m .40267 .86973 L .3997 .86601 L p .704 .821 .938 r
F P
0 g
s
.50354 .83355 m .52629 .81312 L .50169 .83278 L closepath p .698 .771 .908 r
F P
0 g
s
.7922 .55621 m .79749 .5649 L .79162 .5543 L p 0 0 .414 r
F P
0 g
s
.79162 .5543 m .79749 .5649 L p .80669 .5857 L .69 .304 0 r
F P
0 g
s
.80972 .59254 m .80584 .58435 L p .80669 .5857 L .69 .304 0 r
F P
0 g
s
.80584 .58435 m .79162 .5543 L p .80669 .5857 L .69 .304 0 r
F P
0 g
s
.79162 .5543 m .80972 .59254 L .8036 .58201 L p 0 0 .288 r
F P
0 g
s
.8036 .58201 m .791 .55222 L p .79162 .5543 L 0 0 .288 r
F P
0 g
s
.791 .55222 m .78722 .54331 L .79162 .5543 L p 0 0 .288 r
F P
0 g
s
.77884 .53428 m .7922 .55621 L p .79162 .5543 L 0 0 .414 r
F P
0 g
s
.79162 .5543 m .7739 .52369 L .77884 .53428 L p 0 0 .414 r
F P
0 g
s
.7739 .52369 m .78922 .55014 L p .78722 .54331 L 0 0 .454 r
F P
0 g
s
.78922 .55014 m .79162 .5543 L .78722 .54331 L p 0 0 .454 r
F P
0 g
s
.78722 .54331 m .80203 .57828 L p .79778 .5714 L 0 0 .26 r
F P
0 g
s
.79778 .5714 m .78505 .53588 L p .78722 .54331 L 0 0 .26 r
F P
0 g
s
.78505 .53588 m .78357 .53172 L .78722 .54331 L p 0 0 .26 r
F P
0 g
s
.80203 .57828 m .8036 .58201 L .7983 .57236 L p 0 0 .26 r
F P
0 g
s
.7983 .57236 m .79778 .5714 L p .80203 .57828 L 0 0 .26 r
F P
0 g
s
.64544 .87742 m .59906 .84982 L .6012 .8475 L p .538 .635 .895 r
F P
0 g
s
.6012 .8475 m .64912 .87377 L .64544 .87742 L p .538 .635 .895 r
F P
0 g
s
.52629 .81312 m .55176 .83239 L .54995 .83317 L closepath p .623 .712 .91 r
F P
0 g
s
.49286 .82708 m .45478 .85047 L .45733 .85271 L p .766 .807 .886 r
F P
0 g
s
.45733 .85271 m .49403 .82815 L .49286 .82708 L p .766 .807 .886 r
F P
0 g
s
.75975 .43789 m .76 .46575 L p .75895 .45443 L .784 .613 .049 r
F P
0 g
s
.75895 .45443 m .75822 .42083 L .75975 .43789 L p .784 .613 .049 r
F P
0 g
s
.75822 .42083 m .75895 .45443 L .75686 .43751 L p .817 .625 .071 r
F P
0 g
s
.764 .47062 m .75776 .44168 L p .75895 .45443 L 0 0 .21 r
F P
0 g
s
.75776 .44168 m .75686 .43751 L .75895 .45443 L p 0 0 .21 r
F P
0 g
s
.76 .46575 m .76004 .46998 L .75895 .45443 L p .784 .613 .049 r
F P
0 g
s
.27507 .86755 m .2232 .85086 L .23037 .85766 L p .244 .6 .951 r
F P
0 g
s
.23037 .85766 m .27969 .87371 L .27507 .86755 L p .244 .6 .951 r
F P
0 g
s
.50169 .83278 m .52629 .81312 L .49993 .83196 L closepath p .699 .775 .91 r
F P
0 g
s
.52629 .81312 m .55346 .83154 L .55176 .83239 L closepath p .618 .711 .912 r
F P
0 g
s
.38182 .36981 m .37423 .32261 L .35627 .32828 L p .592 .433 .636 r
F P
0 g
s
.35627 .32828 m .36447 .37489 L .38182 .36981 L p .592 .433 .636 r
F P
0 g
s
.40821 .30502 m .40557 .2572 L .42381 .24623 L p .521 .342 .578 r
F P
0 g
s
.40557 .2572 m .40821 .30502 L .39137 .31489 L p .534 .357 .588 r
F P
0 g
s
.33061 .41886 m .3244 .37987 L .30154 .38101 L p .66 .451 .591 r
F P
0 g
s
.30154 .38101 m .30706 .42006 L .33061 .41886 L p .66 .451 .591 r
F P
0 g
s
.45052 .84582 m .40267 .86973 L .40609 .8734 L p .763 .826 .901 r
F P
0 g
s
.40609 .8734 m .45251 .84818 L .45052 .84582 L p .763 .826 .901 r
F P
0 g
s
.49993 .83196 m .52629 .81312 L .49828 .83108 L closepath p .701 .779 .912 r
F P
0 g
s
.59663 .85205 m .55914 .82766 L .56024 .82658 L p .551 .635 .888 r
F P
0 g
s
.56024 .82658 m .59906 .84982 L .59663 .85205 L p .551 .635 .888 r
F P
0 g
s
.52629 .81312 m .55506 .83064 L .55346 .83154 L closepath p .614 .71 .914 r
F P
0 g
s
.87022 .66592 m .8743 .71383 L .86439 .69921 L p .953 .628 .372 r
F P
0 g
s
.86439 .69921 m .85774 .65152 L .87022 .66592 L p .953 .628 .372 r
F P
0 g
s
.72263 .22136 m .72937 .2588 L .71214 .24156 L p .905 .517 .272 r
F P
0 g
s
.71214 .24156 m .70483 .20565 L .72263 .22136 L p .905 .517 .272 r
F P
0 g
s
.49828 .83108 m .52629 .81312 L .49674 .83015 L closepath p .702 .783 .914 r
F P
0 g
s
.14617 .75847 m .17034 .80232 L .1692 .80024 L p 0 0 .343 r
F P
0 g
s
.1692 .80024 m .16519 .79293 L p .16024 .78397 L 0 0 .343 r
F P
0 g
s
.14617 .75847 m .1692 .80024 L .16024 .78397 L 0 0 .343 r
F
.16519 .79293 m .13856 .74818 L .14617 .75847 L p F P
0 g
s
.13408 .73672 m .13856 .74818 L p .14798 .76171 L 0 0 .546 r
F P
0 g
s
.16254 .7826 m .13533 .73873 L p .14798 .76171 L 0 0 .546 r
F P
0 g
s
.13533 .73873 m .13408 .73672 L p .14798 .76171 L 0 0 .546 r
F P
0 g
s
.49183 .82599 m .45251 .84818 L .45478 .85047 L p .768 .816 .891 r
F P
0 g
s
.45478 .85047 m .49286 .82708 L .49183 .82599 L p .768 .816 .891 r
F P
0 g
s
.76127 .48391 m .77085 .51215 L .76887 .49946 L p 0 0 .331 r
F P
0 g
s
.76887 .49946 m .76004 .46998 L .76127 .48391 L p 0 0 .331 r
F P
0 g
s
.52629 .81312 m .55654 .8297 L .55506 .83064 L closepath p .609 .71 .916 r
F P
0 g
s
.77232 .89283 m .71263 .88518 L .71583 .87908 L p .637 .772 .945 r
F P
0 g
s
.71583 .87908 m .77666 .88462 L .77232 .89283 L p .637 .772 .945 r
F P
0 g
s
.87792 .81985 m .83668 .85105 L .83648 .83884 L p .896 .885 .815 r
F P
0 g
s
.83648 .83884 m .87631 .80527 L .87792 .81985 L p .896 .885 .815 r
F P
0 g
s
.25359 .45951 m .25524 .42382 L .22884 .42775 L p .603 .358 .518 r
F P
0 g
s
.22884 .42775 m .22649 .46487 L .25359 .45951 L p .603 .358 .518 r
F P
0 g
s
.49674 .83015 m .52629 .81312 L .49532 .82917 L closepath p .703 .787 .917 r
F P
0 g
s
.52629 .81312 m .5579 .8287 L .55654 .8297 L closepath p .604 .71 .919 r
F P
0 g
s
.59906 .84982 m .56024 .82658 L .5612 .82547 L p .541 .635 .893 r
F P
0 g
s
.5612 .82547 m .6012 .8475 L .59906 .84982 L p .541 .635 .893 r
F P
0 g
s
.12056 .62441 m .12067 .67355 L .12346 .65916 L p 0 0 .152 r
F P
0 g
s
.81534 .58615 m .83466 .62575 L .82496 .61417 L p .837 .388 0 r
F P
0 g
s
.82496 .61417 m .80533 .5754 L .81534 .58615 L p .837 .388 0 r
F P
0 g
s
.64912 .87377 m .6012 .8475 L .60304 .84509 L p .531 .635 .899 r
F P
0 g
s
.60304 .84509 m .65229 .86993 L .64912 .87377 L p .531 .635 .899 r
F P
0 g
s
.3375 .87267 m .27969 .87371 L .28516 .87972 L p .561 .778 .98 r
F P
0 g
s
.28516 .87972 m .34093 .87773 L .3375 .87267 L p .561 .778 .98 r
F P
0 g
s
.70858 .89094 m .65229 .86993 L .65493 .86591 L p .563 .687 .924 r
F P
0 g
s
.65493 .86591 m .71263 .88518 L .70858 .89094 L p .563 .687 .924 r
F P
0 g
s
.49532 .82917 m .52629 .81312 L .49403 .82815 L closepath p .703 .792 .919 r
F P
0 g
s
.89161 .74526 m .87268 .79049 L .86739 .77583 L p .968 .793 .613 r
F P
0 g
s
.86739 .77583 m .88358 .72926 L .89161 .74526 L p .968 .793 .613 r
F P
0 g
s
.35189 .41712 m .34541 .37806 L .3244 .37987 L p .653 .456 .605 r
F P
0 g
s
.3244 .37987 m .33061 .41886 L .35189 .41712 L p .653 .456 .605 r
F P
0 g
s
.52629 .81312 m .55914 .82766 L .5579 .8287 L closepath p .6 .71 .921 r
F P
0 g
s
.49094 .82486 m .45052 .84582 L .45251 .84818 L p .769 .825 .896 r
F P
0 g
s
.45251 .84818 m .49183 .82599 L .49094 .82486 L p .769 .825 .896 r
F P
0 g
s
.49403 .82815 m .52629 .81312 L .49286 .82708 L closepath p .704 .796 .922 r
F P
0 g
s
.44883 .84342 m .3997 .86601 L .40267 .86973 L p .764 .835 .906 r
F P
0 g
s
.40267 .86973 m .45052 .84582 L .44883 .84342 L p .764 .835 .906 r
F P
0 g
s
.39721 .86223 m .34093 .87773 L .34501 .88273 L p .703 .828 .942 r
F P
0 g
s
.34501 .88273 m .3997 .86601 L .39721 .86223 L p .703 .828 .942 r
F P
0 g
s
.52629 .81312 m .56024 .82658 L .55914 .82766 L closepath p .595 .71 .924 r
F P
0 g
s
.75428 .2981 m .75287 .34166 L .74382 .32113 L p .985 .706 .394 r
F P
0 g
s
.74382 .32113 m .74334 .27795 L .75428 .2981 L p .985 .706 .394 r
F P
0 g
s
.38182 .36981 m .37423 .32261 L .39137 .31489 L p .563 .416 .639 r
F P
0 g
s
.6012 .8475 m .5612 .82547 L .56202 .82433 L p .532 .634 .897 r
F P
0 g
s
.56202 .82433 m .60304 .84509 L .6012 .8475 L p .532 .634 .897 r
F P
0 g
s
.49286 .82708 m .52629 .81312 L .49183 .82599 L closepath p .704 .8 .925 r
F P
0 g
s
.42537 .29318 m .42381 .24623 L .44288 .23414 L p .512 .324 .563 r
F P
0 g
s
.42381 .24623 m .42537 .29318 L .40821 .30502 L p .521 .342 .578 r
F P
0 g
s
.52629 .81312 m .5612 .82547 L .56024 .82658 L closepath p .591 .71 .926 r
F P
0 g
s
.49019 .8237 m .44883 .84342 L .45052 .84582 L p .77 .834 .901 r
F P
0 g
s
.45052 .84582 m .49094 .82486 L .49019 .8237 L p .77 .834 .901 r
F P
0 g
s
.49183 .82599 m .52629 .81312 L .49094 .82486 L closepath p .703 .805 .928 r
F P
0 g
s
.21254 .83593 m .17034 .80232 L .17762 .81082 L p 0 .253 .754 r
F P
0 g
s
.17762 .81082 m .21716 .84366 L .21254 .83593 L p 0 .253 .754 r
F P
0 g
s
.19332 .51082 m .20066 .4722 L .1775 .48165 L p .453 .208 .452 r
F P
0 g
s
.1775 .48165 m .17044 .52193 L .19332 .51082 L p .453 .208 .452 r
F P
0 g
s
.28066 .45574 m .28167 .42147 L .25524 .42382 L p .632 .385 .526 r
F P
0 g
s
.25524 .42382 m .25359 .45951 L .28066 .45574 L p .632 .385 .526 r
F P
0 g
s
.37082 .41415 m .36447 .37489 L .34541 .37806 L p .632 .45 .618 r
F P
0 g
s
.34541 .37806 m .35189 .41712 L .37082 .41415 L p .632 .45 .618 r
F P
0 g
s
.52629 .81312 m .56202 .82433 L .5612 .82547 L closepath p .586 .711 .929 r
F P
0 g
s
.65229 .86993 m .60304 .84509 L .60457 .84261 L p .524 .635 .902 r
F P
0 g
s
.60457 .84261 m .65493 .86591 L .65229 .86993 L p .524 .635 .902 r
F P
0 g
s
.1446 .57965 m .15147 .53469 L .13743 .54876 L p .112 0 .352 r
F P
0 g
s
.13743 .54876 m .13127 .59439 L .1446 .57965 L p .112 0 .352 r
F P
0 g
s
.83513 .86283 m .77969 .87587 L .78141 .8667 L p .767 .85 .913 r
F P
0 g
s
.78141 .8667 m .83668 .85105 L .83513 .86283 L p .767 .85 .913 r
F P
0 g
s
.49094 .82486 m .52629 .81312 L .49019 .8237 L closepath p .703 .809 .931 r
F P
0 g
s
.60304 .84509 m .56202 .82433 L .5627 .82316 L p .523 .635 .902 r
F P
0 g
s
.5627 .82316 m .60457 .84261 L .60304 .84509 L p .523 .635 .902 r
F P
0 g
s
.52629 .81312 m .5627 .82316 L .56202 .82433 L closepath p .582 .712 .932 r
F P
0 g
s
.78722 .54331 m .77085 .51215 L .7739 .52369 L p 0 0 .454 r
F P
0 g
s
.44745 .84097 m .39721 .86223 L .3997 .86601 L p .764 .845 .912 r
F P
0 g
s
.3997 .86601 m .44883 .84342 L .44745 .84097 L p .764 .845 .912 r
F P
0 g
s
.49019 .8237 m .52629 .81312 L .48959 .82253 L closepath p .702 .813 .934 r
F P
0 g
s
.44883 .84342 m .49019 .8237 L .48959 .82253 L p .77 .843 .907 r
F P
0 g
s
.48959 .82253 m .44745 .84097 L .44883 .84342 L p .77 .843 .907 r
F P
0 g
s
.70483 .20565 m .71214 .24156 L .69169 .22711 L p .864 .469 .289 r
F P
0 g
s
.69169 .22711 m .68445 .19248 L .70483 .20565 L p .864 .469 .289 r
F P
0 g
s
.71263 .88518 m .65493 .86591 L .65704 .86174 L p .563 .688 .924 r
F P
0 g
s
.65704 .86174 m .71583 .87908 L .71263 .88518 L p .563 .688 .924 r
F P
0 g
s
.85774 .65152 m .86439 .69921 L .85438 .6855 L p .949 .608 .333 r
F P
0 g
s
.85438 .6855 m .84569 .63816 L .85774 .65152 L p .949 .608 .333 r
F P
0 g
s
.60457 .84261 m .5627 .82316 L .56323 .82197 L p .513 .635 .907 r
F P
0 g
s
.52629 .81312 m .56323 .82197 L .5627 .82316 L closepath p .577 .713 .935 r
F P
0 g
s
.77666 .88462 m .71583 .87908 L .71815 .87268 L p .647 .769 .937 r
F P
0 g
s
.71815 .87268 m .77969 .87587 L .77666 .88462 L p .647 .769 .937 r
F P
0 g
s
.12259 .68711 m .13408 .73672 L .1332 .72417 L p 0 0 .273 r
F P
0 g
s
.48959 .82253 m .52629 .81312 L .48914 .82133 L closepath p .7 .817 .937 r
F P
0 g
s
.44745 .84097 m .48959 .82253 L .48914 .82133 L p .77 .853 .913 r
F P
0 g
s
.75907 .36212 m .75568 .40225 L .75104 .3827 L p .982 .758 .351 r
F P
0 g
s
.75104 .3827 m .75287 .34166 L .75907 .36212 L p .982 .758 .351 r
F P
0 g
s
.39792 .36246 m .39137 .31489 L .40821 .30502 L p .54 .398 .636 r
F P
0 g
s
.39137 .31489 m .39792 .36246 L .38182 .36981 L p .563 .416 .639 r
F P
0 g
s
.27143 .86115 m .21716 .84366 L .2232 .85086 L p .299 .622 .959 r
F P
0 g
s
.2232 .85086 m .27507 .86755 L .27143 .86115 L p .299 .622 .959 r
F P
0 g
s
.30659 .45303 m .30706 .42006 L .28167 .42147 L p .65 .402 .531 r
F P
0 g
s
.28167 .42147 m .28066 .45574 L .30659 .45303 L p .65 .402 .531 r
F P
0 g
s
.65493 .86591 m .60457 .84261 L .60577 .84006 L p .517 .636 .906 r
F P
0 g
s
.56323 .82197 m .60577 .84006 L .60457 .84261 L p .513 .635 .907 r
F P
0 g
s
.60577 .84006 m .56323 .82197 L .56361 .82076 L p .503 .636 .913 r
F P
0 g
s
.52629 .81312 m .56361 .82076 L .56323 .82197 L closepath p .573 .714 .938 r
F P
0 g
s
.44345 .27973 m .44288 .23414 L .46316 .22144 L p .508 .307 .543 r
F P
0 g
s
.44288 .23414 m .44345 .27973 L .42537 .29318 L p .512 .324 .563 r
F P
0 g
s
.38766 .40939 m .38182 .36981 L .36447 .37489 L p .595 .43 .628 r
F P
0 g
s
.36447 .37489 m .37082 .41415 L .38766 .40939 L p .595 .43 .628 r
F P
0 g
s
.39521 .8584 m .3375 .87267 L .34093 .87773 L p .703 .835 .945 r
F P
0 g
s
.34093 .87773 m .39721 .86223 L .39521 .8584 L p .703 .835 .945 r
F P
0 g
s
.80533 .5754 m .82496 .61417 L .8167 .60318 L p .771 .341 0 r
F P
0 g
s
.8167 .60318 m .79749 .5649 L .80533 .5754 L p .771 .341 0 r
F P
0 g
s
.48914 .82133 m .52629 .81312 L .48884 .82012 L closepath p .698 .82 .94 r
F P
0 g
s
.44639 .83849 m .48914 .82133 L .48884 .82012 L p .768 .862 .919 r
F P
0 g
s
.48914 .82133 m .44639 .83849 L .44745 .84097 L p .77 .853 .913 r
F P
0 g
s
.60577 .84006 m .65704 .86174 L .65493 .86591 L p .517 .636 .906 r
F P
0 g
s
.39721 .86223 m .44745 .84097 L .44639 .83849 L p .764 .854 .917 r
F P
0 g
s
.75686 .43751 m .75568 .40225 L .75822 .42083 L p .817 .625 .071 r
F P
0 g
s
.48964 .81405 m .52629 .81312 L .49027 .81287 L closepath p .681 .838 .959 r
F P
0 g
s
.48917 .81526 m .52629 .81312 L .48964 .81405 L closepath p .684 .836 .956 r
F P
0 g
s
.48886 .81647 m .52629 .81312 L .48917 .81526 L closepath p .688 .833 .953 r
F P
0 g
s
.4887 .81769 m .52629 .81312 L .48886 .81647 L closepath p .691 .83 .95 r
F P
0 g
s
.52629 .81312 m .56383 .81954 L .56361 .82076 L closepath p .569 .715 .941 r
F P
0 g
s
.48869 .81891 m .52629 .81312 L .4887 .81769 L closepath p .694 .827 .947 r
F P
0 g
s
.52629 .81312 m .56391 .81831 L .56383 .81954 L closepath p .565 .717 .944 r
F P
0 g
s
.48884 .82012 m .52629 .81312 L .48869 .81891 L closepath p .696 .824 .943 r
F P
0 g
s
.52629 .81312 m .56382 .81709 L .56391 .81831 L closepath p .561 .719 .947 r
F P
0 g
s
.52629 .81312 m .56358 .81586 L .56382 .81709 L closepath p .556 .721 .95 r
F P
0 g
s
.52629 .81312 m .56319 .81465 L .56358 .81586 L closepath p .553 .724 .953 r
F P
0 g
s
.52629 .81312 m .56265 .81345 L .56319 .81465 L closepath p .549 .726 .957 r
F P
0 g
s
.52629 .81312 m .56195 .81227 L .56265 .81345 L closepath p .545 .729 .96 r
F P
0 g
s
.52629 .81312 m .56111 .81112 L .56195 .81227 L closepath p .542 .732 .963 r
F P
0 g
s
.52629 .81312 m .56012 .80999 L .56111 .81112 L closepath p .539 .736 .966 r
F P
0 g
s
.52629 .81312 m .55899 .80891 L .56012 .80999 L closepath p .536 .739 .969 r
F P
0 g
s
.52629 .81312 m .55772 .80786 L .55899 .80891 L closepath p .533 .743 .972 r
F P
0 g
s
.52629 .81312 m .55632 .80685 L .55772 .80786 L closepath p .531 .747 .974 r
F P
0 g
s
.52629 .81312 m .5548 .80589 L .55632 .80685 L closepath p .529 .751 .977 r
F P
0 g
s
.52629 .81312 m .55315 .80499 L .5548 .80589 L closepath p .528 .755 .979 r
F P
0 g
s
.52629 .81312 m .55139 .80414 L .55315 .80499 L closepath p .527 .759 .982 r
F P
0 g
s
.52629 .81312 m .54953 .80335 L .55139 .80414 L closepath p .527 .763 .983 r
F P
0 g
s
.52629 .81312 m .54756 .80262 L .54953 .80335 L closepath p .527 .768 .985 r
F P
0 g
s
.52629 .81312 m .54551 .80195 L .54756 .80262 L closepath p .527 .772 .987 r
F P
0 g
s
.52629 .81312 m .54337 .80136 L .54551 .80195 L closepath p .528 .776 .988 r
F P
0 g
s
.52629 .81312 m .54116 .80084 L .54337 .80136 L closepath p .53 .781 .99 r
F P
0 g
s
.52629 .81312 m .53889 .80038 L .54116 .80084 L closepath p .532 .785 .991 r
F P
0 g
s
.52629 .81312 m .53656 .80001 L .53889 .80038 L closepath p .534 .79 .991 r
F P
0 g
s
.52629 .81312 m .53419 .79971 L .53656 .80001 L closepath p .538 .794 .992 r
F P
0 g
s
.52629 .81312 m .53179 .79948 L .53419 .79971 L closepath p .541 .799 .993 r
F P
0 g
s
.52629 .81312 m .52936 .79934 L .53179 .79948 L closepath p .545 .803 .993 r
F P
0 g
s
.52629 .81312 m .52692 .79928 L .52936 .79934 L closepath p .55 .807 .993 r
F P
0 g
s
.52629 .81312 m .52447 .79929 L .52692 .79928 L closepath p .555 .811 .993 r
F P
0 g
s
.52629 .81312 m .52204 .79939 L .52447 .79929 L closepath p .56 .816 .993 r
F P
0 g
s
.52629 .81312 m .51962 .79957 L .52204 .79939 L closepath p .566 .82 .993 r
F P
0 g
s
.52629 .81312 m .51723 .79982 L .51962 .79957 L closepath p .572 .823 .992 r
F P
0 g
s
.52629 .81312 m .51488 .80016 L .51723 .79982 L closepath p .579 .827 .992 r
F P
0 g
s
.52629 .81312 m .51258 .80057 L .51488 .80016 L closepath p .586 .83 .991 r
F P
0 g
s
.52629 .81312 m .51034 .80105 L .51258 .80057 L closepath p .593 .833 .99 r
F P
0 g
s
.52629 .81312 m .50816 .80162 L .51034 .80105 L closepath p .6 .836 .989 r
F P
0 g
s
.50607 .80225 m .52629 .81312 L .50816 .80162 L closepath p .608 .839 .987 r
F P
0 g
s
.50405 .80295 m .52629 .81312 L .50607 .80225 L closepath p .615 .841 .986 r
F P
0 g
s
.50214 .80371 m .52629 .81312 L .50405 .80295 L closepath p .623 .842 .984 r
F P
0 g
s
.50032 .80454 m .52629 .81312 L .50214 .80371 L closepath p .63 .844 .982 r
F P
0 g
s
.49861 .80542 m .52629 .81312 L .50032 .80454 L closepath p .637 .844 .98 r
F P
0 g
s
.49703 .80636 m .52629 .81312 L .49861 .80542 L closepath p .643 .845 .978 r
F P
0 g
s
.49556 .80735 m .52629 .81312 L .49703 .80636 L closepath p .65 .845 .975 r
F P
0 g
s
.49422 .80838 m .52629 .81312 L .49556 .80735 L closepath p .656 .845 .973 r
F P
0 g
s
.49302 .80945 m .52629 .81312 L .49422 .80838 L closepath p .661 .844 .97 r
F P
0 g
s
.49196 .81056 m .52629 .81312 L .49302 .80945 L closepath p .667 .843 .967 r
F P
0 g
s
.49104 .8117 m .52629 .81312 L .49196 .81056 L closepath p .672 .842 .965 r
F P
0 g
s
.49027 .81287 m .52629 .81312 L .49104 .8117 L closepath p .676 .84 .962 r
F P
0 g
s
.33478 .86751 m .27507 .86755 L .27969 .87371 L p .568 .781 .979 r
F P
0 g
s
.27969 .87371 m .3375 .87267 L .33478 .86751 L p .568 .781 .979 r
F P
0 g
s
.56361 .82076 m .60666 .83746 L .60577 .84006 L p .503 .636 .913 r
F P
0 g
s
.60666 .83746 m .56361 .82076 L .56383 .81954 L p .493 .637 .918 r
F P
0 g
s
.87631 .80527 m .83648 .83884 L .83468 .82644 L p .897 .856 .793 r
F P
0 g
s
.83468 .82644 m .87268 .79049 L .87631 .80527 L p .897 .856 .793 r
F P
0 g
s
.44564 .83597 m .48884 .82012 L .48869 .81891 L p .766 .87 .925 r
F P
0 g
s
.48884 .82012 m .44564 .83597 L .44639 .83849 L p .768 .862 .919 r
F P
0 g
s
.33054 .45074 m .33061 .41886 L .30706 .42006 L p .654 .409 .536 r
F P
0 g
s
.30706 .42006 m .30659 .45303 L .33054 .45074 L p .654 .409 .536 r
F P
0 g
s
.65704 .86174 m .60577 .84006 L .60666 .83746 L p .509 .637 .911 r
F P
0 g
s
.44639 .83849 m .39521 .8584 L .39721 .86223 L p .764 .854 .917 r
F P
0 g
s
.56383 .81954 m .60721 .83483 L .60666 .83746 L p .493 .637 .918 r
F P
0 g
s
.60721 .83483 m .56383 .81954 L .56391 .81831 L p .483 .639 .924 r
F P
0 g
s
.88358 .72926 m .86739 .77583 L .86084 .76154 L p .962 .766 .594 r
F P
0 g
s
.86084 .76154 m .8743 .71383 L .88358 .72926 L p .962 .766 .594 r
F P
0 g
s
.76004 .46998 m .76887 .49946 L .76695 .48557 L p 0 0 .292 r
F P
0 g
s
.76695 .48557 m .75895 .45443 L .76004 .46998 L p 0 0 .292 r
F P
0 g
s
.44523 .83343 m .48869 .81891 L .4887 .81769 L p .763 .879 .93 r
F P
0 g
s
.48869 .81891 m .44523 .83343 L .44564 .83597 L p .766 .87 .925 r
F P
0 g
s
.21886 .50152 m .22649 .46487 L .20066 .4722 L p .523 .264 .464 r
F P
0 g
s
.20066 .4722 m .19332 .51082 L .21886 .50152 L p .523 .264 .464 r
F P
0 g
s
.39521 .8584 m .44639 .83849 L .44564 .83597 L p .763 .863 .923 r
F P
0 g
s
.56391 .81831 m .60742 .83216 L .60721 .83483 L p .483 .639 .924 r
F P
0 g
s
.60742 .83216 m .56391 .81831 L .56382 .81709 L p .472 .641 .93 r
F P
0 g
s
.44515 .83087 m .4887 .81769 L .48886 .81647 L p .758 .887 .936 r
F P
0 g
s
.4887 .81769 m .44515 .83087 L .44523 .83343 L p .763 .879 .93 r
F P
0 g
s
.35208 .4482 m .35189 .41712 L .33061 .41886 L p .644 .403 .539 r
F P
0 g
s
.33061 .41886 m .33054 .45074 L .35208 .4482 L p .644 .403 .539 r
F P
0 g
s
.38766 .40939 m .38182 .36981 L .39792 .36246 L p .551 .401 .631 r
F P
0 g
s
.71583 .87908 m .65704 .86174 L .65859 .85742 L p .564 .689 .924 r
F P
0 g
s
.65859 .85742 m .71815 .87268 L .71583 .87908 L p .564 .689 .924 r
F P
0 g
s
.60666 .83746 m .65859 .85742 L .65704 .86174 L p .509 .637 .911 r
F P
0 g
s
.65859 .85742 m .60666 .83746 L .60721 .83483 L p .502 .638 .915 r
F P
0 g
s
.56382 .81709 m .60731 .82949 L .60742 .83216 L p .472 .641 .93 r
F P
0 g
s
.60731 .82949 m .56382 .81709 L .56358 .81586 L p .46 .643 .936 r
F P
0 g
s
.74334 .27795 m .74382 .32113 L .73131 .30148 L p .966 .663 .398 r
F P
0 g
s
.73131 .30148 m .72937 .2588 L .74334 .27795 L p .966 .663 .398 r
F P
0 g
s
.13856 .74818 m .16519 .79293 L .16254 .7826 L p 0 0 .546 r
F P
0 g
s
.46298 .26531 m .46316 .22144 L .48487 .20882 L p .511 .294 .52 r
F P
0 g
s
.46316 .22144 m .46298 .26531 L .44345 .27973 L p .508 .307 .543 r
F P
0 g
s
.41346 .35272 m .40821 .30502 L .42537 .29318 L p .52 .376 .626 r
F P
0 g
s
.40821 .30502 m .41346 .35272 L .39792 .36246 L p .54 .398 .636 r
F P
0 g
s
.68445 .19248 m .69169 .22711 L .66834 .21623 L p .815 .424 .312 r
F P
0 g
s
.66834 .21623 m .66176 .18244 L .68445 .19248 L p .815 .424 .312 r
F P
0 g
s
.4454 .8283 m .48886 .81647 L .48917 .81526 L p .752 .895 .942 r
F P
0 g
s
.48886 .81647 m .4454 .8283 L .44515 .83087 L p .758 .887 .936 r
F P
0 g
s
.13104 .64427 m .13127 .59439 L .12317 .60947 L p 0 0 .348 r
F P
0 g
s
.12317 .60947 m .12346 .65916 L .13104 .64427 L p 0 0 .348 r
F P
0 g
s
.56358 .81586 m .60685 .82682 L .60731 .82949 L p .46 .643 .936 r
F P
0 g
s
.60685 .82682 m .56358 .81586 L .56319 .81465 L p .448 .646 .942 r
F P
0 g
s
.39373 .85452 m .44564 .83597 L .44523 .83343 L p .761 .872 .928 r
F P
0 g
s
.44564 .83597 m .39373 .85452 L .39521 .8584 L p .763 .863 .923 r
F P
0 g
s
.83668 .85105 m .78141 .8667 L .78187 .85723 L p .777 .835 .897 r
F P
0 g
s
.78187 .85723 m .83648 .83884 L .83668 .85105 L p .777 .835 .897 r
F P
0 g
s
.3375 .87267 m .39521 .8584 L .39373 .85452 L p .703 .841 .948 r
F P
0 g
s
.37114 .44477 m .37082 .41415 L .35189 .41712 L p .615 .383 .542 r
F P
0 g
s
.35189 .41712 m .35208 .4482 L .37114 .44477 L p .615 .383 .542 r
F P
0 g
s
.39373 .85452 m .33478 .86751 L .3375 .87267 L p .703 .841 .948 r
F P
0 g
s
.446 .82573 m .48917 .81526 L .48964 .81405 L p .745 .902 .948 r
F P
0 g
s
.48917 .81526 m .446 .82573 L .4454 .8283 L p .752 .895 .942 r
F P
0 g
s
.84569 .63816 m .85438 .6855 L .84469 .67275 L p .948 .594 .285 r
F P
0 g
s
.84469 .67275 m .83466 .62575 L .84569 .63816 L p .948 .594 .285 r
F P
0 g
s
.77969 .87587 m .71815 .87268 L .71959 .86605 L p .655 .766 .931 r
F P
0 g
s
.71959 .86605 m .78141 .8667 L .77969 .87587 L p .655 .766 .931 r
F P
0 g
s
.56319 .81465 m .60607 .82417 L .60685 .82682 L p .448 .646 .942 r
F P
0 g
s
.60607 .82417 m .56319 .81465 L .56265 .81345 L p .436 .649 .949 r
F P
0 g
s
.16256 .5657 m .17044 .52193 L .15147 .53469 L p .299 .086 .413 r
F P
0 g
s
.15147 .53469 m .1446 .57965 L .16256 .5657 L p .299 .086 .413 r
F P
0 g
s
.60721 .83483 m .65957 .853 L .65859 .85742 L p .502 .638 .915 r
F P
0 g
s
.65957 .853 m .60721 .83483 L .60742 .83216 L p .494 .64 .92 r
F P
0 g
s
.44693 .82316 m .48964 .81405 L .49027 .81287 L p .736 .908 .953 r
F P
0 g
s
.48964 .81405 m .44693 .82316 L .446 .82573 L p .745 .902 .948 r
F P
0 g
s
.56265 .81345 m .60495 .82155 L .60607 .82417 L p .436 .649 .949 r
F P
0 g
s
.60495 .82155 m .56265 .81345 L .56195 .81227 L p .423 .653 .955 r
F P
0 g
s
.77085 .51215 m .78706 .543 L p .78357 .53172 L 0 0 .432 r
F P
0 g
s
.78357 .53172 m .76887 .49946 L .77085 .51215 L p 0 0 .432 r
F P
0 g
s
.76887 .49946 m .78357 .53172 L .77976 .51943 L p 0 0 .367 r
F P
0 g
s
.79151 .5606 m .77976 .51944 L p .78357 .53172 L .696 .406 0 r
F P
0 g
s
.77976 .51944 m .77976 .51943 L .78357 .53172 L p .696 .406 0 r
F P
0 g
s
.78706 .543 m .78722 .54331 L .78357 .53172 L p 0 0 .432 r
F P
0 g
s
.24574 .49397 m .25359 .45951 L .22649 .46487 L p .568 .298 .467 r
F P
0 g
s
.22649 .46487 m .21886 .50152 L .24574 .49397 L p .568 .298 .467 r
F P
0 g
s
.39278 .85057 m .44523 .83343 L .44515 .83087 L p .758 .88 .934 r
F P
0 g
s
.44523 .83343 m .39278 .85057 L .39373 .85452 L p .761 .872 .928 r
F P
0 g
s
.2096 .8276 m .16519 .79293 L .17034 .80232 L p .009 .35 .827 r
F P
0 g
s
.17034 .80232 m .21254 .83593 L .2096 .8276 L p .009 .35 .827 r
F P
0 g
s
.4482 .82061 m .49027 .81287 L .49104 .8117 L p .726 .913 .958 r
F P
0 g
s
.49027 .81287 m .4482 .82061 L .44693 .82316 L p .736 .908 .953 r
F P
0 g
s
.71815 .87268 m .65859 .85742 L .65957 .853 L p .564 .69 .925 r
F P
0 g
s
.79749 .5649 m .8167 .60318 L .80972 .59254 L p .69 .304 0 r
F P
0 g
s
.40299 .40246 m .39792 .36246 L .41346 .35272 L p .51 .37 .626 r
F P
0 g
s
.39792 .36246 m .40299 .40246 L .38766 .40939 L p .551 .401 .631 r
F P
0 g
s
.388 .43992 m .38766 .40939 L .37082 .41415 L p .563 .344 .54 r
F P
0 g
s
.37082 .41415 m .37114 .44477 L .388 .43992 L p .563 .344 .54 r
F P
0 g
s
.48434 .25069 m .48487 .20882 L .5081 .19704 L p .523 .285 .495 r
F P
0 g
s
.48487 .20882 m .48434 .25069 L .46298 .26531 L p .511 .294 .52 r
F P
0 g
s
.56195 .81227 m .60351 .81897 L .60495 .82155 L p .423 .653 .955 r
F P
0 g
s
.60351 .81897 m .56195 .81227 L .56111 .81112 L p .41 .657 .96 r
F P
0 g
s
.33282 .86222 m .27143 .86115 L .27507 .86755 L p .577 .784 .977 r
F P
0 g
s
.27507 .86755 m .33478 .86751 L .33282 .86222 L p .577 .784 .977 r
F P
0 g
s
.60742 .83216 m .65999 .8485 L .65957 .853 L p .494 .64 .92 r
F P
0 g
s
.65999 .8485 m .60742 .83216 L .60731 .82949 L p .486 .643 .926 r
F P
0 g
s
.44981 .81808 m .49104 .8117 L .49196 .81056 L p .714 .917 .963 r
F P
0 g
s
.49104 .8117 m .44981 .81808 L .4482 .82061 L p .726 .913 .958 r
F P
0 g
s
.2689 .85444 m .21254 .83593 L .21716 .84366 L p .353 .64 .962 r
F P
0 g
s
.21716 .84366 m .27143 .86115 L .2689 .85444 L p .353 .64 .962 r
F P
0 g
s
.65957 .853 m .71959 .86605 L .71815 .87268 L p .564 .69 .925 r
F P
0 g
s
.56111 .81112 m .60174 .81646 L .60351 .81897 L p .41 .657 .96 r
F P
0 g
s
.60174 .81646 m .56111 .81112 L .56012 .80999 L p .397 .661 .966 r
F P
0 g
s
.66176 .18244 m .66834 .21623 L .64267 .20945 L p .762 .383 .338 r
F P
0 g
s
.64267 .20945 m .6372 .17598 L .66176 .18244 L p .762 .383 .338 r
F P
0 g
s
.33478 .86751 m .39373 .85452 L .39278 .85057 L p .703 .846 .951 r
F P
0 g
s
.42919 .34072 m .42537 .29318 L .44345 .27973 L p .505 .356 .612 r
F P
0 g
s
.42537 .29318 m .42919 .34072 L .41346 .35272 L p .52 .376 .626 r
F P
0 g
s
.87268 .79049 m .83468 .82644 L .83149 .81405 L p .898 .834 .774 r
F P
0 g
s
.83149 .81405 m .86739 .77583 L .87268 .79049 L p .898 .834 .774 r
F P
0 g
s
.45174 .8156 m .49196 .81056 L .49302 .80945 L p .701 .92 .967 r
F P
0 g
s
.49196 .81056 m .45174 .8156 L .44981 .81808 L p .714 .917 .963 r
F P
0 g
s
.39239 .84656 m .44515 .83087 L .4454 .8283 L p .754 .888 .939 r
F P
0 g
s
.44515 .83087 m .39239 .84656 L .39278 .85057 L p .758 .88 .934 r
F P
0 g
s
.75287 .34166 m .75104 .3827 L .74337 .36294 L p .989 .733 .371 r
F P
0 g
s
.74337 .36294 m .74382 .32113 L .75287 .34166 L p .989 .733 .371 r
F P
0 g
s
.8743 .71383 m .86084 .76154 L .85342 .74785 L p .959 .749 .575 r
F P
0 g
s
.85342 .74785 m .86439 .69921 L .8743 .71383 L p .959 .749 .575 r
F P
0 g
s
.56012 .80999 m .59966 .81402 L .60174 .81646 L p .397 .661 .966 r
F P
0 g
s
.59966 .81402 m .56012 .80999 L .55899 .80891 L p .383 .666 .97 r
F P
0 g
s
.45399 .81317 m .49302 .80945 L .49422 .80838 L p .686 .922 .971 r
F P
0 g
s
.49302 .80945 m .45399 .81317 L .45174 .8156 L p .701 .92 .967 r
F P
0 g
s
.27268 .48797 m .28066 .45574 L .25359 .45951 L p .596 .317 .463 r
F P
0 g
s
.25359 .45951 m .24574 .49397 L .27268 .48797 L p .596 .317 .463 r
F P
0 g
s
.60731 .82949 m .65985 .84397 L .65999 .8485 L p .486 .643 .926 r
F P
0 g
s
.65985 .84397 m .60731 .82949 L .60685 .82682 L p .476 .646 .932 r
F P
0 g
s
.55899 .80891 m .59727 .81166 L .59966 .81402 L p .383 .666 .97 r
F P
0 g
s
.59727 .81166 m .55899 .80891 L .55772 .80786 L p .37 .671 .974 r
F P
0 g
s
.39278 .85057 m .33282 .86222 L .33478 .86751 L p .703 .846 .951 r
F P
0 g
s
.71959 .86605 m .65957 .853 L .65999 .8485 L p .564 .692 .927 r
F P
0 g
s
.13619 .71072 m .12346 .65916 L .12067 .67355 L p 0 0 .462 r
F P
0 g
s
.12067 .67355 m .1332 .72417 L .13619 .71072 L p 0 0 .462 r
F P
0 g
s
.388 .43992 m .38766 .40939 L .40299 .40246 L p .492 .289 .532 r
F P
0 g
s
.45656 .8108 m .49422 .80838 L .49556 .80735 L p .67 .922 .974 r
F P
0 g
s
.49422 .80838 m .45656 .8108 L .45399 .81317 L p .686 .922 .971 r
F P
0 g
s
.5077 .23682 m .5081 .19704 L .53275 .1869 L p .544 .282 .469 r
F P
0 g
s
.5081 .19704 m .5077 .23682 L .48434 .25069 L p .523 .285 .495 r
F P
0 g
s
.75568 .40225 m .75686 .43751 L .75266 .41966 L p .886 .657 .138 r
F P
0 g
s
.75266 .41966 m .75104 .3827 L .75568 .40225 L p .886 .657 .138 r
F P
0 g
s
.55772 .80786 m .59458 .8094 L .59727 .81166 L p .37 .671 .974 r
F P
0 g
s
.59458 .8094 m .55772 .80786 L .55632 .80685 L p .357 .676 .977 r
F P
0 g
s
.39257 .84249 m .4454 .8283 L .446 .82573 L p .75 .895 .944 r
F P
0 g
s
.4454 .8283 m .39257 .84249 L .39239 .84656 L p .754 .888 .939 r
F P
0 g
s
.45942 .80851 m .49556 .80735 L .49703 .80636 L p .652 .921 .977 r
F P
0 g
s
.49556 .80735 m .45942 .80851 L .45656 .8108 L p .67 .922 .974 r
F P
0 g
s
.78141 .8667 m .71959 .86605 L .72017 .85925 L p .662 .763 .925 r
F P
0 g
s
.72017 .85925 m .78187 .85723 L .78141 .8667 L p .662 .763 .925 r
F P
0 g
s
.2986 .48312 m .30659 .45303 L .28066 .45574 L p .61 .321 .453 r
F P
0 g
s
.28066 .45574 m .27268 .48797 L .2986 .48312 L p .61 .321 .453 r
F P
0 g
s
.72937 .2588 m .73131 .30148 L .71502 .2837 L p .934 .615 .41 r
F P
0 g
s
.71502 .2837 m .71214 .24156 L .72937 .2588 L p .934 .615 .41 r
F P
0 g
s
.55632 .80685 m .5916 .80723 L .59458 .8094 L p .357 .676 .977 r
F P
0 g
s
.5916 .80723 m .55632 .80685 L .5548 .80589 L p .345 .681 .979 r
F P
0 g
s
.6372 .17598 m .64267 .20945 L .61543 .20707 L p .708 .348 .364 r
F P
0 g
s
.61543 .20707 m .61137 .17334 L .6372 .17598 L p .708 .348 .364 r
F P
0 g
s
.83466 .62575 m .84469 .67275 L .83557 .66091 L p .946 .585 .23 r
F P
0 g
s
.83557 .66091 m .82496 .61417 L .83466 .62575 L p .946 .585 .23 r
F P
0 g
s
.60685 .82682 m .65916 .83943 L .65985 .84397 L p .476 .646 .932 r
F P
0 g
s
.65916 .83943 m .60685 .82682 L .60607 .82417 L p .466 .65 .939 r
F P
0 g
s
.83648 .83884 m .78187 .85723 L .78114 .84761 L p .785 .824 .883 r
F P
0 g
s
.78114 .84761 m .83468 .82644 L .83648 .83884 L p .785 .824 .883 r
F P
0 g
s
.33282 .86222 m .39278 .85057 L .39239 .84656 L p .702 .851 .954 r
F P
0 g
s
.46257 .80631 m .49703 .80636 L .49861 .80542 L p .633 .918 .978 r
F P
0 g
s
.49703 .80636 m .46257 .80631 L .45942 .80851 L p .652 .921 .977 r
F P
0 g
s
.41755 .39321 m .41346 .35272 L .42919 .34072 L p .474 .337 .614 r
F P
0 g
s
.41346 .35272 m .41755 .39321 L .40299 .40246 L p .51 .37 .626 r
F P
0 g
s
.75895 .45443 m .76695 .48557 L .764 .47062 L p 0 0 .21 r
F P
0 g
s
.5548 .80589 m .58835 .80518 L .5916 .80723 L p .345 .681 .979 r
F P
0 g
s
.58835 .80518 m .5548 .80589 L .55315 .80499 L p .333 .686 .98 r
F P
0 g
s
.18423 .5529 m .19332 .51082 L .17044 .52193 L p .409 .169 .436 r
F P
0 g
s
.17044 .52193 m .16256 .5657 L .18423 .5529 L p .409 .169 .436 r
F P
0 g
s
.466 .80422 m .49861 .80542 L .50032 .80454 L p .612 .914 .98 r
F P
0 g
s
.49861 .80542 m .466 .80422 L .46257 .80631 L p .633 .918 .978 r
F P
0 g
s
.53295 .22465 m .53275 .1869 L .55851 .17917 L p .574 .287 .443 r
F P
0 g
s
.53275 .1869 m .53295 .22465 L .5077 .23682 L p .544 .282 .469 r
F P
0 g
s
.32272 .47894 m .33054 .45074 L .30659 .45303 L p .609 .31 .438 r
F P
0 g
s
.30659 .45303 m .2986 .48312 L .32272 .47894 L p .609 .31 .438 r
F P
0 g
s
.39334 .83837 m .446 .82573 L .44693 .82316 L p .743 .902 .949 r
F P
0 g
s
.446 .82573 m .39334 .83837 L .39257 .84249 L p .75 .895 .944 r
F P
0 g
s
.65999 .8485 m .72017 .85925 L .71959 .86605 L p .564 .692 .927 r
F P
0 g
s
.55315 .80499 m .58482 .80325 L .58835 .80518 L p .333 .686 .98 r
F P
0 g
s
.58482 .80325 m .55315 .80499 L .55139 .80414 L p .323 .691 .98 r
F P
0 g
s
.46969 .80225 m .50032 .80454 L .50214 .80371 L p .591 .909 .98 r
F P
0 g
s
.50032 .80454 m .46969 .80225 L .466 .80422 L p .612 .914 .98 r
F P
0 g
s
.72017 .85925 m .65999 .8485 L .65985 .84397 L p .562 .695 .929 r
F P
0 g
s
.55139 .80414 m .58103 .80144 L .58482 .80325 L p .323 .691 .98 r
F P
0 g
s
.58103 .80144 m .55139 .80414 L .54953 .80335 L p .314 .697 .979 r
F P
0 g
s
.4459 .32686 m .44345 .27973 L .46298 .26531 L p .499 .338 .594 r
F P
0 g
s
.44345 .27973 m .4459 .32686 L .42919 .34072 L p .505 .356 .612 r
F P
0 g
s
.61137 .17334 m .61543 .20707 L .5875 .20908 L p .657 .32 .39 r
F P
0 g
s
.5875 .20908 m .58491 .17448 L .61137 .17334 L p .657 .32 .39 r
F P
0 g
s
.60607 .82417 m .65791 .83492 L .65916 .83943 L p .466 .65 .939 r
F P
0 g
s
.65791 .83492 m .60607 .82417 L .60495 .82155 L p .455 .654 .946 r
F P
0 g
s
.14322 .62931 m .1446 .57965 L .13127 .59439 L p .148 .02 .437 r
F P
0 g
s
.13127 .59439 m .13104 .64427 L .14322 .62931 L p .148 .02 .437 r
F P
0 g
s
.34459 .47487 m .35208 .4482 L .33054 .45074 L p .588 .281 .416 r
F P
0 g
s
.33054 .45074 m .32272 .47894 L .34459 .47487 L p .588 .281 .416 r
F P
0 g
s
.47362 .80041 m .50214 .80371 L .50405 .80295 L p .569 .902 .98 r
F P
0 g
s
.50214 .80371 m .47362 .80041 L .46969 .80225 L p .591 .909 .98 r
F P
0 g
s
.55975 .21514 m .55851 .17917 L .58491 .17448 L p .612 .3 .416 r
F P
0 g
s
.55851 .17917 m .55975 .21514 L .53295 .22465 L p .574 .287 .443 r
F P
0 g
s
.54953 .80335 m .57701 .79975 L .58103 .80144 L p .314 .697 .979 r
F P
0 g
s
.57701 .79975 m .54953 .80335 L .54756 .80262 L p .307 .702 .978 r
F P
0 g
s
.33169 .85677 m .2689 .85444 L .27143 .86115 L p .587 .786 .975 r
F P
0 g
s
.27143 .86115 m .33282 .86222 L .33169 .85677 L p .587 .786 .975 r
F P
0 g
s
.40324 .4333 m .40299 .40246 L .41755 .39321 L p .416 .23 .518 r
F P
0 g
s
.40299 .40246 m .40324 .4333 L .388 .43992 L p .492 .289 .532 r
F P
0 g
s
.58491 .17448 m .5875 .20908 L .55975 .21514 L p .612 .3 .416 r
F P
0 g
s
.47778 .79871 m .50405 .80295 L .50607 .80225 L p .546 .894 .98 r
F P
0 g
s
.50405 .80295 m .47778 .79871 L .47362 .80041 L p .569 .902 .98 r
F P
0 g
s
.16271 .77137 m .1332 .72417 L .13408 .73672 L p 0 .131 .669 r
F P
0 g
s
.13408 .73672 m .16254 .7826 L .16271 .77137 L p 0 .131 .669 r
F P
0 g
s
.54756 .80262 m .57276 .7982 L .57701 .79975 L p .307 .702 .978 r
F P
0 g
s
.57276 .7982 m .54756 .80262 L .54551 .80195 L p .302 .708 .976 r
F P
0 g
s
.39469 .8342 m .44693 .82316 L .4482 .82061 L p .736 .907 .954 r
F P
0 g
s
.44693 .82316 m .39469 .8342 L .39334 .83837 L p .743 .902 .949 r
F P
0 g
s
.48215 .79716 m .50607 .80225 L .50816 .80162 L p .523 .885 .978 r
F P
0 g
s
.50607 .80225 m .48215 .79716 L .47778 .79871 L p .546 .894 .98 r
F P
0 g
s
.36414 .47041 m .37114 .44477 L .35208 .4482 L p .544 .23 .386 r
F P
0 g
s
.35208 .4482 m .34459 .47487 L .36414 .47041 L p .544 .23 .386 r
F P
0 g
s
.39239 .84656 m .33169 .85677 L .33282 .86222 L p .702 .851 .954 r
F P
0 g
s
.54551 .80195 m .5683 .79679 L .57276 .7982 L p .302 .708 .976 r
F P
0 g
s
.5683 .79679 m .54551 .80195 L .54337 .80136 L p .298 .714 .974 r
F P
0 g
s
.33169 .85677 m .39239 .84656 L .39257 .84249 L p .701 .855 .956 r
F P
0 g
s
.50816 .80162 m .48671 .79577 L .48215 .79716 L p .523 .885 .978 r
F P
0 g
s
.49144 .79455 m .51034 .80105 L .50816 .80162 L p .498 .874 .977 r
F P
0 g
s
.50816 .80162 m .48671 .79577 L .49144 .79455 L p .498 .874 .977 r
F P
0 g
s
.60495 .82155 m .65613 .83048 L .65791 .83492 L p .455 .654 .946 r
F P
0 g
s
.65613 .83048 m .60495 .82155 L .60351 .81897 L p .443 .659 .953 r
F P
0 g
s
.86439 .69921 m .85342 .74785 L .84547 .7349 L p .962 .74 .557 r
F P
0 g
s
.84547 .7349 m .85438 .6855 L .86439 .69921 L p .962 .74 .557 r
F P
0 g
s
.54337 .80136 m .56366 .79552 L .5683 .79679 L p .298 .714 .974 r
F P
0 g
s
.56366 .79552 m .54337 .80136 L .54116 .80084 L p .297 .721 .972 r
F P
0 g
s
.86739 .77583 m .83149 .81405 L .82712 .80189 L p .899 .818 .759 r
F P
0 g
s
.82712 .80189 m .86084 .76154 L .86739 .77583 L p .899 .818 .759 r
F P
0 g
s
.49633 .79349 m .51258 .80057 L .51034 .80105 L p .473 .862 .975 r
F P
0 g
s
.51034 .80105 m .49144 .79455 L .49633 .79349 L p .473 .862 .975 r
F P
0 g
s
.77976 .51943 m .76695 .48557 L .76887 .49946 L p 0 0 .367 r
F P
0 g
s
.54116 .80084 m .55884 .79439 L .56366 .79552 L p .297 .721 .972 r
F P
0 g
s
.55884 .79439 m .54116 .80084 L .53889 .80038 L p .297 .728 .969 r
F P
0 g
s
.50134 .79261 m .51488 .80016 L .51258 .80057 L p .448 .849 .973 r
F P
0 g
s
.51258 .80057 m .49633 .79349 L .50134 .79261 L p .448 .849 .973 r
F P
0 g
s
.53889 .80038 m .55388 .79341 L .55884 .79439 L p .297 .728 .969 r
F P
0 g
s
.55388 .79341 m .53889 .80038 L .53656 .80001 L p .3 .735 .968 r
F P
0 g
s
.50647 .79191 m .51723 .79982 L .51488 .80016 L p .424 .836 .97 r
F P
0 g
s
.51488 .80016 m .50134 .79261 L .50647 .79191 L p .424 .836 .97 r
F P
0 g
s
.26763 .84737 m .2096 .8276 L .21254 .83593 L p .403 .653 .96 r
F P
0 g
s
.21254 .83593 m .2689 .85444 L .26763 .84737 L p .403 .653 .96 r
F P
0 g
s
.65985 .84397 m .7199 .85236 L .72017 .85925 L p .562 .695 .929 r
F P
0 g
s
.7199 .85236 m .65985 .84397 L .65916 .83943 L p .561 .698 .933 r
F P
0 g
s
.20855 .81861 m .16254 .7826 L .16519 .79293 L p .157 .422 .861 r
F P
0 g
s
.16519 .79293 m .2096 .8276 L .20855 .81861 L p .157 .422 .861 r
F P
0 g
s
.53656 .80001 m .54879 .79259 L .55388 .79341 L p .3 .735 .968 r
F P
0 g
s
.54879 .79259 m .53656 .80001 L .53419 .79971 L p .304 .744 .966 r
F P
0 g
s
.39664 .83001 m .4482 .82061 L .44981 .81808 L p .727 .912 .958 r
F P
0 g
s
.4482 .82061 m .39664 .83001 L .39469 .8342 L p .736 .907 .954 r
F P
0 g
s
.51169 .79139 m .51962 .79957 L .51723 .79982 L p .401 .823 .968 r
F P
0 g
s
.51723 .79982 m .50647 .79191 L .51169 .79139 L p .401 .823 .968 r
F P
0 g
s
.53419 .79971 m .5436 .79192 L .54879 .79259 L p .304 .744 .966 r
F P
0 g
s
.5436 .79192 m .53419 .79971 L .53179 .79948 L p .311 .753 .965 r
F P
0 g
s
.38164 .46509 m .388 .43992 L .37114 .44477 L p .471 .156 .35 r
F P
0 g
s
.37114 .44477 m .36414 .47041 L .38164 .46509 L p .471 .156 .35 r
F P
0 g
s
.51698 .79105 m .52204 .79939 L .51962 .79957 L p .381 .809 .966 r
F P
0 g
s
.51962 .79957 m .51169 .79139 L .51698 .79105 L p .381 .809 .966 r
F P
0 g
s
.53179 .79948 m .53834 .79141 L .5436 .79192 L p .311 .753 .965 r
F P
0 g
s
.53834 .79141 m .53179 .79948 L .52936 .79934 L p .321 .763 .964 r
F P
0 g
s
.52231 .79088 m .52447 .79929 L .52204 .79939 L p .362 .797 .965 r
F P
0 g
s
.52204 .79939 m .51698 .79105 L .52231 .79088 L p .362 .797 .965 r
F P
0 g
s
.52936 .79934 m .53302 .79106 L .53834 .79141 L p .321 .763 .964 r
F P
0 g
s
.53302 .79106 m .52936 .79934 L .52692 .79928 L p .332 .773 .964 r
F P
0 g
s
.52767 .79088 m .52692 .79928 L .52447 .79929 L p .346 .785 .964 r
F P
0 g
s
.52447 .79929 m .52231 .79088 L .52767 .79088 L p .346 .785 .964 r
F P
0 g
s
.52692 .79928 m .52767 .79088 L .53302 .79106 L p .332 .773 .964 r
F P
0 g
s
.78187 .85723 m .72017 .85925 L .7199 .85236 L p .668 .762 .921 r
F P
0 g
s
.7199 .85236 m .78114 .84761 L .78187 .85723 L p .668 .762 .921 r
F P
0 g
s
.43224 .38173 m .42919 .34072 L .4459 .32686 L p .45 .31 .598 r
F P
0 g
s
.42919 .34072 m .43224 .38173 L .41755 .39321 L p .474 .337 .614 r
F P
0 g
s
.60351 .81897 m .65382 .82614 L .65613 .83048 L p .443 .659 .953 r
F P
0 g
s
.65382 .82614 m .60351 .81897 L .60174 .81646 L p .43 .664 .959 r
F P
0 g
s
.20852 .5415 m .21886 .50152 L .19332 .51082 L p .477 .217 .441 r
F P
0 g
s
.19332 .51082 m .18423 .5529 L .20852 .5415 L p .477 .217 .441 r
F P
0 g
s
.74382 .32113 m .74337 .36294 L .73196 .34388 L p .981 .698 .402 r
F P
0 g
s
.73196 .34388 m .73131 .30148 L .74382 .32113 L p .981 .698 .402 r
F P
0 g
s
.82496 .61417 m .83557 .66091 L .82709 .64985 L p .938 .582 .174 r
F P
0 g
s
.82709 .64985 m .8167 .60318 L .82496 .61417 L p .938 .582 .174 r
F P
0 g
s
.71214 .24156 m .71502 .2837 L .69496 .26878 L p .89 .565 .426 r
F P
0 g
s
.69496 .26878 m .69169 .22711 L .71214 .24156 L p .89 .565 .426 r
F P
0 g
s
.33143 .85116 m .39257 .84249 L .39334 .83837 L p .7 .858 .958 r
F P
0 g
s
.39257 .84249 m .33143 .85116 L .33169 .85677 L p .701 .855 .956 r
F P
0 g
s
.83468 .82644 m .78114 .84761 L .7793 .83798 L p .79 .815 .872 r
F P
0 g
s
.7793 .83798 m .83149 .81405 L .83468 .82644 L p .79 .815 .872 r
F P
0 g
s
.46427 .31176 m .46298 .26531 L .48434 .25069 L p .504 .327 .575 r
F P
0 g
s
.46298 .26531 m .46427 .31176 L .4459 .32686 L p .499 .338 .594 r
F P
0 g
s
.39918 .82581 m .44981 .81808 L .45174 .8156 L p .716 .916 .962 r
F P
0 g
s
.44981 .81808 m .39918 .82581 L .39664 .83001 L p .727 .912 .958 r
F P
0 g
s
.41767 .42472 m .41755 .39321 L .43224 .38173 L p .355 .18 .501 r
F P
0 g
s
.41755 .39321 m .41767 .42472 L .40324 .4333 L p .416 .23 .518 r
F P
0 g
s
.60174 .81646 m .65099 .82192 L .65382 .82614 L p .43 .664 .959 r
F P
0 g
s
.65099 .82192 m .60174 .81646 L .59966 .81402 L p .417 .67 .966 r
F P
0 g
s
.38164 .46509 m .388 .43992 L .40324 .4333 L p .366 .061 .309 r
F P
0 g
s
.65916 .83943 m .71881 .84546 L .7199 .85236 L p .561 .698 .933 r
F P
0 g
s
.71881 .84546 m .65916 .83943 L .65791 .83492 L p .558 .703 .937 r
F P
0 g
s
.2689 .85444 m .33169 .85677 L .33143 .85116 L p .597 .787 .971 r
F P
0 g
s
.14312 .69661 m .13104 .64427 L .12346 .65916 L p .078 .074 .55 r
F P
0 g
s
.12346 .65916 m .13619 .71072 L .14312 .69661 L p .078 .074 .55 r
F P
0 g
s
.40229 .82162 m .45174 .8156 L .45399 .81317 L p .704 .918 .966 r
F P
0 g
s
.45174 .8156 m .40229 .82162 L .39918 .82581 L p .716 .916 .962 r
F P
0 g
s
.75104 .3827 m .75266 .41966 L .74535 .40155 L p .95 .682 .228 r
F P
0 g
s
.74535 .40155 m .74337 .36294 L .75104 .3827 L p .95 .682 .228 r
F P
0 g
s
.33143 .85116 m .26763 .84737 L .2689 .85444 L p .597 .787 .971 r
F P
0 g
s
.59966 .81402 m .64766 .81786 L .65099 .82192 L p .417 .67 .966 r
F P
0 g
s
.64766 .81786 m .59966 .81402 L .59727 .81166 L p .402 .676 .972 r
F P
0 g
s
.23423 .53158 m .24574 .49397 L .21886 .50152 L p .52 .242 .434 r
F P
0 g
s
.21886 .50152 m .20852 .5415 L .23423 .53158 L p .52 .242 .434 r
F P
0 g
s
.15951 .61467 m .16256 .5657 L .1446 .57965 L p .302 .128 .471 r
F P
0 g
s
.1446 .57965 m .14322 .62931 L .15951 .61467 L p .302 .128 .471 r
F P
0 g
s
.78114 .84761 m .7199 .85236 L .71881 .84546 L p .672 .762 .918 r
F P
0 g
s
.33208 .84537 m .39334 .83837 L .39469 .8342 L p .699 .861 .959 r
F P
0 g
s
.39334 .83837 m .33208 .84537 L .33143 .85116 L p .7 .858 .958 r
F P
0 g
s
.85438 .6855 m .84547 .7349 L .83726 .72277 L p .968 .74 .54 r
F P
0 g
s
.83726 .72277 m .84469 .67275 L .85438 .6855 L p .968 .74 .54 r
F P
0 g
s
.40597 .81749 m .45399 .81317 L .45656 .8108 L p .691 .92 .97 r
F P
0 g
s
.45399 .81317 m .40597 .81749 L .40229 .82162 L p .704 .918 .966 r
F P
0 g
s
.75686 .43751 m .764 .47062 L .75893 .45493 L p .746 .495 0 r
F P
0 g
s
.75893 .45493 m .75266 .41966 L .75686 .43751 L p .746 .495 0 r
F P
0 g
s
.86084 .76154 m .82712 .80189 L .82179 .79013 L p .901 .809 .748 r
F P
0 g
s
.82179 .79013 m .85342 .74785 L .86084 .76154 L p .901 .809 .748 r
F P
0 g
s
.59727 .81166 m .64384 .81396 L .64766 .81786 L p .402 .676 .972 r
F P
0 g
s
.64384 .81396 m .59727 .81166 L .59458 .8094 L p .388 .682 .976 r
F P
0 g
s
.65791 .83492 m .71694 .83862 L .71881 .84546 L p .558 .703 .937 r
F P
0 g
s
.71694 .83862 m .65791 .83492 L .65613 .83048 L p .554 .708 .943 r
F P
0 g
s
.71881 .84546 m .7793 .83798 L .78114 .84761 L p .672 .762 .918 r
F P
0 g
s
.44793 .36838 m .4459 .32686 L .46427 .31176 L p .443 .292 .581 r
F P
0 g
s
.4459 .32686 m .44793 .36838 L .43224 .38173 L p .45 .31 .598 r
F P
0 g
s
.4848 .29629 m .48434 .25069 L .5077 .23682 L p .519 .324 .555 r
F P
0 g
s
.48434 .25069 m .4848 .29629 L .46427 .31176 L p .504 .327 .575 r
F P
0 g
s
.39765 .45859 m .40324 .4333 L .41767 .42472 L p .251 0 .274 r
F P
0 g
s
.40324 .4333 m .39765 .45859 L .38164 .46509 L p .366 .061 .309 r
F P
0 g
s
.41019 .81343 m .45656 .8108 L .45942 .80851 L p .676 .92 .974 r
F P
0 g
s
.45656 .8108 m .41019 .81343 L .40597 .81749 L p .691 .92 .97 r
F P
0 g
s
.26024 .52307 m .27268 .48797 L .24574 .49397 L p .543 .25 .419 r
F P
0 g
s
.24574 .49397 m .23423 .53158 L .26024 .52307 L p .543 .25 .419 r
F P
0 g
s
.69169 .22711 m .69496 .26878 L .6715 .25757 L p .838 .515 .443 r
F P
0 g
s
.6715 .25757 m .66834 .21623 L .69169 .22711 L p .838 .515 .443 r
F P
0 g
s
.59458 .8094 m .63953 .81026 L .64384 .81396 L p .388 .682 .976 r
F P
0 g
s
.63953 .81026 m .59458 .8094 L .5916 .80723 L p .373 .688 .98 r
F P
0 g
s
.16586 .75933 m .13619 .71072 L .1332 .72417 L p .128 .246 .718 r
F P
0 g
s
.1332 .72417 m .16271 .77137 L .16586 .75933 L p .128 .246 .718 r
F P
0 g
s
.26771 .83992 m .20855 .81861 L .2096 .8276 L p .448 .661 .953 r
F P
0 g
s
.2096 .8276 m .26763 .84737 L .26771 .83992 L p .448 .661 .953 r
F P
0 g
s
.26763 .84737 m .33143 .85116 L .33208 .84537 L p .607 .787 .967 r
F P
0 g
s
.4322 .41424 m .43224 .38173 L .44793 .36838 L p .324 .153 .489 r
F P
0 g
s
.43224 .38173 m .4322 .41424 L .41767 .42472 L p .355 .18 .501 r
F P
0 g
s
.83149 .81405 m .7793 .83798 L .77645 .82846 L p .795 .81 .864 r
F P
0 g
s
.77645 .82846 m .82712 .80189 L .83149 .81405 L p .795 .81 .864 r
F P
0 g
s
.33369 .83941 m .39469 .8342 L .39664 .83001 L p .697 .863 .961 r
F P
0 g
s
.39469 .8342 m .33369 .83941 L .33208 .84537 L p .699 .861 .959 r
F P
0 g
s
.8167 .60318 m .82709 .64985 L .81914 .63942 L p .924 .585 .132 r
F P
0 g
s
.81914 .63942 m .80972 .59254 L .8167 .60318 L p .924 .585 .132 r
F P
0 g
s
.41494 .80948 m .45942 .80851 L .46257 .80631 L p .66 .918 .977 r
F P
0 g
s
.45942 .80851 m .41494 .80948 L .41019 .81343 L p .676 .92 .974 r
F P
0 g
s
.28556 .51577 m .2986 .48312 L .27268 .48797 L p .551 .24 .395 r
F P
0 g
s
.27268 .48797 m .26024 .52307 L .28556 .51577 L p .551 .24 .395 r
F P
0 g
s
.65613 .83048 m .71432 .83191 L .71694 .83862 L p .554 .708 .943 r
F P
0 g
s
.71432 .83191 m .65613 .83048 L .65382 .82614 L p .549 .715 .949 r
F P
0 g
s
.76695 .48557 m .77976 .51943 L .77483 .5065 L p 0 0 .26 r
F P
0 g
s
.77483 .5065 m .764 .47062 L .76695 .48557 L p 0 0 .26 r
F P
0 g
s
.5916 .80723 m .63474 .80674 L .63953 .81026 L p .373 .688 .98 r
F P
0 g
s
.63474 .80674 m .5916 .80723 L .58835 .80518 L p .359 .693 .982 r
F P
0 g
s
.20957 .80898 m .16271 .77137 L .16254 .7826 L p .274 .469 .869 r
F P
0 g
s
.16254 .7826 m .20855 .81861 L .20957 .80898 L p .274 .469 .869 r
F P
0 g
s
.7793 .83798 m .71881 .84546 L .71694 .83862 L p .675 .764 .918 r
F P
0 g
s
.30949 .50934 m .32272 .47894 L .2986 .48312 L p .541 .213 .362 r
F P
0 g
s
.2986 .48312 m .28556 .51577 L .30949 .50934 L p .541 .213 .362 r
F P
0 g
s
.73131 .30148 m .73196 .34388 L .7164 .32655 L p .951 .652 .434 r
F P
0 g
s
.7164 .32655 m .71502 .2837 L .73131 .30148 L p .951 .652 .434 r
F P
0 g
s
.42017 .80567 m .46257 .80631 L .466 .80422 L p .642 .916 .979 r
F P
0 g
s
.46257 .80631 m .42017 .80567 L .41494 .80948 L p .66 .918 .977 r
F P
0 g
s
.50773 .28144 m .5077 .23682 L .53295 .22465 L p .545 .328 .537 r
F P
0 g
s
.5077 .23682 m .50773 .28144 L .4848 .29629 L p .519 .324 .555 r
F P
0 g
s
.33208 .84537 m .26771 .83992 L .26763 .84737 L p .607 .787 .967 r
F P
0 g
s
.33161 .50343 m .34459 .47487 L .32272 .47894 L p .511 .167 .319 r
F P
0 g
s
.32272 .47894 m .30949 .50934 L .33161 .50343 L p .511 .167 .319 r
F P
0 g
s
.58835 .80518 m .62949 .80344 L .63474 .80674 L p .359 .693 .982 r
F P
0 g
s
.62949 .80344 m .58835 .80518 L .58482 .80325 L p .346 .698 .983 r
F P
0 g
s
.33626 .83331 m .39664 .83001 L .39918 .82581 L p .694 .865 .963 r
F P
0 g
s
.39664 .83001 m .33626 .83331 L .33369 .83941 L p .697 .863 .961 r
F P
0 g
s
.17917 .60071 m .18423 .5529 L .16256 .5657 L p .396 .191 .48 r
F P
0 g
s
.16256 .5657 m .15951 .61467 L .17917 .60071 L p .396 .191 .48 r
F P
0 g
s
.71694 .83862 m .77645 .82846 L .7793 .83798 L p .675 .764 .918 r
F P
0 g
s
.42587 .80203 m .466 .80422 L .46969 .80225 L p .624 .912 .982 r
F P
0 g
s
.466 .80422 m .42587 .80203 L .42017 .80567 L p .642 .916 .979 r
F P
0 g
s
.84469 .67275 m .83726 .72277 L .82897 .71149 L p .977 .747 .524 r
F P
0 g
s
.82897 .71149 m .83557 .66091 L .84469 .67275 L p .977 .747 .524 r
F P
0 g
s
.41294 .45073 m .41767 .42472 L .4322 .41424 L p .176 0 .263 r
F P
0 g
s
.41767 .42472 m .41294 .45073 L .39765 .45859 L p .251 0 .274 r
F P
0 g
s
.35186 .49764 m .36414 .47041 L .34459 .47487 L p .46 .101 .268 r
F P
0 g
s
.34459 .47487 m .33161 .50343 L .35186 .49764 L p .46 .101 .268 r
F P
0 g
s
.65382 .82614 m .71098 .82539 L .71432 .83191 L p .549 .715 .949 r
F P
0 g
s
.71098 .82539 m .65382 .82614 L .65099 .82192 L p .544 .722 .956 r
F P
0 g
s
.66834 .21623 m .6715 .25757 L .64532 .25072 L p .781 .468 .458 r
F P
0 g
s
.64532 .25072 m .64267 .20945 L .66834 .21623 L p .781 .468 .458 r
F P
0 g
s
.58482 .80325 m .62378 .80034 L .62949 .80344 L p .346 .698 .983 r
F P
0 g
s
.62378 .80034 m .58482 .80325 L .58103 .80144 L p .334 .703 .983 r
F P
0 g
s
.85342 .74785 m .82179 .79013 L .81568 .7789 L p .905 .806 .74 r
F P
0 g
s
.81568 .7789 m .84547 .7349 L .85342 .74785 L p .905 .806 .74 r
F P
0 g
s
.46542 .35377 m .46427 .31176 L .4848 .29629 L p .453 .287 .565 r
F P
0 g
s
.46427 .31176 m .46542 .35377 L .44793 .36838 L p .443 .292 .581 r
F P
0 g
s
.15385 .68217 m .14322 .62931 L .13104 .64427 L p .248 .179 .579 r
F P
0 g
s
.13104 .64427 m .14312 .69661 L .15385 .68217 L p .248 .179 .579 r
F P
0 g
s
.26771 .83992 m .33208 .84537 L .33369 .83941 L p .617 .786 .962 r
F P
0 g
s
.432 .79861 m .46969 .80225 L .47362 .80041 L p .604 .907 .983 r
F P
0 g
s
.46969 .80225 m .432 .79861 L .42587 .80203 L p .624 .912 .982 r
F P
0 g
s
.77645 .82846 m .71694 .83862 L .71432 .83191 L p .677 .768 .919 r
F P
0 g
s
.58103 .80144 m .61763 .79745 L .62378 .80034 L p .334 .703 .983 r
F P
0 g
s
.61763 .79745 m .58103 .80144 L .57701 .79975 L p .323 .708 .981 r
F P
0 g
s
.74337 .36294 m .74535 .40155 L .73417 .38399 L p .977 .68 .318 r
F P
0 g
s
.73417 .38399 m .73196 .34388 L .74337 .36294 L p .977 .68 .318 r
F P
0 g
s
.37044 .49162 m .38164 .46509 L .36414 .47041 L p .389 .022 .215 r
F P
0 g
s
.36414 .47041 m .35186 .49764 L .37044 .49162 L p .389 .022 .215 r
F P
0 g
s
.53299 .26828 m .53295 .22465 L .55975 .21514 L p .58 .342 .519 r
F P
0 g
s
.53295 .22465 m .53299 .26828 L .50773 .28144 L p .545 .328 .537 r
F P
0 g
s
.43854 .79542 m .47362 .80041 L .47778 .79871 L p .583 .9 .984 r
F P
0 g
s
.47362 .80041 m .43854 .79542 L .432 .79861 L p .604 .907 .983 r
F P
0 g
s
.33978 .8271 m .39918 .82581 L .40229 .82162 L p .691 .865 .965 r
F P
0 g
s
.39918 .82581 m .33978 .8271 L .33626 .83331 L p .694 .865 .963 r
F P
0 g
s
.82712 .80189 m .77645 .82846 L .7727 .81919 L p .799 .808 .859 r
F P
0 g
s
.7727 .81919 m .82179 .79013 L .82712 .80189 L p .799 .808 .859 r
F P
0 g
s
.44776 .40217 m .44793 .36838 L .46542 .35377 L p .328 .152 .484 r
F P
0 g
s
.44793 .36838 m .44776 .40217 L .4322 .41424 L p .324 .153 .489 r
F P
0 g
s
.57701 .79975 m .61106 .79478 L .61763 .79745 L p .323 .708 .981 r
F P
0 g
s
.61106 .79478 m .57701 .79975 L .57276 .7982 L p .315 .712 .979 r
F P
0 g
s
.65099 .82192 m .70696 .81912 L .71098 .82539 L p .544 .722 .956 r
F P
0 g
s
.70696 .81912 m .65099 .82192 L .64766 .81786 L p .537 .73 .964 r
F P
0 g
s
.44544 .79249 m .47778 .79871 L .48215 .79716 L p .561 .893 .985 r
F P
0 g
s
.47778 .79871 m .44544 .79249 L .43854 .79542 L p .583 .9 .984 r
F P
0 g
s
.64267 .20945 m .64532 .25072 L .61734 .24854 L p .725 .427 .473 r
F P
0 g
s
.61734 .24854 m .61543 .20707 L .64267 .20945 L p .725 .427 .473 r
F P
0 g
s
.78357 .53172 m .79778 .5714 L .79151 .5606 L p .696 .406 0 r
F P
0 g
s
.26923 .83209 m .20957 .80898 L .20855 .81861 L p .487 .666 .942 r
F P
0 g
s
.20855 .81861 m .26771 .83992 L .26923 .83209 L p .487 .666 .942 r
F P
0 g
s
.57276 .7982 m .60408 .79231 L .61106 .79478 L p .315 .712 .979 r
F P
0 g
s
.60408 .79231 m .57276 .7982 L .5683 .79679 L p .308 .717 .977 r
F P
0 g
s
.80972 .59254 m .81914 .63942 L .81142 .62947 L p .915 .6 .122 r
F P
0 g
s
.81142 .62947 m .8036 .58201 L .80972 .59254 L p .915 .6 .122 r
F P
0 g
s
.75266 .41966 m .75893 .45493 L .75079 .43901 L p .88 .586 .07 r
F P
0 g
s
.75079 .43901 m .74535 .40155 L .75266 .41966 L p .88 .586 .07 r
F P
0 g
s
.56018 .25784 m .55975 .21514 L .5875 .20908 L p .623 .363 .503 r
F P
0 g
s
.55975 .21514 m .56018 .25784 L .53299 .26828 L p .58 .342 .519 r
F P
0 g
s
.4527 .78984 m .48215 .79716 L .48671 .79577 L p .538 .884 .985 r
F P
0 g
s
.48215 .79716 m .4527 .78984 L .44544 .79249 L p .561 .893 .985 r
F P
0 g
s
.37044 .49162 m .38164 .46509 L .39765 .45859 L p .29 0 .164 r
F P
0 g
s
.20132 .58774 m .20852 .5415 L .18423 .5529 L p .455 .226 .476 r
F P
0 g
s
.18423 .5529 m .17917 .60071 L .20132 .58774 L p .455 .226 .476 r
F P
0 g
s
.71432 .83191 m .7727 .81919 L .77645 .82846 L p .677 .768 .919 r
F P
0 g
s
.33369 .83941 m .26923 .83209 L .26771 .83992 L p .617 .786 .962 r
F P
0 g
s
.5683 .79679 m .59672 .79006 L .60408 .79231 L p .308 .717 .977 r
F P
0 g
s
.59672 .79006 m .5683 .79679 L .56366 .79552 L p .304 .721 .974 r
F P
0 g
s
.17206 .74666 m .14312 .69661 L .13619 .71072 L p .271 .317 .727 r
F P
0 g
s
.13619 .71072 m .16586 .75933 L .17206 .74666 L p .271 .317 .727 r
F P
0 g
s
.34425 .82083 m .40229 .82162 L .40597 .81749 L p .687 .866 .966 r
F P
0 g
s
.40229 .82162 m .34425 .82083 L .33978 .8271 L p .691 .865 .965 r
F P
0 g
s
.61543 .20707 m .61734 .24854 L .58861 .25104 L p .672 .391 .488 r
F P
0 g
s
.58861 .25104 m .5875 .20908 L .61543 .20707 L p .672 .391 .488 r
F P
0 g
s
.48671 .79577 m .46026 .78749 L .4527 .78984 L p .538 .884 .985 r
F P
0 g
s
.46812 .78546 m .49144 .79455 L .48671 .79577 L p .512 .873 .984 r
F P
0 g
s
.48671 .79577 m .46026 .78749 L .46812 .78546 L p .512 .873 .984 r
F P
0 g
s
.26923 .83209 m .33369 .83941 L .33626 .83331 L p .626 .784 .957 r
F P
0 g
s
.5875 .20908 m .58861 .25104 L .56018 .25784 L p .623 .363 .503 r
F P
0 g
s
.71502 .2837 m .7164 .32655 L .69671 .31192 L p .904 .6 .46 r
F P
0 g
s
.69671 .31192 m .69496 .26878 L .71502 .2837 L p .904 .6 .46 r
F P
0 g
s
.7727 .81919 m .71432 .83191 L .71098 .82539 L p .679 .773 .922 r
F P
0 g
s
.64766 .81786 m .70227 .81314 L .70696 .81912 L p .537 .73 .964 r
F P
0 g
s
.70227 .81314 m .64766 .81786 L .64384 .81396 L p .53 .739 .971 r
F P
0 g
s
.56366 .79552 m .58901 .78801 L .59672 .79006 L p .304 .721 .974 r
F P
0 g
s
.58901 .78801 m .56366 .79552 L .55884 .79439 L p .301 .726 .972 r
F P
0 g
s
.42836 .44155 m .4322 .41424 L .44776 .40217 L p .16 0 .28 r
F P
0 g
s
.4322 .41424 m .42836 .44155 L .41294 .45073 L p .176 0 .263 r
F P
0 g
s
.48528 .33871 m .4848 .29629 L .50773 .28144 L p .478 .294 .552 r
F P
0 g
s
.4848 .29629 m .48528 .33871 L .46542 .35377 L p .453 .287 .565 r
F P
0 g
s
.47623 .78374 m .49633 .79349 L .49144 .79455 L p .484 .86 .983 r
F P
0 g
s
.49144 .79455 m .46812 .78546 L .47623 .78374 L p .484 .86 .983 r
F P
0 g
s
.21277 .79877 m .16586 .75933 L .16271 .77137 L p .362 .498 .861 r
F P
0 g
s
.16271 .77137 m .20957 .80898 L .21277 .79877 L p .362 .498 .861 r
F P
0 g
s
.83557 .66091 m .82897 .71149 L .82062 .70101 L p .986 .76 .513 r
F P
0 g
s
.82062 .70101 m .82709 .64985 L .83557 .66091 L p .986 .76 .513 r
F P
0 g
s
.84547 .7349 m .81568 .7789 L .80896 .76829 L p .91 .809 .735 r
F P
0 g
s
.80896 .76829 m .83726 .72277 L .84547 .7349 L p .91 .809 .735 r
F P
0 g
s
.55884 .79439 m .58098 .78618 L .58901 .78801 L p .301 .726 .972 r
F P
0 g
s
.58098 .78618 m .55884 .79439 L .55388 .79341 L p .301 .731 .97 r
F P
0 g
s
.48458 .78234 m .50134 .79261 L .49633 .79349 L p .456 .846 .98 r
F P
0 g
s
.49633 .79349 m .47623 .78374 L .48458 .78234 L p .456 .846 .98 r
F P
0 g
s
.55388 .79341 m .57268 .78457 L .58098 .78618 L p .301 .731 .97 r
F P
0 g
s
.57268 .78457 m .55388 .79341 L .54879 .79259 L p .303 .737 .968 r
F P
0 g
s
.49312 .78126 m .50647 .79191 L .50134 .79261 L p .43 .832 .978 r
F P
0 g
s
.50134 .79261 m .48458 .78234 L .49312 .78126 L p .43 .832 .978 r
F P
0 g
s
.764 .47062 m .77483 .5065 L .76781 .4931 L p .753 .466 0 r
F P
0 g
s
.76781 .4931 m .75893 .45493 L .764 .47062 L p .753 .466 0 r
F P
0 g
s
.34963 .81455 m .40597 .81749 L .41019 .81343 L p .682 .865 .968 r
F P
0 g
s
.40597 .81749 m .34963 .81455 L .34425 .82083 L p .687 .866 .966 r
F P
0 g
s
.54879 .79259 m .56414 .78318 L .57268 .78457 L p .303 .737 .968 r
F P
0 g
s
.56414 .78318 m .54879 .79259 L .5436 .79192 L p .307 .743 .967 r
F P
0 g
s
.50183 .7805 m .51169 .79139 L .50647 .79191 L p .405 .818 .975 r
F P
0 g
s
.50647 .79191 m .49312 .78126 L .50183 .7805 L p .405 .818 .975 r
F P
0 g
s
.16802 .66772 m .15951 .61467 L .14322 .62931 L p .355 .241 .584 r
F P
0 g
s
.14322 .62931 m .15385 .68217 L .16802 .66772 L p .355 .241 .584 r
F P
0 g
s
.82179 .79013 m .7727 .81919 L .76812 .81026 L p .803 .81 .857 r
F P
0 g
s
.76812 .81026 m .81568 .7789 L .82179 .79013 L p .803 .81 .857 r
F P
0 g
s
.22497 .57591 m .23423 .53158 L .20852 .5415 L p .491 .241 .463 r
F P
0 g
s
.20852 .5415 m .20132 .58774 L .22497 .57591 L p .491 .241 .463 r
F P
0 g
s
.64384 .81396 m .69694 .80747 L .70227 .81314 L p .53 .739 .971 r
F P
0 g
s
.69694 .80747 m .64384 .81396 L .63953 .81026 L p .522 .748 .978 r
F P
0 g
s
.5436 .79192 m .55542 .78202 L .56414 .78318 L p .307 .743 .967 r
F P
0 g
s
.55542 .78202 m .5436 .79192 L .53834 .79141 L p .313 .751 .967 r
F P
0 g
s
.38784 .48511 m .39765 .45859 L .41294 .45073 L p .186 0 .13 r
F P
0 g
s
.39765 .45859 m .38784 .48511 L .37044 .49162 L p .29 0 .164 r
F P
0 g
s
.51068 .78005 m .51698 .79105 L .51169 .79139 L p .383 .804 .973 r
F P
0 g
s
.51169 .79139 m .50183 .7805 L .51068 .78005 L p .383 .804 .973 r
F P
0 g
s
.53834 .79141 m .54655 .7811 L .55542 .78202 L p .313 .751 .967 r
F P
0 g
s
.54655 .7811 m .53834 .79141 L .53302 .79106 L p .322 .759 .967 r
F P
0 g
s
.51962 .77989 m .52231 .79088 L .51698 .79105 L p .364 .791 .971 r
F P
0 g
s
.51698 .79105 m .51068 .78005 L .51962 .77989 L p .364 .791 .971 r
F P
0 g
s
.53302 .79106 m .5376 .78043 L .54655 .7811 L p .322 .759 .967 r
F P
0 g
s
.5376 .78043 m .53302 .79106 L .52767 .79088 L p .333 .769 .968 r
F P
0 g
s
.5286 .78003 m .52767 .79088 L .52231 .79088 L p .347 .779 .969 r
F P
0 g
s
.52231 .79088 m .51962 .77989 L .5286 .78003 L p .347 .779 .969 r
F P
0 g
s
.52767 .79088 m .5286 .78003 L .5376 .78043 L p .333 .769 .968 r
F P
0 g
s
.46516 .38903 m .46542 .35377 L .48528 .33871 L p .358 .17 .485 r
F P
0 g
s
.46542 .35377 m .46516 .38903 L .44776 .40217 L p .328 .152 .484 r
F P
0 g
s
.27224 .82392 m .33626 .83331 L .33978 .8271 L p .634 .782 .952 r
F P
0 g
s
.33626 .83331 m .27224 .82392 L .26923 .83209 L p .626 .784 .957 r
F P
0 g
s
.71098 .82539 m .76812 .81026 L .7727 .81919 L p .679 .773 .922 r
F P
0 g
s
.76812 .81026 m .71098 .82539 L .70696 .81912 L p .679 .78 .927 r
F P
0 g
s
.35587 .80833 m .41019 .81343 L .41494 .80948 L p .676 .864 .971 r
F P
0 g
s
.41019 .81343 m .35587 .80833 L .34963 .81455 L p .682 .865 .968 r
F P
0 g
s
.73196 .34388 m .73417 .38399 L .71871 .3679 L p .961 .649 .389 r
F P
0 g
s
.71871 .3679 m .7164 .32655 L .73196 .34388 L p .961 .649 .389 r
F P
0 g
s
.20957 .80898 m .26923 .83209 L .27224 .82392 L p .519 .668 .93 r
F P
0 g
s
.24921 .56531 m .26024 .52307 L .23423 .53158 L p .511 .242 .443 r
F P
0 g
s
.23423 .53158 m .22497 .57591 L .24921 .56531 L p .511 .242 .443 r
F P
0 g
s
.63953 .81026 m .69095 .80213 L .69694 .80747 L p .522 .748 .978 r
F P
0 g
s
.69095 .80213 m .63953 .81026 L .63474 .80674 L p .515 .756 .984 r
F P
0 g
s
.50783 .32421 m .50773 .28144 L .53299 .26828 L p .514 .31 .541 r
F P
0 g
s
.50773 .28144 m .50783 .32421 L .48528 .33871 L p .478 .294 .552 r
F P
0 g
s
.27224 .82392 m .21277 .79877 L .20957 .80898 L p .519 .668 .93 r
F P
0 g
s
.69496 .26878 m .69671 .31192 L .67325 .30089 L p .847 .546 .48 r
F P
0 g
s
.67325 .30089 m .6715 .25757 L .69496 .26878 L p .847 .546 .48 r
F P
0 g
s
.8036 .58201 m .81142 .62947 L .8035 .61984 L p .923 .631 .15 r
F P
0 g
s
.8035 .61984 m .79778 .5714 L .8036 .58201 L p .923 .631 .15 r
F P
0 g
s
.44482 .43124 m .44776 .40217 L .46516 .38903 L p .195 0 .316 r
F P
0 g
s
.44776 .40217 m .44482 .43124 L .42836 .44155 L p .16 0 .28 r
F P
0 g
s
.83726 .72277 m .80896 .76829 L .8017 .75836 L p .917 .818 .733 r
F P
0 g
s
.8017 .75836 m .82897 .71149 L .83726 .72277 L p .917 .818 .733 r
F P
0 g
s
.36292 .80224 m .41494 .80948 L .42017 .80567 L p .669 .863 .973 r
F P
0 g
s
.41494 .80948 m .36292 .80224 L .35587 .80833 L p .676 .864 .971 r
F P
0 g
s
.27323 .55587 m .28556 .51577 L .26024 .52307 L p .516 .229 .417 r
F P
0 g
s
.26024 .52307 m .24921 .56531 L .27323 .55587 L p .516 .229 .417 r
F P
0 g
s
.82709 .64985 m .82062 .70101 L .81216 .69127 L p .993 .777 .508 r
F P
0 g
s
.81216 .69127 m .81914 .63942 L .82709 .64985 L p .993 .777 .508 r
F P
0 g
s
.18119 .73358 m .15385 .68217 L .14312 .69661 L p .367 .36 .72 r
F P
0 g
s
.14312 .69661 m .17206 .74666 L .18119 .73358 L p .367 .36 .72 r
F P
0 g
s
.40473 .47796 m .41294 .45073 L .42836 .44155 L p .13 0 .135 r
F P
0 g
s
.41294 .45073 m .40473 .47796 L .38784 .48511 L p .186 0 .13 r
F P
0 g
s
.77976 .51943 m .79151 .5606 L .78402 .54957 L p .796 .502 0 r
F P
0 g
s
.78402 .54957 m .77483 .5065 L .77976 .51943 L p .796 .502 0 r
F P
0 g
s
.63474 .80674 m .68432 .79712 L .69095 .80213 L p .515 .756 .984 r
F P
0 g
s
.68432 .79712 m .63474 .80674 L .62949 .80344 L p .507 .763 .988 r
F P
0 g
s
.70696 .81912 m .7628 .80175 L .76812 .81026 L p .679 .78 .927 r
F P
0 g
s
.7628 .80175 m .70696 .81912 L .70227 .81314 L p .679 .789 .932 r
F P
0 g
s
.27674 .81547 m .33978 .8271 L .34425 .82083 L p .64 .779 .947 r
F P
0 g
s
.33978 .8271 m .27674 .81547 L .27224 .82392 L p .634 .782 .952 r
F P
0 g
s
.81568 .7789 m .76812 .81026 L .7628 .80175 L p .806 .815 .858 r
F P
0 g
s
.7628 .80175 m .80896 .76829 L .81568 .7789 L p .806 .815 .858 r
F P
0 g
s
.29642 .54745 m .30949 .50934 L .28556 .51577 L p .508 .203 .385 r
F P
0 g
s
.28556 .51577 m .27323 .55587 L .29642 .54745 L p .508 .203 .385 r
F P
0 g
s
.74535 .40155 m .75079 .43901 L .73885 .42352 L p .954 .631 .22 r
F P
0 g
s
.73885 .42352 m .73417 .38399 L .74535 .40155 L p .954 .631 .22 r
F P
0 g
s
.21816 .78807 m .17206 .74666 L .16586 .75933 L p .428 .516 .846 r
F P
0 g
s
.16586 .75933 m .21277 .79877 L .21816 .78807 L p .428 .516 .846 r
F P
0 g
s
.18509 .6536 m .17917 .60071 L .15951 .61467 L p .424 .278 .577 r
F P
0 g
s
.15951 .61467 m .16802 .66772 L .18509 .6536 L p .424 .278 .577 r
F P
0 g
s
.3707 .79635 m .42017 .80567 L .42587 .80203 L p .661 .861 .976 r
F P
0 g
s
.42017 .80567 m .3707 .79635 L .36292 .80224 L p .669 .863 .973 r
F P
0 g
s
.31844 .53986 m .33161 .50343 L .30949 .50934 L p .485 .165 .348 r
F P
0 g
s
.30949 .50934 m .29642 .54745 L .31844 .53986 L p .485 .165 .348 r
F P
0 g
s
.533 .31131 m .53299 .26828 L .56018 .25784 L p .559 .335 .532 r
F P
0 g
s
.53299 .26828 m .533 .31131 L .50783 .32421 L p .514 .31 .541 r
F P
0 g
s
.62949 .80344 m .67703 .79245 L .68432 .79712 L p .507 .763 .988 r
F P
0 g
s
.67703 .79245 m .62949 .80344 L .62378 .80034 L p .5 .77 .992 r
F P
0 g
s
.48502 .37554 m .48528 .33871 L .50783 .32421 L p .405 .203 .49 r
F P
0 g
s
.48528 .33871 m .48502 .37554 L .46516 .38903 L p .358 .17 .485 r
F P
0 g
s
.6715 .25757 m .67325 .30089 L .6468 .29411 L p .786 .495 .495 r
F P
0 g
s
.6468 .29411 m .64532 .25072 L .6715 .25757 L p .786 .495 .495 r
F P
0 g
s
.21277 .79877 m .27224 .82392 L .27674 .81547 L p .546 .667 .916 r
F P
0 g
s
.33919 .53284 m .35186 .49764 L .33161 .50343 L p .451 .118 .31 r
F P
0 g
s
.33161 .50343 m .31844 .53986 L .33919 .53284 L p .451 .118 .31 r
F P
0 g
s
.37917 .79073 m .42587 .80203 L .432 .79861 L p .652 .858 .978 r
F P
0 g
s
.42587 .80203 m .37917 .79073 L .3707 .79635 L p .661 .861 .976 r
F P
0 g
s
.70227 .81314 m .75677 .79371 L .7628 .80175 L p .679 .789 .932 r
F P
0 g
s
.75677 .79371 m .70227 .81314 L .69694 .80747 L p .678 .798 .939 r
F P
0 g
s
.28269 .80683 m .34425 .82083 L .34963 .81455 L p .646 .776 .942 r
F P
0 g
s
.34425 .82083 m .28269 .80683 L .27674 .81547 L p .64 .779 .947 r
F P
0 g
s
.75893 .45493 m .76781 .4931 L .75787 .4796 L p .889 .57 .068 r
F P
0 g
s
.75787 .4796 m .75079 .43901 L .75893 .45493 L p .889 .57 .068 r
F P
0 g
s
.62378 .80034 m .66907 .78811 L .67703 .79245 L p .5 .77 .992 r
F P
0 g
s
.66907 .78811 m .62378 .80034 L .61763 .79745 L p .493 .776 .995 r
F P
0 g
s
.27674 .81547 m .21816 .78807 L .21277 .79877 L p .546 .667 .916 r
F P
0 g
s
.7164 .32655 m .71871 .3679 L .69895 .3542 L p .914 .601 .439 r
F P
0 g
s
.69895 .3542 m .69671 .31192 L .7164 .32655 L p .914 .601 .439 r
F P
0 g
s
.56037 .30106 m .56018 .25784 L .58861 .25104 L p .611 .367 .523 r
F P
0 g
s
.56018 .25784 m .56037 .30106 L .533 .31131 L p .559 .335 .532 r
F P
0 g
s
.35882 .52617 m .37044 .49162 L .35186 .49764 L p .409 .069 .275 r
F P
0 g
s
.35186 .49764 m .33919 .53284 L .35882 .52617 L p .409 .069 .275 r
F P
0 g
s
.82897 .71149 m .8017 .75836 L .79395 .74913 L p .923 .829 .735 r
F P
0 g
s
.79395 .74913 m .82062 .70101 L .82897 .71149 L p .923 .829 .735 r
F P
0 g
s
.38825 .78543 m .432 .79861 L .43854 .79542 L p .642 .855 .981 r
F P
0 g
s
.432 .79861 m .38825 .78543 L .37917 .79073 L p .652 .858 .978 r
F P
0 g
s
.42185 .47015 m .42836 .44155 L .44482 .43124 L p .133 0 .177 r
F P
0 g
s
.42836 .44155 m .42185 .47015 L .40473 .47796 L p .13 0 .135 r
F P
0 g
s
.20441 .64009 m .20132 .58774 L .17917 .60071 L p .47 .298 .565 r
F P
0 g
s
.17917 .60071 m .18509 .6536 L .20441 .64009 L p .47 .298 .565 r
F P
0 g
s
.64532 .25072 m .6468 .29411 L .61838 .29194 L p .725 .447 .506 r
F P
0 g
s
.61838 .29194 m .61734 .24854 L .64532 .25072 L p .725 .447 .506 r
F P
0 g
s
.80896 .76829 m .7628 .80175 L .75677 .79371 L p .81 .823 .861 r
F P
0 g
s
.75677 .79371 m .8017 .75836 L .80896 .76829 L p .81 .823 .861 r
F P
0 g
s
.46309 .42024 m .46516 .38903 L .48502 .37554 L p .26 .026 .357 r
F P
0 g
s
.46516 .38903 m .46309 .42024 L .44482 .43124 L p .195 0 .316 r
F P
0 g
s
.81914 .63942 m .81216 .69127 L .8034 .68217 L p .996 .794 .515 r
F P
0 g
s
.8034 .68217 m .81142 .62947 L .81914 .63942 L p .996 .794 .515 r
F P
0 g
s
.61763 .79745 m .66044 .78408 L .66907 .78811 L p .493 .776 .995 r
F P
0 g
s
.66044 .78408 m .61763 .79745 L .61106 .79478 L p .488 .78 .996 r
F P
0 g
s
.19303 .72034 m .16802 .66772 L .15385 .68217 L p .433 .386 .706 r
F P
0 g
s
.15385 .68217 m .18119 .73358 L .19303 .72034 L p .433 .386 .706 r
F P
0 g
s
.58918 .29438 m .58861 .25104 L .61734 .24854 L p .666 .404 .515 r
F P
0 g
s
.58861 .25104 m .58918 .29438 L .56037 .30106 L p .611 .367 .523 r
F P
0 g
s
.79778 .5714 m .8035 .61984 L .79487 .6104 L p .947 .673 .216 r
F P
0 g
s
.79487 .6104 m .79151 .5606 L .79778 .5714 L p .947 .673 .216 r
F P
0 g
s
.61734 .24854 m .61838 .29194 L .58918 .29438 L p .666 .404 .515 r
F P
0 g
s
.39788 .78053 m .43854 .79542 L .44544 .79249 L p .631 .851 .983 r
F P
0 g
s
.43854 .79542 m .39788 .78053 L .38825 .78543 L p .642 .855 .981 r
F P
0 g
s
.69694 .80747 m .75005 .78617 L .75677 .79371 L p .678 .798 .939 r
F P
0 g
s
.75005 .78617 m .69694 .80747 L .69095 .80213 L p .677 .807 .945 r
F P
0 g
s
.29003 .79809 m .34963 .81455 L .35587 .80833 L p .65 .772 .938 r
F P
0 g
s
.34963 .81455 m .29003 .79809 L .28269 .80683 L p .646 .776 .942 r
F P
0 g
s
.35882 .52617 m .37044 .49162 L .38784 .48511 L p .351 .014 .245 r
F P
0 g
s
.22568 .77703 m .18119 .73358 L .17206 .74666 L p .477 .526 .829 r
F P
0 g
s
.17206 .74666 m .21816 .78807 L .22568 .77703 L p .477 .526 .829 r
F P
0 g
s
.21816 .78807 m .27674 .81547 L .28269 .80683 L p .568 .665 .903 r
F P
0 g
s
.50767 .36259 m .50783 .32421 L .533 .31131 L p .463 .244 .495 r
F P
0 g
s
.50783 .32421 m .50767 .36259 L .48502 .37554 L p .405 .203 .49 r
F P
0 g
s
.61106 .79478 m .65114 .78035 L .66044 .78408 L p .488 .78 .996 r
F P
0 g
s
.65114 .78035 m .61106 .79478 L .60408 .79231 L p .483 .783 .998 r
F P
0 g
s
.40802 .77605 m .44544 .79249 L .4527 .78984 L p .619 .847 .986 r
F P
0 g
s
.44544 .79249 m .40802 .77605 L .39788 .78053 L p .631 .851 .983 r
F P
0 g
s
.77483 .5065 m .78402 .54957 L .77452 .5384 L p .898 .595 .095 r
F P
0 g
s
.77452 .5384 m .76781 .4931 L .77483 .5065 L p .898 .595 .095 r
F P
0 g
s
.22526 .62741 m .22497 .57591 L .20132 .58774 L p .5 .306 .549 r
F P
0 g
s
.20132 .58774 m .20441 .64009 L .22526 .62741 L p .5 .306 .549 r
F P
0 g
s
.73417 .38399 m .73885 .42352 L .72269 .40922 L p .957 .625 .334 r
F P
0 g
s
.72269 .40922 m .71871 .3679 L .73417 .38399 L p .957 .625 .334 r
F P
0 g
s
.60408 .79231 m .64117 .7769 L .65114 .78035 L p .483 .783 .998 r
F P
0 g
s
.64117 .7769 m .60408 .79231 L .59672 .79006 L p .479 .785 .998 r
F P
0 g
s
.41862 .77204 m .4527 .78984 L .46026 .78749 L p .606 .842 .989 r
F P
0 g
s
.4527 .78984 m .41862 .77204 L .40802 .77605 L p .619 .847 .986 r
F P
0 g
s
.8017 .75836 m .75677 .79371 L .75005 .78617 L p .812 .832 .865 r
F P
0 g
s
.29865 .78938 m .35587 .80833 L .36292 .80224 L p .652 .768 .934 r
F P
0 g
s
.35587 .80833 m .29865 .78938 L .29003 .79809 L p .65 .772 .938 r
F P
0 g
s
.69095 .80213 m .74264 .77914 L .75005 .78617 L p .677 .807 .945 r
F P
0 g
s
.74264 .77914 m .69095 .80213 L .68432 .79712 L p .674 .816 .951 r
F P
0 g
s
.28269 .80683 m .22568 .77703 L .21816 .78807 L p .568 .665 .903 r
F P
0 g
s
.69671 .31192 m .69895 .3542 L .67528 .34372 L p .853 .547 .47 r
F P
0 g
s
.67528 .34372 m .67325 .30089 L .69671 .31192 L p .853 .547 .47 r
F P
0 g
s
.75005 .78617 m .79395 .74913 L .8017 .75836 L p .812 .832 .865 r
F P
0 g
s
.82062 .70101 m .79395 .74913 L .78565 .74056 L p .927 .841 .739 r
F P
0 g
s
.78565 .74056 m .81216 .69127 L .82062 .70101 L p .927 .841 .739 r
F P
0 g
s
.37771 .51966 m .38784 .48511 L .40473 .47796 L p .289 0 .229 r
F P
0 g
s
.38784 .48511 m .37771 .51966 L .35882 .52617 L p .351 .014 .245 r
F P
0 g
s
.59672 .79006 m .63056 .77374 L .64117 .7769 L p .479 .785 .998 r
F P
0 g
s
.63056 .77374 m .59672 .79006 L .58901 .78801 L p .477 .787 .998 r
F P
0 g
s
.46026 .78749 m .42964 .76853 L .41862 .77204 L p .606 .842 .989 r
F P
0 g
s
.44106 .76554 m .46812 .78546 L .46026 .78749 L p .59 .837 .991 r
F P
0 g
s
.46026 .78749 m .42964 .76853 L .44106 .76554 L p .59 .837 .991 r
F P
0 g
s
.44001 .46184 m .44482 .43124 L .46309 .42024 L p .183 0 .238 r
F P
0 g
s
.44482 .43124 m .44001 .46184 L .42185 .47015 L p .133 0 .177 r
F P
0 g
s
.24696 .61571 m .24921 .56531 L .22497 .57591 L p .517 .304 .53 r
F P
0 g
s
.22497 .57591 m .22526 .62741 L .24696 .61571 L p .517 .304 .53 r
F P
0 g
s
.20722 .7072 m .18509 .6536 L .16802 .66772 L p .479 .401 .69 r
F P
0 g
s
.16802 .66772 m .19303 .72034 L .20722 .7072 L p .479 .401 .69 r
F P
0 g
s
.22568 .77703 m .28269 .80683 L .29003 .79809 L p .586 .662 .89 r
F P
0 g
s
.48378 .40913 m .48502 .37554 L .50767 .36259 L p .339 .099 .397 r
F P
0 g
s
.48502 .37554 m .48378 .40913 L .46309 .42024 L p .26 .026 .357 r
F P
0 g
s
.45286 .76307 m .47623 .78374 L .46812 .78546 L p .572 .829 .994 r
F P
0 g
s
.46812 .78546 m .44106 .76554 L .45286 .76307 L p .572 .829 .994 r
F P
0 g
s
.58901 .78801 m .61934 .77084 L .63056 .77374 L p .477 .787 .998 r
F P
0 g
s
.61934 .77084 m .58901 .78801 L .58098 .78618 L p .475 .787 .999 r
F P
0 g
s
.53307 .35114 m .533 .31131 L .56037 .30106 L p .525 .289 .5 r
F P
0 g
s
.533 .31131 m .53307 .35114 L .50767 .36259 L p .463 .244 .495 r
F P
0 g
s
.81142 .62947 m .8034 .68217 L .79406 .67359 L p .997 .809 .533 r
F P
0 g
s
.79406 .67359 m .8035 .61984 L .81142 .62947 L p .997 .809 .533 r
F P
0 g
s
.30842 .78082 m .36292 .80224 L .3707 .79635 L p .654 .764 .931 r
F P
0 g
s
.36292 .80224 m .30842 .78082 L .29865 .78938 L p .652 .768 .934 r
F P
0 g
s
.75079 .43901 m .75787 .4796 L .74435 .46646 L p .956 .622 .231 r
F P
0 g
s
.74435 .46646 m .73885 .42352 L .75079 .43901 L p .956 .622 .231 r
F P
0 g
s
.68432 .79712 m .73449 .77261 L .74264 .77914 L p .674 .816 .951 r
F P
0 g
s
.73449 .77261 m .68432 .79712 L .67703 .79245 L p .671 .823 .956 r
F P
0 g
s
.465 .76111 m .48458 .78234 L .47623 .78374 L p .553 .822 .996 r
F P
0 g
s
.47623 .78374 m .45286 .76307 L .465 .76111 L p .553 .822 .996 r
F P
0 g
s
.23519 .76583 m .19303 .72034 L .18119 .73358 L p .514 .531 .811 r
F P
0 g
s
.18119 .73358 m .22568 .77703 L .23519 .76583 L p .514 .531 .811 r
F P
0 g
s
.58098 .78618 m .60757 .76821 L .61934 .77084 L p .475 .787 .999 r
F P
0 g
s
.60757 .76821 m .58098 .78618 L .57268 .78457 L p .474 .787 .999 r
F P
0 g
s
.2689 .60507 m .27323 .55587 L .24921 .56531 L p .524 .295 .51 r
F P
0 g
s
.24921 .56531 m .24696 .61571 L .2689 .60507 L p .524 .295 .51 r
F P
0 g
s
.79395 .74913 m .75005 .78617 L .74264 .77914 L p .814 .841 .871 r
F P
0 g
s
.47746 .75967 m .49312 .78126 L .48458 .78234 L p .536 .814 .997 r
F P
0 g
s
.48458 .78234 m .465 .76111 L .47746 .75967 L p .536 .814 .997 r
F P
0 g
s
.57268 .78457 m .5953 .76585 L .60757 .76821 L p .474 .787 .999 r
F P
0 g
s
.5953 .76585 m .57268 .78457 L .56414 .78318 L p .473 .787 .999 r
F P
0 g
s
.79151 .5606 m .79487 .6104 L .78494 .6011 L p .976 .714 .304 r
F P
0 g
s
.78494 .6011 m .78402 .54957 L .79151 .5606 L p .976 .714 .304 r
F P
0 g
s
.67325 .30089 m .67528 .34372 L .64848 .33709 L p .787 .492 .489 r
F P
0 g
s
.64848 .33709 m .6468 .29411 L .67325 .30089 L p .787 .492 .489 r
F P
0 g
s
.49021 .75872 m .50183 .7805 L .49312 .78126 L p .521 .807 .998 r
F P
0 g
s
.49312 .78126 m .47746 .75967 L .49021 .75872 L p .521 .807 .998 r
F P
0 g
s
.39637 .5132 m .40473 .47796 L .42185 .47015 L p .257 0 .24 r
F P
0 g
s
.40473 .47796 m .39637 .5132 L .37771 .51966 L p .289 0 .229 r
F P
0 g
s
.56414 .78318 m .58264 .76377 L .5953 .76585 L p .473 .787 .999 r
F P
0 g
s
.58264 .76377 m .56414 .78318 L .55542 .78202 L p .474 .787 .999 r
F P
0 g
s
.29003 .79809 m .23519 .76583 L .22568 .77703 L p .586 .662 .89 r
F P
0 g
s
.29061 .59547 m .29642 .54745 L .27323 .55587 L p .522 .278 .487 r
F P
0 g
s
.27323 .55587 m .2689 .60507 L .29061 .59547 L p .522 .278 .487 r
F P
0 g
s
.50321 .75824 m .51068 .78005 L .50183 .7805 L p .508 .801 .998 r
F P
0 g
s
.50183 .7805 m .49021 .75872 L .50321 .75824 L p .508 .801 .998 r
F P
0 g
s
.3192 .77253 m .3707 .79635 L .37917 .79073 L p .653 .76 .928 r
F P
0 g
s
.3707 .79635 m .3192 .77253 L .30842 .78082 L p .654 .764 .931 r
F P
0 g
s
.74264 .77914 m .78565 .74056 L .79395 .74913 L p .814 .841 .871 r
F P
0 g
s
.55542 .78202 m .56965 .76198 L .58264 .76377 L p .474 .787 .999 r
F P
0 g
s
.56965 .76198 m .55542 .78202 L .54655 .7811 L p .475 .787 .999 r
F P
0 g
s
.56077 .34216 m .56037 .30106 L .58918 .29438 L p .589 .337 .503 r
F P
0 g
s
.56037 .30106 m .56077 .34216 L .53307 .35114 L p .525 .289 .5 r
F P
0 g
s
.23519 .76583 m .29003 .79809 L .29865 .78938 L p .6 .658 .878 r
F P
0 g
s
.5164 .7582 m .51962 .77989 L .51068 .78005 L p .497 .796 .998 r
F P
0 g
s
.51068 .78005 m .50321 .75824 L .5164 .7582 L p .497 .796 .998 r
F P
0 g
s
.54655 .7811 m .55644 .76051 L .56965 .76198 L p .475 .787 .999 r
F P
0 g
s
.55644 .76051 m .54655 .7811 L .5376 .78043 L p .478 .788 .999 r
F P
0 g
s
.71871 .3679 m .72269 .40922 L .7023 .39689 L p .915 .587 .408 r
F P
0 g
s
.7023 .39689 m .69895 .3542 L .71871 .3679 L p .915 .587 .408 r
F P
0 g
s
.67703 .79245 m .72555 .76656 L .73449 .77261 L p .671 .823 .956 r
F P
0 g
s
.72555 .76656 m .67703 .79245 L .66907 .78811 L p .668 .827 .96 r
F P
0 g
s
.22334 .69441 m .20441 .64009 L .18509 .6536 L p .511 .408 .674 r
F P
0 g
s
.18509 .6536 m .20722 .7072 L .22334 .69441 L p .511 .408 .674 r
F P
0 g
s
.52972 .75859 m .5286 .78003 L .51962 .77989 L p .489 .792 .999 r
F P
0 g
s
.51962 .77989 m .5164 .7582 L .52972 .75859 L p .489 .792 .999 r
F P
0 g
s
.81216 .69127 m .78565 .74056 L .77672 .73262 L p .928 .851 .746 r
F P
0 g
s
.77672 .73262 m .8034 .68217 L .81216 .69127 L p .928 .851 .746 r
F P
0 g
s
.5376 .78043 m .5431 .75937 L .55644 .76051 L p .478 .788 .999 r
F P
0 g
s
.5431 .75937 m .5376 .78043 L .5286 .78003 L p .482 .789 .999 r
F P
0 g
s
.5286 .78003 m .52972 .75859 L .5431 .75937 L p .482 .789 .999 r
F P
0 g
s
.31181 .58686 m .31844 .53986 L .29642 .54745 L p .512 .257 .465 r
F P
0 g
s
.29642 .54745 m .29061 .59547 L .31181 .58686 L p .512 .257 .465 r
F P
0 g
s
.45987 .45331 m .46309 .42024 L .48378 .40913 L p .259 0 .303 r
F P
0 g
s
.46309 .42024 m .45987 .45331 L .44001 .46184 L p .183 0 .238 r
F P
0 g
s
.76781 .4931 m .77452 .5384 L .76234 .52728 L p .962 .654 .246 r
F P
0 g
s
.76234 .52728 m .75787 .4796 L .76781 .4931 L p .962 .654 .246 r
F P
0 g
s
.6468 .29411 m .64848 .33709 L .61963 .33467 L p .72 .438 .498 r
F P
0 g
s
.61963 .33467 m .61838 .29194 L .6468 .29411 L p .72 .438 .498 r
F P
0 g
s
.50717 .39864 m .50767 .36259 L .53307 .35114 L p .42 .172 .429 r
F P
0 g
s
.50767 .36259 m .50717 .39864 L .48378 .40913 L p .339 .099 .397 r
F P
0 g
s
.33086 .76463 m .37917 .79073 L .38825 .78543 L p .652 .756 .926 r
F P
0 g
s
.37917 .79073 m .33086 .76463 L .3192 .77253 L p .653 .76 .928 r
F P
0 g
s
.58998 .33646 m .58918 .29438 L .61838 .29194 L p .654 .387 .503 r
F P
0 g
s
.58918 .29438 m .58998 .33646 L .56077 .34216 L p .589 .337 .503 r
F P
0 g
s
.78565 .74056 m .74264 .77914 L .73449 .77261 L p .814 .849 .876 r
F P
0 g
s
.2465 .75464 m .20722 .7072 L .19303 .72034 L p .541 .532 .794 r
F P
0 g
s
.19303 .72034 m .23519 .76583 L .2465 .75464 L p .541 .532 .794 r
F P
0 g
s
.61838 .29194 m .61963 .33467 L .58998 .33646 L p .654 .387 .503 r
F P
0 g
s
.3324 .57913 m .33919 .53284 L .31844 .53986 L p .497 .233 .444 r
F P
0 g
s
.31844 .53986 m .31181 .58686 L .3324 .57913 L p .497 .233 .444 r
F P
0 g
s
.66907 .78811 m .71576 .76095 L .72555 .76656 L p .668 .827 .96 r
F P
0 g
s
.71576 .76095 m .66907 .78811 L .66044 .78408 L p .664 .83 .963 r
F P
0 g
s
.2465 .75464 m .29865 .78938 L .30842 .78082 L p .611 .653 .867 r
F P
0 g
s
.29865 .78938 m .2465 .75464 L .23519 .76583 L p .6 .658 .878 r
F P
0 g
s
.8035 .61984 m .79406 .67359 L .78381 .66546 L p .994 .819 .562 r
F P
0 g
s
.78381 .66546 m .79487 .6104 L .8035 .61984 L p .994 .819 .562 r
F P
0 g
s
.41541 .50676 m .42185 .47015 L .44001 .46184 L p .262 0 .274 r
F P
0 g
s
.42185 .47015 m .41541 .50676 L .39637 .5132 L p .257 0 .24 r
F P
0 g
s
.24091 .6822 m .22526 .62741 L .20441 .64009 L p .533 .41 .658 r
F P
0 g
s
.20441 .64009 m .22334 .69441 L .24091 .6822 L p .533 .41 .658 r
F P
0 g
s
.34327 .75722 m .38825 .78543 L .39788 .78053 L p .649 .752 .925 r
F P
0 g
s
.38825 .78543 m .34327 .75722 L .33086 .76463 L p .652 .756 .926 r
F P
0 g
s
.73449 .77261 m .77672 .73262 L .78565 .74056 L p .814 .849 .876 r
F P
0 g
s
.35248 .57215 m .35882 .52617 L .33919 .53284 L p .479 .211 .428 r
F P
0 g
s
.33919 .53284 m .3324 .57913 L .35248 .57215 L p .479 .211 .428 r
F P
0 g
s
.73885 .42352 m .74435 .46646 L .72691 .45423 L p .953 .62 .35 r
F P
0 g
s
.72691 .45423 m .72269 .40922 L .73885 .42352 L p .953 .62 .35 r
F P
0 g
s
.66044 .78408 m .70505 .75575 L .71576 .76095 L p .664 .83 .963 r
F P
0 g
s
.70505 .75575 m .66044 .78408 L .65114 .78035 L p .66 .829 .965 r
F P
0 g
s
.69895 .3542 m .7023 .39689 L .67807 .38722 L p .853 .536 .45 r
F P
0 g
s
.67807 .38722 m .67528 .34372 L .69895 .3542 L p .853 .536 .45 r
F P
0 g
s
.8034 .68217 m .77672 .73262 L .76702 .72525 L p .926 .857 .755 r
F P
0 g
s
.76702 .72525 m .79406 .67359 L .8034 .68217 L p .926 .857 .755 r
F P
0 g
s
.77672 .73262 m .73449 .77261 L .72555 .76656 L p .811 .854 .881 r
F P
0 g
s
.35631 .75038 m .39788 .78053 L .40802 .77605 L p .645 .748 .924 r
F P
0 g
s
.39788 .78053 m .35631 .75038 L .34327 .75722 L p .649 .752 .925 r
F P
0 g
s
.78402 .54957 m .78494 .6011 L .77316 .59193 L p .992 .74 .397 r
F P
0 g
s
.77316 .59193 m .77452 .5384 L .78402 .54957 L p .992 .74 .397 r
F P
0 g
s
.53323 .38955 m .53307 .35114 L .56077 .34216 L p .499 .241 .454 r
F P
0 g
s
.53307 .35114 m .53323 .38955 L .50717 .39864 L p .42 .172 .429 r
F P
0 g
s
.25934 .74367 m .22334 .69441 L .20722 .7072 L p .562 .531 .778 r
F P
0 g
s
.20722 .7072 m .2465 .75464 L .25934 .74367 L p .562 .531 .778 r
F P
0 g
s
.25934 .74367 m .30842 .78082 L .3192 .77253 L p .619 .648 .857 r
F P
0 g
s
.30842 .78082 m .25934 .74367 L .2465 .75464 L p .611 .653 .867 r
F P
0 g
s
.25947 .67073 m .24696 .61571 L .22526 .62741 L p .547 .407 .642 r
F P
0 g
s
.22526 .62741 m .24091 .6822 L .25947 .67073 L p .547 .407 .642 r
F P
0 g
s
.35248 .57215 m .35882 .52617 L .37771 .51966 L p .453 .186 .417 r
F P
0 g
s
.48195 .44499 m .48378 .40913 L .50717 .39864 L p .345 .08 .361 r
F P
0 g
s
.48378 .40913 m .48195 .44499 L .45987 .45331 L p .259 0 .303 r
F P
0 g
s
.36989 .74419 m .40802 .77605 L .41862 .77204 L p .64 .744 .924 r
F P
0 g
s
.40802 .77605 m .36989 .74419 L .35631 .75038 L p .645 .748 .924 r
F P
0 g
s
.65114 .78035 m .69335 .75092 L .70505 .75575 L p .66 .829 .965 r
F P
0 g
s
.69335 .75092 m .65114 .78035 L .64117 .7769 L p .655 .826 .965 r
F P
0 g
s
.43544 .50041 m .44001 .46184 L .45987 .45331 L p .299 .027 .322 r
F P
0 g
s
.44001 .46184 m .43544 .50041 L .41541 .50676 L p .262 0 .274 r
F P
0 g
s
.72555 .76656 m .76702 .72525 L .77672 .73262 L p .811 .854 .881 r
F P
0 g
s
.27861 .66015 m .2689 .60507 L .24696 .61571 L p .555 .4 .626 r
F P
0 g
s
.24696 .61571 m .25947 .67073 L .27861 .66015 L p .555 .4 .626 r
F P
0 g
s
.75787 .4796 m .76234 .52728 L .74697 .51649 L p .974 .67 .366 r
F P
0 g
s
.74697 .51649 m .74435 .46646 L .75787 .4796 L p .974 .67 .366 r
F P
0 g
s
.27346 .73308 m .3192 .77253 L .33086 .76463 L p .624 .642 .848 r
F P
0 g
s
.3192 .77253 m .27346 .73308 L .25934 .74367 L p .619 .648 .857 r
F P
0 g
s
.38397 .73869 m .41862 .77204 L .42964 .76853 L p .635 .741 .925 r
F P
0 g
s
.41862 .77204 m .38397 .73869 L .36989 .74419 L p .64 .744 .924 r
F P
0 g
s
.76702 .72525 m .72555 .76656 L .71576 .76095 L p .807 .855 .885 r
F P
0 g
s
.67528 .34372 m .67807 .38722 L .65076 .38078 L p .786 .481 .472 r
F P
0 g
s
.65076 .38078 m .64848 .33709 L .67528 .34372 L p .786 .481 .472 r
F P
0 g
s
.56152 .38264 m .56077 .34216 L .58998 .33646 L p .574 .305 .471 r
F P
0 g
s
.56077 .34216 m .56152 .38264 L .53323 .38955 L p .499 .241 .454 r
F P
0 g
s
.79487 .6104 m .78381 .66546 L .77228 .65768 L p .985 .821 .597 r
F P
0 g
s
.77228 .65768 m .78494 .6011 L .79487 .6104 L p .985 .821 .597 r
F P
0 g
s
.37228 .56584 m .37771 .51966 L .39637 .5132 L p .423 .164 .414 r
F P
0 g
s
.37771 .51966 m .37228 .56584 L .35248 .57215 L p .453 .186 .417 r
F P
0 g
s
.27346 .73308 m .24091 .6822 L .22334 .69441 L p .576 .528 .764 r
F P
0 g
s
.22334 .69441 m .25934 .74367 L .27346 .73308 L p .576 .528 .764 r
F P
0 g
s
.64117 .7769 m .68064 .74643 L .69335 .75092 L p .655 .826 .965 r
F P
0 g
s
.68064 .74643 m .64117 .7769 L .63056 .77374 L p .65 .821 .965 r
F P
0 g
s
.29802 .65051 m .29061 .59547 L .2689 .60507 L p .557 .391 .612 r
F P
0 g
s
.2689 .60507 m .27861 .66015 L .29802 .65051 L p .557 .391 .612 r
F P
0 g
s
.42964 .76853 m .3985 .73392 L .38397 .73869 L p .635 .741 .925 r
F P
0 g
s
.41348 .72989 m .44106 .76554 L .42964 .76853 L p .626 .737 .927 r
F P
0 g
s
.42964 .76853 m .3985 .73392 L .41348 .72989 L p .626 .737 .927 r
F P
0 g
s
.72269 .40922 m .72691 .45423 L .70553 .4435 L p .91 .588 .423 r
F P
0 g
s
.70553 .4435 m .7023 .39689 L .72269 .40922 L p .91 .588 .423 r
F P
0 g
s
.79406 .67359 m .76702 .72525 L .75635 .71838 L p .919 .858 .765 r
F P
0 g
s
.75635 .71838 m .78381 .66546 L .79406 .67359 L p .919 .858 .765 r
F P
0 g
s
.28857 .72304 m .33086 .76463 L .34327 .75722 L p .627 .637 .841 r
F P
0 g
s
.33086 .76463 m .28857 .72304 L .27346 .73308 L p .624 .642 .848 r
F P
0 g
s
.63056 .77374 m .6669 .74227 L .68064 .74643 L p .65 .821 .965 r
F P
0 g
s
.6669 .74227 m .63056 .77374 L .61934 .77084 L p .644 .814 .964 r
F P
0 g
s
.64848 .33709 m .65076 .38078 L .62142 .37789 L p .717 .424 .481 r
F P
0 g
s
.62142 .37789 m .61963 .33467 L .64848 .33709 L p .717 .424 .481 r
F P
0 g
s
.59127 .37859 m .58998 .33646 L .61963 .33467 L p .646 .366 .48 r
F P
0 g
s
.58998 .33646 m .59127 .37859 L .56152 .38264 L p .574 .305 .471 r
F P
0 g
s
.50649 .43739 m .50717 .39864 L .53323 .38955 L p .429 .165 .409 r
F P
0 g
s
.50717 .39864 m .50649 .43739 L .48195 .44499 L p .345 .08 .361 r
F P
0 g
s
.42891 .7266 m .45286 .76307 L .44106 .76554 L p .616 .733 .93 r
F P
0 g
s
.44106 .76554 m .41348 .72989 L .42891 .7266 L p .616 .733 .93 r
F P
0 g
s
.31749 .64186 m .31181 .58686 L .29061 .59547 L p .555 .38 .599 r
F P
0 g
s
.29061 .59547 m .29802 .65051 L .31749 .64186 L p .555 .38 .599 r
F P
0 g
s
.61963 .33467 m .62142 .37789 L .59127 .37859 L p .646 .366 .48 r
F P
0 g
s
.28857 .72304 m .25947 .67073 L .24091 .6822 L p .586 .523 .751 r
F P
0 g
s
.24091 .6822 m .27346 .73308 L .28857 .72304 L p .586 .523 .751 r
F P
0 g
s
.71576 .76095 m .75635 .71838 L .76702 .72525 L p .807 .855 .885 r
F P
0 g
s
.75635 .71838 m .71576 .76095 L .70505 .75575 L p .801 .852 .888 r
F P
0 g
s
.77452 .5384 m .77316 .59193 L .75904 .58297 L p .987 .744 .477 r
F P
0 g
s
.75904 .58297 m .76234 .52728 L .77452 .5384 L p .987 .744 .477 r
F P
0 g
s
.39216 .5601 m .39637 .5132 L .41541 .50676 L p .407 .159 .423 r
F P
0 g
s
.39637 .5132 m .39216 .5601 L .37228 .56584 L p .423 .164 .414 r
F P
0 g
s
.61934 .77084 m .65217 .73841 L .6669 .74227 L p .644 .814 .964 r
F P
0 g
s
.65217 .73841 m .61934 .77084 L .60757 .76821 L p .638 .805 .963 r
F P
0 g
s
.4448 .72404 m .465 .76111 L .45286 .76307 L p .606 .73 .933 r
F P
0 g
s
.45286 .76307 m .42891 .7266 L .4448 .72404 L p .606 .73 .933 r
F P
0 g
s
.457 .49431 m .45987 .45331 L .48195 .44499 L p .355 .095 .374 r
F P
0 g
s
.45987 .45331 m .457 .49431 L .43544 .50041 L p .299 .027 .322 r
F P
0 g
s
.30444 .71368 m .34327 .75722 L .35631 .75038 L p .628 .632 .835 r
F P
0 g
s
.34327 .75722 m .30444 .71368 L .28857 .72304 L p .627 .637 .841 r
F P
0 g
s
.33692 .63419 m .3324 .57913 L .31181 .58686 L p .55 .369 .588 r
F P
0 g
s
.31181 .58686 m .31749 .64186 L .33692 .63419 L p .55 .369 .588 r
F P
0 g
s
.46118 .7222 m .47746 .75967 L .465 .76111 L p .598 .728 .935 r
F P
0 g
s
.465 .76111 m .4448 .72404 L .46118 .7222 L p .598 .728 .935 r
F P
0 g
s
.60757 .76821 m .63652 .73487 L .65217 .73841 L p .638 .805 .963 r
F P
0 g
s
.63652 .73487 m .60757 .76821 L .5953 .76585 L p .631 .795 .961 r
F P
0 g
s
.30444 .71368 m .27861 .66015 L .25947 .67073 L p .592 .517 .739 r
F P
0 g
s
.25947 .67073 m .28857 .72304 L .30444 .71368 L p .592 .517 .739 r
F P
0 g
s
.74435 .46646 m .74697 .51649 L .72815 .50638 L p .946 .652 .448 r
F P
0 g
s
.72815 .50638 m .72691 .45423 L .74435 .46646 L p .946 .652 .448 r
F P
0 g
s
.47802 .72103 m .49021 .75872 L .47746 .75967 L p .592 .727 .938 r
F P
0 g
s
.47746 .75967 m .46118 .7222 L .47802 .72103 L p .592 .727 .938 r
F P
0 g
s
.78494 .6011 m .77228 .65768 L .75914 .65022 L p .97 .812 .631 r
F P
0 g
s
.75914 .65022 m .77316 .59193 L .78494 .6011 L p .97 .812 .631 r
F P
0 g
s
.7023 .39689 m .70553 .4435 L .6806 .43482 L p .85 .541 .464 r
F P
0 g
s
.6806 .43482 m .67807 .38722 L .7023 .39689 L p .85 .541 .464 r
F P
0 g
s
.5953 .76585 m .62004 .73165 L .63652 .73487 L p .631 .795 .961 r
F P
0 g
s
.62004 .73165 m .5953 .76585 L .58264 .76377 L p .623 .784 .959 r
F P
0 g
s
.70505 .75575 m .74454 .71195 L .75635 .71838 L p .801 .852 .888 r
F P
0 g
s
.74454 .71195 m .70505 .75575 L .69335 .75092 L p .793 .844 .89 r
F P
0 g
s
.32086 .70509 m .35631 .75038 L .36989 .74419 L p .628 .627 .83 r
F P
0 g
s
.35631 .75038 m .32086 .70509 L .30444 .71368 L p .628 .632 .835 r
F P
0 g
s
.78381 .66546 m .75635 .71838 L .74454 .71195 L p .908 .851 .775 r
F P
0 g
s
.74454 .71195 m .77228 .65768 L .78381 .66546 L p .908 .851 .775 r
F P
0 g
s
.53343 .4311 m .53323 .38955 L .56152 .38264 L p .509 .242 .445 r
F P
0 g
s
.53323 .38955 m .53343 .4311 L .50649 .43739 L p .429 .165 .409 r
F P
0 g
s
.35634 .62746 m .35248 .57215 L .3324 .57913 L p .545 .36 .581 r
F P
0 g
s
.3324 .57913 m .33692 .63419 L .35634 .62746 L p .545 .36 .581 r
F P
0 g
s
.4953 .72051 m .50321 .75824 L .49021 .75872 L p .59 .728 .94 r
F P
0 g
s
.49021 .75872 m .47802 .72103 L .4953 .72051 L p .59 .728 .94 r
F P
0 g
s
.58264 .76377 m .60289 .72876 L .62004 .73165 L p .623 .784 .959 r
F P
0 g
s
.60289 .72876 m .58264 .76377 L .56965 .76198 L p .616 .773 .956 r
F P
0 g
s
.41254 .5549 m .41541 .50676 L .43544 .50041 L p .411 .175 .443 r
F P
0 g
s
.41541 .50676 m .41254 .5549 L .39216 .5601 L p .407 .159 .423 r
F P
0 g
s
.51297 .72061 m .5164 .7582 L .50321 .75824 L p .589 .732 .942 r
F P
0 g
s
.50321 .75824 m .4953 .72051 L .51297 .72061 L p .589 .732 .942 r
F P
0 g
s
.32086 .70509 m .29802 .65051 L .27861 .66015 L p .595 .511 .729 r
F P
0 g
s
.27861 .66015 m .30444 .71368 L .32086 .70509 L p .595 .511 .729 r
F P
0 g
s
.56965 .76198 m .58522 .72624 L .60289 .72876 L p .616 .773 .956 r
F P
0 g
s
.58522 .72624 m .56965 .76198 L .55644 .76051 L p .608 .763 .953 r
F P
0 g
s
.53093 .72127 m .52972 .75859 L .5164 .7582 L p .592 .737 .945 r
F P
0 g
s
.5164 .7582 m .51297 .72061 L .53093 .72127 L p .592 .737 .945 r
F P
0 g
s
.55644 .76051 m .56722 .72413 L .58522 .72624 L p .608 .763 .953 r
F P
0 g
s
.56722 .72413 m .55644 .76051 L .5431 .75937 L p .601 .753 .95 r
F P
0 g
s
.54906 .72246 m .5431 .75937 L .52972 .75859 L p .596 .744 .948 r
F P
0 g
s
.52972 .75859 m .53093 .72127 L .54906 .72246 L p .596 .744 .948 r
F P
0 g
s
.33769 .69736 m .36989 .74419 L .38397 .73869 L p .626 .623 .827 r
F P
0 g
s
.36989 .74419 m .33769 .69736 L .32086 .70509 L p .628 .627 .83 r
F P
0 g
s
.5431 .75937 m .54906 .72246 L .56722 .72413 L p .601 .753 .95 r
F P
0 g
s
.48047 .48874 m .48195 .44499 L .50649 .43739 L p .421 .167 .422 r
F P
0 g
s
.48195 .44499 m .48047 .48874 L .457 .49431 L p .355 .095 .374 r
F P
0 g
s
.35634 .62746 m .35248 .57215 L .37228 .56584 L p .534 .35 .578 r
F P
0 g
s
.69335 .75092 m .73143 .70591 L .74454 .71195 L p .793 .844 .89 r
F P
0 g
s
.73143 .70591 m .69335 .75092 L .68064 .74643 L p .782 .833 .891 r
F P
0 g
s
.76234 .52728 m .75904 .58297 L .74225 .57434 L p .962 .727 .536 r
F P
0 g
s
.74225 .57434 m .74697 .51649 L .76234 .52728 L p .962 .727 .536 r
F P
0 g
s
.33769 .69736 m .31749 .64186 L .29802 .65051 L p .595 .504 .721 r
F P
0 g
s
.29802 .65051 m .32086 .70509 L .33769 .69736 L p .595 .504 .721 r
F P
0 g
s
.67807 .38722 m .6806 .43482 L .65279 .42863 L p .786 .488 .484 r
F P
0 g
s
.65279 .42863 m .65076 .38078 L .67807 .38722 L p .786 .488 .484 r
F P
0 g
s
.56237 .42668 m .56152 .38264 L .59127 .37859 L p .584 .311 .47 r
F P
0 g
s
.56152 .38264 m .56237 .42668 L .53343 .4311 L p .509 .242 .445 r
F P
0 g
s
.35487 .69052 m .38397 .73869 L .3985 .73392 L p .624 .619 .825 r
F P
0 g
s
.38397 .73869 m .35487 .69052 L .33769 .69736 L p .626 .623 .827 r
F P
0 g
s
.43383 .55027 m .43544 .50041 L .457 .49431 L p .432 .207 .47 r
F P
0 g
s
.43544 .50041 m .43383 .55027 L .41254 .5549 L p .411 .175 .443 r
F P
0 g
s
.72691 .45423 m .72815 .50638 L .7059 .49735 L p .899 .616 .498 r
F P
0 g
s
.7059 .49735 m .70553 .4435 L .72691 .45423 L p .899 .616 .498 r
F P
0 g
s
.77228 .65768 m .74454 .71195 L .73143 .70591 L p .894 .839 .784 r
F P
0 g
s
.73143 .70591 m .75914 .65022 L .77228 .65768 L p .894 .839 .784 r
F P
0 g
s
.37589 .62164 m .37228 .56584 L .39216 .5601 L p .52 .341 .579 r
F P
0 g
s
.37228 .56584 m .37589 .62164 L .35634 .62746 L p .534 .35 .578 r
F P
0 g
s
.35487 .69052 m .33692 .63419 L .31749 .64186 L p .594 .498 .715 r
F P
0 g
s
.31749 .64186 m .33769 .69736 L .35487 .69052 L p .594 .498 .715 r
F P
0 g
s
.77316 .59193 m .75914 .65022 L .74408 .64308 L p .946 .794 .66 r
F P
0 g
s
.74408 .64308 m .75904 .58297 L .77316 .59193 L p .946 .794 .66 r
F P
0 g
s
.59257 .4246 m .59127 .37859 L .62142 .37789 L p .653 .375 .485 r
F P
0 g
s
.59127 .37859 m .59257 .4246 L .56237 .42668 L p .584 .311 .47 r
F P
0 g
s
.65076 .38078 m .65279 .42863 L .62308 .4252 L p .72 .433 .49 r
F P
0 g
s
.62308 .4252 m .62142 .37789 L .65076 .38078 L p .72 .433 .49 r
F P
0 g
s
.3985 .73392 m .37237 .68459 L .35487 .69052 L p .624 .619 .825 r
F P
0 g
s
.39025 .67957 m .41348 .72989 L .3985 .73392 L p .619 .616 .826 r
F P
0 g
s
.3985 .73392 m .37237 .68459 L .39025 .67957 L p .619 .616 .826 r
F P
0 g
s
.68064 .74643 m .71686 .70023 L .73143 .70591 L p .782 .833 .891 r
F P
0 g
s
.71686 .70023 m .68064 .74643 L .6669 .74227 L p .77 .818 .891 r
F P
0 g
s
.62142 .37789 m .62308 .4252 L .59257 .4246 L p .653 .375 .485 r
F P
0 g
s
.50601 .48401 m .50649 .43739 L .53343 .4311 L p .488 .238 .462 r
F P
0 g
s
.50649 .43739 m .50601 .48401 L .48047 .48874 L p .421 .167 .422 r
F P
0 g
s
.40857 .67544 m .42891 .7266 L .41348 .72989 L p .612 .613 .828 r
F P
0 g
s
.41348 .72989 m .39025 .67957 L .40857 .67544 L p .612 .613 .828 r
F P
0 g
s
.37237 .68459 m .35634 .62746 L .33692 .63419 L p .593 .494 .711 r
F P
0 g
s
.33692 .63419 m .35487 .69052 L .37237 .68459 L p .593 .494 .711 r
F P
0 g
s
.39576 .61668 m .39216 .5601 L .41254 .5549 L p .512 .341 .585 r
F P
0 g
s
.39216 .5601 m .39576 .61668 L .37589 .62164 L p .52 .341 .579 r
F P
0 g
s
.6669 .74227 m .70077 .6949 L .71686 .70023 L p .77 .818 .891 r
F P
0 g
s
.70077 .6949 m .6669 .74227 L .65217 .73841 L p .756 .801 .889 r
F P
0 g
s
.42745 .67218 m .4448 .72404 L .42891 .7266 L p .607 .612 .831 r
F P
0 g
s
.42891 .7266 m .40857 .67544 L .42745 .67218 L p .607 .612 .831 r
F P
0 g
s
.45641 .54626 m .457 .49431 L .48047 .48874 L p .466 .25 .5 r
F P
0 g
s
.457 .49431 m .45641 .54626 L .43383 .55027 L p .432 .207 .47 r
F P
0 g
s
.74697 .51649 m .74225 .57434 L .72261 .56622 L p .923 .696 .576 r
F P
0 g
s
.72261 .56622 m .72815 .50638 L .74697 .51649 L p .923 .696 .576 r
F P
0 g
s
.75914 .65022 m .73143 .70591 L .71686 .70023 L p .875 .821 .791 r
F P
0 g
s
.37237 .68459 m .35634 .62746 L .37589 .62164 L p .587 .49 .711 r
F P
0 g
s
.70553 .4435 m .7059 .49735 L .68055 .48977 L p .844 .572 .526 r
F P
0 g
s
.68055 .48977 m .6806 .43482 L .70553 .4435 L p .844 .572 .526 r
F P
0 g
s
.71686 .70023 m .74408 .64308 L .75914 .65022 L p .875 .821 .791 r
F P
0 g
s
.65217 .73841 m .68315 .68991 L .70077 .6949 L p .756 .801 .889 r
F P
0 g
s
.68315 .68991 m .65217 .73841 L .63652 .73487 L p .741 .782 .886 r
F P
0 g
s
.44697 .66976 m .46118 .7222 L .4448 .72404 L p .604 .614 .834 r
F P
0 g
s
.4448 .72404 m .42745 .67218 L .44697 .66976 L p .604 .614 .834 r
F P
0 g
s
.53354 .48047 m .53343 .4311 L .56237 .42668 L p .552 .304 .493 r
F P
0 g
s
.53343 .4311 m .53354 .48047 L .50601 .48401 L p .488 .238 .462 r
F P
0 g
s
.37589 .62164 m .39025 .67957 L .37237 .68459 L p .587 .49 .711 r
F P
0 g
s
.75904 .58297 m .74408 .64308 L .72693 .63628 L p .917 .768 .681 r
F P
0 g
s
.72693 .63628 m .74225 .57434 L .75904 .58297 L p .917 .768 .681 r
F P
0 g
s
.4162 .61255 m .41254 .5549 L .43383 .55027 L p .515 .35 .595 r
F P
0 g
s
.41254 .5549 m .4162 .61255 L .39576 .61668 L p .512 .341 .585 r
F P
0 g
s
.4672 .66817 m .47802 .72103 L .46118 .7222 L p .606 .618 .838 r
F P
0 g
s
.46118 .7222 m .44697 .66976 L .4672 .66817 L p .606 .618 .838 r
F P
0 g
s
.39025 .67957 m .37589 .62164 L .39576 .61668 L p .579 .486 .712 r
F P
0 g
s
.63652 .73487 m .66409 .6853 L .68315 .68991 L p .741 .782 .886 r
F P
0 g
s
.66409 .6853 m .63652 .73487 L .62004 .73165 L p .725 .762 .882 r
F P
0 g
s
.74408 .64308 m .71686 .70023 L .70077 .6949 L p .854 .798 .796 r
F P
0 g
s
.39576 .61668 m .40857 .67544 L .39025 .67957 L p .579 .486 .712 r
F P
0 g
s
.48051 .543 m .48047 .48874 L .50601 .48401 L p .508 .298 .529 r
F P
0 g
s
.48047 .48874 m .48051 .543 L .45641 .54626 L p .466 .25 .5 r
F P
0 g
s
.6806 .43482 m .68055 .48977 L .65269 .48394 L p .788 .524 .538 r
F P
0 g
s
.65269 .48394 m .65279 .42863 L .6806 .43482 L p .788 .524 .538 r
F P
0 g
s
.48816 .66736 m .4953 .72051 L .47802 .72103 L p .61 .626 .842 r
F P
0 g
s
.47802 .72103 m .4672 .66817 L .48816 .66736 L p .61 .626 .842 r
F P
0 g
s
.56269 .47847 m .56237 .42668 L .59257 .4246 L p .614 .365 .516 r
F P
0 g
s
.56237 .42668 m .56269 .47847 L .53354 .48047 L p .552 .304 .493 r
F P
0 g
s
.62004 .73165 m .64373 .68109 L .66409 .6853 L p .725 .762 .882 r
F P
0 g
s
.64373 .68109 m .62004 .73165 L .60289 .72876 L p .708 .742 .878 r
F P
0 g
s
.72815 .50638 m .72261 .56622 L .70018 .55884 L p .879 .659 .6 r
F P
0 g
s
.70018 .55884 m .7059 .49735 L .72815 .50638 L p .879 .659 .6 r
F P
0 g
s
.50982 .66732 m .51297 .72061 L .4953 .72051 L p .619 .637 .846 r
F P
0 g
s
.4953 .72051 m .48816 .66736 L .50982 .66732 L p .619 .637 .846 r
F P
0 g
s
.40857 .67544 m .39576 .61668 L .4162 .61255 L p .575 .486 .716 r
F P
0 g
s
.70077 .6949 m .72693 .63628 L .74408 .64308 L p .854 .798 .796 r
F P
0 g
s
.43744 .60924 m .43383 .55027 L .45641 .54626 L p .527 .368 .609 r
F P
0 g
s
.43383 .55027 m .43744 .60924 L .4162 .61255 L p .515 .35 .595 r
F P
0 g
s
.4162 .61255 m .42745 .67218 L .40857 .67544 L p .575 .486 .716 r
F P
0 g
s
.60289 .72876 m .62232 .67735 L .64373 .68109 L p .708 .742 .878 r
F P
0 g
s
.62232 .67735 m .60289 .72876 L .58522 .72624 L p .691 .722 .873 r
F P
0 g
s
.65279 .42863 m .65269 .48394 L .62315 .48008 L p .731 .474 .539 r
F P
0 g
s
.62315 .48008 m .62308 .4252 L .65279 .42863 L p .731 .474 .539 r
F P
0 g
s
.53206 .66801 m .53093 .72127 L .51297 .72061 L p .63 .65 .851 r
F P
0 g
s
.51297 .72061 m .50982 .66732 L .53206 .66801 L p .63 .65 .851 r
F P
0 g
s
.59284 .47828 m .59257 .4246 L .62308 .4252 L p .673 .421 .532 r
F P
0 g
s
.59257 .4246 m .59284 .47828 L .56269 .47847 L p .614 .365 .516 r
F P
0 g
s
.58522 .72624 m .60013 .67412 L .62232 .67735 L p .691 .722 .873 r
F P
0 g
s
.60013 .67412 m .58522 .72624 L .56722 .72413 L p .675 .702 .867 r
F P
0 g
s
.55469 .6694 m .54906 .72246 L .53093 .72127 L p .643 .666 .857 r
F P
0 g
s
.53093 .72127 m .53206 .66801 L .55469 .6694 L p .643 .666 .857 r
F P
0 g
s
.62308 .4252 m .62315 .48008 L .59284 .47828 L p .673 .421 .532 r
F P
0 g
s
.74225 .57434 m .72693 .63628 L .70761 .62989 L p .884 .737 .694 r
F P
0 g
s
.70761 .62989 m .72261 .56622 L .74225 .57434 L p .884 .737 .694 r
F P
0 g
s
.56722 .72413 m .57748 .67145 L .60013 .67412 L p .675 .702 .867 r
F P
0 g
s
.57748 .67145 m .56722 .72413 L .54906 .72246 L p .658 .683 .862 r
F P
0 g
s
.72693 .63628 m .70077 .6949 L .68315 .68991 L p .83 .772 .797 r
F P
0 g
s
.54906 .72246 m .55469 .6694 L .57748 .67145 L p .658 .683 .862 r
F P
0 g
s
.50622 .54064 m .50601 .48401 L .53354 .48047 L p .554 .347 .555 r
F P
0 g
s
.50601 .48401 m .50622 .54064 L .48051 .543 L p .508 .298 .529 r
F P
0 g
s
.43744 .60924 m .44697 .66976 L .42745 .67218 L p .576 .491 .722 r
F P
0 g
s
.42745 .67218 m .4162 .61255 L .43744 .60924 L p .576 .491 .722 r
F P
0 g
s
.45967 .60675 m .45641 .54626 L .48051 .543 L p .547 .393 .624 r
F P
0 g
s
.45641 .54626 m .45967 .60675 L .43744 .60924 L p .527 .368 .609 r
F P
0 g
s
.7059 .49735 m .70018 .55884 L .67525 .55241 L p .833 .618 .612 r
F P
0 g
s
.67525 .55241 m .68055 .48977 L .7059 .49735 L p .833 .618 .612 r
F P
0 g
s
.68315 .68991 m .70761 .62989 L .72693 .63628 L p .83 .772 .797 r
F P
0 g
s
.45967 .60675 m .4672 .66817 L .44697 .66976 L p .582 .501 .728 r
F P
0 g
s
.44697 .66976 m .43744 .60924 L .45967 .60675 L p .582 .501 .728 r
F P
0 g
s
.70761 .62989 m .68315 .68991 L .66409 .6853 L p .805 .745 .797 r
F P
0 g
s
.53341 .53934 m .53354 .48047 L .56269 .47847 L p .601 .396 .576 r
F P
0 g
s
.53354 .48047 m .53341 .53934 L .50622 .54064 L p .554 .347 .555 r
F P
0 g
s
.72261 .56622 m .70761 .62989 L .6862 .624 L p .848 .703 .702 r
F P
0 g
s
.6862 .624 m .70018 .55884 L .72261 .56622 L p .848 .703 .702 r
F P
0 g
s
.48301 .60509 m .48816 .66736 L .4672 .66817 L p .593 .516 .736 r
F P
0 g
s
.4672 .66817 m .45967 .60675 L .48301 .60509 L p .593 .516 .736 r
F P
0 g
s
.48301 .60509 m .48051 .543 L .50622 .54064 L p .573 .423 .64 r
F P
0 g
s
.48051 .543 m .48301 .60509 L .45967 .60675 L p .547 .393 .624 r
F P
0 g
s
.68055 .48977 m .67525 .55241 L .64827 .54712 L p .786 .576 .616 r
F P
0 g
s
.64827 .54712 m .65269 .48394 L .68055 .48977 L p .786 .576 .616 r
F P
0 g
s
.66409 .6853 m .6862 .624 L .70761 .62989 L p .805 .745 .797 r
F P
0 g
s
.6862 .624 m .66409 .6853 L .64373 .68109 L p .779 .717 .794 r
F P
0 g
s
.56178 .53926 m .56269 .47847 L .59284 .47828 L p .647 .443 .593 r
F P
0 g
s
.56269 .47847 m .56178 .53926 L .53341 .53934 L p .601 .396 .576 r
F P
0 g
s
.50747 .60431 m .50982 .66732 L .48816 .66736 L p .609 .534 .745 r
F P
0 g
s
.48816 .66736 m .48301 .60509 L .50747 .60431 L p .609 .534 .745 r
F P
0 g
s
.65269 .48394 m .64827 .54712 L .61989 .54312 L p .74 .533 .613 r
F P
0 g
s
.61989 .54312 m .62315 .48008 L .65269 .48394 L p .74 .533 .613 r
F P
0 g
s
.64373 .68109 m .66291 .61871 L .6862 .624 L p .779 .717 .794 r
F P
0 g
s
.66291 .61871 m .64373 .68109 L .62232 .67735 L p .753 .688 .79 r
F P
0 g
s
.59082 .54049 m .59284 .47828 L .62315 .48008 L p .694 .489 .606 r
F P
0 g
s
.59284 .47828 m .59082 .54049 L .56178 .53926 L p .647 .443 .593 r
F P
0 g
s
.53292 .60443 m .53206 .66801 L .50982 .66732 L p .629 .556 .753 r
F P
0 g
s
.50982 .66732 m .50747 .60431 L .53292 .60443 L p .629 .556 .753 r
F P
0 g
s
.70018 .55884 m .6862 .624 L .66291 .61871 L p .812 .668 .704 r
F P
0 g
s
.66291 .61871 m .67525 .55241 L .70018 .55884 L p .812 .668 .704 r
F P
0 g
s
.50747 .60431 m .50622 .54064 L .53341 .53934 L p .603 .456 .655 r
F P
0 g
s
.50622 .54064 m .50747 .60431 L .48301 .60509 L p .573 .423 .64 r
F P
0 g
s
.62315 .48008 m .61989 .54312 L .59082 .54049 L p .694 .489 .606 r
F P
0 g
s
.62232 .67735 m .63809 .61413 L .66291 .61871 L p .753 .688 .79 r
F P
0 g
s
.63809 .61413 m .62232 .67735 L .60013 .67412 L p .727 .66 .784 r
F P
0 g
s
.55912 .60548 m .55469 .6694 L .53206 .66801 L p .651 .58 .762 r
F P
0 g
s
.53206 .66801 m .53292 .60443 L .55912 .60548 L p .651 .58 .762 r
F P
0 g
s
.60013 .67412 m .61218 .61036 L .63809 .61413 L p .727 .66 .784 r
F P
0 g
s
.61218 .61036 m .60013 .67412 L .57748 .67145 L p .701 .633 .777 r
F P
0 g
s
.58569 .60746 m .57748 .67145 L .55469 .6694 L p .675 .606 .77 r
F P
0 g
s
.55469 .6694 m .55912 .60548 L .58569 .60746 L p .675 .606 .77 r
F P
0 g
s
.57748 .67145 m .58569 .60746 L .61218 .61036 L p .701 .633 .777 r
F P
0 g
s
.53292 .60443 m .53341 .53934 L .56178 .53926 L p .636 .491 .669 r
F P
0 g
s
.53341 .53934 m .53292 .60443 L .50747 .60431 L p .603 .456 .655 r
F P
0 g
s
.67525 .55241 m .66291 .61871 L .63809 .61413 L p .776 .632 .702 r
F P
0 g
s
.63809 .61413 m .64827 .54712 L .67525 .55241 L p .776 .632 .702 r
F P
0 g
s
.55912 .60548 m .56178 .53926 L .59082 .54049 L p .67 .526 .68 r
F P
0 g
s
.56178 .53926 m .55912 .60548 L .53292 .60443 L p .636 .491 .669 r
F P
0 g
s
.64827 .54712 m .63809 .61413 L .61218 .61036 L p .74 .597 .697 r
F P
0 g
s
.61218 .61036 m .61989 .54312 L .64827 .54712 L p .74 .597 .697 r
F P
0 g
s
.58569 .60746 m .59082 .54049 L .61989 .54312 L p .705 .561 .69 r
F P
0 g
s
.59082 .54049 m .58569 .60746 L .55912 .60548 L p .67 .526 .68 r
F P
0 g
s
.61989 .54312 m .61218 .61036 L .58569 .60746 L p .705 .561 .69 r
F P
0 g
s
.25 Mabswid
.67257 0 m
.92728 .41494 L
s
.92728 .41494 m
1 .947 L
s
1 .947 m
.7065 .58421 L
s
.7065 .58421 m
.67257 0 L
s
.08825 .24561 m
0 .80261 L
s
0 .80261 m
.7065 .58421 L
s
.7065 .58421 m
.67257 0 L
s
.67257 0 m
.08825 .24561 L
s
.08825 .24561 m
.67257 0 L
s
.17892 .2075 m
.18385 .21286 L
s
[(-0.005)] .16907 .19677 .91822 1 Mshowa
.36353 .1299 m
.36807 .13559 L
s
[(0)] .35445 .11851 .79742 1 Mshowa
.56273 .04617 m
.56681 .0522 L
s
[(0.005)] .55457 .03411 .67661 1 Mshowa
.125 Mabswid
.21475 .19244 m
.21767 .19569 L
s
.25112 .17715 m
.25398 .18045 L
s
.28803 .16164 m
.29085 .16497 L
s
.32549 .14589 m
.32827 .14927 L
s
.40215 .11367 m
.40482 .11712 L
s
.44136 .09718 m
.44398 .10068 L
s
.48119 .08044 m
.48375 .08398 L
s
.52164 .06344 m
.52415 .06702 L
s
.14361 .22234 m
.14661 .22552 L
s
.10881 .23697 m
.11185 .24011 L
s
.60448 .02862 m
.60686 .03228 L
s
.64689 .01079 m
.64922 .01449 L
s
.25 Mabswid
0 .80261 m
.40027 1.08447 L
s
.08157 .86005 m
.08252 .85283 L
s
[(-0.005)] .07967 .87449 .13161 -1 Mshowa
.22176 .95877 m
.22239 .95151 L
s
[(0)] .22049 .97328 .08756 -1 Mshowa
.34333 1.04438 m
.3437 1.0371 L
s
[(0.005)] .34258 1.05892 .05134 -1 Mshowa
.125 Mabswid
.1113 .88099 m
.11183 .87665 L
s
.14015 .9013 m
.14064 .89696 L
s
.16815 .92102 m
.1686 .91667 L
s
.19534 .94017 m
.19576 .93582 L
s
.24744 .97685 m
.24778 .9725 L
s
.27241 .99443 m
.27272 .99007 L
s
.29669 1.01153 m
.29698 1.00717 L
s
.32032 1.02818 m
.32058 1.02381 L
s
.05092 .83847 m
.05153 .83414 L
s
.01929 .8162 m
.01995 .81188 L
s
.36573 1.06015 m
.36593 1.05579 L
s
.38755 1.07552 m
.38772 1.07115 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{265.25, 287.625},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 264.25}, {286.625, 0}} -> {-0.0582161, -0.0541919, \
0.00365101, 0.00365101}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics3D", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"],

Cell[BoxData["\<\"aluminum.pdf\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"epsnn", " ", "normal"}], ")"}], "/.", " ", "TiN"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot3D", "[", " ", 
  RowBox[{
   RowBox[{"Evaluate", "[", "%", "]"}], "  ", ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "0", ",", "  ", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"p", ",", " ", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], " ", ",", " ", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", " ", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "50"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<TiN.pdf\>\"", ",", "%"}], "]"}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567259 1.16609 1.11022e-016 1.16609 [
[.11032 .22158 -35.2488 -9 ]
[.11032 .22158 .75124 0 ]
[.22936 .1713 -33.7991 -9 ]
[.22936 .1713 2.20086 0 ]
[.35449 .11847 -5.39159 -9 ]
[.35449 .11847 .60841 0 ]
[.48616 .0629 -25.7499 -9 ]
[.48616 .0629 4.25009 0 ]
[.62491 .0044 -24.5419 -9 ]
[.62491 .0044 5.45811 0 ]
[.02779 .8392 -20.6731 0 ]
[.02779 .8392 15.3269 9 ]
[.12899 .91015 -20.0864 0 ]
[.12899 .91015 15.9136 9 ]
[.22057 .97436 -3.26266 0 ]
[.22057 .97436 2.73734 9 ]
[.30384 1.03274 -15.9399 0 ]
[.30384 1.03274 14.0601 9 ]
[.37989 1.08605 -15.6095 0 ]
[.37989 1.08605 14.3905 9 ]
[.07046 .2797 -36 -2.63315 ]
[.07046 .2797 0 6.36685 ]
[.05323 .38753 -36 -2.72899 ]
[.05323 .38753 0 6.27101 ]
[.03462 .50403 -6 -2.83334 ]
[.03462 .50403 0 6.16666 ]
[.01445 .6303 -30 -2.94736 ]
[.01445 .6303 0 6.05264 ]
[-0.00747 .76761 -30 -3.07249 ]
[-0.00747 .76761 0 5.92751 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08845 .24554 m
.67243 0 L
s
.1204 .23211 m
.12544 .23737 L
s
[(-0.002)] .11032 .22158 .95826 1 Mshowa
.23898 .18225 m
.24379 .18773 L
s
[(-0.001)] .22936 .1713 .87773 1 Mshowa
.36357 .12986 m
.36812 .13556 L
s
[(0)] .35449 .11847 .7972 1 Mshowa
.49465 .07475 m
.49889 .08068 L
s
[(0.001)] .48616 .0629 .71666 1 Mshowa
.63273 .01669 m
.63664 .02284 L
s
[(0.002)] .62491 .0044 .63613 1 Mshowa
.125 Mabswid
.14366 .22233 m
.14666 .22551 L
s
.16714 .21246 m
.17011 .21567 L
s
.19085 .20249 m
.19379 .20572 L
s
.2148 .19242 m
.21771 .19568 L
s
.2634 .17198 m
.26626 .17529 L
s
.28807 .16161 m
.29089 .16495 L
s
.31298 .15113 m
.31578 .1545 L
s
.33815 .14055 m
.34091 .14395 L
s
.38925 .11907 m
.39195 .12251 L
s
.4152 .10816 m
.41785 .11163 L
s
.44141 .09714 m
.44403 .10064 L
s
.46789 .086 m
.47048 .08953 L
s
.52169 .06338 m
.5242 .06696 L
s
.54901 .0519 m
.55148 .0555 L
s
.57662 .04029 m
.57905 .04392 L
s
.60453 .02855 m
.60692 .03222 L
s
.09737 .24179 m
.10042 .24492 L
s
.66124 .00471 m
.66354 .00843 L
s
.25 Mabswid
0 .80371 m
.4004 1.0855 L
s
.02993 .82478 m
.03101 .81757 L
s
[(-0.002)] .02779 .8392 .14851 -1 Mshowa
.13067 .89567 m
.13151 .88843 L
s
[(-0.001)] .12899 .91015 .11591 -1 Mshowa
.22184 .95984 m
.22248 .95258 L
s
[(0)] .22057 .97436 .08755 -1 Mshowa
.30476 1.01819 m
.30521 1.01092 L
s
[(0.001)] .30384 1.03274 .06266 -1 Mshowa
.38048 1.07149 m
.38078 1.0642 L
s
[(0.002)] .37989 1.08605 .04063 -1 Mshowa
.125 Mabswid
.05092 .83955 m
.05153 .83522 L
s
.07147 .85401 m
.07205 .84968 L
s
.0916 .86818 m
.09216 .86384 L
s
.11133 .88207 m
.11186 .87773 L
s
.14962 .90901 m
.1501 .90467 L
s
.16821 .92209 m
.16866 .91774 L
s
.18643 .93492 m
.18686 .93057 L
s
.20431 .9475 m
.20471 .94314 L
s
.23905 .97195 m
.23941 .96759 L
s
.25593 .98383 m
.25627 .97947 L
s
.27251 .9955 m
.27282 .99114 L
s
.28878 1.00695 m
.28907 1.00259 L
s
.32044 1.02923 m
.3207 1.02487 L
s
.33585 1.04008 m
.33609 1.03571 L
s
.35099 1.05073 m
.35121 1.04636 L
s
.36587 1.0612 m
.36606 1.05683 L
s
.00851 .8097 m
.00918 .80538 L
s
.39485 1.08159 m
.39501 1.07722 L
s
.25 Mabswid
.08845 .24554 m
0 .80371 L
s
.08392 .27412 m
.09065 .27133 L
s
[(-0.002)] .07046 .2797 1 -0.41486 Mshowa
.06679 .38219 m
.07358 .37952 L
s
[(-0.001)] .05323 .38753 1 -0.39356 Mshowa
.04829 .49897 m
.05512 .49644 L
s
[(0)] .03462 .50403 1 -0.37037 Mshowa
.02823 .62554 m
.03512 .62317 L
s
[(0.001)] .01445 .6303 1 -0.34503 Mshowa
.00642 .7632 m
.01337 .761 L
s
[(0.002)] -0.00747 .76761 1 -0.31722 Mshowa
.125 Mabswid
.0806 .29508 m
.08464 .29342 L
s
.07723 .31637 m
.08128 .31472 L
s
.0738 .33797 m
.07786 .33634 L
s
.07033 .35991 m
.07439 .3583 L
s
.06321 .40482 m
.06728 .40323 L
s
.05957 .4278 m
.06365 .42623 L
s
.05587 .45115 m
.05996 .44959 L
s
.05211 .47487 m
.0562 .47333 L
s
.04441 .52346 m
.04852 .52196 L
s
.04046 .54835 m
.04458 .54687 L
s
.03645 .57366 m
.04057 .57219 L
s
.03238 .59938 m
.03651 .59794 L
s
.02402 .65214 m
.02816 .65074 L
s
.01973 .6792 m
.02388 .67781 L
s
.01537 .70672 m
.01952 .70535 L
s
.01093 .73472 m
.01509 .73337 L
s
.08719 .25346 m
.09123 .25177 L
s
.00182 .7922 m
.006 .7909 L
s
.25 Mabswid
.08845 .24554 m
0 .80371 L
s
0 .80371 m
.4004 1.0855 L
s
.4004 1.0855 m
.41801 .58161 L
s
.41801 .58161 m
.08845 .24554 L
s
.67243 0 m
.92713 .415 L
s
.92713 .415 m
1 .94815 L
s
1 .94815 m
.70641 .58544 L
s
.70641 .58544 m
.67243 0 L
s
.08845 .24554 m
0 .80371 L
s
0 .80371 m
.70641 .58544 L
s
.70641 .58544 m
.67243 0 L
s
.67243 0 m
.08845 .24554 L
s
.41801 .58161 m
.92713 .415 L
s
.92713 .415 m
1 .94815 L
s
1 .94815 m
.4004 1.0855 L
s
.4004 1.0855 m
.41801 .58161 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48661 .62816 m .48949 .58866 L .50583 .58973 L p .71 .56 .682 r
F P
0 g
s
.50583 .58973 m .50425 .62912 L .48661 .62816 L p .71 .56 .682 r
F P
0 g
s
.50784 .55007 m .50583 .58973 L .48949 .58866 L p .712 .589 .716 r
F P
0 g
s
.50425 .62912 m .50583 .58973 L .52214 .59017 L p .696 .547 .68 r
F P
0 g
s
.50583 .58973 m .50784 .55007 L .52254 .55058 L p .7 .577 .714 r
F P
0 g
s
.52254 .55058 m .52214 .59017 L .50583 .58973 L p .7 .577 .714 r
F P
0 g
s
.46903 .62649 m .47322 .58697 L .48949 .58866 L p .725 .574 .684 r
F P
0 g
s
.48949 .58866 m .48661 .62816 L .46903 .62649 L p .725 .574 .684 r
F P
0 g
s
.49313 .54901 m .48949 .58866 L .47322 .58697 L p .724 .601 .718 r
F P
0 g
s
.48949 .58866 m .49313 .54901 L .50784 .55007 L p .712 .589 .716 r
F P
0 g
s
.52214 .59017 m .52182 .62938 L .50425 .62912 L p .696 .547 .68 r
F P
0 g
s
.52182 .62938 m .52214 .59017 L .53834 .58999 L p .682 .534 .677 r
F P
0 g
s
.52214 .59017 m .52254 .55058 L .53719 .55053 L p .688 .567 .713 r
F P
0 g
s
.53719 .55053 m .53834 .58999 L .52214 .59017 L p .688 .567 .713 r
F P
0 g
s
.51024 .5114 m .50784 .55007 L .49313 .54901 L p .71 .618 .752 r
F P
0 g
s
.50784 .55007 m .51024 .5114 L .52303 .51189 L p .701 .608 .75 r
F P
0 g
s
.52303 .51189 m .52254 .55058 L .50784 .55007 L p .701 .608 .75 r
F P
0 g
s
.45163 .6241 m .45713 .58466 L .47322 .58697 L p .74 .588 .686 r
F P
0 g
s
.47322 .58697 m .46903 .62649 L .45163 .6241 L p .74 .588 .686 r
F P
0 g
s
.47851 .5474 m .47322 .58697 L .45713 .58466 L p .736 .613 .72 r
F P
0 g
s
.47322 .58697 m .47851 .5474 L .49313 .54901 L p .724 .601 .718 r
F P
0 g
s
.52254 .55058 m .52303 .51189 L .5358 .51188 L p .692 .6 .749 r
F P
0 g
s
.5358 .51188 m .53719 .55053 L .52254 .55058 L p .692 .6 .749 r
F P
0 g
s
.53834 .58999 m .53923 .62896 L .52182 .62938 L p .682 .534 .677 r
F P
0 g
s
.53923 .62896 m .53834 .58999 L .55436 .5892 L p .67 .522 .675 r
F P
0 g
s
.53834 .58999 m .53719 .55053 L .55172 .54992 L p .677 .557 .711 r
F P
0 g
s
.55172 .54992 m .55436 .5892 L .53834 .58999 L p .677 .557 .711 r
F P
0 g
s
.49746 .51044 m .49313 .54901 L .47851 .5474 L p .72 .627 .753 r
F P
0 g
s
.49313 .54901 m .49746 .51044 L .51024 .5114 L p .71 .618 .752 r
F P
0 g
s
.53719 .55053 m .5358 .51188 L .54849 .51138 L p .683 .592 .747 r
F P
0 g
s
.54849 .51138 m .55172 .54992 L .53719 .55053 L p .683 .592 .747 r
F P
0 g
s
.45713 .58466 m .46404 .54525 L .47851 .5474 L p .736 .613 .72 r
F P
0 g
s
.48477 .50899 m .47851 .5474 L .46404 .54525 L p .73 .637 .755 r
F P
0 g
s
.47851 .5474 m .48477 .50899 L .49746 .51044 L p .72 .627 .753 r
F P
0 g
s
.55436 .5892 m .55638 .62789 L .53923 .62896 L p .67 .522 .675 r
F P
0 g
s
.55638 .62789 m .55436 .5892 L .57016 .58782 L p .658 .511 .673 r
F P
0 g
s
.55436 .5892 m .55172 .54992 L .56608 .54876 L p .667 .548 .709 r
F P
0 g
s
.56608 .54876 m .57016 .58782 L .55436 .5892 L p .667 .548 .709 r
F P
0 g
s
.43455 .621 m .44131 .58174 L .45713 .58466 L p .755 .603 .688 r
F P
0 g
s
.45713 .58466 m .45163 .6241 L .43455 .621 L p .755 .603 .688 r
F P
0 g
s
.46404 .54525 m .45713 .58466 L .44131 .58174 L p .749 .625 .722 r
F P
0 g
s
.48448 .66656 m .48661 .62816 L .50425 .62912 L p .707 .532 .65 r
F P
0 g
s
.50425 .62912 m .50309 .66732 L .48448 .66656 L p .707 .532 .65 r
F P
0 g
s
.50309 .66732 m .50425 .62912 L .52182 .62938 L p .691 .517 .647 r
F P
0 g
s
.55172 .54992 m .54849 .51138 L .56107 .51038 L p .675 .584 .746 r
F P
0 g
s
.56107 .51038 m .56608 .54876 L .55172 .54992 L p .675 .584 .746 r
F P
0 g
s
.4659 .665 m .46903 .62649 L .48661 .62816 L p .724 .548 .652 r
F P
0 g
s
.48661 .62816 m .48448 .66656 L .4659 .665 L p .724 .548 .652 r
F P
0 g
s
.52182 .62938 m .52159 .66729 L .50309 .66732 L p .691 .517 .647 r
F P
0 g
s
.52159 .66729 m .52182 .62938 L .53923 .62896 L p .675 .502 .644 r
F P
0 g
s
.44131 .58174 m .44981 .54256 L .46404 .54525 L p .749 .625 .722 r
F P
0 g
s
.47222 .50707 m .46404 .54525 L .44981 .54256 L p .741 .648 .757 r
F P
0 g
s
.46404 .54525 m .47222 .50707 L .48477 .50899 L p .73 .637 .755 r
F P
0 g
s
.44751 .6626 m .45163 .6241 L .46903 .62649 L p .742 .564 .654 r
F P
0 g
s
.46903 .62649 m .4659 .665 L .44751 .6626 L p .742 .564 .654 r
F P
0 g
s
.57016 .58782 m .56608 .54876 L .58025 .54704 L p .658 .539 .708 r
F P
0 g
s
.56608 .54876 m .56107 .51038 L .5735 .50887 L p .667 .578 .746 r
F P
0 g
s
.5735 .50887 m .58025 .54704 L .56608 .54876 L p .667 .578 .746 r
F P
0 g
s
.57016 .58782 m .57324 .62621 L .55638 .62789 L p .658 .511 .673 r
F P
0 g
s
.57324 .62621 m .57016 .58782 L .5857 .58585 L p .647 .501 .671 r
F P
0 g
s
.58025 .54704 m .5857 .58585 L .57016 .58782 L p .658 .539 .708 r
F P
0 g
s
.53923 .62896 m .53987 .66652 L .52159 .66729 L p .675 .502 .644 r
F P
0 g
s
.53987 .66652 m .53923 .62896 L .55638 .62789 L p .66 .489 .641 r
F P
0 g
s
.41792 .61722 m .42587 .57822 L .44131 .58174 L p .77 .617 .69 r
F P
0 g
s
.44131 .58174 m .43455 .621 L .41792 .61722 L p .77 .617 .69 r
F P
0 g
s
.44981 .54256 m .44131 .58174 L .42587 .57822 L p .762 .638 .724 r
F P
0 g
s
.42949 .65939 m .43455 .621 L .45163 .6241 L p .759 .581 .655 r
F P
0 g
s
.45163 .6241 m .44751 .6626 L .42949 .65939 L p .759 .581 .655 r
F P
0 g
s
.42587 .57822 m .43589 .53936 L .44981 .54256 L p .762 .638 .724 r
F P
0 g
s
.45987 .50469 m .44981 .54256 L .43589 .53936 L p .751 .658 .759 r
F P
0 g
s
.44981 .54256 m .45987 .50469 L .47222 .50707 L p .741 .648 .757 r
F P
0 g
s
.5857 .58585 m .58025 .54704 L .59419 .54477 L p .65 .532 .707 r
F P
0 g
s
.58025 .54704 m .5735 .50887 L .58574 .50686 L p .66 .572 .745 r
F P
0 g
s
.58574 .50686 m .59419 .54477 L .58025 .54704 L p .66 .572 .745 r
F P
0 g
s
.52358 .47536 m .52303 .51189 L .51024 .5114 L p .699 .639 .785 r
F P
0 g
s
.52303 .51189 m .52358 .47536 L .53422 .47534 L p .692 .632 .784 r
F P
0 g
s
.53422 .47534 m .5358 .51188 L .52303 .51189 L p .692 .632 .784 r
F P
0 g
s
.51294 .47495 m .51024 .5114 L .49746 .51044 L p .707 .646 .786 r
F P
0 g
s
.51024 .5114 m .51294 .47495 L .52358 .47536 L p .699 .639 .785 r
F P
0 g
s
.55638 .62789 m .55782 .66506 L .53987 .66652 L p .66 .489 .641 r
F P
0 g
s
.55782 .66506 m .55638 .62789 L .57324 .62621 L p .647 .476 .638 r
F P
0 g
s
.5857 .58585 m .58978 .62393 L .57324 .62621 L p .647 .501 .671 r
F P
0 g
s
.58978 .62393 m .5857 .58585 L .60098 .58331 L p .638 .493 .669 r
F P
0 g
s
.59419 .54477 m .60098 .58331 L .5857 .58585 L p .65 .532 .707 r
F P
0 g
s
.5358 .51188 m .53422 .47534 L .54481 .4749 L p .685 .626 .783 r
F P
0 g
s
.54481 .4749 m .54849 .51138 L .5358 .51188 L p .685 .626 .783 r
F P
0 g
s
.50233 .47413 m .49746 .51044 L .48477 .50899 L p .714 .653 .788 r
F P
0 g
s
.49746 .51044 m .50233 .47413 L .51294 .47495 L p .707 .646 .786 r
F P
0 g
s
.54849 .51138 m .54481 .4749 L .55532 .47404 L p .679 .62 .783 r
F P
0 g
s
.55532 .47404 m .56107 .51038 L .54849 .51138 L p .679 .62 .783 r
F P
0 g
s
.49179 .47291 m .48477 .50899 L .47222 .50707 L p .722 .661 .789 r
F P
0 g
s
.48477 .50899 m .49179 .47291 L .50233 .47413 L p .714 .653 .788 r
F P
0 g
s
.40185 .61279 m .41089 .57413 L .42587 .57822 L p .785 .632 .691 r
F P
0 g
s
.42587 .57822 m .41792 .61722 L .40185 .61279 L p .785 .632 .691 r
F P
0 g
s
.43589 .53936 m .42587 .57822 L .41089 .57413 L p .774 .651 .726 r
F P
0 g
s
.41199 .65539 m .41792 .61722 L .43455 .621 L p .777 .597 .656 r
F P
0 g
s
.43455 .621 m .42949 .65939 L .41199 .65539 L p .777 .597 .656 r
F P
0 g
s
.41089 .57413 m .42235 .53564 L .43589 .53936 L p .774 .651 .726 r
F P
0 g
s
.44777 .50185 m .43589 .53936 L .42235 .53564 L p .76 .669 .761 r
F P
0 g
s
.43589 .53936 m .44777 .50185 L .45987 .50469 L p .751 .658 .759 r
F P
0 g
s
.60098 .58331 m .59419 .54477 L .60791 .54194 L p .642 .526 .706 r
F P
0 g
s
.59419 .54477 m .58574 .50686 L .59779 .50435 L p .654 .567 .745 r
F P
0 g
s
.59779 .50435 m .60791 .54194 L .59419 .54477 L p .654 .567 .745 r
F P
0 g
s
.57324 .62621 m .5754 .66298 L .55782 .66506 L p .647 .476 .638 r
F P
0 g
s
.5754 .66298 m .57324 .62621 L .58978 .62393 L p .635 .465 .636 r
F P
0 g
s
.56107 .51038 m .55532 .47404 L .56571 .47275 L p .673 .615 .783 r
F P
0 g
s
.56571 .47275 m .5735 .50887 L .56107 .51038 L p .673 .615 .783 r
F P
0 g
s
.48138 .47128 m .47222 .50707 L .45987 .50469 L p .729 .669 .791 r
F P
0 g
s
.47222 .50707 m .48138 .47128 L .49179 .47291 L p .722 .661 .789 r
F P
0 g
s
.60098 .58331 m .60601 .62108 L .58978 .62393 L p .638 .493 .669 r
F P
0 g
s
.60601 .62108 m .60098 .58331 L .616 .5802 L p .629 .486 .668 r
F P
0 g
s
.60791 .54194 m .616 .5802 L .60098 .58331 L p .642 .526 .706 r
F P
0 g
s
.48298 .70344 m .48448 .66656 L .50309 .66732 L p .703 .507 .621 r
F P
0 g
s
.50309 .66732 m .50228 .70391 L .48298 .70344 L p .703 .507 .621 r
F P
0 g
s
.50228 .70391 m .50309 .66732 L .52159 .66729 L p .685 .491 .618 r
F P
0 g
s
.46369 .70204 m .4659 .665 L .48448 .66656 L p .722 .525 .623 r
F P
0 g
s
.48448 .66656 m .48298 .70344 L .46369 .70204 L p .722 .525 .623 r
F P
0 g
s
.52159 .66729 m .52143 .70352 L .50228 .70391 L p .685 .491 .618 r
F P
0 g
s
.52143 .70352 m .52159 .66729 L .53987 .66652 L p .667 .475 .615 r
F P
0 g
s
.44461 .6997 m .44751 .6626 L .4659 .665 L p .742 .542 .624 r
F P
0 g
s
.4659 .665 m .46369 .70204 L .44461 .6997 L p .742 .542 .624 r
F P
0 g
s
.5735 .50887 m .56571 .47275 L .57597 .47103 L p .667 .611 .783 r
F P
0 g
s
.57597 .47103 m .58574 .50686 L .5735 .50887 L p .667 .611 .783 r
F P
0 g
s
.47112 .46926 m .45987 .50469 L .44777 .50185 L p .737 .677 .793 r
F P
0 g
s
.45987 .50469 m .47112 .46926 L .48138 .47128 L p .729 .669 .791 r
F P
0 g
s
.616 .5802 m .60791 .54194 L .62137 .53855 L p .636 .521 .706 r
F P
0 g
s
.60791 .54194 m .59779 .50435 L .6096 .50133 L p .648 .563 .746 r
F P
0 g
s
.6096 .50133 m .62137 .53855 L .60791 .54194 L p .648 .563 .746 r
F P
0 g
s
.39514 .65064 m .40185 .61279 L .41792 .61722 L p .794 .613 .656 r
F P
0 g
s
.41792 .61722 m .41199 .65539 L .39514 .65064 L p .794 .613 .656 r
F P
0 g
s
.58978 .62393 m .5926 .66032 L .5754 .66298 L p .635 .465 .636 r
F P
0 g
s
.5926 .66032 m .58978 .62393 L .60601 .62108 L p .624 .455 .633 r
F P
0 g
s
.38642 .60774 m .39646 .56949 L .41089 .57413 L p .8 .646 .691 r
F P
0 g
s
.41089 .57413 m .40185 .61279 L .38642 .60774 L p .8 .646 .691 r
F P
0 g
s
.42235 .53564 m .41089 .57413 L .39646 .56949 L p .786 .663 .727 r
F P
0 g
s
.39646 .56949 m .40925 .53144 L .42235 .53564 L p .786 .663 .727 r
F P
0 g
s
.43598 .49857 m .42235 .53564 L .40925 .53144 L p .77 .679 .763 r
F P
0 g
s
.42235 .53564 m .43598 .49857 L .44777 .50185 L p .76 .669 .761 r
F P
0 g
s
.53987 .66652 m .5403 .70232 L .52143 .70352 L p .667 .475 .615 r
F P
0 g
s
.5403 .70232 m .53987 .66652 L .55782 .66506 L p .65 .459 .612 r
F P
0 g
s
.42593 .69642 m .42949 .65939 L .44751 .6626 L p .761 .56 .625 r
F P
0 g
s
.44751 .6626 m .44461 .6997 L .42593 .69642 L p .761 .56 .625 r
F P
0 g
s
.58574 .50686 m .57597 .47103 L .58604 .46887 L p .662 .607 .783 r
F P
0 g
s
.58604 .46887 m .59779 .50435 L .58574 .50686 L p .662 .607 .783 r
F P
0 g
s
.616 .5802 m .62194 .6177 L .60601 .62108 L p .629 .486 .668 r
F P
0 g
s
.62194 .6177 m .616 .5802 L .63076 .57651 L p .622 .48 .667 r
F P
0 g
s
.62137 .53855 m .63076 .57651 L .616 .5802 L p .636 .521 .706 r
F P
0 g
s
.46107 .46686 m .44777 .50185 L .43598 .49857 L p .744 .686 .795 r
F P
0 g
s
.44777 .50185 m .46107 .46686 L .47112 .46926 L p .737 .677 .793 r
F P
0 g
s
.63076 .57651 m .62137 .53855 L .63458 .53461 L p .63 .517 .707 r
F P
0 g
s
.62137 .53855 m .6096 .50133 L .62116 .4978 L p .642 .56 .747 r
F P
0 g
s
.62116 .4978 m .63458 .53461 L .62137 .53855 L p .642 .56 .747 r
F P
0 g
s
.55782 .66506 m .55878 .7004 L .5403 .70232 L p .65 .459 .612 r
F P
0 g
s
.55878 .7004 m .55782 .66506 L .5754 .66298 L p .635 .446 .609 r
F P
0 g
s
.59779 .50435 m .58604 .46887 L .59592 .46629 L p .657 .604 .783 r
F P
0 g
s
.59592 .46629 m .6096 .50133 L .59779 .50435 L p .657 .604 .783 r
F P
0 g
s
.60601 .62108 m .60943 .65713 L .5926 .66032 L p .624 .455 .633 r
F P
0 g
s
.60943 .65713 m .60601 .62108 L .62194 .6177 L p .615 .447 .631 r
F P
0 g
s
.40783 .69224 m .41199 .65539 L .42949 .65939 L p .781 .578 .625 r
F P
0 g
s
.42949 .65939 m .42593 .69642 L .40783 .69224 L p .781 .578 .625 r
F P
0 g
s
.38263 .56431 m .39665 .52675 L .40925 .53144 L p .798 .675 .729 r
F P
0 g
s
.40925 .53144 m .39646 .56949 L .38263 .56431 L p .798 .675 .729 r
F P
0 g
s
.42454 .49485 m .40925 .53144 L .39665 .52675 L p .779 .689 .764 r
F P
0 g
s
.40925 .53144 m .42454 .49485 L .43598 .49857 L p .77 .679 .763 r
F P
0 g
s
.37905 .64519 m .38642 .60774 L .40185 .61279 L p .811 .629 .656 r
F P
0 g
s
.40185 .61279 m .39514 .65064 L .37905 .64519 L p .811 .629 .656 r
F P
0 g
s
.63076 .57651 m .63762 .61377 L .62194 .6177 L p .622 .48 .667 r
F P
0 g
s
.63762 .61377 m .63076 .57651 L .64528 .57226 L p .616 .475 .667 r
F P
0 g
s
.63458 .53461 m .64528 .57226 L .63076 .57651 L p .63 .517 .707 r
F P
0 g
s
.37172 .60211 m .38263 .56431 L .39646 .56949 L p .814 .66 .692 r
F P
0 g
s
.39646 .56949 m .38642 .60774 L .37172 .60211 L p .814 .66 .692 r
F P
0 g
s
.45127 .46407 m .43598 .49857 L .42454 .49485 L p .751 .694 .796 r
F P
0 g
s
.43598 .49857 m .45127 .46407 L .46107 .46686 L p .744 .686 .795 r
F P
0 g
s
.52417 .44183 m .52358 .47536 L .51294 .47495 L p .695 .667 .818 r
F P
0 g
s
.52358 .47536 m .52417 .44183 L .53252 .4418 L p .69 .662 .818 r
F P
0 g
s
.53252 .4418 m .53422 .47534 L .52358 .47536 L p .69 .662 .818 r
F P
0 g
s
.51583 .44153 m .51294 .47495 L .50233 .47413 L p .7 .672 .819 r
F P
0 g
s
.51294 .47495 m .51583 .44153 L .52417 .44183 L p .695 .667 .818 r
F P
0 g
s
.53422 .47534 m .53252 .4418 L .54083 .44143 L p .685 .658 .817 r
F P
0 g
s
.54083 .44143 m .54481 .4749 L .53422 .47534 L p .685 .658 .817 r
F P
0 g
s
.50752 .4409 m .50233 .47413 L .49179 .47291 L p .705 .677 .82 r
F P
0 g
s
.50233 .47413 m .50752 .4409 L .51583 .44153 L p .7 .672 .819 r
F P
0 g
s
.5754 .66298 m .57683 .69785 L .55878 .7004 L p .635 .446 .609 r
F P
0 g
s
.57683 .69785 m .5754 .66298 L .5926 .66032 L p .622 .433 .606 r
F P
0 g
s
.6096 .50133 m .59592 .46629 L .60556 .46328 L p .653 .602 .785 r
F P
0 g
s
.60556 .46328 m .62116 .4978 L .6096 .50133 L p .653 .602 .785 r
F P
0 g
s
.54481 .4749 m .54083 .44143 L .54909 .44071 L p .681 .654 .817 r
F P
0 g
s
.54909 .44071 m .55532 .47404 L .54481 .4749 L p .681 .654 .817 r
F P
0 g
s
.62116 .4978 m .63458 .53461 L .64753 .53011 L p .636 .557 .748 r
F P
0 g
s
.63458 .53461 m .64528 .57226 L .65956 .56744 L p .623 .513 .708 r
F P
0 g
s
.65956 .56744 m .64753 .53011 L .63458 .53461 L p .623 .513 .708 r
F P
0 g
s
.49928 .43993 m .49179 .47291 L .48138 .47128 L p .711 .683 .821 r
F P
0 g
s
.49179 .47291 m .49928 .43993 L .50752 .4409 L p .705 .677 .82 r
F P
0 g
s
.55532 .47404 m .54909 .44071 L .55727 .43965 L p .676 .651 .817 r
F P
0 g
s
.55727 .43965 m .56571 .47275 L .55532 .47404 L p .676 .651 .817 r
F P
0 g
s
.62194 .6177 m .62595 .65347 L .60943 .65713 L p .615 .447 .631 r
F P
0 g
s
.62595 .65347 m .62194 .6177 L .63762 .61377 L p .608 .441 .63 r
F P
0 g
s
.39045 .68719 m .39514 .65064 L .41199 .65539 L p .801 .596 .625 r
F P
0 g
s
.41199 .65539 m .40783 .69224 L .39045 .68719 L p .801 .596 .625 r
F P
0 g
s
.49113 .43864 m .48138 .47128 L .47112 .46926 L p .716 .689 .823 r
F P
0 g
s
.48138 .47128 m .49113 .43864 L .49928 .43993 L p .711 .683 .821 r
F P
0 g
s
.46225 .73764 m .46369 .70204 L .48298 .70344 L p .72 .504 .597 r
F P
0 g
s
.48298 .70344 m .482 .73884 L .46225 .73764 L p .72 .504 .597 r
F P
0 g
s
.482 .73884 m .48298 .70344 L .50228 .70391 L p .699 .486 .596 r
F P
0 g
s
.56571 .47275 m .55727 .43965 L .56532 .43825 L p .672 .648 .817 r
F P
0 g
s
.56532 .43825 m .57597 .47103 L .56571 .47275 L p .672 .648 .817 r
F P
0 g
s
.50228 .70391 m .50175 .73901 L .482 .73884 L p .699 .486 .596 r
F P
0 g
s
.50175 .73901 m .50228 .70391 L .52143 .70352 L p .679 .469 .594 r
F P
0 g
s
.39665 .52675 m .41351 .4907 L .42454 .49485 L p .779 .689 .764 r
F P
0 g
s
.44175 .4609 m .42454 .49485 L .41351 .4907 L p .758 .702 .798 r
F P
0 g
s
.42454 .49485 m .44175 .4609 L .45127 .46407 L p .751 .694 .796 r
F P
0 g
s
.64528 .57226 m .65309 .60931 L .63762 .61377 L p .616 .475 .667 r
F P
0 g
s
.64528 .57226 m .65309 .60931 L .66837 .60431 L p .609 .471 .668 r
F P
0 g
s
.66837 .60431 m .65956 .56744 L .64528 .57226 L p .609 .471 .668 r
F P
0 g
s
.60556 .46328 m .62116 .4978 L .63245 .49377 L p .648 .599 .786 r
F P
0 g
s
.64753 .53011 m .63245 .49377 L .62116 .4978 L p .636 .557 .748 r
F P
0 g
s
.36942 .55864 m .38457 .52159 L .39665 .52675 L p .809 .687 .73 r
F P
0 g
s
.39665 .52675 m .38263 .56431 L .36942 .55864 L p .809 .687 .73 r
F P
0 g
s
.41351 .4907 m .39665 .52675 L .38457 .52159 L p .788 .699 .766 r
F P
0 g
s
.5926 .66032 m .59443 .69477 L .57683 .69785 L p .622 .433 .606 r
F P
0 g
s
.59443 .69477 m .5926 .66032 L .60943 .65713 L p .611 .423 .603 r
F P
0 g
s
.44271 .73539 m .44461 .6997 L .46369 .70204 L p .741 .523 .598 r
F P
0 g
s
.46369 .70204 m .46225 .73764 L .44271 .73539 L p .741 .523 .598 r
F P
0 g
s
.52143 .70352 m .52133 .73823 L .50175 .73901 L p .679 .469 .594 r
F P
0 g
s
.52133 .73823 m .52143 .70352 L .5403 .70232 L p .66 .452 .592 r
F P
0 g
s
.48311 .43703 m .47112 .46926 L .46107 .46686 L p .721 .694 .824 r
F P
0 g
s
.47112 .46926 m .48311 .43703 L .49113 .43864 L p .716 .689 .823 r
F P
0 g
s
.36378 .63912 m .37172 .60211 L .38642 .60774 L p .828 .645 .655 r
F P
0 g
s
.38642 .60774 m .37905 .64519 L .36378 .63912 L p .828 .645 .655 r
F P
0 g
s
.57597 .47103 m .56532 .43825 L .57324 .43652 L p .668 .645 .818 r
F P
0 g
s
.57324 .43652 m .58604 .46887 L .57597 .47103 L p .668 .645 .818 r
F P
0 g
s
.63245 .49377 m .64753 .53011 L .66019 .52505 L p .629 .554 .75 r
F P
0 g
s
.64753 .53011 m .65956 .56744 L .67361 .56203 L p .615 .51 .711 r
F P
0 g
s
.67361 .56203 m .66019 .52505 L .64753 .53011 L p .615 .51 .711 r
F P
0 g
s
.35775 .59595 m .36942 .55864 L .38263 .56431 L p .828 .673 .691 r
F P
0 g
s
.38263 .56431 m .37172 .60211 L .35775 .59595 L p .828 .673 .691 r
F P
0 g
s
.63762 .61377 m .64222 .64934 L .62595 .65347 L p .608 .441 .63 r
F P
0 g
s
.64222 .64934 m .63762 .61377 L .65309 .60931 L p .602 .436 .63 r
F P
0 g
s
.42359 .73209 m .42593 .69642 L .44461 .6997 L p .762 .542 .598 r
F P
0 g
s
.44461 .6997 m .44271 .73539 L .42359 .73209 L p .762 .542 .598 r
F P
0 g
s
.5403 .70232 m .54058 .73659 L .52133 .73823 L p .66 .452 .592 r
F P
0 g
s
.54058 .73659 m .5403 .70232 L .55878 .7004 L p .642 .436 .589 r
F P
0 g
s
.47525 .4351 m .46107 .46686 L .45127 .46407 L p .726 .7 .826 r
F P
0 g
s
.46107 .46686 m .47525 .4351 L .48311 .43703 L p .721 .694 .824 r
F P
0 g
s
.58604 .46887 m .57324 .43652 L .581 .43444 L p .665 .643 .818 r
F P
0 g
s
.581 .43444 m .59592 .46629 L .58604 .46887 L p .665 .643 .818 r
F P
0 g
s
.63245 .49377 m .61495 .45986 L .60556 .46328 L p .648 .599 .786 r
F P
0 g
s
.61495 .45986 m .63245 .49377 L .64344 .48925 L p .642 .597 .788 r
F P
0 g
s
.66019 .52505 m .64344 .48925 L .63245 .49377 L p .629 .554 .75 r
F P
0 g
s
.38457 .52159 m .4029 .48613 L .41351 .4907 L p .788 .699 .766 r
F P
0 g
s
.43254 .45737 m .41351 .4907 L .4029 .48613 L p .764 .709 .8 r
F P
0 g
s
.41351 .4907 m .43254 .45737 L .44175 .4609 L p .758 .702 .798 r
F P
0 g
s
.65956 .56744 m .66837 .60431 L .68349 .59875 L p .601 .467 .67 r
F P
0 g
s
.68349 .59875 m .67361 .56203 L .65956 .56744 L p .601 .467 .67 r
F P
0 g
s
.37393 .68137 m .37905 .64519 L .39514 .65064 L p .82 .613 .623 r
F P
0 g
s
.39514 .65064 m .39045 .68719 L .37393 .68137 L p .82 .613 .623 r
F P
0 g
s
.60943 .65713 m .61163 .69122 L .59443 .69477 L p .611 .423 .603 r
F P
0 g
s
.61163 .69122 m .60943 .65713 L .62595 .65347 L p .602 .415 .601 r
F P
0 g
s
.64344 .48925 m .66019 .52505 L .67254 .51944 L p .622 .551 .753 r
F P
0 g
s
.66019 .52505 m .67361 .56203 L .6874 .55604 L p .608 .507 .714 r
F P
0 g
s
.6874 .55604 m .67254 .51944 L .66019 .52505 L p .608 .507 .714 r
F P
0 g
s
.55878 .7004 m .55941 .73421 L .54058 .73659 L p .642 .436 .589 r
F P
0 g
s
.55941 .73421 m .55878 .7004 L .57683 .69785 L p .626 .422 .586 r
F P
0 g
s
.35686 .55247 m .37305 .51598 L .38457 .52159 L p .82 .698 .73 r
F P
0 g
s
.38457 .52159 m .36942 .55864 L .35686 .55247 L p .82 .698 .73 r
F P
0 g
s
.4029 .48613 m .38457 .52159 L .37305 .51598 L p .796 .708 .768 r
F P
0 g
s
.59592 .46629 m .581 .43444 L .58856 .43203 L p .661 .641 .819 r
F P
0 g
s
.58856 .43203 m .60556 .46328 L .59592 .46629 L p .661 .641 .819 r
F P
0 g
s
.46758 .43286 m .45127 .46407 L .44175 .4609 L p .731 .706 .827 r
F P
0 g
s
.45127 .46407 m .46758 .43286 L .47525 .4351 L p .726 .7 .826 r
F P
0 g
s
.40509 .72775 m .40783 .69224 L .42593 .69642 L p .783 .561 .598 r
F P
0 g
s
.42593 .69642 m .42359 .73209 L .40509 .72775 L p .783 .561 .598 r
F P
0 g
s
.65309 .60931 m .65831 .64475 L .64222 .64934 L p .602 .436 .63 r
F P
0 g
s
.65309 .60931 m .65831 .64475 L .67428 .6397 L p .595 .432 .631 r
F P
0 g
s
.67428 .6397 m .66837 .60431 L .65309 .60931 L p .595 .432 .631 r
F P
0 g
s
.64344 .48925 m .62406 .45602 L .61495 .45986 L p .642 .597 .788 r
F P
0 g
s
.62406 .45602 m .64344 .48925 L .6541 .48424 L p .636 .595 .791 r
F P
0 g
s
.67254 .51944 m .6541 .48424 L .64344 .48925 L p .622 .551 .753 r
F P
0 g
s
.34936 .63248 m .35775 .59595 L .37172 .60211 L p .844 .659 .653 r
F P
0 g
s
.37172 .60211 m .36378 .63912 L .34936 .63248 L p .844 .659 .653 r
F P
0 g
s
.34453 .58928 m .35686 .55247 L .36942 .55864 L p .84 .686 .691 r
F P
0 g
s
.36942 .55864 m .35775 .59595 L .34453 .58928 L p .84 .686 .691 r
F P
0 g
s
.58856 .43203 m .60556 .46328 L .61495 .45986 L p .657 .639 .821 r
F P
0 g
s
.37305 .51598 m .39277 .48115 L .4029 .48613 L p .796 .708 .768 r
F P
0 g
s
.42369 .45347 m .4029 .48613 L .39277 .48115 L p .77 .717 .802 r
F P
0 g
s
.4029 .48613 m .42369 .45347 L .43254 .45737 L p .764 .709 .8 r
F P
0 g
s
.46013 .43032 m .44175 .4609 L .43254 .45737 L p .735 .712 .829 r
F P
0 g
s
.44175 .4609 m .46013 .43032 L .46758 .43286 L p .731 .706 .827 r
F P
0 g
s
.67361 .56203 m .68349 .59875 L .69843 .5926 L p .593 .463 .673 r
F P
0 g
s
.69843 .5926 m .6874 .55604 L .67361 .56203 L p .593 .463 .673 r
F P
0 g
s
.62595 .65347 m .62849 .68727 L .61163 .69122 L p .602 .415 .601 r
F P
0 g
s
.62849 .68727 m .62595 .65347 L .64222 .64934 L p .595 .409 .599 r
F P
0 g
s
.57683 .69785 m .57775 .7312 L .55941 .73421 L p .626 .422 .586 r
F P
0 g
s
.57775 .7312 m .57683 .69785 L .59443 .69477 L p .613 .41 .584 r
F P
0 g
s
.6541 .48424 m .67254 .51944 L .68454 .51328 L p .615 .549 .757 r
F P
0 g
s
.67254 .51944 m .6874 .55604 L .7009 .54945 L p .599 .504 .717 r
F P
0 g
s
.7009 .54945 m .68454 .51328 L .67254 .51944 L p .599 .504 .717 r
F P
0 g
s
.35834 .67486 m .36378 .63912 L .37905 .64519 L p .838 .63 .621 r
F P
0 g
s
.37905 .64519 m .37393 .68137 L .35834 .67486 L p .838 .63 .621 r
F P
0 g
s
.38738 .72246 m .39045 .68719 L .40783 .69224 L p .805 .579 .596 r
F P
0 g
s
.40783 .69224 m .40509 .72775 L .38738 .72246 L p .805 .579 .596 r
F P
0 g
s
.61495 .45986 m .5959 .4293 L .58856 .43203 L p .657 .639 .821 r
F P
0 g
s
.5959 .4293 m .61495 .45986 L .62406 .45602 L p .653 .638 .823 r
F P
0 g
s
.34495 .54584 m .36209 .50991 L .37305 .51598 L p .829 .708 .731 r
F P
0 g
s
.37305 .51598 m .35686 .55247 L .34495 .54584 L p .829 .708 .731 r
F P
0 g
s
.39277 .48115 m .37305 .51598 L .36209 .50991 L p .803 .717 .77 r
F P
0 g
s
.66837 .60431 m .67428 .6397 L .69016 .63415 L p .588 .428 .632 r
F P
0 g
s
.69016 .63415 m .68349 .59875 L .66837 .60431 L p .588 .428 .632 r
F P
0 g
s
.52478 .4115 m .52417 .44183 L .51583 .44153 L p .689 .691 .847 r
F P
0 g
s
.52417 .44183 m .52478 .4115 L .53076 .41146 L p .685 .688 .847 r
F P
0 g
s
.53076 .41146 m .53252 .4418 L .52417 .44183 L p .685 .688 .847 r
F P
0 g
s
.6541 .48424 m .63285 .45177 L .62406 .45602 L p .636 .595 .791 r
F P
0 g
s
.63285 .45177 m .6541 .48424 L .66439 .47875 L p .631 .594 .794 r
F P
0 g
s
.68454 .51328 m .66439 .47875 L .6541 .48424 L p .615 .549 .757 r
F P
0 g
s
.53252 .4418 m .53076 .41146 L .53672 .41116 L p .682 .686 .847 r
F P
0 g
s
.53672 .41116 m .54083 .44143 L .53252 .4418 L p .682 .686 .847 r
F P
0 g
s
.51881 .41129 m .51583 .44153 L .50752 .4409 L p .692 .694 .848 r
F P
0 g
s
.51583 .44153 m .51881 .41129 L .52478 .4115 L p .689 .691 .847 r
F P
0 g
s
.45292 .42748 m .43254 .45737 L .42369 .45347 L p .74 .717 .831 r
F P
0 g
s
.43254 .45737 m .45292 .42748 L .46013 .43032 L p .735 .712 .829 r
F P
0 g
s
.54083 .44143 m .53672 .41116 L .54264 .41062 L p .68 .683 .847 r
F P
0 g
s
.54264 .41062 m .54909 .44071 L .54083 .44143 L p .68 .683 .847 r
F P
0 g
s
.51286 .41084 m .50752 .4409 L .49928 .43993 L p .695 .698 .848 r
F P
0 g
s
.50752 .4409 m .51286 .41084 L .51881 .41129 L p .692 .694 .848 r
F P
0 g
s
.59443 .69477 m .59561 .72769 L .57775 .7312 L p .613 .41 .584 r
F P
0 g
s
.59561 .72769 m .59443 .69477 L .61163 .69122 L p .601 .4 .581 r
F P
0 g
s
.54909 .44071 m .54264 .41062 L .5485 .40983 L p .677 .681 .847 r
F P
0 g
s
.5485 .40983 m .55727 .43965 L .54909 .44071 L p .677 .681 .847 r
F P
0 g
s
.50696 .41015 m .49928 .43993 L .49113 .43864 L p .698 .701 .849 r
F P
0 g
s
.49928 .43993 m .50696 .41015 L .51286 .41084 L p .695 .698 .848 r
F P
0 g
s
.46142 .77208 m .46225 .73764 L .482 .73884 L p .717 .486 .575 r
F P
0 g
s
.482 .73884 m .48143 .77308 L .46142 .77208 L p .717 .486 .575 r
F P
0 g
s
.48143 .77308 m .482 .73884 L .50175 .73901 L p .696 .468 .574 r
F P
0 g
s
.64222 .64934 m .64511 .68296 L .62849 .68727 L p .595 .409 .599 r
F P
0 g
s
.64511 .68296 m .64222 .64934 L .65831 .64475 L p .59 .404 .599 r
F P
0 g
s
.36209 .50991 m .38311 .47575 L .39277 .48115 L p .803 .717 .77 r
F P
0 g
s
.41522 .44922 m .39277 .48115 L .38311 .47575 L p .776 .724 .804 r
F P
0 g
s
.39277 .48115 m .41522 .44922 L .42369 .45347 L p .77 .717 .802 r
F P
0 g
s
.50175 .73901 m .50144 .77299 L .48143 .77308 L p .696 .468 .574 r
F P
0 g
s
.50144 .77299 m .50175 .73901 L .52133 .73823 L p .675 .451 .573 r
F P
0 g
s
.6874 .55604 m .69843 .5926 L .71317 .58586 L p .584 .46 .677 r
F P
0 g
s
.71317 .58586 m .7009 .54945 L .6874 .55604 L p .584 .46 .677 r
F P
0 g
s
.55727 .43965 m .5485 .40983 L .55428 .4088 L p .674 .679 .847 r
F P
0 g
s
.55428 .4088 m .56532 .43825 L .55727 .43965 L p .674 .679 .847 r
F P
0 g
s
.50114 .40921 m .49113 .43864 L .48311 .43703 L p .701 .705 .85 r
F P
0 g
s
.49113 .43864 m .50114 .40921 L .50696 .41015 L p .698 .701 .849 r
F P
0 g
s
.44163 .76993 m .44271 .73539 L .46225 .73764 L p .739 .505 .574 r
F P
0 g
s
.46225 .73764 m .46142 .77208 L .44163 .76993 L p .739 .505 .574 r
F P
0 g
s
.52133 .73823 m .52127 .77188 L .50144 .77299 L p .675 .451 .573 r
F P
0 g
s
.52127 .77188 m .52133 .73823 L .54058 .73659 L p .655 .435 .572 r
F P
0 g
s
.62406 .45602 m .60299 .42625 L .5959 .4293 L p .653 .638 .823 r
F P
0 g
s
.60299 .42625 m .62406 .45602 L .63285 .45177 L p .649 .637 .825 r
F P
0 g
s
.33579 .62534 m .34453 .58928 L .35775 .59595 L p .858 .673 .651 r
F P
0 g
s
.35775 .59595 m .34936 .63248 L .33579 .62534 L p .858 .673 .651 r
F P
0 g
s
.33202 .58215 m .34495 .54584 L .35686 .55247 L p .852 .697 .69 r
F P
0 g
s
.35686 .55247 m .34453 .58928 L .33202 .58215 L p .852 .697 .69 r
F P
0 g
s
.66439 .47875 m .68454 .51328 L .69613 .50659 L p .608 .548 .761 r
F P
0 g
s
.68454 .51328 m .7009 .54945 L .71403 .54228 L p .591 .501 .722 r
F P
0 g
s
.71403 .54228 m .69613 .50659 L .68454 .51328 L p .591 .501 .722 r
F P
0 g
s
.56532 .43825 m .55428 .4088 L .55995 .40752 L p .672 .678 .848 r
F P
0 g
s
.55995 .40752 m .57324 .43652 L .56532 .43825 L p .672 .678 .848 r
F P
0 g
s
.49541 .40804 m .48311 .43703 L .47525 .4351 L p .704 .708 .851 r
F P
0 g
s
.48311 .43703 m .49541 .40804 L .50114 .40921 L p .701 .705 .85 r
F P
0 g
s
.44599 .42435 m .42369 .45347 L .41522 .44922 L p .743 .723 .832 r
F P
0 g
s
.42369 .45347 m .44599 .42435 L .45292 .42748 L p .74 .717 .831 r
F P
0 g
s
.37059 .71631 m .37393 .68137 L .39045 .68719 L p .825 .598 .594 r
F P
0 g
s
.39045 .68719 m .38738 .72246 L .37059 .71631 L p .825 .598 .594 r
F P
0 g
s
.66439 .47875 m .64129 .44714 L .63285 .45177 L p .631 .594 .794 r
F P
0 g
s
.64129 .44714 m .66439 .47875 L .67427 .4728 L p .625 .593 .798 r
F P
0 g
s
.69613 .50659 m .67427 .4728 L .66439 .47875 L p .608 .548 .761 r
F P
0 g
s
.68349 .59875 m .69016 .63415 L .70597 .62807 L p .58 .424 .635 r
F P
0 g
s
.70597 .62807 m .69843 .5926 L .68349 .59875 L p .58 .424 .635 r
F P
0 g
s
.42226 .76663 m .42359 .73209 L .44271 .73539 L p .762 .524 .574 r
F P
0 g
s
.44271 .73539 m .44163 .76993 L .42226 .76663 L p .762 .524 .574 r
F P
0 g
s
.54058 .73659 m .54076 .76987 L .52127 .77188 L p .655 .435 .572 r
F P
0 g
s
.54076 .76987 m .54058 .73659 L .55941 .73421 L p .637 .42 .571 r
F P
0 g
s
.57324 .43652 m .55995 .40752 L .5655 .406 L p .669 .677 .848 r
F P
0 g
s
.5655 .406 m .581 .43444 L .57324 .43652 L p .669 .677 .848 r
F P
0 g
s
.61163 .69122 m .61304 .72379 L .59561 .72769 L p .601 .4 .581 r
F P
0 g
s
.61304 .72379 m .61163 .69122 L .62849 .68727 L p .592 .392 .579 r
F P
0 g
s
.48979 .40663 m .47525 .4351 L .46758 .43286 L p .707 .712 .852 r
F P
0 g
s
.47525 .4351 m .48979 .40663 L .49541 .40804 L p .704 .708 .851 r
F P
0 g
s
.34368 .66775 m .34936 .63248 L .36378 .63912 L p .856 .646 .618 r
F P
0 g
s
.36378 .63912 m .35834 .67486 L .34368 .66775 L p .856 .646 .618 r
F P
0 g
s
.33365 .53873 m .35169 .50339 L .36209 .50991 L p .838 .718 .732 r
F P
0 g
s
.36209 .50991 m .34495 .54584 L .33365 .53873 L p .838 .718 .732 r
F P
0 g
s
.38311 .47575 m .36209 .50991 L .35169 .50339 L p .81 .725 .771 r
F P
0 g
s
.65831 .64475 m .66158 .6783 L .64511 .68296 L p .59 .404 .599 r
F P
0 g
s
.65831 .64475 m .66158 .6783 L .67799 .67329 L p .584 .401 .599 r
F P
0 g
s
.67799 .67329 m .67428 .6397 L .65831 .64475 L p .584 .401 .599 r
F P
0 g
s
.63285 .45177 m .60982 .42288 L .60299 .42625 L p .649 .637 .825 r
F P
0 g
s
.60982 .42288 m .63285 .45177 L .64129 .44714 L p .644 .636 .827 r
F P
0 g
s
.35169 .50339 m .37396 .46995 L .38311 .47575 L p .81 .725 .771 r
F P
0 g
s
.40715 .44462 m .38311 .47575 L .37396 .46995 L p .781 .73 .806 r
F P
0 g
s
.38311 .47575 m .40715 .44462 L .41522 .44922 L p .776 .724 .804 r
F P
0 g
s
.581 .43444 m .5655 .406 L .5709 .40425 L p .667 .675 .849 r
F P
0 g
s
.5709 .40425 m .58856 .43203 L .581 .43444 L p .667 .675 .849 r
F P
0 g
s
.7009 .54945 m .71317 .58586 L .72761 .57849 L p .574 .456 .681 r
F P
0 g
s
.72761 .57849 m .71403 .54228 L .7009 .54945 L p .574 .456 .681 r
F P
0 g
s
.48431 .405 m .46758 .43286 L .46013 .43032 L p .71 .716 .853 r
F P
0 g
s
.46758 .43286 m .48431 .405 L .48979 .40663 L p .707 .712 .852 r
F P
0 g
s
.55941 .73421 m .5598 .7671 L .54076 .76987 L p .637 .42 .571 r
F P
0 g
s
.5598 .7671 m .55941 .73421 L .57775 .7312 L p .621 .407 .57 r
F P
0 g
s
.43936 .42093 m .41522 .44922 L .40715 .44462 L p .747 .728 .834 r
F P
0 g
s
.41522 .44922 m .43936 .42093 L .44599 .42435 L p .743 .723 .832 r
F P
0 g
s
.40353 .76222 m .40509 .72775 L .42359 .73209 L p .784 .544 .573 r
F P
0 g
s
.42359 .73209 m .42226 .76663 L .40353 .76222 L p .784 .544 .573 r
F P
0 g
s
.67427 .4728 m .69613 .50659 L .70726 .49938 L p .6 .546 .766 r
F P
0 g
s
.69613 .50659 m .71403 .54228 L .72672 .53452 L p .581 .499 .727 r
F P
0 g
s
.72672 .53452 m .70726 .49938 L .69613 .50659 L p .581 .499 .727 r
F P
0 g
s
.5709 .40425 m .58856 .43203 L .5959 .4293 L p .664 .675 .85 r
F P
0 g
s
.67427 .4728 m .64935 .44214 L .64129 .44714 L p .625 .593 .798 r
F P
0 g
s
.64935 .44214 m .67427 .4728 L .68369 .46642 L p .618 .593 .802 r
F P
0 g
s
.70726 .49938 m .68369 .46642 L .67427 .4728 L p .6 .546 .766 r
F P
0 g
s
.69843 .5926 m .70597 .62807 L .72167 .62141 L p .571 .42 .638 r
F P
0 g
s
.72167 .62141 m .71317 .58586 L .69843 .5926 L p .571 .42 .638 r
F P
0 g
s
.47899 .40314 m .46013 .43032 L .45292 .42748 L p .713 .719 .854 r
F P
0 g
s
.46013 .43032 m .47899 .40314 L .48431 .405 L p .71 .716 .853 r
F P
0 g
s
.62849 .68727 m .63011 .71957 L .61304 .72379 L p .592 .392 .579 r
F P
0 g
s
.63011 .71957 m .62849 .68727 L .64511 .68296 L p .586 .387 .578 r
F P
0 g
s
.32017 .57456 m .33365 .53873 L .34495 .54584 L p .862 .707 .689 r
F P
0 g
s
.34495 .54584 m .33202 .58215 L .32017 .57456 L p .862 .707 .689 r
F P
0 g
s
.64129 .44714 m .61635 .41923 L .60982 .42288 L p .644 .636 .827 r
F P
0 g
s
.61635 .41923 m .64129 .44714 L .64935 .44214 L p .64 .636 .83 r
F P
0 g
s
.32299 .61774 m .33202 .58215 L .34453 .58928 L p .871 .685 .648 r
F P
0 g
s
.34453 .58928 m .33579 .62534 L .32299 .61774 L p .871 .685 .648 r
F P
0 g
s
.35478 .7094 m .35834 .67486 L .37393 .68137 L p .845 .616 .591 r
F P
0 g
s
.37393 .68137 m .37059 .71631 L .35478 .7094 L p .845 .616 .591 r
F P
0 g
s
.67428 .6397 m .67799 .67329 L .6944 .66787 L p .577 .397 .6 r
F P
0 g
s
.6944 .66787 m .69016 .63415 L .67428 .6397 L p .577 .397 .6 r
F P
0 g
s
.57775 .7312 m .57834 .76372 L .5598 .7671 L p .621 .407 .57 r
F P
0 g
s
.57834 .76372 m .57775 .7312 L .59561 .72769 L p .607 .395 .568 r
F P
0 g
s
.5959 .4293 m .57613 .40226 L .5709 .40425 L p .664 .675 .85 r
F P
0 g
s
.57613 .40226 m .5959 .4293 L .60299 .42625 L p .661 .674 .851 r
F P
0 g
s
.37396 .46995 m .39951 .43967 L .40715 .44462 L p .781 .73 .806 r
F P
0 g
s
.43305 .41724 m .40715 .44462 L .39951 .43967 L p .75 .732 .836 r
F P
0 g
s
.40715 .44462 m .43305 .41724 L .43936 .42093 L p .747 .728 .834 r
F P
0 g
s
.47385 .40106 m .45292 .42748 L .44599 .42435 L p .715 .723 .856 r
F P
0 g
s
.45292 .42748 m .47385 .40106 L .47899 .40314 L p .713 .719 .854 r
F P
0 g
s
.34186 .49642 m .36532 .46374 L .37396 .46995 L p .816 .733 .773 r
F P
0 g
s
.37396 .46995 m .35169 .50339 L .34186 .49642 L p .816 .733 .773 r
F P
0 g
s
.39951 .43967 m .37396 .46995 L .36532 .46374 L p .785 .737 .808 r
F P
0 g
s
.32294 .53117 m .34186 .49642 L .35169 .50339 L p .845 .726 .732 r
F P
0 g
s
.35169 .50339 m .33365 .53873 L .32294 .53117 L p .845 .726 .732 r
F P
0 g
s
.71403 .54228 m .72761 .57849 L .74166 .57051 L p .562 .452 .686 r
F P
0 g
s
.74166 .57051 m .72672 .53452 L .71403 .54228 L p .562 .452 .686 r
F P
0 g
s
.38561 .75675 m .38738 .72246 L .40509 .72775 L p .807 .563 .571 r
F P
0 g
s
.40509 .72775 m .40353 .76222 L .38561 .75675 L p .807 .563 .571 r
F P
0 g
s
.32995 .66014 m .33579 .62534 L .34936 .63248 L p .872 .66 .613 r
F P
0 g
s
.34936 .63248 m .34368 .66775 L .32995 .66014 L p .872 .66 .613 r
F P
0 g
s
.60299 .42625 m .58118 .40005 L .57613 .40226 L p .661 .674 .851 r
F P
0 g
s
.58118 .40005 m .60299 .42625 L .60982 .42288 L p .659 .673 .853 r
F P
0 g
s
.64935 .44214 m .62256 .41529 L .61635 .41923 L p .64 .636 .83 r
F P
0 g
s
.62256 .41529 m .64935 .44214 L .65699 .43679 L p .636 .636 .833 r
F P
0 g
s
.68369 .46642 m .65699 .43679 L .64935 .44214 L p .618 .593 .802 r
F P
0 g
s
.65699 .43679 m .68369 .46642 L .69259 .45963 L p .612 .592 .807 r
F P
0 g
s
.68369 .46642 m .70726 .49938 L .71783 .49169 L p .591 .545 .772 r
F P
0 g
s
.71783 .49169 m .69259 .45963 L .68369 .46642 L p .591 .545 .772 r
F P
0 g
s
.70726 .49938 m .72672 .53452 L .73885 .52621 L p .569 .496 .733 r
F P
0 g
s
.73885 .52621 m .71783 .49169 L .70726 .49938 L p .569 .496 .733 r
F P
0 g
s
.64511 .68296 m .64695 .71511 L .63011 .71957 L p .586 .387 .578 r
F P
0 g
s
.64695 .71511 m .64511 .68296 L .66158 .6783 L p .581 .383 .578 r
F P
0 g
s
.46891 .39876 m .44599 .42435 L .43936 .42093 L p .717 .726 .857 r
F P
0 g
s
.44599 .42435 m .46891 .39876 L .47385 .40106 L p .715 .723 .856 r
F P
0 g
s
.71317 .58586 m .72167 .62141 L .73717 .61413 L p .56 .416 .642 r
F P
0 g
s
.73717 .61413 m .72761 .57849 L .71317 .58586 L p .56 .416 .642 r
F P
0 g
s
.59561 .72769 m .59638 .75986 L .57834 .76372 L p .607 .395 .568 r
F P
0 g
s
.59638 .75986 m .59561 .72769 L .61304 .72379 L p .596 .386 .567 r
F P
0 g
s
.69016 .63415 m .6944 .66787 L .71081 .66201 L p .57 .393 .603 r
F P
0 g
s
.71081 .66201 m .70597 .62807 L .69016 .63415 L p .57 .393 .603 r
F P
0 g
s
.36532 .46374 m .39232 .43439 L .39951 .43967 L p .785 .737 .808 r
F P
0 g
s
.42709 .41328 m .39951 .43967 L .39232 .43439 L p .753 .737 .838 r
F P
0 g
s
.39951 .43967 m .42709 .41328 L .43305 .41724 L p .75 .732 .836 r
F P
0 g
s
.60982 .42288 m .58603 .39763 L .58118 .40005 L p .659 .673 .853 r
F P
0 g
s
.58603 .39763 m .60982 .42288 L .61635 .41923 L p .656 .673 .854 r
F P
0 g
s
.46121 .80554 m .46142 .77208 L .48143 .77308 L p .715 .468 .551 r
F P
0 g
s
.48143 .77308 m .48128 .8064 L .46121 .80554 L p .715 .468 .551 r
F P
0 g
s
.48128 .8064 m .48143 .77308 L .50144 .77299 L p .693 .451 .552 r
F P
0 g
s
.50144 .77299 m .50135 .80612 L .48128 .8064 L p .693 .451 .552 r
F P
0 g
s
.50135 .80612 m .50144 .77299 L .52127 .77188 L p .672 .434 .552 r
F P
0 g
s
.30892 .56653 m .32294 .53117 L .33365 .53873 L p .871 .717 .688 r
F P
0 g
s
.33365 .53873 m .32017 .57456 L .30892 .56653 L p .871 .717 .688 r
F P
0 g
s
.33999 .70187 m .34368 .66775 L .35834 .67486 L p .864 .633 .586 r
F P
0 g
s
.35834 .67486 m .35478 .7094 L .33999 .70187 L p .864 .633 .586 r
F P
0 g
s
.52539 .38379 m .52478 .4115 L .51881 .41129 L p .682 .71 .869 r
F P
0 g
s
.52478 .4115 m .52539 .38379 L .52899 .38376 L p .68 .708 .869 r
F P
0 g
s
.52899 .38376 m .53076 .41146 L .52478 .4115 L p .68 .708 .869 r
F P
0 g
s
.31089 .60973 m .32017 .57456 L .33202 .58215 L p .883 .696 .644 r
F P
0 g
s
.33202 .58215 m .32299 .61774 L .31089 .60973 L p .883 .696 .644 r
F P
0 g
s
.33258 .489 m .35722 .45713 L .36532 .46374 L p .821 .74 .775 r
F P
0 g
s
.36532 .46374 m .34186 .49642 L .33258 .489 L p .821 .74 .775 r
F P
0 g
s
.39232 .43439 m .36532 .46374 L .35722 .45713 L p .789 .743 .811 r
F P
0 g
s
.46419 .39627 m .43936 .42093 L .43305 .41724 L p .719 .729 .858 r
F P
0 g
s
.43936 .42093 m .46419 .39627 L .46891 .39876 L p .717 .726 .857 r
F P
0 g
s
.53076 .41146 m .52899 .38376 L .53257 .38357 L p .679 .707 .869 r
F P
0 g
s
.53257 .38357 m .53672 .41116 L .53076 .41146 L p .679 .707 .869 r
F P
0 g
s
.52127 .77188 m .52125 .8048 L .50135 .80612 L p .672 .434 .552 r
F P
0 g
s
.52125 .8048 m .52127 .77188 L .54076 .76987 L p .653 .419 .553 r
F P
0 g
s
.5218 .38368 m .51881 .41129 L .51286 .41084 L p .683 .711 .87 r
F P
0 g
s
.51881 .41129 m .5218 .38368 L .52539 .38379 L p .682 .71 .869 r
F P
0 g
s
.44136 .80349 m .44163 .76993 L .46142 .77208 L p .738 .487 .549 r
F P
0 g
s
.46142 .77208 m .46121 .80554 L .44136 .80349 L p .738 .487 .549 r
F P
0 g
s
.36863 .75036 m .37059 .71631 L .38738 .72246 L p .828 .583 .568 r
F P
0 g
s
.38738 .72246 m .38561 .75675 L .36863 .75036 L p .828 .583 .568 r
F P
0 g
s
.53672 .41116 m .53257 .38357 L .53614 .38323 L p .677 .706 .869 r
F P
0 g
s
.53614 .38323 m .54264 .41062 L .53672 .41116 L p .677 .706 .869 r
F P
0 g
s
.65699 .43679 m .62842 .41108 L .62256 .41529 L p .636 .636 .833 r
F P
0 g
s
.62842 .41108 m .65699 .43679 L .66417 .43111 L p .631 .636 .837 r
F P
0 g
s
.69259 .45963 m .66417 .43111 L .65699 .43679 L p .612 .592 .807 r
F P
0 g
s
.51823 .38341 m .51286 .41084 L .50696 .41015 L p .685 .713 .87 r
F P
0 g
s
.51286 .41084 m .51823 .38341 L .5218 .38368 L p .683 .711 .87 r
F P
0 g
s
.72672 .53452 m .74166 .57051 L .75519 .5619 L p .549 .448 .692 r
F P
0 g
s
.75519 .5619 m .73885 .52621 L .72672 .53452 L p .549 .448 .692 r
F P
0 g
s
.54264 .41062 m .53614 .38323 L .53966 .38275 L p .676 .705 .869 r
F P
0 g
s
.53966 .38275 m .5485 .40983 L .54264 .41062 L p .676 .705 .869 r
F P
0 g
s
.51468 .38299 m .50696 .41015 L .50114 .40921 L p .687 .715 .87 r
F P
0 g
s
.50696 .41015 m .51468 .38299 L .51823 .38341 L p .685 .713 .87 r
F P
0 g
s
.66158 .6783 m .66366 .71042 L .64695 .71511 L p .581 .383 .578 r
F P
0 g
s
.66158 .6783 m .66366 .71042 L .68035 .70549 L p .576 .38 .578 r
F P
0 g
s
.68035 .70549 m .67799 .67329 L .66158 .6783 L p .576 .38 .578 r
F P
0 g
s
.31279 .52313 m .33258 .489 L .34186 .49642 L p .852 .735 .733 r
F P
0 g
s
.34186 .49642 m .32294 .53117 L .31279 .52313 L p .852 .735 .733 r
F P
0 g
s
.61304 .72379 m .61398 .75568 L .59638 .75986 L p .596 .386 .567 r
F P
0 g
s
.61398 .75568 m .61304 .72379 L .63011 .71957 L p .587 .379 .566 r
F P
0 g
s
.66417 .43111 m .69259 .45963 L .70091 .45247 L p .605 .592 .812 r
F P
0 g
s
.69259 .45963 m .71783 .49169 L .72776 .48355 L p .581 .544 .778 r
F P
0 g
s
.72776 .48355 m .70091 .45247 L .69259 .45963 L p .581 .544 .778 r
F P
0 g
s
.5485 .40983 m .53966 .38275 L .54313 .38211 L p .674 .704 .87 r
F P
0 g
s
.54313 .38211 m .55428 .4088 L .5485 .40983 L p .674 .704 .87 r
F P
0 g
s
.61635 .41923 m .59065 .395 L .58603 .39763 L p .656 .673 .854 r
F P
0 g
s
.59065 .395 m .61635 .41923 L .62256 .41529 L p .653 .673 .856 r
F P
0 g
s
.51119 .38242 m .50114 .40921 L .49541 .40804 L p .688 .717 .871 r
F P
0 g
s
.50114 .40921 m .51119 .38242 L .51468 .38299 L p .687 .715 .87 r
F P
0 g
s
.54076 .76987 m .54082 .80257 L .52125 .8048 L p .653 .419 .553 r
F P
0 g
s
.54082 .80257 m .54076 .76987 L .5598 .7671 L p .634 .406 .554 r
F P
0 g
s
.71783 .49169 m .73885 .52621 L .75032 .51737 L p .557 .493 .739 r
F P
0 g
s
.75032 .51737 m .72776 .48355 L .71783 .49169 L p .557 .493 .739 r
F P
0 g
s
.55428 .4088 m .54313 .38211 L .54654 .38132 L p .673 .703 .87 r
F P
0 g
s
.54654 .38132 m .55995 .40752 L .55428 .4088 L p .673 .703 .87 r
F P
0 g
s
.42193 .80023 m .42226 .76663 L .44163 .76993 L p .761 .506 .548 r
F P
0 g
s
.44163 .76993 m .44136 .80349 L .42193 .80023 L p .761 .506 .548 r
F P
0 g
s
.50775 .3817 m .49541 .40804 L .48979 .40663 L p .69 .718 .871 r
F P
0 g
s
.49541 .40804 m .50775 .3817 L .51119 .38242 L p .688 .717 .871 r
F P
0 g
s
.72761 .57849 m .73717 .61413 L .75235 .60621 L p .547 .41 .647 r
F P
0 g
s
.75235 .60621 m .74166 .57051 L .72761 .57849 L p .547 .41 .647 r
F P
0 g
s
.70597 .62807 m .71081 .66201 L .72721 .65562 L p .561 .389 .605 r
F P
0 g
s
.72721 .65562 m .72167 .62141 L .70597 .62807 L p .561 .389 .605 r
F P
0 g
s
.31705 .6521 m .32299 .61774 L .33579 .62534 L p .886 .673 .608 r
F P
0 g
s
.33579 .62534 m .32995 .66014 L .31705 .6521 L p .886 .673 .608 r
F P
0 g
s
.45971 .39357 m .43305 .41724 L .42709 .41328 L p .721 .732 .86 r
F P
0 g
s
.43305 .41724 m .45971 .39357 L .46419 .39627 L p .719 .729 .858 r
F P
0 g
s
.35722 .45713 m .38561 .42878 L .39232 .43439 L p .789 .743 .811 r
F P
0 g
s
.42149 .40905 m .39232 .43439 L .38561 .42878 L p .755 .741 .84 r
F P
0 g
s
.39232 .43439 m .42149 .40905 L .42709 .41328 L p .753 .737 .838 r
F P
0 g
s
.55995 .40752 m .54654 .38132 L .54986 .38039 L p .671 .702 .87 r
F P
0 g
s
.54986 .38039 m .5655 .406 L .55995 .40752 L p .671 .702 .87 r
F P
0 g
s
.50438 .38084 m .48979 .40663 L .48431 .405 L p .691 .72 .872 r
F P
0 g
s
.48979 .40663 m .50438 .38084 L .50775 .3817 L p .69 .718 .871 r
F P
0 g
s
.5598 .7671 m .55996 .79957 L .54082 .80257 L p .634 .406 .554 r
F P
0 g
s
.55996 .79957 m .5598 .7671 L .57834 .76372 L p .618 .394 .554 r
F P
0 g
s
.5655 .406 m .54986 .38039 L .5531 .37932 L p .67 .702 .871 r
F P
0 g
s
.5531 .37932 m .5709 .40425 L .5655 .406 L p .67 .702 .871 r
F P
0 g
s
.62256 .41529 m .59503 .39217 L .59065 .395 L p .653 .673 .856 r
F P
0 g
s
.59503 .39217 m .62256 .41529 L .62842 .41108 L p .65 .673 .858 r
F P
0 g
s
.66417 .43111 m .6339 .40663 L .62842 .41108 L p .631 .636 .837 r
F P
0 g
s
.6339 .40663 m .66417 .43111 L .67086 .42513 L p .626 .636 .841 r
F P
0 g
s
.70091 .45247 m .67086 .42513 L .66417 .43111 L p .605 .592 .812 r
F P
0 g
s
.5011 .37984 m .48431 .405 L .47899 .40314 L p .692 .722 .872 r
F P
0 g
s
.48431 .405 m .5011 .37984 L .50438 .38084 L p .691 .72 .872 r
F P
0 g
s
.40312 .79581 m .40353 .76222 L .42226 .76663 L p .784 .525 .546 r
F P
0 g
s
.42226 .76663 m .42193 .80023 L .40312 .79581 L p .784 .525 .546 r
F P
0 g
s
.63011 .71957 m .63123 .75126 L .61398 .75568 L p .587 .379 .566 r
F P
0 g
s
.63123 .75126 m .63011 .71957 L .64695 .71511 L p .581 .374 .566 r
F P
0 g
s
.67799 .67329 m .68035 .70549 L .6971 .70027 L p .571 .376 .578 r
F P
0 g
s
.6971 .70027 m .6944 .66787 L .67799 .67329 L p .571 .376 .578 r
F P
0 g
s
.32387 .48112 m .34966 .45012 L .35722 .45713 L p .826 .748 .777 r
F P
0 g
s
.35722 .45713 m .33258 .489 L .32387 .48112 L p .826 .748 .777 r
F P
0 g
s
.38561 .42878 m .35722 .45713 L .34966 .45012 L p .792 .748 .813 r
F P
0 g
s
.5531 .37932 m .5709 .40425 L .57613 .40226 L p .669 .701 .871 r
F P
0 g
s
.45548 .39068 m .42709 .41328 L .42149 .40905 L p .723 .735 .861 r
F P
0 g
s
.42709 .41328 m .45548 .39068 L .45971 .39357 L p .721 .732 .86 r
F P
0 g
s
.29821 .55805 m .31279 .52313 L .32294 .53117 L p .879 .725 .687 r
F P
0 g
s
.32294 .53117 m .30892 .56653 L .29821 .55805 L p .879 .725 .687 r
F P
0 g
s
.35267 .74315 m .35478 .7094 L .37059 .71631 L p .849 .602 .564 r
F P
0 g
s
.37059 .71631 m .36863 .75036 L .35267 .74315 L p .849 .602 .564 r
F P
0 g
s
.49791 .3787 m .47899 .40314 L .47385 .40106 L p .694 .724 .873 r
F P
0 g
s
.47899 .40314 m .49791 .3787 L .5011 .37984 L p .692 .722 .872 r
F P
0 g
s
.73885 .52621 m .75519 .5619 L .76803 .55269 L p .533 .442 .698 r
F P
0 g
s
.76803 .55269 m .75032 .51737 L .73885 .52621 L p .533 .442 .698 r
F P
0 g
s
.67086 .42513 m .70091 .45247 L .70859 .44496 L p .597 .592 .817 r
F P
0 g
s
.70091 .45247 m .72776 .48355 L .73697 .47499 L p .57 .542 .784 r
F P
0 g
s
.73697 .47499 m .70859 .44496 L .70091 .45247 L p .57 .542 .784 r
F P
0 g
s
.32617 .69382 m .32995 .66014 L .34368 .66775 L p .881 .648 .581 r
F P
0 g
s
.34368 .66775 m .33999 .70187 L .32617 .69382 L p .881 .648 .581 r
F P
0 g
s
.57613 .40226 m .55623 .37812 L .5531 .37932 L p .669 .701 .871 r
F P
0 g
s
.55623 .37812 m .57613 .40226 L .58118 .40005 L p .667 .701 .872 r
F P
0 g
s
.29939 .60133 m .30892 .56653 L .32017 .57456 L p .893 .704 .641 r
F P
0 g
s
.32017 .57456 m .31089 .60973 L .29939 .60133 L p .893 .704 .641 r
F P
0 g
s
.30318 .51461 m .32387 .48112 L .33258 .489 L p .858 .742 .734 r
F P
0 g
s
.33258 .489 m .31279 .52313 L .30318 .51461 L p .858 .742 .734 r
F P
0 g
s
.57834 .76372 m .57862 .79597 L .55996 .79957 L p .618 .394 .554 r
F P
0 g
s
.57862 .79597 m .57834 .76372 L .59638 .75986 L p .605 .384 .554 r
F P
0 g
s
.34966 .45012 m .37938 .42285 L .38561 .42878 L p .792 .748 .813 r
F P
0 g
s
.41628 .40458 m .38561 .42878 L .37938 .42285 L p .757 .746 .842 r
F P
0 g
s
.38561 .42878 m .41628 .40458 L .42149 .40905 L p .755 .741 .84 r
F P
0 g
s
.62842 .41108 m .59914 .38916 L .59503 .39217 L p .65 .673 .858 r
F P
0 g
s
.59914 .38916 m .62842 .41108 L .6339 .40663 L p .647 .673 .861 r
F P
0 g
s
.72167 .62141 m .72721 .65562 L .7435 .64865 L p .549 .383 .609 r
F P
0 g
s
.7435 .64865 m .73717 .61413 L .72167 .62141 L p .549 .383 .609 r
F P
0 g
s
.72776 .48355 m .75032 .51737 L .76098 .50805 L p .542 .489 .746 r
F P
0 g
s
.76098 .50805 m .73697 .47499 L .72776 .48355 L p .542 .489 .746 r
F P
0 g
s
.49484 .37743 m .47385 .40106 L .46891 .39876 L p .695 .726 .874 r
F P
0 g
s
.47385 .40106 m .49484 .37743 L .49791 .3787 L p .694 .724 .873 r
F P
0 g
s
.74166 .57051 m .75235 .60621 L .76704 .59762 L p .531 .404 .652 r
F P
0 g
s
.76704 .59762 m .75519 .5619 L .74166 .57051 L p .531 .404 .652 r
F P
0 g
s
.58118 .40005 m .55925 .37678 L .55623 .37812 L p .667 .701 .872 r
F P
0 g
s
.55925 .37678 m .58118 .40005 L .58603 .39763 L p .666 .701 .873 r
F P
0 g
s
.67086 .42513 m .63898 .40194 L .6339 .40663 L p .626 .636 .841 r
F P
0 g
s
.63898 .40194 m .67086 .42513 L .67701 .41887 L p .622 .637 .845 r
F P
0 g
s
.70859 .44496 m .67701 .41887 L .67086 .42513 L p .597 .592 .817 r
F P
0 g
s
.45152 .38762 m .42149 .40905 L .41628 .40458 L p .724 .738 .862 r
F P
0 g
s
.42149 .40905 m .45152 .38762 L .45548 .39068 L p .723 .735 .861 r
F P
0 g
s
.3851 .79029 m .38561 .75675 L .40353 .76222 L p .806 .545 .543 r
F P
0 g
s
.40353 .76222 m .40312 .79581 L .3851 .79029 L p .806 .545 .543 r
F P
0 g
s
.64695 .71511 m .64823 .74668 L .63123 .75126 L p .581 .374 .566 r
F P
0 g
s
.64823 .74668 m .64695 .71511 L .66366 .71042 L p .576 .371 .565 r
F P
0 g
s
.49189 .37603 m .46891 .39876 L .46419 .39627 L p .696 .727 .875 r
F P
0 g
s
.46891 .39876 m .49189 .37603 L .49484 .37743 L p .695 .726 .874 r
F P
0 g
s
.6944 .66787 m .6971 .70027 L .71391 .69471 L p .564 .372 .58 r
F P
0 g
s
.71391 .69471 m .71081 .66201 L .6944 .66787 L p .564 .372 .58 r
F P
0 g
s
.30488 .64371 m .31089 .60973 L .32299 .61774 L p .898 .683 .603 r
F P
0 g
s
.32299 .61774 m .31705 .6521 L .30488 .64371 L p .898 .683 .603 r
F P
0 g
s
.58603 .39763 m .56213 .37531 L .55925 .37678 L p .666 .701 .873 r
F P
0 g
s
.56213 .37531 m .58603 .39763 L .59065 .395 L p .664 .7 .874 r
F P
0 g
s
.6339 .40663 m .60298 .38597 L .59914 .38916 L p .647 .673 .861 r
F P
0 g
s
.60298 .38597 m .6339 .40663 L .63898 .40194 L p .645 .674 .863 r
F P
0 g
s
.59638 .75986 m .5968 .79192 L .57862 .79597 L p .605 .384 .554 r
F P
0 g
s
.5968 .79192 m .59638 .75986 L .61398 .75568 L p .593 .376 .555 r
F P
0 g
s
.31572 .47279 m .34266 .44274 L .34966 .45012 L p .83 .755 .78 r
F P
0 g
s
.34966 .45012 m .32387 .48112 L .31572 .47279 L p .83 .755 .78 r
F P
0 g
s
.37938 .42285 m .34966 .45012 L .34266 .44274 L p .795 .754 .816 r
F P
0 g
s
.48907 .3745 m .46419 .39627 L .45971 .39357 L p .697 .729 .875 r
F P
0 g
s
.46419 .39627 m .48907 .3745 L .49189 .37603 L p .696 .727 .875 r
F P
0 g
s
.67701 .41887 m .70859 .44496 L .71558 .43715 L p .589 .592 .823 r
F P
0 g
s
.70859 .44496 m .73697 .47499 L .74537 .46608 L p .559 .541 .791 r
F P
0 g
s
.74537 .46608 m .71558 .43715 L .70859 .44496 L p .559 .541 .791 r
F P
0 g
s
.34266 .44274 m .37366 .41661 L .37938 .42285 L p .795 .754 .816 r
F P
0 g
s
.41148 .39987 m .37938 .42285 L .37366 .41661 L p .759 .75 .844 r
F P
0 g
s
.37938 .42285 m .41148 .39987 L .41628 .40458 L p .757 .746 .842 r
F P
0 g
s
.59065 .395 m .56488 .37372 L .56213 .37531 L p .664 .7 .874 r
F P
0 g
s
.56488 .37372 m .59065 .395 L .59503 .39217 L p .663 .7 .875 r
F P
0 g
s
.75032 .51737 m .76803 .55269 L .78 .54292 L p .514 .436 .705 r
F P
0 g
s
.78 .54292 m .76098 .50805 L .75032 .51737 L p .514 .436 .705 r
F P
0 g
s
.44784 .38438 m .41628 .40458 L .41148 .39987 L p .725 .74 .864 r
F P
0 g
s
.41628 .40458 m .44784 .38438 L .45152 .38762 L p .724 .738 .862 r
F P
0 g
s
.33774 .73529 m .33999 .70187 L .35478 .7094 L p .868 .619 .56 r
F P
0 g
s
.35478 .7094 m .35267 .74315 L .33774 .73529 L p .868 .619 .56 r
F P
0 g
s
.73717 .61413 m .7435 .64865 L .75954 .64103 L p .535 .376 .612 r
F P
0 g
s
.75954 .64103 m .75235 .60621 L .73717 .61413 L p .535 .376 .612 r
F P
0 g
s
.28797 .5491 m .30318 .51461 L .31279 .52313 L p .886 .732 .686 r
F P
0 g
s
.31279 .52313 m .29821 .55805 L .28797 .5491 L p .886 .732 .686 r
F P
0 g
s
.67701 .41887 m .64363 .39705 L .63898 .40194 L p .622 .637 .845 r
F P
0 g
s
.64363 .39705 m .67701 .41887 L .68258 .41237 L p .617 .638 .849 r
F P
0 g
s
.71558 .43715 m .68258 .41237 L .67701 .41887 L p .589 .592 .823 r
F P
0 g
s
.4864 .37286 m .45971 .39357 L .45548 .39068 L p .697 .731 .876 r
F P
0 g
s
.45971 .39357 m .4864 .37286 L .48907 .3745 L p .697 .729 .875 r
F P
0 g
s
.29409 .5056 m .31572 .47279 L .32387 .48112 L p .863 .75 .736 r
F P
0 g
s
.32387 .48112 m .30318 .51461 L .29409 .5056 L p .863 .75 .736 r
F P
0 g
s
.66366 .71042 m .66512 .74199 L .64823 .74668 L p .576 .371 .565 r
F P
0 g
s
.66366 .71042 m .66512 .74199 L .682 .73716 L p .572 .367 .565 r
F P
0 g
s
.682 .73716 m .68035 .70549 L .66366 .71042 L p .572 .367 .565 r
F P
0 g
s
.73697 .47499 m .76098 .50805 L .77071 .4983 L p .526 .485 .754 r
F P
0 g
s
.77071 .4983 m .74537 .46608 L .73697 .47499 L p .526 .485 .754 r
F P
0 g
s
.63898 .40194 m .60652 .38262 L .60298 .38597 L p .645 .674 .863 r
F P
0 g
s
.60652 .38262 m .63898 .40194 L .64363 .39705 L p .642 .674 .865 r
F P
0 g
s
.75519 .5619 m .76704 .59762 L .78104 .58836 L p .512 .395 .657 r
F P
0 g
s
.78104 .58836 m .76803 .55269 L .75519 .5619 L p .512 .395 .657 r
F P
0 g
s
.368 .7838 m .36863 .75036 L .38561 .75675 L p .829 .565 .54 r
F P
0 g
s
.38561 .75675 m .3851 .79029 L .368 .7838 L p .829 .565 .54 r
F P
0 g
s
.31322 .68539 m .31705 .6521 L .32995 .66014 L p .896 .661 .576 r
F P
0 g
s
.32995 .66014 m .32617 .69382 L .31322 .68539 L p .896 .661 .576 r
F P
0 g
s
.71081 .66201 m .71391 .69471 L .73078 .6887 L p .555 .367 .581 r
F P
0 g
s
.73078 .6887 m .72721 .65562 L .71081 .66201 L p .555 .367 .581 r
F P
0 g
s
.28837 .59253 m .29821 .55805 L .30892 .56653 L p .901 .712 .638 r
F P
0 g
s
.30892 .56653 m .29939 .60133 L .28837 .59253 L p .901 .712 .638 r
F P
0 g
s
.61398 .75568 m .61454 .78758 L .5968 .79192 L p .593 .376 .555 r
F P
0 g
s
.61454 .78758 m .61398 .75568 L .63123 .75126 L p .585 .37 .555 r
F P
0 g
s
.59503 .39217 m .56748 .37202 L .56488 .37372 L p .663 .7 .875 r
F P
0 g
s
.56748 .37202 m .59503 .39217 L .59914 .38916 L p .661 .701 .876 r
F P
0 g
s
.48161 .83852 m .48128 .8064 L .50135 .80612 L p .69 .429 .522 r
F P
0 g
s
.50135 .80612 m .50152 .83818 L .48161 .83852 L p .69 .429 .522 r
F P
0 g
s
.50152 .83818 m .50135 .80612 L .52125 .8048 L p .669 .413 .525 r
F P
0 g
s
.46172 .83774 m .46121 .80554 L .48128 .8064 L p .712 .445 .52 r
F P
0 g
s
.48128 .8064 m .48161 .83852 L .46172 .83774 L p .712 .445 .52 r
F P
0 g
s
.52125 .8048 m .52128 .83681 L .50152 .83818 L p .669 .413 .525 r
F P
0 g
s
.52128 .83681 m .52125 .8048 L .54082 .80257 L p .65 .399 .527 r
F P
0 g
s
.48389 .3711 m .45548 .39068 L .45152 .38762 L p .698 .732 .877 r
F P
0 g
s
.45548 .39068 m .48389 .3711 L .4864 .37286 L p .697 .731 .876 r
F P
0 g
s
.44205 .83577 m .44136 .80349 L .46121 .80554 L p .735 .463 .517 r
F P
0 g
s
.46121 .80554 m .46172 .83774 L .44205 .83577 L p .735 .463 .517 r
F P
0 g
s
.37366 .41661 m .4071 .39494 L .41148 .39987 L p .759 .75 .844 r
F P
0 g
s
.44447 .38098 m .41148 .39987 L .4071 .39494 L p .726 .743 .866 r
F P
0 g
s
.41148 .39987 m .44447 .38098 L .44784 .38438 L p .725 .74 .864 r
F P
0 g
s
.30816 .46402 m .33625 .43497 L .34266 .44274 L p .834 .762 .783 r
F P
0 g
s
.34266 .44274 m .31572 .47279 L .30816 .46402 L p .834 .762 .783 r
F P
0 g
s
.37366 .41661 m .34266 .44274 L .33625 .43497 L p .797 .76 .819 r
F P
0 g
s
.33625 .43497 m .36848 .41009 L .37366 .41661 L p .797 .76 .819 r
F P
0 g
s
.4071 .39494 m .37366 .41661 L .36848 .41009 L p .76 .754 .847 r
F P
0 g
s
.59914 .38916 m .56991 .3702 L .56748 .37202 L p .661 .701 .876 r
F P
0 g
s
.56991 .3702 m .59914 .38916 L .60298 .38597 L p .66 .701 .877 r
F P
0 g
s
.54082 .80257 m .54075 .83454 L .52128 .83681 L p .65 .399 .527 r
F P
0 g
s
.54075 .83454 m .54082 .80257 L .55996 .79957 L p .632 .387 .529 r
F P
0 g
s
.52601 .35767 m .52539 .38379 L .5218 .38368 L p .676 .721 .883 r
F P
0 g
s
.52539 .38379 m .52601 .35767 L .52721 .35766 L p .676 .721 .883 r
F P
0 g
s
.52721 .35766 m .52899 .38376 L .52539 .38379 L p .676 .721 .883 r
F P
0 g
s
.52899 .38376 m .52721 .35766 L .52842 .3576 L p .675 .72 .883 r
F P
0 g
s
.52842 .3576 m .53257 .38357 L .52899 .38376 L p .675 .72 .883 r
F P
0 g
s
.68258 .41237 m .71558 .43715 L .7218 .42909 L p .581 .593 .829 r
F P
0 g
s
.71558 .43715 m .74537 .46608 L .75285 .45686 L p .545 .539 .799 r
F P
0 g
s
.75285 .45686 m .7218 .42909 L .71558 .43715 L p .545 .539 .799 r
F P
0 g
s
.5248 .35763 m .5218 .38368 L .51823 .38341 L p .677 .722 .883 r
F P
0 g
s
.5218 .38368 m .5248 .35763 L .52601 .35767 L p .676 .721 .883 r
F P
0 g
s
.53257 .38357 m .52842 .3576 L .52961 .35748 L p .674 .72 .883 r
F P
0 g
s
.52961 .35748 m .53614 .38323 L .53257 .38357 L p .674 .72 .883 r
F P
0 g
s
.64363 .39705 m .60975 .37913 L .60652 .38262 L p .642 .674 .865 r
F P
0 g
s
.60975 .37913 m .64363 .39705 L .64783 .39196 L p .639 .675 .868 r
F P
0 g
s
.68258 .41237 m .64783 .39196 L .64363 .39705 L p .617 .638 .849 r
F P
0 g
s
.5236 .35754 m .51823 .38341 L .51468 .38299 L p .677 .722 .883 r
F P
0 g
s
.51823 .38341 m .5236 .35754 L .5248 .35763 L p .677 .722 .883 r
F P
0 g
s
.29329 .63499 m .29939 .60133 L .31089 .60973 L p .908 .692 .598 r
F P
0 g
s
.31089 .60973 m .30488 .64371 L .29329 .63499 L p .908 .692 .598 r
F P
0 g
s
.53614 .38323 m .52961 .35748 L .53079 .35731 L p .674 .719 .883 r
F P
0 g
s
.53079 .35731 m .53966 .38275 L .53614 .38323 L p .674 .719 .883 r
F P
0 g
s
.42277 .8326 m .42193 .80023 L .44136 .80349 L p .758 .481 .514 r
F P
0 g
s
.44136 .80349 m .44205 .83577 L .42277 .8326 L p .758 .481 .514 r
F P
0 g
s
.48155 .36924 m .45152 .38762 L .44784 .38438 L p .699 .733 .878 r
F P
0 g
s
.45152 .38762 m .48155 .36924 L .48389 .3711 L p .698 .732 .877 r
F P
0 g
s
.64783 .39196 m .68258 .41237 L .68753 .40565 L p .611 .639 .853 r
F P
0 g
s
.7218 .42909 m .68753 .40565 L .68258 .41237 L p .581 .593 .829 r
F P
0 g
s
.52242 .3574 m .51468 .38299 L .51119 .38242 L p .678 .723 .883 r
F P
0 g
s
.51468 .38299 m .52242 .3574 L .5236 .35754 L p .677 .722 .883 r
F P
0 g
s
.68035 .70549 m .682 .73716 L .69895 .73215 L p .567 .364 .565 r
F P
0 g
s
.69895 .73215 m .6971 .70027 L .68035 .70549 L p .567 .364 .565 r
F P
0 g
s
.53966 .38275 m .53079 .35731 L .53196 .3571 L p .673 .719 .883 r
F P
0 g
s
.53196 .3571 m .54313 .38211 L .53966 .38275 L p .673 .719 .883 r
F P
0 g
s
.75235 .60621 m .75954 .64103 L .77513 .63271 L p .517 .366 .616 r
F P
0 g
s
.77513 .63271 m .76704 .59762 L .75235 .60621 L p .517 .366 .616 r
F P
0 g
s
.52124 .35721 m .51119 .38242 L .50775 .3817 L p .679 .724 .884 r
F P
0 g
s
.51119 .38242 m .52124 .35721 L .52242 .3574 L p .678 .723 .883 r
F P
0 g
s
.63123 .75126 m .63193 .78306 L .61454 .78758 L p .585 .37 .555 r
F P
0 g
s
.63193 .78306 m .63123 .75126 L .64823 .74668 L p .578 .365 .555 r
F P
0 g
s
.54313 .38211 m .53196 .3571 L .5331 .35683 L p .673 .719 .884 r
F P
0 g
s
.5331 .35683 m .54654 .38132 L .54313 .38211 L p .673 .719 .884 r
F P
0 g
s
.52009 .35696 m .50775 .3817 L .50438 .38084 L p .679 .724 .884 r
F P
0 g
s
.50775 .3817 m .52009 .35696 L .52124 .35721 L p .679 .724 .884 r
F P
0 g
s
.55996 .79957 m .55984 .83152 L .54075 .83454 L p .632 .387 .529 r
F P
0 g
s
.55984 .83152 m .55996 .79957 L .57862 .79597 L p .616 .376 .531 r
F P
0 g
s
.60298 .38597 m .57217 .36829 L .56991 .3702 L p .66 .701 .877 r
F P
0 g
s
.57217 .36829 m .60298 .38597 L .60652 .38262 L p .658 .701 .878 r
F P
0 g
s
.76098 .50805 m .78 .54292 L .79094 .53264 L p .492 .428 .712 r
F P
0 g
s
.79094 .53264 m .77071 .4983 L .76098 .50805 L p .492 .428 .712 r
F P
0 g
s
.54654 .38132 m .5331 .35683 L .53421 .35651 L p .672 .719 .884 r
F P
0 g
s
.53421 .35651 m .54986 .38039 L .54654 .38132 L p .672 .719 .884 r
F P
0 g
s
.72721 .65562 m .73078 .6887 L .7476 .68215 L p .543 .36 .583 r
F P
0 g
s
.7476 .68215 m .7435 .64865 L .72721 .65562 L p .543 .36 .583 r
F P
0 g
s
.51897 .35667 m .50438 .38084 L .5011 .37984 L p .68 .725 .884 r
F P
0 g
s
.50438 .38084 m .51897 .35667 L .52009 .35696 L p .679 .724 .884 r
F P
0 g
s
.3238 .72692 m .32617 .69382 L .33999 .70187 L p .886 .636 .555 r
F P
0 g
s
.33999 .70187 m .33774 .73529 L .3238 .72692 L p .886 .636 .555 r
F P
0 g
s
.36848 .41009 m .40317 .3898 L .4071 .39494 L p .76 .754 .847 r
F P
0 g
s
.44142 .37743 m .4071 .39494 L .40317 .3898 L p .726 .746 .867 r
F P
0 g
s
.4071 .39494 m .44142 .37743 L .44447 .38098 L p .726 .743 .866 r
F P
0 g
s
.54986 .38039 m .53421 .35651 L .53529 .35615 L p .672 .718 .884 r
F P
0 g
s
.53529 .35615 m .5531 .37932 L .54986 .38039 L p .672 .718 .884 r
F P
0 g
s
.27817 .53966 m .29409 .5056 L .30318 .51461 L p .892 .74 .687 r
F P
0 g
s
.30318 .51461 m .28797 .5491 L .27817 .53966 L p .892 .74 .687 r
F P
0 g
s
.28553 .49609 m .30816 .46402 L .31572 .47279 L p .868 .758 .739 r
F P
0 g
s
.31572 .47279 m .29409 .5056 L .28553 .49609 L p .868 .758 .739 r
F P
0 g
s
.3519 .77646 m .35267 .74315 L .36863 .75036 L p .85 .584 .537 r
F P
0 g
s
.36863 .75036 m .368 .7838 L .3519 .77646 L p .85 .584 .537 r
F P
0 g
s
.74537 .46608 m .77071 .4983 L .77938 .48818 L p .507 .48 .762 r
F P
0 g
s
.77938 .48818 m .75285 .45686 L .74537 .46608 L p .507 .48 .762 r
F P
0 g
s
.51787 .35633 m .5011 .37984 L .49791 .3787 L p .68 .726 .884 r
F P
0 g
s
.5011 .37984 m .51787 .35633 L .51897 .35667 L p .68 .725 .884 r
F P
0 g
s
.47938 .36728 m .44784 .38438 L .44447 .38098 L p .699 .735 .879 r
F P
0 g
s
.44784 .38438 m .47938 .36728 L .48155 .36924 L p .699 .733 .878 r
F P
0 g
s
.76803 .55269 m .78104 .58836 L .79413 .57846 L p .488 .385 .663 r
F P
0 g
s
.79413 .57846 m .78 .54292 L .76803 .55269 L p .488 .385 .663 r
F P
0 g
s
.53529 .35615 m .5531 .37932 L .55623 .37812 L p .671 .718 .884 r
F P
0 g
s
.40407 .82828 m .40312 .79581 L .42193 .80023 L p .781 .501 .511 r
F P
0 g
s
.42193 .80023 m .42277 .8326 L .40407 .82828 L p .781 .501 .511 r
F P
0 g
s
.51681 .35594 m .49791 .3787 L .49484 .37743 L p .68 .726 .885 r
F P
0 g
s
.49791 .3787 m .51681 .35594 L .51787 .35633 L p .68 .726 .884 r
F P
0 g
s
.64783 .39196 m .61265 .3755 L .60975 .37913 L p .639 .675 .868 r
F P
0 g
s
.61265 .3755 m .64783 .39196 L .65155 .38671 L p .636 .676 .871 r
F P
0 g
s
.68753 .40565 m .65155 .38671 L .64783 .39196 L p .611 .639 .853 r
F P
0 g
s
.33045 .42685 m .36386 .40329 L .36848 .41009 L p .799 .766 .823 r
F P
0 g
s
.36848 .41009 m .33625 .43497 L .33045 .42685 L p .799 .766 .823 r
F P
0 g
s
.40317 .3898 m .36848 .41009 L .36386 .40329 L p .761 .758 .85 r
F P
0 g
s
.60652 .38262 m .57425 .36628 L .57217 .36829 L p .658 .701 .878 r
F P
0 g
s
.57425 .36628 m .60652 .38262 L .60975 .37913 L p .657 .701 .879 r
F P
0 g
s
.55623 .37812 m .53633 .35574 L .53529 .35615 L p .671 .718 .884 r
F P
0 g
s
.53633 .35574 m .55623 .37812 L .55925 .37678 L p .67 .718 .884 r
F P
0 g
s
.57862 .79597 m .57849 .82792 L .55984 .83152 L p .616 .376 .531 r
F P
0 g
s
.57849 .82792 m .57862 .79597 L .5968 .79192 L p .602 .367 .533 r
F P
0 g
s
.27776 .58333 m .28797 .5491 L .29821 .55805 L p .907 .719 .636 r
F P
0 g
s
.29821 .55805 m .28837 .59253 L .27776 .58333 L p .907 .719 .636 r
F P
0 g
s
.30102 .67664 m .30488 .64371 L .31705 .6521 L p .908 .672 .57 r
F P
0 g
s
.31705 .6521 m .31322 .68539 L .30102 .67664 L p .908 .672 .57 r
F P
0 g
s
.51578 .35551 m .49484 .37743 L .49189 .37603 L p .681 .727 .885 r
F P
0 g
s
.49484 .37743 m .51578 .35551 L .51681 .35594 L p .68 .726 .885 r
F P
0 g
s
.30122 .4548 m .33045 .42685 L .33625 .43497 L p .837 .77 .787 r
F P
0 g
s
.33625 .43497 m .30816 .46402 L .30122 .4548 L p .837 .77 .787 r
F P
0 g
s
.55925 .37678 m .53734 .35529 L .53633 .35574 L p .67 .718 .884 r
F P
0 g
s
.53734 .35529 m .55925 .37678 L .56213 .37531 L p .67 .718 .885 r
F P
0 g
s
.6971 .70027 m .69895 .73215 L .716 .72689 L p .56 .359 .565 r
F P
0 g
s
.716 .72689 m .71391 .69471 L .6971 .70027 L p .56 .359 .565 r
F P
0 g
s
.64823 .74668 m .64908 .77845 L .63193 .78306 L p .578 .365 .555 r
F P
0 g
s
.64908 .77845 m .64823 .74668 L .66512 .74199 L p .572 .361 .555 r
F P
0 g
s
.4774 .36523 m .44447 .38098 L .44142 .37743 L p .699 .736 .88 r
F P
0 g
s
.44447 .38098 m .4774 .36523 L .47938 .36728 L p .699 .735 .879 r
F P
0 g
s
.65155 .38671 m .68753 .40565 L .69184 .39875 L p .606 .64 .858 r
F P
0 g
s
.68753 .40565 m .7218 .42909 L .72722 .42081 L p .571 .593 .836 r
F P
0 g
s
.72722 .42081 m .69184 .39875 L .68753 .40565 L p .571 .593 .836 r
F P
0 g
s
.5148 .35504 m .49189 .37603 L .48907 .3745 L p .681 .728 .885 r
F P
0 g
s
.49189 .37603 m .5148 .35504 L .51578 .35551 L p .681 .727 .885 r
F P
0 g
s
.7218 .42909 m .75285 .45686 L .75935 .44738 L p .531 .537 .807 r
F P
0 g
s
.75935 .44738 m .72722 .42081 L .7218 .42909 L p .531 .537 .807 r
F P
0 g
s
.36386 .40329 m .3997 .38448 L .40317 .3898 L p .761 .758 .85 r
F P
0 g
s
.43869 .37375 m .40317 .3898 L .3997 .38448 L p .727 .748 .869 r
F P
0 g
s
.40317 .3898 m .43869 .37375 L .44142 .37743 L p .726 .746 .867 r
F P
0 g
s
.56213 .37531 m .5383 .35479 L .53734 .35529 L p .67 .718 .885 r
F P
0 g
s
.5383 .35479 m .56213 .37531 L .56488 .37372 L p .669 .718 .885 r
F P
0 g
s
.60975 .37913 m .57614 .36418 L .57425 .36628 L p .657 .701 .879 r
F P
0 g
s
.57614 .36418 m .60975 .37913 L .61265 .3755 L p .656 .702 .881 r
F P
0 g
s
.51386 .35452 m .48907 .3745 L .4864 .37286 L p .681 .728 .885 r
F P
0 g
s
.48907 .3745 m .51386 .35452 L .5148 .35504 L p .681 .728 .885 r
F P
0 g
s
.76704 .59762 m .77513 .63271 L .79003 .62367 L p .494 .354 .62 r
F P
0 g
s
.79003 .62367 m .78104 .58836 L .76704 .59762 L p .494 .354 .62 r
F P
0 g
s
.7435 .64865 m .7476 .68215 L .76421 .67497 L p .527 .35 .585 r
F P
0 g
s
.76421 .67497 m .75954 .64103 L .7435 .64865 L p .527 .35 .585 r
F P
0 g
s
.56488 .37372 m .53921 .35426 L .5383 .35479 L p .669 .718 .885 r
F P
0 g
s
.53921 .35426 m .56488 .37372 L .56748 .37202 L p .669 .718 .885 r
F P
0 g
s
.38612 .82286 m .3851 .79029 L .40312 .79581 L p .804 .52 .508 r
F P
0 g
s
.40312 .79581 m .40407 .82828 L .38612 .82286 L p .804 .52 .508 r
F P
0 g
s
.5968 .79192 m .59669 .82388 L .57849 .82792 L p .602 .367 .533 r
F P
0 g
s
.59669 .82388 m .5968 .79192 L .61454 .78758 L p .591 .36 .535 r
F P
0 g
s
.65155 .38671 m .61522 .37175 L .61265 .3755 L p .636 .676 .871 r
F P
0 g
s
.61522 .37175 m .65155 .38671 L .65478 .38131 L p .633 .677 .874 r
F P
0 g
s
.69184 .39875 m .65478 .38131 L .65155 .38671 L p .606 .64 .858 r
F P
0 g
s
.28215 .62597 m .28837 .59253 L .29939 .60133 L p .916 .698 .593 r
F P
0 g
s
.29939 .60133 m .29329 .63499 L .28215 .62597 L p .916 .698 .593 r
F P
0 g
s
.51298 .35397 m .4864 .37286 L .48389 .3711 L p .682 .729 .886 r
F P
0 g
s
.4864 .37286 m .51298 .35397 L .51386 .35452 L p .681 .728 .885 r
F P
0 g
s
.47561 .36309 m .44142 .37743 L .43869 .37375 L p .699 .737 .88 r
F P
0 g
s
.44142 .37743 m .47561 .36309 L .4774 .36523 L p .699 .736 .88 r
F P
0 g
s
.56748 .37202 m .54007 .35368 L .53921 .35426 L p .669 .718 .885 r
F P
0 g
s
.54007 .35368 m .56748 .37202 L .56991 .3702 L p .668 .718 .886 r
F P
0 g
s
.77071 .4983 m .79094 .53264 L .80066 .52193 L p .466 .418 .72 r
F P
0 g
s
.80066 .52193 m .77938 .48818 L .77071 .4983 L p .466 .418 .72 r
F P
0 g
s
.32531 .4184 m .35983 .39625 L .36386 .40329 L p .801 .772 .827 r
F P
0 g
s
.36386 .40329 m .33045 .42685 L .32531 .4184 L p .801 .772 .827 r
F P
0 g
s
.3997 .38448 m .36386 .40329 L .35983 .39625 L p .762 .763 .853 r
F P
0 g
s
.33682 .76845 m .33774 .73529 L .35267 .74315 L p .869 .603 .533 r
F P
0 g
s
.35267 .74315 m .3519 .77646 L .33682 .76845 L p .869 .603 .533 r
F P
0 g
s
.27753 .48608 m .30122 .4548 L .30816 .46402 L p .873 .767 .742 r
F P
0 g
s
.30816 .46402 m .28553 .49609 L .27753 .48608 L p .873 .767 .742 r
F P
0 g
s
.61265 .3755 m .57783 .362 L .57614 .36418 L p .656 .702 .881 r
F P
0 g
s
.57783 .362 m .61265 .3755 L .61522 .37175 L p .654 .702 .882 r
F P
0 g
s
.51215 .35337 m .48389 .3711 L .48155 .36924 L p .682 .729 .886 r
F P
0 g
s
.48389 .3711 m .51215 .35337 L .51298 .35397 L p .682 .729 .886 r
F P
0 g
s
.66512 .74199 m .6661 .77378 L .64908 .77845 L p .572 .361 .555 r
F P
0 g
s
.66512 .74199 m .6661 .77378 L .68309 .76906 L p .568 .357 .554 r
F P
0 g
s
.68309 .76906 m .682 .73716 L .66512 .74199 L p .568 .357 .554 r
F P
0 g
s
.75285 .45686 m .77938 .48818 L .78688 .47777 L p .485 .474 .771 r
F P
0 g
s
.78688 .47777 m .75935 .44738 L .75285 .45686 L p .485 .474 .771 r
F P
0 g
s
.26881 .52972 m .28553 .49609 L .29409 .5056 L p .897 .748 .688 r
F P
0 g
s
.29409 .5056 m .27817 .53966 L .26881 .52972 L p .897 .748 .688 r
F P
0 g
s
.31076 .71816 m .31322 .68539 L .32617 .69382 L p .901 .65 .55 r
F P
0 g
s
.32617 .69382 m .3238 .72692 L .31076 .71816 L p .901 .65 .55 r
F P
0 g
s
.71391 .69471 m .716 .72689 L .73311 .72126 L p .551 .352 .565 r
F P
0 g
s
.73311 .72126 m .73078 .6887 L .71391 .69471 L p .551 .352 .565 r
F P
0 g
s
.56991 .3702 m .54087 .35307 L .54007 .35368 L p .668 .718 .886 r
F P
0 g
s
.54087 .35307 m .56991 .3702 L .57217 .36829 L p .668 .718 .886 r
F P
0 g
s
.35983 .39625 m .39671 .37898 L .3997 .38448 L p .762 .763 .853 r
F P
0 g
s
.43631 .36994 m .3997 .38448 L .39671 .37898 L p .727 .751 .871 r
F P
0 g
s
.3997 .38448 m .43631 .36994 L .43869 .37375 L p .727 .748 .869 r
F P
0 g
s
.78 .54292 m .79413 .57846 L .80608 .56797 L p .46 .371 .669 r
F P
0 g
s
.80608 .56797 m .79094 .53264 L .78 .54292 L p .46 .371 .669 r
F P
0 g
s
.65478 .38131 m .69184 .39875 L .69547 .39171 L p .6 .641 .863 r
F P
0 g
s
.69184 .39875 m .72722 .42081 L .73179 .41235 L p .561 .593 .843 r
F P
0 g
s
.73179 .41235 m .69547 .39171 L .69184 .39875 L p .561 .593 .843 r
F P
0 g
s
.51138 .35274 m .48155 .36924 L .47938 .36728 L p .682 .73 .887 r
F P
0 g
s
.48155 .36924 m .51138 .35274 L .51215 .35337 L p .682 .729 .886 r
F P
0 g
s
.47402 .36088 m .43869 .37375 L .43631 .36994 L p .7 .739 .882 r
F P
0 g
s
.43869 .37375 m .47402 .36088 L .47561 .36309 L p .699 .737 .88 r
F P
0 g
s
.29495 .44517 m .32531 .4184 L .33045 .42685 L p .84 .778 .792 r
F P
0 g
s
.33045 .42685 m .30122 .4548 L .29495 .44517 L p .84 .778 .792 r
F P
0 g
s
.61454 .78758 m .61449 .81956 L .59669 .82388 L p .591 .36 .535 r
F P
0 g
s
.61449 .81956 m .61454 .78758 L .63193 .78306 L p .581 .354 .536 r
F P
0 g
s
.57217 .36829 m .54162 .35243 L .54087 .35307 L p .668 .718 .886 r
F P
0 g
s
.54162 .35243 m .57217 .36829 L .57425 .36628 L p .667 .718 .887 r
F P
0 g
s
.65478 .38131 m .61743 .3679 L .61522 .37175 L p .633 .677 .874 r
F P
0 g
s
.61743 .3679 m .65478 .38131 L .65749 .37579 L p .63 .678 .876 r
F P
0 g
s
.69547 .39171 m .65749 .37579 L .65478 .38131 L p .6 .641 .863 r
F P
0 g
s
.61522 .37175 m .57931 .35976 L .57783 .362 L p .654 .702 .882 r
F P
0 g
s
.57931 .35976 m .61522 .37175 L .61743 .3679 L p .653 .703 .883 r
F P
0 g
s
.26748 .57369 m .27817 .53966 L .28797 .5491 L p .913 .725 .634 r
F P
0 g
s
.28797 .5491 m .27776 .58333 L .26748 .57369 L p .913 .725 .634 r
F P
0 g
s
.72722 .42081 m .75935 .44738 L .7648 .43772 L p .514 .535 .815 r
F P
0 g
s
.7648 .43772 m .73179 .41235 L .72722 .42081 L p .514 .535 .815 r
F P
0 g
s
.51066 .35208 m .47938 .36728 L .4774 .36523 L p .682 .731 .887 r
F P
0 g
s
.47938 .36728 m .51066 .35208 L .51138 .35274 L p .682 .73 .887 r
F P
0 g
s
.36902 .81645 m .368 .7838 L .3851 .79029 L p .826 .54 .504 r
F P
0 g
s
.3851 .79029 m .38612 .82286 L .36902 .81645 L p .826 .54 .504 r
F P
0 g
s
.2894 .66766 m .29329 .63499 L .30488 .64371 L p .918 .68 .564 r
F P
0 g
s
.30488 .64371 m .30102 .67664 L .2894 .66766 L p .918 .68 .564 r
F P
0 g
s
.57425 .36628 m .5423 .35175 L .54162 .35243 L p .667 .718 .887 r
F P
0 g
s
.5423 .35175 m .57425 .36628 L .57614 .36418 L p .667 .718 .887 r
F P
0 g
s
.75954 .64103 m .76421 .67497 L .7804 .66708 L p .506 .338 .586 r
F P
0 g
s
.7804 .66708 m .77513 .63271 L .75954 .64103 L p .506 .338 .586 r
F P
0 g
s
.39671 .37898 m .43428 .36603 L .43631 .36994 L p .727 .751 .871 r
F P
0 g
s
.47265 .3586 m .43631 .36994 L .43428 .36603 L p .699 .74 .883 r
F P
0 g
s
.43631 .36994 m .47265 .3586 L .47402 .36088 L p .7 .739 .882 r
F P
0 g
s
.51001 .35139 m .4774 .36523 L .47561 .36309 L p .682 .731 .887 r
F P
0 g
s
.4774 .36523 m .51001 .35139 L .51066 .35208 L p .682 .731 .887 r
F P
0 g
s
.78104 .58836 m .79003 .62367 L .80399 .61392 L p .466 .339 .623 r
F P
0 g
s
.80399 .61392 m .79413 .57846 L .78104 .58836 L p .466 .339 .623 r
F P
0 g
s
.682 .73716 m .68309 .76906 L .70012 .76424 L p .562 .352 .553 r
F P
0 g
s
.70012 .76424 m .69895 .73215 L .682 .73716 L p .562 .352 .553 r
F P
0 g
s
.32086 .40965 m .35641 .38899 L .35983 .39625 L p .802 .779 .832 r
F P
0 g
s
.35983 .39625 m .32531 .4184 L .32086 .40965 L p .802 .779 .832 r
F P
0 g
s
.39671 .37898 m .35983 .39625 L .35641 .38899 L p .762 .767 .857 r
F P
0 g
s
.35641 .38899 m .39422 .37334 L .39671 .37898 L p .762 .767 .857 r
F P
0 g
s
.43428 .36603 m .39671 .37898 L .39422 .37334 L p .727 .753 .874 r
F P
0 g
s
.57614 .36418 m .54292 .35105 L .5423 .35175 L p .667 .718 .887 r
F P
0 g
s
.54292 .35105 m .57614 .36418 L .57783 .362 L p .666 .718 .888 r
F P
0 g
s
.4826 .86852 m .48161 .83852 L .50152 .83818 L p .684 .394 .477 r
F P
0 g
s
.50152 .83818 m .50205 .86823 L .4826 .86852 L p .684 .394 .477 r
F P
0 g
s
.50205 .86823 m .50152 .83818 L .52128 .83681 L p .663 .38 .481 r
F P
0 g
s
.61743 .3679 m .58059 .35745 L .57931 .35976 L p .653 .703 .883 r
F P
0 g
s
.58059 .35745 m .61743 .3679 L .61927 .36395 L p .652 .703 .885 r
F P
0 g
s
.65749 .37579 m .61927 .36395 L .61743 .3679 L p .63 .678 .876 r
F P
0 g
s
.73078 .6887 m .73311 .72126 L .7502 .71515 L p .538 .343 .564 r
F P
0 g
s
.7502 .71515 m .7476 .68215 L .73078 .6887 L p .538 .343 .564 r
F P
0 g
s
.4632 .86774 m .46172 .83774 L .48161 .83852 L p .706 .41 .473 r
F P
0 g
s
.48161 .83852 m .4826 .86852 L .4632 .86774 L p .706 .41 .473 r
F P
0 g
s
.52128 .83681 m .52138 .86698 L .50205 .86823 L p .663 .38 .481 r
F P
0 g
s
.52138 .86698 m .52128 .83681 L .54075 .83454 L p .644 .367 .486 r
F P
0 g
s
.63193 .78306 m .63195 .81509 L .61449 .81956 L p .581 .354 .536 r
F P
0 g
s
.63195 .81509 m .63193 .78306 L .64908 .77845 L p .573 .349 .537 r
F P
0 g
s
.50943 .35068 m .47561 .36309 L .47402 .36088 L p .682 .732 .888 r
F P
0 g
s
.47561 .36309 m .50943 .35068 L .51001 .35139 L p .682 .731 .887 r
F P
0 g
s
.61927 .36395 m .65749 .37579 L .65967 .37017 L p .628 .679 .879 r
F P
0 g
s
.65749 .37579 m .69547 .39171 L .6984 .38454 L p .594 .642 .868 r
F P
0 g
s
.6984 .38454 m .65967 .37017 L .65749 .37579 L p .594 .642 .868 r
F P
0 g
s
.69547 .39171 m .73179 .41235 L .73546 .40377 L p .551 .593 .85 r
F P
0 g
s
.73546 .40377 m .6984 .38454 L .69547 .39171 L p .551 .593 .85 r
F P
0 g
s
.27134 .61662 m .27776 .58333 L .28837 .59253 L p .922 .704 .59 r
F P
0 g
s
.28837 .59253 m .28215 .62597 L .27134 .61662 L p .922 .704 .59 r
F P
0 g
s
.57783 .362 m .54347 .35032 L .54292 .35105 L p .666 .718 .888 r
F P
0 g
s
.54347 .35032 m .57783 .362 L .57931 .35976 L p .666 .718 .888 r
F P
0 g
s
.27016 .47559 m .29495 .44517 L .30122 .4548 L p .877 .777 .747 r
F P
0 g
s
.30122 .4548 m .27753 .48608 L .27016 .47559 L p .877 .777 .747 r
F P
0 g
s
.444 .86585 m .44205 .83577 L .46172 .83774 L p .729 .427 .468 r
F P
0 g
s
.46172 .83774 m .4632 .86774 L .444 .86585 L p .729 .427 .468 r
F P
0 g
s
.32271 .75991 m .3238 .72692 L .33774 .73529 L p .887 .62 .529 r
F P
0 g
s
.33774 .73529 m .33682 .76845 L .32271 .75991 L p .887 .62 .529 r
F P
0 g
s
.54075 .83454 m .54048 .86487 L .52138 .86698 L p .644 .367 .486 r
F P
0 g
s
.54048 .86487 m .54075 .83454 L .55984 .83152 L p .626 .356 .489 r
F P
0 g
s
.77938 .48818 m .80066 .52193 L .80903 .51087 L p .435 .406 .727 r
F P
0 g
s
.80903 .51087 m .78688 .47777 L .77938 .48818 L p .435 .406 .727 r
F P
0 g
s
.39422 .37334 m .43262 .36202 L .43428 .36603 L p .727 .753 .874 r
F P
0 g
s
.47149 .35626 m .43428 .36603 L .43262 .36202 L p .699 .741 .884 r
F P
0 g
s
.43428 .36603 m .47149 .35626 L .47265 .3586 L p .699 .74 .883 r
F P
0 g
s
.75935 .44738 m .78688 .47777 L .79312 .46715 L p .46 .467 .779 r
F P
0 g
s
.79312 .46715 m .7648 .43772 L .75935 .44738 L p .46 .467 .779 r
F P
0 g
s
.50892 .34994 m .47402 .36088 L .47265 .3586 L p .682 .732 .888 r
F P
0 g
s
.47402 .36088 m .50892 .34994 L .50943 .35068 L p .682 .732 .888 r
F P
0 g
s
.28939 .43515 m .32086 .40965 L .32531 .4184 L p .843 .787 .797 r
F P
0 g
s
.32531 .4184 m .29495 .44517 L .28939 .43515 L p .843 .787 .797 r
F P
0 g
s
.25991 .51925 m .27753 .48608 L .28553 .49609 L p .902 .757 .691 r
F P
0 g
s
.28553 .49609 m .26881 .52972 L .25991 .51925 L p .902 .757 .691 r
F P
0 g
s
.57931 .35976 m .54395 .34957 L .54347 .35032 L p .666 .718 .888 r
F P
0 g
s
.54395 .34957 m .57931 .35976 L .58059 .35745 L p .665 .719 .889 r
F P
0 g
s
.29846 .70915 m .30102 .67664 L .31322 .68539 L p .913 .662 .545 r
F P
0 g
s
.31322 .68539 m .31076 .71816 L .29846 .70915 L p .913 .662 .545 r
F P
0 g
s
.61927 .36395 m .58164 .35509 L .58059 .35745 L p .652 .703 .885 r
F P
0 g
s
.58164 .35509 m .61927 .36395 L .62074 .35994 L p .651 .704 .886 r
F P
0 g
s
.65967 .37017 m .62074 .35994 L .61927 .36395 L p .628 .679 .879 r
F P
0 g
s
.79094 .53264 m .80608 .56797 L .81669 .55696 L p .426 .355 .674 r
F P
0 g
s
.81669 .55696 m .80066 .52193 L .79094 .53264 L p .426 .355 .674 r
F P
0 g
s
.52124 .35721 m .52009 .35696 L p .52543 .34551 L .672 .728 .891 r
F P
0 g
s
.52562 .3451 m .526 .34573 L .52543 .34551 L .672 .728 .891 r
F
.52592 .34446 m .52479 .34425 L .52516 .34472 L F
.50821 .34111 m .52463 .3446 L p .52479 .34425 L F P
0 g
s
.52479 .34425 m .52168 .34381 L .51715 .34291 L .672 .728 .891 r
F
.5154 .34247 m .51715 .34291 L .50821 .34111 L F
.52479 .34425 m .51715 .34291 L .5154 .34247 L F
.52463 .3446 m .52516 .34472 L p .52479 .34425 L F P
0 g
s
.52516 .34471 m .51541 .34264 L p .52549 .34458 L .672 .728 .891 r
F P
0 g
s
.51541 .34264 m .50821 .34111 L p .51727 .34293 L .672 .728 .891 r
F P
0 g
s
.51541 .34264 m .51727 .34293 L .52549 .34458 L .672 .728 .891 r
F
.52479 .3443 m .52242 .34396 L .52479 .34425 L F
.52242 .34396 m .50789 .3419 L .52168 .34381 L F
.52242 .34396 m .52168 .34381 L .52479 .34425 L F
.52516 .34472 m .52632 .34496 L p .52592 .34446 L F P
0 g
s
.52632 .34496 m .52516 .34472 L p .5258 .34471 L .672 .728 .891 r
F P
0 g
s
.52613 .34473 m .52609 .34507 L .52606 .34464 L .672 .728 .891 r
F
.52609 .34507 m .52606 .34527 L .52606 .34506 L F
.52609 .34507 m .52606 .34506 L .52606 .34464 L F
.5255 .34462 m .52546 .34439 L .52592 .34446 L F
.52592 .34446 m .52479 .3443 L .52479 .34425 L F
.52613 .34473 m .52606 .34464 L .52606 .34415 L F
.5268 .34381 m .52671 .34401 L p .52627 .3437 L F P
0 g
s
.52671 .34401 m .52609 .34551 L p .52623 .34401 L .672 .728 .891 r
F P
0 g
s
.52609 .34551 m .52603 .3455 L .52623 .34401 L .672 .728 .891 r
F
.52606 .34415 m .52606 .34484 L .5258 .34471 L F
.52592 .34446 m .52594 .34449 L .52619 .34452 L F
.52594 .34449 m .52632 .34496 L .52619 .34452 L F
.53146 .33256 m .53027 .33236 L p .52622 .34352 L F P
0 g
s
.52619 .34452 m .52632 .34496 L .52629 .34461 L .672 .728 .891 r
F
.52613 .34472 m .52632 .34496 L .52557 .3446 L F
.52671 .34401 m .52623 .34401 L .52627 .3437 L F
.53146 .33256 m .5268 .34381 L p .52627 .3437 L F P
0 g
s
.52878 .33864 m .52607 .34416 L .52721 .34221 L .672 .728 .891 r
F
.52607 .34416 m .52592 .34446 L .52608 .34417 L F
.52607 .34416 m .52608 .34417 L .52721 .34221 L F
.52632 .34496 m .52655 .34501 L p .52629 .34461 L F P
0 g
s
.52655 .34501 m .52683 .34507 L p .52659 .34486 L .672 .728 .891 r
F P
0 g
s
.52629 .34461 m .52655 .34501 L .52659 .34486 L .672 .728 .891 r
F
.52671 .34401 m .52941 .3375 L p .52639 .34409 L F P
0 g
s
.52941 .3375 m .53146 .33256 L p .52875 .33871 L .672 .728 .891 r
F P
0 g
s
.52639 .34409 m .52941 .3375 L .52875 .33871 L .672 .728 .891 r
F
.52629 .34453 m .52612 .34472 L .52632 .34496 L F
.52606 .34484 m .52606 .34527 L .5258 .34471 L F
.5258 .34471 m .52571 .34494 L .52611 .34471 L F
.526 .34573 m .52124 .35721 L p .52543 .34551 L F P
0 g
s
.52009 .35696 m .52422 .349 L p .52555 .34539 L .672 .728 .891 r
F P
0 g
s
.52745 .3452 m .54435 .3488 L p .52748 .34483 L .672 .728 .891 r
F P
0 g
s
.52728 .34478 m .52745 .3452 L .52748 .34483 L .672 .728 .891 r
F
.52619 .34452 m .52716 .34505 L .52728 .34478 L F
.52716 .34505 m .52745 .3452 L .52728 .34478 L F
.52533 .34455 m .52242 .34396 L .52546 .34439 L F
.52552 .34457 m .50821 .34111 L .52458 .34412 L F
.52458 .34412 m .52298 .34408 L .52573 .34463 L F
.52549 .34458 m .51727 .34293 L .52552 .34457 L F
.52292 .34406 m .52302 .34408 L .52544 .34456 L F
.52632 .34496 m .52671 .34401 L p .52626 .34412 L F P
0 g
s
.54435 .3488 m .54469 .34801 L p .52803 .34486 L .672 .728 .891 r
F P
0 g
s
.52803 .34486 m .52592 .34446 L .52798 .34494 L .672 .728 .891 r
F
.52803 .34486 m .52798 .34494 L .54435 .3488 L F
.52662 .34415 m .52645 .3447 L .52673 .34418 L F
.52672 .34419 m .52645 .3447 L p .52658 .34423 L F P
0 g
s
.52714 .34237 m .52662 .34415 L .53262 .33281 L .672 .728 .891 r
F
.52672 .34418 m .52658 .34423 L .52705 .34254 L F
.52672 .34419 m .52658 .34423 L .52672 .34418 L F
.52621 .34416 m .52618 .34435 L .52606 .34415 L F
.52618 .34435 m .52613 .34473 L .52609 .34439 L F
.52618 .34435 m .52609 .34439 L .52606 .34415 L F
.5258 .34471 m .52611 .34471 L .52651 .34381 L F
.52635 .34374 m .52651 .34381 L .52714 .34237 L F
.5258 .34471 m .52651 .34381 L .52635 .34374 L F
.52619 .34452 m .52683 .34507 L .52685 .34488 L F
.52693 .3449 m .52649 .3448 L .52694 .34489 L F
.52693 .3449 m .52694 .34489 L .53243 .34597 L F
.53434 .34643 m .52693 .3449 L .53243 .34597 L F
.53346 .34636 m .52693 .3449 L .53434 .34643 L F
.52662 .34415 m .52673 .34418 L .53262 .33281 L F
.52611 .34471 m .52609 .34476 L .52612 .34472 L F
.52611 .34471 m .52612 .34472 L .52629 .34453 L F
.52596 .34452 m .52557 .3446 L .52494 .34429 L F
.52571 .34494 m .52601 .34495 L .52611 .34471 L F
.52598 .34484 m .52595 .34492 L .52609 .34476 L F
.52598 .34484 m .52609 .34476 L .52611 .34471 L F
.52629 .34453 m .52602 .34459 L .52592 .34446 L F
.52592 .34446 m .5258 .34471 L .52593 .34448 L F
.5258 .34471 m .52516 .34471 L .52549 .34458 L F
.52557 .3446 m .52549 .34458 L .52552 .34457 L F
.5258 .34471 m .52549 .34458 L .52557 .3446 L F
.52602 .34459 m .52577 .34464 L .52592 .34446 L F
.52516 .34472 m .52516 .34471 L p .5258 .34471 L F P
0 g
s
.52577 .34464 m .52514 .34477 L .52557 .3446 L .672 .728 .891 r
F
.52577 .34464 m .52557 .3446 L .52592 .34446 L F
.52592 .34446 m .52593 .34448 L .52595 .34445 L F
.52611 .34471 m .52557 .3446 L .52596 .34452 L F
.52627 .3437 m .52621 .34416 L .52606 .34415 L F
.52592 .34446 m .52595 .34445 L .52662 .34329 L F
.5266 .34328 m .52662 .34329 L .53262 .33281 L F
.52592 .34446 m .52662 .34329 L .5266 .34328 L F
.52613 .34472 m .52557 .3446 L .52611 .34471 L F
.52592 .3449 m .52532 .34473 L .52629 .34453 L F
.5258 .34471 m .52606 .34527 L .52562 .3451 L F
.5258 .34471 m .52562 .3451 L .52565 .3451 L F
.52527 .34471 m .52592 .3449 L .52553 .34463 L F
.52599 .34455 m .526 .34456 L .52613 .34434 L F
.52514 .34477 m .52242 .34396 L .52533 .34455 L F
.52292 .34406 m .52275 .34403 L .52514 .34477 L F
.52514 .34477 m .50789 .3419 L p .52242 .34396 L F P
0 g
s
.50789 .3419 m .52362 .34451 L p .52275 .34403 L .672 .728 .891 r
F P
0 g
s
.52362 .34451 m .52514 .34477 L p .52275 .34403 L .672 .728 .891 r
F P
0 g
s
.52458 .34412 m .52392 .34396 L .52292 .34407 L .672 .728 .891 r
F
.52279 .34404 m .52278 .34404 L .52275 .34403 L F
.50821 .34111 m .50861 .34033 L p .52458 .34412 L F P
0 g
s
.50861 .34033 m .52278 .34404 L p .52392 .34396 L .672 .728 .891 r
F P
0 g
s
.52278 .34404 m .52292 .34407 L p .52392 .34396 L .672 .728 .891 r
F P
0 g
s
.52292 .34406 m .52284 .34405 L .52278 .34404 L .672 .728 .891 r
F
.52292 .34406 m .52278 .34404 L .52279 .34404 L F
.52294 .34407 m .52288 .34406 L .52263 .34396 L F
.52256 .34393 m .52263 .34396 L .51726 .34192 L F
.52294 .34407 m .52263 .34396 L .52256 .34393 L F
.50765 .34271 m .50789 .3419 L p .52275 .34403 L F P
0 g
s
.52284 .34405 m .50765 .34271 L .52275 .34403 L .672 .728 .891 r
F
.52388 .34382 m .52294 .34407 L .51726 .34192 L F
.52294 .34407 m .52292 .34407 L .52288 .34406 L F
.52574 .34503 m .52586 .34511 L .52617 .34433 L F
.52573 .34502 m .52617 .34433 L .52613 .34434 L F
.52571 .34494 m .52424 .34895 L .52601 .34495 L F
.52557 .34531 m .52574 .34503 L .52573 .34502 L F
.52574 .34503 m .52617 .34433 L .52573 .34502 L F
.52581 .34482 m .52584 .34484 L .526 .34456 L F
.52576 .34478 m .5258 .34481 L .52613 .34434 L F
.52376 .35029 m .52404 .34992 L .52588 .34512 L F
.52586 .34511 m .52588 .34512 L .52626 .34412 L F
.52376 .35029 m .52588 .34512 L .52586 .34511 L F
.52568 .34499 m .526 .34456 L .52599 .34455 L F
.52514 .34477 m .52546 .34439 L .5255 .34462 L F
.52302 .34408 m .52527 .34471 L .52545 .34457 L F
.52292 .34407 m .52518 .34466 L p .52545 .34457 L F P
0 g
s
.52518 .34466 m .52292 .34407 L p .52518 .34466 L .672 .728 .891 r
F P
0 g
s
.52499 .34454 m .52292 .34407 L .52487 .34446 L .672 .728 .891 r
F
.52292 .34406 m .52544 .34456 L .52534 .3445 L F
.52518 .34466 m .52292 .34407 L .52499 .34454 L F
.52302 .34408 m .52545 .34457 L .52544 .34456 L F
.52292 .34406 m .52484 .34467 L .52493 .34462 L F
.51727 .34293 m .51744 .34296 L .52552 .34457 L F
.52395 .34467 m .51923 .3441 L .52254 .34426 L F
.52409 .34464 m .52254 .34426 L .52517 .34438 L F
.52395 .34467 m .52254 .34426 L .52409 .34464 L F
.52612 .34472 m .52595 .34492 L .52632 .34496 L F
.52611 .34471 m .52592 .34515 L .52625 .34487 L F
.52632 .34496 m .52592 .3449 L p .52618 .34479 L F P
0 g
s
.52613 .34472 m .52611 .34471 L .52677 .34484 L .672 .728 .891 r
F
.52677 .34484 m .52677 .34484 L .52715 .34491 L F
.52613 .34472 m .52677 .34484 L .52677 .34484 L F
.52649 .3448 m .52613 .34472 L .52648 .34479 L F
.52677 .34487 m .52632 .34496 L .52613 .34472 L F
.52632 .34496 m .52618 .34479 L .52664 .3446 L F
.52595 .34492 m .52577 .34539 L .52625 .34512 L F
.52625 .34512 m .52632 .34496 L p .52595 .34492 L F P
0 g
s
.5262 .34519 m .52645 .3447 L p .52592 .34515 L .672 .728 .891 r
F P
0 g
s
.52606 .34527 m .526 .34573 L .52562 .3451 L .672 .728 .891 r
F
.52577 .34539 m .52606 .3455 L .52625 .34512 L F
.52608 .34541 m .52586 .34528 L .52611 .3447 L F
.52577 .34539 m .5246 .34846 L .52606 .3455 L F
.52592 .34515 m .52424 .34897 L .5262 .34519 L F
.52422 .349 m .52424 .34898 L p .52424 .34897 L F P
0 g
s
.52424 .34898 m .5262 .34519 L p .52424 .34897 L .672 .728 .891 r
F P
0 g
s
.52608 .34541 m .52424 .34898 L p .52586 .34528 L .672 .728 .891 r
F P
0 g
s
.52424 .34895 m .52424 .34897 L .52601 .34495 L .672 .728 .891 r
F
.52557 .34531 m .52423 .34899 L .52575 .34538 L F
.52423 .34899 m .52376 .35029 L .52436 .3488 L F
.52423 .34899 m .52436 .3488 L .52575 .34538 L F
.52124 .35721 m .52528 .34746 L p .5246 .34846 L F P
0 g
s
.52609 .34551 m .526 .34573 L p .52603 .3455 L .672 .728 .891 r
F P
0 g
s
.52528 .34746 m .52625 .34512 L p .5246 .34846 L .672 .728 .891 r
F P
0 g
s
.52582 .34655 m .52244 .35732 L p .52563 .3454 L .672 .728 .891 r
F P
0 g
s
.52244 .35732 m .52246 .35726 L .52563 .3454 L .672 .728 .891 r
F
.52554 .34454 m .52573 .34463 L .52579 .34446 L F
.52611 .34471 m .52625 .34487 L .52645 .3447 L F
.52642 .34477 m .52632 .34496 L p .52611 .3447 L F P
0 g
s
.52629 .34474 m .52592 .3449 L .52611 .34471 L .672 .728 .891 r
F
.52629 .34474 m .52611 .34471 L .52629 .34453 L F
.52664 .3446 m .52629 .34474 L .52629 .34453 L F
.53014 .34526 m .52806 .3451 L .52664 .3446 L F
.52715 .34492 m .52715 .34491 L .52785 .34505 L F
.52613 .34472 m .52715 .34491 L .52715 .34492 L F
.52741 .34498 m .52785 .34505 L .52785 .34506 L F
.52613 .34472 m .52741 .34497 L .52741 .34498 L F
.52741 .34497 m .52785 .34505 L .52741 .34498 L F
.53027 .33236 m .52907 .33221 L p .5275 .33816 L F P
0 g
s
.52907 .33221 m .52806 .33691 L p .5275 .33816 L .672 .728 .891 r
F P
0 g
s
.52785 .33212 m .52651 .34018 L .52806 .33691 L .672 .728 .891 r
F
.52806 .3451 m .52648 .34478 L .52664 .3446 L F
.52788 .34495 m .52611 .34471 L .52676 .3447 L F
.52785 .34506 m .52785 .34505 L .53243 .34597 L F
.52649 .3448 m .52648 .34479 L .52962 .34541 L F
.52961 .34542 m .52962 .34541 L .53243 .34597 L F
.52649 .3448 m .52962 .34541 L .52961 .34542 L F
.52785 .34505 m .52611 .34471 L .52788 .34495 L F
.52645 .3447 m .52642 .34477 L p .52611 .3447 L F P
0 g
s
.52683 .34507 m .52745 .3452 L p .52685 .34488 L .672 .728 .891 r
F P
0 g
s
.53124 .34586 m .52683 .34505 L .52677 .34487 L .672 .728 .891 r
F
.52683 .34505 m .52632 .34496 L .52677 .34487 L F
.52806 .3451 m .52632 .34496 L .52648 .34478 L F
.52628 .34434 m .52615 .34461 L .52629 .34453 L F
.52608 .34466 m .52611 .34471 L .52629 .34453 L F
.52611 .34471 m .52645 .3447 L .52676 .34367 L F
.52658 .34365 m .52676 .34367 L .52714 .34237 L F
.52611 .34471 m .52676 .34367 L .52658 .34365 L F
.52611 .3447 m .52663 .34497 L .52655 .34484 L F
.52676 .3447 m .52611 .34471 L .52596 .34452 L F
.52645 .3447 m .52611 .3447 L .5264 .34455 L F
.52589 .34442 m .52576 .34478 L .52613 .34434 L F
.5263 .3446 m .52642 .34487 L .52662 .34469 L F
.52579 .34446 m .52614 .34469 L .5263 .3446 L F
.52614 .34469 m .52642 .34487 L .5263 .3446 L F
.52599 .3455 m .52585 .34549 L .52586 .34528 L F
.53244 .34598 m .52632 .34496 L p .53014 .34526 L F P
0 g
s
.52697 .34491 m .52699 .34498 L .52728 .34499 L .672 .728 .891 r
F
.52726 .34494 m .52728 .34499 L .52758 .345 L F
.53243 .34597 m .52785 .34505 L .52788 .34495 L F
.52632 .34496 m .53244 .34598 L p .52758 .345 L F P
0 g
s
.54435 .3488 m .52999 .34574 L p .53124 .34586 L .672 .728 .891 r
F P
0 g
s
.52999 .34574 m .52632 .34496 L p .53124 .34586 L .672 .728 .891 r
F P
0 g
s
.52671 .34506 m .53074 .34612 L p .52705 .34481 L .672 .728 .891 r
F P
0 g
s
.52705 .34481 m .53074 .34612 L .53232 .34629 L .672 .728 .891 r
F
.52874 .34538 m .52678 .34494 L .52751 .34505 L F
.52611 .3447 m .52592 .34475 L .52589 .34442 L F
.52618 .34433 m .52598 .34484 L .52627 .34429 L F
.52587 .34476 m .52611 .3447 L .52611 .3447 L F
.52608 .34466 m .52598 .34484 L .52611 .34471 L F
.52587 .34476 m .52632 .34496 L .52611 .3447 L F
.52592 .3449 m .52632 .34496 L p .52587 .34476 L F P
0 g
s
.52544 .34456 m .52576 .34478 L .52587 .34476 L .672 .728 .891 r
F
.52576 .34478 m .52592 .3449 L .52587 .34476 L F
.52594 .34498 m .52587 .34498 L .52588 .34476 L F
.52592 .34475 m .52588 .34476 L .52589 .34442 L F
.52594 .34498 m .52588 .34476 L .52592 .34475 L F
.52611 .3447 m .52603 .34526 L .52592 .34475 L F
.52611 .3447 m .52632 .34496 L .52663 .34497 L F
.52642 .34487 m .52671 .34506 L .52665 .34481 L F
.52545 .34457 m .52586 .34484 L .52595 .3448 L F
.52573 .34477 m .52577 .34476 L .52579 .34477 L F
.52611 .34471 m .52599 .34498 L .52602 .34476 L F
.5256 .34522 m .52246 .35724 L .52424 .34897 L F
.52563 .3454 m .52242 .3574 L .5256 .34522 L F
.52599 .34498 m .52599 .34498 L .52611 .34471 L F
.52627 .34429 m .52608 .34466 L .52615 .34461 L F
.5264 .34455 m .52596 .34452 L .52589 .34442 L F
.52871 .34509 m .52643 .34462 L .5264 .34455 L F
.52869 .34513 m .52643 .34462 L .52871 .34509 L F
.52643 .34462 m .52596 .34452 L .5264 .34455 L F
.52623 .34485 m .52637 .34491 L .52611 .3447 L F
.52632 .34496 m .52612 .34471 L .52612 .3447 L F
.5264 .34455 m .52589 .34442 L .5263 .3446 L F
.5264 .34455 m .52611 .3447 L .52631 .34426 L F
.52589 .34442 m .52579 .34446 L .5263 .3446 L F
.52626 .34467 m .52612 .3447 L .52618 .34431 L F
.52611 .3447 m .52637 .34491 L .52619 .34472 L F
.52632 .34496 m .52612 .3447 L .52626 .34467 L F
.52613 .34434 m .52617 .34433 L .52626 .34412 L F
.52645 .3447 m .52643 .34462 L .52643 .34459 L F
.52643 .34462 m .52631 .34426 L .52643 .34459 L F
.52643 .34459 m .52631 .34426 L .52635 .34416 L F
.52645 .3447 m .52633 .34404 L .52665 .34399 L F
.52657 .34416 m .52647 .34448 L p .52627 .34436 L F P
0 g
s
.52631 .34426 m .52627 .34436 L .52618 .34431 L .672 .728 .891 r
F
.52657 .34416 m .52627 .34436 L .52631 .34426 L F
.53074 .34612 m .54395 .34957 L p .53232 .34629 L F P
0 g
s
.52664 .34459 m .52657 .34461 L .52862 .34499 L .672 .728 .891 r
F
.52598 .34418 m .52589 .34442 L .52626 .34412 L F
.52589 .34442 m .52613 .34434 L .52626 .34412 L F
.52626 .34412 m .52618 .34433 L .52627 .34429 L F
.5292 .3374 m .52592 .34446 L .52878 .33864 L F
.52626 .34412 m .52639 .34409 L .53146 .33256 L F
.53146 .33256 m .5292 .3374 L .52878 .33864 L F
.52622 .34352 m .52626 .34412 L .53146 .33256 L F
.52622 .34352 m .52598 .34418 L .52626 .34412 L F
.52631 .34328 m .52657 .34416 L .52589 .34442 L F
.52634 .34407 m .52632 .34406 L .52633 .34404 L F
.52635 .34416 m .52632 .34406 L .52634 .34407 L F
.52635 .34416 m .52627 .34415 L .52632 .34406 L F
.52631 .34426 m .52627 .34415 L .52635 .34416 L F
.52622 .34433 m .5262 .3444 L .52618 .34431 L F
.52627 .34436 m .5262 .3444 L .52622 .34433 L F
.52627 .34429 m .52615 .34461 L .52628 .34434 L F
.52627 .34436 m .52622 .34447 L .5262 .3444 L F
.52631 .34426 m .52611 .3447 L .52627 .34415 L F
.52596 .34452 m .52494 .34429 L .52589 .34442 L F
.52501 .34422 m .52494 .34429 L .52458 .34412 L F
.52458 .34412 m .52554 .34454 L .52579 .34446 L F
.52639 .34306 m .52644 .34336 L .52631 .34328 L F
.52665 .34399 m .52641 .34402 L .52703 .34261 L F
.52711 .34245 m .52657 .34416 L p .52651 .3438 L F P
0 g
s
.5271 .34246 m .52651 .3438 L .52639 .34306 L .672 .728 .891 r
F
.52711 .34245 m .52651 .3438 L .5271 .34246 L F
.52703 .34261 m .52633 .34404 L .52705 .34254 L F
.52641 .34402 m .52633 .34404 L .52703 .34261 L F
.52644 .34336 m .52657 .34416 L .52631 .34328 L F
.52706 .34256 m .52657 .34416 L .52707 .34255 L F
.52557 .34531 m .52575 .34538 L .52586 .34511 L F
.52557 .34531 m .52586 .34511 L .52574 .34503 L F
.52586 .34528 m .52565 .3453 L .52574 .34499 L F
.52568 .34499 m .52573 .34502 L .52584 .34484 L F
.52568 .34499 m .52584 .34484 L .52581 .34482 L F
.52587 .34498 m .52574 .34499 L .52589 .34442 L F
.52586 .34528 m .52574 .34499 L .52587 .34498 L F
.52563 .34465 m .52602 .34472 L .5261 .3447 L F
.52546 .34457 m .52563 .34465 L .5261 .3447 L F
.52573 .34463 m .52592 .34471 L .52594 .34467 L F
.52563 .34465 m .52587 .34476 L .52602 .34472 L F
.52592 .34471 m .52602 .34476 L .52594 .34467 L F
.52594 .34467 m .52602 .34476 L .52611 .3447 L F
.52612 .3447 m .52611 .3447 L .52589 .34442 L F
.52611 .3447 m .52605 .34463 L .52579 .34446 L F
.52611 .3447 m .52619 .34472 L .52605 .34463 L F
.52618 .34431 m .52612 .3447 L .52589 .34442 L F
.52597 .34478 m .5259 .34477 L .52595 .3448 L F
.53243 .34597 m .52869 .34513 L .52871 .34509 L F
.54435 .3488 m .53346 .34636 L .53434 .34643 L F
.54395 .34957 m .54435 .3488 L p .52703 .3447 L F P
0 g
s
.52774 .34493 m .52858 .34516 L .5286 .34509 L .672 .728 .891 r
F
.52662 .34469 m .52665 .34481 L .52705 .34481 L F
.52637 .34491 m .52642 .34487 L .52619 .34472 L F
.52651 .34349 m .52604 .34462 L .526 .34456 L F
.52651 .34349 m .52594 .34449 L .52658 .34356 L F
.52659 .34349 m .52605 .34462 L .52651 .34349 L F
.52573 .34463 m .52611 .3447 L .52579 .34446 L F
.52611 .3447 m .52607 .34465 L .52534 .3445 L F
.52605 .34462 m .52597 .34478 L .52604 .34462 L F
.52605 .34462 m .52604 .34462 L .52651 .34349 L F
.52544 .34456 m .52611 .3447 L .52534 .3445 L F
.52652 .34479 m .52665 .34481 L .52662 .34469 L F
.52647 .34448 m .52642 .34464 L p .52622 .34447 L F P
0 g
s
.52605 .34462 m .52647 .34471 L .52646 .3447 L .672 .728 .891 r
F
.52611 .3447 m .52728 .34499 L .52726 .34494 L F
.52642 .34464 m .52632 .34496 L p .52626 .34467 L F P
0 g
s
.52642 .34464 m .52626 .34467 L .52622 .34447 L .672 .728 .891 r
F
.52611 .34471 m .52602 .34476 L .52627 .34415 L F
.52611 .3447 m .52613 .3447 L .52607 .34465 L F
.52613 .3447 m .52696 .34487 L .52621 .34468 L F
.52613 .3447 m .52621 .34468 L .52607 .34465 L F
.52696 .34487 m .52773 .34503 L .52695 .34485 L F
.52696 .34487 m .52695 .34485 L .52607 .34465 L F
.52665 .34481 m .52696 .34488 L .52705 .34481 L F
.52773 .34503 m .52774 .34499 L .52607 .34465 L F
.52546 .34457 m .5261 .3447 L .52611 .3447 L F
.52573 .34463 m .5259 .34477 L .52601 .34479 L F
.52599 .34498 m .52611 .34471 L .52611 .3447 L F
.52612 .34471 m .52608 .34497 L .52611 .3447 L F
.52573 .34463 m .52632 .34496 L .52623 .34485 L F
.52594 .34449 m .52586 .34484 L .52578 .34476 L F
.52651 .34349 m .52605 .34444 L .52594 .34449 L F
.52517 .34438 m .52605 .34462 L .52597 .34453 L F
.52605 .34444 m .52586 .34484 L .52594 .34449 L F
.52592 .3449 m .52553 .34483 L p .52553 .34478 L F P
0 g
s
.52553 .34478 m .52514 .34477 L .52532 .34473 L .672 .728 .891 r
F
.52553 .34483 m .52514 .34477 L p .52553 .34478 L F P
0 g
s
.52514 .34477 m .52592 .3449 L p .52493 .34462 L .672 .728 .891 r
F P
0 g
s
.52576 .34478 m .52568 .34499 L .5258 .34481 L .672 .728 .891 r
F
.52589 .34442 m .52574 .34499 L .52568 .34499 L F
.5258 .34478 m .52573 .34477 L .5258 .34478 L F
.52578 .34476 m .52586 .34484 L .52568 .34494 L F
.5262 .34519 m .5261 .34508 L .52611 .3447 L F
.52632 .34496 m .5262 .34519 L p .52611 .3447 L F P
0 g
s
.5262 .34519 m .52608 .34541 L p .5261 .34508 L .672 .728 .891 r
F P
0 g
s
.52703 .3447 m .52743 .34492 L .52808 .3451 L .672 .728 .891 r
F
.52703 .3447 m .5264 .34455 L .52743 .34492 L F
.52646 .3447 m .52774 .34498 L .52774 .34493 L F
.52607 .34465 m .52774 .34499 L .52605 .34462 L F
.52774 .34499 m .52774 .34498 L .52605 .34462 L F
.52957 .34538 m .52957 .34537 L .52774 .34498 L F
.52774 .34498 m .52774 .34498 L .52605 .34462 L F
.52703 .3447 m .52808 .3451 L .52926 .34534 L F
.52957 .34538 m .52774 .34498 L .52774 .34498 L F
.52603 .34446 m .52626 .34438 L .52623 .34421 L F
.52603 .34446 m .52623 .34421 L .52621 .34409 L F
.52594 .34449 m .52603 .34446 L .52621 .34409 L F
.52627 .34325 m .52597 .34394 L .52639 .34409 L F
.52623 .34296 m .52604 .34367 L .52627 .34325 L F
.52604 .34367 m .52597 .34394 L .52627 .34325 L F
.52534 .3445 m .52607 .34465 L .52605 .34462 L F
.52526 .3444 m .52534 .3445 L .52605 .34462 L F
.52611 .3447 m .52611 .3447 L .52631 .34426 L F
.52594 .34449 m .52517 .34438 L .52597 .34453 L F
.52591 .34417 m .52586 .34438 L .52608 .3441 L F
.52604 .34462 m .52597 .34478 L .526 .34456 L F
.52527 .34471 m .52553 .34463 L .52545 .34457 L F
.52518 .34466 m .52564 .34478 L p .52545 .34457 L F P
0 g
s
.52573 .34477 m .52518 .34466 L .52577 .34476 L .672 .728 .891 r
F
.52602 .34476 m .52608 .34478 L .52606 .34474 L F
.52632 .34496 m .52615 .34551 L p .52612 .34471 L F P
0 g
s
.52608 .34478 m .52623 .34485 L .52606 .34474 L .672 .728 .891 r
F
.52606 .34474 m .52623 .34485 L .52611 .3447 L F
.526 .34456 m .52597 .34478 L .52586 .34484 L F
.52573 .34463 m .52545 .34457 L .5259 .34477 L F
.52602 .34476 m .52597 .34478 L .52605 .34462 L F
.52602 .34476 m .52605 .34462 L .52607 .34465 L F
.52594 .34449 m .52578 .34476 L .52611 .3447 L F
.5262 .34481 m .52529 .34461 L .52615 .34475 L F
.52529 .34461 m .52531 .3446 L .52615 .34475 L F
.52611 .3447 m .52554 .34474 L .52572 .34463 L F
.52612 .3447 m .52612 .34471 L .52611 .3447 L F
.52628 .3446 m .52628 .34491 L .52642 .34464 L F
.52642 .34464 m .52657 .34416 L .52642 .34464 L F
.52639 .34409 m .52642 .34464 L .52657 .34416 L F
.52647 .34448 m .52622 .34447 L .52627 .34436 L F
.52626 .34438 m .52642 .34464 L .52639 .34409 L F
.52597 .34453 m .52605 .34462 L .52721 .34484 L F
.54469 .34801 m .53244 .34598 L p .53014 .34526 L F P
0 g
s
.52718 .34475 m .52721 .34484 L .54469 .34801 L .672 .728 .891 r
F
.5264 .34455 m .5263 .3446 L .52705 .34481 L F
.52708 .34479 m .52705 .34481 L .52743 .34492 L F
.5264 .34455 m .52705 .34481 L .52708 .34479 L F
.52636 .34455 m .52611 .3447 L .52594 .34449 L F
.52611 .3447 m .52699 .34498 L .52697 .34491 L F
.52611 .3447 m .52628 .34491 L .52628 .3446 L F
.5266 .34481 m .5261 .34471 L .5266 .34481 L F
.5261 .34471 m .52539 .34457 L .5261 .34471 L F
.5261 .34471 m .5261 .34471 L .5266 .34481 L F
.52617 .34457 m .52611 .3447 L .52628 .3446 L F
.52642 .34464 m .52657 .34416 L .52657 .34416 L F
.52632 .34496 m .52642 .34464 L .52642 .34464 L F
.52518 .34466 m .52517 .34465 L .5262 .34481 L F
.52545 .34457 m .52564 .34478 L .52562 .34468 L F
.52517 .34465 m .52529 .34461 L .5262 .34481 L F
.52524 .34421 m .52487 .34446 L .52388 .34382 L F
.52517 .34438 m .52292 .34406 L .52534 .3445 L F
.52298 .34408 m .52292 .34407 L .52573 .34463 L F
.52487 .34446 m .52292 .34407 L .52388 .34382 L F
.52524 .34421 m .51726 .34192 L .52467 .3443 L F
.50861 .34033 m .50908 .33957 L p .51726 .34192 L F P
0 g
s
.52288 .34406 m .50861 .34033 L .51726 .34192 L .672 .728 .891 r
F
.52292 .34407 m .52278 .34404 L p .52288 .34406 L F P
0 g
s
.52278 .34404 m .50861 .34033 L p .52288 .34406 L .672 .728 .891 r
F P
0 g
s
.51923 .3441 m .50765 .34271 L .52284 .34405 L .672 .728 .891 r
F
.52288 .34406 m .52284 .34405 L .52292 .34406 L F
.51923 .3441 m .52284 .34405 L .52288 .34406 L F
.50908 .33957 m .51541 .34155 L p .51726 .34192 L F P
0 g
s
.52586 .34438 m .52594 .34449 L .52608 .3441 L .672 .728 .891 r
F
.52619 .34453 m .5264 .34461 L .52638 .34457 L F
.52607 .34465 m .52605 .34462 L .52627 .34415 L F
.52594 .34449 m .52617 .34456 L .52619 .34453 L F
.52594 .34449 m .52597 .34453 L .52617 .34456 L F
.52594 .34449 m .52611 .3447 L .52626 .34438 L F
.52619 .34453 m .52617 .34456 L .5264 .34461 L F
.52626 .34438 m .52611 .3447 L .52679 .3442 L F
.52638 .34457 m .5264 .34461 L .53092 .34545 L F
.53093 .34543 m .53092 .34545 L .54469 .34801 L F
.52638 .34457 m .53092 .34545 L .53093 .34543 L F
.52715 .34363 m .53376 .33311 L p .52714 .34364 L F P
0 g
s
.52586 .34438 m .52539 .34436 L .52556 .3443 L .672 .728 .891 r
F
.52642 .34464 m .52657 .34416 L .52642 .34464 L F
.52597 .34453 m .52721 .34484 L .52718 .34475 L F
.52636 .34455 m .52594 .34449 L .52634 .34456 L F
.52636 .34455 m .52634 .34456 L .52657 .34461 L F
.52664 .34459 m .52636 .34455 L .52657 .34461 L F
.52608 .3441 m .52596 .34452 L .52642 .34464 L F
.52664 .34459 m .52611 .3447 L .52636 .34455 L F
.52611 .3447 m .52652 .34464 L .52679 .3442 L F
.52688 .34319 m .52707 .34255 L p .52688 .34319 L F P
0 g
s
.52657 .34416 m .52688 .34319 L .52688 .34319 L .672 .728 .891 r
F
.52657 .34416 m .52688 .34319 L p .52657 .34416 L F P
0 g
s
.52711 .34243 m .52672 .34419 L .52705 .34254 L .672 .728 .891 r
F
.53262 .33281 m .52724 .34319 L p .52711 .34243 L F P
0 g
s
.52724 .34319 m .52672 .34419 L p .52711 .34243 L .672 .728 .891 r
F P
0 g
s
.53027 .33236 m .52711 .34245 L p .52639 .34306 L .672 .728 .891 r
F P
0 g
s
.5271 .34232 m .52623 .34296 L .52707 .34255 L .672 .728 .891 r
F
.5275 .33816 m .52683 .3407 L .5271 .34232 L F
.52683 .3407 m .52623 .34296 L .5271 .34232 L F
.52669 .34339 m .52679 .3442 L .52875 .34108 L F
.52674 .34393 m .52674 .34393 L .5273 .343 L F
.52649 .34386 m .52657 .34416 L .52706 .34256 L F
.52649 .34386 m .52639 .34409 L .52657 .34416 L F
.52637 .34412 m .52679 .3442 L .52669 .34339 L F
.52681 .34417 m .52715 .34363 L .52714 .34364 L F
.52681 .34417 m .52715 .34363 L .52681 .34417 L F
.52726 .34346 m .5268 .3442 L p .5273 .343 L F P
0 g
s
.5268 .3442 m .52674 .34393 L .5273 .343 L .672 .728 .891 r
F
.5275 .34491 m .52692 .34487 L .52775 .34475 L F
.52611 .3447 m .52572 .34463 L .52594 .34449 L F
.52544 .34456 m .52546 .34457 L .52611 .3447 L F
.52611 .3447 m .5254 .34456 L .52607 .34465 L F
.52499 .34454 m .52487 .34446 L .52612 .34471 L F
.52613 .34473 m .52612 .34471 L .5266 .34481 L F
.52499 .34454 m .52612 .34471 L .52613 .34473 L F
.52585 .34549 m .52563 .3454 L .52565 .3453 L F
.52422 .349 m .52326 .3504 L .52551 .34575 L F
.52569 .34579 m .52563 .3454 L .52584 .34578 L F
.52556 .34577 m .52551 .34575 L .52592 .3449 L F
.52424 .34895 m .52422 .349 L .52424 .34897 L F
.52422 .349 m .52551 .34575 L .52556 .34577 L F
.52599 .34498 m .52595 .34493 L .52602 .34476 L F
.52603 .34526 m .52597 .34527 L .52592 .34475 L F
.52581 .34525 m .52597 .34478 L .52602 .34476 L F
.52592 .3449 m .52592 .3449 L .52597 .34478 L F
.52608 .34497 m .52607 .34497 L .52611 .3447 L F
.52595 .3448 m .52586 .34484 L .52632 .34496 L F
.52586 .34484 m .52586 .34484 L .52632 .34496 L F
.52586 .34484 m .52632 .34496 L p .52632 .34496 L F P
0 g
s
.52586 .34484 m .52586 .34484 L .52632 .34496 L .672 .728 .891 r
F
.52611 .3447 m .52568 .34494 L .526 .34495 L F
.5258 .34478 m .5258 .34478 L .52664 .34491 L F
.5258 .34478 m .52579 .34477 L .52664 .34491 L F
.52637 .34491 m .52671 .34506 L .52642 .34487 L F
.52564 .34478 m .52586 .34484 L p .52562 .34468 L F P
0 g
s
.52607 .34576 m .52595 .34577 L .52612 .34471 L .672 .728 .891 r
F
.52601 .34479 m .52597 .34478 L .52632 .34496 L F
.52597 .34478 m .52595 .3448 L .52632 .34496 L F
.52632 .34496 m .52518 .34466 L .52666 .34495 L F
.52557 .34478 m .52555 .34476 L .52603 .34475 L F
.52655 .34484 m .52663 .34497 L .52699 .34498 L F
.52665 .34481 m .52671 .34506 L .52696 .34488 L F
.52661 .34482 m .52693 .34487 L .52693 .34488 L F
.52724 .34372 m .52751 .34335 L p .52645 .34393 L F P
0 g
s
.52765 .342 m .52875 .34108 L .53376 .33311 L .672 .728 .891 r
F
.52669 .34339 m .52875 .34108 L .52765 .342 L F
.52914 .34046 m .52726 .34346 L p .52985 .33882 L F P
0 g
s
.52726 .34346 m .5273 .343 L .52985 .33882 L .672 .728 .891 r
F
.52641 .34433 m .52679 .3442 L .52621 .34409 L F
.52663 .33208 m .52541 .33209 L p .52552 .33662 L F P
0 g
s
.52775 .34204 m .52643 .34443 L .52633 .34419 L .672 .728 .891 r
F
.52843 .34099 m .52779 .3421 L .52775 .34204 L F
.52779 .3421 m .52643 .34443 L .52775 .34204 L F
.52785 .33212 m .52663 .33208 L p .52609 .33963 L F P
0 g
s
.52705 .34254 m .52659 .34349 L .52651 .34349 L .672 .728 .891 r
F
.52711 .34243 m .52651 .34349 L .52669 .34339 L F
.52651 .34349 m .52658 .34356 L .52669 .34339 L F
.52623 .34296 m .52649 .34386 L .52706 .34256 L F
.52621 .34409 m .52637 .34412 L .52669 .34339 L F
.52662 .34355 m .52658 .34363 L .5266 .34355 L F
.52663 .34352 m .52633 .34419 L .52662 .34355 L F
.52985 .33882 m .52673 .34359 L .52663 .34352 L F
.52673 .34359 m .52633 .34419 L .52663 .34352 L F
.5265 .34413 m .52634 .34419 L .52658 .34365 L F
.52623 .34296 m .52639 .34409 L .52649 .34386 L F
.52634 .34419 m .52628 .34421 L .52658 .34365 L F
.52985 .33882 m .52849 .34106 L .52843 .34099 L F
.52849 .34106 m .52643 .34443 L .52843 .34099 L F
.53376 .33311 m .52914 .34046 L p .52985 .33882 L F P
0 g
s
.53487 .33345 m .53376 .33311 L p .52662 .34355 L .672 .728 .891 r
F P
0 g
s
.52658 .34365 m .52628 .34421 L .52641 .34359 L .672 .728 .891 r
F
.52654 .34372 m .52633 .34419 L .52627 .34405 L F
.52662 .34355 m .52658 .34363 L .52662 .34355 L F
.52662 .34355 m .52627 .34405 L .52655 .3437 L F
.52658 .34365 m .52641 .34359 L .5266 .34355 L F
.52532 .3446 m .5266 .34482 L .52661 .34482 L F
.52532 .34459 m .5266 .34482 L .52532 .3446 L F
.52661 .34484 m .52693 .34488 L .52695 .3449 L F
.52642 .34487 m .52665 .34481 L .52652 .34479 L F
.52499 .34454 m .52661 .34482 L .52661 .34484 L F
.52661 .34482 m .52693 .34488 L .52661 .34484 L F
.52601 .34477 m .52603 .34475 L .52668 .34475 L F
.52584 .34578 m .52567 .34547 L .52585 .34549 L F
.52603 .34526 m .52599 .3455 L .52603 .34526 L F
.52603 .34526 m .52599 .3455 L .52597 .34527 L F
.52599 .3455 m .52586 .34528 L .52597 .34527 L F
.52579 .34543 m .52588 .34566 L .52628 .34491 L F
.52597 .34527 m .52586 .34528 L .52587 .34498 L F
.52597 .34527 m .52587 .34498 L .52594 .34498 L F
.52599 .34498 m .52563 .3458 L .52595 .34493 L F
.52563 .3458 m .52422 .349 L .52559 .34578 L F
.52585 .34549 m .52565 .3453 L .52586 .34528 L F
.52563 .3458 m .52559 .34578 L .52595 .34493 L F
.52573 .34558 m .52539 .34661 L .52588 .34566 L F
.52558 .34591 m .52539 .34661 L .52573 .34558 L F
.52573 .34558 m .52588 .34566 L .52579 .34543 L F
.52567 .34547 m .52563 .3454 L .52585 .34549 L F
.52568 .34499 m .52557 .34531 L .52573 .34502 L F
.52568 .34499 m .52565 .3453 L .5256 .34522 L F
.52574 .34499 m .52565 .3453 L .52568 .34499 L F
.52565 .3453 m .52563 .3454 L .52561 .3453 L F
.52565 .3453 m .52561 .3453 L .5256 .34522 L F
.52424 .34898 m .52599 .34498 L .52599 .34498 L F
.52422 .349 m .52579 .34523 L .52581 .34525 L F
.52556 .34577 m .52592 .3449 L .52592 .3449 L F
.52422 .349 m .52556 .34577 L .52556 .34577 L F
.52556 .34577 m .52592 .3449 L .52556 .34577 L F
.52582 .34655 m .52569 .34579 L .52584 .34578 L F
.52526 .34664 m .52595 .34554 L .52595 .34554 L F
.52526 .34664 m .52242 .35737 L .52558 .34591 L F
.52244 .35732 m .52242 .3574 L p .52246 .35726 L F P
0 g
s
.52539 .34661 m .52242 .35737 L .52587 .34641 L .672 .728 .891 r
F
.52462 .35038 m .52632 .34496 L .52632 .34496 L F
.52242 .35737 m .52462 .35038 L .52462 .35038 L F
.52462 .35038 m .52632 .34496 L .52462 .35038 L F
.52526 .34665 m .52595 .34554 L p .52526 .34664 L F P
0 g
s
.52548 .34539 m .52009 .35696 L .52555 .34539 L .672 .728 .891 r
F
.52009 .35696 m .51897 .35667 L p .52455 .34691 L F P
0 g
s
.52568 .34494 m .52474 .34696 L .52455 .34691 L .672 .728 .891 r
F
.52474 .34696 m .52009 .35696 L .52455 .34691 L F
.52568 .34494 m .52562 .34583 L .52579 .34543 L F
.52558 .3455 m .52569 .34553 L .52578 .34517 L F
.52597 .34478 m .52567 .3454 L .52568 .34494 L F
.52558 .3455 m .52578 .34517 L .52573 .34512 L F
.52567 .3454 m .52361 .34967 L .52553 .34528 L F
.52565 .3451 m .52548 .34539 L .52555 .34539 L F
.52562 .3451 m .52548 .34539 L .52565 .3451 L F
.52567 .3454 m .52553 .34528 L .52568 .34494 L F
.52568 .34494 m .52497 .34619 L .52562 .34583 L F
.52615 .34551 m .52607 .34576 L p .52608 .34551 L F P
0 g
s
.52607 .34576 m .52582 .34655 L p .52595 .34577 L .672 .728 .891 r
F P
0 g
s
.52539 .34661 m .52587 .34641 L .52615 .34551 L .672 .728 .891 r
F
.52615 .34551 m .52608 .34551 L .52612 .34471 L F
.52626 .34438 m .52633 .34422 L .52621 .34409 L F
.52597 .34394 m .52626 .34438 L .52639 .34409 L F
.52633 .34419 m .52625 .3444 L .52628 .34421 L F
.52608 .34497 m .52603 .34526 L .52607 .34497 L F
.52586 .34484 m .52632 .34496 L .52632 .34496 L F
.52611 .3447 m .52595 .34502 L .52628 .34491 L F
.52611 .3447 m .526 .34495 L .52632 .34496 L F
.52863 .34497 m .52862 .34499 L .53303 .34582 L F
.52664 .34459 m .53303 .34582 L .53284 .34576 L F
.53224 .34567 m .52898 .34528 L .53004 .34507 L F
.52774 .34499 m .52957 .34538 L .52774 .34498 L F
.52774 .34498 m .52858 .34516 L .52774 .34493 L F
.52902 .34529 m .52717 .34492 L .52719 .34492 L F
.52897 .34528 m .52758 .345 L .52874 .34503 L F
.52695 .3449 m .52717 .34492 L .52707 .34493 L F
.52678 .34494 m .5262 .34481 L .52707 .34493 L F
.52641 .34491 m .52645 .34488 L .52721 .34492 L F
.52641 .34491 m .52721 .34492 L .52735 .34495 L F
.52761 .345 m .52758 .345 L .53248 .34598 L F
.52902 .34529 m .52719 .34492 L .52898 .34528 L F
.52707 .34493 m .52717 .34492 L .52902 .34529 L F
.52877 .34537 m .52751 .34505 L .52842 .3452 L F
.52678 .34494 m .52707 .34493 L .52902 .34529 L F
.52897 .34528 m .52632 .34496 L .52758 .345 L F
.52653 .34492 m .52749 .3451 L .52766 .34509 L F
.52663 .3449 m .52759 .34507 L .52756 .34503 L F
.52499 .34454 m .5266 .34481 L .5266 .34482 L F
.52518 .34466 m .5262 .34481 L .52622 .34484 L F
.52578 .34476 m .52568 .34494 L .52611 .3447 L F
.52512 .34481 m .52525 .34476 L .52621 .34482 L F
.52579 .34523 m .52597 .34478 L .52581 .34525 L F
.52568 .34494 m .52579 .34543 L .526 .34495 L F
.52564 .34488 m .52512 .34481 L .52561 .34484 L F
.52512 .34481 m .52395 .34467 L .52525 .34476 L F
.52466 .34476 m .5258 .3449 L p .52475 .34471 L F P
0 g
s
.52585 .34494 m .52591 .34499 L .52611 .3447 L .672 .728 .891 r
F
.52693 .34488 m .52693 .34487 L .52717 .34492 L F
.52614 .34517 m .52623 .34524 L .52642 .34464 L F
.52632 .34496 m .52642 .34464 L .52632 .34496 L F
.52622 .34484 m .5262 .34481 L .52664 .34491 L F
.5262 .34481 m .52615 .34475 L .52707 .34493 L F
.52611 .3447 m .52758 .345 L .52761 .345 L F
.52625 .34487 m .52621 .34482 L .52777 .34492 L F
.52666 .34495 m .5258 .34478 L .52664 .34491 L F
.52632 .34496 m .52652 .34463 L .52632 .34496 L F
.52632 .34496 m .52632 .34496 L .52631 .34496 L F
.52735 .34515 m .52971 .34602 L .52955 .34586 L F
.52671 .34506 m .52664 .34491 L .52874 .34538 L F
.52677 .34502 m .52749 .3451 L p .52674 .34498 L F P
0 g
s
.52693 .34488 m .52717 .34492 L .52695 .3449 L .672 .728 .891 r
F
.52625 .34487 m .52777 .34492 L .52775 .34495 L F
.52623 .34484 m .52659 .34491 L .52663 .3449 L F
.52587 .34486 m .52585 .34494 L .52611 .3447 L F
.52578 .34517 m .52585 .34523 L .52611 .3447 L F
.52561 .34484 m .52621 .34482 L .52625 .34487 L F
.52587 .3448 m .52623 .34485 L .52623 .34484 L F
.52603 .34526 m .52603 .34526 L .52611 .3447 L F
.52585 .34523 m .52592 .3453 L .52628 .34491 L F
.52594 .34449 m .52596 .34452 L .52608 .3441 L F
.52484 .34467 m .52514 .34477 L .52493 .34462 L F
.52525 .34476 m .52464 .34472 L .52594 .34449 L F
.52464 .34472 m .52395 .34467 L .52458 .34461 L F
.52499 .34454 m .52532 .34459 L .52532 .3446 L F
.52611 .34471 m .525 .34449 L .52503 .34449 L F
.52529 .34461 m .52499 .34454 L .52531 .3446 L F
.52517 .34465 m .52499 .34454 L .52529 .34461 L F
.52464 .34472 m .52458 .34461 L .52594 .34449 L F
.52585 .34523 m .52568 .34555 L .52592 .3453 L F
.52595 .34502 m .52585 .34523 L .52604 .34509 L F
.52579 .34543 m .52585 .3457 L .526 .34495 L F
.52572 .3456 m .52599 .34515 L .52599 .34515 L F
.52361 .34967 m .52365 .34953 L .52553 .34528 L F
.52497 .34619 m .52526 .34664 L .52526 .34663 L F
.52497 .34619 m .52526 .34663 L .52562 .34583 L F
.52425 .34826 m .52526 .34664 L .52425 .34825 L F
.52526 .34664 m .52632 .34496 L .52526 .34664 L F
.52526 .34664 m .52526 .34664 L .52425 .34825 L F
.52599 .3455 m .52582 .34655 L .52585 .34549 L F
.52539 .34661 m .52615 .34551 L .52602 .3454 L F
.52526 .34664 m .52632 .34496 L .52631 .34496 L F
.52562 .34583 m .52526 .34663 L .52585 .3457 L F
.52595 .34502 m .52604 .34509 L .52628 .34491 L F
.526 .34495 m .52585 .3457 L .52632 .34496 L F
.52773 .34503 m .53248 .34598 L .52774 .34499 L F
.5286 .34509 m .53248 .34598 L .53475 .3462 L F
.52858 .34516 m .53248 .34598 L .5286 .34509 L F
.52857 .34555 m .52857 .34555 L .54391 .34956 L F
.54384 .34954 m .52836 .34549 L p .54391 .34956 L F P
0 g
s
.52836 .34549 m .52836 .34549 L .54391 .34956 L .672 .728 .891 r
F
.52926 .34534 m .52808 .3451 L .54377 .34952 L F
.52857 .34555 m .52836 .34549 L .53146 .34599 L F
.52836 .34549 m .52874 .34538 L .53146 .34599 L F
.53146 .34599 m .52874 .34538 L .52902 .34529 L F
.54372 .3495 m .54377 .34952 L .54395 .34957 L F
.54391 .34956 m .52857 .34555 L .53146 .34599 L F
.53146 .34599 m .52898 .34528 L .53549 .34776 L F
.54469 .34801 m .54495 .34721 L p .52971 .34503 L F P
0 g
s
.52971 .34503 m .52966 .34516 L .54469 .34801 L .672 .728 .891 r
F
.52632 .34496 m .52671 .34506 L p .52623 .34485 L F P
0 g
s
.52671 .34506 m .52632 .34496 L .52666 .34495 L .672 .728 .891 r
F
.52632 .34496 m .52632 .34496 L .53154 .34559 L F
.53154 .34559 m .53154 .34559 L .54461 .34716 L F
.52632 .34496 m .53154 .34559 L .53154 .34559 L F
.54292 .35105 m .5431 .3508 L p .5351 .34794 L F P
0 g
s
.52899 .34528 m .52632 .34496 L p .52899 .34528 L .672 .728 .891 r
F P
0 g
s
.52564 .34488 m .52561 .34484 L .52645 .34488 L .672 .728 .891 r
F
.52632 .34496 m .52564 .34488 L .52641 .34491 L F
.5258 .3449 m .52632 .34496 L p .52577 .34483 L F P
0 g
s
.52632 .34496 m .52677 .34502 L p .52629 .34493 L .672 .728 .891 r
F P
0 g
s
.52577 .34483 m .52632 .34496 L .52629 .34493 L .672 .728 .891 r
F
.52632 .34496 m .52657 .34416 L p .52632 .34496 L F P
0 g
s
.52656 .34472 m .5256 .34458 L .52652 .34463 L .672 .728 .891 r
F
.52626 .34438 m .52641 .34433 L .52633 .34422 L F
.52632 .34496 m .52641 .34491 L .53004 .34507 L F
.52659 .34491 m .52759 .34507 L .52663 .3449 L F
.52667 .34476 m .52668 .34475 L .52704 .34475 L F
.5266 .34482 m .52693 .34487 L .52661 .34482 L F
.5266 .34482 m .5266 .34481 L .52693 .34487 L F
.52717 .34492 m .5266 .34481 L .5266 .34481 L F
.52647 .34471 m .52774 .34498 L .52646 .3447 L F
.52692 .34487 m .52653 .34484 L .52704 .34475 L F
.52717 .34492 m .52693 .34487 L .52719 .34492 L F
.52693 .34487 m .52503 .34449 L .52692 .34487 L F
.52693 .34487 m .52692 .34487 L .52719 .34492 L F
.5266 .34355 m .52641 .34359 L .5275 .33816 L F
.52633 .34384 m .52663 .34351 L .52653 .34328 L F
.52639 .34366 m .52628 .34421 L .52608 .34387 L F
.5262 .3442 m .52641 .34397 L .52633 .34384 L F
.52623 .34296 m .52608 .34387 L .52597 .34394 L F
.52599 .34325 m .52587 .344 L .52633 .34384 L F
.52586 .34484 m .52518 .34466 L p .52586 .34484 L F P
0 g
s
.52518 .34466 m .52586 .34484 L .52586 .34484 L .672 .728 .891 r
F
.52653 .34484 m .52557 .34478 L .52667 .34476 L F
.52573 .34477 m .52579 .34477 L .5258 .34478 L F
.52557 .34478 m .52603 .34475 L .52601 .34477 L F
.52603 .34475 m .52525 .34476 L .52611 .3447 L F
.52545 .34462 m .52559 .34473 L .5262 .34481 L F
.52632 .34496 m .52632 .34496 L .52631 .34496 L F
.52394 .34467 m .52395 .34467 L .52466 .34476 L F
.52588 .34548 m .52608 .3451 L .52589 .34549 L F
.52608 .3451 m .52622 .34484 L .52609 .3451 L F
.52608 .3451 m .52609 .3451 L .52589 .34549 L F
.52568 .34555 m .52573 .34558 L .52579 .34543 L F
.52555 .34709 m .5255 .34702 L .5258 .34508 L F
.52573 .34512 m .52578 .34517 L .52585 .34494 L F
.52581 .34491 m .52585 .34494 L .52596 .34452 L F
.52573 .34512 m .52585 .34494 L .52581 .34491 L F
.52595 .34463 m .5256 .34458 L .52644 .3447 L F
.5266 .34481 m .5261 .34471 L .52611 .34471 L F
.52642 .34464 m .52642 .34464 L .52632 .34496 L F
.52691 .34475 m .52615 .34475 L .52664 .34459 L F
.52595 .34463 m .52644 .3447 L .52739 .34484 L F
.52664 .34459 m .52615 .34475 L .52611 .3447 L F
.52739 .34486 m .52595 .34463 L .52739 .34484 L F
.52611 .3447 m .52611 .3447 L .52761 .345 L F
.52653 .34484 m .52667 .34476 L .52704 .34475 L F
.52739 .34484 m .52656 .34472 L .52652 .34463 L F
.52665 .34461 m .5265 .34457 L .5268 .34484 L F
.52581 .34491 m .52596 .34452 L .52579 .34489 L F
.52558 .3455 m .52581 .34491 L .52558 .3455 L F
.52581 .34491 m .52596 .34452 L .52581 .34491 L F
.52581 .34491 m .52581 .34491 L .52558 .3455 L F
.52664 .34487 m .5272 .34497 L .52718 .34494 L F
.52611 .3447 m .52632 .34496 L .52652 .34464 L F
.52632 .34496 m .52623 .34485 L .52637 .34461 L F
.5268 .34465 m .52572 .34444 L .52586 .34438 L F
.52589 .34442 m .52494 .34429 L .52501 .34422 L F
.52589 .34442 m .52458 .34412 L .52579 .34446 L F
.52572 .34444 m .52539 .34436 L .52586 .34438 L F
.52596 .34452 m .52611 .3447 L .52617 .34457 L F
.52682 .34469 m .52572 .34444 L .5268 .34465 L F
.52652 .34463 m .52603 .3446 L .52594 .34449 L F
.5265 .34457 m .52586 .34438 L .52621 .34467 L F
.52586 .34438 m .52524 .34421 L .526 .34457 L F
.52586 .34438 m .526 .34457 L .52621 .34467 L F
.52601 .34474 m .5262 .34481 L .52617 .34477 L F
.52559 .34482 m .52621 .34482 L .52561 .34484 L F
.5258 .34508 m .52576 .34504 L .52579 .34482 L F
.52539 .34457 m .52539 .34457 L .5266 .34481 L F
.52603 .3446 m .52589 .34459 L .52594 .34449 L F
.5258 .34459 m .5256 .34458 L .52582 .34452 L F
.52586 .34438 m .52573 .34485 L .52594 .34449 L F
.52573 .34485 m .52575 .34486 L .52594 .34449 L F
.52507 .34481 m .52632 .34496 L .52632 .34496 L F
.52466 .34476 m .52507 .34481 L .52507 .34481 L F
.52507 .34481 m .52632 .34496 L .52507 .34481 L F
.52581 .34476 m .52585 .34475 L .52594 .34449 L F
.5257 .34496 m .52585 .34475 L .52581 .34476 L F
.52485 .34465 m .52563 .34476 L .52481 .34463 L F
.52611 .3447 m .52607 .34465 L .52739 .34486 L F
.52739 .34487 m .52739 .34486 L .52766 .3449 L F
.52611 .3447 m .52739 .34486 L .52739 .34487 L F
.54495 .34721 m .54483 .3472 L p .54461 .34716 L F P
0 g
s
.54513 .3464 m .52706 .34462 L .54485 .3472 L .672 .728 .891 r
F
.52632 .34495 m .52652 .34463 L .52652 .34464 L F
.52631 .34496 m .52652 .34463 L .52632 .34495 L F
.52683 .3447 m .52572 .34444 L .52682 .34469 L F
.52652 .34463 m .52632 .34496 L p .52645 .34446 L F P
0 g
s
.52623 .34485 m .52643 .34443 L .52645 .34446 L .672 .728 .891 r
F
.52631 .34463 m .52621 .34467 L .52627 .34405 L F
.52631 .34463 m .52643 .34443 L .52631 .34463 L F
.5264 .3446 m .52621 .34467 L .52625 .3444 L F
.52582 .34481 m .52579 .34482 L .52586 .34438 L F
.52563 .34476 m .52587 .3448 L .52561 .34475 L F
.52587 .3448 m .52623 .34484 L .52588 .34479 L F
.5257 .34496 m .52579 .34491 L .52579 .34489 L F
.5257 .34496 m .52579 .34489 L .52576 .34487 L F
.52573 .34485 m .5257 .34496 L .52575 .34486 L F
.5257 .34496 m .52551 .34568 L .52579 .34491 L F
.52573 .34485 m .52576 .34504 L .5257 .34496 L F
.52586 .34438 m .52579 .34482 L .52573 .34485 L F
.52573 .34485 m .5258 .3449 L .52577 .34483 L F
.52579 .34482 m .52576 .34504 L .52573 .34485 L F
.5254 .34456 m .52543 .34455 L .52607 .34465 L F
.52517 .34438 m .52523 .34442 L .52526 .3444 L F
.52523 .34442 m .52534 .3445 L .52526 .3444 L F
.52594 .34449 m .52532 .34455 L .52517 .34438 L F
.52503 .34449 m .52487 .34446 L .52488 .34446 L F
.52539 .34457 m .525 .34449 L .52539 .34457 L F
.525 .34449 m .52487 .34446 L .52501 .34448 L F
.525 .34449 m .52501 .34448 L .52503 .34449 L F
.52532 .34455 m .52395 .34467 L .52486 .34445 L F
.52532 .34455 m .52486 .34445 L .52517 .34438 L F
.5256 .34458 m .52503 .34449 L .52524 .34421 L F
.52503 .34449 m .52488 .34446 L .52524 .34421 L F
.52524 .34421 m .52467 .3443 L .52566 .34461 L F
.52596 .34452 m .52587 .34486 L .52611 .3447 L F
.52594 .34477 m .52593 .34477 L .52597 .34453 L F
.52632 .34496 m .52637 .34461 L .52641 .3446 L F
.52572 .34462 m .52564 .34461 L .52594 .34449 L F
.52554 .34474 m .52564 .34461 L .52572 .34462 L F
.52554 .34474 m .52548 .34467 L .52564 .34461 L F
.5261 .34471 m .525 .34449 L .52611 .34471 L F
.52544 .34461 m .5264 .34476 L .52536 .34455 L F
.52631 .34463 m .5262 .34481 L .52621 .34467 L F
.5272 .34498 m .52784 .34507 L .5272 .34498 L F
.5272 .34497 m .52785 .34507 L .52718 .34494 L F
.53244 .34598 m .53248 .34598 L p .52758 .345 L F P
0 g
s
.53591 .34848 m .54292 .35105 L p .5351 .34794 L .672 .728 .891 r
F P
0 g
s
.52889 .34533 m .52842 .3452 L .52902 .34529 L .672 .728 .891 r
F
.52632 .34496 m .52632 .34496 L .53296 .34576 L F
.52632 .34496 m .53296 .34576 L .53296 .34576 L F
.52632 .34496 m .53409 .34589 L .53409 .3459 L F
.52665 .34461 m .52666 .34462 L .52685 .3447 L F
.52601 .34477 m .52668 .34475 L .52667 .34476 L F
.52719 .34492 m .52611 .3447 L .52739 .34487 L F
.52795 .34507 m .52955 .34586 L .52923 .34553 L F
.52719 .34492 m .52739 .34487 L .5274 .34491 L F
.52665 .34461 m .52753 .34499 L .52795 .34507 L F
.52718 .34494 m .52785 .34507 L .52789 .34506 L F
.52749 .3451 m .52903 .34529 L p .52766 .34509 L F P
0 g
s
.52874 .34538 m .52751 .34505 L .52877 .34537 L .672 .728 .891 r
F
.52753 .34499 m .52894 .34559 L .52795 .34507 L F
.52894 .34559 m .52905 .34561 L .52795 .34507 L F
.52666 .34489 m .5272 .34497 L .52664 .34487 L F
.52686 .34485 m .52703 .34505 L .52694 .34487 L F
.52718 .34494 m .52789 .34506 L .52743 .34497 L F
.52756 .34503 m .52766 .34509 L .52784 .34507 L F
.52759 .34507 m .52766 .34509 L .52756 .34503 L F
.52836 .34549 m .52671 .34506 L .52874 .34538 L F
.52753 .34499 m .52703 .34505 L .52955 .34586 L F
.52685 .3447 m .52694 .34487 L .52753 .34499 L F
.52659 .34481 m .52743 .34497 L .52686 .34486 L F
.52615 .34475 m .52603 .34475 L .52611 .3447 L F
.52603 .34509 m .52601 .34507 L .52611 .3447 L F
.52625 .3444 m .52611 .3447 L .526 .34432 L F
.52623 .34484 m .52588 .34479 L .52588 .34479 L F
.52597 .34476 m .5262 .34481 L .52601 .34474 L F
.52611 .3447 m .52589 .34521 L .52595 .34476 L F
.52611 .3447 m .52595 .34476 L .52598 .34454 L F
.52579 .34489 m .52596 .34452 L .52594 .34449 L F
.52524 .34421 m .52603 .34473 L .52611 .3447 L F
.526 .34457 m .52611 .3447 L .52621 .34467 L F
.526 .34432 m .52597 .34453 L .52591 .34436 L F
.52609 .34471 m .52686 .34486 L .5264 .34476 L F
.52751 .34335 m .53487 .33345 L p .52679 .34351 L F P
0 g
s
.52787 .34251 m .52721 .34348 L .52789 .34215 L .672 .728 .891 r
F
.52721 .34348 m .52719 .34328 L .52789 .34215 L F
.52462 .34449 m .52606 .34472 L .52609 .34471 L F
.52462 .34449 m .52606 .34472 L .52462 .34449 L F
.52597 .34453 m .52593 .34477 L .5259 .34445 L F
.52593 .34477 m .52589 .34503 L .52589 .34478 L F
.52593 .34477 m .52589 .34478 L .5259 .34445 L F
.52594 .34449 m .5256 .34458 L .52539 .34436 L F
.52556 .3443 m .52539 .34436 L .52524 .34421 L F
.52524 .34421 m .52611 .3447 L .526 .34457 L F
.52611 .3447 m .52598 .34454 L .526 .34432 L F
.52623 .34484 m .52622 .34484 L .52588 .34479 L F
.52588 .34479 m .52588 .34479 L .52561 .34475 L F
.52612 .34471 m .52611 .3447 L .52627 .34405 L F
.52586 .3448 m .5267 .34493 L .52587 .3448 L F
.5267 .34493 m .52721 .34501 L .5267 .34493 L F
.52564 .34488 m .52645 .34488 L .52641 .34491 L F
.5267 .34493 m .5267 .34493 L .52587 .3448 L F
.52606 .34472 m .52686 .34486 L .52609 .34471 L F
.52589 .34479 m .52486 .34464 L .52486 .34464 L F
.52719 .34328 m .52678 .34393 L .52716 .34306 L F
.5272 .34498 m .52589 .34479 L .52589 .34479 L F
.5272 .34498 m .52589 .34479 L .5272 .34498 L F
.52643 .34443 m .52631 .34463 L .52627 .34405 L F
.5265 .34413 m .5264 .3446 L p .52625 .3444 L F P
0 g
s
.5264 .3446 m .5265 .34413 L p .52634 .34453 L .672 .728 .891 r
F P
0 g
s
.52721 .34501 m .52721 .34501 L .52587 .3448 L .672 .728 .891 r
F
.52581 .3451 m .5258 .34508 L .52584 .34481 L F
.52581 .3451 m .52584 .34481 L .52585 .3448 L F
.52603 .34509 m .52605 .345 L .52605 .345 L F
.52605 .345 m .52611 .3447 L .52605 .345 L F
.52559 .34473 m .52666 .34489 L .52664 .34487 L F
.52605 .345 m .52611 .3447 L .52612 .34471 L F
.52567 .34491 m .525 .34486 L p .52563 .34487 L F P
0 g
s
.525 .34486 m .50748 .34352 L p .52499 .34483 L .672 .728 .891 r
F P
0 g
s
.525 .34486 m .52499 .34483 L .52563 .34487 L .672 .728 .891 r
F
.52589 .34503 m .52584 .34533 L .52582 .34504 L F
.52558 .3455 m .52581 .34491 L .52579 .34489 L F
.52576 .34505 m .5257 .34545 L .52567 .34507 L F
.52549 .34519 m .52491 .34641 L .5244 .34679 L F
.52585 .3448 m .52584 .34481 L .52591 .34436 L F
.52686 .34485 m .52694 .34487 L .52685 .3447 L F
.52735 .34495 m .52721 .34492 L .52872 .345 L F
.5275 .33816 m .52661 .34256 L .52623 .34296 L F
.52651 .34018 m .52614 .34238 L .5269 .34227 L F
.52614 .34238 m .52653 .34328 L .5269 .34227 L F
.52707 .34255 m .53027 .33236 L p .5275 .33816 L F P
0 g
s
.52806 .33691 m .52662 .34355 L p .5275 .33816 L .672 .728 .891 r
F P
0 g
s
.52662 .34355 m .5266 .34355 L .5275 .33816 L .672 .728 .891 r
F
.5269 .34227 m .52806 .33691 L p .52651 .34018 L F P
0 g
s
.52647 .34362 m .52646 .34363 L .52775 .33276 L .672 .728 .891 r
F
.52781 .33251 m .52648 .34361 L p .52775 .33276 L F P
0 g
s
.52648 .34361 m .52647 .34362 L .52775 .33276 L .672 .728 .891 r
F
.52661 .34256 m .52639 .34366 L .52623 .34296 L F
.52614 .34238 m .52599 .34325 L .52653 .34328 L F
.52639 .34366 m .52608 .34387 L .52623 .34296 L F
.52599 .34325 m .52633 .34384 L .52653 .34328 L F
.52713 .33644 m .52646 .34363 L .52587 .344 L F
.52775 .33276 m .52728 .33672 L .52713 .33644 L F
.52728 .33672 m .52646 .34363 L .52713 .33644 L F
.5133 .33558 m .51421 .33503 L p .52071 .34003 L F P
0 g
s
.52692 .34487 m .52704 .34475 L .52775 .34475 L .672 .728 .891 r
F
.5265 .34457 m .52643 .34477 L .5268 .34484 L F
.5264 .34476 m .52716 .34488 L .52609 .34467 L F
.52898 .34528 m .52719 .34492 L .52766 .3449 L F
.52739 .34484 m .52683 .3447 L .52739 .34482 L F
.52775 .34475 m .52691 .34475 L .52664 .34459 L F
.52683 .3447 m .52682 .34469 L .52739 .34482 L F
.52739 .34482 m .52682 .34469 L .5268 .34465 L F
.52766 .3449 m .52739 .34484 L .52739 .34482 L F
.5274 .34491 m .52739 .34487 L .52766 .3449 L F
.52766 .3449 m .52739 .34486 L .52739 .34484 L F
.52784 .34507 m .52809 .3451 L .52785 .34507 L F
.52898 .34528 m .52665 .34461 L .52795 .34507 L F
.52809 .3451 m .52915 .34525 L .52803 .34509 L F
.52809 .3451 m .52803 .34509 L .52785 .34507 L F
.52766 .34509 m .52903 .34529 L .52784 .34507 L F
.52877 .34537 m .52842 .3452 L .52889 .34533 L F
.52898 .34528 m .52795 .34507 L .52898 .34544 L F
.52898 .34528 m .52795 .34507 L .52898 .34528 L F
.52909 .34539 m .52898 .34544 L .52923 .34553 L F
.52898 .34528 m .52898 .34544 L .52909 .34539 L F
.52665 .34461 m .5268 .34484 L .52686 .34485 L F
.52716 .34488 m .52715 .34486 L .52609 .34467 L F
.52841 .34507 m .5284 .34506 L .52715 .34485 L F
.52715 .34486 m .52715 .34485 L .52609 .34467 L F
.52841 .34507 m .52715 .34485 L .52715 .34486 L F
.52688 .34419 m .52785 .34288 L .52785 .34289 L F
.52641 .34397 m .52663 .34351 L .52633 .34384 L F
.52642 .34398 m .52646 .34363 L .52647 .34362 L F
.52666 .34462 m .52686 .34485 L .52685 .3447 L F
.52643 .34443 m .52643 .34443 L .52603 .34509 L F
.52652 .34464 m .52681 .34417 L .52681 .34417 L F
.52652 .34463 m .52715 .34363 L p .52652 .34464 L F P
0 g
s
.52636 .34455 m .52596 .34451 L .52639 .34458 L .672 .728 .891 r
F
.52588 .34548 m .52582 .34544 L .5262 .34481 L F
.52622 .34484 m .5262 .34481 L .52643 .34443 L F
.52626 .34489 m .52648 .34493 L .52625 .34488 L F
.52628 .34421 m .52625 .3444 L .526 .34432 L F
.52611 .3447 m .52604 .34462 L .52627 .34405 L F
.52596 .34451 m .52599 .34455 L .52641 .34461 L F
.52639 .34458 m .52641 .34461 L .52709 .3447 L F
.52596 .34451 m .52641 .34461 L .52639 .34458 L F
.52622 .34466 m .52621 .34467 L .52628 .3447 L F
.52622 .34466 m .52628 .3447 L .52643 .34477 L F
.52603 .34509 m .52643 .34443 L .52643 .34443 L F
.52603 .34509 m .52643 .34443 L .52643 .34443 L F
.52577 .34483 m .52677 .34502 L .52674 .34498 L F
.52632 .34496 m .52677 .3451 L p .52639 .34491 L F P
0 g
s
.52836 .34549 m .52745 .34526 L p .52836 .34549 L .672 .728 .891 r
F P
0 g
s
.52745 .34526 m .52586 .34484 L p .52745 .34526 L .672 .728 .891 r
F P
0 g
s
.52745 .34526 m .52745 .34526 L .52836 .34549 L .672 .728 .891 r
F
.52785 .34291 m .52724 .34372 L p .52785 .34289 L F P
0 g
s
.52632 .34496 m .52632 .34496 L .52857 .34555 L .672 .728 .891 r
F
.52822 .34546 m .52857 .34555 L .52857 .34555 L F
.52586 .34484 m .52822 .34546 L .52822 .34546 L F
.52822 .34546 m .52857 .34555 L .52822 .34546 L F
.52586 .34484 m .52586 .34484 L .52822 .34546 L F
.52677 .3451 m .52582 .34481 L p .52675 .34506 L F P
0 g
s
.5263 .34464 m .52622 .34466 L .52628 .34469 L .672 .728 .891 r
F
.5263 .34464 m .52628 .34469 L .52643 .34477 L F
.5265 .34457 m .5263 .34464 L .52643 .34477 L F
.52638 .3446 m .52621 .34467 L .52813 .34493 L F
.52664 .34459 m .52862 .34499 L .52863 .34497 L F
.52971 .34503 m .52664 .34459 L .52966 .34516 L F
.53004 .34507 m .5275 .34491 L .52775 .34475 L F
.52812 .34489 m .52813 .34493 L .52923 .34508 L F
.52638 .3446 m .52813 .34493 L .52812 .34489 L F
.52724 .34372 m .52724 .3437 L .52785 .34289 L F
.5271 .34391 m .52724 .34372 L p .52706 .34385 L F P
0 g
s
.52688 .34419 m .52785 .34288 L .52688 .34419 L .672 .728 .891 r
F
.5264 .34476 m .52537 .34455 L .52536 .34455 L F
.52564 .34488 m .52564 .34488 L .52632 .34496 L F
.52585 .34494 m .52578 .34517 L .52591 .34499 L F
.52589 .34503 m .52582 .34504 L .52585 .3448 L F
.52589 .34478 m .52585 .3448 L .52591 .34436 L F
.52589 .34503 m .52585 .3448 L .52589 .34478 L F
.52566 .34479 m .52582 .34481 L .52563 .34476 L F
.5265 .34413 m .52625 .3444 L .52633 .34419 L F
.52624 .34442 m .5265 .34413 L .52642 .344 L F
.52582 .34481 m .52671 .34494 L .52586 .3448 L F
.52671 .34494 m .5267 .34493 L .52586 .3448 L F
.52582 .34481 m .52626 .34489 L .52625 .34488 L F
.52566 .34479 m .52581 .34482 L .52582 .34481 L F
.52581 .34482 m .52626 .34489 L .52582 .34481 L F
.52631 .3445 m .52634 .34453 L .5265 .34413 L F
.52641 .3446 m .52637 .34461 L .52645 .34446 L F
.5268 .3442 m .52652 .34463 L p .52674 .34393 L F P
0 g
s
.52652 .34463 m .52645 .34446 L .52674 .34393 L .672 .728 .891 r
F
.52657 .34462 m .52691 .34416 L p .52621 .34449 L F P
0 g
s
.52691 .34416 m .52708 .34392 L p .52682 .34409 L .672 .728 .891 r
F P
0 g
s
.52621 .34449 m .52691 .34416 L .52682 .34409 L .672 .728 .891 r
F
.5259 .34443 m .52584 .34481 L .52586 .34438 L F
.52584 .34481 m .52582 .34481 L .52586 .34438 L F
.52576 .34487 m .52579 .34489 L .52585 .34475 L F
.52577 .34483 m .52749 .3451 L .52581 .34482 L F
.5258 .34505 m .5258 .34505 L .52586 .34438 L F
.52524 .34421 m .52566 .34461 L .52594 .34467 L F
.52456 .34448 m .52462 .34449 L .52462 .34449 L F
.52439 .34442 m .52544 .34461 L .52536 .34455 L F
.52269 .34419 m .52441 .34445 L .52439 .34442 L F
.52441 .34445 m .52544 .34461 L .52439 .34442 L F
.5254 .34456 m .52503 .34449 L .52543 .34455 L F
.52545 .34462 m .52597 .34476 L .52601 .34474 L F
.52591 .34503 m .52597 .34453 L .52598 .34454 L F
.52589 .34521 m .52591 .34503 L .52591 .34503 L F
.52591 .34503 m .52597 .34453 L .52591 .34503 L F
.5261 .3447 m .52608 .34467 L .52537 .34455 L F
.52611 .3447 m .52608 .34467 L .5261 .3447 L F
.52611 .3447 m .52609 .34467 L .52608 .34467 L F
.52611 .34471 m .52604 .34462 L .52611 .3447 L F
.52604 .34462 m .52599 .34455 L .52627 .34405 L F
.52642 .344 m .52642 .344 L .52611 .3447 L F
.52601 .34507 m .52603 .34473 L .52611 .34471 L F
.52599 .34515 m .526 .34506 L .52601 .34507 L F
.526 .34506 m .52603 .34473 L .52601 .34507 L F
.52632 .34496 m .52611 .34508 L .52623 .34485 L F
.52622 .34484 m .52643 .34443 L .52623 .34485 L F
.52711 .34387 m .52702 .3439 L .52721 .34348 L F
.52724 .3437 m .52711 .34387 L .52721 .34348 L F
.52631 .3445 m .5265 .34413 L .52624 .34442 L F
.52629 .3444 m .52724 .34372 L .526 .3445 L F
.52688 .34418 m .52683 .34405 L .52721 .34348 L F
.52662 .34355 m .5265 .34413 L p .52658 .34363 L F P
0 g
s
.5265 .34413 m .52662 .34355 L p .52642 .344 L .672 .728 .891 r
F P
0 g
s
.52645 .34393 m .52751 .34335 L .52679 .34351 L .672 .728 .891 r
F
.52678 .34393 m .52673 .34381 L .52716 .34306 L F
.52688 .34419 m .52724 .3437 L .52724 .3437 L F
.52724 .3437 m .52724 .3437 L .52785 .34288 L F
.52679 .34394 m .52678 .34393 L .52719 .34328 L F
.52721 .34348 m .52652 .3445 L .52719 .34328 L F
.52642 .344 m .52724 .34372 L .52645 .34393 L F
.52785 .34288 m .52724 .3437 L .52787 .34251 L F
.52724 .3437 m .52721 .34348 L .52787 .34251 L F
.52901 .34131 m .52785 .34288 L .52929 .3404 L F
.52785 .34288 m .52787 .34251 L .52929 .3404 L F
.52785 .34289 m .52785 .34288 L .52901 .34131 L F
.52899 .34136 m .52785 .34291 L p .52901 .34131 L F P
0 g
s
.52785 .34291 m .52785 .34289 L .52901 .34131 L .672 .728 .891 r
F
.53433 .33419 m .52899 .34136 L p .53445 .33398 L F P
0 g
s
.52899 .34136 m .52901 .34131 L .53445 .33398 L .672 .728 .891 r
F
.52731 .34382 m .53594 .33385 L p .52647 .34404 L F P
0 g
s
.52957 .3412 m .52786 .34318 L p .52966 .34084 L .672 .728 .891 r
F P
0 g
s
.52616 .34469 m .52814 .34502 L .52621 .34467 L .672 .728 .891 r
F
.52814 .34502 m .52814 .34501 L .52621 .34467 L F
.52898 .34528 m .52874 .34503 L .53004 .34507 L F
.52923 .3452 m .52923 .3452 L .52814 .34501 L F
.52814 .34501 m .52814 .34501 L .52621 .34467 L F
.52923 .3452 m .52814 .34501 L .52814 .34501 L F
.5262 .34482 m .52632 .34496 L .52639 .34491 L F
.5272 .34498 m .5272 .34498 L .52561 .34475 L F
.52631 .34463 m .52631 .34463 L .52603 .34509 L F
.52617 .34477 m .5262 .34481 L .52664 .34487 L F
.52545 .34462 m .52664 .34487 L .52659 .34481 L F
.52623 .34485 m .52766 .34509 L .52623 .34484 L F
.52648 .34493 m .52749 .3451 L .52653 .34492 L F
.52621 .34467 m .52603 .34473 L .52694 .34502 L F
.52696 .34502 m .52694 .34502 L .52703 .34505 L F
.52561 .34475 m .52785 .34507 L .52559 .34473 L F
.52621 .34467 m .52694 .34502 L .52696 .34502 L F
.52623 .34484 m .52667 .34491 L .52622 .34484 L F
.52667 .34491 m .52667 .3449 L .52561 .34475 L F
.52625 .34488 m .52648 .34493 L .52653 .34492 L F
.52603 .34473 m .52677 .3451 L .52691 .34504 L F
.52672 .345 m .52673 .345 L .52578 .34475 L F
.5263 .34494 m .52626 .34489 L .5276 .34527 L F
.5276 .34529 m .5276 .34527 L .52955 .34582 L F
.52677 .3451 m .528 .34542 L p .52691 .34504 L F P
0 g
s
.5263 .34494 m .5276 .34527 L .5276 .34529 L .672 .728 .891 r
F
.52729 .34375 m .52783 .343 L .52784 .34307 L F
.5262 .34481 m .52612 .34471 L .52627 .34405 L F
.52625 .3444 m .52619 .34467 L .52611 .3447 L F
.52636 .34415 m .52611 .3447 L .52611 .3447 L F
.52642 .344 m .52636 .34415 L .52636 .34415 L F
.52636 .34415 m .52611 .3447 L .52636 .34415 L F
.52603 .34473 m .5259 .34478 L .52618 .34485 L F
.52611 .3447 m .52608 .345 L .52597 .34502 L F
.52624 .34487 m .52624 .34487 L .52578 .34474 L F
.52605 .34512 m .5262 .34481 L .52606 .34514 L F
.5262 .34481 m .52603 .34509 L .52612 .34471 L F
.52603 .34509 m .52631 .34463 L .52603 .34509 L F
.52599 .34515 m .52599 .34515 L .52643 .34443 L F
.52619 .34467 m .52605 .34535 L .52611 .3447 L F
.52602 .3454 m .52623 .34524 L .52614 .34517 L F
.52551 .34568 m .52558 .3455 L .52558 .3455 L F
.52551 .34568 m .52526 .34664 L .52569 .34553 L F
.52526 .34664 m .52558 .34591 L .52569 .34553 L F
.52556 .34549 m .52553 .34603 L .52526 .34664 L F
.52553 .34603 m .52547 .34698 L .52526 .34665 L F
.52553 .34603 m .52526 .34665 L .52526 .34664 L F
.52526 .34664 m .52632 .34496 L .52526 .34664 L F
.52595 .34554 m .52614 .34525 L p .52595 .34554 L F P
0 g
s
.52614 .34525 m .52652 .34463 L p .52614 .34525 L .672 .728 .891 r
F P
0 g
s
.52595 .34554 m .52614 .34525 L .52614 .34525 L .672 .728 .891 r
F
.52632 .34496 m .52526 .34665 L p .52611 .34508 L F P
0 g
s
.52244 .35732 m .52544 .34775 L p .52242 .35737 L .672 .728 .891 r
F P
0 g
s
.52544 .34775 m .52632 .34496 L p .52544 .34775 L .672 .728 .891 r
F P
0 g
s
.52242 .35737 m .52544 .34775 L .52544 .34775 L .672 .728 .891 r
F
.52589 .34549 m .52609 .3451 L .52611 .34508 L F
.52605 .34535 m .52605 .34535 L .52611 .3447 L F
.52582 .34481 m .5263 .34496 L p .52599 .34483 L F P
0 g
s
.52611 .34508 m .52618 .34492 L .52617 .34496 L .672 .728 .891 r
F
.52618 .34492 m .52622 .34484 L .52617 .34496 L F
.52617 .34496 m .52622 .34484 L .52623 .34485 L F
.52602 .3454 m .52615 .34551 L .52623 .34524 L F
.5264 .34476 m .52615 .34469 L .52611 .3447 L F
.52615 .34469 m .52609 .34467 L .52611 .3447 L F
.52643 .34443 m .52674 .34393 L .52674 .34393 L F
.526 .3445 m .52724 .34372 L .52639 .34401 L F
.52625 .34529 m .52613 .34533 L .52619 .34481 L F
.52626 .34489 m .52624 .34487 L .52612 .34509 L F
.52671 .34494 m .52766 .34509 L .5267 .34493 L F
.52784 .34507 m .52785 .34507 L .52622 .34483 L F
.52694 .34487 m .52703 .34505 L .52753 .34499 L F
.52686 .34485 m .5268 .34484 L .52703 .34505 L F
.52677 .34489 m .5268 .34488 L .52807 .34522 L F
.52672 .345 m .52649 .34493 L .52649 .34493 L F
.52632 .34496 m .52619 .34481 L .52621 .34467 L F
.52603 .34473 m .52691 .34504 L .52694 .34502 L F
.52587 .34281 m .52583 .34326 L .52648 .34361 L F
.52566 .34461 m .52582 .34481 L .52603 .34473 L F
.52587 .34465 m .52566 .34461 L .52586 .34467 L F
.52587 .34465 m .52586 .34467 L .52603 .34473 L F
.52594 .34467 m .52587 .34465 L .52603 .34473 L F
.52621 .34467 m .52619 .34467 L .52625 .3444 L F
.52589 .34453 m .52621 .34467 L .52638 .3446 L F
.52521 .34444 m .52579 .34457 L .52589 .34453 L F
.52579 .34457 m .52621 .34467 L .52589 .34453 L F
.52627 .34405 m .52599 .34455 L .52596 .34451 L F
.52628 .34421 m .526 .34432 L .52608 .34387 L F
.52627 .34405 m .52596 .34451 L .52639 .34401 L F
.52582 .34481 m .52586 .3448 L .52563 .34476 L F
.52587 .3448 m .52588 .34479 L .52561 .34475 L F
.52603 .34473 m .52606 .34475 L .52607 .34475 L F
.52606 .34475 m .52632 .34496 L .52607 .34475 L F
.52632 .34496 m .52625 .34529 L p .52619 .34481 L F P
0 g
s
.52606 .34514 m .5262 .34481 L .52622 .34484 L .672 .728 .891 r
F
.52607 .34475 m .52632 .34496 L .5262 .34482 L F
.52577 .34474 m .52615 .34476 L .52624 .34487 L F
.52536 .34455 m .52436 .34435 L .52536 .34455 L F
.5244 .34436 m .52436 .34435 L .52536 .34455 L F
.52622 .34483 m .52622 .34483 L .52486 .34464 L F
.52622 .34484 m .52622 .34483 L .52486 .34464 L F
.52536 .34455 m .52536 .34455 L .52537 .34455 L F
.52536 .34455 m .52537 .34455 L .52537 .34455 L F
.52563 .34476 m .52586 .3448 L .52587 .3448 L F
.52508 .3445 m .52582 .34481 L .52566 .34461 L F
.52436 .34435 m .52439 .34442 L .52536 .34455 L F
.52463 .3444 m .52513 .34457 L .52508 .3445 L F
.52456 .34448 m .52559 .34473 L .52545 .34462 L F
.52513 .34457 m .52582 .34481 L .52508 .3445 L F
.52596 .34451 m .52581 .34479 L .52579 .34476 L F
.5257 .3446 m .52616 .34469 L .52621 .34467 L F
.52603 .34473 m .52604 .34462 L .52611 .34471 L F
.52589 .34521 m .52586 .34517 L .52593 .34477 L F
.52589 .34521 m .52593 .34477 L .52594 .34477 L F
.52599 .34515 m .52577 .34528 L .52604 .34462 L F
.52521 .34444 m .52536 .34455 L .52621 .34467 L F
.52596 .34451 m .52521 .34444 L .52599 .34455 L F
.52596 .34451 m .52552 .34458 L .52521 .34444 L F
.526 .34432 m .52591 .34436 L .52597 .34394 L F
.52597 .34394 m .52591 .34436 L .52586 .34438 L F
.52587 .344 m .52581 .34433 L .52615 .34432 L F
.52577 .34528 m .52599 .34455 L .52604 .34462 L F
.52579 .34476 m .52611 .3447 L .52603 .3446 L F
.52579 .34476 m .52582 .34473 L .52581 .34473 L F
.52584 .34481 m .5258 .34505 L .52582 .34481 L F
.5258 .34505 m .5258 .34508 L .5258 .34505 L F
.5258 .34508 m .52579 .34482 L .52582 .34481 L F
.52577 .34528 m .52568 .34533 L .52599 .34455 L F
.52567 .34507 m .5257 .34545 L .52556 .34549 L F
.52568 .34533 m .52546 .34546 L .52558 .34526 L F
.52624 .34487 m .52624 .34487 L .52578 .34474 L F
.52578 .34474 m .52578 .34474 L .52518 .34458 L F
.52624 .34487 m .52578 .34474 L .52578 .34474 L F
.5257 .34496 m .52576 .34505 L .52567 .34507 L F
.52576 .34504 m .52576 .34505 L .5257 .34496 L F
.52568 .34533 m .52558 .34526 L .52583 .34482 L F
.52586 .34486 m .52583 .34482 L .52599 .34455 L F
.52568 .34533 m .52583 .34482 L .52586 .34486 L F
.52582 .34473 m .52623 .34445 L .52581 .34473 L F
.52659 .34481 m .52664 .34487 L .52743 .34497 L F
.52622 .34483 m .52785 .34507 L .52622 .34483 L F
.52784 .34507 m .52622 .34483 L .52622 .34484 L F
.52667 .34491 m .5272 .34498 L .52667 .3449 L F
.5268 .34484 m .52643 .34477 L .52703 .34505 L F
.52612 .34471 m .52688 .34487 L .5268 .34488 L F
.52615 .34468 m .52611 .3447 L .52596 .34451 L F
.52617 .34478 m .52625 .34462 L .52611 .34471 L F
.52636 .34455 m .52615 .34468 L .52596 .34451 L F
.52625 .34462 m .52631 .3445 L .52612 .3447 L F
.52625 .34462 m .52612 .3447 L .52611 .34471 L F
.52726 .34464 m .52621 .34472 L .52615 .34468 L F
.5264 .3446 m .52632 .34496 L p .52621 .34467 L F P
0 g
s
.52622 .34484 m .5264 .3446 L .52634 .34453 L .672 .728 .891 r
F
.52706 .34462 m .52636 .34455 L .52709 .3447 L F
.52636 .34455 m .52639 .34458 L .52709 .3447 L F
.52726 .34464 m .52615 .34468 L .52636 .34455 L F
.52621 .34472 m .52611 .3447 L .52615 .34468 L F
.52649 .34493 m .52578 .34474 L .52578 .34474 L F
.5259 .34478 m .52582 .34481 L .52618 .34485 L F
.52649 .34493 m .52578 .34475 L .52578 .34474 L F
.52599 .34455 m .52558 .34526 L .52596 .34451 L F
.52582 .34481 m .52578 .34475 L .52626 .34489 L F
.52579 .34476 m .52558 .34526 L .52549 .34519 L F
.52581 .34479 m .52558 .34526 L .52579 .34476 L F
.52613 .34533 m .52619 .34467 L .52621 .34467 L F
.52609 .3451 m .52622 .34484 L .52611 .34508 L F
.52597 .34658 m .5258 .34663 L .52605 .34535 L F
.52611 .34533 m .52605 .34535 L .52619 .34467 L F
.52597 .34658 m .52605 .34535 L .52611 .34533 L F
.52785 .34507 m .52915 .34525 L .52803 .34505 L F
.52799 .34508 m .52802 .34508 L .52808 .3451 L F
.54461 .34716 m .53224 .34567 L .53004 .34507 L F
.52923 .345 m .52923 .34508 L .54485 .3472 L F
.52721 .34501 m .52766 .34509 L .52721 .34501 L F
.52706 .34462 m .52709 .3447 L .54485 .3472 L F
.54293 .34623 m .53184 .34538 L p .54211 .3461 L F P
0 g
s
.52888 .34576 m .52971 .34602 L p .529 .34577 L .672 .728 .891 r
F P
0 g
s
.5351 .34794 m .5281 .34544 L .53591 .34848 L .672 .728 .891 r
F
.52655 .34479 m .52688 .34487 L .52612 .34471 L F
.52581 .34473 m .52623 .34445 L .526 .3445 L F
.52573 .34467 m .52599 .34472 L .52577 .34474 L F
.52514 .34456 m .52573 .34467 L .52577 .34474 L F
.52596 .34451 m .52579 .34476 L .526 .3445 L F
.52578 .34474 m .52578 .34474 L .52518 .34458 L F
.52537 .34455 m .52568 .34461 L .5257 .3446 L F
.52568 .34461 m .52616 .34469 L .5257 .3446 L F
.52536 .34455 m .52537 .34455 L .52621 .34467 L F
.52611 .3447 m .52552 .34458 L .52596 .34451 L F
.52569 .34462 m .52566 .34458 L .52612 .34471 L F
.52666 .34485 m .52666 .34485 L .5268 .34488 L F
.52579 .34476 m .52549 .34519 L .52599 .34497 L F
.52618 .34485 m .52605 .34484 L .52621 .34487 L F
.52605 .34484 m .52599 .34483 L .52621 .34487 L F
.52621 .34487 m .52599 .34483 L .52632 .34496 L F
.52569 .34695 m .52632 .34496 L .52632 .34496 L F
.52242 .35737 m .52569 .34695 L .52569 .34695 L F
.52569 .34695 m .52632 .34496 L .52569 .34695 L F
.52578 .34517 m .52568 .34555 L .52585 .34523 L F
.52574 .34556 m .5258 .34508 L .52575 .34552 L F
.52584 .34533 m .52575 .34552 L .52582 .34504 L F
.5258 .34508 m .52572 .34561 L .52576 .34504 L F
.52579 .34543 m .52562 .34583 L .52585 .3457 L F
.52527 .34662 m .52582 .34544 L .52588 .34548 L F
.52572 .34561 m .5255 .34702 L .52567 .34571 L F
.52572 .34561 m .52567 .34571 L .52576 .34504 L F
.52527 .34663 m .52588 .34548 L .52589 .34549 L F
.52472 .34788 m .52472 .34788 L .52599 .34498 L F
.52525 .34667 m .52527 .34662 L .52527 .34663 L F
.52527 .34662 m .52588 .34548 L .52527 .34663 L F
.52589 .34521 m .52584 .34533 L .52586 .34517 L F
.52589 .34521 m .52549 .34598 L .52577 .34528 L F
.52599 .34515 m .52572 .34559 L .52589 .34521 L F
.52568 .34555 m .52558 .34591 L .52573 .34558 L F
.52572 .34559 m .52549 .34598 L .52589 .34521 L F
.52575 .34552 m .5258 .34508 L .52581 .3451 L F
.52555 .34709 m .52574 .34556 L .52575 .34552 L F
.52589 .34521 m .52589 .34522 L .52589 .34521 L F
.52567 .34728 m .52589 .34522 L .52589 .34521 L F
.52567 .34728 m .52556 .34712 L .52589 .34522 L F
.52572 .3456 m .52599 .34515 L .52572 .3456 L F
.52527 .34662 m .52572 .3456 L .52582 .34544 L F
.52572 .3456 m .52572 .34559 L .52599 .34515 L F
.52572 .3456 m .52599 .34515 L .52599 .34515 L F
.5268 .34488 m .52688 .34487 L .52807 .34522 L F
.52716 .34488 m .52841 .34507 L .52715 .34486 L F
.52784 .34507 m .5272 .34498 L .5272 .34498 L F
.52735 .34495 m .52872 .345 L .52873 .34502 L F
.52686 .34486 m .52743 .34497 L .52803 .34505 L F
.52743 .34497 m .52789 .34506 L .52803 .34505 L F
.5264 .34476 m .52803 .34505 L .52816 .34503 L F
.52688 .34487 m .52692 .34486 L .52808 .3451 L F
.52777 .34503 m .52708 .3449 L .52801 .34485 L F
.52655 .34479 m .52671 .34482 L .52688 .34487 L F
.52624 .34487 m .52615 .34476 L .52709 .34504 L F
.52621 .34467 m .52814 .34501 L .52813 .34493 L F
.52783 .343 m .52727 .34365 L .52781 .34282 L F
.52758 .34518 m .52615 .34476 L .52756 .34509 L F
.52626 .34489 m .5264 .3446 L .52624 .34487 L F
.52609 .34565 m .52612 .34533 L .52613 .34533 L F
.52618 .34559 m .52632 .34496 L p .52575 .34602 L F P
0 g
s
.52632 .34496 m .5264 .3446 L p .52626 .34489 L .672 .728 .891 r
F P
0 g
s
.52605 .34535 m .52604 .34541 L .52605 .34535 L .672 .728 .891 r
F
.52608 .34565 m .52611 .34533 L .52609 .34565 L F
.52611 .34533 m .52619 .34467 L .52612 .34533 L F
.52611 .34533 m .52612 .34533 L .52609 .34565 L F
.52613 .34472 m .52666 .34485 L .52613 .34472 L F
.52615 .34476 m .52613 .34473 L .52667 .34486 L F
.5252 .34457 m .52535 .34451 L .52615 .34476 L F
.52611 .3447 m .52611 .3447 L .52606 .34482 L F
.52624 .34487 m .5264 .3446 L .52622 .34484 L F
.526 .34497 m .52617 .34478 L .52611 .34471 L F
.52599 .34472 m .52615 .34476 L .52589 .34474 L F
.52611 .34471 m .52611 .3447 L .52606 .34482 L F
.52515 .34457 m .52625 .34487 L .52626 .34489 L F
.52579 .34476 m .52624 .34486 L .52611 .3447 L F
.52573 .34463 m .52612 .34471 L .52666 .34485 L F
.52594 .34481 m .52607 .34473 L .52687 .34471 L F
.52873 .34502 m .52872 .345 L .53004 .34507 L F
.52638 .3446 m .52923 .34508 L .52923 .345 L F
.52677 .34475 m .52687 .34471 L .52771 .34468 L F
.52594 .34481 m .52687 .34471 L .52677 .34475 L F
.52805 .34509 m .52632 .34496 L p .52805 .34509 L F P
0 g
s
.52624 .34487 m .52709 .34504 L .52712 .34507 L .672 .728 .891 r
F
.52715 .34502 m .52715 .34502 L .52632 .34496 L F
.5263 .34496 m .52632 .34496 L p .52599 .34483 L F P
0 g
s
.52612 .34509 m .52624 .34487 L .52622 .34484 L .672 .728 .891 r
F
.52549 .34519 m .52596 .34506 L .52624 .34486 L F
.52584 .34533 m .52555 .34709 L .52575 .34552 L F
.52589 .34521 m .52556 .34712 L .52584 .34533 L F
.52526 .34665 m .52527 .34663 L .52611 .34508 L F
.52551 .34568 m .52567 .34555 L .52558 .3455 L F
.52567 .34555 m .52569 .34553 L .52558 .3455 L F
.5257 .34545 m .52547 .34698 L .52556 .34549 L F
.52553 .34604 m .52575 .34602 L .52609 .34517 L F
.52602 .34512 m .52609 .34517 L .52634 .34453 L F
.52603 .34509 m .52599 .34515 L .52601 .34507 L F
.52599 .34515 m .52603 .34509 L .52599 .34515 L F
.52603 .34509 m .52603 .34509 L .52599 .34515 L F
.52608 .345 m .52604 .34541 L .52597 .34502 L F
.52588 .34548 m .52605 .34512 L .52606 .34514 L F
.52604 .34541 m .52567 .34728 L .52589 .34521 L F
.52553 .34604 m .52609 .34517 L .52602 .34512 L F
.52631 .34458 m .52634 .34453 L .52625 .34462 L F
.52569 .34462 m .52612 .34471 L .52573 .34463 L F
.52537 .34451 m .52655 .34479 L .52612 .34471 L F
.52436 .34435 m .52269 .34419 L .52439 .34442 L F
.52269 .34419 m .52336 .34445 L .52481 .34463 L F
.52269 .34419 m .52481 .34463 L .52456 .34448 L F
.52517 .34438 m .52017 .34415 L .52292 .34406 L F
.52457 .34426 m .52463 .3444 L .52566 .34461 L F
.52521 .34444 m .5244 .34436 L .52536 .34455 L F
.52521 .34444 m .52463 .34441 L .5244 .34436 L F
.52463 .34441 m .52434 .34439 L .5244 .34436 L F
.5244 .34436 m .52582 .34481 L p .52444 .34434 L F P
0 g
s
.52463 .34441 m .5244 .34436 L .5244 .34436 L .672 .728 .891 r
F
.52507 .34449 m .52463 .34441 L .52521 .34444 L F
.52436 .34435 m .52497 .3444 L .52507 .34449 L F
.52442 .34437 m .52507 .34449 L .52514 .34456 L F
.52436 .34435 m .52507 .34449 L .52442 .34437 L F
.52017 .34415 m .52001 .34409 L .52292 .34406 L F
.52291 .34427 m .5168 .34361 L .52336 .34445 L F
.52017 .34415 m .51923 .3441 L .52001 .34409 L F
.51921 .3441 m .52394 .34467 L p .5168 .34361 L F P
0 g
s
.5168 .34361 m .52394 .34467 L .52336 .34445 L .672 .728 .891 r
F
.52394 .34467 m .50765 .34271 L p .52395 .34467 L F P
0 g
s
.52372 .34473 m .50748 .34352 L .52434 .34439 L .672 .728 .891 r
F
.52615 .34476 m .52667 .34486 L .52668 .34488 L F
.52609 .34493 m .52617 .34478 L .526 .34497 L F
.52582 .34481 m .52626 .34489 L .5263 .34494 L F
.52606 .34482 m .52599 .34497 L .52624 .34486 L F
.52649 .34493 m .52649 .34493 L .52624 .34487 L F
.52649 .34493 m .52624 .34487 L .52624 .34487 L F
.52649 .34493 m .52578 .34475 L .52649 .34493 L F
.52624 .34487 m .52649 .34493 L .52624 .34487 L F
.52639 .34493 m .52563 .34487 L .52662 .34482 L F
.52466 .34476 m .52466 .34476 L .52564 .34488 L F
.52466 .34476 m .52564 .34488 L .52564 .34488 L F
.52632 .34496 m .52466 .34476 L p .52632 .34496 L F P
0 g
s
.52466 .34476 m .52394 .34467 L p .52466 .34476 L .672 .728 .891 r
F P
0 g
s
.52466 .34476 m .52466 .34476 L .52632 .34496 L .672 .728 .891 r
F
.52612 .3452 m .52632 .34496 L .52626 .34489 L F
.52575 .34602 m .52617 .34523 L .52612 .3452 L F
.52617 .34523 m .52632 .34496 L .52612 .3452 L F
.52358 .34475 m .52383 .34477 L .52358 .34475 L F
.52383 .34477 m .52576 .34492 L .52383 .34477 L F
.52383 .34477 m .52383 .34477 L .52358 .34475 L F
.52784 .34307 m .52783 .343 L .52966 .34084 L F
.52786 .34318 m .52784 .34307 L .52966 .34084 L F
.52781 .34282 m .52687 .34394 L .52779 .3427 L F
.52687 .34394 m .52684 .3439 L .52779 .3427 L F
.52633 .34439 m .52629 .34441 L .52667 .34366 L F
.52636 .34452 m .52641 .3441 L .52641 .3441 L F
.52625 .34462 m .52634 .34453 L .52631 .3445 L F
.52673 .34381 m .52663 .34398 L .52667 .34366 L F
.52544 .35229 m .52603 .34727 L .52603 .34728 L F
.52544 .35229 m .52624 .34547 L .52624 .34547 L F
.52442 .34437 m .52514 .34456 L .52442 .34437 L F
.52441 .34436 m .52514 .34456 L .52515 .34457 L F
.52442 .34437 m .52514 .34456 L .52441 .34436 L F
.52394 .34467 m .52466 .34476 L .52466 .34476 L F
.52434 .34478 m .52463 .34441 L .52507 .34449 L F
.52582 .34481 m .52435 .34435 L p .52578 .34475 L F P
0 g
s
.52451 .34445 m .52464 .34455 L .52541 .34465 L .672 .728 .891 r
F
.52573 .34463 m .52613 .34472 L .52613 .34472 L F
.52711 .34387 m .52688 .34418 L .52702 .3439 L F
.52629 .3444 m .5271 .34391 L .52706 .34385 L F
.52611 .34471 m .52642 .344 L .52611 .3447 L F
.52579 .34476 m .52641 .34436 L .52629 .3444 L F
.52645 .34446 m .52643 .34443 L .52674 .34393 L F
.52643 .34443 m .52674 .34393 L .52643 .34443 L F
.52643 .34443 m .52674 .34393 L .52643 .34443 L F
.52643 .34443 m .52643 .34443 L .52674 .34393 L F
.52641 .34436 m .5271 .34391 L .52629 .3444 L F
.52537 .34455 m .52568 .34461 L .52537 .34455 L F
.52568 .34461 m .52814 .34502 L .52568 .34461 L F
.52814 .34502 m .52814 .34502 L .52568 .34461 L F
.52615 .34476 m .52569 .34462 L .52613 .34473 L F
.52686 .34486 m .52803 .34505 L .5264 .34476 L F
.52708 .3449 m .52672 .34483 L .52801 .34485 L F
.52692 .34486 m .52664 .3448 L .52706 .34484 L F
.52657 .34461 m .52688 .34418 L .52688 .34418 L F
.52602 .34512 m .52631 .34458 L .526 .3451 L F
.52512 .34481 m .52559 .34482 L .52561 .34484 L F
.52563 .34487 m .52434 .34478 L .52556 .3448 L F
.52632 .34496 m .52576 .34492 L p .52629 .34493 L F P
0 g
s
.52603 .3446 m .52611 .3447 L .52621 .34449 L .672 .728 .891 r
F
.52624 .34441 m .52623 .34441 L .52595 .34506 L F
.52623 .34441 m .52607 .34466 L .52608 .34467 L F
.526 .3451 m .52631 .34458 L .52625 .34462 L F
.52611 .34471 m .52631 .3445 L .52624 .34442 L F
.52611 .3447 m .52657 .34462 L .52621 .34449 L F
.52601 .34458 m .52595 .3445 L .5266 .34468 L F
.52672 .34483 m .52646 .34477 L .52771 .34468 L F
.52661 .34472 m .5266 .34468 L .52753 .34495 L F
.52611 .3447 m .52624 .34441 L .52611 .3447 L F
.52601 .34458 m .5266 .34468 L .52661 .34472 L F
.52597 .34502 m .52604 .34541 L .52589 .34521 L F
.5256 .34589 m .52602 .34512 L .526 .3451 L F
.5257 .34482 m .52577 .34483 L .52566 .34479 L F
.52577 .34483 m .52581 .34482 L .52566 .34479 L F
.5257 .34482 m .52573 .34485 L .52577 .34483 L F
.52336 .34445 m .5258 .3449 L .5257 .34482 L F
.52563 .34487 m .52556 .3448 L .52594 .34481 L F
.52579 .34476 m .52599 .34497 L .52606 .34482 L F
.52611 .34471 m .52595 .34506 L .52611 .34471 L F
.52599 .34486 m .52598 .34486 L .5259 .34502 L F
.52606 .34474 m .52598 .34486 L .52599 .34486 L F
.52606 .34474 m .52603 .34475 L .52598 .34486 L F
.52595 .34506 m .52611 .3447 L .5259 .34502 L F
.52611 .3447 m .52623 .34441 L .52609 .34468 L F
.52611 .3447 m .52609 .34468 L .5259 .34502 L F
.52573 .34463 m .52613 .34472 L .52572 .34463 L F
.52613 .34472 m .5268 .34488 L .52613 .34472 L F
.52613 .34472 m .52613 .34472 L .52572 .34463 L F
.52585 .34486 m .52594 .34481 L .52662 .34482 L F
.52563 .34487 m .52594 .34481 L .52585 .34486 L F
.52611 .34471 m .52595 .34506 L .52595 .34506 L F
.52624 .34441 m .52611 .34471 L .52611 .34471 L F
.52609 .34468 m .52671 .34482 L .52655 .34479 L F
.52632 .34496 m .52629 .34493 L .52634 .34493 L F
.52632 .34496 m .52634 .34493 L .52639 .34493 L F
.52632 .34496 m .52657 .34462 L p .52626 .34489 L F P
0 g
s
.5262 .34481 m .52594 .34481 L .52618 .34479 L .672 .728 .891 r
F
.5262 .34481 m .52618 .34479 L .52646 .34477 L F
.52631 .34496 m .52657 .34461 L .52631 .34496 L F
.52667 .34486 m .5268 .34488 L .52677 .34489 L F
.52666 .34485 m .5268 .34488 L .52667 .34486 L F
.52631 .34496 m .52657 .34461 L .52632 .34496 L F
.52668 .34488 m .52667 .34486 L .52795 .34518 L F
.52639 .34493 m .52662 .34482 L .52672 .34483 L F
.52688 .34487 m .52671 .34482 L .52692 .34486 L F
.52639 .34493 m .52672 .34483 L .52708 .3449 L F
.52692 .34486 m .52799 .34508 L .52808 .3451 L F
.52777 .34503 m .52639 .34493 L .52708 .3449 L F
.52604 .34462 m .52604 .34462 L .52615 .34432 L F
.52662 .34355 m .52655 .3437 L .52662 .34355 L F
.52662 .34355 m .52663 .34352 L p .52648 .34386 L F P
0 g
s
.51541 .34155 m .5244 .34436 L p .51726 .34192 L .672 .728 .891 r
F P
0 g
s
.51726 .34192 m .5244 .34436 L .52444 .34434 L .672 .728 .891 r
F
.51726 .34192 m .521 .34318 L .52111 .34315 L F
.52552 .34438 m .5182 .34233 L .52545 .34429 L F
.5182 .34233 m .51541 .34155 L .51821 .34232 L F
.5182 .34233 m .51821 .34232 L .52545 .34429 L F
.52606 .34482 m .52636 .34415 L .52635 .34415 L F
.52497 .3444 m .52606 .34463 L .52609 .34467 L F
.5254 .34447 m .52539 .34447 L .52614 .34474 L F
.5256 .34589 m .52602 .34512 L .5256 .34589 L F
.52602 .34512 m .52602 .34512 L .5256 .34589 L F
.52569 .34567 m .52609 .34493 L .526 .34497 L F
.52571 .34568 m .52609 .34493 L .52569 .34567 L F
.52612 .34533 m .52619 .34467 L .52613 .34533 L F
.52549 .34598 m .52546 .34546 L .52577 .34528 L F
.52525 .34667 m .525 .34678 L .52572 .3456 L F
.52553 .34604 m .52595 .34506 L .52556 .34594 L F
.52595 .34506 m .52606 .34482 L .52595 .34506 L F
.52595 .34506 m .52595 .34506 L .52556 .34594 L F
.52427 .3448 m .52576 .34492 L p .52427 .3448 L F P
0 g
s
.52553 .34604 m .5256 .34589 L .5256 .34589 L .672 .728 .891 r
F
.52553 .34604 m .52571 .34568 L .52569 .34567 L F
.52553 .34601 m .52553 .34604 L .52556 .34594 L F
.52549 .34598 m .52491 .34641 L .52546 .34546 L F
.52525 .34578 m .52526 .34586 L .52582 .34563 L F
.52534 .34628 m .52554 .34601 L p .52526 .34586 L F P
0 g
s
.52554 .34601 m .52582 .34563 L p .52526 .34586 L .672 .728 .891 r
F P
0 g
s
.52556 .34712 m .52555 .34709 L .52584 .34533 L .672 .728 .891 r
F
.5255 .34702 m .52547 .34698 L .52576 .34504 L F
.52539 .34685 m .52504 .34895 L .52526 .34664 L F
.52547 .34698 m .52504 .34895 L .52539 .34685 L F
.52547 .34698 m .52479 .35167 L .52504 .34895 L F
.52567 .34728 m .52479 .35167 L .52556 .34712 L F
.52556 .34712 m .52479 .35167 L .52555 .34709 L F
.52597 .34658 m .5236 .35754 L p .5258 .34663 L F P
0 g
s
.52526 .34664 m .52479 .35167 L .52479 .34843 L .672 .728 .891 r
F
.52555 .34709 m .52479 .35167 L .5255 .34702 L F
.5255 .34702 m .52479 .35167 L .52547 .34698 L F
.52479 .35167 m .5236 .35754 L .52479 .34843 L F
.5236 .35754 m .52609 .346 L p .52553 .34604 L F P
0 g
s
.52553 .34601 m .5257 .34667 L .52549 .34628 L .672 .728 .891 r
F
.52525 .34578 m .52559 .34569 L .52562 .3455 L F
.52559 .34569 m .52582 .34563 L .52562 .3455 L F
.52582 .34563 m .52632 .34496 L p .52562 .3455 L F P
0 g
s
.52558 .34526 m .52491 .34641 L .52549 .34519 L .672 .728 .891 r
F
.52553 .34604 m .52611 .34471 L .52606 .34482 L F
.52521 .3456 m .52525 .34578 L .52612 .34502 L F
.52664 .3448 m .52606 .34463 L .52662 .34474 L F
.52596 .34506 m .52612 .34502 L .52657 .34462 L F
.52521 .3456 m .52612 .34502 L .52596 .34506 L F
.52571 .34495 m .52553 .34601 L .5259 .34502 L F
.52576 .34492 m .5259 .34502 L .52598 .34478 L F
.52571 .34495 m .5259 .34502 L .52576 .34492 L F
.52567 .34491 m .52563 .34487 L .52639 .34493 L F
.52576 .34491 m .52568 .34491 L .52568 .34491 L F
.52633 .34496 m .52576 .34491 L .52576 .34491 L F
.52576 .34491 m .52568 .34491 L .52576 .34491 L F
.52798 .34519 m .52688 .34487 L .52808 .3451 L F
.52632 .34496 m .52777 .34503 L .52803 .34509 L F
.52609 .34527 m .52657 .34462 L .52609 .34527 L F
.52657 .34462 m .52688 .34419 L .52657 .34462 L F
.52657 .34462 m .52657 .34462 L .52609 .34527 L F
.52625 .34487 m .52673 .345 L .52626 .34489 L F
.52673 .345 m .52784 .34531 L .52673 .34501 L F
.52673 .345 m .52673 .34501 L .52626 .34489 L F
.52784 .34531 m .52982 .34585 L .52784 .34531 L F
.52694 .34502 m .52732 .34518 L .52735 .34515 L F
.52784 .34531 m .52784 .34531 L .52626 .34489 L F
.52716 .34502 m .52633 .34496 L .52633 .34496 L F
.52632 .34496 m .52568 .34491 L .52632 .34496 L F
.52602 .34512 m .52631 .34458 L .52602 .34512 L F
.52632 .34496 m .52632 .34496 L .52568 .34491 L F
.52607 .34508 m .52601 .3451 L .52618 .34479 L F
.52552 .34458 m .52507 .34449 L .52521 .34444 L F
.52533 .34449 m .52524 .34452 L .5255 .34458 L F
.52533 .34449 m .5255 .34458 L .52555 .34459 L F
.52538 .3445 m .52655 .34479 L .52537 .34451 L F
.52569 .34462 m .52497 .3444 L .52566 .34458 L F
.52539 .34447 m .52533 .34449 L .52555 .34459 L F
.52554 .34601 m .52564 .34588 L .52564 .34588 L F
.52553 .34601 m .52556 .34594 L .5259 .34502 L F
.5259 .34502 m .5259 .34502 L .52604 .34462 L F
.52619 .34504 m .52626 .34489 L .52617 .34502 L F
.52612 .34502 m .52632 .34496 L .52626 .34489 L F
.52616 .34506 m .52617 .34502 L .52612 .34509 L F
.52619 .34504 m .52617 .34502 L .52616 .34506 L F
.52525 .34578 m .52632 .34496 L .52612 .34502 L F
.52576 .34492 m .52632 .34496 L .52576 .34492 L F
.52632 .34496 m .52742 .34505 L .52632 .34496 L F
.52632 .34496 m .52632 .34496 L .52576 .34492 L F
.52553 .34601 m .5259 .34502 L .5259 .34502 L F
.5262 .34482 m .52645 .34432 L .52645 .34434 L F
.52599 .34472 m .52589 .34474 L .52577 .34474 L F
.52623 .34441 m .52621 .34438 L .52607 .34466 L F
.52597 .34453 m .5259 .34445 L .52591 .34436 L F
.52598 .34454 m .52597 .34453 L .526 .34432 L F
.52623 .34445 m .52624 .34442 L .526 .3445 L F
.52607 .34466 m .52632 .34416 L .52604 .34462 L F
.52552 .34438 m .52545 .34429 L .52664 .34461 L F
.52606 .34463 m .5256 .3445 L .52603 .3446 L F
.52596 .34451 m .526 .3445 L .52639 .34401 L F
.52591 .34436 m .5259 .34443 L .52586 .34438 L F
.52581 .34433 m .52604 .34462 L .52615 .34432 L F
.52664 .34461 m .52545 .34429 L .52537 .34418 L F
.52581 .34433 m .52572 .34489 L .52604 .34462 L F
.52578 .34474 m .52578 .34475 L .52515 .34457 L F
.52486 .34464 m .52622 .34483 L .52486 .34464 L F
.52518 .34466 m .52518 .34466 L .52586 .34484 L F
.52554 .34474 m .52525 .34476 L .52548 .34467 L F
.52563 .34476 m .52561 .34475 L .52481 .34463 L F
.52486 .34464 m .52561 .34475 L .52559 .34473 L F
.52594 .34481 m .52556 .3448 L .52607 .34473 L F
.52557 .34478 m .52525 .34476 L .52555 .34476 L F
.52556 .3448 m .52434 .34478 L .5255 .34475 L F
.52556 .3448 m .5255 .34475 L .52607 .34473 L F
.52657 .34462 m .52656 .34459 L .52664 .34461 L F
.52801 .34485 m .52672 .34483 L .52771 .34468 L F
.52771 .34468 m .52719 .3447 L .52726 .34464 L F
.52719 .3447 m .52623 .34473 L .52726 .34464 L F
.52623 .34473 m .52613 .34473 L .52621 .34472 L F
.52623 .34473 m .52621 .34472 L .52726 .34464 L F
.52805 .34509 m .52645 .34464 L .52664 .34461 L F
.52808 .3451 m .52802 .34508 L .52805 .34509 L F
.52802 .34508 m .52645 .34464 L .52805 .34509 L F
.52839 .34466 m .52641 .34455 L .52749 .34493 L F
.52615 .34492 m .52632 .34496 L .52618 .34486 L F
.52618 .34486 m .52632 .34496 L .52625 .34487 L F
.52607 .34508 m .5262 .34481 L .5262 .34482 L F
.5256 .3445 m .52558 .34447 L .52661 .34473 L F
.52662 .34474 m .52661 .34473 L .52706 .34484 L F
.5256 .3445 m .52661 .34473 L .52662 .34474 L F
.52631 .34495 m .52631 .34495 L .52657 .34461 L F
.5262 .34482 m .52716 .34502 L .52619 .3448 L F
.52454 .34477 m .52434 .34478 L .52452 .34475 L F
.52394 .34467 m .52466 .34476 L p .52336 .34445 L F P
0 g
s
.52372 .34473 m .52434 .34439 L .52463 .34441 L .672 .728 .891 r
F
.52256 .34455 m .52064 .34452 L .52293 .3447 L F
.52198 .34431 m .52064 .34452 L .52256 .34455 L F
.52198 .34431 m .50784 .34354 L .52064 .34452 L F
.52198 .34431 m .52293 .3447 L .52505 .34486 L F
.52336 .34445 m .52466 .34476 L .52475 .34471 L F
.52336 .34445 m .52485 .34465 L .52481 .34463 L F
.52434 .34478 m .52372 .34473 L .52463 .34441 L F
.52198 .34431 m .52505 .34486 L .52474 .34462 L F
.52486 .34464 m .52486 .34464 L .52481 .34463 L F
.52481 .34463 m .52486 .34464 L .52486 .34464 L F
.52514 .34456 m .52535 .34451 L .5252 .34457 L F
.52456 .34448 m .52481 .34463 L .52559 .34473 L F
.52514 .34456 m .52519 .34458 L .52515 .34457 L F
.52519 .34458 m .52518 .34458 L .52515 .34457 L F
.52336 .34445 m .52566 .34479 L .52563 .34476 L F
.52552 .34458 m .52434 .34478 L .52507 .34449 L F
.52564 .34588 m .52657 .34461 L .52564 .34588 L F
.52553 .34601 m .52604 .34462 L .52604 .34462 L F
.52572 .34489 m .52573 .34558 L .52553 .34601 L F
.52606 .34482 m .52611 .3447 L .52556 .34594 L F
.52591 .34515 m .52531 .3463 L .5259 .34516 L F
.52598 .34512 m .52575 .34553 L .52591 .34515 L F
.52595 .34506 m .52595 .34506 L .52556 .34594 L F
.52575 .34553 m .52531 .3463 L .52591 .34515 L F
.5259 .34517 m .52582 .34484 L .52588 .34481 L F
.52566 .34574 m .52575 .34553 L .52624 .34467 L F
.52554 .34601 m .52609 .34527 L .52609 .34527 L F
.52607 .34508 m .52566 .34574 L .52601 .3451 L F
.52596 .34614 m .52587 .34525 L .5259 .34517 L F
.52587 .34525 m .52582 .34484 L .5259 .34517 L F
.52603 .34727 m .52594 .34615 L .52596 .34614 L F
.52594 .34615 m .52582 .34484 L .52596 .34614 L F
.526 .34475 m .52599 .34476 L .52617 .34478 L F
.52631 .34495 m .52657 .34461 L .52631 .34496 L F
.52582 .34563 m .52631 .34495 L .52631 .34496 L F
.52577 .34492 m .52577 .34491 L .52616 .34492 L F
.52577 .34492 m .52616 .34492 L .52629 .34493 L F
.5259 .34502 m .52607 .34466 L .52604 .34462 L F
.52691 .34504 m .52732 .34518 L .52694 .34502 L F
.52624 .34487 m .52758 .34518 L .52759 .34524 L F
.52576 .34491 m .52632 .34496 L .52576 .34491 L F
.52632 .34496 m .52716 .34502 L .52632 .34496 L F
.52632 .34496 m .52632 .34496 L .52576 .34491 L F
.52592 .34548 m .52584 .34551 L .52626 .34489 L F
.52572 .34463 m .52666 .34485 L .52667 .34486 L F
.52609 .34467 m .52671 .34482 L .52609 .34468 L F
.52621 .34472 m .52613 .34473 L .52611 .3447 L F
.52609 .34467 m .52606 .34463 L .52664 .3448 L F
.52665 .34481 m .52664 .3448 L .52671 .34482 L F
.52609 .34467 m .52664 .3448 L .52665 .34481 L F
.52678 .34393 m .52648 .34441 L .52673 .34381 L F
.52645 .34464 m .52561 .34441 L .52656 .34459 L F
.52571 .34495 m .52598 .34478 L .52604 .34462 L F
.526 .34475 m .52588 .34481 L .52585 .34432 L F
.52484 .34428 m .52595 .3445 L .52601 .34458 L F
.52585 .34432 m .52582 .34484 L .52581 .34433 L F
.52519 .34458 m .52624 .34487 L .52518 .34458 L F
.52611 .3447 m .52548 .34473 L .52552 .34458 L F
.52581 .34433 m .52579 .34485 L .52572 .34489 L F
.52497 .3444 m .52609 .34467 L .52609 .34468 L F
.5256 .34426 m .5257 .34458 L .52607 .34471 L F
.52611 .3447 m .52624 .34486 L .52657 .34462 L F
.52627 .34491 m .52626 .34489 L .52652 .3445 L F
.52634 .34464 m .52622 .34484 L .52629 .34465 L F
.52622 .34484 m .52607 .34508 L .5262 .34482 L F
.52622 .34484 m .5262 .34482 L .52629 .34465 L F
.52683 .345 m .52716 .34502 L .52716 .34502 L F
.52683 .345 m .52716 .34502 L .52683 .345 L F
.52632 .34496 m .52809 .3451 L p .52632 .34496 L F P
0 g
s
.52615 .34476 m .52795 .34518 L .52795 .34519 L .672 .728 .891 r
F
.52712 .34507 m .52709 .34504 L .52758 .34518 L F
.52759 .34524 m .52758 .34518 L .52982 .34585 L F
.52672 .345 m .52982 .34585 L .52673 .345 L F
.52716 .34513 m .52982 .34585 L .52717 .34515 L F
.52702 .34488 m .52687 .345 L .52902 .34577 L F
.52664 .3448 m .52662 .34474 L .52706 .34484 L F
.52673 .34476 m .52677 .34483 L .52702 .34488 L F
.52617 .34478 m .52738 .34496 L .52738 .34496 L F
.52617 .34478 m .52738 .34496 L .5269 .34486 L F
.52619 .3448 m .52716 .34502 L .52738 .34496 L F
.52677 .34483 m .52687 .345 L .52702 .34488 L F
.52692 .34486 m .52706 .34484 L .52799 .34508 L F
.52841 .34507 m .52929 .34521 L .5284 .34506 L F
.52816 .34503 m .52803 .34505 L .52929 .34521 L F
.52956 .34512 m .52929 .34521 L .54485 .3472 L F
.52803 .34509 m .52777 .34503 L .54211 .3461 L F
.52754 .34496 m .52802 .34508 L .52799 .34508 L F
.52601 .34458 m .52754 .34496 L .52754 .34496 L F
.52754 .34496 m .52802 .34508 L .52754 .34496 L F
.52779 .3427 m .52722 .34339 L .52778 .34263 L F
.52548 .3447 m .52619 .3448 L .52617 .34478 L F
.52624 .34441 m .52624 .34441 L .52595 .34506 L F
.52608 .34467 m .52607 .34466 L .52603 .34475 L F
.5256 .34426 m .52607 .34471 L .52611 .3447 L F
.52561 .34441 m .52563 .3444 L .52656 .34459 L F
.52623 .34441 m .52603 .34475 L .52606 .34474 L F
.52606 .34463 m .52603 .3446 L .52662 .34474 L F
.52584 .34436 m .52611 .3447 L .52642 .34462 L F
.52589 .34479 m .52486 .34464 L .52589 .34479 L F
.52607 .34473 m .52434 .34478 L .52611 .3447 L F
.52588 .34476 m .52588 .34478 L .52604 .34462 L F
.52572 .34489 m .52588 .34478 L .52588 .34476 L F
.52572 .34489 m .52575 .34491 L .52588 .34478 L F
.52588 .34481 m .52582 .34484 L .52585 .34432 L F
.5256 .34426 m .52611 .3447 L .52584 .34436 L F
.52604 .34462 m .52632 .34416 L .5262 .3442 L F
.52636 .34411 m .52611 .3447 L .52585 .34432 L F
.52642 .34462 m .52664 .34481 L .52673 .34476 L F
.52664 .34481 m .52687 .345 L .52677 .34483 L F
.52671 .34482 m .52664 .3448 L .52692 .34486 L F
.52664 .34481 m .52677 .34483 L .52673 .34476 L F
.52735 .34497 m .52902 .34577 L .52876 .34554 L F
.52652 .3445 m .52645 .34461 L .52649 .34443 L F
.52645 .34461 m .52626 .34489 L .5264 .34462 L F
.52655 .34458 m .52581 .34433 L .52647 .3446 L F
.52645 .34461 m .5264 .34462 L .52649 .34443 L F
.52646 .34461 m .52726 .34499 L .52735 .34497 L F
.5256 .34426 m .52642 .34462 L .52646 .34461 L F
.52642 .34462 m .52726 .34499 L .52646 .34461 L F
.52715 .34502 m .52809 .3451 L .52715 .34502 L F
.52772 .34522 m .52758 .34518 L .52807 .34522 L F
.52758 .34518 m .52756 .34509 L .52807 .34522 L F
.52715 .34502 m .52809 .3451 L .52716 .34502 L F
.52772 .34522 m .52807 .34522 L .53046 .34591 L F
.52726 .34499 m .52902 .34577 L .52735 .34497 L F
.52611 .3447 m .52604 .34486 L .526 .34475 L F
.52624 .34441 m .52595 .34506 L .52595 .34506 L F
.52623 .34445 m .52629 .3444 L .52624 .34442 L F
.52639 .34401 m .52642 .344 L .52645 .34393 L F
.52623 .34441 m .52663 .34351 L .52621 .34438 L F
.52642 .34399 m .52642 .34399 L .52623 .34441 L F
.52642 .34399 m .52623 .34441 L .52624 .34441 L F
.52624 .34441 m .52642 .34399 L .52624 .34441 L F
.5264 .34419 m .52613 .34472 L .52635 .34407 L F
.52611 .34471 m .52611 .34471 L .52611 .3447 L F
.52613 .34473 m .52611 .34471 L .52611 .34471 L F
.52611 .3447 m .52611 .3447 L .52556 .34594 L F
.52613 .34473 m .52607 .34473 L .52611 .34471 L F
.52641 .3441 m .52604 .34486 L .52636 .34411 L F
.52582 .34484 m .52581 .34484 L .52581 .34433 L F
.52548 .34473 m .52536 .34461 L .52552 .34458 L F
.5262 .34481 m .52618 .34479 L .52626 .34466 L F
.52636 .34415 m .52649 .34385 L .52635 .34415 L F
.52597 .34394 m .52591 .34417 L .52608 .3441 L F
.52608 .34387 m .526 .34432 L .52597 .34394 L F
.52587 .344 m .52615 .34432 L .52633 .34384 L F
.52646 .34363 m .52641 .3441 L .52587 .344 L F
.52583 .34326 m .52578 .34404 L .52639 .34404 L F
.52532 .34458 m .52541 .34465 L .52662 .34481 L F
.52611 .3447 m .526 .34475 L .52589 .34443 L F
.52619 .3448 m .52738 .34496 L .52617 .34478 L F
.52588 .34481 m .52615 .34492 L .52618 .34486 L F
.52474 .34462 m .5258 .34485 L .52588 .34481 L F
.5258 .34485 m .52615 .34492 L .52588 .34481 L F
.52581 .34505 m .5258 .34504 L .5258 .34485 L F
.52581 .34484 m .5258 .34485 L .52581 .34433 L F
.52576 .34492 m .52577 .34492 L .52629 .34493 L F
.5258 .34485 m .52576 .34491 L .52632 .34496 L F
.52581 .34505 m .5258 .34485 L .52581 .34484 L F
.52632 .34496 m .52632 .34496 L .52576 .34492 L F
.52576 .34492 m .52632 .34496 L .52632 .34496 L F
.52632 .34496 m .52632 .34496 L .52576 .34492 L F
.52607 .34508 m .52618 .34479 L .5262 .34481 L F
.52597 .34477 m .5262 .34482 L .52619 .3448 L F
.52554 .34475 m .52625 .34487 L .52548 .3447 L F
.52625 .34487 m .52716 .34502 L .52622 .34484 L F
.52625 .34487 m .52622 .34484 L .52548 .3447 L F
.52624 .34486 m .52678 .34393 L .52679 .34394 L F
.52584 .34551 m .52623 .34485 L .52624 .34486 L F
.52623 .34485 m .52678 .34393 L .52624 .34486 L F
.52566 .34464 m .52609 .34471 L .5261 .34471 L F
.52566 .34464 m .52662 .34481 L .52566 .34464 L F
.52532 .34458 m .52629 .34474 L .52625 .34473 L F
.52595 .34506 m .52595 .34506 L .52559 .34588 L F
.52624 .34441 m .52559 .34588 L .52559 .34588 L F
.52556 .34594 m .52595 .34506 L .5259 .34502 L F
.52586 .34527 m .52579 .34542 L .52582 .34484 L F
.52548 .34473 m .52454 .34477 L .52536 .34461 L F
.52497 .34459 m .52617 .34478 L .52615 .34475 L F
.5235 .3444 m .52497 .34461 L .52497 .34459 L F
.52497 .34461 m .52617 .34478 L .52497 .34459 L F
.52532 .34458 m .52566 .34464 L .52566 .34464 L F
.52569 .34462 m .52573 .34463 L .52572 .34463 L F
.52524 .34452 m .52532 .34458 L .52625 .34473 L F
.52548 .3447 m .52593 .34479 L .52597 .34477 L F
.52568 .34461 m .52568 .34461 L .52537 .34455 L F
.52539 .34447 m .52582 .34478 L .52604 .34472 L F
.5252 .34449 m .52524 .34452 L .52614 .34468 L F
.52518 .34454 m .52582 .34478 L p .52555 .34459 L F P
0 g
s
.52524 .34452 m .52518 .34454 L .52555 .34459 L .672 .728 .891 r
F
.52561 .34441 m .52552 .34438 L .52563 .3444 L F
.52635 .34464 m .52634 .34464 L .52648 .34441 L F
.52634 .34464 m .52629 .34465 L .52645 .34434 L F
.52635 .34458 m .52636 .34452 L .52635 .34458 L F
.52614 .34474 m .52629 .34441 L .52615 .34476 L F
.52581 .34433 m .52646 .34461 L .52647 .3446 L F
.52619 .34468 m .52629 .34441 L .52633 .34439 L F
.52615 .34476 m .52618 .34468 L .52619 .34468 L F
.52618 .34468 m .52629 .34441 L .52619 .34468 L F
.52581 .34433 m .5258 .34434 L .52646 .34461 L F
.52647 .3446 m .52646 .34461 L .52735 .34497 L F
.52628 .34466 m .52626 .34466 L .52645 .34432 L F
.52624 .34444 m .52635 .34458 L .52612 .3447 L F
.52618 .34478 m .52615 .34476 L .52667 .34366 L F
.52641 .3441 m .52636 .34452 L .52624 .34444 L F
.52642 .34436 m .52618 .34478 L .52635 .34438 L F
.52636 .34452 m .52635 .34458 L .52624 .34444 L F
.52641 .34455 m .52597 .34453 L .52616 .34467 L F
.52635 .34407 m .52613 .34472 L .52597 .34453 L F
.52634 .34455 m .52601 .34457 L .52597 .34453 L F
.52497 .3444 m .52484 .34428 L .52606 .34463 L F
.52597 .34453 m .5252 .34449 L .52607 .34466 L F
.52601 .34457 m .52585 .34458 L .52597 .34453 L F
.52623 .34445 m .52628 .3445 L .52637 .34413 L F
.52635 .34415 m .52649 .34385 L .52648 .34386 L F
.52663 .34398 m .52652 .344 L .52667 .34366 L F
.52606 .34482 m .52663 .34352 L .52663 .34352 L F
.52667 .34366 m .52639 .34402 L .5269 .34357 L F
.52613 .34472 m .52597 .34503 L .52611 .3447 L F
.52598 .34512 m .52614 .34474 L .52615 .34476 L F
.52575 .34602 m .52619 .34504 L .52612 .34509 L F
.52592 .34548 m .52626 .34489 L .52627 .34491 L F
.52598 .34512 m .5259 .34516 L .52629 .34441 L F
.52618 .34478 m .52598 .34512 L .52615 .34476 L F
.52611 .34471 m .52626 .34533 L .52604 .34486 L F
.52607 .34471 m .52614 .34474 L .52614 .34474 L F
.5254 .34447 m .52606 .34471 L .52607 .34471 L F
.52581 .34505 m .52578 .34564 L .5258 .34504 L F
.52632 .34496 m .52576 .34492 L .52576 .34492 L F
.52572 .34489 m .52576 .34491 L .5258 .34485 L F
.52576 .34492 m .52567 .34491 L p .52577 .34491 L F P
0 g
s
.52572 .34489 m .52571 .34495 L .52575 .34491 L .672 .728 .891 r
F
.52579 .34485 m .52573 .34612 L .52572 .34489 L F
.52576 .34492 m .52632 .34496 L p .52576 .34492 L F P
0 g
s
.52632 .34496 m .52576 .34492 L .52576 .34492 L .672 .728 .891 r
F
.52427 .3448 m .52632 .34496 L .52427 .3448 L F
.52632 .34496 m .52632 .34496 L .52427 .3448 L F
.52573 .34558 m .52554 .34601 L .52553 .34601 L F
.52584 .34551 m .52531 .3463 L .52578 .34554 L F
.52578 .34564 m .52575 .34559 L .52576 .34555 L F
.5258 .34511 m .52579 .34518 L .52596 .34506 L F
.52549 .34519 m .52579 .34518 L .5258 .34511 L F
.52549 .34519 m .52521 .3456 L .52579 .34518 L F
.52579 .34554 m .52576 .34555 L .52581 .34433 L F
.52578 .34564 m .52576 .34555 L .52579 .34554 L F
.52974 .34459 m .52801 .34457 L .52909 .34476 L F
.52582 .34563 m .52657 .34461 L .52582 .34563 L F
.52582 .34563 m .52657 .34461 L .52582 .34563 L F
.52568 .34491 m .52632 .34496 L .52568 .34491 L F
.52624 .34547 m .5259 .34514 L .52588 .34481 L F
.52611 .3447 m .5257 .34552 L .52597 .34453 L F
.5257 .34552 m .52531 .3463 L .52562 .34546 L F
.5257 .34552 m .52562 .34546 L .52597 .34453 L F
.52582 .34484 m .52581 .34505 L .52581 .34484 L F
.52589 .34476 m .52531 .3463 L .52577 .34479 L F
.52633 .34456 m .52601 .34457 L .52634 .34455 L F
.52597 .34453 m .52589 .34476 L .52577 .34479 L F
.52639 .34402 m .52597 .34453 L .52635 .34416 L F
.52597 .34453 m .52599 .34455 L .52635 .34416 L F
.52601 .34457 m .52601 .34457 L .52634 .34455 L F
.52599 .34455 m .52623 .34442 L .52635 .34416 L F
.52632 .34416 m .52641 .34397 L .5262 .3442 L F
.52641 .3441 m .52585 .34432 L .52587 .344 L F
.52587 .344 m .52585 .34432 L .52581 .34433 L F
.52578 .34404 m .52576 .34427 L .52623 .34445 L F
.52597 .34453 m .5258 .34475 L .52599 .34455 L F
.5258 .34475 m .52581 .34475 L .52599 .34455 L F
.52601 .34457 m .52585 .34458 L .52601 .34457 L F
.52606 .34471 m .52539 .34447 L .52604 .34472 L F
.52577 .34479 m .52606 .34464 L .52604 .34462 L F
.52524 .34452 m .52611 .3447 L .52614 .34468 L F
.5252 .34449 m .52614 .34468 L .52616 .34467 L F
.52451 .34445 m .52541 .34465 L .52532 .34458 L F
.52501 .34458 m .52503 .34457 L .52548 .34458 L F
.52667 .34366 m .5264 .34419 L .52635 .34407 L F
.52639 .34402 m .52635 .34416 L .5264 .34405 L F
.52626 .3446 m .52642 .34409 L .52639 .34404 L F
.52632 .34496 m .52633 .34496 L .52632 .34496 L F
.52657 .34462 m .52594 .34547 L p .52657 .34462 L F P
0 g
s
.52632 .34496 m .52632 .34496 L .52632 .34496 L .672 .728 .891 r
F
.52626 .34489 m .52624 .34486 L .52649 .34443 L F
.52593 .34479 m .52622 .34484 L .52597 .34477 L F
.52622 .34484 m .52716 .34502 L .5262 .34482 L F
.52622 .34484 m .5262 .34482 L .52597 .34477 L F
.52645 .34464 m .52656 .34459 L .52657 .34462 L F
.52657 .34461 m .52631 .34495 L .52652 .3445 L F
.52631 .34495 m .52592 .34548 L .52627 .34491 L F
.52631 .34495 m .52627 .34491 L .52652 .3445 L F
.52616 .34477 m .52632 .34496 L .52647 .34488 L F
.52584 .34551 m .52617 .34494 L .52617 .34495 L F
.52617 .34494 m .52634 .34464 L .52617 .34495 L F
.52612 .34471 m .52662 .34481 L .52629 .34474 L F
.5261 .34471 m .52612 .34471 L .52612 .34471 L F
.52612 .34471 m .52662 .34481 L .52612 .34471 L F
.52623 .34485 m .52634 .34464 L .52635 .34464 L F
.52617 .34495 m .52623 .34485 L .52623 .34485 L F
.52623 .34485 m .52634 .34464 L .52623 .34485 L F
.52631 .34494 m .52626 .34533 L .52611 .34471 L F
.52604 .34472 m .52632 .34496 L .52616 .34477 L F
.52609 .34471 m .52662 .34481 L .5261 .34471 L F
.52613 .34472 m .52666 .34485 L .52666 .34485 L F
.52672 .34483 m .5262 .34481 L .52646 .34477 L F
.52662 .34481 m .52661 .3448 L .52629 .34474 L F
.52584 .34551 m .52648 .34441 L .52649 .34442 L F
.52615 .34475 m .52617 .34478 L .5269 .34486 L F
.52615 .34475 m .5269 .34486 L .52672 .34482 L F
.52649 .34493 m .52672 .345 L .52649 .34493 L F
.52632 .34496 m .52639 .34493 L .52777 .34503 L F
.52664 .34481 m .52611 .3447 L .52687 .345 L F
.52631 .34496 m .52657 .34461 L .52657 .34461 L F
.5262 .34481 m .52626 .34466 L .52628 .34466 L F
.52631 .34496 m .52657 .34461 L .52657 .34461 L F
.52632 .34496 m .52657 .34461 L .52657 .34462 L F
.52642 .34462 m .52611 .3447 L .52664 .34481 L F
.52672 .34482 m .5269 .34486 L .52749 .34493 L F
.5263 .34461 m .52645 .34432 L .52631 .3446 L F
.5263 .34461 m .52631 .3446 L .5262 .34482 L F
.5262 .34481 m .5263 .34461 L .5262 .34482 L F
.52601 .34458 m .52753 .34495 L .52754 .34496 L F
.52753 .34491 m .52655 .34458 L .5273 .34494 L F
.52738 .34496 m .5273 .34494 L .52735 .34497 L F
.52753 .34491 m .5273 .34494 L .52738 .34496 L F
.52735 .34491 m .52738 .34496 L .52749 .34493 L F
.52738 .34496 m .52738 .34496 L .52738 .34496 L F
.52742 .34505 m .52805 .34509 L .52742 .34505 L F
.52795 .34519 m .52795 .34518 L .52807 .34522 L F
.52716 .34502 m .52809 .3451 L .52809 .3451 L F
.52632 .34496 m .52804 .34509 L .52633 .34496 L F
.53184 .34538 m .52805 .34509 L p .53182 .34536 L F P
0 g
s
.52804 .34509 m .53097 .34532 L .52803 .34509 L .672 .728 .891 r
F
.52804 .34509 m .52803 .34509 L .52633 .34496 L F
.52894 .34559 m .52955 .34586 L .52905 .34561 L F
.52717 .34515 m .52982 .34585 L .52955 .34582 L F
.52923 .34553 m .52955 .34586 L .53549 .34776 L F
.52786 .34505 m .53028 .34615 L .53043 .34617 L F
.52754 .34496 m .52753 .34495 L .52802 .34508 L F
.52753 .34491 m .52783 .34505 L .52786 .34505 L F
.52783 .34505 m .53028 .34615 L .52786 .34505 L F
.52783 .34505 m .52735 .34497 L .53028 .34615 L F
.52753 .34491 m .52738 .34496 L .52783 .34505 L F
.52814 .34502 m .52929 .34521 L .52814 .34502 L F
.52804 .34505 m .52777 .34503 L .52801 .34485 L F
.52775 .34495 m .52777 .34492 L .53004 .34507 L F
.52813 .34493 m .52929 .34521 L .52956 .34512 L F
.52805 .34509 m .52805 .34509 L .53182 .34536 L F
.52814 .34502 m .52923 .3452 L .52814 .34501 L F
.52814 .34501 m .52929 .34521 L .52813 .34493 L F
.54211 .3461 m .52841 .34508 L .52771 .34468 L F
.52749 .34493 m .52738 .34496 L .53099 .34532 L F
.52738 .34496 m .52716 .34502 L .52802 .34509 L F
.52808 .3451 m .52753 .34491 L .52786 .34505 L F
.52738 .34496 m .52802 .34509 L .53099 .34532 L F
.52971 .34602 m .54347 .35032 L p .52955 .34586 L F P
0 g
s
.53046 .34591 m .52798 .34519 L .52808 .3451 L .672 .728 .891 r
F
.52898 .34528 m .52923 .34553 L .53549 .34776 L F
.53367 .347 m .52982 .34585 L .53046 .34591 L F
.52971 .34602 m .53116 .34635 L .53123 .3464 L F
.52888 .34576 m .52955 .34582 L .53367 .347 L F
.53146 .34599 m .53549 .34776 L .54347 .35032 L F
.54347 .35032 m .52971 .34602 L p .53367 .347 L F P
0 g
s
.53046 .34591 m .52808 .3451 L .53183 .34677 L .672 .728 .891 r
F
.52982 .34585 m .52772 .34522 L .53046 .34591 L F
.52808 .3451 m .52786 .34505 L .53183 .34677 L F
.52738 .34496 m .52735 .34497 L .52783 .34505 L F
.53043 .34617 m .53028 .34615 L .53183 .34677 L F
.52532 .34458 m .52662 .34481 L .52662 .34481 L F
.52611 .3447 m .52625 .34473 L .52614 .34468 L F
.52625 .34463 m .52621 .34482 L .52612 .3447 L F
.52655 .34458 m .52647 .3446 L .52735 .34497 L F
.52641 .34455 m .52616 .34467 L .52749 .34493 L F
.52635 .34458 m .52621 .34482 L .52625 .34463 L F
.52611 .3447 m .52614 .34474 L .52687 .345 L F
.52635 .34458 m .52631 .34494 L .52621 .34482 L F
.52582 .34563 m .52631 .34496 L .52631 .34496 L F
.52582 .34478 m .52512 .34452 L p .52514 .34451 L F P
0 g
s
.52548 .34458 m .52523 .34453 L .52597 .34453 L .672 .728 .891 r
F
.52514 .34456 m .52497 .3444 L .52535 .34451 L F
.52597 .34453 m .52517 .34453 L .52511 .34448 L F
.52582 .34478 m .52514 .34451 L .52573 .34463 L F
.5235 .3444 m .52371 .34451 L .52599 .34476 L F
.52548 .34458 m .52361 .34455 L .52523 .34453 L F
.50784 .34354 m .52293 .3447 L .52293 .3447 L F
.50784 .34354 m .52293 .3447 L .52293 .3447 L F
.50806 .34357 m .52427 .3448 L p .50784 .34354 L F P
0 g
s
.50784 .34354 m .52427 .3448 L .52427 .3448 L .672 .728 .891 r
F
.52361 .34455 m .51932 .3445 L .52347 .34452 L F
.52361 .34455 m .52347 .34452 L .52523 .34453 L F
.52621 .34483 m .52631 .34457 L .52626 .3446 L F
.52626 .34489 m .52584 .34551 L .52624 .34486 L F
.52612 .34521 m .52623 .34485 L .52621 .34483 L F
.52623 .34485 m .52631 .34457 L .52621 .34483 L F
.52662 .34481 m .52672 .34482 L .52661 .3448 L F
.52662 .34481 m .52662 .34481 L .52672 .34482 L F
.52629 .34474 m .52735 .34491 L .52625 .34473 L F
.52614 .34468 m .52625 .34473 L .52749 .34493 L F
.52616 .34467 m .52614 .34468 L .52749 .34493 L F
.52625 .34487 m .52632 .34496 L .52716 .34502 L F
.52566 .34574 m .52624 .34467 L .52626 .34466 L F
.52606 .34471 m .52604 .34472 L .52647 .34488 L F
.52648 .34487 m .52647 .34488 L .52812 .34551 L F
.52606 .34471 m .52647 .34488 L .52648 .34487 L F
.52583 .34465 m .5258 .34475 L .52573 .34463 L F
.52611 .3447 m .5258 .34475 L .52583 .34465 L F
.52577 .34479 m .52604 .34462 L .52599 .34455 L F
.52597 .34453 m .52607 .34466 L .52616 .34467 L F
.52597 .34467 m .52582 .34459 L .52626 .3446 L F
.52611 .3447 m .52583 .34465 L .5259 .34444 L F
.52474 .34462 m .52576 .34491 L .52562 .34481 L F
.52506 .34489 m .52573 .34463 L .52597 .34467 L F
.52573 .34463 m .52582 .34459 L .52597 .34467 L F
.5262 .34502 m .52637 .34458 L .52634 .34455 L F
.5262 .34502 m .52634 .34455 L .52631 .34457 L F
.52612 .3447 m .52631 .34494 L .52611 .34471 L F
.52601 .34513 m .52616 .34505 L .52626 .3446 L F
.52626 .34466 m .52624 .34467 L .52673 .34381 L F
.52646 .34459 m .52602 .34458 L .52641 .34455 L F
.52602 .34458 m .52585 .34458 L .52601 .34457 L F
.52602 .34458 m .52601 .34457 L .52641 .34455 L F
.52594 .34547 m .52594 .34547 L .52657 .34462 L F
.52614 .34523 m .52631 .34457 L .52612 .34521 L F
.52577 .34479 m .52589 .34519 L .52603 .34487 L F
.52505 .34486 m .52576 .34491 L .52576 .34491 L F
.52336 .34445 m .5257 .34482 L .52566 .34479 L F
.52454 .34477 m .52452 .34475 L .52552 .34458 L F
.52474 .34462 m .52505 .34486 L .52576 .34491 L F
.52568 .34491 m .52568 .34491 L .52505 .34486 L F
.52568 .34491 m .52568 .34491 L .52505 .34486 L F
.52506 .34486 m .52632 .34496 L .52506 .34486 L F
.52574 .34494 m .52519 .34492 L p .52591 .34483 L F P
0 g
s
.52606 .34471 m .52614 .34474 L .52607 .34471 L .672 .728 .891 r
F
.52582 .34478 m .52632 .34496 L p .52604 .34472 L F P
0 g
s
.52611 .3447 m .52607 .34471 L .52614 .34474 L .672 .728 .891 r
F
.52626 .34488 m .52582 .34478 L .52612 .34471 L F
.52601 .34513 m .52626 .3446 L .52623 .34462 L F
.52611 .3447 m .52582 .34478 L .5258 .34475 L F
.52611 .3447 m .52626 .3446 L .52636 .34475 L F
.52427 .3448 m .52576 .34492 L .52576 .34492 L F
.52576 .34492 m .52576 .34492 L .52459 .34483 L F
.52506 .34486 m .52568 .34491 L .52505 .34486 L F
.52427 .3448 m .52576 .34492 L .52576 .34492 L F
.52519 .34492 m .52506 .34489 L .52597 .34479 L F
.52613 .34471 m .52582 .34478 L .52611 .3447 L F
.52577 .34479 m .52603 .34487 L .52606 .34464 L F
.5258 .34475 m .52577 .34479 L .52581 .34475 L F
.52632 .34496 m .52459 .34483 L .52459 .34483 L F
.52506 .34489 m .52597 .34467 L .52597 .34479 L F
.5235 .3444 m .52599 .34476 L .526 .34475 L F
.52576 .34492 m .52576 .34492 L .52362 .34475 L F
.52474 .34462 m .52554 .34475 L .52548 .3447 L F
.52506 .34489 m .52366 .34456 L .52582 .34459 L F
.52521 .34457 m .52525 .3446 L .52529 .3446 L F
.52625 .345 m .52637 .34458 L .5262 .34502 L F
.52631 .34495 m .52635 .34458 L .52631 .34495 L F
.52554 .34601 m .52564 .34588 L .52554 .34601 L F
.52564 .34588 m .52657 .34461 L .52564 .34588 L F
.52564 .34588 m .52564 .34588 L .52554 .34601 L F
.52718 .34467 m .52714 .34466 L .52755 .34462 L F
.52501 .34458 m .52548 .34458 L .52553 .34459 L F
.5253 .34457 m .52529 .3446 L .52606 .34464 L F
.5166 .34506 m .5139 .34509 L p .51784 .34494 L F P
0 g
s
.52614 .34474 m .52634 .34481 L .52635 .34481 L .672 .728 .891 r
F
.52614 .34474 m .52614 .34474 L .52634 .34481 L F
.52626 .34488 m .52613 .34471 L .52641 .34476 L F
.52619 .3448 m .52617 .34477 L .52636 .34475 L F
.52623 .34462 m .52628 .3445 L .52614 .34468 L F
.52624 .34547 m .52588 .34481 L .526 .34475 L F
.52588 .34535 m .52623 .34462 L .52614 .34468 L F
.5259 .34537 m .52623 .34462 L .52588 .34535 L F
.52564 .34588 m .52582 .34563 L .52582 .34563 L F
.52584 .34551 m .52578 .34554 L .52634 .34464 L F
.52564 .34588 m .52582 .34563 L .52582 .34563 L F
.52594 .34547 m .52552 .34604 L p .52594 .34547 L F P
0 g
s
.52603 .34727 m .52573 .34671 L .52579 .34553 L .672 .728 .891 r
F
.52559 .34588 m .52559 .34588 L .52556 .34594 L F
.52592 .34548 m .52531 .3463 L .52584 .34551 L F
.52575 .34575 m .52591 .34538 L .52573 .34575 L F
.52591 .34538 m .52623 .34462 L .5259 .34537 L F
.52588 .34549 m .52579 .34553 L .52579 .34542 L F
.52591 .34538 m .5259 .34537 L .52573 .34575 L F
.52484 .34428 m .52471 .34416 L .52595 .3445 L F
.5256 .3445 m .52484 .34428 L .52558 .34447 L F
.52537 .34418 m .51541 .34155 L .51479 .34126 L F
.51533 .34077 m .51479 .34126 L .50962 .33884 L F
.52537 .34418 m .51479 .34126 L .51533 .34077 L F
.52545 .34429 m .51541 .34155 L .52537 .34418 L F
.52632 .34496 m .52622 .34577 L p .52631 .34495 L F P
0 g
s
.52622 .34577 m .52544 .35229 L p .52621 .34577 L .672 .728 .891 r
F P
0 g
s
.52622 .34577 m .52621 .34577 L .52631 .34495 L .672 .728 .891 r
F
.52631 .34495 m .52635 .34458 L .52635 .34458 L F
.52624 .34547 m .52631 .34495 L .52631 .34495 L F
.52742 .34505 m .52742 .34505 L .52576 .34492 L F
.5272 .34534 m .52853 .3459 L p .52764 .34541 L F P
0 g
s
.52541 .33209 m .52419 .33216 L p .52548 .34304 L .672 .728 .891 r
F P
0 g
s
.52597 .34467 m .52611 .3447 L .52597 .34479 L .672 .728 .891 r
F
.52573 .34494 m .52611 .3447 L .52605 .34463 L F
.52632 .34496 m .52636 .34452 L .52636 .34452 L F
.52631 .34495 m .52635 .34458 L .52631 .34495 L F
.52752 .34524 m .52614 .34474 L .52748 .34526 L F
.52632 .34496 m .52631 .34495 L .52636 .34452 L F
.52636 .34475 m .52626 .3446 L .52648 .3446 L F
.52635 .34466 m .52637 .34458 L p .52633 .34469 L F P
0 g
s
.52618 .34526 m .52635 .34466 L .52633 .34469 L .672 .728 .891 r
F
.52621 .34577 m .52626 .34531 L .52627 .34532 L F
.52626 .34531 m .52635 .34458 L .52627 .34532 L F
.52627 .34532 m .52635 .34458 L .52635 .34458 L F
.52624 .34547 m .52626 .34533 L .52624 .34547 L F
.52626 .34533 m .52636 .34452 L .52626 .34533 L F
.52626 .34533 m .52626 .34533 L .52624 .34547 L F
.52665 .34472 m .52648 .3446 L .52755 .34462 L F
.52625 .34468 m .52613 .34471 L .52611 .3447 L F
.52597 .34467 m .52626 .3446 L .52611 .3447 L F
.52623 .34462 m .52626 .3446 L .52628 .3445 L F
.52606 .34464 m .52611 .3447 L .52615 .3446 L F
.52611 .3447 m .52589 .34443 L .52585 .34432 L F
.52611 .3447 m .52611 .3447 L .52605 .34463 L F
.52611 .3447 m .52614 .34468 L .52612 .34467 L F
.52611 .3447 m .52612 .34467 L .52605 .34463 L F
.52615 .3446 m .52611 .3447 L .52649 .34444 L F
.52626 .34488 m .52612 .34471 L .52613 .34471 L F
.52614 .34474 m .52606 .34471 L .52615 .34475 L F
.52603 .34487 m .52632 .34496 L .52611 .3447 L F
.52603 .34487 m .52611 .3447 L .52606 .34464 L F
.52597 .34479 m .52611 .3447 L .52636 .34475 L F
.52611 .3447 m .5262 .34481 L .52631 .34467 L F
.52611 .3447 m .52614 .34468 L .52611 .3447 L F
.52631 .34457 m .52634 .34455 L .52632 .34453 L F
.52636 .34452 m .52636 .34452 L .52641 .3441 L F
.52642 .34409 m .52632 .34496 L p .52641 .3441 L F P
0 g
s
.52635 .34458 m .52636 .34452 L .52636 .34452 L .672 .728 .891 r
F
.52639 .34423 m .52641 .3441 L .52639 .34423 L F
.52642 .34436 m .52635 .34438 L .52652 .344 L F
.52639 .34423 m .52639 .34423 L .52636 .34452 L F
.52636 .34452 m .52639 .34423 L .52636 .34452 L F
.52635 .34458 m .52635 .34458 L .52642 .34399 L F
.52635 .34458 m .52642 .34399 L .52635 .34458 L F
.52637 .34458 m .52642 .34409 L p .52632 .34453 L F P
0 g
s
.52641 .34455 m .52633 .34456 L .52634 .34455 L .672 .728 .891 r
F
.52611 .3447 m .52631 .34467 L .52649 .34444 L F
.52636 .34475 m .52648 .3446 L .52665 .34472 L F
.52657 .34461 m .52688 .34418 L .52657 .34462 L F
.52628 .34459 m .52628 .34459 L .5272 .3446 L F
.52716 .34461 m .52524 .34459 L .5272 .3446 L F
.52524 .34459 m .52501 .34458 L .52524 .34458 L F
.52524 .34459 m .52524 .34458 L .5272 .3446 L F
.52624 .34547 m .52624 .34547 L .52635 .34458 L F
.5263 .34497 m .52635 .34458 L .5263 .34496 L F
.5266 .3449 m .52626 .34488 L .52641 .34476 L F
.52576 .34491 m .52683 .345 L .52683 .345 L F
.52626 .34489 m .52716 .34513 L .52717 .34515 L F
.52715 .34502 m .52632 .34496 L .52632 .34496 L F
.52632 .34496 m .52715 .34502 L .52632 .34496 L F
.52576 .34492 m .52715 .34502 L .52716 .34502 L F
.52716 .34502 m .52716 .34502 L .52568 .34491 L F
.52632 .34496 m .52716 .34502 L .52632 .34496 L F
.52576 .34492 m .52742 .34505 L .52576 .34492 L F
.52742 .34505 m .52809 .3451 L .52742 .34505 L F
.52742 .34505 m .52742 .34505 L .52576 .34492 L F
.52724 .34372 m .52657 .34462 L p .52724 .3437 L F P
0 g
s
.52688 .34418 m .52724 .3437 L .52688 .34419 L .672 .728 .891 r
F
.52688 .34418 m .52688 .34418 L .52724 .3437 L F
.52699 .34419 m .52731 .34382 L p .52642 .34438 L F P
0 g
s
.52731 .34382 m .52699 .34419 L p .52729 .34375 L .672 .728 .891 r
F P
0 g
s
.52657 .34461 m .52657 .34461 L .52688 .34418 L .672 .728 .891 r
F
.52657 .34461 m .52688 .34418 L .52657 .34461 L F
.52632 .34496 m .53072 .34658 L p .52647 .34488 L F P
0 g
s
.53072 .34658 m .53441 .34793 L p .53094 .3466 L .672 .728 .891 r
F P
0 g
s
.52647 .34488 m .53072 .34658 L .53094 .3466 L .672 .728 .891 r
F
.53253 .34719 m .53441 .34793 L .53448 .34793 L F
.52647 .34488 m .53248 .34719 L .53253 .34719 L F
.53248 .34719 m .53441 .34793 L .53253 .34719 L F
.52732 .34518 m .52971 .34602 L .52735 .34515 L F
.52677 .3451 m .52675 .34506 L .52955 .34582 L F
.5281 .34544 m .52752 .34524 L .52812 .34551 L F
.52752 .34524 m .52748 .34526 L .52812 .34551 L F
.52635 .34481 m .52634 .34481 L .52798 .3454 L F
.52799 .3454 m .52798 .3454 L .53149 .34665 L F
.52635 .34481 m .52798 .3454 L .52799 .3454 L F
.52326 .3504 m .5229 .35092 L .52568 .34494 L F
.52497 .34619 m .51909 .35646 L .52526 .34664 L F
.51901 .3566 m .52572 .3456 L .52572 .3456 L F
.51897 .35667 m .51901 .3566 L p .51909 .35646 L F P
0 g
s
.52549 .34598 m .51897 .35667 L .52491 .34641 L .672 .728 .891 r
F
.51901 .3566 m .519 .35661 L .52572 .34559 L F
.51901 .3566 m .52572 .34559 L .52572 .3456 L F
.51897 .35667 m .51787 .35633 L p .5244 .34679 L F P
0 g
s
.52491 .34641 m .51897 .35667 L .5244 .34679 L .672 .728 .891 r
F
.51787 .35633 m .52534 .34628 L p .52521 .3456 L F P
0 g
s
.52577 .34479 m .52531 .3463 L .52527 .34632 L .672 .728 .891 r
F
.52577 .34479 m .52527 .34632 L .52489 .34607 L F
.53441 .34793 m .53591 .34848 L p .53448 .34793 L F P
0 g
s
.53149 .34665 m .53149 .34665 L .53183 .34677 L .672 .728 .891 r
F
.52799 .3454 m .53149 .34665 L .53149 .34665 L F
.52635 .34481 m .52799 .3454 L .52799 .3454 L F
.52799 .3454 m .53149 .34665 L .52799 .3454 L F
.52645 .34493 m .52626 .34488 L .5266 .3449 L F
.52649 .34444 m .52642 .34465 L .52663 .34456 L F
.5263 .34496 m .52635 .34458 L .52635 .34458 L F
.52641 .34476 m .52625 .34468 L .52656 .34463 L F
.52642 .34476 m .52636 .34475 L .52714 .34466 L F
.52629 .34474 m .52672 .34482 L .52735 .34491 L F
.52684 .34485 m .52643 .34476 L .52667 .34473 L F
.52668 .34481 m .52641 .34476 L .5266 .3446 L F
.52633 .34492 m .52657 .34463 L p .52642 .34465 L F P
0 g
s
.52657 .34463 m .52663 .34456 L p .52642 .34465 L .672 .728 .891 r
F P
0 g
s
.52641 .34476 m .52613 .34471 L .52625 .34468 L .672 .728 .891 r
F
.52656 .34463 m .52625 .34468 L .5266 .3446 L F
.52623 .34485 m .52646 .34451 L .52649 .34444 L F
.52618 .35073 m .52601 .35767 L p .52588 .35014 L F P
0 g
s
.52544 .35229 m .52544 .35228 L .52624 .34547 L .672 .728 .891 r
F
.52544 .35229 m .52624 .34547 L .52624 .34547 L F
.52603 .34727 m .52544 .35228 L .52573 .34671 L F
.52603 .34727 m .52621 .34577 L .52603 .34728 L F
.52621 .34577 m .52631 .34495 L .52621 .34577 L F
.52621 .34577 m .52621 .34577 L .52603 .34728 L F
.52626 .34533 m .52624 .34547 L .5262 .34535 L F
.52554 .34601 m .52631 .34495 L .52631 .34495 L F
.52552 .34604 m .52554 .34601 L .52554 .34601 L F
.52554 .34601 m .52631 .34495 L .52554 .34601 L F
.52564 .34588 m .52657 .34461 L .52564 .34588 L F
.52552 .34604 m .52631 .34496 L .52632 .34496 L F
.52625 .34529 m .52597 .34658 L p .52613 .34533 L F P
0 g
s
.52597 .34658 m .52608 .34565 L .52609 .34565 L .672 .728 .891 r
F
.52609 .346 m .52618 .34559 L p .52575 .34602 L F P
0 g
s
.52624 .34547 m .52604 .34717 L .5259 .34517 L .672 .728 .891 r
F
.52591 .34515 m .5259 .34517 L .5259 .34514 L F
.52624 .34547 m .5259 .34517 L .52591 .34515 L F
.52604 .34717 m .52603 .34727 L .52603 .3472 L F
.52604 .34717 m .52603 .3472 L .5259 .34514 L F
.52584 .34656 m .52621 .34552 L .52614 .34542 L F
.52621 .34577 m .5263 .34496 L .52621 .34577 L F
.5263 .34496 m .52635 .34458 L .5263 .34496 L F
.5263 .34496 m .5263 .34496 L .52621 .34577 L F
.52748 .34526 m .52748 .34527 L .5279 .34543 L F
.52888 .34576 m .52677 .3451 L p .52955 .34582 L F P
0 g
s
.5279 .34542 m .5279 .34543 L .52812 .34551 L .672 .728 .891 r
F
.52614 .34474 m .5279 .34543 L .5279 .34542 L F
.52802 .34558 m .52632 .34496 L p .52901 .34555 L F P
0 g
s
.52632 .34496 m .52582 .34478 L p .52645 .34493 L .672 .728 .891 r
F P
0 g
s
.52614 .34474 m .52748 .34527 L .52748 .34526 L .672 .728 .891 r
F
.52632 .34496 m .52645 .34493 L .52901 .34555 L F
.52621 .34552 m .52628 .34532 L .52614 .34542 L F
.52626 .34533 m .5262 .34535 L .52604 .34486 L F
.52614 .34542 m .52628 .34532 L .52618 .34526 L F
.52631 .34544 m .5263 .34567 L p .52599 .34518 L F P
0 g
s
.52624 .34547 m .5263 .34497 L .5263 .34496 L .672 .728 .891 r
F
.52628 .34532 m .52632 .34496 L p .52626 .34531 L F P
0 g
s
.52632 .34496 m .52635 .34466 L p .52626 .34531 L .672 .728 .891 r
F P
0 g
s
.52618 .34526 m .52626 .34531 L .52635 .34466 L .672 .728 .891 r
F
.52632 .34496 m .52631 .34544 L p .52614 .34501 L F P
0 g
s
.52595 .34539 m .52632 .34496 L p .52603 .34487 L .672 .728 .891 r
F P
0 g
s
.52614 .34474 m .52615 .34475 L .52748 .34527 L .672 .728 .891 r
F
.52674 .345 m .52645 .34493 L .5266 .3449 L F
.5259 .34444 m .52583 .34465 L .52547 .34415 L F
.52553 .34459 m .52548 .34458 L .52628 .34459 L F
.52621 .34446 m .52614 .34468 L .52623 .34445 L F
.52606 .34464 m .52615 .3446 L .52604 .34462 L F
.52615 .3446 m .52617 .34456 L .52604 .34462 L F
.52553 .34459 m .52628 .34459 L .52628 .34459 L F
.52605 .34463 m .52612 .34467 L .52621 .34446 L F
.52612 .34467 m .52614 .34468 L .52621 .34446 L F
.52614 .34468 m .52628 .3445 L .52623 .34445 L F
.52648 .34441 m .52634 .34464 L .52645 .34434 L F
.52615 .3446 m .52699 .34419 L .52617 .34456 L F
.52547 .34415 m .52537 .34417 L .52627 .34466 L F
.52573 .34575 m .5259 .34537 L .52588 .34535 L F
.52588 .34549 m .52579 .34542 L .52586 .34527 L F
.52573 .34576 m .52573 .34576 L .52614 .34468 L F
.52566 .34571 m .52566 .34572 L .52611 .3447 L F
.52554 .34601 m .52564 .34588 L .52564 .34588 L F
.52573 .34558 m .52573 .34612 L .52554 .34601 L F
.52566 .34572 m .52564 .346 L .52573 .34576 L F
.52566 .34572 m .52573 .34576 L .52611 .3447 L F
.52632 .34496 m .52779 .34558 L .52779 .34558 L F
.52607 .34506 m .52597 .34511 L .52614 .34488 L F
.52611 .3447 m .52573 .34576 L .52614 .34468 L F
.52597 .34503 m .52531 .3463 L .52611 .3447 L F
.52577 .34479 m .52522 .34547 L .52595 .34539 L F
.52571 .34496 m .52566 .34571 L .52611 .3447 L F
.52591 .34483 m .52597 .34479 L .52617 .34477 L F
.52611 .3447 m .52611 .3447 L .52573 .34494 L F
.52574 .34494 m .52591 .34483 L .52643 .34476 L F
.52585 .34458 m .52548 .34458 L .52597 .34453 L F
.52576 .34427 m .52571 .34492 L .52605 .34463 L F
.52519 .34492 m .52574 .34494 L p .52526 .34468 L F P
0 g
s
.52571 .34492 m .52571 .34496 L .52573 .34494 L .672 .728 .891 r
F
.52562 .34481 m .52572 .34489 L .5258 .34485 L F
.52519 .34492 m .52597 .34479 L .52591 .34483 L F
.52571 .34492 m .52573 .34494 L .52605 .34463 L F
.52589 .34519 m .52595 .34539 L .52603 .34487 L F
.52652 .3445 m .52649 .34443 L .52719 .34328 L F
.52722 .34339 m .52654 .34421 L .52721 .34332 L F
.52727 .34365 m .52724 .3435 L .52781 .34282 L F
.52786 .34318 m .52731 .34382 L p .52784 .34307 L F P
0 g
s
.52728 .34369 m .52727 .34365 L .52783 .343 L .672 .728 .891 r
F
.52663 .34483 m .52574 .34494 L .52643 .34476 L F
.52574 .34494 m .52611 .3447 L .52573 .34494 L F
.52574 .34494 m .52632 .34496 L p .5254 .3447 L F P
0 g
s
.52602 .3449 m .52596 .34503 L .52592 .3448 L .672 .728 .891 r
F
.52589 .3452 m .52579 .34488 L .52596 .34503 L F
.52595 .34506 m .52585 .34516 L .52594 .34505 L F
.52597 .34511 m .52592 .34513 L .52595 .34506 L F
.52592 .34513 m .52585 .34516 L .52595 .34506 L F
.52596 .34503 m .52579 .34488 L .52592 .3448 L F
.52564 .346 m .52602 .34568 L .52616 .34505 L F
.52614 .34599 m .52589 .3452 L .52596 .34503 L F
.52628 .34672 m .5261 .34606 L .52614 .34599 L F
.52552 .34604 m .52551 .34604 L .52631 .34495 L F
.52564 .346 m .52616 .34505 L .52601 .34513 L F
.52637 .34494 m .52574 .34494 L .52663 .34483 L F
.5254 .3447 m .52632 .34496 L .52623 .34484 L F
.52592 .3448 m .52579 .34488 L .52578 .34429 L F
.52584 .34436 m .52578 .34429 L .52578 .34404 L F
.52592 .3448 m .52578 .34429 L .52584 .34436 L F
.5256 .34426 m .52234 .34315 L .5257 .34458 L F
.52213 .34308 m .522 .34317 L .5257 .34458 L F
.52573 .34463 m .52514 .34451 L .52558 .34434 L F
.52583 .34465 m .52573 .34463 L .52547 .34415 L F
.52578 .34426 m .52579 .34503 L .52576 .34427 L F
.52558 .34434 m .52498 .34447 L .52547 .34415 L F
.52498 .34447 m .52501 .344 L .52547 .34415 L F
.5255 .3443 m .52535 .34454 L .52611 .3447 L F
.52502 .34397 m .52611 .3447 L .52604 .34461 L F
.52604 .34473 m .52592 .3448 L .52584 .34436 L F
.52595 .34451 m .52584 .34436 L .52578 .34404 L F
.52604 .34473 m .52584 .34436 L .52595 .34451 L F
.52616 .34476 m .52612 .34471 L .52614 .34469 L F
.52458 .34456 m .52535 .34467 L .52525 .3446 L F
.52535 .34454 m .5253 .34454 L .52556 .34458 L F
.5253 .34454 m .52454 .34453 L .5253 .34457 L F
.5253 .34454 m .5253 .34457 L .52556 .34458 L F
.52234 .34315 m .52236 .34318 L .5257 .34458 L F
.52499 .34439 m .52471 .34389 L .52501 .344 L F
.52498 .34447 m .52471 .34389 L .52499 .34439 L F
.52234 .34315 m .52213 .34308 L .52236 .34318 L F
.52213 .34308 m .5186 .34188 L .522 .34317 L F
.5186 .34188 m .51046 .33912 L .51883 .34212 L F
.52111 .34315 m .52444 .34434 L .52457 .34426 L F
.52484 .34428 m .51541 .34155 L .52471 .34416 L F
.5186 .34188 m .51883 .34212 L .521 .3429 L F
.52087 .34275 m .521 .3429 L .5257 .34458 L F
.5186 .34188 m .521 .3429 L .52087 .34275 L F
.52663 .34398 m .52642 .34436 L .52652 .344 L F
.52645 .34434 m .52645 .34432 L .52673 .34381 L F
.52635 .34416 m .52694 .34405 L .52647 .34404 L F
.52622 .34445 m .52623 .34445 L .52627 .34434 L F
.52623 .34445 m .52637 .34413 L .52627 .34434 L F
.52648 .34441 m .52645 .34434 L .52673 .34381 L F
.52635 .34458 m .52642 .34399 L .52642 .34398 L F
.52623 .34442 m .52694 .34405 L .52635 .34416 L F
.52665 .34399 m .52614 .34461 L .52656 .344 L F
.52603 .34727 m .52579 .34553 L .52588 .34549 L F
.52573 .34612 m .5257 .34667 L .52553 .34601 L F
.52578 .34564 m .52544 .35228 L .52575 .34559 L F
.52564 .346 m .52549 .34804 L .52602 .34568 L F
.52582 .34643 m .52575 .34647 L .52573 .34558 L F
.52575 .34552 m .52573 .34558 L .52571 .34496 L F
.52582 .34643 m .52573 .34558 L .52575 .34552 L F
.52489 .34607 m .52527 .34632 L .52427 .34696 L F
.52522 .34547 m .52525 .34557 L .52595 .34539 L F
.52541 .34601 m .52567 .34571 L p .52525 .34557 L F P
0 g
s
.52567 .34571 m .52595 .34539 L p .52525 .34557 L .672 .728 .891 r
F P
0 g
s
.52611 .34665 m .52611 .34665 L .52609 .34683 L .672 .728 .891 r
F
.52609 .34683 m .52609 .34683 L .52603 .34728 L F
.52604 .34729 m .52616 .34626 L p .52549 .34804 L F P
0 g
s
.52549 .34804 m .52599 .34592 L .52597 .34591 L .672 .728 .891 r
F
.52544 .35229 m .5248 .35763 L p .52544 .35228 L F P
0 g
s
.52549 .34628 m .52544 .35228 L .52483 .35022 L .672 .728 .891 r
F
.5257 .34667 m .52544 .35228 L .52549 .34628 L F
.52549 .34804 m .52616 .34626 L .52584 .34656 L F
.52544 .35228 m .5248 .35763 L .52483 .35022 L F
.5248 .35763 m .52604 .34729 L p .52549 .34804 L F P
0 g
s
.52601 .35767 m .5248 .35763 L p .52566 .34571 L .672 .728 .891 r
F P
0 g
s
.52571 .34496 m .52573 .34574 L .52566 .34571 L .672 .728 .891 r
F
.52564 .346 m .52575 .34575 L .52573 .34575 L F
.52573 .34576 m .52564 .346 L .52573 .34576 L F
.52573 .34574 m .52601 .35767 L .52566 .34571 L F
.52595 .34539 m .52567 .34571 L p .52579 .34544 L F P
0 g
s
.5241 .34686 m .52427 .34696 L .52376 .34729 L .672 .728 .891 r
F
.52577 .34479 m .52427 .34696 L .5241 .34686 L F
.51787 .35633 m .51681 .35594 L p .52376 .34729 L F P
0 g
s
.52531 .3463 m .51787 .35633 L .52376 .34729 L .672 .728 .891 r
F
.51681 .35594 m .52541 .34601 L p .52522 .34547 L F P
0 g
s
.52567 .34571 m .52468 .34685 L p .52579 .34544 L .672 .728 .891 r
F P
0 g
s
.52468 .34685 m .51681 .35594 L p .52476 .34664 L .672 .728 .891 r
F P
0 g
s
.52468 .34685 m .52476 .34664 L .52579 .34544 L .672 .728 .891 r
F
.52625 .34468 m .52611 .3447 L .5259 .34444 L F
.52593 .34447 m .52617 .34468 L .52627 .34466 L F
.52762 .345 m .52674 .345 L .52668 .34481 L F
.52643 .34476 m .52699 .34468 L .52696 .34469 L F
.52738 .34496 m .52738 .34496 L .52749 .34493 L F
.52625 .34473 m .52735 .34491 L .52735 .3449 L F
.5269 .34486 m .52738 .34496 L .52735 .34491 L F
.52735 .3449 m .52735 .34491 L .52749 .34493 L F
.52705 .34499 m .52667 .34473 L .52755 .34462 L F
.52761 .345 m .52668 .34481 L .5266 .3446 L F
.52762 .345 m .52668 .34481 L .52761 .345 L F
.52619 .3448 m .52642 .34476 L .52643 .34476 L F
.52642 .34476 m .52699 .34468 L .52643 .34476 L F
.52705 .34499 m .52643 .34476 L .52684 .34485 L F
.52674 .345 m .52641 .34476 L .52668 .34481 L F
.52617 .34478 m .52705 .34499 L .5272 .34492 L F
.52591 .34483 m .52617 .34477 L .52619 .3448 L F
.52535 .34467 m .52621 .34483 L .52617 .34478 L F
.52692 .34494 m .52637 .34494 L .52663 .34483 L F
.5262 .34481 m .52623 .34485 L .52649 .34444 L F
.52619 .3449 m .52614 .34488 L .52632 .34465 L F
.52628 .34477 m .52636 .34475 L .52639 .34475 L F
.52628 .34477 m .52639 .34475 L .52642 .34476 L F
.52619 .3448 m .52628 .34477 L .52642 .34476 L F
.52623 .34485 m .52632 .34496 L .52646 .34451 L F
.52502 .34397 m .52531 .34453 L .52535 .34454 L F
.52497 .3444 m .52538 .3445 L .52537 .34451 L F
.521 .34318 m .52463 .3444 L .52111 .34315 L F
.52497 .3444 m .51541 .34155 L .52484 .34428 L F
.52539 .34447 m .5233 .34373 L .52518 .34454 L F
.50962 .33884 m .52318 .34381 L p .5233 .34373 L F P
0 g
s
.52318 .34381 m .52518 .34454 L p .5233 .34373 L .672 .728 .891 r
F P
0 g
s
.52501 .34458 m .50739 .34434 L .52503 .34457 L .672 .728 .891 r
F
.52293 .3447 m .52358 .34475 L .52293 .3447 L F
.52358 .34475 m .52358 .34475 L .52293 .3447 L F
.52576 .34492 m .52576 .34492 L .52293 .3447 L F
.52459 .34483 m .52459 .34483 L .52427 .3448 L F
.52364 .34475 m .52506 .34486 L .52362 .34475 L F
.52506 .34486 m .52506 .34486 L .52362 .34475 L F
.52293 .3447 m .52364 .34475 L .52293 .3447 L F
.52364 .34475 m .52362 .34475 L .52293 .3447 L F
.52293 .3447 m .52506 .34486 L .52505 .34486 L F
.52293 .3447 m .52427 .3448 L .52427 .3448 L F
.52519 .34492 m .50739 .34434 L p .52366 .34456 L F P
0 g
s
.52218 .34451 m .5139 .34509 L .51632 .34444 L .672 .728 .891 r
F
.52454 .34453 m .52458 .34456 L .52525 .3446 L F
.52454 .34453 m .52372 .34452 L .52458 .34456 L F
.5253 .34454 m .52189 .34471 L .52218 .34451 L F
.52189 .34471 m .5139 .34509 L .52218 .34451 L F
.52512 .34452 m .52498 .34447 L p .52558 .34434 L F P
0 g
s
.5254 .34456 m .52468 .34425 L .52573 .34452 L .672 .728 .891 r
F
.5258 .3454 m .52582 .34643 L .52575 .34552 L F
.5258 .3454 m .52575 .34552 L .52571 .34496 L F
.52592 .34513 m .52551 .34573 L .52585 .34516 L F
.52582 .34536 m .52551 .34573 L .52592 .34513 L F
.52595 .34539 m .52574 .34545 L .52599 .34516 L F
.5261 .34606 m .5258 .3454 L .52588 .34522 L F
.52573 .34557 m .5259 .3456 L .52598 .34513 L F
.52573 .34557 m .52575 .34652 L .5259 .3456 L F
.52573 .34557 m .52589 .3457 L .52573 .34581 L F
.52579 .34503 m .5258 .3454 L .52571 .34496 L F
.52588 .34522 m .5258 .3454 L .52579 .34488 L F
.52588 .34522 m .52579 .34488 L .52589 .3452 L F
.52543 .34555 m .52589 .34492 L .5259 .34495 L F
.52591 .34497 m .52543 .34555 L .5259 .34495 L F
.52606 .34479 m .52592 .3448 L .52604 .34473 L F
.52602 .3449 m .52592 .3448 L .52606 .34479 L F
.52585 .34516 m .52604 .34484 L .52598 .345 L F
.526 .34476 m .52617 .34478 L .52605 .34473 L F
.52617 .34478 m .5272 .34492 L .52615 .34475 L F
.52617 .34478 m .52615 .34475 L .52605 .34473 L F
.52631 .34495 m .52659 .34457 L .5266 .34459 L F
.52599 .34592 m .52631 .34457 L .52597 .34591 L F
.52595 .34539 m .5263 .34494 L .52631 .34495 L F
.5263 .34494 m .52659 .34457 L .52631 .34495 L F
.52611 .3447 m .52606 .34479 L .52604 .34473 L F
.52611 .3447 m .52604 .34473 L .52595 .34451 L F
.52664 .34459 m .52632 .34496 L p .52661 .3446 L F P
0 g
s
.52632 .34496 m .52629 .34497 L .52631 .34495 L .672 .728 .891 r
F
.52632 .34496 m .52631 .34495 L .52697 .34414 L F
.52605 .34473 m .52615 .34475 L .52611 .3447 L F
.52619 .3449 m .52632 .34465 L .52637 .34464 L F
.52615 .34475 m .5272 .34492 L .52611 .3447 L F
.52576 .34427 m .52605 .34463 L .52623 .34445 L F
.52631 .34457 m .52642 .34409 L .52626 .3446 L F
.52649 .34442 m .52648 .34441 L .52678 .34393 L F
.52604 .34462 m .52694 .34405 L .52599 .34455 L F
.52604 .34461 m .52621 .34472 L .52593 .34447 L F
.52616 .34476 m .52614 .34469 L .52623 .34467 L F
.52616 .34469 m .52611 .3447 L .52621 .34472 L F
.52604 .34461 m .52611 .3447 L .52616 .34469 L F
.5259 .34495 m .52589 .34492 L .52606 .3447 L F
.52611 .34469 m .52611 .3447 L .52665 .34399 L F
.5266 .3446 m .52625 .34468 L .5259 .34444 L F
.52581 .34433 m .5256 .34426 L .5258 .34434 L F
.52547 .34415 m .52627 .34466 L .52634 .34465 L F
.52632 .34496 m .52595 .34451 L .52578 .34404 L F
.52611 .3447 m .52606 .3447 L .52614 .34461 L F
.52611 .3447 m .52614 .34461 L .52665 .34399 L F
.52635 .34366 m .52634 .34415 L p .52578 .34404 L F P
0 g
s
.52576 .34427 m .5259 .34444 L .52547 .34415 L .672 .728 .891 r
F
.5266 .3446 m .5259 .34444 L .52576 .34427 L F
.5266 .3446 m .52547 .34415 L .52634 .34465 L F
.52688 .34418 m .52657 .34461 L .52683 .34405 L F
.52604 .34462 m .52699 .34419 L .52642 .34438 L F
.52654 .34421 m .52591 .34497 L .52651 .3442 L F
.52622 .34445 m .52627 .34434 L .52639 .34404 L F
.52633 .34418 m .52632 .34457 L .52613 .34464 L F
.52687 .34498 m .52632 .34496 L p .52692 .34494 L F P
0 g
s
.52632 .34496 m .52574 .34494 L p .52637 .34494 L .672 .728 .891 r
F P
0 g
s
.52632 .34496 m .52637 .34494 L .52692 .34494 L .672 .728 .891 r
F
.52557 .34527 m .52604 .34462 L .52605 .34462 L F
.52534 .34559 m .52556 .34528 L .52557 .34527 L F
.52556 .34528 m .52604 .34462 L .52557 .34527 L F
.52595 .34506 m .52597 .34502 L .52617 .34478 L F
.52618 .34478 m .52617 .34478 L .52687 .34394 L F
.52595 .34506 m .52617 .34478 L .52618 .34478 L F
.52535 .34454 m .52556 .34458 L .52603 .34461 L F
.52657 .34462 m .52688 .34418 L .52688 .34419 L F
.52657 .34462 m .52657 .34462 L .52724 .3437 L F
.52657 .34461 m .52652 .3445 L .52683 .34405 L F
.52663 .34456 m .52689 .34424 L p .52656 .3444 L F P
0 g
s
.52604 .34528 m .52675 .34427 L .5268 .34428 L .672 .728 .891 r
F
.52595 .34539 m .52603 .34527 L .52604 .34528 L F
.52603 .34527 m .52675 .34427 L .52604 .34528 L F
.52253 .34344 m .52251 .34344 L .52539 .34447 L F
.52253 .34344 m .52539 .34447 L .5254 .34447 L F
.51046 .33912 m .51021 .33905 L .52251 .34344 L F
.51046 .33912 m .52251 .34344 L .52253 .34344 L F
.51046 .33912 m .50962 .33884 L .51021 .33905 L F
.52498 .34447 m .50962 .33884 L p .52471 .34389 L F P
0 g
s
.52258 .34337 m .52531 .34453 L p .52502 .34397 L .672 .728 .891 r
F P
0 g
s
.50962 .33884 m .51022 .33812 L p .51651 .34061 L .672 .728 .891 r
F P
0 g
s
.52547 .34415 m .51927 .34207 L .51962 .34184 L .672 .728 .891 r
F
.52468 .34425 m .52439 .34376 L .52562 .34425 L F
.52603 .34527 m .52599 .34516 L .52675 .34427 L F
.52653 .34461 m .52634 .34465 L .52644 .34471 L F
.52653 .34461 m .52644 .34471 L .52677 .3449 L F
.5266 .3446 m .52653 .34461 L .52677 .3449 L F
.52623 .34467 m .52614 .34469 L .52705 .34359 L F
.52632 .34457 m .52615 .34467 L .52613 .34464 L F
.52578 .34404 m .52622 .34445 L .52639 .34404 L F
.52634 .34415 m .52613 .34464 L .52578 .34404 L F
.52614 .34461 m .52609 .34467 L .52627 .34432 L F
.52597 .34511 m .52618 .34478 L .5262 .34481 L F
.52598 .345 m .52612 .34471 L .52616 .34476 L F
.52607 .34506 m .52612 .34494 L .52613 .34498 L F
.52612 .34494 m .52614 .34488 L .52613 .34498 L F
.52613 .34498 m .52614 .34488 L .52619 .3449 L F
.52624 .34486 m .52607 .34506 L .52623 .34485 L F
.52632 .34496 m .52614 .34501 L .52606 .34479 L F
.52571 .34496 m .52574 .34494 L .52573 .34494 L F
.52571 .34492 m .52579 .34503 L .52571 .34496 L F
.52576 .34427 m .52579 .34488 L .52571 .34492 L F
.52579 .34488 m .52579 .34503 L .52571 .34492 L F
.5254 .3447 m .52593 .3448 L .52535 .34467 L F
.52624 .34486 m .52623 .34485 L .52687 .34394 L F
.52593 .3448 m .52683 .34495 L .52596 .34478 L F
.52632 .34469 m .52632 .34474 L .52647 .34477 L F
.52627 .34466 m .52632 .34474 L .52632 .34469 L F
.5262 .34481 m .52618 .34478 L .52687 .34394 L F
.52627 .34466 m .52621 .34472 L .52632 .34474 L F
.52617 .34468 m .52621 .34472 L .52627 .34466 L F
.52597 .34501 m .52598 .345 L .52684 .3439 L F
.52683 .34495 m .52683 .34494 L .52596 .34478 L F
.52621 .34483 m .52705 .34499 L .52617 .34478 L F
.52621 .34472 m .52688 .34513 L .52647 .34477 L F
.52632 .34457 m .52632 .34496 L .52615 .34467 L F
.52621 .34472 m .52611 .3447 L .5268 .34517 L F
.52655 .34433 m .52594 .34505 L .52649 .34435 L F
.52632 .34496 m .52633 .34457 L p .52621 .34482 L F P
0 g
s
.52614 .34461 m .52627 .34432 L .52676 .34372 L .672 .728 .891 r
F
.52634 .34418 m .52633 .34454 L p .52633 .34418 L F P
0 g
s
.52665 .34462 m .5266 .3446 L .52677 .3449 L .672 .728 .891 r
F
.52901 .34555 m .52767 .34523 L .52762 .345 L F
.52767 .34523 m .52674 .345 L .52762 .345 L F
.52812 .34502 m .52705 .34499 L p .52755 .34462 L F P
0 g
s
.52841 .34508 m .52804 .34505 L .52801 .34485 L .672 .728 .891 r
F
.53061 .34478 m .52839 .34466 L .52882 .34507 L F
.52839 .34466 m .52749 .34493 L .52882 .34507 L F
.53451 .345 m .53061 .34478 L .53099 .34532 L F
.53061 .34478 m .52882 .34507 L .53099 .34532 L F
.54513 .3464 m .54524 .34558 L p .53451 .345 L F P
0 g
s
.53184 .34538 m .53182 .34536 L .54211 .3461 L .672 .728 .891 r
F
.54513 .3464 m .54293 .34623 L p .54211 .3461 L F P
0 g
s
.53451 .345 m .53099 .34532 L .54513 .3464 L .672 .728 .891 r
F
.54524 .34558 m .52812 .34502 L p .52755 .34462 L F P
0 g
s
.52767 .34472 m .5272 .34492 L .5309 .34506 L .672 .728 .891 r
F
.52705 .34499 m .52761 .345 L p .5272 .34492 L F P
0 g
s
.52761 .345 m .54524 .34558 L p .5272 .34492 L .672 .728 .891 r
F P
0 g
s
.52799 .34515 m .52765 .34501 L .52787 .34545 L .672 .728 .891 r
F
.52765 .34501 m .52665 .34462 L .52705 .34489 L F
.52765 .34501 m .52705 .34489 L .52787 .34545 L F
.5281 .34544 m .52812 .34551 L .53591 .34848 L F
.52955 .34582 m .52982 .34585 L .53367 .347 L F
.52971 .34602 m .52888 .34576 L p .53116 .34635 L F P
0 g
s
.52876 .34554 m .52902 .34577 L .53183 .34677 L .672 .728 .891 r
F
.53123 .3464 m .53116 .34635 L .53367 .347 L F
.53046 .34591 m .53183 .34677 L .5431 .3508 L F
.54292 .35105 m .52802 .34558 L p .52901 .34555 L F P
0 g
s
.52825 .34552 m .52787 .34545 L .52853 .3459 L .672 .728 .891 r
F
.52799 .34515 m .52787 .34545 L .52825 .34552 L F
.54106 .3512 m .54055 .35099 L .54117 .35127 L F
.53786 .34905 m .54055 .35099 L .54106 .3512 L F
.53786 .34905 m .52799 .34515 L .54055 .35099 L F
.52853 .3459 m .54117 .35127 L p .52799 .34515 L F P
0 g
s
.54117 .35127 m .5423 .35175 L p .53786 .34905 L .672 .728 .891 r
F P
0 g
s
.52779 .34558 m .52779 .34558 L .54147 .35137 L .672 .728 .891 r
F
.54117 .35127 m .5272 .34534 L p .54147 .35137 L F P
0 g
s
.5272 .34534 m .52721 .34534 L .54147 .35137 L .672 .728 .891 r
F
.52779 .34558 m .5278 .34558 L .54147 .35137 L F
.52756 .34548 m .52761 .34549 L .54147 .35137 L F
.52829 .34553 m .52728 .34519 L .52857 .34549 L F
.52603 .34461 m .52606 .34464 L .52645 .34466 L F
.52699 .34468 m .52714 .34466 L .52696 .34469 L F
.526 .34476 m .52605 .34473 L .52529 .3446 L F
.52535 .34454 m .52535 .34455 L .5253 .34454 L F
.52529 .3446 m .52605 .34473 L .52575 .34462 L F
.52525 .3446 m .52529 .3446 L .52529 .3446 L F
.52529 .3446 m .52605 .34473 L .52529 .3446 L F
.52535 .34455 m .52582 .34475 L p .52535 .34454 L F P
0 g
s
.52531 .34453 m .52582 .34475 L .52582 .34475 L .672 .728 .891 r
F
.52516 .34447 m .52531 .34453 L .52531 .34453 L F
.52531 .34453 m .52582 .34475 L .52531 .34453 L F
.52605 .34473 m .52611 .3447 L .52575 .34462 L F
.52611 .3447 m .52535 .34454 L .52582 .34475 L F
.52531 .34453 m .52535 .34455 L p .52535 .34454 L F P
0 g
s
.52576 .34462 m .52611 .3447 L .52606 .34464 L .672 .728 .891 r
F
.52531 .34453 m .52531 .34452 L .52582 .34473 L F
.52609 .34467 m .52606 .3447 L .52605 .34462 L F
.52606 .3447 m .52589 .34492 L .526 .34472 L F
.52576 .34462 m .52611 .3447 L .52576 .34462 L F
.52606 .3447 m .526 .34472 L .52605 .34462 L F
.5259 .34495 m .52606 .3447 L .52611 .34469 L F
.52604 .34484 m .52607 .34477 L .52612 .34471 L F
.52632 .34496 m .52606 .34479 L .52611 .3447 L F
.52611 .3447 m .52584 .34475 L .5263 .34494 L F
.52584 .34475 m .52582 .34475 L .5263 .34494 L F
.52582 .34475 m .52632 .34496 L p .5263 .34494 L F P
0 g
s
.52582 .34474 m .52582 .34473 L .5268 .34515 L .672 .728 .891 r
F
.52705 .34499 m .52687 .34498 L p .52692 .34494 L F P
0 g
s
.52632 .34496 m .52705 .34499 L p .52623 .34484 L .672 .728 .891 r
F P
0 g
s
.52632 .34496 m .5268 .34517 L p .52611 .3447 L .672 .728 .891 r
F P
0 g
s
.52582 .34474 m .5268 .34515 L .5268 .34515 L .672 .728 .891 r
F
.52627 .34432 m .52585 .34483 L .52633 .34418 L F
.5253 .34457 m .52606 .34464 L .52603 .34461 L F
.52585 .34483 m .52585 .34481 L .52633 .34418 L F
.52611 .34469 m .52665 .34399 L .52667 .34399 L F
.52633 .34454 m .52632 .34453 L .52633 .34418 L F
.52633 .34457 m .52634 .34418 L p .52627 .34452 L F P
0 g
s
.52627 .34434 m .52637 .34413 L .52639 .34404 L .672 .728 .891 r
F
.52634 .34415 m .52634 .34418 L p .52633 .34418 L F P
0 g
s
.52676 .34372 m .52627 .34432 L .52633 .34418 L .672 .728 .891 r
F
.52627 .34452 m .52634 .34418 L .52633 .34421 L F
.52667 .34399 m .52665 .34399 L .52721 .34332 L F
.52623 .34441 m .52634 .34415 L .52625 .34413 L F
.52621 .34482 m .52633 .34421 L .52623 .34441 L F
.52633 .34418 m .52605 .34452 L .52599 .34455 L F
.52635 .34416 m .52599 .34455 L .52625 .34438 L F
.52633 .34421 m .52634 .34415 L .52623 .34441 L F
.5268 .34381 m .52665 .34399 L .52676 .34372 L F
.52665 .34399 m .52656 .344 L .52676 .34372 L F
.52694 .34405 m .52681 .34395 L .52647 .34404 L F
.52623 .34467 m .52705 .34359 L .5271 .34357 L F
.52654 .34421 m .52651 .3442 L .52721 .34332 L F
.52693 .34405 m .52702 .34389 L .52681 .34395 L F
.52694 .34405 m .52702 .34389 L .52693 .34405 L F
.52694 .34405 m .52731 .34382 L .52702 .34389 L F
.52727 .34365 m .52693 .34406 L .52724 .3435 L F
.52693 .34406 m .52687 .34394 L .52724 .3435 L F
.52676 .34372 m .52635 .34416 L .52727 .34374 L F
.5262 .34447 m .52621 .34447 L .52621 .34447 L F
.52585 .34483 m .52537 .34543 L .52585 .34481 L F
.52537 .34543 m .5253 .34551 L .52537 .34542 L F
.52537 .34543 m .52537 .34542 L .52584 .34481 L F
.52535 .34454 m .52603 .34461 L .52602 .34458 L F
.52585 .34481 m .52584 .34481 L .52633 .34418 L F
.52537 .34543 m .52584 .34481 L .52585 .34481 L F
.52687 .34394 m .52655 .34433 L .52684 .3439 L F
.52635 .34416 m .52708 .34386 L .5271 .34382 L F
.52591 .34497 m .5259 .34495 L .52721 .34332 L F
.52609 .34527 m .52688 .34419 L .52688 .34419 L F
.52649 .34444 m .52663 .34456 L .52656 .3444 L F
.52672 .3443 m .52624 .34486 L .5266 .34434 L F
.52672 .3443 m .5266 .34434 L .52687 .34394 L F
.52693 .34406 m .52672 .3443 L .52687 .34394 L F
.52604 .34528 m .52727 .34365 L .52728 .34369 L F
.52595 .34539 m .52604 .34528 L .52604 .34528 L F
.52604 .34528 m .52727 .34365 L .52604 .34528 L F
.52557 .34412 m .52325 .34331 L .52288 .3429 L F
.52619 .34464 m .5272 .34492 L .52749 .3448 L F
.5274 .34483 m .5274 .34484 L .52688 .34483 L F
.5274 .34484 m .52736 .34494 L .52688 .34483 L F
.52683 .34495 m .52705 .34499 L .52683 .34494 L F
.52665 .34462 m .52677 .3449 L .52794 .34556 L F
.52802 .34555 m .52794 .34556 L .52853 .3459 L F
.52665 .34462 m .52794 .34556 L .52802 .34555 L F
.52743 .3447 m .52743 .34471 L .52759 .34471 L F
.52743 .34471 m .52749 .3448 L .52767 .34472 L F
.52619 .34464 m .52749 .3448 L .52743 .34471 L F
.52759 .34471 m .52759 .34471 L .52767 .34472 L F
.5285 .3447 m .5268 .34483 L .52659 .3447 L F
.52773 .34469 m .52767 .34472 L .54524 .34558 L F
.54524 .34558 m .54526 .34476 L p .52974 .34459 L F P
0 g
s
.52974 .34459 m .52909 .34476 L .54524 .34558 L .672 .728 .891 r
F
.54526 .34476 m .52816 .34483 L .5285 .3447 L F
.52816 .34483 m .5268 .34483 L .5285 .3447 L F
.52602 .34458 m .52603 .34461 L .52742 .34468 L F
.52741 .34467 m .52742 .34468 L .52773 .34469 L F
.52602 .34458 m .52742 .34468 L .52741 .34467 L F
.52609 .34467 m .52605 .34462 L .52627 .34432 L F
.52599 .34455 m .52602 .34458 L .52627 .3446 L F
.52599 .34455 m .52627 .3446 L .52631 .34457 L F
.52605 .34462 m .52604 .34462 L .52627 .34432 L F
.52604 .34462 m .52603 .34461 L .52627 .34432 L F
.52611 .3447 m .52664 .34481 L .52619 .34464 L F
.52664 .34481 m .5272 .34492 L .52657 .34475 L F
.52634 .34465 m .52627 .34466 L .52709 .34511 L F
.52664 .34481 m .52657 .34475 L .52619 .34464 L F
.52606 .34464 m .52611 .3447 L .52619 .34464 L F
.52631 .34455 m .52611 .3447 L .52599 .34455 L F
.52613 .34472 m .52622 .34462 L .52616 .34466 L F
.52603 .34461 m .52645 .34466 L .52642 .34463 L F
.52621 .34482 m .52633 .34457 L .52627 .34452 L F
.52631 .34457 m .52627 .3446 L .52741 .34467 L F
.52741 .34467 m .52741 .34467 L .52773 .34469 L F
.52631 .34457 m .52741 .34467 L .52741 .34467 L F
.5271 .34357 m .52705 .34359 L .52779 .3427 L F
.52845 .34227 m .52783 .343 L .52847 .34204 L F
.52783 .343 m .52781 .34282 L .52847 .34204 L F
.52966 .34084 m .52845 .34227 L .52975 .3405 L F
.52845 .34227 m .52847 .34204 L .52975 .3405 L F
.53181 .33862 m .52957 .3412 L p .53214 .33794 L F P
0 g
s
.52957 .3412 m .52966 .34084 L .53214 .33794 L .672 .728 .891 r
F
.528 .34328 m .53697 .33429 L p .52676 .34372 L F P
0 g
s
.52733 .34395 m .528 .34328 L p .52728 .34376 L .672 .728 .891 r
F P
0 g
s
.52794 .3433 m .5271 .34414 L .52788 .34332 L .672 .728 .891 r
F
.52794 .3433 m .52788 .34332 L .53226 .33871 L F
.53208 .33913 m .52794 .3433 L .53226 .33871 L F
.5272 .3446 m .52646 .34459 L .52641 .34455 L F
.52755 .34462 m .52716 .34461 L .5272 .3446 L F
.52735 .34456 m .52599 .34455 L .52741 .34467 L F
.52735 .34456 m .52611 .3447 L .52631 .34455 L F
.52616 .34466 m .52622 .34462 L .52623 .34449 L F
.52696 .34469 m .52714 .34466 L .52718 .34467 L F
.52603 .34461 m .52767 .34472 L .52773 .34469 L F
.52665 .34463 m .52667 .34461 L p .52601 .34466 L F P
0 g
s
.52699 .34419 m .52664 .34459 L p .52697 .34414 L .672 .728 .891 r
F P
0 g
s
.52664 .34459 m .52661 .3446 L .52697 .34414 L .672 .728 .891 r
F
.52667 .34461 m .52701 .34427 L p .52661 .34442 L F P
0 g
s
.52601 .34466 m .52667 .34461 L .52661 .34442 L .672 .728 .891 r
F
.52534 .34559 m .52497 .34603 L .52533 .34556 L F
.52497 .34603 m .51681 .35594 L .52504 .34583 L F
.52623 .34848 m .52629 .34613 L p .52613 .3475 L F P
0 g
s
.52582 .34643 m .52601 .35767 L .52575 .34647 L .672 .728 .891 r
F
.52583 .35005 m .52623 .34848 L .52613 .3475 L F
.52618 .35073 m .52623 .34848 L p .52583 .35005 L F P
0 g
s
.52631 .34495 m .52611 .34665 L .52611 .34665 L .672 .728 .891 r
F
.5263 .34567 m .52628 .34672 L p .52614 .34599 L F P
0 g
s
.52623 .34667 m .52587 .34968 L p .52581 .3462 L .672 .728 .891 r
F P
0 g
s
.52603 .34728 m .52621 .34577 L .52621 .34577 L .672 .728 .891 r
F
.52628 .34672 m .52595 .34636 L .5261 .34606 L F
.52583 .35005 m .52629 .34613 L .5261 .34627 L F
.52613 .34472 m .52621 .34482 L .52622 .34462 L F
.52582 .34474 m .5268 .34515 L .52582 .34474 L F
.5268 .34517 m .5272 .34534 L p .5269 .34515 L F P
0 g
s
.5268 .34515 m .52721 .34533 L .5268 .34515 L .672 .728 .891 r
F
.5268 .34515 m .5268 .34515 L .52582 .34474 L F
.52551 .34573 m .51681 .35594 L .52538 .34572 L F
.52585 .34516 m .52319 .34832 L .5257 .34522 L F
.52477 .34652 m .52571 .34557 L p .52452 .34644 L F P
0 g
s
.52647 .34477 m .52688 .34513 L .52681 .34498 L .672 .728 .891 r
F
.52676 .34501 m .5254 .34456 L .52674 .34495 L F
.52633 .34454 m .52632 .34496 L p .52632 .34453 L F P
0 g
s
.52632 .34496 m .52582 .34475 L p .52632 .34496 L .672 .728 .891 r
F P
0 g
s
.52597 .34511 m .52595 .34506 L .52618 .34478 L .672 .728 .891 r
F
.52595 .34506 m .52594 .34505 L .52597 .34502 L F
.52611 .3447 m .52613 .34465 L .52601 .34466 L F
.52688 .34483 m .52736 .34494 L .5268 .34483 L F
.52634 .34465 m .52709 .34511 L .52713 .3451 L F
.52659 .3447 m .5268 .34483 L .52611 .3447 L F
.52599 .34455 m .52535 .34454 L .52602 .34458 L F
.52605 .34452 m .52584 .34479 L .52599 .34455 L F
.52587 .34474 m .52582 .34475 L .52599 .34455 L F
.52599 .34455 m .52582 .34475 L .52581 .34473 L F
.52599 .34455 m .52581 .34473 L .52602 .34459 L F
.52599 .34455 m .52611 .3447 L .52577 .34463 L F
.52606 .34464 m .52625 .34413 L .52615 .3441 L F
.52551 .34573 m .52538 .34572 L .52585 .34516 L F
.52576 .34515 m .52452 .34644 L .52571 .34557 L F
.52564 .34562 m .5257 .34557 L .52565 .34562 L F
.52604 .34484 m .52612 .34471 L .52598 .345 L F
.52614 .34501 m .52597 .34506 L .52596 .34503 L F
.52614 .34501 m .52596 .34503 L .52602 .3449 L F
.52614 .34501 m .52602 .3449 L .52606 .34479 L F
.52596 .34472 m .52611 .3447 L .52601 .34466 L F
.52581 .34473 m .52596 .34472 L .52601 .34466 L F
.52593 .3448 m .52596 .34478 L .52535 .34467 L F
.52526 .34468 m .52574 .34494 L .5254 .3447 L F
.5253 .34551 m .52529 .34547 L .52534 .3454 L F
.52713 .3451 m .52709 .34511 L .52853 .3459 L F
.5268 .34495 m .5272 .34534 L .52764 .34541 L F
.52761 .34549 m .5268 .34515 L .52775 .34536 L F
.52621 .34472 m .5268 .34517 L .5269 .34515 L F
.5268 .34515 m .52582 .34473 L .52677 .34504 L F
.52688 .34513 m .5272 .34534 L .5268 .34495 L F
.5268 .34515 m .52677 .34504 L .52775 .34536 L F
.52665 .34462 m .52703 .34423 L .52703 .34423 L F
.52582 .34473 m .5258 .34469 L .52676 .34501 L F
.52677 .34504 m .52676 .34501 L .52961 .34597 L F
.52582 .34473 m .52676 .34501 L .52677 .34504 L F
.52581 .34473 m .52691 .34431 L .52691 .34425 L F
.52691 .34431 m .52701 .34427 L .52693 .34425 L F
.52691 .34431 m .52693 .34425 L .52691 .34425 L F
.52631 .34495 m .52631 .34495 L .52611 .34665 L F
.52631 .34495 m .52609 .34683 L .52609 .34683 L F
.52616 .34626 m .52628 .34532 L p .52584 .34656 L F P
0 g
s
.5261 .34606 m .526 .34611 L .52605 .34596 L .672 .728 .891 r
F
.52584 .34656 m .52625 .345 L .5262 .34502 L F
.526 .34611 m .52581 .3462 L .52605 .34596 L F
.52605 .34596 m .52581 .3462 L .5258 .3454 L F
.52574 .34554 m .52599 .34529 L p .52573 .34554 L F P
0 g
s
.52628 .34536 m .52599 .34518 L .52597 .34506 L .672 .728 .891 r
F
.52628 .34536 m .52597 .34506 L .52614 .34501 L F
.52624 .34539 m .52599 .34518 L .52628 .34536 L F
.52632 .34496 m .52595 .34539 L p .52629 .34497 L F P
0 g
s
.52615 .34564 m .52632 .34496 L .52621 .34482 L .672 .728 .891 r
F
.52599 .34529 m .52665 .34463 L p .52598 .34529 L F P
0 g
s
.52573 .34554 m .52599 .34529 L .52598 .34529 L .672 .728 .891 r
F
.52761 .34549 m .52775 .34536 L .52779 .34554 L F
.52779 .34554 m .52775 .34536 L .52961 .34597 L F
.5268 .34516 m .52721 .34533 L .52721 .34533 L F
.5268 .34515 m .52721 .34533 L .5268 .34516 L F
.52598 .34513 m .52612 .34471 L .52611 .3447 L F
.52598 .34513 m .52611 .3447 L .52604 .34474 L F
.52601 .34515 m .52612 .34471 L .52598 .34513 L F
.52582 .34475 m .52632 .34496 L .52632 .34496 L F
.52594 .34505 m .52598 .345 L .52597 .34501 L F
.52582 .34475 m .52632 .34496 L .52632 .34496 L F
.52678 .34494 m .52681 .34498 L .5268 .34495 L F
.52647 .34477 m .52681 .34498 L .52678 .34494 L F
.52701 .34427 m .52665 .34463 L p .52703 .34423 L F P
0 g
s
.52672 .34489 m .52594 .34472 L .52671 .34484 L .672 .728 .891 r
F
.52597 .34591 m .52614 .34523 L .52612 .34521 L F
.5263 .34567 m .52614 .34599 L .52599 .34518 L F
.52599 .34562 m .52621 .34482 L .52594 .34561 L F
.52773 .34524 m .52594 .34472 L .52769 .34509 L F
.52587 .34579 m .52591 .3456 L .5259 .3456 L F
.52604 .34517 m .52621 .34482 L .52613 .34472 L F
.52594 .34561 m .52608 .3452 L .52604 .34517 L F
.52608 .3452 m .52621 .34482 L .52604 .34517 L F
.52589 .34492 m .52587 .34487 L .52605 .34462 L F
.52584 .34479 m .52582 .34475 L .52582 .34475 L F
.52584 .34479 m .52582 .34475 L .52587 .34474 L F
.52516 .34447 m .52632 .34496 L .52632 .34496 L F
.52516 .34447 m .52631 .34496 L .52632 .34496 L F
.52573 .34497 m .5249 .34498 L p .52611 .3447 L F P
0 g
s
.52584 .34479 m .52534 .3454 L .52582 .34475 L .672 .728 .891 r
F
.52534 .3454 m .51681 .35594 L .52532 .34538 L F
.52534 .3454 m .52532 .34538 L .52582 .34475 L F
.51681 .35594 m .51578 .35551 L p .52526 .34533 L F P
0 g
s
.52581 .34473 m .52531 .34537 L .52526 .34533 L .672 .728 .891 r
F
.52531 .34537 m .51681 .35594 L .52526 .34533 L F
.52582 .34475 m .52532 .34538 L .52581 .34473 L F
.52532 .34538 m .51681 .35594 L .52531 .34537 L F
.52532 .34538 m .52531 .34537 L .52581 .34473 L F
.52537 .34542 m .52584 .34479 L .52584 .34481 L F
.52537 .34542 m .52534 .3454 L .52584 .34479 L F
.52589 .34492 m .52542 .34548 L .52587 .34487 L F
.5254 .34546 m .52603 .34461 L .52604 .34462 L F
.52497 .34603 m .5254 .34546 L .5254 .34546 L F
.5254 .34546 m .52603 .34461 L .5254 .34546 L F
.52582 .34473 m .5254 .34456 L .5258 .34469 L F
.52531 .34453 m .52582 .34474 L .52582 .34474 L F
.52531 .34453 m .52582 .34473 L .52582 .34474 L F
.52582 .34475 m .52531 .34453 L p .52582 .34475 L F P
0 g
s
.52531 .34453 m .52582 .34474 L .52582 .34475 L .672 .728 .891 r
F
.52499 .34492 m .52519 .34492 L p .52458 .34456 L F P
0 g
s
.5249 .34498 m .52451 .34498 L p .52577 .34463 L .672 .728 .891 r
F P
0 g
s
.52451 .34498 m .5166 .34506 L p .5241 .34471 L .672 .728 .891 r
F P
0 g
s
.526 .34476 m .52529 .3446 L .52529 .3446 L .672 .728 .891 r
F
.52516 .34447 m .52582 .34475 L .52582 .34475 L F
.52516 .34447 m .52582 .34475 L .52582 .34475 L F
.52535 .34467 m .526 .34476 L .52525 .3446 L F
.52516 .34447 m .52582 .34475 L .52582 .34475 L F
.52458 .34456 m .52519 .34492 L .52526 .34468 L F
.52436 .3449 m .52499 .34492 L p .52372 .34452 L F P
0 g
s
.52372 .34452 m .52499 .34492 L .52458 .34456 L .672 .728 .891 r
F
.52451 .34498 m .5241 .34471 L .52577 .34463 L F
.52595 .34636 m .52581 .3462 L .5261 .34606 L F
.52575 .34652 m .52583 .35005 L .5261 .34627 L F
.52575 .34652 m .52591 .34576 L .52587 .34579 L F
.52575 .34652 m .5261 .34627 L .52615 .34564 L F
.52599 .34562 m .52615 .34564 L .52621 .34482 L F
.5261 .34606 m .52588 .34522 L .52614 .34599 L F
.52575 .34652 m .52615 .34564 L .52599 .34562 L F
.52582 .34475 m .52582 .34475 L .52632 .34496 L F
.52582 .34475 m .52582 .34475 L .52632 .34496 L F
.52582 .34475 m .52632 .34496 L .52582 .34475 L F
.52585 .34516 m .5257 .34522 L .52607 .34477 L F
.52585 .34516 m .52607 .34477 L .52604 .34484 L F
.52582 .34475 m .52632 .34496 L .52582 .34475 L F
.52582 .34475 m .52582 .34475 L .52631 .34496 L F
.52594 .34505 m .52585 .34516 L .52594 .34504 L F
.52581 .34473 m .52572 .34554 L .52611 .3447 L F
.52571 .34496 m .5259 .34508 L .52606 .34464 L F
.52586 .34485 m .5259 .34517 L .52582 .34488 L F
.5259 .3456 m .52601 .34515 L .52598 .34513 L F
.52573 .34554 m .52573 .34557 L .52578 .34541 L F
.52595 .34539 m .52599 .34516 L .52603 .34527 L F
.52607 .34506 m .52582 .34536 L .52592 .34513 L F
.52594 .34505 m .52594 .34504 L .52598 .345 L F
.52572 .34554 m .52573 .34554 L .52611 .3447 L F
.52573 .34557 m .52598 .34513 L .5259 .34508 L F
.52588 .34522 m .52589 .3452 L .52614 .34599 L F
.52591 .34576 m .52604 .34517 L .52587 .34579 L F
.52604 .34517 m .52625 .34413 L .52602 .34516 L F
.52604 .34517 m .52602 .34516 L .52587 .34579 L F
.52642 .34463 m .52645 .34466 L .52743 .34471 L F
.52642 .34463 m .52743 .34471 L .52743 .3447 L F
.52735 .34456 m .52741 .34467 L .52773 .34469 L F
.52603 .34461 m .52759 .34471 L .52759 .34471 L F
.52773 .3447 m .52611 .3447 L .52756 .34457 L F
.52609 .34468 m .52603 .3446 L .52669 .34477 L F
.52577 .34463 m .52669 .34477 L .5267 .34481 L F
.52579 .34467 m .52577 .34463 L .52736 .34494 L F
.52611 .3447 m .52626 .34488 L .52665 .34463 L F
.52594 .34472 m .526 .34471 L .52736 .34494 L F
.5267 .34481 m .52629 .34493 L .52611 .3447 L F
.52701 .34487 m .52644 .34491 L .5267 .34481 L F
.52644 .34491 m .52629 .34493 L .5267 .34481 L F
.52593 .3451 m .52631 .34496 L .52632 .34496 L F
.52626 .34488 m .52632 .34496 L .52665 .34463 L F
.52593 .3451 m .52632 .34496 L .52626 .34488 L F
.52611 .3447 m .52593 .3451 L .52626 .34488 L F
.5259 .34508 m .52598 .34513 L .52606 .34464 L F
.52632 .34496 m .52573 .34497 L p .52629 .34493 L F P
0 g
s
.52632 .34496 m .52629 .34493 L .52644 .34491 L .672 .728 .891 r
F
.52665 .34463 m .52632 .34496 L p .52665 .34462 L F P
0 g
s
.52632 .34496 m .52599 .34529 L p .52631 .34497 L .672 .728 .891 r
F P
0 g
s
.52581 .34473 m .52575 .3448 L .52581 .34481 L .672 .728 .891 r
F
.52575 .3448 m .52526 .34533 L .52581 .34481 L F
.52542 .34548 m .52542 .34548 L .52627 .34432 L F
.52581 .34481 m .52526 .34533 L .52576 .34515 L F
.52575 .34462 m .52576 .34462 L .52576 .34462 L F
.52599 .34455 m .52577 .34463 L .52535 .34455 L F
.52599 .34455 m .52535 .34455 L .52535 .34454 L F
.5254 .34456 m .52573 .34452 L .52577 .34463 L F
.52584 .34481 m .52584 .34479 L .52633 .34418 L F
.52598 .34471 m .52598 .34471 L .526 .34471 L F
.52594 .34472 m .52598 .34471 L .52598 .34471 L F
.52594 .34472 m .52579 .34467 L .52598 .34471 L F
.52577 .34463 m .52573 .34452 L .52603 .3446 L F
.52613 .34472 m .52623 .34449 L .52621 .34448 L F
.52613 .34472 m .52623 .34441 L .52616 .34458 L F
.52637 .34464 m .52632 .34465 L .52687 .34394 L F
.52659 .34457 m .52728 .34369 L .5266 .34459 L F
.52581 .34473 m .52711 .34417 L .5262 .34447 L F
.52577 .34463 m .52603 .3446 L .52609 .34468 L F
.52572 .34422 m .52582 .34486 L .52606 .34464 L F
.52699 .34419 m .52697 .34414 L .52729 .34375 L F
.5266 .34459 m .52728 .34369 L .52729 .34375 L F
.5271 .34414 m .52703 .34403 L .53226 .33871 L F
.52687 .34375 m .52651 .34413 L .5265 .34409 L F
.5268 .34428 m .52675 .34427 L .52727 .34365 L F
.5271 .34382 m .52708 .34386 L .52727 .34374 L F
.52731 .34382 m .52729 .34375 L .52784 .34307 L F
.52728 .34369 m .52783 .343 L .52729 .34375 L F
.52722 .34356 m .52727 .34374 L .528 .34328 L F
.52676 .34372 m .52727 .34374 L .52722 .34356 L F
.53226 .33871 m .52703 .34403 L .52687 .34375 L F
.52928 .34196 m .52928 .34195 L .53208 .33913 L F
.53205 .33923 m .52928 .342 L p .53208 .33913 L F P
0 g
s
.52928 .342 m .52928 .34196 L .53208 .33913 L .672 .728 .891 r
F
.52611 .3447 m .5249 .34498 L .52577 .34463 L F
.52569 .34422 m .52582 .34488 L .52571 .34496 L F
.52599 .34455 m .52621 .34447 L .52625 .34438 L F
.52611 .3447 m .52625 .34413 L .52606 .34464 L F
.52612 .34471 m .52614 .34462 L .52611 .3447 L F
.52614 .34462 m .52625 .34413 L .52611 .3447 L F
.52599 .34455 m .52602 .34459 L .52621 .34447 L F
.52655 .34433 m .52649 .34435 L .52684 .3439 L F
.52542 .34477 m .52555 .34486 L .52623 .34485 L F
.52542 .34477 m .52623 .34485 L .52619 .3448 L F
.52611 .3447 m .52665 .34463 L .52613 .34465 L F
.52573 .34452 m .52666 .34466 L .52669 .34477 L F
.52621 .34447 m .52711 .34417 L .52621 .34447 L F
.52661 .34447 m .52623 .34485 L .52651 .34413 L F
.52629 .34493 m .52573 .34497 L .52611 .3447 L F
.52632 .34496 m .52644 .34491 L .52701 .34487 L F
.52583 .34326 m .52639 .34404 L .52648 .34361 L F
.52785 .33212 m .52781 .33251 L p .52775 .33276 L F P
0 g
s
.52683 .3407 m .52785 .33212 L p .52609 .33963 L .672 .728 .891 r
F P
0 g
s
.52609 .33963 m .52587 .34281 L .52683 .3407 L .672 .728 .891 r
F
.52648 .34361 m .52683 .3407 L p .52587 .34281 L F P
0 g
s
.52625 .34438 m .52621 .34447 L .5279 .34334 L .672 .728 .891 r
F
.5279 .34334 m .5279 .34334 L .528 .34328 L F
.52625 .34438 m .5279 .34334 L .5279 .34334 L F
.5271 .34414 m .52664 .3446 L .52703 .34403 L F
.52664 .3446 m .52662 .34454 L .52703 .34403 L F
.52704 .34421 m .52704 .34421 L .52665 .34461 L F
.5271 .34415 m .5271 .34414 L .52928 .34195 L F
.52631 .34495 m .5271 .34414 L .5271 .34415 L F
.52711 .34417 m .52733 .34395 L p .52621 .34447 L F P
0 g
s
.52621 .34448 m .52623 .34449 L .52623 .34441 L .672 .728 .891 r
F
.52621 .34447 m .52733 .34395 L .52728 .34376 L F
.52703 .34403 m .52661 .34447 L .52687 .34375 L F
.52635 .34416 m .52625 .34438 L .52708 .34386 L F
.52661 .34447 m .52651 .34413 L .52687 .34375 L F
.52651 .34413 m .52596 .34471 L .5265 .34409 L F
.5271 .34415 m .5271 .34415 L .52665 .34461 L F
.52701 .34427 m .52711 .34417 L p .52691 .34425 L F P
0 g
s
.52738 .34387 m .52738 .34387 L .5271 .34415 L .672 .728 .891 r
F
.52738 .34387 m .5271 .34415 L .5271 .34415 L F
.52711 .34415 m .5271 .34415 L .52911 .34213 L F
.52704 .34421 m .52738 .34387 L .52704 .34421 L F
.52703 .34423 m .52911 .34213 L .52911 .34213 L F
.52703 .34423 m .52911 .34213 L .52703 .34423 L F
.52928 .342 m .52701 .34427 L p .52928 .34196 L F P
0 g
s
.52701 .34427 m .52703 .34423 L .52928 .34196 L .672 .728 .891 r
F
.52738 .34387 m .52928 .34195 L .52738 .34387 L F
.52886 .34239 m .52928 .34195 L .52928 .34196 L F
.52665 .34461 m .528 .34324 L .528 .34324 L F
.52573 .34497 m .52632 .34496 L p .52565 .34492 L F P
0 g
s
.52672 .34489 m .52671 .34484 L .52736 .34494 L .672 .728 .891 r
F
.5269 .34496 m .52632 .34496 L p .52701 .34487 L F P
0 g
s
.52665 .34461 m .52665 .34461 L .52631 .34495 L .672 .728 .891 r
F
.5263 .34497 m .52665 .34462 L .52665 .34462 L F
.52664 .3446 m .52626 .34498 L .52662 .34454 L F
.52631 .34495 m .52664 .3446 L .52664 .34461 L F
.52631 .34496 m .52664 .34462 L .52665 .34462 L F
.52648 .34464 m .52637 .34465 L .52665 .3448 L F
.5274 .34496 m .52672 .34489 L .52736 .34494 L F
.52769 .34509 m .52737 .34502 L .5274 .34496 L F
.52737 .34502 m .52672 .34489 L .5274 .34496 L F
.52909 .34493 m .52741 .34495 L p .52912 .34482 L F P
0 g
s
.52741 .34494 m .52783 .34495 L .52783 .34494 L .672 .728 .891 r
F
.52665 .34461 m .52631 .34495 L .52631 .34495 L F
.52736 .34494 m .5269 .34496 L .52701 .34487 L F
.52741 .34495 m .52736 .34495 L p .52736 .34494 L F P
0 g
s
.52736 .34495 m .5269 .34496 L p .52736 .34494 L .672 .728 .891 r
F P
0 g
s
.52687 .34493 m .52741 .34494 L .52741 .34494 L .672 .728 .891 r
F
.52632 .34496 m .52736 .34495 L p .52629 .34493 L F P
0 g
s
.52732 .34494 m .52699 .34487 L .52733 .34503 L .672 .728 .891 r
F
.52857 .34549 m .52773 .34524 L .52769 .34509 L F
.52961 .34597 m .52829 .34553 L .52857 .34549 L F
.54147 .35137 m .52761 .34549 L .52961 .34597 L F
.52716 .34502 m .53097 .34532 L .52716 .34502 L F
.52716 .34502 m .53028 .34526 L .53026 .34526 L F
.52716 .34502 m .53097 .34532 L .52716 .34502 L F
.52735 .34496 m .52733 .34503 L .54216 .35189 L F
.52732 .34494 m .52733 .34503 L .52735 .34496 L F
.52782 .34493 m .52814 .34494 L .52813 .34493 L F
.52664 .34461 m .52665 .34461 L .52631 .34495 L F
.52593 .3451 m .52573 .34554 L .52628 .34497 L F
.52573 .34554 m .52573 .34554 L .52628 .34497 L F
.52628 .34497 m .52573 .34554 L .52631 .34496 L F
.52571 .34496 m .52573 .34554 L .5259 .34508 L F
.52543 .34555 m .52535 .34557 L .52589 .34492 L F
.52582 .34488 m .52587 .34524 L .52571 .34496 L F
.52631 .34495 m .52575 .34551 L .52575 .34551 L F
.52631 .34495 m .52575 .34551 L .52575 .34551 L F
.52549 .34314 m .52561 .34412 L .52568 .34328 L F
.52611 .33945 m .52635 .34366 L .52578 .34404 L F
.52658 .33284 m .52643 .33999 L .52611 .33945 L F
.52643 .33999 m .52635 .34366 L .52611 .33945 L F
.52631 .34495 m .52631 .34495 L .52575 .34551 L F
.52631 .34495 m .52631 .34495 L .52575 .34551 L F
.52565 .34492 m .52629 .34493 L .52629 .34492 L F
.52565 .34492 m .52632 .34496 L .52629 .34493 L F
.52565 .34492 m .52629 .34492 L .52561 .34489 L F
.52629 .34492 m .52686 .34492 L .52628 .34491 L F
.52629 .34492 m .52628 .34491 L .52561 .34489 L F
.52581 .34489 m .5265 .3449 L .52581 .34489 L F
.52601 .34508 m .52599 .34495 L .5261 .34469 L F
.52601 .34508 m .5261 .34469 L .52617 .34477 L F
.52686 .34492 m .52685 .34492 L .52561 .34489 L F
.52623 .34485 m .52601 .34508 L .52617 .34477 L F
.52571 .34557 m .5263 .34497 L .5263 .34497 L F
.52626 .34498 m .52601 .34508 L .52623 .34485 L F
.52665 .34461 m .52665 .34461 L .52631 .34495 L F
.52631 .34495 m .52631 .34495 L .52496 .34631 L F
.52665 .34461 m .52631 .34495 L .52631 .34495 L F
.52479 .34487 m .52626 .34489 L .52478 .34486 L F
.52626 .34489 m .52742 .34491 L .52626 .34489 L F
.52626 .34489 m .52626 .34489 L .52478 .34486 L F
.52659 .34487 m .52886 .34488 L .52664 .34485 L F
.52591 .3456 m .52612 .34471 L .5259 .3456 L F
.52626 .34498 m .52576 .34548 L .52601 .34508 L F
.52571 .34557 m .52599 .34528 L .52571 .34557 L F
.52599 .34528 m .52665 .34462 L .52599 .34528 L F
.52599 .34528 m .52599 .34528 L .52571 .34557 L F
.52547 .34415 m .52502 .34397 L .52537 .34417 L F
.51962 .34184 m .51586 .34093 L .51651 .34061 L F
.51927 .34207 m .51586 .34093 L .51962 .34184 L F
.51586 .34093 m .50962 .33884 L .51651 .34061 L F
.51022 .33812 m .52258 .34337 L p .52502 .34397 L F P
0 g
s
.52562 .34425 m .52325 .34331 L .52557 .34412 L .672 .728 .891 r
F
.52468 .34425 m .51022 .33812 L .52439 .34376 L F
.51022 .33812 m .5109 .33744 L p .52288 .3429 L F P
0 g
s
.52325 .34331 m .51022 .33812 L .52288 .3429 L .672 .728 .891 r
F
.52541 .34414 m .51809 .34076 L .52479 .34422 L F
.5109 .33744 m .51856 .34118 L p .51809 .34076 L F P
0 g
s
.51856 .34118 m .52479 .34422 L p .51809 .34076 L .672 .728 .891 r
F P
0 g
s
.52578 .34404 m .52578 .34426 L .52576 .34427 L .672 .728 .891 r
F
.52571 .3442 m .52606 .34464 L .52616 .34402 L F
.52572 .34417 m .52616 .34402 L .52632 .34303 L F
.52571 .3442 m .52616 .34402 L .52572 .34417 L F
.52557 .34412 m .52541 .34414 L .52558 .34422 L F
.52736 .34494 m .52559 .34418 L .52574 .3442 L F
.52573 .34452 m .52562 .34425 L .52666 .34466 L F
.52585 .34438 m .52614 .34468 L .52637 .34465 L F
.52616 .34458 m .52623 .34441 L .52625 .34413 L F
.52736 .34494 m .52562 .34425 L .52561 .34422 L F
.52557 .34412 m .52648 .34464 L .52653 .34463 L F
.52736 .34494 m .52561 .34422 L .52564 .3442 L F
.52669 .34477 m .52666 .34466 L .52736 .34494 L F
.52572 .3442 m .52699 .34487 L .52732 .34494 L F
.52574 .3442 m .52559 .34418 L .52557 .34412 L F
.52557 .34412 m .52573 .34421 L .52572 .3442 L F
.52573 .34421 m .52699 .34487 L .52572 .3442 L F
.52648 .34464 m .52541 .34414 L .52637 .34465 L F
.52623 .3444 m .5261 .34469 L .52594 .34408 L F
.52617 .34477 m .5261 .34469 L .52622 .34467 L F
.52613 .34468 m .5261 .34469 L .52615 .3447 L F
.52622 .34467 m .5261 .34469 L .52627 .34445 L F
.52622 .34467 m .52627 .34445 L .52632 .34443 L F
.52629 .34456 m .5261 .34469 L .52623 .3444 L F
.5261 .34469 m .5262 .34446 L .52651 .34413 L F
.52619 .3445 m .52619 .34463 L .5262 .3445 L F
.52623 .34485 m .52617 .34477 L .52651 .34413 L F
.52668 .34481 m .52597 .34478 L .52597 .34478 L F
.52575 .3438 m .52586 .34485 L .52569 .34398 L F
.52668 .34481 m .52543 .34475 L .52543 .34475 L F
.52668 .34481 m .52484 .34473 L .52484 .34473 L F
.5262 .34565 m .52632 .34496 L .52615 .34564 L F
.52637 .3457 m .52613 .34543 L .52614 .34531 L F
.5257 .34557 m .52631 .34495 L .5257 .34557 L F
.52631 .34495 m .52664 .34461 L .52631 .34495 L F
.52631 .34495 m .52631 .34495 L .5257 .34557 L F
.52742 .34493 m .52742 .34491 L .52627 .3449 L F
.52627 .3449 m .52627 .3449 L .52422 .34486 L F
.52742 .34493 m .52627 .3449 L .52627 .3449 L F
.52613 .34543 m .5259 .34517 L .52614 .34531 L F
.52593 .34534 m .52592 .34535 L .52631 .34495 L F
.52614 .34531 m .5259 .34517 L .52596 .34502 L F
.52593 .34534 m .52631 .34495 L .52631 .34496 L F
.52592 .34535 m .52665 .34461 L .52592 .34535 L F
.5261 .34469 m .52629 .34541 L .52596 .34502 L F
.5261 .34469 m .52608 .34521 L .52618 .34479 L F
.52596 .34502 m .5259 .34517 L .52586 .34485 L F
.52592 .34535 m .52665 .34461 L .52665 .34461 L F
.52623 .34485 m .52659 .34487 L .52664 .34485 L F
.52478 .34486 m .52624 .34487 L .52623 .34485 L F
.52626 .34498 m .52644 .34464 L .52655 .34463 L F
.52624 .34487 m .52659 .34487 L .52623 .34485 L F
.5263 .34497 m .52631 .34496 L .5263 .34497 L F
.52631 .34496 m .52665 .34462 L .52631 .34496 L F
.52631 .34496 m .52631 .34496 L .5263 .34497 L F
.52672 .34482 m .52669 .34481 L .52463 .34472 L F
.5261 .34469 m .52596 .34502 L .52586 .34485 L F
.52604 .34474 m .52611 .3447 L .52606 .34464 L F
.5261 .34469 m .52586 .34485 L .52581 .34432 L F
.52618 .34479 m .52543 .34475 L .52618 .34479 L F
.5259 .34517 m .52587 .34524 L .52582 .34488 L F
.5265 .3449 m .5265 .3449 L .52441 .34486 L F
.52601 .34508 m .52538 .34533 L .52596 .34471 L F
.52584 .34485 m .52588 .34504 L .52596 .345 L F
.52599 .34495 m .52596 .34471 L .5261 .34469 L F
.52497 .34603 m .52504 .34583 L .52537 .34543 L F
.5254 .34546 m .52537 .34543 L .52603 .34461 L F
.52497 .34603 m .52537 .34543 L .5254 .34546 L F
.5243 .34491 m .52484 .34492 L .52429 .34491 L F
.52484 .34492 m .52742 .34493 L .52483 .34491 L F
.52484 .34492 m .52483 .34491 L .52429 .34491 L F
.52742 .34493 m .52742 .34493 L .52483 .34491 L F
.52483 .34491 m .52483 .34491 L .52429 .34491 L F
.52742 .34493 m .52483 .34491 L .52483 .34491 L F
.52534 .34559 m .52533 .34556 L .5254 .34546 L F
.52542 .34547 m .5254 .34546 L .52604 .34462 L F
.52534 .34559 m .5254 .34546 L .52542 .34547 L F
.52626 .34498 m .52623 .34485 L .52629 .34493 L F
.52583 .34472 m .52632 .34496 L p .52611 .3447 L F P
0 g
s
.52633 .34566 m .52594 .34559 L .5259 .34517 L .672 .728 .891 r
F
.52587 .34524 m .52583 .34532 L .52571 .34496 L F
.52569 .34557 m .52568 .34557 L .52576 .34548 L F
.52576 .3455 m .52576 .34548 L .5263 .34494 L F
.52573 .34554 m .52578 .34541 L .5259 .34508 L F
.52571 .34496 m .52581 .34537 L .52574 .34554 L F
.52569 .34557 m .52576 .34548 L .52576 .3455 L F
.5259 .34517 m .526 .34612 L .52587 .34524 L F
.5261 .34627 m .5262 .34565 L .52615 .34564 L F
.52631 .34544 m .52624 .34539 L .52628 .34536 L F
.52629 .34613 m .52632 .34496 L p .5261 .34627 L F P
0 g
s
.52637 .3457 m .52721 .35766 L p .52594 .34559 L .672 .728 .891 r
F P
0 g
s
.52591 .34549 m .52603 .34659 L .52607 .34553 L .672 .728 .891 r
F
.52608 .34521 m .52603 .34659 L .52614 .34525 L F
.52584 .34485 m .52513 .34539 L .52588 .34504 L F
.51578 .35551 m .5148 .35504 L p .5251 .3454 L F P
0 g
s
.52479 .34487 m .52479 .34487 L .52441 .34486 L .672 .728 .891 r
F
.52627 .34489 m .52479 .34487 L .52479 .34487 L F
.52484 .34492 m .52573 .34497 L .52565 .34492 L F
.52473 .34492 m .52484 .34492 L .52484 .34492 L F
.52484 .34492 m .52573 .34497 L .52484 .34492 L F
.52508 .34497 m .52573 .34497 L p .52484 .34492 L F P
0 g
s
.52473 .34492 m .52486 .34494 L .52484 .34492 L .672 .728 .891 r
F
.52486 .34494 m .52508 .34497 L .52484 .34492 L F
.52441 .34486 m .52478 .34486 L .52478 .34486 L F
.52478 .34486 m .52659 .34487 L .52478 .34486 L F
.52429 .34491 m .52565 .34492 L .52422 .34486 L F
.52565 .34492 m .52561 .34489 L .52422 .34486 L F
.52444 .34487 m .52581 .34489 L .52441 .34486 L F
.52581 .34489 m .52581 .34489 L .52441 .34486 L F
.52576 .34548 m .52581 .34538 L .52601 .34508 L F
.52575 .34551 m .5263 .34494 L .52631 .34495 L F
.52579 .34544 m .52394 .3476 L .52574 .34545 L F
.52496 .34631 m .52576 .3455 L .52575 .34551 L F
.52576 .3455 m .5263 .34494 L .52575 .34551 L F
.52592 .34559 m .52586 .34557 L .52581 .34537 L F
.52583 .34532 m .52581 .34537 L .52571 .34496 L F
.52571 .34557 m .52592 .34535 L .52593 .34534 L F
.52592 .34559 m .52581 .34537 L .52583 .34532 L F
.52587 .34524 m .52592 .34559 L .52583 .34532 L F
.5253 .34551 m .52534 .3454 L .52537 .34542 L F
.52571 .34496 m .52574 .34554 L .52573 .34554 L F
.52542 .34548 m .52534 .34559 L .52542 .34548 L F
.52543 .34555 m .51762 .35497 L .52535 .34557 L F
.51762 .35497 m .51681 .35594 L .51761 .35497 L F
.51762 .35497 m .51761 .35497 L .52535 .34557 L F
.52601 .34508 m .52486 .34625 L .52538 .34533 L F
.52526 .34533 m .52344 .34729 L .52576 .34515 L F
.52344 .34729 m .51578 .35551 L .52366 .34734 L F
.52344 .34729 m .52366 .34734 L .52576 .34515 L F
.52721 .35766 m .52637 .3457 L p .52603 .34659 L F P
0 g
s
.526 .34612 m .52721 .35766 L .52573 .3459 L .672 .728 .891 r
F
.52611 .34723 m .52702 .34917 L .52621 .34813 L F
.52593 .34684 m .52721 .35766 L .52603 .34659 L F
.52611 .34723 m .52621 .34813 L .52606 .34794 L F
.52593 .34684 m .52611 .34723 L .52606 .34794 L F
.5265 .34701 m .52702 .34917 L .52593 .34684 L F
.52645 .34845 m .52842 .3576 L p .52606 .34794 L F P
0 g
s
.52842 .3576 m .52667 .34705 L p .52635 .34799 L .672 .728 .891 r
F P
0 g
s
.52635 .34799 m .52788 .3509 L .52668 .34951 L .672 .728 .891 r
F
.52588 .34518 m .52591 .34549 L .52599 .34516 L F
.52591 .34511 m .52599 .34516 L .5261 .34469 L F
.52588 .34518 m .52599 .34516 L .52591 .34511 L F
.52608 .34521 m .52614 .34525 L .52618 .34479 L F
.52568 .34557 m .52555 .34554 L .52601 .34508 L F
.52627 .34489 m .52626 .34489 L .52479 .34487 L F
.52596 .34471 m .5252 .34551 L .52592 .34471 L F
.52586 .34485 m .52582 .34488 L .52572 .34422 L F
.52572 .34413 m .52572 .34416 L .52634 .34289 L F
.52569 .34418 m .52572 .34416 L .52572 .34413 L F
.52569 .34418 m .52571 .3442 L .52572 .34416 L F
.52574 .34424 m .52572 .34422 L .52569 .34398 L F
.52502 .34397 m .52604 .34461 L .52593 .34447 L F
.52586 .34485 m .52572 .34422 L .52574 .34424 L F
.52579 .34466 m .52582 .34488 L .52577 .34464 L F
.52579 .34466 m .52577 .34464 L .52569 .34422 L F
.52572 .34422 m .52579 .34466 L .52569 .34422 L F
.52541 .34414 m .52583 .34472 L .5261 .34469 L F
.52604 .34462 m .5261 .34469 L .52613 .34468 L F
.52541 .34414 m .5261 .34469 L .52604 .34462 L F
.526 .34456 m .5255 .34458 L .52613 .34472 L F
.52529 .3446 m .52529 .3446 L .52525 .3446 L F
.52531 .34453 m .52531 .34453 L .52582 .34475 L F
.52531 .34453 m .52531 .34453 L .52582 .34475 L F
.52516 .34447 m .52516 .34447 L .52582 .34475 L F
.52521 .34457 m .52529 .3446 L .5253 .34457 L F
.52458 .34456 m .5254 .3447 L .52535 .34467 L F
.52579 .34467 m .5254 .34456 L .52577 .34463 L F
.52577 .34463 m .52412 .3447 L .5253 .34454 L F
.5255 .34458 m .52514 .34459 L .52548 .34463 L F
.5255 .34458 m .52548 .34463 L .52613 .34472 L F
.52502 .34397 m .52535 .34454 L .5255 .3443 L F
.52468 .34425 m .52562 .34425 L .52573 .34452 L F
.52541 .34414 m .52484 .34421 L .52583 .34472 L F
.52479 .34422 m .52484 .34424 L p .52484 .34421 L F P
0 g
s
.52484 .34424 m .52583 .34472 L p .52484 .34421 L .672 .728 .891 r
F P
0 g
s
.52668 .34481 m .52668 .34481 L .52543 .34475 L .672 .728 .891 r
F
.52597 .34478 m .52484 .34473 L .52597 .34478 L F
.52596 .34479 m .52597 .34478 L .52463 .34472 L F
.52406 .34469 m .52618 .34479 L .52613 .34472 L F
.52052 .34477 m .52436 .3449 L p .52387 .34461 L F P
0 g
s
.52412 .3447 m .52134 .3448 L .52386 .34464 L .672 .728 .891 r
F
.52392 .34468 m .52405 .34469 L .52406 .34469 L F
.52405 .34469 m .52618 .34479 L .52406 .34469 L F
.52885 .34239 m .52928 .34195 L .52886 .34239 L F
.52641 .34432 m .52638 .34431 L .52651 .34413 L F
.528 .34324 m .52885 .34239 L .52886 .34239 L F
.528 .34324 m .52885 .34239 L .528 .34324 L F
.52539 .34475 m .52539 .34475 L .52668 .34481 L F
.52478 .34486 m .52572 .34488 L .52573 .34487 L F
.52572 .34488 m .52626 .34489 L .52573 .34487 L F
.52573 .34487 m .52626 .34489 L .52624 .34487 L F
.52603 .3446 m .52518 .34549 L .526 .34456 L F
.52518 .34549 m .51578 .35551 L .52516 .34546 L F
.52518 .34549 m .52516 .34546 L .526 .34456 L F
.52569 .34498 m .52483 .34502 L .52538 .34481 L F
.52571 .34499 m .52483 .34502 L .52569 .34498 L F
.52571 .34499 m .52477 .34505 L p .52483 .34502 L F P
0 g
s
.52475 .34503 m .5257 .34499 L .5257 .34498 L .672 .728 .891 r
F
.52477 .34505 m .52322 .34513 L p .52538 .34481 L F P
0 g
s
.52465 .34503 m .52476 .34503 L .52475 .34503 L .672 .728 .891 r
F
.52476 .34503 m .5257 .34499 L .52475 .34503 L F
.52396 .34471 m .52465 .34474 L .52392 .34468 L F
.52454 .34453 m .52491 .34457 L .52505 .34456 L F
.52491 .34457 m .52525 .3446 L .52505 .34456 L F
.52505 .34456 m .52525 .3446 L .52521 .34457 L F
.52412 .3447 m .52386 .34464 L .5253 .34454 L F
.52282 .34466 m .52312 .34487 L .52555 .34486 L F
.5166 .34506 m .51784 .34494 L .52284 .34475 L F
.52288 .34477 m .52284 .34475 L .52577 .34463 L F
.5166 .34506 m .52284 .34475 L .52288 .34477 L F
.52687 .34493 m .52741 .34494 L .52687 .34493 L F
.52699 .34487 m .52687 .34485 L .5281 .34551 L F
.52819 .34553 m .5281 .34551 L .53405 .34873 L F
.52699 .34487 m .5281 .34551 L .52819 .34553 L F
.52591 .34549 m .52607 .34553 L .52608 .34521 L F
.52599 .34516 m .52608 .34521 L .5261 .34469 L F
.52591 .34549 m .52608 .34521 L .52599 .34516 L F
.52629 .34493 m .52623 .34485 L .52644 .34464 L F
.52596 .34479 m .52672 .34482 L .52597 .34478 L F
.52615 .3447 m .52632 .34496 L .52644 .34491 L F
.52923 .34201 m .52923 .34201 L .52665 .34461 L F
.52665 .34461 m .52807 .34317 L .52665 .34461 L F
.52807 .34317 m .52923 .34201 L .52807 .34317 L F
.52807 .34317 m .52807 .34317 L .52665 .34461 L F
.52692 .34443 m .53122 .34067 L p .52626 .34432 L F P
0 g
s
.52726 .34411 m .52745 .34394 L .52745 .34394 L .672 .728 .891 r
F
.52637 .34465 m .52615 .3447 L .52665 .3448 L F
.52614 .34468 m .52615 .3447 L .52637 .34465 L F
.5261 .34469 m .52596 .34471 L .5262 .34446 L F
.52604 .34462 m .52615 .3447 L .52585 .34438 L F
.5267 .34481 m .52669 .34477 L .52736 .34494 L F
.52653 .34463 m .52648 .34464 L .52699 .34487 L F
.52736 .34494 m .52557 .34412 L .52732 .34494 L F
.52631 .34496 m .5271 .34415 L .52711 .34415 L F
.526 .34456 m .5261 .34469 L .5277 .34475 L F
.5261 .34469 m .52613 .34472 L .52627 .34472 L F
.5261 .34469 m .52627 .34472 L .5277 .34475 L F
.52736 .34495 m .52732 .34494 L .52735 .34496 L F
.52736 .34494 m .52732 .34494 L .52736 .34495 L F
.526 .34456 m .5277 .34475 L .52766 .3447 L F
.52728 .34459 m .52611 .3447 L .52735 .34456 L F
.52801 .34457 m .52773 .34469 L .52909 .34476 L F
.52801 .34457 m .52735 .34456 L .52773 .34469 L F
.54526 .34476 m .52773 .3447 L .52756 .34457 L F
.52762 .34463 m .52838 .34476 L .52789 .34464 L F
.526 .34456 m .52766 .3447 L .52762 .34463 L F
.52766 .3447 m .52838 .34476 L .52762 .34463 L F
.52746 .34397 m .52727 .34413 L p .52745 .34394 L F P
0 g
s
.52558 .34492 m .52527 .34474 L .52595 .34462 L .672 .728 .891 r
F
.52629 .34456 m .52618 .34479 L .52619 .34463 L F
.52648 .34464 m .52665 .3448 L .52687 .34485 L F
.52699 .34487 m .52648 .34464 L .52687 .34485 L F
.52618 .34479 m .52746 .34485 L .52613 .34472 L F
.52677 .34482 m .52662 .34479 L .52668 .34477 L F
.52619 .34463 m .52618 .34479 L .52619 .34462 L F
.52619 .34463 m .52618 .34479 L .5261 .34469 L F
.5261 .34469 m .5261 .34469 L .52628 .34456 L F
.5261 .34469 m .52618 .34479 L .52619 .3445 L F
.52662 .34479 m .52611 .34469 L .52623 .34461 L F
.52651 .34467 m .52627 .34458 L .5263 .34455 L F
.52608 .34466 m .52603 .3446 L .52628 .34456 L F
.52619 .34463 m .52619 .34462 L .5262 .3445 L F
.52662 .34479 m .52592 .34446 L .52671 .34475 L F
.52664 .34461 m .52631 .34495 L .52631 .34495 L F
.52632 .34496 m .52632 .34496 L .52665 .34462 L F
.52631 .34495 m .5263 .34494 L .52664 .3446 L F
.52631 .34496 m .52631 .34495 L .52664 .34462 L F
.52619 .3448 m .52623 .34485 L .52746 .34485 L F
.52619 .34476 m .52618 .34479 L .52632 .34496 L F
.52615 .3447 m .52618 .34479 L .52619 .34476 L F
.52615 .3447 m .52611 .3447 L .52618 .34479 L F
.52565 .34492 m .52687 .34493 L .52687 .34493 L F
.52724 .34493 m .52723 .34492 L .52561 .34489 L F
.52668 .34481 m .52618 .34479 L .52668 .34481 L F
.52618 .34479 m .52618 .34479 L .52668 .34481 L F
.52716 .34491 m .52626 .34489 L .52627 .34489 L F
.52626 .34489 m .52742 .34491 L .52624 .34487 L F
.52632 .34496 m .52779 .34558 L .52632 .34496 L F
.52632 .34496 m .52632 .34496 L .52779 .34558 L F
.52632 .34496 m .5278 .34558 L .52632 .34496 L F
.52632 .34496 m .52631 .34496 L .5278 .34558 L F
.52582 .34475 m .52721 .34533 L .52721 .34533 L F
.52615 .3447 m .52682 .3452 L .52665 .3448 L F
.52682 .3452 m .52685 .34522 L .52684 .3452 L F
.52682 .3452 m .52684 .3452 L .52665 .3448 L F
.5148 .35504 m .51386 .35452 L p .52498 .34542 L F P
0 g
s
.52629 .34456 m .52632 .34496 L p .52618 .34479 L .672 .728 .891 r
F P
0 g
s
.52568 .34419 m .52558 .34422 L .52648 .34464 L .672 .728 .891 r
F
.5261 .34469 m .52581 .34432 L .52567 .343 L F
.52629 .34429 m .52603 .3446 L .526 .34456 L F
.5265 .34409 m .52631 .34429 L .52629 .34429 L F
.52631 .34429 m .52603 .3446 L .52629 .34429 L F
.52596 .34471 m .52592 .34471 L .5265 .34409 L F
.52626 .34432 m .526 .34456 L .52619 .3445 L F
.52578 .34423 m .5262 .3445 L .52622 .34428 L F
.52623 .3444 m .52594 .34408 L .52608 .34403 L F
.52584 .34419 m .52622 .34428 L .52625 .34396 L F
.52578 .34423 m .52622 .34428 L .52584 .34419 L F
.5263 .34455 m .52577 .34465 L .526 .34456 L F
.526 .34456 m .52608 .34467 L .5264 .34442 L F
.52579 .3443 m .5261 .34469 L .52619 .3445 L F
.52604 .3447 m .52667 .34464 L .52669 .34463 L F
.52592 .34446 m .52589 .34443 L .52671 .34475 L F
.5261 .34469 m .52592 .34446 L .52636 .34467 L F
.52581 .3443 m .52613 .34468 L .52641 .34466 L F
.52629 .34493 m .52694 .34494 L .52693 .34494 L F
.52694 .34494 m .52736 .34495 L .52693 .34494 L F
.52693 .34494 m .52736 .34495 L .5273 .34494 L F
.52686 .34492 m .52724 .34493 L .52685 .34492 L F
.52716 .34491 m .52716 .34491 L .52626 .34489 L F
.5243 .34491 m .52429 .34491 L .52041 .34488 L F
.52041 .34488 m .52429 .34491 L .52422 .34486 L F
.51955 .34503 m .52508 .34497 L p .51908 .34489 L F P
0 g
s
.51908 .34489 m .52508 .34497 L .52473 .34492 L .672 .728 .891 r
F
.52347 .34503 m .52052 .34513 L .52452 .34461 L F
.52322 .34513 m .52052 .34513 L .52347 .34503 L F
.52322 .34513 m .51861 .34538 L p .52052 .34513 L F P
0 g
s
.52134 .3448 m .5139 .34509 L .52121 .34474 L .672 .728 .891 r
F
.51954 .34477 m .51536 .3449 L .51937 .34488 L F
.52303 .3448 m .52251 .34487 L .52312 .34487 L F
.52282 .34466 m .52392 .34469 L .52392 .34468 L F
.52282 .34466 m .52396 .34471 L .52392 .34469 L F
.52052 .34489 m .5243 .34491 L .52041 .34488 L F
.52134 .3448 m .52121 .34474 L .5253 .34454 L F
.51908 .34489 m .52052 .34489 L .52041 .34488 L F
.52452 .34461 m .51861 .34538 L .51954 .34477 L F
.51611 .34507 m .51955 .34503 L p .51536 .3449 L F P
0 g
s
.51536 .3449 m .51955 .34503 L .51908 .34489 L .672 .728 .891 r
F
.51861 .34538 m .50744 .34598 L p .51954 .34477 L F P
0 g
s
.51721 .34524 m .51816 .34533 L .52512 .34498 L .672 .728 .891 r
F
.52687 .34485 m .52665 .3448 L .52793 .34548 L F
.52687 .34485 m .52793 .34548 L .52803 .3455 L F
.52687 .34485 m .52917 .34614 L .5293 .34616 L F
.52717 .34505 m .52662 .34479 L .52701 .34487 L F
.52697 .34487 m .52742 .34491 L .52745 .34487 L F
.52712 .3449 m .52742 .34491 L .52697 .34487 L F
.52767 .34484 m .52696 .34493 L .52688 .34488 L F
.5272 .34484 m .52668 .34481 L .52668 .34481 L F
.5272 .34484 m .52721 .34484 L .52668 .34481 L F
.5272 .34484 m .52668 .34481 L .52668 .34481 L F
.52728 .34519 m .52732 .34512 L .52857 .34549 L F
.53348 .34788 m .53004 .34628 L .53405 .34873 L F
.53004 .34628 m .52699 .34487 L .52937 .34617 L F
.53004 .34628 m .52937 .34617 L .53405 .34873 L F
.52423 .34492 m .52322 .34513 L .52401 .34481 L F
.51721 .34524 m .52512 .34498 L .52467 .34489 L F
.52543 .34475 m .52543 .34475 L .52484 .34473 L F
.52484 .34473 m .52484 .34473 L .52463 .34472 L F
.52484 .34473 m .52463 .34472 L .52463 .34472 L F
.52484 .34473 m .52463 .34472 L .52484 .34473 L F
.52422 .34486 m .52444 .34487 L .52441 .34486 L F
.52465 .34474 m .52596 .34479 L .52463 .34472 L F
.52282 .34466 m .52555 .34486 L .52542 .34477 L F
.52514 .34459 m .52282 .34466 L .52533 .34471 L F
.526 .34456 m .52423 .34492 L .52452 .34461 L F
.52463 .34472 m .52463 .34472 L .52392 .34468 L F
.52465 .34474 m .52463 .34472 L .52392 .34468 L F
.52423 .34492 m .52401 .34481 L .52452 .34461 L F
.52539 .34475 m .52463 .34472 L .52539 .34475 L F
.52597 .34478 m .52484 .34473 L .52484 .34473 L F
.52512 .34464 m .52089 .34496 L .52535 .34477 L F
.51816 .34533 m .52527 .345 L .52521 .34499 L F
.51816 .34533 m .52464 .34503 L .52465 .34503 L F
.51816 .34533 m .52476 .34503 L .52476 .34503 L F
.51861 .34538 m .52477 .34505 L p .51816 .34533 L F P
0 g
s
.51816 .34533 m .52477 .34505 L .52476 .34503 L .672 .728 .891 r
F
.52273 .3451 m .52568 .34497 L .52564 .34495 L F
.51816 .34533 m .52268 .34511 L .52273 .3451 L F
.52268 .34511 m .52568 .34497 L .52273 .3451 L F
.52923 .34201 m .52928 .34195 L .52923 .34201 L F
.52655 .34463 m .52644 .34464 L .52703 .34403 L F
.53384 .34431 m .52753 .34451 L .53205 .34482 L F
.52756 .34457 m .52728 .34459 L .52735 .34456 L F
.52753 .34451 m .526 .34456 L .52762 .34463 L F
.52753 .34451 m .52762 .34463 L .53205 .34482 L F
.52701 .34375 m .52667 .34457 L .52658 .34411 L F
.52733 .34349 m .52709 .34388 L .52701 .34375 L F
.52709 .34388 m .52667 .34457 L .52701 .34375 L F
.53122 .34067 m .53796 .33478 L p .53138 .34014 L F P
0 g
s
.52911 .34213 m .52911 .34213 L .52928 .34196 L .672 .728 .891 r
F
.52626 .34432 m .53122 .34067 L .53138 .34014 L F
.53541 .33687 m .52845 .34301 L .52733 .34349 L F
.52665 .34463 m .52665 .34462 L .52703 .34423 L F
.52665 .34462 m .52703 .34423 L .52665 .34462 L F
.52704 .34421 m .52665 .34461 L .52665 .34461 L F
.52664 .34461 m .52704 .34421 L .52665 .34461 L F
.52664 .34461 m .52664 .3446 L .5271 .34414 L F
.5271 .34415 m .52665 .34461 L .52665 .34461 L F
.52665 .34462 m .52664 .34462 L .5271 .34415 L F
.52669 .34463 m .52692 .34443 L p .52665 .34439 L F P
0 g
s
.52845 .34301 m .52667 .34457 L .52733 .34349 L .672 .728 .891 r
F
.5261 .34469 m .52583 .34472 L .52615 .3447 L F
.526 .34456 m .52582 .34473 L .52608 .34467 L F
.526 .34456 m .52516 .34546 L .52515 .34545 L F
.526 .34456 m .52515 .34545 L .5252 .34531 L F
.52467 .34489 m .52512 .34498 L .52564 .34495 L F
.52581 .34464 m .52551 .34457 L .5258 .34461 L F
.52479 .34422 m .52574 .34438 L .5258 .34461 L F
.52561 .34412 m .52571 .34499 L .52574 .3442 L F
.52583 .34472 m .52555 .34459 L p .52581 .34464 L F P
0 g
s
.52571 .34499 m .52576 .34502 L .52574 .34424 L .672 .728 .891 r
F
.52574 .34424 m .52574 .34424 L .52574 .3442 L F
.52571 .34499 m .52574 .34424 L .52574 .34424 L F
.52562 .34414 m .52585 .34488 L .52561 .34415 L F
.52582 .34473 m .5252 .34531 L .52584 .34485 L F
.52582 .34474 m .5268 .34515 L .5268 .34516 L F
.5268 .34517 m .52632 .34496 L p .5268 .34516 L F P
0 g
s
.52632 .34496 m .52632 .34496 L .5268 .34516 L .672 .728 .891 r
F
.52582 .34474 m .52761 .34549 L .52582 .34475 L F
.52632 .34496 m .52685 .34522 L p .52644 .34491 L F P
0 g
s
.52681 .3452 m .52583 .34472 L p .52677 .34503 L .672 .728 .891 r
F P
0 g
s
.52582 .34473 m .52584 .34485 L .52604 .3447 L .672 .728 .891 r
F
.52589 .34471 m .52604 .3447 L .52608 .34467 L F
.52632 .34496 m .52629 .34456 L p .52625 .34488 L F P
0 g
s
.52632 .34496 m .52631 .34497 L .52632 .34496 L .672 .728 .891 r
F
.52632 .34496 m .52636 .34559 L p .5261 .34469 L F P
0 g
s
.52636 .34559 m .52637 .3457 L p .52635 .34562 L .672 .728 .891 r
F P
0 g
s
.52599 .34529 m .52599 .34528 L .52665 .34462 L .672 .728 .891 r
F
.52636 .34559 m .52635 .34562 L .5261 .34469 L F
.52583 .34472 m .52583 .34472 L .52677 .34503 L F
.52629 .34493 m .52783 .34494 L .52629 .34492 L F
.52624 .34487 m .52675 .34489 L .52674 .34487 L F
.52675 .34489 m .52712 .3449 L .52674 .34487 L F
.52674 .34487 m .52712 .3449 L .52697 .34487 L F
.5268 .34515 m .5268 .34515 L .52721 .34533 L F
.52728 .34519 m .52676 .34501 L .52732 .34512 L F
.52676 .34501 m .52674 .34495 L .52732 .34512 L F
.5272 .34534 m .5268 .34517 L p .52721 .34534 L F P
0 g
s
.5268 .34517 m .5268 .34516 L .52721 .34534 L .672 .728 .891 r
F
.52089 .34496 m .52106 .34506 L .52468 .34489 L F
.52441 .34486 m .52479 .34487 L .52478 .34486 L F
.52538 .34481 m .52322 .34513 L .52527 .34474 L F
.52089 .34496 m .52468 .34489 L .52471 .34487 L F
.52583 .34472 m .52602 .3447 L .52615 .34475 L F
.52571 .34499 m .52558 .34492 L .52628 .34456 L F
.52339 .34489 m .52573 .34484 L .52576 .34483 L F
.52167 .34494 m .52338 .3449 L .52339 .34489 L F
.52338 .3449 m .52573 .34484 L .52339 .34489 L F
.52166 .34494 m .52573 .34484 L .52167 .34494 L F
.52514 .34459 m .52533 .34471 L .52613 .34472 L F
.52562 .34423 m .52584 .34489 L .52571 .34499 L F
.52564 .3442 m .52561 .34422 L .52559 .34418 L F
.52561 .34432 m .52376 .34346 L .52566 .3442 L F
.52557 .34412 m .51312 .33845 L .52541 .34414 L F
.51312 .33845 m .5109 .33744 L .51317 .33849 L F
.51312 .33845 m .51317 .33849 L .52541 .34414 L F
.52664 .3462 m .52788 .3509 L p .5264 .34607 L F P
0 g
s
.52629 .34541 m .52637 .3457 L .52622 .34546 L .672 .728 .891 r
F
.52629 .34541 m .52622 .34546 L .52596 .34502 L F
.52636 .34559 m .52632 .34496 L p .52616 .34555 L F P
0 g
s
.52637 .3457 m .52631 .34569 L .52633 .34566 L .672 .728 .891 r
F
.52631 .34569 m .52594 .34559 L .52633 .34566 L F
.52637 .3457 m .52636 .34559 L p .52603 .34659 L F P
0 g
s
.52639 .34538 m .52702 .34917 L p .52607 .3452 L .672 .728 .891 r
F P
0 g
s
.52557 .34412 m .52558 .34422 L .52568 .34419 L .672 .728 .891 r
F
.52376 .34346 m .52391 .3434 L .52566 .3442 L F
.52564 .34371 m .52572 .34389 L .52568 .34328 L F
.52561 .34412 m .52572 .34389 L .52564 .34371 L F
.52564 .34189 m .52569 .34418 L .52634 .34289 L F
.52569 .34396 m .52574 .3441 L .52572 .34389 L F
.52561 .34412 m .52574 .3441 L .52569 .34396 L F
.52569 .34398 m .52571 .3441 L .52569 .3441 L F
.52571 .3441 m .52572 .34422 L .52569 .3441 L F
.52569 .3441 m .52572 .34422 L .52569 .34422 L F
.5256 .34407 m .52459 .34371 L .52451 .3435 L F
.52564 .34411 m .52574 .3442 L .52574 .3441 L F
.52568 .34416 m .52574 .3442 L .52564 .34411 L F
.52912 .34482 m .52736 .34494 L .5274 .34483 L F
.52664 .34485 m .52886 .34488 L .52871 .34484 L F
.52721 .34487 m .52706 .34488 L .52723 .34483 L F
.52706 .34488 m .52688 .34488 L .527 .34486 L F
.52706 .34488 m .527 .34486 L .52723 .34483 L F
.52571 .3442 m .52632 .34303 L .52634 .34289 L F
.52615 .3426 m .52629 .34455 L p .52567 .343 L F P
0 g
s
.52629 .34455 m .52629 .34456 L p .52628 .34454 L .672 .728 .891 r
F P
0 g
s
.52629 .34456 m .52627 .34429 L p .5262 .3445 L .672 .728 .891 r
F P
0 g
s
.52669 .34466 m .52574 .34424 L .52569 .34417 L .672 .728 .891 r
F
.52753 .34451 m .52674 .3448 L .5263 .34455 L F
.52613 .34472 m .52746 .34485 L .52751 .34475 L F
.5272 .3449 m .5267 .34467 L .52669 .34466 L F
.5264 .34442 m .52604 .3447 L .52669 .34463 L F
.5267 .34467 m .52574 .34424 L .52669 .34466 L F
.52668 .34462 m .52726 .34411 L .52726 .34411 L F
.52583 .34472 m .52615 .34475 L .52623 .34484 L F
.52603 .34485 m .52596 .345 L .52624 .34486 L F
.5265 .3449 m .52716 .34491 L .5265 .3449 L F
.52665 .3448 m .52685 .34522 L .52674 .34485 L F
.52602 .3447 m .52673 .34484 L .52676 .34499 L F
.52604 .34468 m .52603 .3446 L .52608 .34466 L F
.5259 .34465 m .5261 .34469 L .52602 .3447 L F
.52582 .34473 m .52604 .3447 L .52589 .34471 L F
.52558 .34492 m .52595 .34466 L .52604 .34468 L F
.52595 .34466 m .52603 .3446 L .52604 .34468 L F
.5258 .34461 m .52611 .34469 L .5261 .34469 L F
.52595 .34466 m .52595 .34462 L .52603 .3446 L F
.52583 .34472 m .52581 .34464 L .52602 .3447 L F
.52581 .34464 m .5259 .34465 L .52602 .3447 L F
.52558 .34492 m .52591 .34465 L .52595 .34466 L F
.52591 .34465 m .52595 .34462 L .52595 .34466 L F
.52581 .34464 m .5258 .34461 L .5259 .34465 L F
.5258 .34461 m .5261 .34469 L .5259 .34465 L F
.52614 .34525 m .52629 .34456 L .5262 .3445 L F
.5261 .34469 m .52673 .34484 L .52602 .3447 L F
.52616 .3447 m .52673 .34484 L .5261 .34469 L F
.52611 .34469 m .52636 .34467 L .52673 .34484 L F
.52695 .34493 m .52611 .34469 L .52677 .34482 L F
.52616 .34477 m .52624 .34486 L .52668 .34464 L F
.52584 .34485 m .52596 .345 L .52603 .34485 L F
.52584 .34485 m .52624 .34486 L .52616 .34477 L F
.52627 .3449 m .52573 .34498 L .52611 .3447 L F
.52623 .34484 m .52615 .34475 L .52715 .34514 L F
.52627 .3449 m .52611 .3447 L .52611 .34469 L F
.52611 .34469 m .52616 .3447 L .5261 .34469 L F
.52616 .34477 m .52668 .34464 L .52667 .34464 L F
.52665 .34484 m .52627 .3449 L .52611 .34469 L F
.5261 .34469 m .52636 .34467 L .52611 .34469 L F
.52604 .3447 m .52584 .34485 L .52616 .34477 L F
.52611 .3447 m .5261 .34469 L .52611 .34469 L F
.5261 .34469 m .52616 .34477 L .52667 .34464 L F
.52604 .3447 m .52616 .34477 L .5261 .34469 L F
.52541 .34414 m .52604 .34462 L .52585 .34438 L F
.52592 .34446 m .52561 .34432 L .52589 .34443 L F
.52581 .34464 m .52572 .34462 L .526 .34456 L F
.52572 .34499 m .5261 .34469 L .5261 .34469 L F
.5258 .34461 m .52574 .34438 L .52592 .34446 L F
.5258 .34461 m .52592 .34446 L .5261 .34469 L F
.52579 .3443 m .52587 .34508 L .5261 .34469 L F
.5253 .34533 m .52577 .34543 L .52591 .34511 L F
.52587 .34508 m .52588 .34518 L .52591 .34511 L F
.52587 .34508 m .52591 .34511 L .5261 .34469 L F
.52527 .345 m .5257 .34498 L .52521 .34499 L F
.52617 .34526 m .52629 .34456 L .52614 .34525 L F
.52616 .34555 m .52629 .34456 L .52612 .34554 L F
.52623 .345 m .52632 .34496 L .52625 .34488 L F
.52577 .34465 m .52572 .34462 L .52581 .34464 L F
.52577 .34543 m .52582 .3453 L .52574 .3442 L F
.52596 .345 m .52632 .34496 L .52624 .34486 L F
.5253 .34533 m .52591 .34511 L .52596 .345 L F
.52591 .34511 m .52632 .34496 L .52596 .345 L F
.52583 .34548 m .52591 .34549 L .52588 .34518 L F
.52572 .34499 m .52571 .34499 L p .5261 .34469 L F P
0 g
s
.52583 .34529 m .52588 .34518 L .52585 .34489 L .672 .728 .891 r
F
.52581 .34492 m .52585 .34489 L .52578 .34423 L F
.52583 .34529 m .52585 .34489 L .52581 .34492 L F
.52583 .34548 m .52588 .34518 L .52583 .34529 L F
.52635 .34495 m .52573 .34498 L .52665 .34484 L F
.52695 .34493 m .52694 .34493 L p .52694 .34492 L F P
0 g
s
.52694 .34493 m .52573 .34498 L p .52694 .34492 L .672 .728 .891 r
F P
0 g
s
.52667 .34464 m .52668 .34464 L .52669 .34463 L .672 .728 .891 r
F
.52608 .34403 m .52594 .34408 L .52567 .343 L F
.52629 .34455 m .52628 .34454 L .52567 .343 L F
.52568 .34328 m .52578 .34423 L .52625 .34396 L F
.52586 .3442 m .52569 .34417 L .52579 .34417 L F
.52632 .34443 m .52627 .34445 L .52638 .34431 L F
.52622 .34467 m .52638 .34431 L .52641 .34432 L F
.52627 .34433 m .52619 .3445 L .5264 .34442 L F
.52767 .34472 m .5309 .34506 L .53011 .34484 L F
.52766 .3447 m .5277 .34475 L .52838 .34476 L F
.52789 .34464 m .52838 .34476 L .53205 .34482 L F
.54526 .34476 m .54521 .34394 L p .53384 .34431 L F P
0 g
s
.53384 .34431 m .53205 .34482 L .54526 .34476 L .672 .728 .891 r
F
.54521 .34394 m .52884 .34471 L .52896 .34447 L F
.52884 .34471 m .52674 .3448 L .52896 .34447 L F
.52669 .34464 m .52569 .34417 L .52586 .3442 L F
.5272 .3449 m .52669 .34466 L .52669 .34464 L F
.52669 .34466 m .52569 .34417 L .52669 .34464 L F
.52668 .34462 m .52723 .34408 L .52726 .34411 L F
.52624 .34486 m .52631 .34495 L .52664 .34466 L F
.5259 .34484 m .52578 .34494 L .52628 .34492 L F
.52667 .34464 m .52668 .34462 L .52668 .34462 L F
.52574 .34546 m .52667 .34464 L .52667 .34464 L F
.52672 .34482 m .5272 .34484 L .52669 .34481 L F
.52723 .34483 m .52688 .34488 L .52674 .3448 L F
.52719 .3449 m .5267 .34467 L .5272 .3449 L F
.5267 .34467 m .52574 .34424 L .5267 .34467 L F
.5267 .34467 m .5267 .34467 L .5272 .3449 L F
.52591 .34511 m .5258 .34539 L .52623 .34499 L F
.5258 .34539 m .52578 .34543 L .52623 .34499 L F
.52578 .34543 m .52632 .34496 L p .52623 .34499 L F P
0 g
s
.52597 .34478 m .526 .3449 L .52585 .34488 L .672 .728 .891 r
F
.52573 .34498 m .52693 .34493 L .52574 .34497 L F
.52724 .34492 m .52719 .3449 L .5272 .3449 L F
.52751 .34475 m .52746 .34485 L .53205 .34482 L F
.52941 .3448 m .52878 .34483 L p .52886 .34471 L F P
0 g
s
.52878 .34483 m .52696 .34493 L p .52884 .34471 L .672 .728 .891 r
F P
0 g
s
.52878 .34483 m .52884 .34471 L .52886 .34471 L .672 .728 .891 r
F
.52749 .34546 m .5278 .34558 L .52779 .34558 L F
.52632 .34496 m .52749 .34546 L .52749 .34546 L F
.52749 .34546 m .5278 .34558 L .52749 .34546 L F
.52721 .34533 m .52761 .34549 L .52756 .34548 L F
.52721 .34533 m .52761 .34549 L .52721 .34533 L F
.52721 .34533 m .52721 .34533 L .52761 .34549 L F
.52685 .34522 m .53013 .34682 L p .52674 .34485 L F P
0 g
s
.53013 .34682 m .53405 .34873 L p .53058 .34689 L .672 .728 .891 r
F P
0 g
s
.52674 .34485 m .53013 .34682 L .53058 .34689 L .672 .728 .891 r
F
.52693 .34493 m .52719 .34491 L .52693 .34492 L F
.52767 .34528 m .52719 .34506 L .52721 .34501 L F
.52767 .34528 m .52721 .34501 L .52724 .34492 L F
.53016 .34645 m .52767 .34528 L .52724 .34492 L F
.5272 .3449 m .52716 .34498 L .52773 .34532 L F
.52629 .34492 m .52783 .34494 L .52782 .34493 L F
.52717 .34505 m .52697 .34482 L .52724 .34492 L F
.52719 .34491 m .52725 .34491 L .52719 .34491 L F
.52719 .34491 m .52719 .34491 L .52693 .34492 L F
.52719 .34506 m .52717 .34505 L .52724 .34492 L F
.52676 .34499 m .52673 .34484 L .52858 .34571 L F
.52696 .34493 m .52725 .34491 L p .52696 .34492 L F P
0 g
s
.52696 .34487 m .52777 .34545 L .52773 .34532 L .672 .728 .891 r
F
.52672 .34481 m .52671 .34475 L .52701 .34487 L F
.52551 .34457 m .52553 .34451 L .5258 .34461 L F
.52479 .34422 m .52466 .34387 L .52574 .34438 L F
.5245 .34395 m .52564 .34459 L p .52456 .34373 L F P
0 g
s
.52582 .3453 m .52578 .34423 L .52574 .3442 L .672 .728 .891 r
F
.52583 .34548 m .52583 .3453 L .52582 .3453 L F
.52583 .3453 m .52578 .34423 L .52582 .3453 L F
.52564 .34424 m .52564 .34424 L .52561 .34415 L F
.52585 .34488 m .52564 .34424 L .52564 .34424 L F
.52585 .34488 m .52584 .34488 L .52564 .34424 L F
.52577 .34465 m .52322 .34513 L .52572 .34462 L F
.52512 .34464 m .52584 .34469 L .52573 .34462 L F
.5258 .34539 m .52668 .34459 L .52579 .34541 L F
.52579 .34541 m .5263 .34494 L .52631 .34495 L F
.52574 .34553 m .52575 .34552 L .52592 .34535 L F
.52581 .34537 m .52589 .3457 L .52573 .34557 L F
.52575 .34652 m .52599 .34562 L .52594 .34561 L F
.52589 .3457 m .526 .34612 L .52573 .34581 L F
.52577 .34543 m .52591 .34665 L .52582 .3453 L F
.52591 .34665 m .52593 .34684 L .52592 .34665 L F
.52591 .34665 m .52592 .34665 L .52582 .3453 L F
.51386 .35452 m .51298 .35397 L p .5239 .3461 L F P
0 g
s
.52574 .34546 m .52629 .34497 L .52629 .34497 L .672 .728 .891 r
F
.52631 .34495 m .52631 .34495 L .52574 .34546 L F
.52886 .34471 m .52767 .34484 L .52674 .3448 L F
.52578 .34423 m .52579 .3443 L .5262 .3445 L F
.52561 .34432 m .52566 .3442 L .52724 .34492 L F
.5272 .3449 m .52669 .34464 L .52696 .34487 L F
.52669 .34464 m .52569 .34412 L .52659 .34464 L F
.52701 .34487 m .52671 .34475 L .52697 .34482 L F
.52671 .34475 m .52671 .34473 L .52697 .34482 L F
.52669 .34464 m .52659 .34464 L .52696 .34487 L F
.52626 .34432 m .52669 .34463 L .52665 .34439 L F
.52662 .34464 m .52667 .34457 L .52668 .34459 L F
.52597 .34478 m .52585 .34488 L .52562 .34414 L F
.52584 .34469 m .52606 .34471 L .52573 .34462 L F
.52609 .34469 m .52597 .34478 L .52589 .34442 L F
.52671 .34475 m .52561 .34432 L .52671 .34473 L F
.52581 .34432 m .52613 .34468 L .52581 .3443 L F
.52603 .3446 m .52613 .34468 L .52581 .34432 L F
.52666 .34464 m .52668 .34459 L .52668 .34462 L F
.52631 .34495 m .52663 .34464 L .52666 .34464 L F
.52663 .34464 m .52668 .34459 L .52666 .34464 L F
.52563 .3441 m .52578 .34429 L .52641 .34466 L F
.52579 .34417 m .52569 .34417 L .5256 .34407 L F
.52569 .34412 m .52563 .3441 L .52641 .34466 L F
.52625 .34455 m .52595 .34435 L .52612 .34439 L F
.52617 .3445 m .52609 .34468 L .52595 .34435 L F
.52579 .34417 m .52681 .34483 L .52696 .34487 L F
.52658 .34411 m .52659 .34464 L .52613 .34459 L F
.52625 .34455 m .52609 .34468 L .52617 .3445 L F
.52621 .34441 m .52613 .34459 L .52601 .34457 L F
.52569 .34412 m .52641 .34466 L .52651 .34465 L F
.52658 .34411 m .52613 .34459 L .52621 .34441 L F
.52623 .34441 m .52601 .34457 L .52622 .34443 L F
.52626 .34432 m .52619 .3445 L .52627 .34433 L F
.5262 .3445 m .52627 .34429 L .52622 .34428 L F
.52624 .34438 m .52621 .34441 L .52623 .34441 L F
.52621 .34441 m .52601 .34457 L .52623 .34441 L F
.52612 .34439 m .52595 .34435 L .52578 .34398 L F
.52609 .34468 m .52609 .34469 L .52607 .34466 L F
.52609 .34468 m .52607 .34466 L .52578 .34398 L F
.52574 .34424 m .52459 .34371 L .5256 .34407 L F
.52561 .34412 m .52568 .34416 L .52564 .34411 L F
.52563 .3441 m .52562 .34414 L .52561 .34412 L F
.52561 .34412 m .52562 .34414 L .52561 .34415 L F
.52563 .3441 m .52534 .34403 L .52578 .34429 L F
.52631 .34495 m .52632 .34496 L .52664 .34466 L F
.52629 .34497 m .52668 .34462 L .52668 .34462 L F
.52666 .3448 m .52727 .34486 L .52731 .34477 L F
.5263 .34494 m .52668 .34459 L .52631 .34495 L F
.5259 .34484 m .52693 .34486 L .52666 .3448 L F
.52693 .34486 m .52727 .34486 L .52666 .3448 L F
.52629 .34497 m .52668 .34462 L .52668 .34462 L F
.52572 .34545 m .52568 .34544 L .52667 .34457 L F
.52651 .34465 m .52641 .34466 L .52666 .3448 L F
.52678 .34483 m .52666 .3448 L .52736 .34521 L F
.52662 .34479 m .52671 .34475 L .52672 .34481 L F
.52651 .34465 m .52666 .3448 L .52678 .34483 L F
.52685 .34522 m .52726 .34519 L .52858 .34571 L F
.5274 .34521 m .52736 .34521 L .52777 .34545 L F
.52694 .34439 m .52694 .34439 L .52667 .34464 L F
.52667 .34464 m .52667 .34464 L .52574 .34546 L F
.52694 .34439 m .52667 .34464 L .52667 .34464 L F
.52693 .34493 m .52696 .34493 L .52696 .34492 L F
.52652 .34465 m .52736 .34521 L .5274 .34521 L F
.52569 .34412 m .52651 .34465 L .52652 .34465 L F
.52693 .34493 m .52696 .34493 L .52693 .34493 L F
.52651 .34465 m .52736 .34521 L .52652 .34465 L F
.52516 .34546 m .51578 .35551 L .5251 .3454 L F
.5251 .3454 m .52504 .34546 L .52513 .34539 L F
.52577 .34543 m .52578 .34543 L .52591 .34511 L F
.5253 .34551 m .51681 .35594 L .52529 .34547 L F
.52491 .34613 m .52507 .34568 L .52534 .34537 L F
.52491 .34613 m .52534 .34537 L .52538 .34533 L F
.52486 .34625 m .52491 .34613 L .52538 .34533 L F
.52443 .34662 m .52578 .34543 L p .52504 .34546 L F P
0 g
s
.52504 .34546 m .52578 .34543 L .5253 .34533 L .672 .728 .891 r
F
.5252 .34551 m .51578 .35551 L .52518 .34549 L F
.52228 .34942 m .5223 .34933 L .5257 .34522 L F
.51578 .35551 m .52477 .34652 L p .52452 .34644 L F P
0 g
s
.52486 .34625 m .52176 .34942 L .52507 .34568 L .672 .728 .891 r
F
.52176 .34942 m .52186 .34906 L .52538 .34533 L F
.5148 .35504 m .52443 .34662 L p .52504 .34546 L F P
0 g
s
.52319 .34832 m .5232 .34828 L .5257 .34522 L .672 .728 .891 r
F
.52568 .34557 m .51578 .35551 L .52555 .34554 L F
.52583 .34532 m .5148 .35504 L .52498 .34542 L F
.51386 .35452 m .52504 .34595 L p .52498 .34542 L F P
0 g
s
.525 .34531 m .52459 .34629 L .5239 .3461 L .672 .728 .891 r
F
.52607 .34466 m .52589 .34442 L .52578 .34398 L F
.52609 .34469 m .52589 .34442 L .52607 .34466 L F
.52606 .34471 m .52609 .34469 L .52573 .34462 L F
.52573 .34462 m .52634 .34473 L .52579 .34462 L F
.5257 .34498 m .52573 .34498 L .52568 .34497 L F
.52573 .34498 m .52574 .34497 L .52568 .34497 L F
.5257 .34498 m .52568 .34497 L .52521 .34499 L F
.52572 .34499 m .5261 .34469 L .52611 .3447 L F
.52545 .34484 m .52592 .34482 L .52535 .34477 L F
.52592 .34482 m .52666 .3448 L .52596 .34479 L F
.52592 .34482 m .52596 .34479 L .52535 .34477 L F
.52603 .34548 m .52603 .34548 L .52584 .34489 L F
.52584 .34488 m .52584 .34489 L .52561 .34415 L F
.5259 .34484 m .52628 .34492 L .52622 .34484 L F
.52602 .34485 m .526 .3449 L .52597 .34478 L F
.52583 .34472 m .52677 .34503 L .52677 .34503 L F
.52694 .34492 m .52635 .34495 L .52665 .34484 L F
.52659 .34464 m .52628 .34492 L .52609 .34468 L F
.52613 .34468 m .52614 .34469 L .52641 .34466 L F
.52564 .34495 m .52699 .34491 L .52702 .34488 L F
.52564 .34495 m .52702 .34488 L .52702 .34488 L F
.52693 .34493 m .52693 .34492 L .52574 .34497 L F
.52668 .34459 m .52668 .34459 L .52574 .34546 L F
.52629 .34497 m .52668 .34462 L .52629 .34497 L F
.52629 .34497 m .52628 .34497 L .52668 .34462 L F
.52622 .34484 m .52628 .34492 L .52702 .34488 L F
.52693 .34486 m .52702 .34488 L .52727 .34486 L F
.52622 .34484 m .52702 .34488 L .52693 .34486 L F
.52606 .34471 m .52634 .34473 L .52609 .34469 L F
.52602 .34469 m .5268 .34523 L .52614 .34469 L F
.5261 .34469 m .52628 .34456 L .52611 .34469 L F
.52609 .34468 m .52614 .34469 L .52613 .34468 L F
.52631 .34496 m .52572 .34499 L .52573 .34498 L F
.52572 .34499 m .52632 .34496 L .52572 .34498 L F
.52632 .34496 m .52572 .34499 L p .52631 .34496 L F P
0 g
s
.52571 .34499 m .52632 .34496 L p .52572 .34499 L .672 .728 .891 r
F P
0 g
s
.52568 .34497 m .52699 .34491 L .52564 .34495 L .672 .728 .891 r
F
.526 .3449 m .52589 .34504 L .52593 .34489 L F
.526 .3449 m .52592 .34511 L .52589 .34504 L F
.52585 .34488 m .52592 .34511 L .52584 .34488 L F
.52579 .34541 m .5263 .34494 L .52579 .34541 L F
.52592 .34511 m .52603 .34548 L .52592 .34511 L F
.52592 .34511 m .52592 .34511 L .52584 .34488 L F
.52609 .34468 m .52583 .34532 L .52601 .34457 L F
.52602 .34469 m .52614 .34469 L .52609 .34468 L F
.52545 .34498 m .52725 .34491 L .52725 .34489 L F
.52521 .34499 m .52545 .34498 L .52545 .34498 L F
.52545 .34498 m .52725 .34491 L .52545 .34498 L F
.5257 .34498 m .52693 .34493 L .52693 .34493 L F
.52696 .34493 m .52632 .34496 L p .52631 .34496 L F P
0 g
s
.52583 .34472 m .52715 .34514 L .52715 .34515 L .672 .728 .891 r
F
.52632 .34496 m .52696 .34493 L p .52633 .34496 L F P
0 g
s
.52614 .34469 m .5268 .34523 L .52648 .34476 L .672 .728 .891 r
F
.52614 .34469 m .52648 .34476 L .52641 .34466 L F
.52535 .34477 m .52666 .3448 L .52634 .34473 L F
.52592 .34482 m .5259 .34484 L .52666 .3448 L F
.5257 .34499 m .52696 .34493 L .5257 .34498 L F
.52572 .34498 m .52632 .34496 L .52633 .34496 L F
.52628 .34492 m .52583 .34531 L .52609 .34468 L F
.52639 .34653 m .5265 .34701 L .52636 .34656 L F
.52704 .34815 m .52788 .3509 L .52635 .34799 L F
.52788 .3509 m .52961 .35748 L p .52668 .34951 L F P
0 g
s
.52961 .35748 m .52709 .34788 L p .52651 .34757 L .672 .728 .891 r
F P
0 g
s
.52548 .34486 m .52564 .34495 L .52578 .34494 L .672 .728 .891 r
F
.52548 .34486 m .52578 .34494 L .5259 .34484 L F
.52467 .34489 m .52564 .34495 L .52548 .34486 L F
.52568 .34468 m .52542 .34477 L .52634 .34473 L F
.52464 .34503 m .5257 .34499 L .52465 .34503 L F
.52572 .3446 m .52569 .3446 L .52585 .3447 L F
.52569 .34461 m .52585 .3447 L p .52569 .3446 L F P
0 g
s
.52456 .34373 m .52564 .34459 L .52572 .3446 L .672 .728 .891 r
F
.52486 .34389 m .52585 .3447 L .52602 .34469 L F
.52459 .34371 m .5109 .33744 L .52451 .3435 L F
.52365 .34305 m .52487 .34396 L .52486 .34389 L F
.52487 .34396 m .52585 .3447 L .52486 .34389 L F
.52584 .34464 m .52572 .34462 L .52584 .34464 L F
.52585 .3447 m .52572 .34462 L .52584 .34464 L F
.52585 .3447 m .52569 .34461 L p .52572 .34462 L F P
0 g
s
.52582 .34463 m .52565 .34469 L .52569 .34461 L .672 .728 .891 r
F
.5266 .34464 m .52667 .34457 L .52662 .34464 L F
.52667 .34464 m .52668 .34462 L .52667 .34464 L F
.52613 .34459 m .52609 .34468 L .52601 .34457 L F
.52611 .34469 m .52628 .34456 L .5263 .34455 L F
.52659 .34464 m .52609 .34468 L .52613 .34459 L F
.52609 .34469 m .52597 .34478 L .52609 .34469 L F
.52632 .34496 m .52669 .34463 L p .52664 .34466 L F P
0 g
s
.52669 .34463 m .52528 .34587 L p .52667 .34464 L .672 .728 .891 r
F P
0 g
s
.52639 .34538 m .52602 .34485 L .52609 .34469 L .672 .728 .891 r
F
.52602 .34485 m .52597 .34478 L .52609 .34469 L F
.52579 .34542 m .52668 .34462 L .52668 .34462 L F
.52528 .34587 m .52579 .34542 L .52579 .34542 L F
.52579 .34542 m .52668 .34462 L .52579 .34542 L F
.52632 .34496 m .52622 .345 L .52609 .34469 L F
.52585 .3447 m .52632 .34496 L p .52602 .34469 L F P
0 g
s
.52632 .34496 m .5268 .34523 L p .52638 .34494 L .672 .728 .891 r
F P
0 g
s
.5261 .34469 m .52632 .34496 L .52609 .34469 L .672 .728 .891 r
F
.5262 .34482 m .52632 .34496 L .52638 .34494 L F
.52579 .34462 m .52646 .34466 L .52634 .3446 L F
.52646 .34466 m .52703 .3447 L .52634 .3446 L F
.52634 .3446 m .52703 .3447 L .52743 .34456 L F
.52668 .34462 m .52694 .34439 L .52668 .34462 L F
.52668 .34462 m .52668 .34462 L .52694 .34439 L F
.52609 .34468 m .52634 .34473 L .52606 .34464 L F
.52625 .34455 m .52632 .34496 L .5261 .34469 L F
.52606 .34464 m .52634 .34473 L .52703 .3447 L F
.52625 .34455 m .52632 .34496 L p .52625 .34455 L F P
0 g
s
.52602 .34469 m .52632 .34496 L .5262 .34482 L .672 .728 .891 r
F
.52625 .34499 m .52624 .34487 L .52615 .34502 L F
.52624 .34487 m .52623 .34454 L .52619 .3448 L F
.52632 .34496 m .52585 .3447 L .52638 .34494 L F
.52624 .34487 m .52619 .3448 L .52615 .34502 L F
.52624 .34486 m .52585 .3447 L .52594 .3447 L F
.52667 .34705 m .52632 .34496 L p .52635 .34799 L F P
0 g
s
.52632 .34496 m .52625 .34455 L p .52626 .34489 L .672 .728 .891 r
F P
0 g
s
.52632 .34496 m .52639 .34538 L p .52622 .345 L .672 .728 .891 r
F P
0 g
s
.51164 .33678 m .51244 .33616 L p .52474 .34348 L .672 .728 .891 r
F P
0 g
s
.52376 .34346 m .5109 .33744 L .52391 .3434 L .672 .728 .891 r
F
.5109 .33744 m .51164 .33678 L p .52451 .3435 L F P
0 g
s
.52214 .34263 m .5245 .34395 L p .52365 .34305 L .672 .728 .891 r
F P
0 g
s
.52365 .34305 m .5245 .34395 L .52456 .34373 L .672 .728 .891 r
F
.52365 .34305 m .52493 .34393 L .52534 .34403 L F
.51164 .33678 m .52214 .34263 L p .52365 .34305 L F P
0 g
s
.52479 .34422 m .5109 .33744 L p .52466 .34387 L .672 .728 .891 r
F P
0 g
s
.52489 .34417 m .51164 .33678 L p .52474 .34348 L .672 .728 .891 r
F P
0 g
s
.51244 .33616 m .52405 .34352 L p .52474 .34348 L .672 .728 .891 r
F P
0 g
s
.51244 .33616 m .5133 .33558 L p .52407 .34286 L .672 .728 .891 r
F P
0 g
s
.52639 .34538 m .52631 .34534 L .52631 .34528 L .672 .728 .891 r
F
.52616 .34555 m .52632 .34496 L .52623 .345 L F
.52631 .34534 m .52607 .3452 L .52631 .34528 L F
.52631 .34528 m .52607 .3452 L .526 .3449 L F
.52629 .34597 m .52632 .34496 L .52626 .34489 L F
.52638 .34494 m .52626 .34489 L .52624 .34486 L F
.52626 .34489 m .52585 .3447 L .52624 .34486 L F
.52609 .34468 m .52609 .34469 L .52609 .34469 L F
.52666 .3448 m .5268 .34523 L .52673 .34484 L F
.52648 .34476 m .5268 .34523 L .52666 .3448 L F
.52706 .34509 m .52584 .34464 L .52708 .34505 L F
.52668 .34459 m .52723 .34408 L .52668 .34462 L F
.52728 .34448 m .5266 .34473 L .52625 .34455 L F
.54521 .34394 m .54509 .34313 L p .52728 .34448 L F P
0 g
s
.52728 .34448 m .52601 .34457 L .52748 .34452 L .672 .728 .891 r
F
.52728 .34448 m .52748 .34452 L .54521 .34394 L F
.52601 .34457 m .52604 .34461 L .52761 .34455 L F
.52624 .34487 m .52625 .34455 L .52623 .34457 L F
.52626 .34489 m .52625 .34455 L .52624 .34487 L F
.52624 .34486 m .52594 .3447 L .52615 .34475 L F
.52625 .34455 m .52603 .3446 L .52601 .34457 L F
.52593 .34489 m .52589 .34504 L .52585 .34488 L F
.52592 .34511 m .52584 .34489 L .52584 .34488 L F
.52591 .34511 m .52584 .34489 L .52592 .34511 L F
.52573 .34484 m .5259 .34484 L .52576 .34483 L F
.52576 .34483 m .5259 .34484 L .52592 .34482 L F
.52571 .34499 m .52577 .34543 L .52576 .34502 L F
.5252 .34531 m .52522 .34531 L .52584 .34485 L F
.52602 .34469 m .52613 .34468 L .52582 .34443 L F
.52564 .34424 m .52584 .34489 L .52562 .34423 L F
.52583 .34451 m .52582 .34443 L .52534 .34403 L F
.52567 .343 m .52575 .3438 L .52569 .34398 L F
.52574 .3442 m .52578 .34423 L .52568 .34328 L F
.52569 .34412 m .52579 .34418 L .52579 .34417 L F
.52564 .34412 m .52597 .34478 L .52562 .34414 L F
.52578 .34429 m .52581 .34432 L .52581 .3443 L F
.52578 .34398 m .52589 .34442 L .52564 .34412 L F
.52589 .34442 m .52597 .34478 L .52564 .34412 L F
.52534 .34403 m .52582 .34443 L .52581 .34432 L F
.52561 .34415 m .52564 .34424 L .52562 .34423 L F
.52534 .34403 m .52581 .34432 L .52578 .34429 L F
.52602 .34469 m .52582 .34443 L .52583 .34451 L F
.52586 .34462 m .52609 .34468 L .52606 .34464 L F
.52579 .34462 m .52584 .34463 L .52586 .34462 L F
.52584 .34463 m .52609 .34468 L .52586 .34462 L F
.52601 .34457 m .52599 .34463 L .5259 .34468 L F
.52599 .34463 m .52583 .34532 L .5259 .34468 L F
.5251 .3454 m .52513 .34539 L .52608 .34467 L F
.52571 .34499 m .52593 .34546 L .52577 .34543 L F
.5252 .34551 m .52518 .34549 L .52592 .34471 L F
.5252 .34531 m .52515 .34545 L .5251 .3454 L F
.52513 .34539 m .52504 .34546 L .52529 .34533 L F
.52513 .34539 m .52529 .34533 L .52588 .34504 L F
.5259 .34468 m .52583 .34532 L .52513 .3454 L F
.52585 .3447 m .52606 .34463 L .52603 .34461 L F
.52519 .34524 m .52513 .3454 L .52498 .34542 L F
.52682 .34471 m .52695 .34479 L .54521 .34394 L F
.52631 .34495 m .52667 .34464 L .52631 .34495 L F
.52667 .34464 m .52694 .34439 L .52667 .34464 L F
.52667 .34464 m .52667 .34464 L .52631 .34495 L F
.52641 .34466 m .52648 .34476 L .52666 .3448 L F
.52634 .34473 m .52695 .34479 L .52682 .34471 L F
.52634 .34473 m .52666 .3448 L .52695 .34479 L F
.52624 .34486 m .52615 .34475 L .52706 .34509 L F
.5268 .34504 m .5268 .34504 L .52726 .34519 L F
.52677 .34503 m .5268 .34504 L .5268 .34504 L F
.52677 .34503 m .52677 .34503 L .5268 .34504 L F
.52715 .34515 m .52715 .34514 L .52726 .34519 L F
.52685 .34522 m .52681 .3452 L p .52726 .34519 L F P
0 g
s
.52681 .3452 m .52677 .34503 L .52726 .34519 L .672 .728 .891 r
F
.52721 .3454 m .52685 .34522 L p .52858 .34571 L F P
0 g
s
.52944 .34648 m .52721 .3454 L p .53016 .34645 L .672 .728 .891 r
F P
0 g
s
.52803 .3455 m .52793 .34548 L .52917 .34614 L .672 .728 .891 r
F
.52721 .3454 m .52858 .34571 L .53016 .34645 L F
.5293 .34616 m .52917 .34614 L .53405 .34873 L F
.53405 .34873 m .54162 .35243 L p .53348 .34788 L F P
0 g
s
.54162 .35243 m .52944 .34648 L p .53016 .34645 L .672 .728 .891 r
F P
0 g
s
.52089 .34496 m .52545 .34484 L .52535 .34477 L .672 .728 .891 r
F
.52303 .34528 m .50759 .34679 L p .52445 .34469 L F P
0 g
s
.51625 .34595 m .52357 .34523 L p .51527 .34587 L .672 .728 .891 r
F P
0 g
s
.51527 .34587 m .52357 .34523 L .52309 .34515 L .672 .728 .891 r
F
.51961 .34535 m .52018 .34542 L .52309 .34515 L F
.51961 .34535 m .52309 .34515 L .52267 .34508 L F
.52896 .34447 m .52674 .3448 L .52753 .34451 L F
.5276 .34455 m .52761 .34455 L .52766 .34455 L F
.52743 .34456 m .52703 .3447 L .54521 .34394 L F
.52824 .3446 m .52658 .34474 L .52744 .34446 L F
.52836 .3461 m .54087 .35307 L p .52915 .34625 L F P
0 g
s
.5272 .3449 m .52696 .34487 L .52719 .34491 L .672 .728 .891 r
F
.52702 .34488 m .52702 .34488 L .52703 .34488 L F
.52681 .34483 m .52777 .34545 L .52696 .34487 L F
.52719 .34491 m .52696 .34487 L .52716 .34498 L F
.52769 .34516 m .52773 .34532 L .52882 .34596 L F
.52842 .34566 m .52663 .34479 L .52709 .34487 L F
.52773 .34532 m .52777 .34545 L .54087 .35307 L F
.54087 .35307 m .5284 .34582 L .52842 .34566 L F
.5284 .34582 m .52663 .34479 L .52842 .34566 L F
.52673 .34484 m .52836 .3461 L .52915 .34625 L F
.54087 .35307 m .52779 .34573 L .52729 .34517 L F
.52585 .3447 m .52597 .34469 L .52606 .34463 L F
.52708 .34505 m .526 .34469 L .52663 .34479 L F
.526 .34469 m .52584 .34464 L .5261 .34469 L F
.526 .34469 m .5261 .34469 L .52663 .34479 L F
.52715 .34473 m .52628 .34491 L .52658 .34474 L F
.5252 .34593 m .5266 .34464 L .52662 .34464 L F
.52594 .34528 m .52628 .34497 L .52629 .34497 L F
.52639 .34538 m .526 .3449 L .52602 .34485 L F
.52597 .34516 m .52623 .34454 L .52595 .34501 L F
.52574 .34546 m .52668 .34462 L .52574 .34546 L F
.52594 .34528 m .52594 .34528 L .52628 .34497 L F
.52603 .34659 m .52636 .34559 L .52616 .34555 L F
.526 .3449 m .52639 .34653 L .52592 .34511 L F
.52604 .34567 m .52611 .34524 L .52597 .34516 L F
.52611 .34524 m .52623 .34454 L .52597 .34516 L F
.52668 .34459 m .52723 .34408 L .52668 .34459 L F
.52668 .34462 m .52726 .34411 L .52668 .34462 L F
.52668 .34462 m .52694 .34439 L .52694 .34439 L F
.52668 .34462 m .52726 .34411 L .52668 .34462 L F
.52727 .34413 m .52669 .34463 L p .52726 .34411 L F P
0 g
s
.52669 .34463 m .52667 .34464 L .52726 .34411 L .672 .728 .891 r
F
.52672 .34465 m .52747 .34408 L p .52636 .34467 L F P
0 g
s
.5266 .34473 m .52651 .34476 L .52625 .34455 L .672 .728 .891 r
F
.52651 .34476 m .52623 .34485 L .5261 .34469 L F
.52588 .34493 m .52621 .34482 L .52617 .34478 L F
.52588 .34493 m .52636 .34467 L .52586 .34478 L F
.52594 .3447 m .52599 .34469 L .52615 .34475 L F
.52613 .34472 m .52606 .34469 L .52586 .34478 L F
.5261 .34469 m .52625 .34455 L .5261 .34469 L F
.52625 .34455 m .52609 .34469 L .52609 .34468 L F
.52601 .34457 m .52585 .3447 L .52603 .34461 L F
.5261 .34469 m .52586 .34464 L .52603 .3446 L F
.5261 .34469 m .52603 .3446 L .52625 .34455 L F
.52586 .34478 m .52609 .34468 L .52606 .34463 L F
.5261 .34469 m .52603 .3446 L .5261 .34469 L F
.52623 .34454 m .52618 .34451 L .5261 .34469 L F
.52625 .34455 m .52625 .34455 L p .52625 .34455 L F P
0 g
s
.52625 .34455 m .52625 .34455 L .52625 .34455 L .672 .728 .891 r
F
.52667 .34457 m .52659 .34464 L .52658 .34411 L F
.52579 .34418 m .52681 .34483 L .52579 .34417 L F
.52611 .34372 m .52625 .34455 L p .52578 .34398 L F P
0 g
s
.52625 .34455 m .52623 .34441 L p .52623 .34457 L .672 .728 .891 r
F P
0 g
s
.52606 .34463 m .52747 .34408 L .52625 .34449 L .672 .728 .891 r
F
.5261 .34469 m .52625 .34455 L .52625 .34455 L F
.52609 .34468 m .52747 .34408 L .52606 .34463 L F
.52612 .34472 m .5261 .34469 L .52595 .34501 L F
.52623 .34454 m .5261 .34469 L .52612 .34472 L F
.52631 .3446 m .52624 .34456 L .52625 .34455 L F
.52603 .34461 m .52606 .34463 L .52625 .34449 L F
.52601 .34457 m .52603 .34461 L .52625 .34449 L F
.52663 .34479 m .5261 .34469 L .52579 .3443 L F
.5252 .34531 m .5251 .3454 L .52522 .34531 L F
.52601 .34457 m .52513 .3454 L .52519 .34524 L F
.52569 .3446 m .52579 .34462 L .52604 .34461 L F
.52603 .3446 m .52586 .34464 L .52601 .34457 L F
.52586 .34464 m .52565 .34469 L .52582 .34463 L F
.52586 .34464 m .52582 .34463 L .52601 .34457 L F
.52493 .34393 m .52602 .34469 L .52534 .34403 L F
.52601 .34457 m .52569 .3446 L .52604 .34461 L F
.52601 .34457 m .52582 .34463 L .52569 .3446 L F
.52582 .34443 m .52603 .3446 L .52581 .34432 L F
.5261 .34469 m .52584 .34464 L .52579 .3443 L F
.52636 .34467 m .5261 .34469 L .52613 .34472 L F
.5261 .34469 m .52606 .34469 L .52613 .34472 L F
.52571 .34502 m .5261 .34469 L .5261 .34469 L F
.52623 .34441 m .52614 .34386 L p .52598 .34479 L F P
0 g
s
.52595 .34501 m .5261 .34469 L .52598 .34479 L .672 .728 .891 r
F
.5261 .34469 m .52623 .34441 L .52598 .34479 L F
.52623 .34485 m .52571 .34502 L .5261 .34469 L F
.52617 .34478 m .52672 .34465 L .52636 .34467 L F
.52621 .34482 m .52672 .34465 L .52617 .34478 L F
.52672 .34465 m .52672 .34465 L .52672 .34465 L F
.5266 .34473 m .52625 .34455 L .52625 .34455 L F
.52636 .34467 m .52671 .34449 L .52606 .34469 L F
.52623 .34454 m .52623 .34441 L .52618 .34451 L F
.52663 .34479 m .52579 .3443 L .52673 .34472 L F
.52524 .34478 m .52303 .34528 L .52496 .34465 L F
.52726 .34411 m .52744 .34389 L .52745 .34394 L F
.52723 .34408 m .52744 .34389 L .52726 .34411 L F
.52745 .34394 m .52744 .34389 L .53541 .33687 L F
.52745 .34394 m .52745 .34394 L .53541 .33687 L F
.53527 .33713 m .52746 .34397 L p .53541 .33687 L F P
0 g
s
.52746 .34397 m .52745 .34394 L .53541 .33687 L .672 .728 .891 r
F
.52753 .34403 m .5389 .33531 L p .52681 .34409 L F P
0 g
s
.5389 .33531 m .52747 .34408 L p .52719 .34374 L .672 .728 .891 r
F P
0 g
s
.52701 .34375 m .52747 .34361 L .5389 .33531 L .672 .728 .891 r
F
.52892 .34321 m .53979 .33587 L p .52719 .34374 L F P
0 g
s
.5228 .34508 m .52309 .34515 L .52554 .34493 L .672 .728 .891 r
F
.52583 .34531 m .52583 .34532 L .52609 .34468 L F
.52591 .34513 m .52595 .34515 L .52586 .34439 L F
.52603 .34659 m .52616 .34555 L .52612 .34554 L F
.52593 .34546 m .52623 .34611 L .52577 .34543 L F
.52606 .34607 m .5261 .3461 L .52597 .34516 L F
.52595 .34515 m .52597 .34516 L .52586 .34439 L F
.52584 .34489 m .52591 .34511 L .52571 .34499 L F
.52591 .34511 m .52623 .34611 L .52585 .34528 L F
.52591 .34511 m .52585 .34528 L .52571 .34499 L F
.52574 .34546 m .52579 .34542 L .52574 .34546 L F
.52579 .34542 m .52631 .34495 L .52579 .34542 L F
.52576 .34548 m .52568 .34557 L .52581 .34538 L F
.52579 .34542 m .52579 .34542 L .52574 .34546 L F
.52606 .34607 m .52597 .34516 L .52595 .34515 L F
.52569 .3446 m .52512 .34464 L .52579 .34462 L F
.52582 .34463 m .52569 .34461 L .52569 .3446 L F
.52476 .34503 m .52572 .34499 L .52572 .34498 L F
.52476 .34503 m .52632 .34496 L .52476 .34503 L F
.52477 .34505 m .52571 .34499 L p .52476 .34503 L F P
0 g
s
.52476 .34503 m .52571 .34499 L .52572 .34499 L .672 .728 .891 r
F
.52571 .34502 m .52447 .34514 L p .52533 .34483 L F P
0 g
s
.52585 .3447 m .52498 .34542 L .52597 .34469 L .672 .728 .891 r
F
.52571 .34502 m .52533 .34483 L .52586 .34464 L F
.52571 .34502 m .52533 .34483 L .52571 .34502 L F
.52564 .34459 m .52569 .34461 L p .52569 .3446 L F P
0 g
s
.52584 .34464 m .52556 .34413 L .52577 .34416 L .672 .728 .891 r
F
.52569 .34461 m .52505 .34426 L p .52584 .34464 L F P
0 g
s
.52555 .34459 m .52551 .34457 L p .52581 .34464 L .672 .728 .891 r
F P
0 g
s
.52563 .34421 m .52579 .34535 L .52579 .3443 L .672 .728 .891 r
F
.52584 .34464 m .52505 .34426 L .52556 .34413 L F
.52553 .34416 m .52557 .34433 L .52563 .34421 L F
.52512 .34464 m .52542 .34477 L .52568 .34468 L F
.52565 .34469 m .52524 .34478 L .52569 .3446 L F
.52557 .34433 m .52579 .34535 L .52563 .34421 L F
.52594 .3447 m .52584 .34464 L .52599 .34469 L F
.52594 .3447 m .52585 .3447 L .52584 .34464 L F
.52585 .3447 m .52585 .3447 L .52594 .3447 L F
.52571 .34502 m .52586 .34464 L .5261 .34469 L F
.52498 .34542 m .52588 .34493 L .52586 .34478 L F
.52579 .34506 m .52591 .34509 L .52579 .3443 L F
.52498 .34542 m .52592 .34527 L .52588 .34493 L F
.52579 .34535 m .5259 .34512 L .52579 .34506 L F
.5259 .34512 m .52591 .34509 L .52579 .34506 L F
.52588 .34493 m .52632 .34496 L .52603 .34488 L F
.52603 .34488 m .52632 .34496 L .52621 .34482 L F
.52628 .34491 m .52572 .34502 L .52623 .34485 L F
.52592 .34559 m .526 .34612 L .52586 .34557 L F
.52586 .3458 m .52594 .34574 L .52591 .34549 L F
.52586 .3458 m .52591 .34549 L .52583 .34548 L F
.52593 .34684 m .52594 .34574 L .52586 .3458 L F
.52577 .34543 m .52623 .34611 L .52581 .34584 L F
.52593 .34684 m .52603 .34659 L .52598 .34612 L F
.52593 .34684 m .52598 .34612 L .52594 .34574 L F
.52581 .34584 m .5265 .34701 L .52593 .34684 L F
.52623 .34611 m .5265 .34701 L .52581 .34584 L F
.52579 .34535 m .52635 .34797 L .52591 .34509 L F
.52635 .34797 m .52635 .34799 L .52635 .34797 L F
.52635 .34797 m .52635 .34797 L .52591 .34509 L F
.51215 .35337 m .51138 .35274 L p .52315 .34619 L F P
0 g
s
.52582 .34529 m .52579 .34535 L .52592 .34527 L .672 .728 .891 r
F
.52577 .34538 m .52581 .34535 L p .52579 .34535 L F P
0 g
s
.52581 .34535 m .52592 .34527 L p .52579 .34535 L .672 .728 .891 r
F P
0 g
s
.52579 .34535 m .52623 .34608 L .52604 .34653 L .672 .728 .891 r
F
.52572 .34502 m .52584 .34528 L .52579 .34535 L F
.52572 .34502 m .52571 .34502 L .52572 .34502 L F
.52579 .3443 m .52591 .34513 L .52586 .34439 L F
.5252 .34593 m .5266 .34464 L .5252 .34593 L F
.52603 .34548 m .52591 .34511 L .52592 .34511 L F
.52592 .34527 m .52632 .34496 L p .52588 .34493 L F P
0 g
s
.52572 .34502 m .52572 .34502 L .52623 .34485 L .672 .728 .891 r
F
.5259 .34485 m .52572 .34502 L .52572 .34502 L F
.52564 .34498 m .52632 .34496 L .52554 .34493 L F
.52547 .34489 m .52554 .34493 L .52585 .3449 L F
.52505 .34426 m .52498 .34416 L .52575 .34408 L F
.52569 .34412 m .52365 .34305 L .52534 .34403 L F
.52548 .34392 m .52489 .34417 L .52474 .34348 L F
.52405 .34352 m .52574 .3446 L p .52474 .34348 L F P
0 g
s
.52588 .34487 m .52585 .3449 L .52675 .34481 L .672 .728 .891 r
F
.52623 .34485 m .52675 .34481 L .52674 .34481 L F
.52588 .34487 m .52623 .34485 L .52623 .34485 L F
.52672 .34465 m .52672 .34465 L .52636 .34467 L F
.52628 .34491 m .52623 .34485 L .52658 .34474 L F
.52632 .34496 m .52672 .34466 L p .52621 .34482 L F P
0 g
s
.52709 .34487 m .52673 .34472 L .52673 .34466 L .672 .728 .891 r
F
.52688 .34475 m .52672 .34465 L .5268 .34483 L F
.52671 .34449 m .5267 .34441 L .52606 .34469 L F
.52673 .34466 m .52579 .3443 L .52586 .34414 L F
.52672 .34466 m .52672 .34465 L p .52672 .34465 L F P
0 g
s
.52621 .34482 m .52672 .34466 L .52672 .34465 L .672 .728 .891 r
F
.52636 .34466 m .52625 .34487 L .52609 .34467 L F
.52603 .34472 m .52596 .3448 L .52662 .34474 L F
.52632 .34496 m .52625 .34487 L .52668 .34435 L F
.52617 .34447 m .52579 .3443 L .52619 .34445 L F
.52568 .3441 m .52613 .34467 L .52652 .34466 L F
.52595 .34501 m .52614 .34386 L .52606 .34377 L F
.52563 .34133 m .52564 .34189 L .52638 .34235 L F
.52564 .34189 m .52634 .34289 L .52638 .34235 L F
.52661 .33293 m .52635 .34366 L p .52658 .33284 L F P
0 g
s
.52552 .33662 m .52563 .34133 L .52649 .33807 L .672 .728 .891 r
F
.52638 .34235 m .52649 .33807 L p .52563 .34133 L F P
0 g
s
.52663 .33208 m .52661 .33293 L p .52658 .33284 L .672 .728 .891 r
F P
0 g
s
.52649 .33807 m .52663 .33208 L p .52552 .33662 L .672 .728 .891 r
F P
0 g
s
.52541 .33209 m .52615 .3426 L p .52567 .343 L .672 .728 .891 r
F P
0 g
s
.52625 .34396 m .52541 .33209 L p .52548 .34304 L .672 .728 .891 r
F P
0 g
s
.52611 .34372 m .52578 .34398 L .52541 .34241 L .672 .728 .891 r
F
.52581 .34401 m .52606 .34377 L .52573 .34339 L F
.52595 .34501 m .52606 .34377 L .52581 .34401 L F
.52611 .34465 m .526 .34476 L .52562 .34352 L F
.52546 .34282 m .52578 .34398 L .52561 .34412 L F
.52534 .34326 m .52548 .34392 L .52574 .3435 L F
.52564 .34353 m .52562 .34352 L .52557 .34338 L F
.52578 .34398 m .52562 .34414 L .52563 .3441 L F
.52548 .34392 m .52586 .34439 L .52574 .3435 L F
.52611 .34465 m .52562 .34352 L .52564 .34353 L F
.52577 .34416 m .52556 .34413 L .52575 .34408 L F
.52548 .34392 m .52553 .34416 L .52579 .3443 L F
.52562 .34409 m .52614 .34468 L .52568 .3441 L F
.52562 .34409 m .52573 .34434 L .52553 .34416 L F
.52573 .34434 m .52607 .34508 L .5256 .34428 L F
.5259 .34444 m .526 .34476 L .52562 .34409 L F
.52581 .34494 m .52632 .34496 L .52585 .3449 L F
.52557 .34433 m .5259 .34485 L .52572 .34502 L F
.52547 .34489 m .52589 .34486 L .52539 .34485 L F
.52589 .34486 m .52671 .34481 L .52592 .34483 L F
.52589 .34486 m .52592 .34483 L .52539 .34485 L F
.52696 .3449 m .52571 .34502 L p .52715 .34474 L F P
0 g
s
.52675 .34481 m .52673 .34472 L .52709 .34487 L .672 .728 .891 r
F
.52688 .34475 m .52681 .34483 L .52692 .3448 L F
.52671 .34481 m .52718 .34478 L .52666 .3448 L F
.52601 .34457 m .52766 .34455 L .5276 .34452 L F
.52668 .34459 m .52667 .34457 L .52744 .34389 L F
.52672 .34465 m .52672 .34466 L p .52668 .34435 L F P
0 g
s
.52672 .34466 m .52632 .34496 L p .5265 .34466 L .672 .728 .891 r
F P
0 g
s
.52673 .34472 m .52617 .34447 L .52673 .34466 L .672 .728 .891 r
F
.52672 .34465 m .52657 .34466 L .52672 .34466 L F
.52672 .34466 m .5265 .34466 L .52668 .34435 L F
.52672 .34465 m .52586 .34414 L .52657 .34466 L F
.52672 .34466 m .52657 .34466 L .52672 .34477 L F
.52621 .34444 m .52636 .34466 L .52601 .34458 L F
.52601 .34457 m .52625 .34449 L .52747 .34361 L F
.52665 .34412 m .52646 .34448 L .52621 .34444 L F
.52663 .34479 m .52673 .34472 L .52675 .34481 L F
.52617 .34447 m .52619 .34445 L .52673 .34466 L F
.52586 .34414 m .52579 .3443 L .52575 .34408 L F
.52586 .34414 m .52568 .3441 L .52675 .34482 L F
.52632 .34496 m .52708 .34489 L p .52624 .34486 L F P
0 g
s
.5268 .34483 m .52675 .34482 L .5271 .34505 L .672 .728 .891 r
F
.52668 .34435 m .52642 .34466 L .52665 .34412 L F
.52642 .34466 m .52625 .34487 L .52636 .34466 L F
.52624 .34438 m .52622 .34443 L .52747 .34361 L F
.52642 .34466 m .52636 .34466 L .52665 .34412 L F
.52657 .34466 m .52675 .34482 L .5268 .34483 L F
.52586 .34414 m .52655 .34466 L .52657 .34466 L F
.52655 .34466 m .52675 .34482 L .52657 .34466 L F
.526 .34476 m .52595 .3448 L .52562 .34409 L F
.52573 .34434 m .5256 .34428 L .52553 .34416 L F
.52694 .34439 m .52726 .34411 L .52694 .34439 L F
.52668 .34462 m .52726 .34411 L .52726 .34411 L F
.52694 .34439 m .52694 .34439 L .52726 .34411 L F
.52671 .34449 m .52747 .34408 L .5267 .34441 L F
.52747 .34408 m .52753 .34403 L p .52625 .34449 L F P
0 g
s
.52727 .34413 m .52726 .34411 L .52745 .34394 L .672 .728 .891 r
F
.52726 .34411 m .52745 .34394 L .52726 .34411 L F
.52726 .34411 m .52726 .34411 L .52745 .34394 L F
.52625 .34449 m .52753 .34403 L .52681 .34409 L F
.52747 .34408 m .52672 .34465 L p .52719 .34374 L F P
0 g
s
.52672 .34465 m .52668 .34435 L .52719 .34374 L .672 .728 .891 r
F
.52722 .34444 m .52622 .34456 L .52737 .34447 L F
.52555 .34426 m .52561 .34434 L .52557 .34433 L F
.52553 .34416 m .52557 .34422 L .52555 .34426 L F
.52557 .34422 m .52592 .34483 L .52555 .34426 L F
.52625 .34487 m .52592 .34527 L .52596 .34499 L F
.52562 .34409 m .52489 .34417 L .52548 .34392 L F
.5249 .34361 m .52574 .3446 L .52614 .34468 L F
.52599 .34456 m .52614 .34468 L .52562 .34409 L F
.52611 .34461 m .52609 .34467 L .52601 .34458 L F
.52617 .34447 m .52621 .34455 L .5261 .34463 L F
.52618 .34444 m .52619 .34448 L p .52617 .34447 L F P
0 g
s
.52619 .34448 m .52621 .34455 L p .52617 .34447 L .672 .728 .891 r
F P
0 g
s
.52602 .34459 m .52615 .34461 L .52618 .34458 L .672 .728 .891 r
F
.52604 .34461 m .52615 .34461 L .52602 .34459 L F
.52548 .34304 m .52549 .34314 L .52568 .34328 L F
.52553 .34291 m .52578 .34398 L .52546 .34282 L F
.52534 .34326 m .52574 .3435 L .52559 .3424 L F
.52618 .34444 m .5261 .34463 L .52549 .34287 L F
.52541 .34241 m .52553 .34291 L .52546 .34282 L F
.52502 .34177 m .52534 .34326 L .52559 .3424 L F
.52566 .34311 m .52549 .34287 L .52488 .34111 L F
.52618 .34444 m .52549 .34287 L .52566 .34311 L F
.5268 .34523 m .52836 .3461 L p .52673 .34484 L F P
0 g
s
.52706 .3451 m .52706 .34509 L .52729 .34517 L .672 .728 .891 r
F
.52779 .34573 m .52624 .34486 L .52729 .34517 L F
.52729 .34517 m .52706 .34509 L .52708 .34505 L F
.52598 .34494 m .52614 .34522 L .52597 .34495 L F
.51138 .35274 m .51066 .35208 L p .52093 .34708 L F P
0 g
s
.5446 .34152 m .54424 .34073 L p .52958 .34384 L .672 .728 .891 r
F P
0 g
s
.5301 .34703 m .52632 .34496 L .52638 .34494 L .672 .728 .891 r
F
.52646 .34448 m .52636 .34466 L .52621 .34444 L F
.52618 .3445 m .52644 .34454 L .52622 .34449 L F
.52601 .34458 m .52615 .34457 L .52618 .3445 L F
.52621 .34455 m .52619 .34448 L p .52618 .34454 L F P
0 g
s
.52618 .34454 m .52619 .34448 L .52618 .34451 L .672 .728 .891 r
F
.52615 .34457 m .52644 .34454 L .52618 .3445 L F
.52719 .34374 m .52677 .34403 L .52892 .34321 L F
.52621 .34444 m .52601 .34458 L .52618 .3445 L F
.52617 .34453 m .52618 .34444 L .5261 .3445 L F
.52618 .34454 m .52618 .34451 L .52617 .34453 L F
.52618 .34451 m .52618 .34444 L .52617 .34453 L F
.52677 .34403 m .52621 .34444 L .52676 .34423 L F
.52621 .34444 m .52618 .3445 L .52676 .34423 L F
.52719 .34374 m .52668 .34435 L .52665 .34412 L F
.52677 .34403 m .52676 .34423 L .52892 .34321 L F
.5258 .34461 m .52593 .3446 L .52593 .3446 L F
.52593 .3446 m .52626 .34457 L .52593 .3446 L F
.52593 .3446 m .52626 .34457 L .52626 .34457 L F
.52636 .34466 m .52609 .34467 L .52611 .34461 L F
.5262 .34456 m .52611 .34465 L .5261 .34463 L F
.52621 .34455 m .5262 .34456 L .5262 .34456 L F
.5262 .34456 m .52611 .34465 L .5262 .34456 L F
.52622 .34456 m .5258 .34461 L .52626 .34457 L F
.52613 .34467 m .52614 .34468 L .52652 .34466 L F
.52589 .34463 m .52662 .34474 L .52631 .3446 L F
.52625 .34499 m .52615 .34502 L .52604 .34567 L F
.52632 .34496 m .52592 .34527 L p .52625 .34487 L F P
0 g
s
.52634 .34532 m .52614 .34522 L .526 .34476 L .672 .728 .891 r
F
.52621 .34529 m .52612 .34465 L .52621 .34529 L F
.52612 .34465 m .526 .34375 L .52612 .34466 L F
.52671 .34481 m .52593 .34482 L .52592 .34483 L F
.52585 .3449 m .52632 .34496 L .52624 .34486 L F
.52625 .34487 m .52596 .34499 L .52609 .34467 L F
.52634 .34532 m .526 .34476 L .52609 .34467 L F
.52592 .34483 m .52591 .34484 L .52555 .34426 L F
.52512 .34464 m .52535 .34477 L .52542 .34477 L F
.52569 .3446 m .52524 .34478 L .52496 .34465 L F
.5251 .34469 m .52636 .34473 L .52589 .34463 L F
.52596 .3448 m .52673 .34479 L .52662 .34474 L F
.52539 .34485 m .52593 .34482 L .52596 .3448 L F
.52593 .34482 m .52673 .34479 L .52596 .3448 L F
.52607 .34508 m .52606 .34508 L .52592 .34483 L F
.52593 .34483 m .52592 .34483 L .5256 .34428 L F
.52607 .34508 m .52592 .34483 L .52593 .34483 L F
.52681 .34483 m .52681 .34483 L .52692 .3448 L F
.52715 .34474 m .52571 .34502 L .52715 .34473 L F
.52708 .34489 m .52696 .3449 L p .52715 .34474 L F P
0 g
s
.52692 .3448 m .52681 .34483 L .52695 .34486 L .672 .728 .891 r
F
.52675 .34481 m .52714 .34488 L .52718 .34478 L F
.52624 .34486 m .52704 .34488 L .52675 .34481 L F
.52704 .34488 m .5271 .34505 L .52784 .34554 L F
.52688 .34475 m .52697 .34486 L .52704 .34488 L F
.52697 .34486 m .5271 .34505 L .52704 .34488 L F
.52704 .34488 m .52714 .34488 L .52675 .34481 L F
.52695 .34486 m .5268 .34483 L .52703 .34499 L F
.52681 .34483 m .5268 .34483 L .52695 .34486 L F
.52614 .34468 m .52609 .34467 L .52675 .34524 L F
.52609 .34467 m .52588 .34463 L .5259 .34467 L F
.52609 .34467 m .526 .34467 L .52601 .34458 L F
.52614 .34473 m .52609 .34467 L .52611 .34465 L F
.52619 .34459 m .52609 .34468 L .52601 .34458 L F
.52652 .34466 m .52614 .34468 L .52673 .34481 L F
.52636 .34473 m .52662 .34474 L .52589 .34463 L F
.52612 .34464 m .52613 .34472 L .52611 .34465 L F
.52621 .34455 m .52613 .34472 L .52612 .34464 L F
.52609 .34467 m .5259 .34467 L .5263 .34494 L F
.52609 .34467 m .5263 .34494 L .52675 .34524 L F
.52671 .34481 m .52666 .3448 L .52593 .34482 L F
.52623 .34485 m .52675 .34481 L .52623 .34485 L F
.52672 .3448 m .52673 .34481 L .52675 .34482 L F
.52547 .34489 m .52677 .34481 L .52676 .3448 L F
.52624 .34486 m .52706 .34509 L .52706 .3451 L F
.52614 .34468 m .52687 .34531 L .52675 .34482 L F
.52621 .34456 m .52632 .34496 L .52613 .34472 L F
.52592 .34483 m .52598 .34494 L .52591 .34484 L F
.52554 .34493 m .52581 .34494 L .52585 .3449 L F
.52547 .34489 m .52585 .3449 L .52588 .34487 L F
.52579 .34463 m .52587 .34468 L p .5258 .34461 L F P
0 g
s
.52609 .34467 m .52596 .34499 L .526 .34467 L .672 .728 .891 r
F
.5259 .34468 m .52588 .34468 L .52632 .34496 L F
.52588 .34469 m .52632 .34496 L p .52588 .34468 L F P
0 g
s
.52621 .34457 m .52632 .34496 L p .52621 .34456 L .672 .728 .891 r
F P
0 g
s
.52621 .34457 m .52619 .34459 L .5262 .34456 L .672 .728 .891 r
F
.52617 .345 m .52621 .34455 L .52618 .34454 L F
.52619 .34448 m .52618 .34444 L p .52618 .34451 L F P
0 g
s
.52622 .34449 m .52644 .34454 L .52771 .34385 L .672 .728 .891 r
F
.52773 .34377 m .52771 .34385 L .52892 .34321 L F
.52622 .34449 m .52771 .34385 L .52773 .34377 L F
.53011 .34706 m .52632 .34496 L .5301 .34703 L F
.53302 .34869 m .52632 .34496 L .53299 .34865 L F
.53974 .35244 m .52632 .34496 L .53973 .35243 L F
.54083 .35305 m .52632 .34496 L .54083 .35305 L F
.52687 .34531 m .54007 .35368 L p .52703 .345 L F P
0 g
s
.53299 .34865 m .53011 .34706 L .5301 .34703 L .672 .728 .891 r
F
.52792 .34556 m .52784 .34554 L .52828 .34583 L F
.52833 .34573 m .52828 .34583 L .54007 .35368 L F
.54007 .35368 m .52687 .34531 L p .52803 .34554 L F P
0 g
s
.52803 .34554 m .5279 .34575 L .53163 .34856 L .672 .728 .891 r
F
.52601 .34457 m .52761 .34455 L .5276 .34455 L F
.52726 .34452 m .5266 .34473 L .52728 .34448 L F
.5249 .34342 m .5244 .34332 L .52407 .34286 L F
.52495 .3441 m .51244 .33616 L p .52407 .34286 L F P
0 g
s
.52396 .34278 m .52316 .34224 L .52351 .34282 L .672 .728 .891 r
F
.52316 .34224 m .5133 .33558 L .52351 .34282 L F
.5133 .33558 m .52337 .34283 L p .52351 .34282 L F P
0 g
s
.52502 .34334 m .52364 .34303 L .52276 .34161 L .672 .728 .891 r
F
.5276 .34452 m .52766 .34455 L .54521 .34394 L F
.5272 .34484 m .52746 .34485 L .52721 .34484 L F
.52767 .34484 m .52721 .34487 L .52723 .34483 L F
.54521 .34394 m .52941 .3448 L p .52886 .34471 L F P
0 g
s
.52731 .34477 m .52727 .34486 L .54521 .34394 L .672 .728 .891 r
F
.54509 .34313 m .52891 .34471 L p .52744 .34446 L F P
0 g
s
.52618 .34458 m .52927 .34436 L .5292 .34435 L .672 .728 .891 r
F
.5249 .34364 m .52574 .3446 L .5249 .34361 L F
.52478 .34353 m .52574 .3446 L .52479 .34352 L F
.52474 .34348 m .52538 .34403 L .52568 .3441 L F
.52377 .33879 m .5253 .34369 L .52418 .33817 L F
.52618 .34458 m .52615 .34461 L .52776 .34448 L F
.52642 .34466 m .52624 .34471 L .52619 .34459 L F
.52618 .34458 m .52776 .34448 L .52774 .34447 L F
.52626 .34457 m .52626 .34457 L .52743 .34448 L F
.52722 .34444 m .52642 .34466 L .5262 .34456 L F
.52722 .34444 m .52737 .34447 L .54509 .34313 L F
.5273 .34443 m .52722 .34445 L .52722 .34444 L F
.52744 .34446 m .52726 .34452 L .52728 .34448 L F
.52622 .34456 m .52626 .34457 L .53161 .34416 L F
.53156 .34415 m .53161 .34416 L .54509 .34313 L F
.52622 .34456 m .53161 .34416 L .53156 .34415 L F
.52722 .34445 m .52642 .34466 L .52722 .34444 L F
.52631 .3446 m .52662 .34474 L .53696 .34384 L F
.53657 .34379 m .53696 .34384 L .54509 .34313 L F
.52631 .3446 m .53696 .34384 L .53657 .34379 L F
.52618 .34468 m .52674 .34463 L .52644 .34454 L F
.52626 .34457 m .52743 .34448 L .52743 .34448 L F
.52654 .34472 m .52644 .34467 L .5273 .34443 L F
.52663 .34467 m .52682 .34463 L .52618 .34468 L F
.52538 .34403 m .52599 .34456 L .52562 .34409 L F
.52575 .34397 m .5259 .34444 L .52562 .34409 L F
.52677 .34472 m .52535 .3441 L .52676 .34471 L F
.52592 .34483 m .52593 .34482 L .52539 .34485 L F
.52451 .34502 m .52459 .34513 L .52576 .34498 L F
.52459 .34513 m .52632 .34496 L p .52576 .34498 L F P
0 g
s
.52587 .34469 m .52588 .34502 L .52515 .34526 L .672 .728 .891 r
F
.52517 .34519 m .52515 .34526 L .525 .34531 L F
.52587 .34469 m .52515 .34526 L .52517 .34519 L F
.52588 .34463 m .5258 .34461 L .52588 .34467 L F
.52561 .34434 m .52614 .34522 L .52557 .34433 L F
.52573 .34462 m .52572 .34464 L .52615 .34461 L F
.52267 .34508 m .52547 .34489 L .52539 .34485 L F
.52471 .34487 m .52468 .34489 L .5259 .34484 L F
.52496 .34465 m .52303 .34528 L .52445 .34469 L F
.5251 .34469 m .51961 .34535 L .52539 .34485 L F
.52492 .34471 m .5241 .34528 L .52433 .34478 L F
.52573 .34462 m .52583 .34461 L .52581 .34461 L F
.52583 .34461 m .52615 .34461 L .52581 .34461 L F
.5258 .34461 m .52581 .34461 L .52626 .34457 L F
.5258 .34461 m .52573 .34462 L .52581 .34461 L F
.5251 .34469 m .52596 .3448 L .52603 .34472 L F
.52573 .34462 m .5251 .34469 L .52572 .34464 L F
.52601 .34458 m .52527 .34485 L .52492 .34471 L F
.52447 .34514 m .52418 .34502 L .52586 .34464 L F
.52267 .34508 m .52554 .34493 L .52547 .34489 L F
.52527 .34485 m .5241 .34528 L .52492 .34471 L F
.52591 .34513 m .52606 .34607 L .52595 .34515 L F
.52596 .34499 m .52592 .34527 L .52584 .34527 L F
.5263 .34621 m .52626 .34489 L .52629 .34621 L F
.52612 .34554 m .52617 .34526 L .52614 .34525 L F
.52627 .34548 m .52625 .34499 L .52604 .34567 L F
.52639 .34653 m .52636 .34656 L .52592 .34511 L F
.52603 .34548 m .52623 .34611 L .52603 .34548 L F
.52635 .34799 m .52627 .34548 L .52604 .34567 L F
.52614 .34522 m .52672 .34711 L .52572 .34502 L F
.52581 .34531 m .52608 .3457 L .52603 .34545 L F
.52574 .3446 m .52579 .34463 L p .5258 .34461 L F P
0 g
s
.52574 .3446 m .52577 .3446 L .52577 .3446 L .672 .728 .891 r
F
.52577 .3446 m .52587 .34462 L .52577 .3446 L F
.52577 .3446 m .52587 .34462 L .52587 .34463 L F
.52615 .34476 m .52642 .34466 L .52644 .34467 L F
.52624 .34471 m .52615 .34469 L .52619 .34459 L F
.52642 .34466 m .52619 .34459 L .52621 .34457 L F
.52617 .34461 m .52618 .34454 L .52617 .34453 L F
.5262 .34456 m .52619 .34459 L .52601 .34458 L F
.52618 .3446 m .52618 .34454 L .52617 .34461 L F
.52621 .34455 m .52621 .34457 L p .52621 .34456 L F P
0 g
s
.52613 .34473 m .52617 .34453 L .52612 .34463 L .672 .728 .891 r
F
.52677 .34476 m .52495 .3441 L .52495 .34409 L F
.52634 .34532 m .52609 .34467 L .52614 .34473 L F
.52859 .34471 m .52658 .34474 L .52862 .34466 L F
.52662 .34474 m .52718 .34478 L .52721 .34469 L F
.52699 .34487 m .52699 .34487 L p .52747 .34446 L F P
0 g
s
.52681 .34483 m .5268 .34483 L .52681 .34483 L .672 .728 .891 r
F
.52674 .34481 m .52675 .34481 L .52677 .34481 L F
.52704 .34497 m .52703 .34499 L .5271 .34505 L F
.52692 .3448 m .52703 .34499 L .52704 .34497 L F
.52662 .34487 m .52706 .34488 L .52704 .34488 L F
.52624 .34486 m .52706 .34488 L .52662 .34487 L F
.52624 .34486 m .52708 .34489 L .52706 .34488 L F
.52688 .34475 m .52784 .34554 L .52792 .34556 L F
.5279 .34545 m .52627 .34471 L .527 .34485 L F
.52688 .34475 m .52828 .34583 L .52833 .34573 L F
.52803 .34554 m .5279 .34548 L .5279 .34545 L F
.5279 .34548 m .52627 .34471 L .5279 .34545 L F
.52765 .34417 m .52775 .34411 L p .5276 .34417 L F P
0 g
s
.53979 .33587 m .52776 .34399 L p .52743 .34369 L .672 .728 .891 r
F P
0 g
s
.52644 .34467 m .52642 .34466 L .5273 .34443 L .672 .728 .891 r
F
.52682 .34463 m .52892 .34321 L p .52644 .34454 L F P
0 g
s
.52775 .34411 m .52948 .34308 L p .52711 .3439 L .672 .728 .891 r
F P
0 g
s
.52775 .34411 m .52765 .34417 L p .52797 .34351 L .672 .728 .891 r
F P
0 g
s
.52652 .34466 m .52673 .34481 L .52672 .3448 L .672 .728 .891 r
F
.52672 .34465 m .52672 .34477 L .5268 .34483 L F
.52673 .34479 m .52718 .34478 L .52662 .34474 L F
.52676 .3448 m .52677 .34481 L .52718 .34478 L F
.52699 .34487 m .52574 .34504 L p .52716 .34456 L F P
0 g
s
.5265 .34487 m .52656 .34485 L .527 .34506 L .672 .728 .891 r
F
.52675 .34482 m .52687 .34531 L .52703 .345 L F
.52647 .34467 m .52686 .34512 L .52692 .34501 L F
.5261 .3445 m .52618 .34444 L .52609 .34442 L F
.52677 .34474 m .52486 .34397 L .52517 .34403 L F
.527 .34485 m .52677 .34475 L .52677 .34474 L F
.52677 .34475 m .52486 .34397 L .52677 .34474 L F
.52584 .34528 m .52588 .34536 L .52581 .34535 L F
.5259 .34485 m .52614 .34522 L .52572 .34502 L F
.52581 .34531 m .52603 .34545 L .52593 .34503 L F
.52596 .34499 m .52584 .34527 L .525 .34531 L F
.525 .34531 m .52502 .34546 L .52592 .34504 L F
.52747 .34446 m .52625 .34487 L .5273 .34443 L F
.526 .34476 m .52614 .34522 L .52595 .3448 L F
.5258 .34461 m .52632 .34496 L .5263 .34494 L F
.52607 .34508 m .52614 .34522 L .52606 .34508 L F
.52601 .34458 m .52609 .34468 L .52615 .34457 L F
.52612 .34464 m .5261 .3445 L .52609 .34468 L F
.52617 .34477 m .52617 .34453 L .52613 .34473 L F
.52612 .34468 m .52618 .34468 L .52644 .34454 L F
.52619 .34468 m .52603 .3446 L .52652 .34467 L F
.52603 .3446 m .52495 .3441 L .5259 .34444 L F
.52619 .34459 m .52616 .34466 L .52613 .34464 L F
.52615 .34469 m .52614 .34469 L .52613 .34464 L F
.52609 .34468 m .52619 .34468 L .52616 .34469 L F
.52571 .34132 m .52611 .34372 L p .52541 .34241 L F P
0 g
s
.52419 .33216 m .52571 .34132 L p .52541 .34241 L .672 .728 .891 r
F P
0 g
s
.52614 .34386 m .52419 .33216 L p .52573 .34339 L .672 .728 .891 r
F P
0 g
s
.52419 .33216 m .52298 .33228 L p .52502 .34177 L .672 .728 .891 r
F P
0 g
s
.52502 .34177 m .52559 .3424 L .52419 .33216 L .672 .728 .891 r
F
.52508 .34024 m .52618 .34444 L p .52488 .34111 L F P
0 g
s
.52613 .34472 m .526 .34375 L .526 .34375 L .672 .728 .891 r
F
.52621 .34529 m .52613 .34473 L .52613 .34472 L F
.52613 .34473 m .526 .34375 L .52613 .34472 L F
.52585 .34437 m .52495 .34409 L .52517 .34409 L F
.527 .34485 m .5259 .34444 L .52585 .34437 L F
.5259 .34444 m .52495 .34409 L .52585 .34437 L F
.52609 .34468 m .52616 .34469 L .52612 .34471 L F
.52616 .34466 m .52615 .34469 L .52613 .34464 L F
.52612 .34471 m .52616 .34469 L .52656 .34485 L F
.52632 .34496 m .52614 .34473 L .52613 .34472 L F
.52632 .34496 m .52621 .34457 L p .52619 .3448 L F P
0 g
s
.52614 .34474 m .52656 .34485 L .5265 .34487 L .672 .728 .891 r
F
.52601 .34458 m .52588 .34502 L .52587 .34469 L F
.52601 .34458 m .526 .34467 L .52599 .34467 L F
.52601 .34458 m .52595 .34468 L .52609 .34468 L F
.52591 .34465 m .52612 .34471 L .52586 .34464 L F
.52587 .34468 m .52588 .34469 L p .52588 .34468 L F P
0 g
s
.5258 .34461 m .52587 .34468 L .5259 .34468 L .672 .728 .891 r
F
.52586 .34464 m .52612 .34471 L .52614 .34474 L F
.52602 .34468 m .52609 .34468 L .52612 .34471 L F
.52609 .34468 m .52595 .34468 L .52608 .34471 L F
.52612 .34464 m .52609 .34468 L .52608 .34523 L F
.52609 .34523 m .52608 .34523 L .52608 .3454 L F
.52612 .34464 m .52608 .34523 L .52609 .34523 L F
.52609 .34468 m .52608 .34471 L .52612 .34471 L F
.52617 .345 m .52618 .3446 L .52617 .34461 L F
.52612 .34471 m .52656 .34485 L .52614 .34474 L F
.52617 .345 m .52621 .34457 L .52621 .34457 L F
.52616 .34469 m .52627 .34471 L .52656 .34485 L F
.52646 .34475 m .52644 .34467 L .52654 .34472 L F
.52632 .34496 m .52675 .34524 L p .5263 .34494 L F P
0 g
s
.52675 .34524 m .52681 .34527 L p .52675 .34522 L .672 .728 .891 r
F P
0 g
s
.52614 .34468 m .52675 .34524 L .52675 .34522 L .672 .728 .891 r
F
.52681 .34527 m .52687 .34531 L p .52682 .34527 L F P
0 g
s
.52614 .34468 m .52681 .34527 L .52682 .34527 L .672 .728 .891 r
F
.52687 .34531 m .52579 .34463 L p .527 .34506 L F P
0 g
s
.52617 .345 m .52617 .34486 L .52615 .34486 L .672 .728 .891 r
F
.52617 .34486 m .52617 .34477 L .52615 .34486 L F
.52615 .34486 m .52617 .34477 L .52613 .34473 L F
.52623 .34485 m .52617 .34477 L .52604 .3448 L F
.52632 .34496 m .52644 .34541 L p .52614 .34473 L F P
0 g
s
.52644 .34541 m .52664 .3462 L p .52639 .34546 L .672 .728 .891 r
F P
0 g
s
.52633 .34601 m .52632 .34496 L .52629 .34597 L .672 .728 .891 r
F
.52644 .34541 m .52639 .34546 L .52614 .34473 L F
.52699 .34487 m .52716 .34456 L .52747 .34446 L F
.52838 .34564 m .52688 .34475 L .52833 .34573 L F
.52691 .34485 m .52707 .34484 L .52707 .34482 L F
.525 .34531 m .5259 .34497 L .52589 .34483 L F
.52563 .34506 m .52576 .345 L .52574 .34502 L F
.52621 .34529 m .52612 .34464 L .52609 .34523 L F
.52625 .34487 m .52623 .34485 L .5273 .34443 L F
.52634 .34472 m .52644 .34467 L .52646 .34475 L F
.52627 .34471 m .52642 .34466 L .52627 .34471 L F
.52623 .34485 m .52622 .34484 L .5273 .34443 L F
.52619 .34468 m .52652 .34467 L .527 .34485 L F
.52673 .34481 m .52658 .34467 L .52661 .34478 L F
.5261 .3445 m .52599 .34372 L .52602 .34446 L F
.52676 .34471 m .52578 .34429 L .52564 .34411 L F
.52578 .34429 m .52535 .3441 L .52564 .34411 L F
.52611 .34465 m .52557 .34338 L .52568 .34341 L F
.52602 .34446 m .52599 .34372 L .52579 .3443 L F
.52586 .34439 m .52579 .3443 L .52577 .34434 L F
.52602 .34446 m .52579 .3443 L .52586 .34439 L F
.52658 .34467 m .52598 .34415 L .5265 .34467 L F
.52574 .34502 m .52634 .34472 L .52646 .34475 L F
.52595 .34468 m .52598 .34468 L .527 .34506 L F
.52627 .34471 m .52619 .34468 L .527 .34485 L F
.52623 .34485 m .52671 .34466 L .52617 .34477 L F
.52671 .34466 m .52682 .34463 L .52663 .34467 L F
.52671 .34466 m .52663 .34467 L .52617 .34477 L F
.52588 .34463 m .52588 .34467 L .5259 .34467 L F
.52579 .34463 m .52586 .34464 L .52598 .34468 L F
.52601 .34458 m .52588 .34468 L .52595 .34468 L F
.52579 .34463 m .52598 .34468 L .52595 .34468 L F
.52623 .34485 m .52626 .34488 L .52682 .34463 L F
.52674 .34468 m .52632 .34496 L p .52642 .34467 L F P
0 g
s
.52617 .345 m .52632 .34496 L .52619 .3448 L .672 .728 .891 r
F
.52609 .34468 m .52604 .3448 L .52607 .34565 L F
.52577 .34434 m .52599 .34372 L .5255 .34316 L F
.5258 .34414 m .52564 .34411 L .52575 .34411 L F
.52534 .3441 m .52535 .3441 L .52688 .34477 L F
.52575 .34408 m .52562 .34409 L .52548 .34392 L F
.52525 .34284 m .52575 .34397 L .52553 .34416 L F
.5253 .34369 m .52575 .34425 L .5256 .34359 L F
.52488 .34111 m .52539 .34278 L .52525 .34284 L F
.52539 .34278 m .52575 .34397 L .52525 .34284 L F
.52298 .33228 m .52508 .34024 L p .52488 .34111 L F P
0 g
s
.5253 .34369 m .5256 .34359 L .52298 .33228 L .672 .728 .891 r
F
.5253 .34369 m .5244 .34332 L .5249 .34342 L F
.52586 .34414 m .52474 .34348 L .52568 .3441 L F
.527 .34485 m .52514 .34376 L .5253 .34369 L F
.52479 .34352 m .5249 .34364 L .5249 .34361 L F
.52474 .34348 m .52478 .34353 L .52479 .34352 L F
.52514 .34376 m .5244 .34332 L .5253 .34369 L F
.52541 .34319 m .52557 .34359 L .5252 .34337 L F
.52598 .34415 m .5253 .34369 L .52569 .34409 L F
.52575 .34411 m .52561 .34407 L .52554 .34399 L F
.52581 .34461 m .52604 .34461 L .52602 .34459 L F
.52609 .34468 m .52586 .34464 L .52601 .34458 L F
.52587 .34462 m .52607 .34466 L .52587 .34463 L F
.52613 .34464 m .52614 .34474 L .52609 .34468 L F
.52609 .34468 m .52612 .34471 L .52615 .34457 L F
.52607 .34466 m .52619 .34468 L .52608 .34466 L F
.52607 .34466 m .52608 .34466 L .52587 .34463 L F
.526 .34467 m .52596 .34499 L .52599 .34467 L F
.52588 .34468 m .52589 .34483 L .52607 .34474 L F
.52608 .34471 m .52607 .34474 L .52612 .34471 L F
.52588 .34468 m .52607 .34474 L .52608 .34471 L F
.52574 .3446 m .52591 .34465 L .52586 .34464 L F
.52598 .34494 m .52597 .34495 L .52591 .34484 L F
.52599 .34467 m .52596 .34499 L .52588 .34502 L F
.52563 .34506 m .52569 .34489 L .52596 .34481 L F
.52596 .34517 m .52604 .3448 L .52593 .34503 L F
.52607 .34565 m .52605 .34522 L .52596 .34517 L F
.52605 .34522 m .52604 .3448 L .52596 .34517 L F
.52612 .34463 m .52617 .34453 L .5261 .3445 L F
.52677 .34476 m .52495 .3441 L .52677 .34476 L F
.52618 .34444 m .526 .34375 L p .52609 .34442 L F P
0 g
s
.52688 .34477 m .52564 .34411 L .5258 .34414 L .672 .728 .891 r
F
.52517 .34244 m .5256 .34356 L .52507 .3423 L F
.5256 .34356 m .52604 .3447 L .52557 .34354 L F
.5256 .34356 m .52557 .34354 L .52507 .3423 L F
.53321 .3434 m .52719 .3444 L .53416 .34358 L F
.52743 .34369 m .52682 .34463 L .52711 .3439 L F
.52719 .3444 m .52615 .34457 L .52733 .34443 L F
.52719 .3444 m .52733 .34443 L .54488 .34232 L F
.52616 .34469 m .52619 .34468 L .52627 .34471 L F
.52615 .34469 m .52614 .34474 L .52614 .34469 L F
.52612 .34471 m .52663 .34467 L .52618 .34468 L F
.5259 .34497 m .52596 .34495 L .52589 .34483 L F
.52612 .34465 m .52612 .34466 L .52621 .34529 L F
.52596 .34495 m .52623 .34485 L .52602 .34484 L F
.52596 .34495 m .52602 .34484 L .52589 .34483 L F
.52593 .34503 m .52595 .34491 L .5259 .34493 L F
.52589 .34483 m .52617 .34477 L .52612 .34471 L F
.52596 .34481 m .52596 .3448 L .52596 .34481 L F
.52602 .34484 m .52604 .3448 L .52589 .34483 L F
.52623 .34485 m .52604 .3448 L .52602 .34484 L F
.52576 .345 m .52596 .34481 L .52644 .34467 L F
.52615 .34475 m .52627 .34471 L .52615 .34476 L F
.52627 .34471 m .52627 .34471 L .52615 .34476 L F
.52624 .34471 m .52614 .34474 L .52615 .34469 L F
.52617 .34477 m .52663 .34467 L .52612 .34471 L F
.52623 .34485 m .52619 .34481 L .52631 .34467 L F
.52674 .34463 m .52674 .34461 L .52644 .34454 L F
.52661 .34467 m .52664 .34467 L .52688 .34477 L F
.52674 .34468 m .52598 .34415 L .52673 .34481 L F
.52635 .34467 m .52631 .34467 L .52672 .34414 L F
.52623 .34485 m .52631 .34467 L .52635 .34467 L F
.52598 .34415 m .52569 .34409 L .52647 .34467 L F
.5265 .34467 m .52647 .34467 L .52661 .34478 L F
.52598 .34415 m .52647 .34467 L .5265 .34467 L F
.52621 .34457 m .52621 .34455 L p .52621 .34457 L F P
0 g
s
.52615 .34457 m .52612 .34468 L .52644 .34454 L .672 .728 .891 r
F
.5261 .3445 m .52607 .34465 L .52609 .34468 L F
.5261 .3445 m .52602 .34446 L .52604 .3448 L F
.52603 .3446 m .5259 .34444 L .52652 .34467 L F
.52632 .34496 m .52682 .34463 L p .52549 .34524 L F P
0 g
s
.52574 .34504 m .52563 .34506 L p .52571 .34503 L .672 .728 .891 r
F P
0 g
s
.52568 .34504 m .52576 .34503 L .52567 .34503 L .672 .728 .891 r
F
.52576 .34503 m .52699 .34487 L .52576 .34502 L F
.525 .34531 m .52592 .34504 L .52596 .34495 L F
.52582 .34525 m .52593 .34503 L .52589 .34487 L F
.52574 .34504 m .52571 .34503 L .52622 .34484 L F
.52563 .34506 m .52596 .34481 L .52576 .345 L F
.52609 .34468 m .52537 .3449 L .52586 .34464 L F
.52537 .3449 m .5241 .34528 L .52527 .34485 L F
.5251 .34469 m .52539 .34485 L .52596 .3448 L F
.52537 .3449 m .52527 .34485 L .52586 .34464 L F
.52621 .34529 m .52609 .34523 L .52608 .3454 L F
.52627 .34536 m .5261 .34533 L .52602 .34516 L F
.52584 .34528 m .52581 .34535 L .52579 .34535 L F
.52504 .34595 m .52577 .34538 L p .52498 .34542 L F P
0 g
s
.52498 .34542 m .52577 .34538 L .52582 .34529 L .672 .728 .891 r
F
.52592 .34527 m .52459 .34629 L p .525 .34531 L F P
0 g
s
.5258 .34529 m .52581 .34531 L .5258 .34528 L .672 .728 .891 r
F
.52581 .34531 m .52593 .34503 L .52582 .34525 L F
.52588 .34513 m .5258 .34529 L .52632 .34496 L F
.52578 .34533 m .52583 .34529 L p .5258 .34529 L F P
0 g
s
.52583 .34529 m .52632 .34496 L p .5258 .34529 L .672 .728 .891 r
F P
0 g
s
.52624 .34486 m .52652 .34453 L .52653 .34453 L .672 .728 .891 r
F
.52456 .34521 m .52464 .34513 L .52544 .34492 L F
.52588 .34468 m .52512 .34523 L .52589 .34483 L F
.52548 .34494 m .52544 .34492 L .52642 .34466 L F
.52456 .34521 m .52544 .34492 L .52548 .34494 L F
.52664 .3462 m .5264 .34607 L .52614 .34522 L F
.52629 .34621 m .52626 .34489 L .52624 .34487 L F
.52664 .3462 m .52614 .34522 L .52634 .34532 L F
.52672 .34711 m .52693 .34779 L .52647 .34696 L F
.52693 .34779 m .52704 .34815 L .52647 .34696 L F
.52647 .34696 m .52704 .34815 L .52608 .34672 L F
.52709 .34788 m .52632 .34496 L p .52651 .34757 L F P
0 g
s
.52648 .34539 m .52634 .34537 L .52631 .34527 L .672 .728 .891 r
F
.52574 .34504 m .52699 .34487 L p .52576 .34503 L F P
0 g
s
.52591 .34524 m .52586 .34524 L .52623 .34485 L .672 .728 .891 r
F
.52576 .34502 m .52699 .34487 L .52576 .34502 L F
.52538 .34532 m .52632 .34496 L .52531 .34532 L F
.52632 .34496 m .52591 .34524 L p .52624 .34487 L F P
0 g
s
.5262 .34523 m .52602 .34516 L .52595 .34499 L .672 .728 .891 r
F
.52579 .34463 m .52574 .3446 L p .52586 .34464 L F P
0 g
s
.52451 .34502 m .52564 .34498 L .52554 .34493 L .672 .728 .891 r
F
.526 .34477 m .52437 .3452 L .52609 .34468 L F
.52437 .3452 m .5241 .34528 L .52436 .3452 L F
.52437 .3452 m .52436 .3452 L .52609 .34468 L F
.52648 .34539 m .53079 .35731 L p .52634 .34537 L F P
0 g
s
.52609 .34468 m .52604 .3448 L .52609 .34468 L .672 .728 .891 r
F
.52607 .34465 m .52604 .3448 L .52609 .34468 L F
.52596 .34495 m .52626 .34488 L .52623 .34485 L F
.52623 .34485 m .52578 .34533 L .52619 .34481 L F
.52596 .34495 m .52592 .34504 L .52626 .34488 L F
.52614 .34474 m .526 .34477 L .52609 .34468 L F
.52596 .34481 m .52615 .34475 L .52615 .34476 L F
.52626 .34457 m .52823 .34442 L .52822 .34442 L F
.52862 .34466 m .52658 .34474 L .52824 .3446 L F
.52721 .34469 m .52718 .34478 L .54509 .34313 L F
.52856 .34464 m .52699 .34487 L p .52747 .34446 L F P
0 g
s
.52891 .34471 m .52708 .34489 L p .52715 .34473 L .672 .728 .891 r
F P
0 g
s
.52582 .34495 m .5281 .34468 L .52814 .34463 L .672 .728 .891 r
F
.52539 .34501 m .52582 .34496 L .52582 .34495 L F
.52625 .34487 m .52574 .34504 L .52623 .34485 L F
.52632 .34496 m .52624 .34487 L .52642 .34467 L F
.52634 .34467 m .52642 .34474 L .52647 .34467 L F
.52512 .34523 m .5251 .34526 L .52612 .34471 L F
.52563 .34506 m .52456 .34521 L p .52569 .34489 L F P
0 g
s
.52539 .34501 m .52554 .34504 L .52555 .34504 L .672 .728 .891 r
F
.52574 .3446 m .52495 .3441 L p .5258 .34449 L F P
0 g
s
.52564 .34411 m .52572 .34504 L .52575 .34425 L .672 .728 .891 r
F
.52574 .3446 m .5258 .34449 L .52603 .3446 L F
.52574 .3446 m .52603 .3446 L .52607 .34466 L F
.52589 .34487 m .52599 .34455 L .52577 .34434 L F
.52599 .34455 m .52602 .34446 L .52586 .34439 L F
.52599 .34455 m .52586 .34439 L .52577 .34434 L F
.52607 .34466 m .52603 .3446 L .52619 .34468 L F
.52598 .34476 m .52596 .34479 L .52552 .34397 L F
.52557 .34403 m .52552 .34397 L .5252 .34337 L F
.52598 .34476 m .52552 .34397 L .52557 .34403 L F
.52598 .34489 m .52644 .34467 L .52598 .3449 L F
.52598 .34489 m .52598 .3449 L .52574 .34502 L F
.52581 .34531 m .52589 .34487 L .52579 .34497 L F
.52576 .345 m .52598 .34489 L .52574 .34502 L F
.52576 .3444 m .5258 .34449 L .52575 .34425 L F
.52579 .34497 m .5258 .34449 L .52576 .3444 L F
.52579 .34497 m .52589 .34487 L .5258 .34449 L F
.526 .34485 m .52565 .34435 L .52575 .3444 L F
.52573 .34466 m .52577 .34466 L .52575 .34425 L F
.52572 .34504 m .52577 .34466 L .52573 .34466 L F
.52572 .34504 m .52579 .34497 L .52577 .34466 L F
.52549 .34428 m .52572 .34504 L .52564 .34411 L F
.52552 .34429 m .52587 .3449 L .5255 .34433 L F
.5255 .34433 m .52583 .34494 L .52572 .34504 L F
.52583 .34494 m .52593 .34512 L .52574 .34504 L F
.52553 .34524 m .52632 .34496 L .52549 .34524 L F
.52572 .34504 m .5258 .34529 L .52579 .34497 L F
.52583 .34494 m .52574 .34504 L .52572 .34504 L F
.52558 .34499 m .52555 .34504 L .52577 .34501 L F
.52581 .34497 m .52577 .34501 L .5263 .34493 L F
.52558 .34499 m .52577 .34501 L .52581 .34497 L F
.52685 .34483 m .52683 .34483 L .52582 .34495 L F
.52576 .34502 m .52699 .34487 L .52696 .34486 L F
.52642 .34474 m .5267 .34524 L .52672 .345 L F
.52597 .34433 m .52624 .34466 L .52634 .34467 L F
.52661 .34467 m .52534 .3441 L .52664 .34467 L F
.52653 .34439 m .52631 .34467 L .52612 .34455 L F
.52631 .34467 m .52619 .34481 L .52615 .34466 L F
.52612 .34468 m .52612 .34471 L .52618 .34468 L F
.52619 .34481 m .52607 .34466 L .52615 .34466 L F
.52587 .3449 m .52586 .3449 L .5255 .34433 L F
.52607 .34466 m .5262 .34482 L .52608 .34466 L F
.52596 .3448 m .52602 .34446 L .52589 .34487 L F
.52515 .34478 m .52595 .34481 L .52607 .34466 L F
.52604 .3448 m .52603 .34471 L .52603 .34481 L F
.52587 .34463 m .52608 .34466 L .52602 .34468 L F
.52608 .34466 m .52619 .34468 L .52609 .34468 L F
.52608 .34466 m .52609 .34468 L .52602 .34468 L F
.52603 .34471 m .52603 .3446 L .52603 .34481 L F
.52603 .3446 m .52602 .34446 L .52603 .3446 L F
.52603 .3446 m .52603 .3446 L .52603 .34481 L F
.52603 .34481 m .52602 .34446 L .52593 .34503 L F
.52598 .34479 m .52642 .34466 L .52596 .34481 L F
.52595 .34481 m .5262 .34482 L .52607 .34466 L F
.52574 .34504 m .52622 .34484 L .52623 .34485 L F
.52456 .34521 m .52598 .34479 L .52596 .34481 L F
.52535 .34488 m .52557 .34498 L .52582 .34495 L F
.5259 .34486 m .52582 .34495 L .52665 .34483 L F
.52535 .34488 m .52582 .34495 L .5259 .34486 L F
.52558 .34499 m .5263 .34493 L .52628 .34491 L F
.52607 .34466 m .52608 .34466 L .52607 .34466 L F
.52619 .34481 m .52585 .34523 L .52607 .34466 L F
.52602 .34516 m .52593 .34512 L .52583 .34494 L F
.52586 .3449 m .52583 .34494 L .5255 .34433 L F
.52451 .34519 m .52697 .34486 L .52451 .34519 L F
.52706 .34488 m .527 .34485 L .52699 .34487 L F
.52697 .34486 m .52707 .34484 L .52697 .34486 L F
.52624 .34487 m .52673 .3443 L .52674 .34432 L F
.52591 .34524 m .52624 .34486 L .52624 .34487 L F
.52624 .34486 m .52673 .3443 L .52624 .34487 L F
.52697 .34486 m .52697 .34486 L .52631 .34495 L F
.52631 .34495 m .52631 .34495 L .52451 .34519 L F
.52697 .34486 m .52631 .34495 L .52631 .34495 L F
.52597 .34433 m .52593 .34462 L .52624 .34466 L F
.52596 .34479 m .52589 .34487 L .52565 .34435 L F
.52509 .34474 m .52607 .34466 L .52607 .34466 L F
.52593 .34462 m .52607 .34466 L .52624 .34466 L F
.52765 .34417 m .52757 .34379 L .52797 .34351 L F
.52743 .34369 m .52711 .3439 L .52948 .34308 L F
.52569 .34409 m .52634 .34467 L .52647 .34467 L F
.52608 .34466 m .52607 .34466 L .52561 .34349 L F
.52608 .34466 m .52561 .34349 L .52562 .34349 L F
.52607 .34466 m .52604 .3447 L .52598 .34454 L F
.52593 .3443 m .52592 .34447 L .52597 .34433 L F
.52607 .34466 m .52598 .34454 L .52503 .3421 L F
.52607 .34466 m .52503 .3421 L .52504 .3421 L F
.52607 .34466 m .52499 .34198 L .52502 .342 L F
.52509 .34474 m .52607 .34466 L .52597 .34463 L F
.52607 .34466 m .52607 .34466 L .52607 .34466 L F
.52597 .34463 m .52607 .34466 L .52605 .34463 L F
.52607 .34466 m .52607 .34466 L .52605 .34463 L F
.52602 .34516 m .52583 .34494 L .52586 .3449 L F
.526 .34485 m .52595 .34499 L .52589 .34487 L F
.52692 .34532 m .527 .34506 L .52803 .34554 L F
.52692 .34501 m .52722 .34545 L .52717 .3452 L F
.52687 .34531 m .527 .34506 L .52692 .34532 L F
.5267 .34524 m .5282 .34632 L p .52672 .345 L F P
0 g
s
.52722 .34545 m .52757 .34576 L .52737 .34549 L .672 .728 .891 r
F
.52722 .34545 m .52737 .34549 L .52717 .3452 L F
.52717 .3452 m .5282 .34632 L .52887 .34648 L F
.52757 .34576 m .5282 .34632 L .52717 .3452 L F
.5282 .34632 m .53921 .35426 L p .52887 .34648 L F P
0 g
s
.52803 .34554 m .52706 .34488 L .5279 .34575 L .672 .728 .891 r
F
.53103 .34757 m .52803 .34554 L .53163 .34856 L F
.53103 .34757 m .53163 .34856 L .53921 .35426 L F
.53921 .35426 m .5267 .34524 L p .52743 .3452 L F P
0 g
s
.52895 .34663 m .52743 .3452 L .5289 .34708 L .672 .728 .891 r
F
.52568 .34341 m .52557 .34338 L .52488 .34111 L F
.52599 .34372 m .52298 .33228 L p .5255 .34316 L F P
0 g
s
.52615 .34456 m .52608 .34466 L .52408 .3393 L .672 .728 .891 r
F
.52615 .34456 m .52408 .3393 L .52418 .33946 L F
.52612 .34455 m .52607 .34465 L .52602 .34459 L F
.52535 .34488 m .52623 .34485 L .52515 .34478 L F
.52623 .34485 m .5262 .34482 L .52595 .34481 L F
.52593 .34483 m .52595 .34481 L .52515 .34478 L F
.52623 .34485 m .52595 .34481 L .52593 .34483 L F
.52565 .34435 m .52589 .34487 L .52552 .34429 L F
.52589 .34487 m .52602 .34516 L .52587 .3449 L F
.52589 .34487 m .52587 .3449 L .52552 .34429 L F
.52599 .34484 m .52595 .3448 L .52596 .34479 L F
.526 .34485 m .52595 .3448 L .52599 .34484 L F
.526 .34485 m .52589 .34487 L .52595 .3448 L F
.52587 .3449 m .52602 .34516 L .52586 .3449 L F
.52607 .34465 m .52578 .34533 L .52602 .34459 L F
.52623 .34485 m .52665 .34483 L .5262 .34482 L F
.52591 .34445 m .52602 .34472 L .52568 .34417 L F
.52569 .34409 m .52592 .34467 L .52593 .3443 L F
.52557 .34359 m .52591 .34445 L .52538 .34366 L F
.52569 .34409 m .5256 .34407 L .52576 .34427 L F
.52535 .3441 m .52478 .34385 L .52575 .34411 L F
.52591 .34445 m .52568 .34417 L .52538 .34366 L F
.52602 .34472 m .52598 .34476 L .5252 .34337 L F
.52539 .34501 m .52555 .34504 L .52558 .34499 L F
.52576 .34503 m .52576 .34502 L .52567 .34503 L F
.52567 .34503 m .52576 .34502 L .52576 .34502 L F
.52399 .34526 m .52568 .34504 L .52567 .34503 L F
.52451 .34519 m .52631 .34495 L .5263 .34493 L F
.52502 .34546 m .52578 .34533 L .52588 .34513 L F
.5258 .34529 m .5258 .34528 L .52579 .34497 L F
.52592 .34465 m .52578 .34533 L .52514 .34516 L F
.52607 .34466 m .52612 .34467 L .52624 .34466 L F
.52639 .34467 m .52623 .34485 L .52635 .34467 L F
.52634 .34467 m .52627 .3447 L .52642 .34474 L F
.52624 .34466 m .52627 .3447 L .52634 .34467 L F
.52642 .34474 m .52655 .34476 L .52647 .34467 L F
.52658 .34467 m .5265 .34467 L .52661 .34478 L F
.52688 .34477 m .52677 .34472 L .52676 .34471 L F
.52674 .34463 m .52682 .34463 L .52674 .34461 L F
.527 .34485 m .52598 .34415 L .52699 .34487 L F
.527 .34485 m .52661 .34467 L .52688 .34477 L F
.52608 .34466 m .52665 .34483 L .52761 .34447 L F
.52608 .34466 m .52608 .34467 L .52612 .34467 L F
.52608 .34466 m .52612 .34467 L .52607 .34466 L F
.52607 .34466 m .52605 .34472 L .52604 .3447 L F
.52615 .34466 m .52607 .34466 L .52612 .34455 L F
.52631 .34467 m .52615 .34466 L .52612 .34455 L F
.52673 .3443 m .52639 .34467 L .52672 .34414 L F
.52674 .34432 m .52673 .3443 L .52711 .3439 L F
.52676 .34466 m .52674 .34432 L .52711 .3439 L F
.52672 .34414 m .52653 .34439 L .52602 .34459 L F
.52672 .34414 m .52613 .34452 L .52755 .34417 L F
.52604 .3447 m .52602 .34472 L .52592 .34447 L F
.52593 .34462 m .52592 .34465 L .52607 .34466 L F
.52601 .34463 m .526 .34465 L .52592 .34465 L F
.52615 .34457 m .52509 .34474 L .52611 .34462 L F
.52602 .34459 m .52601 .34463 L .52592 .34465 L F
.52615 .34457 m .52604 .34461 L .52602 .34459 L F
.52613 .34452 m .52602 .34459 L .52613 .34459 L F
.52602 .34459 m .52592 .34465 L .52604 .34462 L F
.52602 .34459 m .52604 .34462 L .52613 .34459 L F
.52592 .34447 m .52592 .34447 L .52591 .34445 L F
.52604 .3447 m .52592 .34447 L .52592 .34447 L F
.52592 .34447 m .52592 .34467 L .52595 .3445 L F
.52604 .3447 m .52591 .34445 L .52597 .34452 L F
.52561 .34407 m .52485 .34387 L .52554 .34399 L F
.52547 .34391 m .52561 .34414 L .52564 .34411 L F
.5253 .34369 m .52561 .34414 L .52547 .34391 L F
.5253 .34369 m .52549 .34428 L .52561 .34414 L F
.52575 .3444 m .52565 .34435 L .52534 .34368 L F
.52536 .34367 m .52534 .34368 L .5252 .34337 L F
.5253 .34369 m .52556 .34416 L .5255 .34433 L F
.5252 .34337 m .52534 .34368 L .5253 .34369 L F
.52534 .34368 m .52556 .34416 L .5253 .34369 L F
.52514 .34376 m .52478 .34385 L .5244 .34332 L F
.52554 .34399 m .52486 .34387 L .52514 .34376 L F
.52486 .34387 m .52478 .34385 L .52514 .34376 L F
.5253 .34369 m .52521 .34372 L .52551 .34395 L F
.5253 .34369 m .52551 .34395 L .52569 .34409 L F
.52552 .34397 m .52534 .34368 L .52536 .34367 L F
.52575 .3444 m .52547 .34391 L .52552 .34397 L F
.52547 .34391 m .52534 .34368 L .52552 .34397 L F
.52485 .34387 m .52478 .34385 L .52486 .34387 L F
.52485 .34387 m .52486 .34387 L .52554 .34399 L F
.52556 .34416 m .52565 .34435 L .52552 .34429 L F
.52576 .34427 m .52499 .34395 L .52592 .34467 L F
.52517 .34403 m .52486 .34397 L .52478 .34385 L F
.52484 .34389 m .52499 .34401 L p .52499 .34395 L F P
0 g
s
.52499 .34401 m .52592 .34467 L p .52499 .34395 L .672 .728 .891 r
F P
0 g
s
.526 .34465 m .52578 .34533 L .52592 .34465 L .672 .728 .891 r
F
.52592 .34465 m .52592 .34467 L .52608 .34467 L F
.52624 .34486 m .52652 .34453 L .52624 .34486 L F
.52624 .34486 m .52623 .34485 L .52652 .34453 L F
.5262 .34482 m .52665 .34483 L .52608 .34466 L F
.52624 .34466 m .52608 .34467 L .5267 .34524 L F
.52608 .34466 m .52605 .34472 L .52607 .34466 L F
.52582 .34496 m .52685 .34483 L .52582 .34495 L F
.52608 .34466 m .52634 .34537 L .52605 .34472 L F
.52607 .34466 m .52608 .34466 L .52611 .34462 L F
.52591 .34524 m .52623 .34485 L .52624 .34486 L F
.52645 .34533 m .52608 .34466 L .52615 .34456 L F
.52592 .34467 m .52632 .34496 L p .52608 .34467 L F P
0 g
s
.52632 .34496 m .5267 .34524 L p .52608 .34467 L .672 .728 .891 r
F P
0 g
s
.52608 .34466 m .52608 .34466 L .52607 .34466 L .672 .728 .891 r
F
.52632 .34496 m .52592 .34467 L p .52609 .34467 L F P
0 g
s
.52592 .34465 m .52592 .34467 L .52606 .34463 L .672 .728 .891 r
F
.52682 .34463 m .52676 .34466 L p .52711 .3439 L F P
0 g
s
.5253 .34369 m .52396 .34278 L .52521 .34372 L .672 .728 .891 r
F
.52396 .34278 m .52484 .34389 L .52569 .34409 L F
.5248 .34386 m .52432 .34318 L .52502 .34334 L F
.52426 .34327 m .52507 .34394 L p .5252 .34348 L F P
0 g
s
.52674 .34468 m .52642 .34467 L .52674 .34432 L .672 .728 .891 r
F
.52615 .34457 m .52611 .34462 L .52745 .34445 L F
.52618 .34458 m .52612 .34461 L .52615 .34457 L F
.52612 .34461 m .52606 .34464 L .52615 .34457 L F
.52638 .34658 m .52632 .34496 L .52617 .345 L F
.52606 .34607 m .52635 .34799 L .5261 .3461 L F
.52635 .34799 m .5263 .34621 L .52629 .34621 L F
.52604 .34653 m .52672 .34711 L .52608 .34672 L F
.52651 .34757 m .52644 .34661 L .52638 .34658 L F
.52644 .34661 m .52632 .34496 L .52638 .34658 L F
.52612 .34488 m .52612 .34489 L .52605 .34472 L F
.52634 .34537 m .52612 .34489 L .52612 .34488 L F
.52634 .34537 m .52631 .34537 L .52612 .34489 L F
.5262 .34462 m .5262 .34465 L .52637 .34463 L F
.52611 .34462 m .5262 .34465 L .5262 .34462 L F
.52611 .34462 m .52608 .34466 L .5262 .34465 L F
.52645 .34533 m .52631 .34527 L .52608 .34466 L F
.52648 .34539 m .52631 .34527 L .52645 .34533 L F
.52617 .34455 m .52648 .34539 L p .52615 .34456 L F P
0 g
s
.52591 .34524 m .52624 .34486 L .52624 .34486 L .672 .728 .891 r
F
.52627 .34536 m .52602 .34516 L .5262 .34523 L F
.52616 .34507 m .52627 .34536 L .52613 .34509 L F
.52645 .34533 m .52617 .34455 L p .52607 .34524 L F P
0 g
s
.52776 .34399 m .52682 .34463 L p .52743 .34369 L .672 .728 .891 r
F P
0 g
s
.52615 .34457 m .52745 .34445 L .52737 .34444 L .672 .728 .891 r
F
.53665 .34331 m .52722 .34444 L .53828 .34363 L F
.52774 .34447 m .52776 .34448 L .52927 .34436 L F
.5292 .34435 m .52927 .34436 L .54509 .34313 L F
.54509 .34313 m .54488 .34232 L p .53665 .34331 L F P
0 g
s
.53665 .34331 m .53828 .34363 L .54509 .34313 L .672 .728 .891 r
F
.52743 .34448 m .52743 .34448 L .52823 .34442 L F
.52822 .34442 m .52823 .34442 L .54509 .34313 L F
.54488 .34232 m .52856 .34464 L p .5273 .34443 L F P
0 g
s
.52615 .34457 m .53271 .34381 L .53257 .3438 L .672 .728 .891 r
F
.52676 .34466 m .52674 .34468 L p .52674 .34432 L F P
0 g
s
.52629 .3446 m .52637 .34463 L .53283 .34382 L .672 .728 .891 r
F
.53271 .34381 m .53283 .34382 L .54488 .34232 L F
.52629 .3446 m .53283 .34382 L .53271 .34381 L F
.52719 .3444 m .52623 .3446 L .52615 .34457 L F
.52721 .34439 m .52719 .3444 L .52719 .3444 L F
.52719 .3444 m .52623 .3446 L .52719 .3444 L F
.52602 .34472 m .52616 .34507 L .52598 .34476 L F
.52606 .34524 m .52616 .3446 L .52613 .34464 L F
.52623 .34544 m .52621 .34529 L .52608 .3454 L F
.52624 .34552 m .52623 .34544 L .52607 .34565 L F
.52602 .34516 m .52638 .34594 L .52593 .34512 L F
.52601 .34565 m .52616 .3446 L .52601 .34564 L F
.52534 .3441 m .52478 .34385 L .52535 .3441 L F
.5256 .34407 m .52484 .34389 L .52576 .34427 L F
.52609 .34467 m .5248 .34386 L .52502 .34334 L F
.52597 .34452 m .52591 .34445 L .52554 .34353 L F
.52539 .34425 m .52593 .34446 L .52589 .34379 L F
.52553 .34418 m .52565 .3444 L .52547 .34433 L F
.52604 .3447 m .52554 .34353 L .52557 .34354 L F
.52389 .33898 m .52608 .34466 L .52384 .33901 L F
.52395 .33894 m .52408 .3393 L .52389 .33898 L F
.52408 .3393 m .52608 .34466 L .52389 .33898 L F
.52508 .34349 m .52539 .34425 L .5256 .34406 L F
.52516 .34352 m .5256 .34406 L .52589 .34379 L F
.52508 .34349 m .5256 .34406 L .52516 .34352 L F
.52298 .33228 m .52179 .33245 L p .52377 .33879 L F P
0 g
s
.52377 .33879 m .52418 .33817 L .52298 .33228 L .672 .728 .891 r
F
.52329 .33659 m .52412 .33888 L p .52313 .33676 L F P
0 g
s
.52412 .33888 m .52617 .34455 L p .52383 .33854 L .672 .728 .891 r
F P
0 g
s
.52412 .33888 m .52383 .33854 L .52313 .33676 L .672 .728 .891 r
F
.52614 .34462 m .52606 .34464 L .52618 .34458 L F
.52616 .3446 m .52617 .34455 L .52613 .34464 L F
.52639 .34467 m .52635 .34467 L .52672 .34414 L F
.52592 .34465 m .52606 .34463 L .52604 .34462 L F
.52606 .34464 m .52586 .34468 L .52604 .34461 L F
.52602 .34459 m .52592 .34465 L .52588 .34461 L F
.52592 .34465 m .52587 .34464 L .52588 .34461 L F
.52604 .34461 m .52586 .34468 L .52602 .34459 L F
.52592 .34465 m .52608 .34467 L .52608 .34466 L F
.52592 .34465 m .52608 .34466 L .52607 .34466 L F
.52587 .34464 m .52487 .34392 L p .52609 .34467 L F P
0 g
s
.52487 .34392 m .5248 .34386 L p .52489 .34392 L .672 .728 .891 r
F P
0 g
s
.52487 .34392 m .52489 .34392 L .52609 .34467 L .672 .728 .891 r
F
.52545 .34427 m .52573 .34505 L .52593 .34446 L F
.52592 .34467 m .52592 .34485 L .52616 .34476 L F
.52661 .34476 m .52632 .34496 L .52609 .34467 L F
.52614 .34474 m .52625 .3447 L .52616 .34476 L F
.52625 .3447 m .52637 .34466 L .52627 .34471 L F
.52625 .3447 m .52627 .34471 L .52616 .34476 L F
.52604 .34462 m .52606 .34463 L .52681 .34441 L F
.52623 .3446 m .52614 .34462 L .52618 .34458 L F
.52611 .34462 m .52637 .34463 L .52629 .3446 L F
.52605 .34463 m .52607 .34466 L .52611 .34462 L F
.52722 .34439 m .52586 .34468 L .52721 .34439 L F
.52606 .34463 m .52636 .34468 L .5276 .34417 L F
.52592 .34467 m .52609 .34467 L .52606 .34463 L F
.52585 .34523 m .52578 .34533 L .52612 .34455 L F
.52592 .34467 m .52616 .34476 L .52609 .34467 L F
.5241 .34528 m .52423 .34483 L .52433 .34478 L F
.52404 .34492 m .52443 .34514 L .52557 .34498 L F
.52592 .34465 m .52514 .34516 L .52514 .34514 L F
.52592 .34465 m .52514 .34514 L .52592 .34485 L F
.52514 .34514 m .52514 .34516 L .52513 .34515 L F
.52531 .34532 m .52553 .34524 L .52549 .34524 L F
.52502 .34546 m .52538 .34532 L .52531 .34532 L F
.52506 .34581 m .52578 .34533 L p .52502 .34546 L F P
0 g
s
.52512 .34523 m .525 .34531 L .5251 .34526 L .672 .728 .891 r
F
.52459 .34629 m .51386 .35452 L p .5239 .3461 L F P
0 g
s
.51298 .35397 m .52506 .34581 L p .525 .34531 L .672 .728 .891 r
F P
0 g
s
.52578 .34533 m .52417 .34641 L p .52513 .34515 L .672 .728 .891 r
F P
0 g
s
.52417 .34641 m .51298 .35397 L p .52406 .34593 L .672 .728 .891 r
F P
0 g
s
.52417 .34641 m .52406 .34593 L .52513 .34515 L .672 .728 .891 r
F
.52179 .34551 m .52554 .34504 L .52539 .34501 L F
.52514 .34514 m .52518 .34515 L .52592 .34485 L F
.52509 .34505 m .52542 .34495 L .52542 .34495 L F
.52404 .34492 m .52535 .34488 L .52515 .34478 L F
.52456 .34521 m .5241 .34528 L p .52464 .34513 L F P
0 g
s
.52399 .34526 m .52451 .34519 L .52451 .34519 L .672 .728 .891 r
F
.52118 .34569 m .50856 .34749 L p .52276 .34497 L F P
0 g
s
.51033 .34718 m .51049 .34722 L .52122 .34568 L .672 .728 .891 r
F
.51049 .34722 m .5241 .34528 L p .52122 .34568 L F P
0 g
s
.52447 .34514 m .52303 .34528 L p .52418 .34502 L .672 .728 .891 r
F P
0 g
s
.52357 .34523 m .52459 .34513 L p .52309 .34515 L .672 .728 .891 r
F P
0 g
s
.52309 .34515 m .52459 .34513 L .52451 .34502 L .672 .728 .891 r
F
.5241 .34528 m .52273 .34547 L p .52423 .34483 L F P
0 g
s
.52433 .34478 m .52118 .34569 L .52182 .3454 L .672 .728 .891 r
F
.52273 .34547 m .52118 .34569 L p .52433 .34478 L F P
0 g
s
.51033 .34718 m .5241 .34528 L .52399 .34526 L .672 .728 .891 r
F
.52404 .34492 m .52557 .34498 L .52535 .34488 L F
.52404 .34492 m .51377 .34661 L .52443 .34514 L F
.52179 .34551 m .522 .34554 L .52554 .34504 L F
.51377 .34661 m .51418 .34664 L .522 .34554 L F
.51377 .34661 m .522 .34554 L .52179 .34551 L F
.52394 .34541 m .5081 .34839 L p .52361 .34515 L F P
0 g
s
.52425 .34529 m .52361 .34515 L .52571 .34471 L .672 .728 .891 r
F
.52394 .34541 m .52361 .34515 L .52425 .34529 L F
.52616 .34507 m .52613 .34509 L .52596 .34479 L F
.52616 .34507 m .52596 .34479 L .52598 .34476 L F
.5262 .34523 m .52595 .34499 L .526 .34485 L F
.52588 .34536 m .52623 .34608 L .52579 .34535 L F
.52581 .34531 m .52651 .34757 L .52608 .3457 L F
.52581 .34533 m .52638 .34594 L .52595 .34576 L F
.52572 .34504 m .52586 .34522 L .52581 .34533 L F
.52591 .34524 m .52583 .34529 L p .52586 .34524 L F P
0 g
s
.52583 .34529 m .52584 .34526 L .52586 .34524 L .672 .728 .891 r
F
.52586 .34522 m .52638 .34594 L .52581 .34533 L F
.52583 .34529 m .52578 .34533 L p .52584 .34526 L F P
0 g
s
.52623 .34544 m .52608 .3454 L .52607 .34565 L .672 .728 .891 r
F
.52593 .34512 m .52638 .34594 L .52572 .34504 L F
.526 .34572 m .52613 .34459 L .52596 .34493 L F
.52519 .34515 m .52586 .34512 L .52596 .34493 L F
.52573 .34505 m .5258 .34524 L .52595 .34482 L F
.5258 .34524 m .526 .34572 L .52596 .34493 L F
.5258 .34524 m .52596 .34493 L .52595 .34482 L F
.52519 .34515 m .52566 .34522 L .52586 .34512 L F
.52558 .34499 m .52694 .34484 L .52689 .34483 L F
.52628 .34491 m .5263 .34493 L .52691 .34485 L F
.52631 .34495 m .5269 .34487 L .5263 .34493 L F
.52627 .3447 m .5267 .34524 L .52642 .34474 L F
.52628 .34491 m .52691 .34485 L .52691 .34485 L F
.52642 .34474 m .52686 .34512 L .52655 .34476 L F
.5263 .34493 m .5269 .34487 L .52691 .34485 L F
.52706 .34488 m .52661 .34478 L .5279 .34575 L F
.52743 .3452 m .52632 .34496 L .52661 .34476 L F
.527 .34485 m .52677 .34476 L .52677 .34476 L F
.52699 .34487 m .52674 .34468 L .52673 .34481 L F
.52684 .34486 m .5264 .34467 L .52722 .34439 L F
.52694 .34482 m .52661 .34476 L .52675 .34467 L F
.52691 .34485 m .52691 .34485 L .52694 .34484 L F
.5269 .34487 m .52707 .34484 L .52691 .34485 L F
.52743 .3452 m .52661 .34476 L .52694 .34482 L F
.52684 .34486 m .52632 .34496 L p .52639 .34473 L F P
0 g
s
.52661 .34476 m .52639 .34473 L .5264 .34467 L .672 .728 .891 r
F
.52684 .34486 m .52639 .34473 L .52661 .34476 L F
.52596 .34493 m .52586 .34512 L .52629 .34492 L F
.52596 .34493 m .52629 .34492 L .52623 .34485 L F
.52607 .34524 m .52616 .3446 L .52606 .34524 L F
.52632 .34496 m .52675 .3447 L p .52566 .34522 L F P
0 g
s
.52632 .34496 m .52616 .34476 L .5264 .34467 L .672 .728 .891 r
F
.5264 .34467 m .52637 .34466 L .52722 .34439 L F
.52519 .34515 m .52675 .3447 L .52679 .34451 L F
.52514 .34514 m .52504 .34521 L .52518 .34515 L F
.52576 .34507 m .5255 .34498 L .52616 .34476 L F
.52462 .34528 m .52471 .34517 L .52542 .34495 L F
.52547 .34497 m .52542 .34495 L .52599 .34477 L F
.52462 .34528 m .52542 .34495 L .52547 .34497 L F
.52613 .34473 m .52718 .3444 L .52718 .34441 L F
.52542 .34495 m .52613 .34473 L .52613 .34473 L F
.52613 .34473 m .52718 .3444 L .52613 .34473 L F
.52616 .34476 m .52637 .34466 L .5264 .34467 L F
.52616 .34476 m .52765 .34417 L .5276 .34417 L F
.52542 .34495 m .526 .34477 L .52542 .34495 L F
.526 .34477 m .52718 .3444 L .526 .34477 L F
.526 .34477 m .526 .34477 L .52542 .34495 L F
.52592 .34467 m .52587 .34464 L p .52609 .34467 L F P
0 g
s
.52613 .34459 m .52614 .34454 L .52606 .3447 L .672 .728 .891 r
F
.52609 .34467 m .52606 .3447 L .52596 .34493 L F
.52542 .34495 m .52614 .34462 L .526 .34477 L F
.526 .34477 m .52614 .34462 L .52718 .3444 L F
.52609 .34467 m .52636 .34468 L .52606 .34463 L F
.52613 .34459 m .52606 .3447 L .52609 .34467 L F
.52542 .34495 m .52571 .34471 L .52614 .34462 L F
.52509 .34505 m .52533 .34492 L .52542 .34495 L F
.52533 .34492 m .52571 .34471 L .52542 .34495 L F
.52509 .34505 m .52542 .34495 L .52509 .34505 L F
.52596 .34493 m .52606 .3447 L .52595 .34482 L F
.52542 .34495 m .52718 .3444 L .52542 .34495 L F
.52542 .34495 m .52542 .34495 L .52509 .34505 L F
.52642 .34532 m .52634 .34531 L .52631 .34525 L F
.52606 .34464 m .52604 .34461 L .52615 .34457 L F
.52595 .34482 m .52614 .34454 L .52593 .34446 L F
.52606 .3447 m .52614 .34454 L .52595 .34482 L F
.52518 .34515 m .52616 .34476 L .52616 .34476 L F
.52519 .34515 m .52616 .34476 L .52518 .34515 L F
.5255 .34498 m .52614 .34474 L .52616 .34476 L F
.52523 .34507 m .52549 .34498 L .5255 .34498 L F
.52549 .34498 m .52614 .34474 L .5255 .34498 L F
.52613 .34452 m .52613 .34459 L .52616 .34453 L F
.52613 .34464 m .52617 .34455 L .52614 .34454 L F
.52616 .34453 m .52613 .34459 L .52625 .34455 L F
.52613 .34452 m .52616 .34453 L .52617 .34451 L F
.52617 .34455 m .52615 .34456 L .52386 .33864 L F
.52387 .33865 m .52386 .33864 L .52313 .33676 L F
.52617 .34455 m .52386 .33864 L .52387 .33865 L F
.52617 .34451 m .52625 .34455 L .52755 .34417 L F
.52614 .34454 m .52616 .34454 L .52614 .34448 L F
.52617 .34455 m .52616 .34453 L p .52616 .34454 L F P
0 g
s
.52616 .34453 m .52614 .34448 L p .52616 .34454 L .672 .728 .891 r
F P
0 g
s
.52616 .34453 m .52625 .34455 L .52617 .34451 L .672 .728 .891 r
F
.52614 .34454 m .52614 .34448 L .52593 .34446 L F
.52624 .34454 m .52616 .34456 L .52591 .34445 L F
.52675 .34467 m .52616 .34456 L .52624 .34454 L F
.52675 .34467 m .52661 .34476 L .52616 .34456 L F
.52521 .34507 m .52548 .34497 L .52523 .34507 L F
.52548 .34497 m .52637 .34466 L .52549 .34498 L F
.52548 .34497 m .52549 .34498 L .52523 .34507 L F
.52557 .34354 m .52554 .34353 L .52418 .34011 L F
.52418 .33946 m .52408 .3393 L .52313 .33676 L F
.52504 .3421 m .52503 .3421 L .52499 .34198 L F
.52502 .342 m .52499 .34198 L .52384 .33901 L F
.52562 .34349 m .52561 .34349 L .52384 .33901 L F
.52421 .33997 m .52517 .34244 L .52418 .34011 L F
.52517 .34244 m .52507 .3423 L .52418 .34011 L F
.52557 .34359 m .52538 .34366 L .5252 .34337 L F
.52418 .34011 m .52541 .34319 L .5252 .34337 L F
.52384 .33901 m .52421 .33997 L .52418 .34011 L F
.52313 .33676 m .52395 .33894 L .52384 .33901 L F
.52179 .33245 m .52329 .33659 L p .52313 .33676 L F P
0 g
s
.52589 .34379 m .52179 .33245 L p .52508 .34349 L .672 .728 .891 r
F P
0 g
s
.52476 .34162 m .52613 .34454 L p .52469 .34154 L .672 .728 .891 r
F P
0 g
s
.52623 .34485 m .52629 .34492 L .52675 .3447 L .672 .728 .891 r
F
.52616 .34476 m .52765 .34417 L .52616 .34476 L F
.52681 .3444 m .52681 .34441 L .5271 .34432 L F
.52632 .34496 m .52626 .34488 L .52664 .34456 L F
.52674 .34457 m .52664 .34456 L .52757 .34379 L F
.52632 .34496 m .52654 .34469 L .52661 .34469 L F
.52609 .34467 m .52616 .34476 L .52636 .34468 L F
.52618 .34479 m .52617 .34478 L .52633 .34466 L F
.52576 .34507 m .52589 .34511 L .52585 .34524 L F
.52632 .34496 m .52576 .34507 L p .52616 .34476 L F P
0 g
s
.52578 .34528 m .52563 .34524 L .5262 .34481 L .672 .728 .891 r
F
.52626 .34488 m .5262 .34481 L .52639 .34467 L F
.5261 .34476 m .52608 .34475 L .52637 .34466 L F
.52635 .34742 m .52632 .34496 L .52634 .34741 L F
.52604 .3447 m .52691 .34694 L .52602 .34472 L F
.52691 .34694 m .52699 .34713 L .52691 .34694 L F
.52691 .34694 m .52691 .34694 L .52602 .34472 L F
.52718 .34441 m .52718 .3444 L .52722 .34439 L F
.52615 .34457 m .52931 .34423 L .52923 .34421 L F
.52732 .34437 m .52722 .34439 L .52721 .34439 L F
.52675 .3447 m .52765 .34417 L p .52679 .34451 L F P
0 g
s
.52592 .34447 m .52595 .3445 L .52597 .34433 L .672 .728 .891 r
F
.52593 .34446 m .52614 .34448 L .52593 .34445 L F
.52675 .34467 m .52591 .34445 L .52608 .34416 L F
.52675 .34467 m .52608 .34416 L .52657 .34469 L F
.52675 .34467 m .52657 .34469 L .52673 .3447 L F
.52708 .34451 m .52632 .34496 L p .52678 .34453 L F P
0 g
s
.52653 .34453 m .52652 .34453 L .52673 .3443 L .672 .728 .891 r
F
.52592 .34465 m .5276 .34417 L .52755 .34417 L F
.52708 .34451 m .52678 .34453 L .52722 .34412 L F
.52711 .34431 m .5271 .34432 L .5276 .34417 L F
.52672 .34414 m .52755 .34417 L .52775 .34411 L F
.52765 .34417 m .52708 .34451 L p .52722 .34412 L F P
0 g
s
.52958 .34384 m .52899 .34397 L .52961 .34403 L .672 .728 .891 r
F
.52899 .34397 m .52717 .34435 L .52961 .34403 L F
.52717 .34435 m .5261 .34458 L .52734 .34438 L F
.52717 .34435 m .52734 .34438 L .52961 .34403 L F
.52608 .34416 m .52652 .34468 L .52657 .34469 L F
.52661 .34469 m .52664 .34456 L .52674 .34457 L F
.52654 .34469 m .52664 .34456 L .52661 .34469 L F
.52585 .34524 m .52632 .34496 L p .52566 .34522 L F P
0 g
s
.52612 .345 m .52632 .34496 L p .52621 .34492 L .672 .728 .891 r
F P
0 g
s
.52594 .34481 m .52612 .345 L .52621 .34492 L .672 .728 .891 r
F
.52576 .34507 m .52612 .345 L p .52594 .34481 L F P
0 g
s
.52585 .34522 m .5262 .34481 L .52626 .34488 L .672 .728 .891 r
F
.52545 .34439 m .52585 .34524 L .5258 .34524 L F
.52578 .34528 m .52587 .34519 L .52585 .34522 L F
.52587 .34519 m .5262 .34481 L .52585 .34522 L F
.52597 .3448 m .52599 .34477 L .52608 .34475 L F
.52597 .34477 m .52632 .34496 L .52618 .34478 L F
.52592 .34465 m .52586 .34468 L .52587 .34464 L F
.52573 .34505 m .52595 .34482 L .52593 .34446 L F
.52595 .3448 m .5259 .34487 L .52523 .3436 L F
.52577 .34475 m .52594 .34481 L .52597 .34477 L F
.52594 .34481 m .52632 .34496 L .52597 .34477 L F
.52628 .34502 m .52627 .34502 L .52608 .34462 L F
.52661 .34476 m .52609 .34467 L .52591 .34445 L F
.52614 .34448 m .52589 .34379 L p .52593 .34445 L F P
0 g
s
.52576 .34409 m .52581 .34433 L .52632 .3447 L .672 .728 .891 r
F
.52597 .3448 m .52608 .34475 L .5261 .34476 L F
.52592 .34502 m .52618 .34479 L .5262 .34481 L F
.52631 .34525 m .52615 .34519 L .52615 .34519 L F
.52594 .34497 m .52633 .34466 L .52592 .34502 L F
.52594 .34497 m .52596 .34493 L .52617 .34478 L F
.52646 .34468 m .52604 .34428 L .52637 .34467 L F
.52608 .34416 m .52586 .34411 L .52654 .34475 L F
.52664 .34435 m .52628 .34466 L .52609 .34457 L F
.52628 .34466 m .52616 .34476 L .52612 .34464 L F
.52581 .34433 m .52606 .34464 L .52632 .3447 L F
.52628 .34466 m .52612 .34464 L .52609 .34457 L F
.52737 .34444 m .52745 .34445 L .52931 .34423 L F
.52923 .34421 m .52931 .34423 L .53271 .34381 L F
.54488 .34232 m .5446 .34152 L p .53321 .3434 L F P
0 g
s
.53321 .3434 m .53416 .34358 L .54488 .34232 L .672 .728 .891 r
F
.52761 .34447 m .52665 .34483 L .54488 .34232 L F
.54397 .34162 m .5279 .34466 L .52732 .34437 L F
.5446 .34152 m .5437 .34169 L p .54397 .34162 L F P
0 g
s
.5437 .34169 m .5279 .34466 L p .54397 .34162 L .672 .728 .891 r
F P
0 g
s
.52961 .34403 m .52734 .34438 L .52966 .34433 L .672 .728 .891 r
F
.52744 .34443 m .52722 .34439 L .52732 .34437 L F
.52734 .34438 m .5261 .34458 L .52775 .34446 L F
.52734 .34438 m .52775 .34446 L .52966 .34433 L F
.52616 .34476 m .52606 .34464 L .52609 .34456 L F
.52609 .34459 m .52606 .34464 L .52785 .34449 L F
.52607 .34462 m .52604 .34455 L .52608 .34462 L F
.52604 .34462 m .5271 .34432 L .52711 .34431 L F
.5265 .34468 m .52639 .34467 L .52757 .34379 L F
.52652 .34468 m .52654 .34475 L .52659 .34477 L F
.52608 .34416 m .52648 .34468 L .52652 .34468 L F
.52648 .34468 m .52654 .34475 L .52652 .34468 L F
.52604 .34462 m .52681 .34441 L .52681 .3444 L F
.52718 .34407 m .52633 .34466 L .52698 .34406 L F
.52633 .34466 m .52596 .34493 L .52628 .34466 L F
.52633 .34466 m .52628 .34466 L .52698 .34406 L F
.5261 .34458 m .52609 .34459 L .52777 .34447 L F
.52775 .34446 m .52777 .34447 L .52966 .34433 L F
.52891 .34471 m .52859 .34471 L .52862 .34466 L F
.52714 .34488 m .54509 .34313 L p .52718 .34478 L F P
0 g
s
.52685 .34483 m .5281 .34468 L .52683 .34483 L .672 .728 .891 r
F
.5279 .34466 m .52684 .34486 L p .52722 .34439 L F P
0 g
s
.5261 .34458 m .52777 .34447 L .52775 .34446 L .672 .728 .891 r
F
.52717 .34563 m .52804 .34658 L .52787 .34633 L F
.5261 .34469 m .52628 .34469 L .52623 .34468 L F
.52611 .3447 m .52628 .34469 L .5261 .34469 L F
.5262 .34481 m .52633 .34466 L .52639 .34467 L F
.52618 .34479 m .52633 .34466 L .5262 .34481 L F
.52638 .3448 m .52645 .34491 L .52667 .34483 L F
.52618 .34478 m .52645 .34491 L .52638 .3448 L F
.52618 .34478 m .52632 .34496 L .52645 .34491 L F
.52606 .34464 m .52611 .34469 L .52623 .34468 L F
.52606 .34464 m .5261 .34469 L .52611 .34469 L F
.52632 .3447 m .52606 .34464 L .52665 .34524 L F
.52613 .34472 m .52607 .34462 L .52608 .34462 L F
.52608 .34416 m .52591 .34445 L .52502 .34334 L F
.52604 .34428 m .5252 .34348 L .52601 .34437 L F
.52612 .34471 m .52595 .34451 L .52549 .34353 L F
.52576 .34409 m .52559 .34405 L .52581 .34433 L F
.52602 .3447 m .52595 .3448 L .52554 .34399 L F
.52179 .33245 m .52061 .33267 L p .52502 .34334 L F P
0 g
s
.52502 .34334 m .52503 .34333 L .52179 .33245 L .672 .728 .891 r
F
.52582 .34433 m .52554 .34399 L .52416 .34126 L F
.52602 .3447 m .52554 .34399 L .52582 .34433 L F
.52595 .3448 m .52598 .34486 L .5259 .34487 L F
.52598 .34486 m .52594 .34497 L .5259 .34487 L F
.52596 .34493 m .52581 .34503 L .52609 .34456 L F
.52545 .34439 m .5259 .34508 L .52589 .34511 L F
.52509 .34569 m .52585 .34524 L p .52504 .34521 L F P
0 g
s
.52504 .34521 m .52585 .34524 L .52519 .34515 L .672 .728 .891 r
F
.52627 .34502 m .52612 .34471 L .52613 .34472 L F
.52602 .3447 m .52611 .3447 L .5261 .34469 L F
.52601 .34472 m .52628 .34469 L .52602 .3447 L F
.52597 .34477 m .52618 .34478 L .526 .34472 L F
.52618 .34478 m .52614 .34474 L .526 .34472 L F
.526 .34472 m .52614 .34474 L .52612 .34471 L F
.52601 .34472 m .526 .34472 L .52628 .34469 L F
.52616 .34476 m .52596 .34493 L .52606 .34464 L F
.52627 .34502 m .52623 .34508 L .52595 .34451 L F
.52627 .34502 m .52595 .34451 L .52612 .34471 L F
.52628 .34502 m .52607 .34461 L .52607 .34461 L F
.52607 .34461 m .52607 .34461 L .52605 .34456 L F
.52577 .34475 m .52597 .34477 L .526 .34472 L F
.52581 .34503 m .52588 .34473 L .52609 .34456 L F
.52602 .34459 m .52606 .34464 L .52609 .34459 L F
.52632 .34496 m .52665 .34524 L p .52606 .34464 L F P
0 g
s
.52626 .34488 m .52639 .34467 L .5265 .34468 L .672 .728 .891 r
F
.52612 .34471 m .52693 .34485 L .52628 .34469 L F
.52632 .34497 m .52608 .3446 L .52612 .34455 L F
.52648 .3453 m .5263 .34499 L .52632 .34497 L F
.5263 .34499 m .52608 .3446 L .52632 .34497 L F
.52735 .34556 m .52708 .34547 L .52731 .34577 L F
.52736 .34553 m .52708 .34547 L .52735 .34556 L F
.52668 .34526 m .52731 .34577 L p .52674 .34516 L F P
0 g
s
.52734 .3455 m .52732 .3455 L .52736 .34553 L .672 .728 .891 r
F
.52731 .34577 m .5289 .34708 L p .52743 .3452 L F P
0 g
s
.52785 .34619 m .52633 .34495 L .52806 .34582 L .672 .728 .891 r
F
.52606 .34464 m .52596 .34463 L .52632 .34496 L F
.52633 .34495 m .52626 .34488 L .52639 .34487 L F
.52626 .34488 m .52599 .34467 L .52615 .34475 L F
.52613 .34454 m .52648 .3453 L p .52612 .34455 L F P
0 g
s
.52626 .34488 m .52615 .34475 L .52639 .34487 L .672 .728 .891 r
F
.52628 .34502 m .5264 .34528 L .52627 .34502 L F
.52648 .3453 m .5264 .34528 L .52608 .3446 L F
.5264 .34528 m .52631 .34525 L .52623 .34508 L F
.5264 .34528 m .52623 .34508 L .52627 .34502 L F
.52642 .34532 m .52631 .34525 L .5264 .34528 L F
.5264 .34528 m .52642 .34532 L .5264 .34528 L F
.52629 .34534 m .52645 .34533 L .52607 .34524 L F
.52627 .34536 m .52732 .348 L .5261 .34533 L F
.52631 .34543 m .52645 .34533 L .52605 .34536 L F
.52634 .34537 m .52699 .34711 L .52631 .34537 L F
.52678 .34623 m .52645 .34533 L p .52638 .34539 L F P
0 g
s
.526 .34572 m .52678 .34623 L .52638 .34539 L .672 .728 .891 r
F
.52699 .34713 m .52712 .34748 L .52698 .34714 L F
.52699 .34713 m .52698 .34714 L .52602 .34472 L F
.52712 .34748 m .52732 .348 L .52712 .34748 L F
.52712 .34748 m .52712 .34748 L .52698 .34715 L F
.52698 .34714 m .52698 .34715 L .52602 .34472 L F
.52712 .34748 m .52698 .34715 L .52698 .34714 L F
.52594 .34497 m .52617 .34478 L .52618 .34479 L F
.52425 .34095 m .52596 .34452 L .52416 .34126 L F
.52596 .34452 m .52631 .34525 L .52591 .3445 L F
.52596 .34452 m .52591 .3445 L .52416 .34126 L F
.52542 .34431 m .52573 .34505 L .52545 .34427 L F
.52545 .34439 m .52589 .34511 L .52576 .34507 L F
.52483 .34485 m .52385 .34505 L .52573 .34507 L F
.5241 .34528 m .52574 .34504 L p .52399 .34526 L F P
0 g
s
.52462 .34528 m .52521 .34507 L .52523 .34507 L .672 .728 .891 r
F
.52591 .34505 m .5259 .34508 L .52545 .34438 L F
.52399 .34526 m .52574 .34504 L .52576 .34503 L F
.52469 .34535 m .52492 .34502 L .5259 .34477 L F
.52605 .34516 m .52597 .34513 L .52547 .34433 L F
.52583 .34497 m .52583 .34497 L .52545 .34439 L F
.52577 .34475 m .52576 .34507 L .52594 .34481 L F
.52462 .34528 m .52599 .34477 L .52597 .3448 L F
.52513 .34482 m .52559 .34502 L .52577 .34475 L F
.52559 .34502 m .52573 .34507 L .52577 .34475 L F
.52504 .34521 m .52519 .34515 L .52518 .34515 L F
.52576 .34507 m .52462 .34528 L p .5255 .34498 L F P
0 g
s
.52566 .34506 m .52573 .34507 L .52513 .34482 L .672 .728 .891 r
F
.51298 .35397 m .51223 .35343 L p .52061 .34806 L F P
0 g
s
.52513 .34515 m .52033 .34863 L .52061 .34806 L .672 .728 .891 r
F
.52033 .34863 m .51298 .35397 L .52061 .34806 L F
.52504 .34521 m .52333 .34629 L .52506 .34537 L F
.52513 .34515 m .51223 .35343 L .51262 .35308 L F
.52333 .34629 m .51215 .35337 L .52506 .34537 L F
.51215 .35337 m .52509 .34569 L p .52506 .34537 L F P
0 g
s
.5259 .34466 m .52372 .34651 L .52337 .34631 L .672 .728 .891 r
F
.5259 .34466 m .52337 .34631 L .52363 .34593 L F
.52394 .34541 m .52509 .34505 L .52509 .34505 L F
.52394 .34541 m .5249 .34503 L .52509 .34505 L F
.52462 .34528 m .52394 .34541 L p .52471 .34517 L F P
0 g
s
.52394 .34541 m .52573 .34507 L p .52385 .34505 L .672 .728 .891 r
F P
0 g
s
.52588 .34473 m .52372 .34651 L .5259 .34466 L .672 .728 .891 r
F
.52628 .34502 m .52605 .34456 L .52605 .34456 L F
.52606 .34456 m .52628 .34502 L .52605 .34456 L F
.52614 .34474 m .52693 .34485 L .52612 .34471 L F
.52618 .34478 m .52693 .34485 L .52614 .34474 L F
.52632 .34496 m .52615 .3446 L p .52611 .34471 L F P
0 g
s
.52627 .3449 m .52633 .34495 L .52627 .3449 L .672 .728 .891 r
F
.52573 .34507 m .52576 .34507 L p .52577 .34475 L F P
0 g
s
.52581 .34503 m .52482 .34573 L .52588 .34473 L .672 .728 .891 r
F
.52482 .34573 m .52491 .34553 L .52588 .34473 L F
.52632 .34496 m .52585 .34524 L p .52626 .34488 L F P
0 g
s
.52622 .34509 m .52615 .34519 L .52598 .34486 L .672 .728 .891 r
F
.52599 .34484 m .52598 .34486 L .52595 .3448 L F
.52622 .34509 m .52598 .34486 L .52599 .34484 L F
.5258 .34524 m .52585 .34524 L .52583 .3453 L F
.52585 .34524 m .52578 .34528 L p .52585 .34522 L F P
0 g
s
.52585 .34524 m .52585 .34522 L .52626 .34488 L .672 .728 .891 r
F
.5264 .34528 m .5264 .34528 L .52605 .34456 L F
.52605 .34456 m .52605 .34456 L .52264 .33758 L F
.5264 .34528 m .52605 .34456 L .52605 .34456 L F
.5259 .34487 m .52587 .34491 L .52547 .34433 L F
.52509 .34474 m .52515 .34478 L .52608 .34466 L F
.52586 .34468 m .52454 .34495 L .52588 .34461 L F
.52602 .34459 m .52508 .34479 L .52602 .3447 L F
.52606 .34464 m .52602 .3447 L .5261 .34469 L F
.52602 .34459 m .52602 .3447 L .52606 .34464 L F
.52565 .3444 m .5259 .34487 L .52547 .34433 L F
.5259 .34487 m .52605 .34516 L .52587 .34491 L F
.52609 .34456 m .52588 .34473 L .5259 .34466 L F
.52581 .34433 m .52587 .34459 L .52606 .34464 L F
.52602 .34459 m .52596 .34463 L .52603 .3446 L F
.52608 .34416 m .5252 .34348 L .52586 .34411 L F
.52612 .34471 m .52549 .34353 L .52554 .34356 L F
.52602 .34459 m .52603 .3446 L .52611 .34457 L F
.5261 .34458 m .52602 .34459 L .52609 .34459 L F
.5261 .34458 m .52603 .3446 L .52602 .34459 L F
.52603 .3446 m .52594 .34463 L .52602 .34459 L F
.52716 .34435 m .52612 .34459 L .5261 .34458 L F
.52612 .34459 m .52594 .34463 L .5261 .34458 L F
.52598 .34486 m .5262 .34529 L .52594 .34497 L F
.52477 .34588 m .52594 .34497 L .52592 .34502 L F
.52477 .34588 m .52596 .34493 L .52594 .34497 L F
.52599 .34467 m .52603 .34467 L .52639 .34487 L F
.52596 .34463 m .52596 .34464 L .52632 .34496 L F
.52627 .3449 m .52627 .3449 L .52591 .34462 L F
.52594 .34465 m .52632 .34496 L p .52594 .34463 L F P
0 g
s
.52591 .34462 m .52633 .34495 L .52632 .34496 L .672 .728 .891 r
F
.52587 .34459 m .52591 .34462 L p .52606 .34464 L F P
0 g
s
.52587 .34459 m .52587 .34459 L .52594 .34465 L .672 .728 .891 r
F
.52594 .34465 m .52594 .34465 L .5267 .34526 L F
.52605 .34516 m .52641 .34585 L .52597 .34513 L F
.52605 .34536 m .52629 .34534 L .52607 .34524 L F
.52601 .34565 m .52631 .34543 L .52605 .34536 L F
.52604 .34569 m .52645 .34533 L .52601 .34565 L F
.52601 .34564 m .52607 .34524 L .52606 .34524 L F
.5259 .34508 m .52641 .34585 L .52583 .3453 L F
.52616 .34589 m .52625 .34535 L .52613 .3453 L F
.52591 .34505 m .52641 .34585 L .5259 .34508 L F
.52583 .34497 m .52641 .34585 L .52583 .34497 L F
.526 .34572 m .52601 .34565 L .52601 .34564 L F
.526 .34572 m .52604 .34569 L .52601 .34565 L F
.52583 .3453 m .52641 .34585 L .526 .34572 L F
.52616 .34589 m .52601 .3448 L .52583 .34512 L F
.5258 .34519 m .52616 .34589 L .52583 .34512 L F
.52648 .3453 m .53196 .3571 L p .5264 .34528 L F P
0 g
s
.52642 .34532 m .53065 .35433 L .52634 .34531 L .672 .728 .891 r
F
.52699 .34711 m .52732 .348 L .52699 .34713 L F
.52699 .34711 m .52699 .34713 L .52605 .34472 L F
.52634 .34741 m .52633 .34601 L .52629 .34597 L F
.52623 .34608 m .52672 .34711 L .52604 .34653 L F
.52651 .34757 m .52624 .34552 L .52607 .34565 L F
.52651 .34757 m .52621 .34529 L .52621 .34529 L F
.52595 .34576 m .52732 .348 L .52651 .34757 L F
.52638 .34594 m .52732 .348 L .52595 .34576 L F
.52684 .34775 m .52794 .35041 L .52651 .34757 L F
.52732 .348 m .52794 .35041 L .52684 .34775 L F
.52732 .348 m .52903 .35258 L .52794 .35041 L F
.52635 .34799 m .52635 .34742 L .52634 .34741 L F
.52608 .34672 m .52704 .34815 L .52635 .34799 L F
.52651 .34757 m .52903 .35258 L .52763 .35115 L F
.52903 .35258 m .53079 .35731 L .52763 .35115 L F
.53079 .35731 m .52678 .34623 L p .526 .34572 L F P
0 g
s
.52631 .34525 m .52856 .34996 L .52615 .34519 L .672 .728 .891 r
F
.5262 .34529 m .52856 .34996 L .52611 .34528 L F
.526 .34572 m .52856 .34996 L .52729 .34885 L F
.52641 .34585 m .52856 .34996 L .526 .34572 L F
.52981 .35295 m .53065 .35433 L .53041 .35411 L F
.52981 .35295 m .53041 .35411 L .52893 .3528 L F
.52729 .34885 m .52981 .35295 L .52893 .3528 L F
.52856 .34996 m .53065 .35433 L .52729 .34885 L F
.53065 .35433 m .53196 .3571 L .52893 .3528 L F
.53196 .3571 m .52649 .34533 L p .52616 .34589 L F P
0 g
s
.52573 .34507 m .52682 .34583 L .52604 .34567 L .672 .728 .891 r
F
.52593 .34467 m .52505 .3449 L .52595 .34461 L F
.52622 .34509 m .52595 .3448 L .52602 .3447 L F
.5262 .34529 m .52611 .34528 L .52594 .34497 L F
.52616 .34589 m .52611 .34471 L .52601 .3448 L F
.52608 .34467 m .52595 .34491 L .52616 .34476 L F
.52686 .34512 m .52722 .34545 L .52692 .34501 L F
.5267 .34524 m .52632 .34496 L p .52743 .3452 L F P
0 g
s
.52673 .34485 m .52671 .34492 L .52736 .34553 L .672 .728 .891 r
F
.5269 .34489 m .52685 .34498 L .52732 .3455 L F
.52675 .34467 m .52732 .3455 L .52734 .3455 L F
.52743 .3452 m .52675 .34467 L .52736 .34553 L F
.52806 .34582 m .52683 .34512 L .52689 .34479 L F
.52646 .34468 m .52637 .34467 L .52731 .34577 L F
.52657 .34469 m .52671 .34492 L .52673 .34485 L F
.52652 .34468 m .52671 .34492 L .52657 .34469 L F
.52632 .34496 m .52693 .34485 L p .52667 .34483 L F P
0 g
s
.52659 .34477 m .52654 .34475 L .52671 .34492 L .672 .728 .891 r
F
.52679 .34482 m .52666 .34478 L .52685 .34498 L F
.52675 .34467 m .52685 .34498 L .5269 .34489 L F
.52604 .34428 m .52601 .34437 L .52698 .34542 L F
.52701 .34542 m .52698 .34542 L .52731 .34577 L F
.52604 .34428 m .52698 .34542 L .52701 .34542 L F
.52606 .34464 m .52623 .34468 L .52795 .3445 L F
.52785 .34449 m .52795 .3445 L .52966 .34433 L F
.52606 .34464 m .52795 .3445 L .52785 .34449 L F
.52239 .33861 m .5245 .3427 L .52251 .33757 L F
.5245 .3427 m .52472 .34263 L .52061 .33267 L F
.52061 .33267 m .51946 .33295 L p .52239 .33861 L F P
0 g
s
.52239 .33861 m .52251 .33757 L .52061 .33267 L .672 .728 .891 r
F
.52594 .34463 m .52593 .34463 L .52594 .34463 L F
.52593 .34463 m .52591 .34462 L .52594 .34463 L F
.52591 .34462 m .52594 .34465 L p .52594 .34463 L F P
0 g
s
.52591 .34461 m .52627 .3449 L .52591 .34462 L .672 .728 .891 r
F
.52552 .3444 m .52591 .34505 L .52545 .34438 L F
.52508 .34479 m .52601 .34472 L .52602 .3447 L F
.52596 .34463 m .52561 .34482 L .52595 .34472 L F
.52561 .34482 m .5251 .34511 L .52595 .34472 L F
.52595 .34472 m .5251 .34511 L .52594 .34492 L F
.52602 .34474 m .52523 .34494 L .52608 .34468 L F
.5249 .34503 m .52571 .34471 L .52509 .34505 L F
.52523 .34494 m .52517 .34493 L .52608 .34468 L F
.52483 .34485 m .52566 .34506 L .52513 .34482 L F
.5081 .34839 m .52394 .34541 L p .52385 .34505 L F P
0 g
s
.52357 .34536 m .52345 .34535 L .5244 .34511 L .672 .728 .891 r
F
.52449 .34511 m .5244 .34511 L .52608 .34468 L F
.52357 .34536 m .5244 .34511 L .52449 .34511 L F
.52334 .34534 m .5232 .34533 L .52595 .34461 L F
.52535 .34434 m .52538 .34439 L .52539 .34425 L F
.52454 .34495 m .5081 .34839 L .52456 .34483 L F
.50847 .34917 m .5081 .34839 L p .52276 .34529 L F P
0 g
s
.52509 .34474 m .52404 .34492 L .52515 .34478 L .672 .728 .891 r
F
.52588 .34461 m .52454 .34495 L .52456 .34483 L F
.52508 .34479 m .52483 .34485 L .52513 .34482 L F
.52595 .34461 m .5232 .34533 L .52276 .34529 L F
.5232 .34533 m .50847 .34917 L .52276 .34529 L F
.52554 .34399 m .52577 .34445 L .52523 .3436 L F
.52577 .34445 m .52573 .34443 L .52523 .3436 L F
.52507 .34394 m .52587 .34459 L p .52581 .34433 L F P
0 g
s
.52539 .34425 m .52542 .34431 L .52545 .34427 L .672 .728 .891 r
F
.52502 .34334 m .52508 .34349 L .52505 .34337 L F
.52502 .34334 m .52553 .34418 L .52545 .34439 L F
.52502 .34334 m .52505 .34337 L .52503 .34333 L F
.52475 .34268 m .52523 .3436 L .52502 .34334 L F
.52523 .3436 m .52553 .34418 L .52502 .34334 L F
.5252 .34348 m .52518 .34354 L .52576 .34409 L F
.52518 .34354 m .52507 .34394 L .52559 .34405 L F
.52518 .34354 m .52559 .34405 L .52576 .34409 L F
.52559 .34405 m .52507 .34394 L .52581 .34433 L F
.52591 .3446 m .5245 .34345 L .52538 .34379 L F
.52554 .34356 m .52549 .34353 L .52459 .34166 L F
.52461 .34169 m .52459 .34166 L .52441 .34129 L F
.52612 .34471 m .52459 .34166 L .52461 .34169 L F
.52472 .34185 m .52441 .34129 L .52448 .34135 L F
.52605 .34456 m .52462 .3417 L .52472 .34185 L F
.52462 .3417 m .52441 .34129 L .52472 .34185 L F
.52604 .34455 m .52441 .34129 L .52605 .34456 L F
.52605 .34456 m .52605 .34456 L .52264 .33758 L F
.52275 .33752 m .52606 .34456 L .52264 .33758 L F
.52606 .34456 m .52605 .34456 L .52264 .33758 L F
.52612 .34455 m .52608 .3446 L .52459 .34143 L F
.52466 .3415 m .52459 .34143 L .52208 .33608 L F
.52612 .34455 m .52459 .34143 L .52466 .3415 L F
.52211 .33613 m .52208 .33608 L .5216 .33507 L F
.52506 .34233 m .52208 .33608 L .52211 .33613 L F
.52612 .34455 m .52505 .34232 L .52506 .34233 L F
.52505 .34232 m .52208 .33608 L .52506 .34233 L F
.52762 .34598 m .52917 .34763 L .52917 .34763 L F
.52613 .34454 m .52612 .34455 L .52469 .34154 L F
.52169 .33499 m .52476 .34162 L p .5216 .33507 L F P
0 g
s
.52476 .34162 m .52469 .34154 L .5216 .33507 L .672 .728 .891 r
F
.52448 .34135 m .52441 .34129 L .52264 .33758 L F
.52484 .34261 m .52554 .34399 L .52475 .34268 L F
.52554 .34399 m .52523 .3436 L .52475 .34268 L F
.52264 .33758 m .52425 .34095 L .52416 .34126 L F
.5216 .33507 m .52275 .33752 L .52264 .33758 L F
.52061 .33267 m .52169 .33499 L p .5216 .33507 L F P
0 g
s
.52611 .34451 m .52061 .33267 L p .52516 .34352 L .672 .728 .891 r
F P
0 g
s
.52639 .34467 m .52633 .34466 L .52757 .34379 L .672 .728 .891 r
F
.52625 .34464 m .52621 .34462 L .52716 .34435 L F
.52632 .34466 m .52625 .34464 L .52723 .34439 L F
.52609 .34456 m .52653 .34468 L .52656 .34468 L F
.52716 .34435 m .52618 .34461 L .52612 .34459 L F
.52621 .34462 m .52714 .34436 L .52714 .34436 L F
.52621 .34462 m .52714 .34436 L .52621 .34462 L F
.52621 .34462 m .52618 .34461 L .52714 .34436 L F
.52609 .34456 m .52656 .34468 L .52686 .34443 L F
.52623 .34468 m .52628 .34469 L .52966 .34433 L F
.52673 .3447 m .52657 .34469 L .52666 .34478 L F
.52675 .34467 m .52666 .34478 L .52679 .34482 L F
.52678 .34477 m .52632 .34466 L .5271 .34447 L F
.52693 .34485 m .52966 .34433 L p .52628 .34469 L F P
0 g
s
.52684 .34475 m .52653 .34468 L .52677 .34469 L .672 .728 .891 r
F
.52673 .34482 m .5271 .34447 L .52692 .34475 L F
.52689 .34479 m .52684 .34478 L .52684 .34475 L F
.52684 .34478 m .52653 .34468 L .52684 .34475 L F
.52717 .34436 m .52625 .34464 L .52716 .34435 L F
.52723 .34439 m .52713 .34441 L .52717 .34436 L F
.52713 .34441 m .52625 .34464 L .52717 .34436 L F
.52729 .34442 m .52632 .34466 L .52723 .34439 L F
.52676 .34473 m .52759 .3443 L p .52686 .34443 L F P
0 g
s
.52729 .34442 m .52723 .34439 L .5283 .34411 L .672 .728 .891 r
F
.5283 .34411 m .52723 .34439 L .52716 .34435 L F
.52759 .3443 m .52684 .34469 L p .52763 .34414 L F P
0 g
s
.52656 .34468 m .52676 .34473 L .52677 .34469 L .672 .728 .891 r
F
.52674 .34474 m .52676 .34473 L p .52656 .34468 L F P
0 g
s
.52683 .34512 m .52601 .34466 L .52684 .34478 L .672 .728 .891 r
F
.52622 .34469 m .52612 .34472 L .5261 .34467 L F
.52612 .34471 m .52604 .34455 L .52613 .34472 L F
.52611 .34471 m .52611 .34464 L .52608 .34467 L F
.52612 .34472 m .52609 .34468 L .5261 .34467 L F
.52591 .34461 m .52591 .3446 L .52633 .34495 L F
.52596 .34467 m .52595 .34491 L .52608 .34467 L F
.52596 .34467 m .52594 .34492 L .52595 .34491 L F
.52611 .34471 m .52608 .34467 L .52579 .34501 L F
.52588 .34485 m .5259 .34477 L .52632 .34466 L F
.52608 .34467 m .52616 .34476 L .52628 .34467 L F
.52673 .34482 m .52649 .34473 L .52678 .34477 L F
.52632 .3447 m .52668 .34526 L .52674 .34516 L F
.52632 .34496 m .52632 .34466 L .52673 .34482 L F
.52632 .34496 m .52674 .34474 L p .52623 .34485 L F P
0 g
s
.52736 .34553 m .52646 .34468 L .52708 .34547 L .672 .728 .891 r
F
.52676 .34473 m .52632 .34496 L p .52667 .34472 L F P
0 g
s
.52613 .3453 m .52632 .34496 L .52611 .34471 L .672 .728 .891 r
F
.52576 .34525 m .52632 .34496 L p .5259 .34501 L F P
0 g
s
.52632 .34496 m .52592 .34517 L p .5263 .34494 L .672 .728 .891 r
F P
0 g
s
.52632 .3447 m .52665 .34524 L .52666 .34522 L .672 .728 .891 r
F
.52632 .34496 m .5263 .34494 L .52667 .34472 L F
.5259 .34501 m .52632 .34496 L .52595 .34492 L F
.5251 .34511 m .5259 .34501 L .52595 .34492 L F
.52583 .34512 m .52601 .3448 L .52579 .34501 L F
.52595 .34492 m .52632 .34496 L .52623 .34485 L F
.52632 .34496 m .5257 .34511 L p .52617 .34477 L F P
0 g
s
.52581 .34508 m .52632 .34496 L p .52588 .34492 L .672 .728 .891 r
F P
0 g
s
.52631 .34525 m .52615 .34519 L .52622 .34509 L .672 .728 .891 r
F
.52649 .34526 m .52615 .34518 L .52588 .34491 L F
.52508 .34479 m .52513 .34482 L .526 .34472 L F
.52505 .3449 m .52499 .34488 L .52595 .34461 L F
.52587 .34459 m .52594 .34465 L .52594 .34465 L F
.52546 .34503 m .5259 .34477 L .52588 .34485 L F
.52625 .34464 m .52608 .34468 L .52621 .34462 L F
.52508 .34479 m .52579 .34474 L .52582 .34473 L F
.52579 .34474 m .526 .34472 L .52582 .34473 L F
.52582 .34473 m .526 .34472 L .52601 .34472 L F
.52608 .34468 m .52532 .34487 L .5261 .34465 L F
.52611 .34471 m .52615 .3446 L .52613 .34462 L F
.52608 .34468 m .5261 .34465 L .52621 .34462 L F
.5251 .34511 m .52576 .34525 L .5259 .34501 L F
.5258 .34519 m .52583 .34512 L .52579 .34501 L F
.5257 .34511 m .52469 .34535 L p .52595 .34482 L F P
0 g
s
.52454 .3435 m .5245 .34345 L .52591 .3446 L .672 .728 .891 r
F
.52454 .3435 m .52591 .3446 L .52591 .34461 L F
.52454 .3435 m .52591 .34461 L .52591 .34462 L F
.52532 .34487 m .51784 .34678 L .52564 .34475 L F
.51784 .34678 m .50847 .34917 L .51767 .3468 L F
.51784 .34678 m .51767 .3468 L .52564 .34475 L F
.52682 .34583 m .52996 .35133 L p .52604 .34567 L F P
0 g
s
.52573 .34507 m .52574 .34506 L .5254 .34424 L .672 .728 .891 r
F
.5254 .34425 m .5254 .34424 L .52504 .34336 L F
.52551 .34457 m .52479 .34422 L p .52553 .34451 L F P
0 g
s
.52573 .34507 m .5254 .34424 L .5254 .34425 L .672 .728 .891 r
F
.52357 .34536 m .50847 .34917 L .52345 .34535 L F
.52505 .3449 m .52334 .34534 L .52499 .34488 L F
.52334 .34534 m .50847 .34917 L .5232 .34533 L F
.52469 .34535 m .5218 .34603 L p .52492 .34502 L F P
0 g
s
.5218 .34603 m .50847 .34917 L p .52121 .34596 L .672 .728 .891 r
F P
0 g
s
.5218 .34603 m .52121 .34596 L .52492 .34502 L .672 .728 .891 r
F
.52523 .34494 m .52357 .34536 L .52517 .34493 L F
.52515 .34557 m .52576 .34525 L p .5251 .34511 L F P
0 g
s
.52469 .34535 m .52539 .34501 L .52546 .34503 L .672 .728 .891 r
F
.52479 .34492 m .52445 .34529 L .52568 .3451 L F
.52553 .34504 m .52568 .3451 L .52581 .34508 L F
.52479 .34492 m .52568 .3451 L .52553 .34504 L F
.52477 .34588 m .52467 .34583 L .52596 .34493 L F
.52577 .34514 m .52579 .34501 L .52574 .34506 L F
.5258 .34519 m .52579 .34515 L .52577 .34514 L F
.52579 .34515 m .52579 .34501 L .52577 .34514 L F
.52363 .34593 m .52337 .34631 L .52315 .34619 L F
.52372 .34651 m .51215 .35337 L p .52315 .34619 L F P
0 g
s
.5251 .34511 m .51643 .34993 L .52515 .34557 L .672 .728 .891 r
F
.51138 .35274 m .519 .34877 L p .51643 .34993 L F P
0 g
s
.519 .34877 m .52515 .34557 L p .51643 .34993 L .672 .728 .891 r
F P
0 g
s
.52627 .3449 m .52633 .34495 L .52633 .34495 L .672 .728 .891 r
F
.52626 .34489 m .52633 .34495 L .52627 .3449 L F
.52632 .34496 m .52617 .34477 L .52628 .3447 L F
.52632 .34496 m .52672 .34527 L .5267 .34526 L F
.52633 .34495 m .52672 .34527 L .52632 .34496 L F
.52633 .34495 m .52633 .34495 L .52672 .34527 L F
.52665 .34524 m .52668 .34526 L p .52666 .34522 L F P
0 g
s
.52587 .34459 m .5267 .34526 L .52669 .34526 L .672 .728 .891 r
F
.52668 .34526 m .52587 .34459 L p .52669 .34526 L F P
0 g
s
.52632 .34496 m .52694 .34555 L p .52613 .34463 L .672 .728 .891 r
F P
0 g
s
.52694 .34555 m .52804 .34658 L p .52709 .34561 L .672 .728 .891 r
F P
0 g
s
.52622 .34469 m .5261 .34467 L .52625 .34464 L .672 .728 .891 r
F
.5261 .34465 m .52608 .34467 L .52628 .34467 L F
.53554 .35248 m .53518 .35219 L .53558 .35256 L F
.53462 .35073 m .53518 .35219 L .53554 .35248 L F
.53462 .35073 m .52898 .34638 L .53518 .35219 L F
.5289 .34708 m .53558 .35256 L p .52898 .34638 L F P
0 g
s
.53558 .35256 m .5383 .35479 L p .53462 .35073 L .672 .728 .891 r
F P
0 g
s
.53739 .354 m .52785 .34619 L .52806 .34582 L .672 .728 .891 r
F
.5267 .34526 m .52672 .34527 L .53739 .354 L F
.52669 .34526 m .5267 .34526 L .53739 .354 L F
.53657 .35337 m .52668 .34526 L p .53739 .354 L F P
0 g
s
.52668 .34526 m .52669 .34526 L .53739 .354 L .672 .728 .891 r
F
.52806 .34582 m .52689 .34479 L .52917 .34763 L F
.52683 .34512 m .52684 .34478 L .52689 .34479 L F
.52689 .34479 m .52682 .34491 L .52917 .34763 L F
.52777 .34447 m .52785 .34449 L .52966 .34433 L F
.52665 .34517 m .52694 .34555 L .52709 .34561 L F
.52663 .3452 m .52694 .34555 L .52665 .34517 L F
.52741 .34576 m .52762 .34598 L .52762 .34598 L F
.5264 .34467 m .52741 .34576 L .52741 .34576 L F
.52741 .34576 m .52762 .34598 L .52741 .34576 L F
.52687 .34483 m .52632 .34496 L p .52691 .34476 L F P
0 g
s
.52633 .34495 m .52639 .34487 L .52806 .34582 L .672 .728 .891 r
F
.52613 .34463 m .52663 .3452 L .52665 .34517 L F
.52619 .34465 m .52711 .34561 L .52619 .34465 L F
.52632 .34496 m .52687 .34483 L p .52622 .34484 L F P
0 g
s
.52632 .34471 m .52628 .3447 L .52632 .34466 L .672 .728 .891 r
F
.5257 .34511 m .52595 .34482 L .52632 .34466 L F
.52684 .34478 m .52651 .34472 L .52653 .34468 L F
.52689 .34479 m .52684 .34478 L .52684 .34478 L F
.52684 .34478 m .52651 .34472 L .52684 .34478 L F
.52755 .34417 m .5276 .34417 L .52775 .34411 L F
.52711 .3439 m .52673 .3443 L .52672 .34414 L F
.52711 .3439 m .52672 .34414 L .52775 .34411 L F
.52765 .34417 m .52727 .34407 L .52763 .34408 L F
.52698 .34406 m .52664 .34435 L .52609 .34456 L F
.52664 .34435 m .52609 .34457 L .52609 .34456 L F
.52714 .34436 m .52714 .34436 L .52716 .34435 L F
.52699 .34406 m .52609 .34456 L .52759 .3443 L F
.52684 .34461 m .52766 .34397 L .52763 .34414 L F
.52606 .34464 m .52613 .34462 L .52608 .34466 L F
.52613 .34462 m .52618 .34461 L .52611 .34464 L F
.52613 .34462 m .52611 .34464 L .52608 .34466 L F
.52613 .34462 m .52593 .34467 L .52615 .3446 L F
.52611 .34464 m .52614 .34457 L .52611 .34462 L F
.52611 .34471 m .52613 .34462 L .52611 .34464 L F
.52613 .34462 m .52614 .34457 L .52611 .34464 L F
.52606 .34464 m .52608 .34467 L .5261 .34465 L F
.52596 .34463 m .52608 .34467 L .52606 .34464 L F
.52608 .34466 m .52618 .34461 L .52621 .34462 L F
.52532 .34487 m .52606 .34464 L .52608 .34466 L F
.52611 .34464 m .52611 .34462 L .52608 .34467 L F
.52605 .34463 m .52593 .34467 L .52605 .34462 L F
.52603 .3446 m .52596 .34463 L .52606 .34464 L F
.52596 .34463 m .52594 .34463 L .52596 .34464 L F
.52612 .34459 m .52597 .34465 L .52594 .34463 L F
.52597 .34465 m .52593 .34467 L .52594 .34465 L F
.52597 .34465 m .52594 .34465 L .52594 .34463 L F
.52596 .34463 m .52596 .34467 L .52608 .34467 L F
.52599 .34467 m .52597 .34465 L .52603 .34467 L F
.52597 .34465 m .52591 .3446 L .52601 .34466 L F
.52597 .34465 m .52601 .34466 L .52603 .34467 L F
.52649 .34473 m .52632 .34466 L .52678 .34477 L F
.52601 .34466 m .52591 .3446 L .52689 .34479 L F
.52665 .34473 m .52656 .34478 L .52674 .34474 L F
.52628 .34467 m .52656 .34478 L .52665 .34473 L F
.52632 .34496 m .52628 .3447 L .52632 .34471 L F
.52628 .34467 m .52594 .34492 L .52656 .34478 L F
.52594 .34449 m .52611 .34451 L .52516 .34352 L F
.52594 .34449 m .52538 .34379 L .52604 .34404 L F
.52615 .3446 m .52605 .34463 L .52612 .34459 L F
.52615 .3446 m .52614 .34457 L p .52613 .34462 L F P
0 g
s
.52614 .34457 m .52611 .34451 L p .52611 .34462 L .672 .728 .891 r
F P
0 g
s
.52618 .34461 m .52613 .34462 L .52615 .3446 L .672 .728 .891 r
F
.52585 .34409 m .52558 .34404 L .52617 .34463 L F
.52651 .34472 m .52629 .34467 L .52653 .34468 L F
.52632 .34466 m .52628 .34467 L .52629 .34465 L F
.52628 .34467 m .52622 .34469 L .52629 .34465 L F
.52629 .34465 m .52622 .34469 L .52625 .34464 L F
.52608 .34462 m .52604 .34455 L .52605 .34456 L F
.52605 .34463 m .52605 .34462 L .52612 .34459 L F
.52603 .3446 m .52606 .34464 L .52674 .34474 L F
.52637 .34467 m .52617 .34478 L .52628 .34465 L F
.5258 .34508 m .52581 .34508 L .52588 .34492 L F
.52573 .34507 m .5258 .34519 L .52574 .34506 L F
.52454 .3435 m .52626 .34489 L .52627 .3449 L F
.52545 .34438 m .52583 .34497 L .52545 .34439 L F
.52587 .34459 m .52454 .3435 L p .52587 .34459 L F P
0 g
s
.52532 .34487 m .52564 .34475 L .52618 .34461 L .672 .728 .891 r
F
.52574 .34506 m .52579 .34501 L .52544 .34417 L F
.52538 .34439 m .52573 .34507 L .52541 .3443 L F
.5254 .34443 m .52593 .34496 L .52573 .34507 L F
.52509 .34485 m .5257 .34484 L .52574 .34479 L F
.52602 .34459 m .52594 .34463 L .52595 .34461 L F
.52532 .34487 m .52621 .34462 L .52621 .34462 L F
.52577 .34445 m .52595 .3448 L .52573 .34443 L F
.52579 .34501 m .52611 .34451 L .52555 .34445 L F
.52574 .34506 m .52544 .34417 L .52542 .34421 L F
.52609 .34456 m .52602 .34459 L .52611 .34457 L F
.52608 .34467 m .52611 .34451 L .52579 .34501 L F
.52574 .34479 m .5262 .34481 L .52616 .34476 L F
.52603 .34464 m .52596 .34486 L .52593 .34483 L F
.52602 .34464 m .52593 .34483 L .5254 .34443 L F
.52617 .34478 m .52614 .34474 L .52628 .34465 L F
.52612 .34472 m .52602 .34474 L .52609 .34468 L F
.52602 .34474 m .52608 .34468 L .5261 .34467 L F
.52604 .34461 m .52595 .34478 L .52616 .34476 L F
.52604 .34461 m .52616 .34476 L .52649 .34473 L F
.52597 .34485 m .52598 .34481 L .52613 .34472 L F
.52593 .34483 m .52588 .34491 L .5254 .34443 L F
.52601 .3446 m .52506 .34485 L .52595 .34478 L F
.52608 .34467 m .52509 .34497 L .52567 .34474 L F
.52509 .34497 m .525 .345 L .52508 .34497 L F
.52539 .34501 m .5259 .34477 L .52546 .34503 L F
.52509 .34485 m .5258 .34508 L .52588 .34492 L F
.52509 .34497 m .52508 .34497 L .52567 .34474 L F
.52597 .34485 m .52613 .34472 L .52614 .34474 L F
.52603 .34464 m .52593 .34483 L .52602 .34464 L F
.52601 .3446 m .52595 .34478 L .52604 .34461 L F
.52604 .34461 m .52567 .34474 L .52603 .3446 L F
.5257 .34484 m .52622 .34484 L .52574 .34479 L F
.52509 .34485 m .52632 .34496 L .52622 .34484 L F
.52593 .34484 m .52594 .34484 L .52598 .34481 L F
.52558 .34509 m .52594 .34484 L .52593 .34484 L F
.52558 .34509 m .52553 .34508 L .52594 .34484 L F
.52558 .34509 m .52598 .34481 L .52597 .34485 L F
.52517 .34488 m .52581 .34508 L .52509 .34485 L F
.52625 .34465 m .52578 .34493 L .52601 .34461 L F
.52578 .34493 m .52484 .34549 L .52587 .34471 L F
.52578 .34493 m .52587 .34471 L .52601 .34461 L F
.52547 .34433 m .52552 .3444 L .52545 .34438 L F
.52574 .34506 m .52516 .34352 L .52511 .34346 L F
.52591 .3446 m .52538 .34379 L .52594 .34449 L F
.52555 .34445 m .52594 .34449 L .52516 .34352 L F
.52558 .34404 m .52603 .34464 L .5254 .34443 L F
.52526 .34397 m .526 .34467 L p .52553 .34403 L F P
0 g
s
.52632 .34496 m .52649 .34526 L p .52603 .34464 L .672 .728 .891 r
F P
0 g
s
.52604 .34461 m .52603 .34464 L .52558 .34404 L .672 .728 .891 r
F
.52632 .34496 m .52603 .34464 L .52604 .34461 L F
.52622 .34484 m .5262 .34481 L .52574 .34479 L F
.52617 .34478 m .52595 .34489 L .52614 .34474 L F
.52595 .34489 m .52558 .34509 L .52597 .34485 L F
.52595 .34489 m .52597 .34485 L .52614 .34474 L F
.526 .34467 m .52632 .34496 L p .52601 .3446 L F P
0 g
s
.52601 .34465 m .526 .34467 L .526 .34467 L .672 .728 .891 r
F
.52553 .34403 m .526 .34467 L .52601 .3446 L F
.52603 .3446 m .52601 .34465 L .52608 .34467 L F
.52592 .34517 m .52617 .34478 L .52628 .34492 L F
.52603 .34464 m .52649 .34526 L .52596 .34486 L F
.52601 .34465 m .526 .34467 L .52608 .34467 L F
.526 .34467 m .52588 .34499 L .52608 .34467 L F
.52663 .34456 m .52591 .3446 L .52604 .34404 L F
.52608 .34467 m .52592 .34459 L .52596 .34451 L F
.52632 .34496 m .526 .34467 L p .52608 .34467 L F P
0 g
s
.52603 .3446 m .52512 .34504 L .52588 .34499 L .672 .728 .891 r
F
.52553 .34403 m .52632 .34496 L .52575 .34425 L F
.52608 .34467 m .52608 .34467 L .52604 .34461 L F
.526 .34467 m .526 .34466 L p .52608 .34467 L F P
0 g
s
.52153 .34609 m .52581 .34508 L p .52171 .34572 L .672 .728 .891 r
F P
0 g
s
.52601 .34461 m .52484 .34549 L .52481 .34549 L .672 .728 .891 r
F
.52502 .34509 m .52481 .34549 L .52441 .34539 L F
.52601 .34461 m .52481 .34549 L .52502 .34509 L F
.52608 .34467 m .52567 .34474 L .52592 .34465 L F
.52592 .34459 m .52591 .34458 L p .52596 .34451 L F P
0 g
s
.525 .345 m .52505 .3449 L .52603 .3446 L .672 .728 .891 r
F
.52593 .34496 m .52589 .34511 L .52573 .34507 L F
.52587 .34516 m .52558 .34509 L .52595 .34489 L F
.52535 .34447 m .52578 .34515 L .52596 .34451 L F
.52596 .34481 m .52479 .3454 L .52599 .3447 L F
.52578 .34515 m .52606 .34469 L .52583 .34497 L F
.52592 .34517 m .52587 .34516 L .52617 .34478 L F
.52593 .34496 m .52615 .34518 L .52589 .34511 L F
.52587 .34516 m .52595 .34489 L .52617 .34478 L F
.52592 .34517 m .5266 .34471 L .52667 .34472 L F
.52649 .34526 m .52588 .34491 L .52593 .34483 L F
.52649 .34533 m .52632 .34496 L p .52616 .34589 L F P
0 g
s
.52615 .34518 m .52682 .34583 L .52573 .34507 L .672 .728 .891 r
F
.52625 .34535 m .52632 .34496 L .52613 .3453 L F
.52649 .34526 m .52682 .34583 L p .52615 .34518 L F P
0 g
s
.52587 .34529 m .52658 .34558 L .52607 .3447 L .672 .728 .891 r
F
.52629 .34517 m .52587 .3451 L .52585 .34508 L F
.52578 .34515 m .52582 .34521 L .52607 .3447 L F
.52582 .34521 m .52588 .34525 L .52607 .3447 L F
.52558 .34509 m .52484 .34549 L .52553 .34508 L F
.52592 .34517 m .52462 .34585 L p .52558 .34509 L F P
0 g
s
.52462 .34585 m .52042 .34804 L p .52477 .34555 L .672 .728 .891 r
F P
0 g
s
.52462 .34585 m .52477 .34555 L .52558 .34509 L .672 .728 .891 r
F
.52582 .34521 m .52587 .34529 L .52588 .34525 L F
.52573 .34508 m .52589 .34519 L .52587 .34529 L F
.519 .34877 m .51941 .34842 L .52558 .34509 L F
.52441 .34539 m .52338 .34597 L .52284 .34615 L F
.52484 .34549 m .51138 .35274 L .52441 .34539 L F
.52512 .34504 m .52284 .34615 L .52489 .34561 L F
.52479 .3454 m .525 .345 L .52509 .34497 L F
.52506 .34485 m .52479 .34492 L .52581 .34508 L F
.52543 .34503 m .52509 .34497 L .52599 .3447 L F
.52489 .34561 m .52572 .34523 L p .52512 .34504 L F P
0 g
s
.52479 .3454 m .52509 .34497 L .52543 .34503 L .672 .728 .891 r
F
.52573 .34508 m .52551 .34504 L .52596 .34481 L F
.52536 .34446 m .52582 .34509 L .52535 .34447 L F
.52582 .34509 m .5262 .3456 L .52581 .34509 L F
.52582 .34509 m .52581 .34509 L .52535 .34447 L F
.52535 .34447 m .52581 .34509 L .52573 .34508 L F
.52588 .34499 m .52578 .34515 L .52632 .34496 L F
.52586 .34515 m .52589 .34519 L .52584 .34515 L F
.52572 .34523 m .52589 .34516 L p .52578 .34515 L F P
0 g
s
.52589 .34516 m .52632 .34496 L p .52578 .34515 L .672 .728 .891 r
F P
0 g
s
.52512 .34504 m .52572 .34523 L .52588 .34499 L .672 .728 .891 r
F
.52578 .34515 m .52607 .3447 L .52606 .34469 L F
.52461 .34512 m .52361 .34543 L .52445 .34529 L F
.52479 .34492 m .52361 .34543 L .52461 .34512 L F
.52479 .34492 m .52171 .34572 L .52361 .34543 L F
.50847 .34917 m .52153 .34609 L p .52171 .34572 L F P
0 g
s
.52479 .3454 m .51759 .34746 L p .525 .345 L .672 .728 .891 r
F P
0 g
s
.52191 .34622 m .52585 .3451 L p .52221 .34597 L .672 .728 .891 r
F P
0 g
s
.52581 .34509 m .52584 .34513 L .52573 .34508 L .672 .728 .891 r
F
.52585 .3451 m .52567 .34515 L p .52573 .34508 L F P
0 g
s
.52585 .3451 m .52573 .34508 L .52596 .34481 L .672 .728 .891 r
F
.52585 .3451 m .52585 .3451 L .52585 .34508 L F
.52221 .34597 m .52585 .3451 L .52585 .34508 L F
.52567 .34515 m .52479 .3454 L p .52551 .34504 L F P
0 g
s
.52567 .34515 m .52551 .34504 L .52573 .34508 L .672 .728 .891 r
F
.52586 .34515 m .52584 .34515 L .52573 .34508 L F
.52584 .34513 m .52586 .34515 L .52584 .34514 L F
.52584 .34513 m .52584 .34514 L .52573 .34508 L F
.52656 .34468 m .52677 .34469 L .52686 .34443 L F
.52677 .34469 m .52653 .34468 L .52663 .34456 L F
.52628 .34492 m .52617 .34478 L .52637 .34467 L F
.52689 .34479 m .52616 .34415 L .52682 .34491 L F
.52765 .34417 m .52722 .34412 L .52732 .34408 L F
.5266 .34471 m .52637 .34467 L .52746 .34408 L F
.52628 .34492 m .52637 .34467 L .5266 .34471 L F
.52629 .34467 m .52591 .3446 L .52653 .34468 L F
.52612 .34462 m .52612 .34463 L .52613 .34463 L F
.52612 .34463 m .52632 .34496 L .52613 .34463 L F
.52604 .34461 m .52632 .34496 L .52612 .34462 L F
.52604 .34567 m .52996 .35133 L .52833 .35009 L F
.52592 .34481 m .52585 .34508 L .52535 .34438 L F
.52529 .34437 m .52535 .34447 L .52596 .34451 L F
.52542 .34421 m .52544 .34417 L .52516 .34352 L F
.52511 .34346 m .52516 .34352 L .52478 .34261 L F
.52276 .34161 m .52143 .34144 L .52071 .34003 L F
.52364 .34303 m .52143 .34144 L p .52276 .34161 L F P
0 g
s
.52143 .34144 m .5133 .33558 L p .52071 .34003 L .672 .728 .891 r
F P
0 g
s
.51421 .33503 m .52426 .34327 L p .52484 .3434 L .672 .728 .891 r
F P
0 g
s
.52502 .34334 m .51421 .33503 L .52484 .3434 L .672 .728 .891 r
F
.5245 .3427 m .5245 .34345 L .52321 .34156 L F
.52503 .34335 m .52504 .34336 L .52473 .34262 L F
.52496 .34326 m .52502 .34334 L .52472 .34263 L F
.52604 .34404 m .52538 .34379 L .5245 .3427 L F
.5252 .34348 m .52502 .34334 L .52484 .3434 L F
.52538 .34379 m .5245 .34345 L .5245 .3427 L F
.52573 .34507 m .52504 .34336 L .52503 .34335 L F
.52416 .34126 m .52484 .34261 L .52475 .34268 L F
.52473 .34262 m .52478 .34261 L .52061 .33267 L F
.52472 .34263 m .52473 .34262 L .52061 .33267 L F
.52532 .34353 m .52558 .34404 L .52581 .34404 L F
.52604 .34404 m .52476 .34292 L .52581 .34404 L F
.5233 .33992 m .52567 .34383 L .52558 .34404 L F
.52403 .34095 m .52567 .34383 L p .5233 .33992 L F P
0 g
s
.52574 .34506 m .52478 .34261 L .52473 .34262 L .672 .728 .891 r
F
.52535 .34434 m .52539 .34425 L .52502 .34334 L F
.52535 .34434 m .52502 .34334 L .52496 .34326 L F
.52538 .34439 m .52541 .3443 L .52539 .34425 L F
.5245 .3427 m .52535 .34434 L .52472 .34263 L F
.52573 .34507 m .52473 .34262 L .52472 .34263 L F
.5245 .3427 m .52558 .34404 L .5254 .34443 L F
.52557 .34403 m .52558 .34404 L .52558 .34404 L F
.52532 .34353 m .52501 .34347 L .52558 .34404 L F
.52476 .34292 m .52501 .34347 L .52532 .34353 L F
.51946 .33295 m .52558 .34404 L .5245 .3427 L F
.52431 .34277 m .52553 .34403 L .52558 .34404 L F
.52431 .34277 m .52558 .34404 L .52557 .34403 L F
.52239 .34084 m .52429 .34277 L .52431 .34277 L F
.52429 .34277 m .52553 .34403 L .52431 .34277 L F
.52429 .34277 m .52499 .34363 L .52553 .34403 L F
.52239 .34084 m .52419 .34281 L .52429 .34277 L F
.52419 .34281 m .52526 .34397 L .52429 .34277 L F
.51421 .33503 m .51518 .33452 L p .52321 .34156 L F P
0 g
s
.52337 .34283 m .52484 .34389 L p .52396 .34278 L .672 .728 .891 r
F P
0 g
s
.5245 .34345 m .51421 .33503 L .52321 .34156 L .672 .728 .891 r
F
.52221 .34111 m .52406 .34285 L p .52239 .34084 L F P
0 g
s
.52239 .34084 m .52406 .34285 L .52419 .34281 L .672 .728 .891 r
F
.52476 .34292 m .5244 .34285 L .52501 .34347 L F
.52476 .34292 m .52239 .34084 L .5244 .34285 L F
.51518 .33452 m .52221 .34111 L p .52239 .34084 L F P
0 g
s
.52596 .34451 m .51518 .33452 L .52465 .34288 L .672 .728 .891 r
F
.52575 .34425 m .52604 .34461 L .52612 .34462 L F
.52611 .34457 m .52603 .3446 L .52674 .34474 L F
.52611 .34462 m .52611 .34451 L .52608 .34467 L F
.52558 .34404 m .52603 .3445 L .52603 .34449 L F
.52581 .34404 m .52558 .34404 L .52558 .34404 L F
.52581 .34404 m .52558 .34404 L .52585 .34409 L F
.52567 .34383 m .52632 .34496 L p .52558 .34404 L F P
0 g
s
.52608 .34454 m .52403 .34095 L p .52482 .34309 L .672 .728 .891 r
F P
0 g
s
.52499 .34363 m .52526 .34397 L .52528 .34398 L .672 .728 .891 r
F
.52499 .34363 m .52528 .34398 L .52553 .34403 L F
.52406 .34285 m .52526 .34397 L p .52419 .34281 L F P
0 g
s
.52591 .34458 m .51518 .33452 L p .52596 .34451 L .672 .728 .891 r
F P
0 g
s
.52529 .34437 m .52596 .34451 L .52482 .34309 L .672 .728 .891 r
F
.52596 .34451 m .52608 .34454 L .52482 .34309 L F
.51946 .33295 m .52403 .34095 L p .5233 .33992 L F P
0 g
s
.52403 .34095 m .51946 .33295 L p .52362 .34109 L .672 .728 .891 r
F P
0 g
s
.5233 .3412 m .52326 .34165 L .52221 .34011 L .672 .728 .891 r
F
.52431 .34246 m .52403 .34095 L .52362 .34109 L F
.52482 .34309 m .52403 .34095 L .52431 .34246 L F
.52607 .3447 m .52613 .34462 L .52608 .34467 L F
.52684 .34453 m .52766 .34397 L .52684 .34461 L F
.52705 .34454 m .5271 .34447 L .52719 .34445 L F
.52705 .34454 m .52719 .34445 L .52894 .344 L F
.5279 .34466 m .52722 .34439 L .52744 .34443 L F
.52602 .34459 m .52785 .34449 L .52777 .34447 L F
.52692 .34475 m .52705 .34454 L .52894 .344 L F
.52684 .34469 m .52684 .34461 L .52763 .34414 L F
.5278 .34439 m .52626 .34457 L .52771 .34463 L F
.52616 .34415 m .52663 .34471 L .52665 .34471 L F
.52653 .34468 m .52674 .34474 L .52656 .34468 L F
.52616 .34415 m .52662 .34471 L .52663 .34471 L F
.52645 .34454 m .52643 .34454 L .52685 .34429 L F
.52685 .34441 m .52637 .34467 L .52685 .34429 L F
.52653 .34468 m .52591 .3446 L .52663 .34456 L F
.52637 .34467 m .52628 .34465 L .52685 .34429 L F
.52585 .34409 m .52787 .34633 L .52762 .34598 L F
.52613 .34414 m .52738 .34572 L .52757 .3458 L F
.52718 .3443 m .52601 .3446 L .5278 .34439 L F
.5271 .34441 m .52654 .34472 L .52703 .34438 L F
.52617 .34463 m .52619 .34465 L .52619 .34465 L F
.52603 .34449 m .52617 .34463 L .52617 .34463 L F
.52617 .34463 m .52619 .34465 L .52617 .34463 L F
.5271 .34407 m .52625 .34465 L .52604 .34461 L F
.52613 .34414 m .5264 .34467 L .5265 .34469 L F
.52628 .34465 m .52643 .34454 L .52645 .34454 L F
.52614 .34474 m .52627 .34465 L .52628 .34465 L F
.52627 .34465 m .52643 .34454 L .52628 .34465 L F
.52613 .34414 m .52585 .34409 L .5264 .34467 L F
.52616 .34476 m .52687 .34483 L .52649 .34473 L F
.5265 .34469 m .5264 .34467 L .52674 .34503 L F
.52585 .34409 m .52617 .34463 L .52637 .34467 L F
.52626 .34457 m .52603 .3446 L .52643 .34461 L F
.52603 .3446 m .52601 .3446 L .52603 .3446 L F
.52603 .3446 m .52603 .3446 L .52643 .34461 L F
.52667 .34472 m .52684 .34453 L .52684 .34461 L F
.5266 .34471 m .52684 .34453 L .52667 .34472 L F
.52684 .34469 m .52676 .34473 L p .52684 .34461 L F P
0 g
s
.52676 .34473 m .52667 .34472 L .52684 .34461 L .672 .728 .891 r
F
.52613 .34414 m .52674 .34503 L .52678 .34497 L F
.52601 .3446 m .52649 .34473 L .52771 .34463 L F
.52603 .3446 m .52604 .34461 L .52601 .34461 L F
.5271 .34407 m .52604 .34461 L .52603 .3446 L F
.52732 .34408 m .52722 .34412 L .52727 .34407 L F
.52763 .34408 m .52727 .34407 L .52757 .34379 L F
.52948 .34308 m .54062 .33648 L p .52743 .34369 L F P
0 g
s
.54062 .33648 m .52775 .34411 L p .52797 .34351 L .672 .728 .891 r
F P
0 g
s
.52759 .3443 m .53011 .34299 L p .52699 .34406 L .672 .728 .891 r
F P
0 g
s
.53011 .34299 m .54139 .33712 L p .53051 .34236 L .672 .728 .891 r
F P
0 g
s
.52797 .34351 m .52718 .34407 L .52698 .34406 L .672 .728 .891 r
F
.52699 .34406 m .53011 .34299 L .53051 .34236 L F
.52881 .34411 m .52894 .344 L .52963 .34383 L F
.52963 .34383 m .52842 .34413 L .5283 .34411 L F
.5297 .34364 m .52789 .34411 L .5304 .344 L F
.52966 .34433 m .5446 .34152 L p .52958 .34384 L F P
0 g
s
.54424 .34073 m .52835 .34448 L p .52963 .34383 L .672 .728 .891 r
F P
0 g
s
.53014 .34353 m .5297 .34364 L .5304 .344 L .672 .728 .891 r
F
.5297 .34364 m .5282 .34432 L .52789 .34411 L F
.5304 .344 m .54424 .34073 L p .53014 .34353 L F P
0 g
s
.5319 .34307 m .52956 .34386 L .5297 .34364 L .672 .728 .891 r
F
.52956 .34386 m .5282 .34432 L .5297 .34364 L F
.5277 .34378 m .52721 .34408 L .5271 .34407 L F
.52721 .34408 m .52625 .34465 L .5271 .34407 L F
.5233 .3412 m .52431 .34246 L .51946 .33295 L F
.52612 .34403 m .52465 .34288 L .5233 .3412 L F
.52521 .34312 m .52514 .34311 L .52597 .34405 L F
.52718 .3443 m .52609 .34467 L .52618 .34456 L F
.52604 .34404 m .52581 .34404 L .52585 .34409 L F
.52604 .34404 m .52585 .34409 L .52613 .34414 L F
.52542 .34383 m .52587 .34396 L .52588 .34397 L F
.52542 .34383 m .52588 .34397 L .52691 .34487 L F
.52759 .3443 m .52763 .34414 L .52987 .34278 L F
.52789 .34411 m .52718 .3443 L .5278 .34439 L F
.52726 .3445 m .52703 .34438 L .52713 .34434 L F
.52726 .3445 m .52713 .34434 L .52789 .34411 L F
.52749 .34463 m .52726 .3445 L .52789 .34411 L F
.53097 .34219 m .52766 .34397 L .5277 .34378 L F
.52763 .34414 m .52766 .34397 L .52987 .34278 L F
.53034 .34287 m .52759 .3443 L p .52987 .34278 L F P
0 g
s
.52819 .34411 m .53421 .34137 L p .5277 .34378 L .672 .728 .891 r
F P
0 g
s
.53004 .34327 m .5269 .3447 L p .52806 .34402 L .672 .728 .891 r
F P
0 g
s
.52789 .34411 m .52715 .34434 L .52718 .3443 L .672 .728 .891 r
F
.5275 .34408 m .52746 .34408 L .52766 .34397 L F
.5266 .34471 m .52746 .34408 L .5275 .34408 L F
.52766 .34397 m .52685 .34441 L .5277 .34378 L F
.52685 .34441 m .52685 .34429 L .5277 .34378 L F
.52732 .34397 m .52662 .34447 L .52819 .34411 L F
.5269 .3447 m .5269 .34463 L .52977 .34301 L F
.52618 .34456 m .52608 .34467 L .52603 .3446 L F
.52622 .34484 m .52687 .34483 L .5262 .34481 L F
.52672 .34483 m .52687 .34483 L .52666 .34481 L F
.52672 .34483 m .52666 .34481 L .52616 .34476 L F
.5262 .34481 m .52672 .34483 L .52616 .34476 L F
.52614 .34474 m .52613 .34472 L .52643 .34454 L F
.52637 .34467 m .52617 .34463 L .52787 .34633 L F
.52673 .34481 m .52681 .34492 L .52682 .34491 L F
.52673 .34483 m .52681 .34492 L .52673 .34481 L F
.52553 .34403 m .52804 .34658 L .52558 .34404 L F
.52632 .34496 m .52608 .34467 L .52691 .34487 L F
.52665 .34471 m .52673 .34483 L .52673 .34481 L F
.52663 .34471 m .52673 .34483 L .52665 .34471 L F
.52663 .34471 m .52662 .34471 L .52681 .34492 L F
.52608 .34467 m .52672 .34474 L .52691 .34487 L F
.52609 .34467 m .52608 .34467 L .52618 .34456 L F
.52613 .34462 m .52612 .34461 L p .52608 .34467 L F P
0 g
s
.52654 .34472 m .5259 .34508 L .52649 .34472 L .672 .728 .891 r
F
.52607 .3447 m .52658 .34558 L .52613 .34462 L F
.52626 .34457 m .52643 .34461 L .52771 .34463 L F
.52603 .3445 m .52804 .34658 L .52603 .34449 L F
.5268 .34483 m .5259 .34508 L p .5271 .34441 L F P
0 g
s
.52607 .3447 m .52608 .34467 L .52607 .34469 L .672 .728 .891 r
F
.5259 .34508 m .52599 .3447 L .52608 .34467 L F
.52649 .34472 m .52608 .34467 L .52703 .34438 L F
.52608 .34467 m .52588 .34499 L .52632 .34496 L F
.5259 .34508 m .52608 .34467 L .52649 .34472 L F
.52697 .34493 m .52676 .34475 L .52698 .34489 L F
.52701 .34375 m .52624 .34438 L .52747 .34361 L F
.52616 .34415 m .52613 .34414 L .52662 .34471 L F
.52706 .34415 m .52603 .3446 L .52662 .34447 L F
.52732 .34397 m .5271 .34407 L .52706 .34415 L F
.5271 .34407 m .52603 .3446 L .52706 .34415 L F
.5267 .34485 m .52673 .34491 L .52674 .3449 L F
.52592 .34481 m .52535 .34438 L .52558 .34447 L F
.52715 .34434 m .52608 .34467 L .52718 .3443 L F
.52654 .34472 m .52649 .34472 L .52703 .34438 L F
.52603 .3446 m .52637 .34468 L .52694 .34439 L F
.52603 .3446 m .52608 .34467 L .52612 .34462 L F
.52612 .34461 m .52608 .34454 L p .52607 .34465 L F P
0 g
s
.52607 .34469 m .52608 .34467 L .52607 .34465 L .672 .728 .891 r
F
.52608 .34467 m .52612 .34461 L .52607 .34465 L F
.52608 .34467 m .52612 .34461 L .52607 .34469 L F
.52596 .34451 m .52607 .3447 L .52608 .34454 L F
.52585 .34409 m .5264 .34467 L .5264 .34467 L F
.52608 .34467 m .52542 .34383 L .52672 .34474 L F
.52637 .34468 m .52674 .34477 L .52678 .34469 L F
.52637 .34468 m .52678 .34469 L .52694 .34439 L F
.52687 .34483 m .52691 .34476 L .52963 .34383 L F
.52687 .34483 m .52771 .34463 L p .52649 .34473 L F P
0 g
s
.52682 .34475 m .52674 .34469 L .52685 .34476 L .672 .728 .891 r
F
.52674 .34469 m .52677 .34469 L .52685 .34476 L F
.52674 .34477 m .52819 .34411 L p .52694 .34439 L F P
0 g
s
.52676 .34475 m .52682 .34475 L .52698 .34489 L .672 .728 .891 r
F
.52698 .34489 m .52682 .34475 L .52685 .34476 L F
.52749 .34463 m .5268 .34483 L p .5271 .34441 L F P
0 g
s
.52669 .34475 m .52665 .34474 L .52804 .34397 L .672 .728 .891 r
F
.52808 .34397 m .52804 .34397 L .52977 .34301 L F
.52669 .34475 m .52804 .34397 L .52808 .34397 L F
.52674 .34469 m .52589 .34397 L .52677 .34469 L F
.52589 .34397 m .52589 .34397 L .52677 .34469 L F
.52608 .34467 m .52632 .34496 L .52612 .34462 L F
.52608 .34467 m .52592 .34465 L .52604 .34461 L F
.526 .34466 m .52592 .34459 L p .52608 .34467 L F P
0 g
s
.52583 .34497 m .52606 .34469 L .52596 .34451 L .672 .728 .891 r
F
.52596 .34465 m .52591 .34487 L .52648 .34472 L F
.52228 .3459 m .52563 .34513 L .52549 .34507 L F
.52221 .34597 m .52563 .34513 L .52228 .3459 L F
.51759 .34746 m .51611 .34773 L .525 .345 L F
.52532 .34482 m .51965 .34659 L .52562 .34495 L F
.525 .345 m .50892 .34994 L .52505 .3449 L F
.51965 .34659 m .52573 .345 L .52562 .34495 L F
.52284 .34615 m .52007 .34783 L .52093 .34708 L F
.52338 .34597 m .52007 .34783 L .52284 .34615 L F
.52007 .34783 m .51138 .35274 L .52093 .34708 L F
.51066 .35208 m .52352 .34623 L p .52284 .34615 L F P
0 g
s
.52352 .34623 m .52489 .34561 L p .52284 .34615 L .672 .728 .891 r
F P
0 g
s
.52538 .3451 m .51066 .35208 L .52518 .34501 L .672 .728 .891 r
F
.52042 .34804 m .5206 .34788 L .52558 .34509 L F
.52996 .35133 m .5331 .35683 L p .52833 .35009 L F P
0 g
s
.52631 .34495 m .5253 .34597 L .5253 .34597 L .672 .728 .891 r
F
.52571 .34557 m .52574 .34554 L p .52573 .34554 L F P
0 g
s
.52599 .34529 m .52497 .34631 L p .52599 .34528 L .672 .728 .891 r
F P
0 g
s
.52587 .34529 m .5331 .35683 L .52658 .34558 L .672 .728 .891 r
F
.52624 .34561 m .5262 .3456 L .52589 .34518 L F
.52589 .34515 m .52589 .34518 L .52529 .34437 L F
.52624 .34561 m .52589 .34518 L .52589 .34515 L F
.52532 .34482 m .52591 .34487 L .52596 .34465 L F
.52598 .34463 m .52471 .34524 L .52598 .34462 L F
.52471 .34524 m .51066 .35208 L .52471 .34524 L F
.52471 .34524 m .52471 .34524 L .52598 .34462 L F
.52542 .34383 m .52465 .34288 L .52587 .34396 L F
.52632 .34496 m .52674 .34477 L p .52612 .34462 L F P
0 g
s
.52608 .34458 m .52614 .34474 L .52603 .3446 L .672 .728 .891 r
F
.52521 .34358 m .5259 .34444 L .525 .3439 L F
.52597 .34462 m .52596 .34465 L .52615 .3446 L F
.52608 .34463 m .52606 .34464 L .52608 .34458 L F
.52606 .34464 m .52605 .34463 L .52608 .34458 L F
.52633 .34465 m .52614 .34474 L .52608 .34458 L F
.52609 .34458 m .52608 .34458 L .52608 .34458 L F
.52633 .34465 m .52608 .34458 L .52609 .34458 L F
.5267 .34563 m .52613 .34462 L p .52658 .34558 L F P
0 g
s
.52596 .34465 m .52648 .34472 L .52623 .34463 L .672 .728 .891 r
F
.52627 .34463 m .52609 .34458 L .52609 .34459 L F
.52632 .34496 m .52615 .34502 L .52665 .34474 L F
.52661 .34523 m .52632 .34496 L p .52691 .34487 L F P
0 g
s
.52673 .34482 m .52894 .344 L .52881 .34411 L .672 .728 .891 r
F
.52835 .34448 m .52687 .34483 L p .52877 .34414 L F P
0 g
s
.52835 .34448 m .52877 .34414 L .52963 .34383 L .672 .728 .891 r
F
.52842 .34413 m .52729 .34442 L .5283 .34411 L F
.52771 .34463 m .5304 .344 L p .52789 .34411 L F P
0 g
s
.5283 .3444 m .52749 .34463 L p .52789 .34411 L .672 .728 .891 r
F P
0 g
s
.52648 .34472 m .52856 .34424 L .52826 .34423 L .672 .728 .891 r
F
.52653 .34473 m .52859 .34424 L .52648 .34472 L F
.54424 .34073 m .54381 .33996 L p .53014 .34353 L F P
0 g
s
.54381 .33996 m .5283 .3444 L p .5282 .34432 L .672 .728 .891 r
F P
0 g
s
.52859 .34424 m .52961 .34399 L .52856 .34424 L .672 .728 .891 r
F
.52859 .34424 m .52856 .34424 L .52648 .34472 L F
.52588 .34496 m .52632 .34496 L .52624 .34487 L F
.5259 .34508 m .52585 .3451 L p .52596 .34481 L F P
0 g
s
.52587 .34502 m .52632 .34496 L .52588 .34496 L .672 .728 .891 r
F
.5259 .34511 m .52592 .34495 L .52645 .34468 L F
.5264 .34467 m .52762 .34598 L .5264 .34467 L F
.52678 .34497 m .52674 .34503 L .52738 .34572 L F
.52661 .34523 m .52697 .34493 L .52696 .34525 L F
.52661 .34473 m .52705 .34527 L .52696 .34513 L F
.52597 .34462 m .52598 .34463 L .52592 .34481 L F
.52598 .34463 m .52594 .34483 L .52592 .34481 L F
.52597 .34462 m .52597 .34462 L .52597 .34462 L F
.52599 .34455 m .52608 .34466 L .52604 .34457 L F
.5262 .34481 m .52614 .34474 L .52633 .34465 L F
.52608 .34466 m .52632 .34496 L .52608 .34462 L F
.5262 .34481 m .52633 .34465 L .52645 .34468 L F
.52619 .34465 m .52711 .34561 L .52717 .34563 L F
.52595 .34513 m .5266 .34473 L .52665 .34474 L F
.5261 .34424 m .5265 .34472 L .52611 .34421 L F
.52711 .34561 m .52804 .34658 L .52717 .34563 L F
.52793 .34647 m .52661 .34523 L p .52693 .34525 L F P
0 g
s
.52682 .34491 m .52681 .34492 L .52917 .34763 L .672 .728 .891 r
F
.52793 .34647 m .52693 .34525 L .52737 .34528 L F
.52762 .34598 m .52917 .34763 L .52762 .34598 L F
.52762 .34598 m .52787 .34633 L .52917 .34763 L F
.52804 .34658 m .52919 .34765 L p .52787 .34633 L F P
0 g
s
.52757 .3458 m .52738 .34572 L .52917 .34763 L .672 .728 .891 r
F
.52917 .34763 m .52917 .34763 L .52919 .34765 L F
.52938 .34698 m .52806 .34582 L .52919 .34765 L F
.52806 .34582 m .52917 .34763 L .52919 .34765 L F
.5332 .35032 m .52938 .34698 L .53384 .35201 L F
.52919 .34765 m .53384 .35201 L p .52938 .34698 L F P
0 g
s
.53384 .35201 m .53734 .35529 L p .5332 .35032 L .672 .728 .891 r
F P
0 g
s
.53734 .35529 m .52793 .34647 L p .52737 .34528 L .672 .728 .891 r
F P
0 g
s
.52573 .345 m .52624 .34487 L .52562 .34495 L .672 .728 .891 r
F
.52627 .3449 m .52645 .34468 L .5266 .34473 L F
.52623 .34485 m .52645 .34468 L .52627 .3449 L F
.52658 .34472 m .52657 .34472 L .5266 .34476 L F
.5269 .3447 m .52674 .34477 L p .5269 .34463 L F P
0 g
s
.52674 .34477 m .52632 .34496 L p .52669 .34475 L .672 .728 .891 r
F P
0 g
s
.52645 .34447 m .52588 .34397 L .52641 .34441 L .672 .728 .891 r
F
.52645 .34447 m .52641 .34441 L .52682 .34475 L F
.52676 .34475 m .52645 .34447 L .52682 .34475 L F
.52691 .34482 m .52624 .34415 L .52662 .34473 L F
.52674 .34477 m .52669 .34475 L .5269 .34463 L F
.52698 .34489 m .52691 .34482 L .52665 .34478 L F
.52691 .34482 m .52662 .34473 L .52665 .34478 L F
.52632 .34496 m .52665 .34474 L .52669 .34475 L F
.52632 .34496 m .5268 .34483 L p .52624 .34487 L F P
0 g
s
.5268 .34483 m .53079 .34368 L p .52663 .34477 L .672 .728 .891 r
F P
0 g
s
.52624 .34487 m .5268 .34483 L .52663 .34477 L .672 .728 .891 r
F
.5266 .34476 m .5267 .34495 L .52673 .34491 L F
.52657 .34472 m .52659 .34476 L .5266 .34476 L F
.52659 .34476 m .5267 .34495 L .5266 .34476 L F
.52661 .34476 m .5266 .34476 L .52669 .34486 L F
.52658 .34472 m .5266 .34476 L .52661 .34476 L F
.52624 .34487 m .52663 .34477 L .5262 .34481 L F
.52663 .34477 m .52961 .34399 L .52653 .34473 L F
.52663 .34477 m .52653 .34473 L .5262 .34481 L F
.52624 .34487 m .5262 .34481 L .52562 .34495 L F
.52599 .34506 m .52632 .34496 L p .52604 .34503 L F P
0 g
s
.52585 .34508 m .52599 .34506 L .52604 .34503 L .672 .728 .891 r
F
.52585 .3451 m .52599 .34506 L p .52585 .34508 L F P
0 g
s
.5259 .34511 m .52623 .34485 L .52627 .3449 L .672 .728 .891 r
F
.5265 .34472 m .52948 .34836 L .52653 .34474 L F
.5265 .34472 m .52653 .34474 L .52611 .34421 L F
.52612 .34417 m .52659 .34472 L .52661 .34473 L F
.52645 .34468 m .52633 .34465 L .52977 .34301 L F
.52611 .3442 m .52651 .3447 L .52657 .34472 L F
.52612 .34418 m .52661 .34476 L .52663 .34477 L F
.52615 .3446 m .52699 .34457 L .527 .34438 L F
.52596 .34465 m .52623 .34463 L .52615 .3446 L F
.52627 .34463 m .52609 .34459 L .52628 .34465 L F
.52623 .34463 m .52699 .34457 L .52615 .3446 L F
.5265 .3447 m .52645 .34468 L .52676 .34453 L F
.5265 .3447 m .52676 .34453 L .52977 .34301 L F
.5266 .34473 m .5265 .3447 L .52977 .34301 L F
.52604 .34461 m .52608 .34463 L .52608 .34461 L F
.52609 .34459 m .52608 .34461 L .52694 .34563 L F
.52611 .34417 m .52657 .34472 L .52658 .34472 L F
.52601 .34405 m .52611 .34417 L .52611 .34417 L F
.52611 .34417 m .52657 .34472 L .52611 .34417 L F
.52619 .3448 m .52653 .34473 L .52648 .34472 L F
.52661 .34523 m .52691 .34487 L .52691 .34499 L F
.5261 .34424 m .52694 .34563 L .52712 .34548 L F
.52559 .34362 m .5261 .34437 L .5261 .34424 L F
.5261 .34437 m .52694 .34563 L .5261 .34424 L F
.52665 .34474 m .5266 .34473 L .52977 .34301 L F
.52673 .34491 m .52948 .34836 L .52881 .34725 L F
.52737 .34528 m .52697 .34493 L .52698 .34489 L F
.52696 .34525 m .52697 .34493 L .52737 .34528 L F
.52737 .34528 m .52698 .34489 L .5272 .34541 L F
.52819 .3461 m .52737 .34528 L .52801 .34635 L F
.52737 .34528 m .5272 .34541 L .52801 .34635 L F
.52948 .34836 m .53633 .35574 L p .52881 .34725 L F P
0 g
s
.52689 .34483 m .52694 .34484 L .5281 .34468 L .672 .728 .891 r
F
.52819 .3461 m .52801 .34635 L .53633 .35574 L F
.52651 .3447 m .5267 .34495 L .52657 .34472 L F
.52623 .34463 m .52648 .34472 L .52699 .34457 L F
.52661 .34476 m .5267 .34486 L .52663 .34477 L F
.5277 .34378 m .52732 .34397 L .52819 .34411 L F
.52839 .34367 m .52633 .34465 L .52609 .34458 L F
.52612 .34418 m .52659 .34472 L .52612 .34417 L F
.52559 .34362 m .52604 .34457 L .52627 .34463 L F
.52611 .34421 m .5267 .34495 L .52611 .3442 L F
.52612 .34419 m .5267 .34486 L .52612 .34418 L F
.52588 .34397 m .52589 .34397 L .52682 .34475 L F
.52601 .34405 m .52597 .34405 L .52657 .34472 L F
.52616 .34415 m .52604 .34404 L .52613 .34414 L F
.52627 .34429 m .52625 .34396 L p .52622 .34428 L F P
0 g
s
.52685 .34476 m .52587 .34396 L .52612 .34403 L .672 .728 .891 r
F
.52624 .34415 m .52608 .34412 L .52665 .34478 L F
.54381 .33996 m .5282 .34432 L .5319 .34307 L F
.52608 .34458 m .52615 .3446 L .54381 .33996 L F
.52661 .34485 m .52614 .34469 L .5271 .34432 L F
.52659 .34472 m .52705 .34527 L .52661 .34473 L F
.52608 .34458 m .52603 .3446 L .52615 .3446 L F
.52603 .3446 m .52597 .34462 L .52598 .34462 L F
.52603 .3446 m .52598 .34462 L .52615 .3446 L F
.52603 .3446 m .52601 .34461 L .52598 .34462 L F
.52601 .34461 m .52598 .34463 L .52598 .34462 L F
.52585 .34508 m .52585 .3451 L .52536 .34446 L F
.52614 .34474 m .52594 .34483 L .52603 .3446 L F
.52594 .34483 m .52538 .3451 L .52597 .34464 L F
.52594 .34483 m .52597 .34464 L .52603 .3446 L F
.52603 .3446 m .52598 .34462 L .52604 .34461 L F
.52598 .34462 m .52608 .34466 L .52604 .34461 L F
.52604 .34465 m .52598 .34462 L .52603 .3446 L F
.52605 .34463 m .52603 .3446 L .52608 .34458 L F
.52604 .34465 m .52603 .3446 L .52605 .34463 L F
.52608 .34458 m .52603 .3446 L .52608 .34461 L F
.52603 .3446 m .52604 .34461 L .52608 .34461 L F
.52608 .34458 m .52608 .34458 L .52603 .3446 L F
.52608 .34458 m .52603 .3446 L .52608 .34458 L F
.52597 .34462 m .52532 .34482 L .52596 .34465 L F
.52603 .3446 m .52479 .34506 L .52456 .34506 L F
.52608 .34458 m .52603 .3446 L .52603 .3446 L F
.52603 .3446 m .52598 .34462 L .52603 .3446 L F
.5253 .34435 m .52587 .3451 L .52529 .34437 L F
.52531 .34434 m .52533 .34436 L .5253 .34435 L F
.52533 .34436 m .52587 .3451 L .5253 .34435 L F
.52532 .34482 m .52562 .34495 L .52591 .34487 L F
.52538 .3451 m .52518 .34501 L .52603 .3446 L F
.52603 .3446 m .52598 .34462 L .52603 .3446 L F
.52598 .34462 m .52479 .34506 L .52598 .34462 L F
.52598 .34462 m .52598 .34462 L .52603 .3446 L F
.52603 .3446 m .52603 .3446 L .52608 .34458 L F
.52632 .34496 m .52694 .34563 L p .52604 .34457 L F P
0 g
s
.52563 .34513 m .52632 .34496 L .52549 .34507 L .672 .728 .891 r
F
.52595 .34513 m .5259 .34511 L .5266 .34473 L F
.5262 .34481 m .52653 .34473 L .52619 .3448 L F
.52628 .34465 m .52609 .34459 L .52694 .34563 L F
.52608 .34466 m .5268 .34566 L .52597 .34462 L F
.52613 .34468 m .52632 .34496 L p .52608 .34466 L F P
0 g
s
.52632 .34496 m .5268 .34566 L p .52608 .34466 L .672 .728 .891 r
F P
0 g
s
.52562 .34495 m .5262 .34481 L .52619 .3448 L .672 .728 .891 r
F
.52574 .34504 m .52614 .34474 L .5262 .34481 L F
.52608 .34466 m .52608 .3447 L .52632 .34496 L F
.52598 .34462 m .52605 .34476 L .52608 .34466 L F
.52598 .34463 m .5268 .34566 L .52594 .34483 L F
.5331 .35683 m .5267 .34563 L p .52658 .34558 L F P
0 g
s
.52587 .3451 m .52585 .3451 L .52585 .34508 L .672 .728 .891 r
F
.5259 .34511 m .5258 .34518 L .5258 .34506 L F
.5258 .34518 m .52572 .34523 L .5258 .34506 L F
.5258 .34506 m .52572 .34523 L .52574 .34504 L F
.52595 .34513 m .52589 .34516 L p .5259 .34511 L F P
0 g
s
.52589 .34516 m .52572 .34523 L p .5259 .34511 L .672 .728 .891 r
F P
0 g
s
.52587 .34529 m .5262 .3456 L .52605 .34559 L .672 .728 .891 r
F
.52589 .34519 m .5262 .3456 L .52587 .34529 L F
.5268 .34566 m .52624 .34561 L .52587 .3451 L F
.5268 .34566 m .52587 .3451 L .52629 .34517 L F
.52587 .3451 m .52624 .34561 L .52585 .3451 L F
.52632 .34496 m .52595 .34513 L p .52615 .34502 L F P
0 g
s
.5268 .34566 m .53421 .35651 L .52624 .34561 L .672 .728 .891 r
F
.52624 .34561 m .53421 .35651 L .5262 .3456 L F
.5262 .3456 m .53421 .35651 L .52605 .34559 L F
.52528 .34587 m .52527 .34588 L .52594 .34528 L F
.52528 .34587 m .52594 .34528 L .52594 .34528 L F
.53421 .35651 m .52632 .34496 L p .52573 .34508 L F P
0 g
s
.52632 .34496 m .52613 .34468 L p .52611 .3447 L .672 .728 .891 r
F P
0 g
s
.52632 .34496 m .52608 .3447 L p .52611 .3447 L .672 .728 .891 r
F P
0 g
s
.5259 .34511 m .52574 .34504 L .52592 .34495 L .672 .728 .891 r
F
.52597 .34462 m .5268 .34566 L .52597 .34462 L F
.52629 .34517 m .52585 .34508 L .52592 .34481 L F
.52573 .34508 m .52632 .34496 L .52611 .3447 L F
.52663 .34477 m .5267 .34486 L .5267 .34485 L F
.5267 .34486 m .52673 .34491 L .5267 .34485 L F
.5267 .34486 m .52669 .34486 L .52673 .34491 L F
.52658 .34472 m .52669 .34486 L .5267 .34486 L F
.52674 .3449 m .52673 .34491 L .52705 .34527 L F
.52696 .34513 m .52705 .34527 L .52801 .34635 L F
.5267 .34495 m .52948 .34836 L .52673 .34491 L F
.52691 .34499 m .52691 .34487 L .52697 .34493 L F
.52698 .34489 m .52665 .34478 L .5272 .34541 L F
.52694 .34563 m .52948 .34836 L p .52712 .34548 L F P
0 g
s
.53633 .35574 m .52632 .34496 L p .52679 .34469 L .672 .728 .891 r
F P
0 g
s
.52632 .34496 m .52611 .3447 L .52679 .34469 L .672 .728 .891 r
F
.52605 .34476 m .52607 .34481 L .52607 .34473 L F
.52605 .34476 m .52607 .34473 L .52608 .34466 L F
.51833 .33327 m .51724 .33364 L p .52328 .34117 L F P
0 g
s
.52607 .3447 m .52608 .3447 L p .52608 .34466 L .672 .728 .891 r
F P
0 g
s
.52608 .34466 m .52608 .3447 L .52611 .3447 L .672 .728 .891 r
F
.52611 .3447 m .5261 .34468 L .5271 .34432 L F
.52608 .34466 m .52611 .3447 L .52617 .3447 L F
.52607 .34471 m .52607 .34469 L .5261 .34468 L F
.52608 .3447 m .52607 .3447 L p .52611 .3447 L F P
0 g
s
.52608 .3447 m .52607 .34481 L .52617 .3447 L .672 .728 .891 r
F
.52607 .34471 m .52609 .3447 L .52611 .3447 L F
.52607 .34471 m .52611 .3447 L .5261 .3447 L F
.52609 .3447 m .5261 .34468 L .52611 .3447 L F
.52608 .3447 m .52611 .3447 L .52679 .34469 L F
.52609 .3447 m .52611 .3447 L .52611 .3447 L F
.52598 .34462 m .52471 .34524 L .52482 .34511 L F
.52598 .34462 m .52482 .34511 L .52607 .34481 L F
.52381 .34548 m .52608 .34463 L .52608 .34464 L F
.51066 .35208 m .51001 .35139 L p .52482 .34511 L F P
0 g
s
.52471 .34524 m .51066 .35208 L .52482 .34511 L .672 .728 .891 r
F
.52587 .3451 m .52536 .34446 L .52536 .34446 L F
.51784 .34783 m .52292 .34583 L .52607 .34469 L F
.52189 .34698 m .52093 .34721 L .52561 .34499 L F
.52189 .34698 m .52561 .34499 L .52574 .34504 L F
.52482 .34511 m .52059 .34691 L .52581 .34507 L F
.51784 .34783 m .52607 .34469 L .52607 .34471 L F
.51921 .34699 m .52191 .34622 L p .51965 .34659 L F P
0 g
s
.51965 .34659 m .52191 .34622 L .52221 .34597 L .672 .728 .891 r
F
.52604 .34465 m .50943 .35068 L .52598 .34462 L F
.52502 .34356 m .52607 .3447 L p .52521 .34358 L F P
0 g
s
.52608 .34466 m .52381 .34548 L .52608 .34464 L .672 .728 .891 r
F
.52607 .34469 m .50943 .35068 L .52608 .34466 L F
.52465 .34288 m .52326 .34165 L .5233 .3412 L F
.52529 .34437 m .52482 .34309 L .52431 .34246 L F
.5233 .3412 m .52529 .34437 L .52431 .34246 L F
.51518 .33452 m .51619 .33406 L p .52221 .34011 L F P
0 g
s
.52326 .34165 m .51518 .33452 L .52221 .34011 L .672 .728 .891 r
F
.5233 .3412 m .52521 .34358 L .525 .3439 L F
.52434 .34249 m .52221 .34011 L .52399 .34246 L F
.5233 .3412 m .52221 .34011 L .52434 .34249 L F
.51619 .33406 m .52217 .3405 L p .52221 .34011 L F P
0 g
s
.52217 .3405 m .52399 .34246 L p .52221 .34011 L .672 .728 .891 r
F P
0 g
s
.52455 .34306 m .52502 .34356 L p .52514 .34311 L .672 .728 .891 r
F P
0 g
s
.52426 .34249 m .52399 .34246 L .52459 .34277 L .672 .728 .891 r
F
.52399 .34246 m .52455 .34306 L p .52459 .34277 L F P
0 g
s
.52607 .3447 m .51619 .33406 L p .52328 .34117 L .672 .728 .891 r
F P
0 g
s
.52587 .34396 m .52465 .34288 L .52612 .34403 L .672 .728 .891 r
F
.52559 .34362 m .52521 .34358 L .52604 .34457 L F
.52529 .34346 m .526 .3445 L p .5259 .34444 L F P
0 g
s
.52521 .34358 m .52599 .34455 L .52604 .34457 L .672 .728 .891 r
F
.52529 .34346 m .5259 .34444 L .52521 .34358 L F
.51946 .33295 m .51833 .33327 L p .5233 .3412 L F P
0 g
s
.52462 .34252 m .5233 .3412 L .52435 .34249 L .672 .728 .891 r
F
.5233 .3412 m .5233 .3412 L .52435 .34249 L F
.52435 .34249 m .5233 .3412 L .52434 .34249 L F
.52514 .34311 m .52502 .34356 L .52559 .34362 L F
.52462 .34252 m .52455 .34306 L .52514 .34311 L F
.51833 .33327 m .52529 .34346 L p .52521 .34358 L F P
0 g
s
.52462 .34252 m .52426 .34249 L .52459 .34277 L .672 .728 .891 r
F
.51833 .33327 m .52521 .34358 L .5233 .3412 L F
.52613 .34468 m .51833 .33327 L p .52328 .34117 L F P
0 g
s
.52598 .34462 m .52608 .34461 L .52608 .34461 L .672 .728 .891 r
F
.52608 .34466 m .52608 .34462 L .52604 .34457 L F
.52606 .34464 m .52604 .34465 L .52605 .34463 L F
.526 .3445 m .52613 .34468 L p .52597 .34462 L F P
0 g
s
.52611 .3447 m .52613 .34468 L .52328 .34117 L .672 .728 .891 r
F
.52717 .34434 m .52661 .34485 L .5271 .34432 L F
.52608 .34461 m .5276 .34443 L .52608 .34461 L F
.52977 .34301 m .52839 .34367 L .52608 .34458 L F
.52839 .34367 m .52609 .34458 L .52608 .34458 L F
.5261 .34468 m .5261 .34468 L .52705 .34431 L F
.52609 .34458 m .52608 .34458 L .52609 .34459 L F
.52608 .34458 m .52608 .34461 L .52609 .34459 L F
.52607 .34469 m .52608 .34466 L .52705 .34431 L F
.52608 .34458 m .52608 .34461 L .52755 .34441 L F
.52608 .34463 m .5262 .34469 L .52608 .34461 L F
.5262 .34469 m .5263 .34475 L .52622 .34469 L F
.5262 .34469 m .52622 .34469 L .52608 .34461 L F
.52611 .3447 m .52677 .34467 L .52679 .34469 L F
.52608 .34461 m .5263 .34475 L .52681 .34462 L F
.52608 .34461 m .52681 .34462 L .52692 .34451 L F
.52595 .34405 m .5261 .34424 L .52597 .34405 L F
.5261 .34424 m .52611 .34421 L .52597 .34405 L F
.52608 .34464 m .52608 .34463 L .52701 .3443 L F
.52521 .34312 m .52612 .34418 L .52612 .34417 L F
.52609 .34458 m .52604 .34457 L .52608 .34461 L F
.52608 .34466 m .5263 .34475 L .52604 .34461 L F
.52608 .34466 m .52608 .34464 L .52701 .3443 L F
.52597 .34405 m .52611 .34421 L .52611 .3442 L F
.52589 .34397 m .52587 .34396 L .52589 .34397 L F
.52701 .3443 m .52608 .34458 L .52701 .34434 L F
.52701 .3443 m .52608 .34463 L .52608 .34458 L F
.52521 .34312 m .52612 .34419 L .52612 .34418 L F
.52588 .34397 m .52587 .34396 L .52589 .34397 L F
.52521 .34312 m .52597 .34405 L .52601 .34405 L F
.52559 .34362 m .52595 .34405 L .52597 .34405 L F
.52624 .34415 m .52521 .34312 L .52608 .34412 L F
.52521 .34312 m .52462 .34252 L .52514 .34311 L F
.52953 .34126 m .52626 .34432 L .52948 .34169 L F
.52611 .3447 m .52328 .34117 L .52677 .34467 L F
.5261 .34468 m .52607 .34469 L .5261 .34468 L F
.52521 .34358 m .52607 .3447 L .52608 .34466 L F
.52607 .3447 m .52328 .34117 L .52611 .3447 L F
.52549 .34507 m .52587 .34502 L .52588 .34496 L F
.52574 .34504 m .52561 .34499 L .52614 .34474 L F
.52482 .34511 m .52628 .34491 L .52625 .34487 L F
.52573 .34508 m .52611 .3447 L .52571 .34505 L F
.52482 .34511 m .52581 .34507 L .52628 .34491 L F
.52572 .34523 m .52552 .34515 L .52574 .34504 L F
.52571 .34506 m .52573 .34508 L .52571 .34505 L F
.52059 .34691 m .52605 .34507 L .52606 .34499 L F
.52571 .34506 m .52605 .34506 L .52573 .34508 L F
.52605 .34506 m .52613 .34506 L .52606 .34507 L F
.52605 .34506 m .52606 .34507 L .52573 .34508 L F
.5266 .34487 m .52632 .34496 L p .52614 .34469 L F P
0 g
s
.52632 .34496 m .52611 .3447 L .52614 .34469 L .672 .728 .891 r
F
.52482 .34511 m .52652 .34483 L .5263 .34475 L F
.52551 .34524 m .51784 .34783 L p .5261 .3447 L F P
0 g
s
.51619 .33406 m .51724 .33364 L p .52328 .34117 L .672 .728 .891 r
F P
0 g
s
.52494 .34506 m .52491 .34506 L .52608 .34463 L .672 .728 .891 r
F
.52506 .34485 m .52517 .34488 L .52509 .34485 L F
.52603 .3446 m .52505 .3449 L .52508 .34484 L F
.52517 .34409 m .52495 .34409 L .52486 .34397 L F
.51953 .3365 m .52571 .34506 L .52328 .34117 L F
.51724 .33364 m .52154 .33943 L .51953 .3365 L F
.52154 .33943 m .52571 .34506 L .51953 .3365 L F
.52381 .34548 m .52444 .34523 L .52491 .34506 L F
.51784 .34783 m .50943 .35068 L p .52292 .34583 L F P
0 g
s
.52381 .34548 m .50943 .35068 L .52444 .34523 L .672 .728 .891 r
F
.51001 .35139 m .50943 .35068 L p .52526 .34488 L F P
0 g
s
.52576 .3447 m .52528 .3449 L .52526 .34488 L .672 .728 .891 r
F
.52381 .34548 m .52491 .34506 L .52494 .34506 L F
.52528 .3449 m .51001 .35139 L .52526 .34488 L F
.52612 .34505 m .52613 .34506 L .52605 .34506 L F
.52605 .34505 m .52605 .34506 L .52571 .34506 L F
.52632 .34496 m .52551 .34524 L p .52611 .3447 L F P
0 g
s
.526 .3445 m .52597 .34462 L .525 .3439 L .672 .728 .891 r
F
.52597 .34462 m .52592 .34481 L .52556 .34445 L F
.52597 .34462 m .52556 .34445 L .525 .3439 L F
.52558 .34447 m .52535 .34438 L .525 .3439 L F
.52529 .34437 m .52536 .34446 L .52535 .34447 L F
.52536 .34446 m .52536 .34446 L .52529 .34437 L F
.525 .3439 m .52531 .34434 L .52529 .34437 L F
.52571 .34505 m .52611 .3447 L .52328 .34117 L F
.5261 .3447 m .52611 .3447 L .52611 .3447 L F
.52608 .34461 m .52692 .34451 L .52694 .3445 L F
.5271 .34432 m .5261 .34468 L .52705 .34431 L F
.52705 .34431 m .52608 .34466 L .52701 .3443 L F
.52689 .34424 m .52608 .34458 L .52755 .34441 L F
.52634 .34418 m .52634 .34415 L p .52633 .34421 L F P
0 g
s
.52634 .34415 m .52638 .34235 L p .52625 .34413 L .672 .728 .891 r
F P
0 g
s
.52615 .3441 m .52625 .34413 L .52634 .34289 L .672 .728 .891 r
F
.52677 .34467 m .52328 .34117 L .51953 .3365 L F
.52679 .34469 m .52677 .34467 L .52677 .34467 L F
.52677 .34467 m .52328 .34117 L .52677 .34467 L F
.52208 .33924 m .51953 .3365 L .51724 .33364 L F
.52679 .34469 m .51953 .3365 L .52208 .33924 L F
.52617 .3447 m .52607 .34481 L .5263 .34475 L F
.52633 .34417 m .52675 .34473 L .52675 .34472 L F
.52677 .34467 m .52633 .34417 L .52673 .3447 L F
.5263 .3445 m .52632 .34496 L .52576 .3447 L F
.52625 .34487 m .52628 .34491 L .52652 .34483 L F
.52659 .34487 m .52614 .34469 L .52661 .34485 L F
.52677 .34467 m .52673 .3447 L .53055 .34981 L F
.53099 .35036 m .53055 .34981 L .53529 .35615 L F
.52677 .34467 m .53055 .34981 L .53099 .35036 L F
.52611 .3447 m .52613 .34468 L .52571 .34505 L F
.52605 .34505 m .52659 .34487 L p .52576 .3447 L F P
0 g
s
.5277 .34449 m .52661 .34485 L .52717 .34434 L .672 .728 .891 r
F
.52679 .34469 m .52677 .34467 L .52679 .34469 L F
.5263 .34475 m .52652 .34483 L .52779 .34438 L F
.52675 .34472 m .52675 .34473 L .53529 .35615 L F
.52639 .34505 m .53529 .35615 L p .52673 .34471 L F P
0 g
s
.52711 .34469 m .5266 .34487 L .52661 .34485 L .672 .728 .891 r
F
.5277 .34449 m .52714 .34469 L p .52711 .34469 L F P
0 g
s
.52714 .34469 m .5266 .34487 L p .52711 .34469 L .672 .728 .891 r
F P
0 g
s
.53633 .35574 m .52679 .34469 L .53101 .35038 L .672 .728 .891 r
F
.53529 .35615 m .53555 .35605 L p .53101 .35038 L F P
0 g
s
.53555 .35605 m .53633 .35574 L p .53101 .35038 L .672 .728 .891 r
F P
0 g
s
.52679 .34469 m .52679 .34469 L .53529 .35615 L .672 .728 .891 r
F
.53239 .34291 m .53198 .34305 L .54381 .33996 L F
.52701 .3443 m .53198 .34305 L .53239 .34291 L F
.52701 .3443 m .52701 .34434 L .53198 .34305 L F
.53165 .34316 m .52947 .3439 L .54381 .33996 L F
.527 .34438 m .52947 .3439 L .53165 .34316 L F
.527 .34438 m .52699 .34457 L .52947 .3439 L F
.53004 .34327 m .52806 .34402 L .52977 .34301 L F
.54381 .33996 m .54331 .33921 L p .52701 .3443 L F P
0 g
s
.54331 .33921 m .53071 .34348 L p .53187 .34278 L .672 .728 .891 r
F P
0 g
s
.53071 .34348 m .52857 .3442 L p .53187 .34278 L .672 .728 .891 r
F P
0 g
s
.52857 .3442 m .52782 .34445 L p .52808 .34416 L .672 .728 .891 r
F P
0 g
s
.52659 .34487 m .54331 .33921 L p .53166 .34285 L .672 .728 .891 r
F P
0 g
s
.52694 .3445 m .5276 .34443 L .52755 .34441 L .672 .728 .891 r
F
.52692 .34451 m .5276 .34443 L .52694 .3445 L F
.52633 .34417 m .52636 .34458 L .52673 .34471 L F
.52576 .3447 m .52659 .34487 L .52632 .34453 L F
.52636 .34458 m .52658 .34486 L .52673 .34471 L F
.52605 .34507 m .52779 .34438 L p .52606 .34499 L F P
0 g
s
.5271 .34465 m .52632 .34496 L p .5268 .34432 L .672 .728 .891 r
F P
0 g
s
.52636 .34458 m .52639 .34505 L .52658 .34486 L .672 .728 .891 r
F
.52752 .34417 m .5271 .34432 L .52749 .34414 L F
.5271 .34432 m .52705 .34431 L .52749 .34414 L F
.52749 .34414 m .52705 .34431 L .52701 .3443 L F
.5274 .34402 m .52689 .34424 L .52779 .34438 L F
.52782 .34445 m .5277 .34449 L p .52752 .34417 L F P
0 g
s
.5277 .34449 m .5271 .34432 L .52752 .34417 L .672 .728 .891 r
F
.52689 .34424 m .52755 .34441 L .52779 .34438 L F
.52844 .34408 m .52808 .34416 L .52816 .34407 L F
.52844 .34408 m .52816 .34407 L .52831 .34389 L F
.52847 .34408 m .52844 .34408 L .52831 .34389 L F
.52819 .34368 m .5274 .34402 L .52853 .34409 L F
.52857 .3442 m .52808 .34416 L .52847 .34408 L F
.52782 .34445 m .52752 .34417 L .52831 .34389 L F
.52831 .34389 m .52752 .34417 L .52749 .34414 L F
.52779 .34438 m .52853 .34409 L p .5274 .34402 L F P
0 g
s
.53187 .34278 m .52857 .3442 L .52831 .34389 L .672 .728 .891 r
F
.53421 .34137 m .54209 .33779 L p .53584 .34039 L F P
0 g
s
.53145 .34229 m .53034 .34287 L p .53097 .34219 L .672 .728 .891 r
F P
0 g
s
.53034 .34287 m .52987 .34278 L .53097 .34219 L .672 .728 .891 r
F
.54139 .33712 m .53145 .34229 L p .53097 .34219 L F P
0 g
s
.5277 .34378 m .53421 .34137 L .53584 .34039 L .672 .728 .891 r
F
.54209 .33779 m .53004 .34327 L p .52977 .34301 L F P
0 g
s
.52853 .34409 m .54274 .33849 L p .52819 .34368 L .672 .728 .891 r
F P
0 g
s
.54331 .33921 m .54274 .33849 L p .5263 .3445 L .672 .728 .891 r
F P
0 g
s
.5263 .3445 m .52576 .3447 L .52632 .34453 L .672 .728 .891 r
F
.5263 .3445 m .52632 .34453 L .54331 .33921 L F
.52692 .34451 m .52681 .34462 L .5276 .34443 L F
.52755 .34441 m .5276 .34443 L .52779 .34438 L F
.52632 .34453 m .52658 .34486 L .53166 .34285 L F
.5266 .34487 m .52659 .34487 L .52661 .34485 L F
.52658 .34486 m .52659 .34487 L .53166 .34285 L F
.52649 .34474 m .52632 .34496 L .5263 .3445 L F
.52566 .34415 m .52639 .34505 L p .52636 .34458 L F P
0 g
s
.52633 .34417 m .52602 .34416 L .52636 .34458 L .672 .728 .891 r
F
.52602 .34416 m .52566 .34415 L .52636 .34458 L F
.5268 .34432 m .52649 .34474 L .5263 .3445 L F
.54274 .33849 m .5271 .34465 L p .5268 .34432 L F P
0 g
s
.52632 .34496 m .52606 .34507 L p .52605 .34505 L .672 .728 .891 r
F P
0 g
s
.52632 .34496 m .52605 .34505 L .52576 .3447 L .672 .728 .891 r
F
.52612 .34505 m .52605 .34506 L .52605 .34505 L F
.52551 .34524 m .5261 .3447 L .52611 .3447 L F
.52571 .34506 m .52571 .34505 L .52328 .34117 L F
.52532 .34454 m .52612 .34505 L .52571 .34506 L F
.52573 .34508 m .52697 .34578 L .5263 .34585 L F
.52613 .34506 m .52697 .34578 L .52573 .34508 L F
.52572 .34523 m .52189 .34698 L p .52552 .34515 L F P
0 g
s
.50943 .35068 m .52605 .34505 L p .52576 .3447 L .672 .728 .891 r
F P
0 g
s
.52209 .34663 m .52605 .34507 L p .52059 .34691 L .672 .728 .891 r
F P
0 g
s
.51001 .35139 m .52209 .34663 L p .52059 .34691 L .672 .728 .891 r
F P
0 g
s
.52606 .34507 m .51001 .35139 L p .52576 .3447 L .672 .728 .891 r
F P
0 g
s
.52633 .34417 m .52633 .34417 L .52675 .34473 L .672 .728 .891 r
F
.52566 .34415 m .52639 .34505 L p .5254 .34445 L F P
0 g
s
.52639 .34505 m .52697 .34578 L p .52612 .34505 L .672 .728 .891 r
F P
0 g
s
.52639 .34505 m .52612 .34505 L .5254 .34445 L .672 .728 .891 r
F
.52628 .3441 m .52566 .34415 L .52633 .34417 L F
.52633 .34417 m .52628 .3441 L .52633 .34417 L F
.52826 .34423 m .52961 .34399 L .53037 .34365 L F
.52856 .34424 m .52961 .34399 L .52826 .34423 L F
.52539 .34381 m .52566 .34415 L p .52502 .34412 L F P
0 g
s
.52566 .34415 m .5254 .34445 L .52502 .34412 L .672 .728 .891 r
F
.52502 .34412 m .5254 .34445 L .52532 .34454 L F
.5254 .34445 m .52612 .34505 L .52532 .34454 L F
.51724 .33364 m .52566 .34415 L p .52628 .3441 L F P
0 g
s
.51759 .34746 m .50892 .34994 L p .51611 .34773 L .672 .728 .891 r
F P
0 g
s
.51965 .34659 m .52221 .34597 L .52228 .3459 L .672 .728 .891 r
F
.50892 .34994 m .51921 .34699 L p .51965 .34659 L F P
0 g
s
.50943 .35068 m .50892 .34994 L p .52456 .34506 L .672 .728 .891 r
F P
0 g
s
.52479 .34506 m .50943 .35068 L .52456 .34506 L .672 .728 .891 r
F
.51724 .33364 m .52539 .34381 L p .52502 .34412 L F P
0 g
s
.52042 .34804 m .519 .34877 L p .5206 .34788 L .672 .728 .891 r
F P
0 g
s
.519 .34877 m .51138 .35274 L p .51941 .34842 L .672 .728 .891 r
F P
0 g
s
.53037 .34365 m .53079 .34368 L .53067 .34357 L .672 .728 .891 r
F
.52961 .34399 m .53079 .34368 L .53037 .34365 L F
.50892 .34994 m .50847 .34917 L p .52508 .34484 L F P
0 g
s
.52505 .3449 m .50892 .34994 L .52508 .34484 L .672 .728 .891 r
F
.53529 .35615 m .53421 .35651 L p .5263 .34585 L F P
0 g
s
.52697 .34578 m .53529 .35615 L p .5263 .34585 L .672 .728 .891 r
F P
0 g
s
.53421 .35651 m .5331 .35683 L p .52605 .34559 L .672 .728 .891 r
F P
0 g
s
.52482 .34573 m .52372 .34651 L .52491 .34553 L .672 .728 .891 r
F
.52189 .34698 m .51066 .35208 L p .52093 .34721 L F P
0 g
s
.54274 .33849 m .54209 .33779 L p .52819 .34368 L .672 .728 .891 r
F P
0 g
s
.52454 .3435 m .51421 .33503 L p .5245 .34345 L .672 .728 .891 r
F P
0 g
s
.52578 .34528 m .52477 .34588 L p .52563 .34524 L .672 .728 .891 r
F P
0 g
s
.52477 .34588 m .52372 .34651 L p .52467 .34583 L .672 .728 .891 r
F P
0 g
s
.53257 .3438 m .53271 .34381 L .54488 .34232 L .672 .728 .891 r
F
.5383 .35479 m .53657 .35337 L p .53739 .354 L F P
0 g
s
.54209 .33779 m .54139 .33712 L p .5277 .34378 L .672 .728 .891 r
F P
0 g
s
.54139 .33712 m .54062 .33648 L p .52699 .34406 L .672 .728 .891 r
F P
0 g
s
.53633 .35574 m .53734 .35529 L p .52819 .3461 L .672 .728 .891 r
F P
0 g
s
.5248 .34386 m .52364 .34303 L p .52432 .34318 L .672 .728 .891 r
F P
0 g
s
.52898 .34638 m .52813 .34573 L .52895 .34663 L .672 .728 .891 r
F
.52813 .34573 m .52743 .3452 L .52895 .34663 L F
.53973 .35243 m .53302 .34869 L .53299 .34865 L F
.54083 .35305 m .53974 .35244 L .53973 .35243 L F
.54087 .35307 m .54083 .35305 L .54083 .35305 L F
.53079 .34368 m .54381 .33996 L p .53067 .34357 L F P
0 g
s
.50856 .34749 m .50781 .3476 L p .50853 .34747 L .672 .728 .891 r
F P
0 g
s
.52267 .34508 m .52274 .34509 L .5228 .34508 L .672 .728 .891 r
F
.52274 .34509 m .52309 .34515 L .5228 .34508 L F
.52418 .3448 m .52182 .3454 L .52276 .34497 L F
.51377 .34661 m .51033 .34718 L .51418 .34664 L F
.50781 .3476 m .51049 .34722 L p .51033 .34718 L F P
0 g
s
.5081 .34839 m .50781 .3476 L p .52456 .34483 L .672 .728 .891 r
F P
0 g
s
.51223 .35343 m .51215 .35337 L p .51262 .35308 L .672 .728 .891 r
F P
0 g
s
.54062 .33648 m .53979 .33587 L p .52743 .34369 L .672 .728 .891 r
F P
0 g
s
.52707 .34482 m .52856 .34464 L .52857 .34461 L .672 .728 .891 r
F
.52707 .34484 m .52856 .34464 L .52707 .34482 L F
.52699 .34487 m .52856 .34464 L p .52696 .34486 L F P
0 g
s
.52856 .34464 m .54488 .34232 L p .52857 .34461 L .672 .728 .891 r
F P
0 g
s
.50856 .34749 m .50853 .34747 L .52276 .34497 L .672 .728 .891 r
F
.526 .34375 m .52599 .34372 L p .526 .34375 L F P
0 g
s
.52745 .34487 m .52872 .34494 L .52886 .34488 L .672 .728 .891 r
F
.52699 .34491 m .52846 .34483 L .52703 .34488 L F
.52708 .34489 m .52714 .34488 L p .52704 .34488 L F P
0 g
s
.52502 .3461 m .5252 .34593 L .5252 .34593 L .672 .728 .891 r
F
.52574 .34546 m .52579 .34541 L .52579 .34541 L F
.52505 .34426 m .52489 .34417 L p .52498 .34416 L F P
0 g
s
.52887 .34577 m .52882 .34596 L .54087 .35307 L .672 .728 .891 r
F
.54007 .35368 m .54087 .35307 L p .52838 .34564 L F P
0 g
s
.52838 .34564 m .52833 .34573 L .54007 .35368 L .672 .728 .891 r
F
.52814 .34463 m .5281 .34468 L .54488 .34232 L F
.52573 .34545 m .5258 .34539 L .52574 .34546 L F
.5258 .34539 m .52579 .34541 L .52574 .34546 L F
.52528 .34587 m .52574 .34546 L .52574 .34546 L F
.5331 .35683 m .53196 .3571 L p .52833 .35009 L F P
0 g
s
.52089 .34496 m .52166 .34494 L .52167 .34494 L .672 .728 .891 r
F
.52433 .34478 m .52182 .3454 L .52418 .3448 L F
.53979 .33587 m .5389 .33531 L p .52719 .34374 L F P
0 g
s
.52769 .34516 m .5272 .3449 L .52773 .34532 L .672 .728 .891 r
F
.52089 .34496 m .51721 .34524 L .52106 .34506 L F
.51721 .34524 m .51139 .34568 L .51816 .34533 L F
.51662 .34548 m .51861 .34538 L p .51638 .34542 L F P
0 g
s
.51638 .34542 m .51861 .34538 L .51816 .34533 L .672 .728 .891 r
F
.51179 .34575 m .51662 .34548 L p .51139 .34568 L F P
0 g
s
.51139 .34568 m .51662 .34548 L .51638 .34542 L .672 .728 .891 r
F
.50744 .34598 m .51179 .34575 L p .51139 .34568 L F P
0 g
s
.50759 .34679 m .50744 .34598 L p .52445 .34469 L .672 .728 .891 r
F P
0 g
s
.51961 .34535 m .51527 .34587 L .52018 .34542 L .672 .728 .891 r
F
.50759 .34679 m .51625 .34595 L p .51527 .34587 L F P
0 g
s
.50781 .3476 m .50759 .34679 L p .52276 .34497 L .672 .728 .891 r
F P
0 g
s
.53796 .33478 m .53527 .33713 L p .53541 .33687 L .672 .728 .891 r
F P
0 g
s
.5389 .33531 m .53796 .33478 L p .52701 .34375 L .672 .728 .891 r
F P
0 g
s
.52176 .34942 m .51578 .35551 L .52186 .34906 L .672 .728 .891 r
F
.52528 .34587 m .52574 .34546 L .52574 .34546 L F
.52703 .34488 m .52846 .34483 L .52852 .3448 L F
.53921 .35426 m .54007 .35368 L p .53103 .34757 L F P
0 g
s
.52575 .34551 m .52575 .34551 L .5253 .34597 L .672 .728 .891 r
F
.5253 .34597 m .5253 .34597 L .52496 .34631 L F
.52575 .34551 m .52575 .34551 L .52496 .34631 L F
.52783 .34494 m .52814 .34494 L .52782 .34493 L F
.52502 .3461 m .52573 .34545 L .52574 .34546 L F
.52741 .34494 m .52783 .34495 L .52741 .34494 L F
.52736 .34495 m .52783 .34495 L p .5273 .34494 L F P
0 g
s
.52783 .34495 m .52814 .34494 L p .52783 .34494 L .672 .728 .891 r
F P
0 g
s
.52814 .34494 m .52872 .34494 L p .52813 .34493 L .672 .728 .891 r
F P
0 g
s
.53734 .35529 m .5383 .35479 L p .5332 .35032 L .672 .728 .891 r
F P
0 g
s
.52724 .34493 m .52742 .34493 L .52723 .34492 L .672 .728 .891 r
F
.53582 .33545 m .53205 .33923 L p .53593 .33527 L F P
0 g
s
.53205 .33923 m .53208 .33913 L .53593 .33527 L .672 .728 .891 r
F
.53593 .33527 m .53208 .33913 L .53226 .33871 L F
.53697 .33429 m .53582 .33545 L p .53593 .33527 L F P
0 g
s
.53796 .33478 m .53697 .33429 L p .52953 .34126 L .672 .728 .891 r
F P
0 g
s
.52953 .34126 m .52948 .34169 L .53796 .33478 L .672 .728 .891 r
F
.52502 .3461 m .52492 .34612 L .52568 .34544 L F
.52502 .3461 m .52568 .34544 L .52572 .34545 L F
.52497 .34631 m .52571 .34557 L .52571 .34557 L F
.5257 .34557 m .5257 .34557 L .52565 .34562 L F
.52564 .34562 m .52565 .34562 L .52496 .34631 L F
.52496 .34631 m .52564 .34562 L .52496 .34631 L F
.52319 .34832 m .52228 .34942 L .5232 .34828 L F
.52228 .34942 m .51681 .35594 L .5223 .34933 L F
.52716 .34491 m .52872 .34494 L .52716 .34491 L F
.52528 .34587 m .52502 .3461 L p .52527 .34588 L F P
0 g
s
.52502 .3461 m .5148 .35504 L p .52492 .34612 L .672 .728 .891 r
F P
0 g
s
.52887 .34577 m .52769 .34516 L .52882 .34596 L .672 .728 .891 r
F
.52912 .34482 m .52741 .34495 L .52736 .34494 L F
.52742 .34491 m .52872 .34494 L .52745 .34487 L F
.54147 .35137 m .52736 .34494 L .54216 .35189 L F
.52736 .34494 m .52735 .34496 L .54216 .35189 L F
.53011 .34484 m .5309 .34506 L .54524 .34558 L F
.54526 .34476 m .52909 .34493 L p .52912 .34482 L F P
0 g
s
.54087 .35307 m .54162 .35243 L p .52887 .34577 L .672 .728 .891 r
F P
0 g
s
.52871 .34484 m .52886 .34488 L .52895 .34484 L .672 .728 .891 r
F
.52531 .34453 m .52516 .34447 L p .52531 .34453 L F P
0 g
s
.52572 .34554 m .52571 .34557 L .52573 .34554 L .672 .728 .891 r
F
.52573 .34554 m .52574 .34554 L .52573 .34557 L F
.52571 .34557 m .5257 .34557 L .52575 .34552 L F
.52571 .34557 m .52575 .34552 L .52574 .34553 L F
.52573 .34581 m .526 .34612 L .52573 .3459 L F
.52394 .3476 m .51681 .35594 L .52395 .34756 L F
.52394 .3476 m .52395 .34756 L .52574 .34545 L F
.52852 .3448 m .53058 .34473 L .53067 .34469 L F
.52846 .34483 m .53058 .34473 L .52852 .3448 L F
.52961 .35748 m .52842 .3576 L p .52668 .34951 L F P
0 g
s
.52516 .34447 m .52516 .34447 L .52531 .34453 L .672 .728 .891 r
F
.52516 .34447 m .52531 .34453 L .52531 .34453 L F
.52725 .34491 m .53058 .34473 L p .52725 .34489 L F P
0 g
s
.53058 .34473 m .54521 .34394 L p .53067 .34469 L .672 .728 .891 r
F P
0 g
s
.52497 .34631 m .52496 .34631 L .5257 .34557 L .672 .728 .891 r
F
.52497 .34631 m .5257 .34557 L .52571 .34557 L F
.52497 .34631 m .52327 .34801 L p .52496 .34631 L F P
0 g
s
.52496 .34631 m .52592 .34535 L .52592 .34535 L .672 .728 .891 r
F
.52327 .34801 m .52496 .34631 L .52496 .34631 L F
.52496 .34631 m .52493 .34632 L .52568 .34557 L F
.52496 .34631 m .52568 .34557 L .52569 .34557 L F
.52327 .34801 m .52322 .34804 L .52493 .34632 L F
.52327 .34801 m .52493 .34632 L .52496 .34631 L F
.52842 .3576 m .52721 .35766 L p .52606 .34794 L F P
0 g
s
.53196 .3571 m .53079 .35731 L p .52893 .3528 L .672 .728 .891 r
F P
0 g
s
.52469 .34427 m .52469 .34427 L .52516 .34447 L .672 .728 .891 r
F
.52469 .34427 m .52516 .34447 L .52516 .34447 L F
.52516 .34447 m .52469 .34427 L p .52516 .34447 L F P
0 g
s
.52742 .34493 m .52872 .34494 L .52742 .34491 L .672 .728 .891 r
F
.52742 .34493 m .52872 .34494 L .52742 .34493 L F
.51632 .34444 m .50739 .34434 L .51568 .34461 L F
.51932 .3445 m .50739 .34434 L .52028 .34422 L F
.5139 .34509 m .50738 .34516 L p .51632 .34444 L F P
0 g
s
.50738 .34516 m .51611 .34507 L p .51536 .3449 L .672 .728 .891 r
F P
0 g
s
.50744 .34598 m .50738 .34516 L p .51954 .34477 L .672 .728 .891 r
F P
0 g
s
.53079 .35731 m .52961 .35748 L p .52763 .35115 L .672 .728 .891 r
F P
0 g
s
.5264 .34405 m .52635 .34416 L .52642 .34409 L .672 .728 .891 r
F
.52641 .3441 m .52642 .34399 L .52642 .34399 L F
.52641 .3441 m .52642 .34399 L .52641 .3441 L F
.52639 .34402 m .52642 .34409 L .5269 .34357 L F
.52722 .34339 m .52721 .34332 L .52778 .34263 L F
.52872 .34494 m .54526 .34476 L p .52895 .34484 L F P
0 g
s
.52469 .34427 m .52468 .34425 L .52531 .34452 L .672 .728 .891 r
F
.52469 .34427 m .52531 .34452 L .52531 .34453 L F
.52377 .34388 m .52376 .34386 L .52468 .34425 L F
.52377 .34388 m .52468 .34425 L .52469 .34427 L F
.52552 .34604 m .52554 .34601 L .52554 .34601 L F
.52642 .344 m .52662 .34355 L .52642 .344 L F
.52627 .34405 m .52639 .34401 L .53487 .33345 L F
.52649 .34385 m .52662 .34355 L .52648 .34386 L F
.52648 .34361 m .52642 .34409 L p .52647 .34362 L F P
0 g
s
.52642 .34409 m .52641 .3441 L .52647 .34362 L .672 .728 .891 r
F
.52778 .34263 m .5268 .34381 L .52676 .34372 L F
.52469 .34427 m .52377 .34388 L p .52469 .34427 L F P
0 g
s
.52848 .34187 m .52779 .3427 L .52778 .34263 L .672 .728 .891 r
F
.52377 .34388 m .51022 .33812 L p .52376 .34386 L F P
0 g
s
.52451 .34445 m .5235 .3444 L .52464 .34455 L .672 .728 .891 r
F
.52511 .34448 m .52409 .34452 L .52397 .34442 L F
.5252 .34449 m .52451 .34445 L .52532 .34458 L F
.52517 .34453 m .52409 .34452 L .52511 .34448 L F
.52601 .35767 m .52618 .35073 L p .52583 .35005 L F P
0 g
s
.52721 .35766 m .52601 .35767 L p .52573 .3459 L .672 .728 .891 r
F P
0 g
s
.5235 .3444 m .52198 .34431 L .52371 .34451 L .672 .728 .891 r
F
.52397 .34442 m .51932 .3445 L .52028 .34422 L F
.52409 .34452 m .51932 .3445 L .52397 .34442 L F
.52716 .34306 m .52673 .34381 L .52667 .34366 L F
.52929 .3404 m .52787 .34251 L .52789 .34215 L F
.53445 .33398 m .52901 .34131 L .52929 .3404 L F
.52667 .34366 m .5269 .34357 L .53594 .33385 L F
.52848 .34188 m .52847 .34189 L .52848 .34187 L F
.52847 .34204 m .52847 .34189 L .52848 .34188 L F
.52847 .34204 m .52781 .34282 L .52847 .34189 L F
.52781 .34282 m .52779 .3427 L .52848 .34187 L F
.52975 .3405 m .52847 .34204 L .52848 .34187 L F
.53214 .33794 m .52966 .34084 L .52975 .3405 L F
.53594 .33385 m .53181 .33862 L p .53214 .33794 L F P
0 g
s
.53697 .33429 m .53594 .33385 L p .52676 .34372 L .672 .728 .891 r
F P
0 g
s
.5423 .35175 m .54117 .35127 L p .54147 .35137 L .672 .728 .891 r
F P
0 g
s
.52269 .34419 m .52152 .34407 L .52291 .34427 L .672 .728 .891 r
F
.52152 .34407 m .5168 .34361 L .52291 .34427 L F
.50765 .34271 m .51921 .3441 L p .5168 .34361 L F P
0 g
s
.50748 .34352 m .50765 .34271 L p .5244 .34436 L .672 .728 .891 r
F P
0 g
s
.52434 .34439 m .50748 .34352 L .5244 .34436 L .672 .728 .891 r
F
.52444 .34434 m .52463 .3444 L .52457 .34426 L F
.52436 .34435 m .52442 .34437 L .52436 .34435 L F
.52442 .34437 m .52442 .34437 L .52436 .34435 L F
.50738 .34516 m .50739 .34434 L p .51632 .34444 L F P
0 g
s
.54162 .35243 m .54216 .35189 L p .53348 .34788 L .672 .728 .891 r
F P
0 g
s
.53026 .34526 m .53097 .34532 L .53099 .34532 L .672 .728 .891 r
F
.53028 .34526 m .53097 .34532 L .53026 .34526 L F
.52525 .34667 m .52526 .34665 L p .52525 .34666 L F P
0 g
s
.52525 .34666 m .52526 .34665 L .52526 .34664 L .672 .728 .891 r
F
.52526 .34665 m .52525 .34667 L p .52527 .34663 L F P
0 g
s
.52923 .3452 m .52929 .34521 L .52923 .3452 L .672 .728 .891 r
F
.52435 .34435 m .52436 .34435 L .52436 .34435 L F
.52436 .34435 m .52497 .3444 L .52436 .34435 L F
.52436 .34435 m .52442 .34437 L .52441 .34436 L F
.52435 .34435 m .52436 .34435 L .52436 .34435 L F
.50748 .34352 m .50806 .34357 L p .50784 .34354 L F P
0 g
s
.50739 .34434 m .50748 .34352 L p .52028 .34422 L .672 .728 .891 r
F P
0 g
s
.52642 .34399 m .52646 .34363 L .52642 .34398 L .672 .728 .891 r
F
.52327 .34801 m .51578 .35551 L p .52322 .34804 L F P
0 g
s
.5383 .35479 m .53921 .35426 L p .53462 .35073 L .672 .728 .891 r
F P
0 g
s
.52642 .34399 m .52642 .34399 L .52646 .34363 L .672 .728 .891 r
F
.52566 .34574 m .52531 .3463 L .52575 .34553 L F
.52789 .34215 m .52719 .34328 L .52716 .34306 L F
.53487 .33345 m .53433 .33419 L p .53445 .33398 L F P
0 g
s
.53594 .33385 m .53487 .33345 L p .52667 .34366 L .672 .728 .891 r
F P
0 g
s
.5423 .35175 m .54292 .35105 L p .53786 .34905 L .672 .728 .891 r
F P
0 g
s
.53296 .34576 m .53296 .34576 L .53409 .34589 L .672 .728 .891 r
F
.53409 .3459 m .53409 .34589 L .54461 .34716 L F
.54216 .35189 m .5423 .35175 L p .54147 .35137 L F P
0 g
s
.54483 .3472 m .52899 .34528 L p .54461 .34716 L .672 .728 .891 r
F P
0 g
s
.52899 .34528 m .52899 .34528 L .54461 .34716 L .672 .728 .891 r
F
.52425 .34825 m .52526 .34664 L .52526 .34664 L F
.51909 .35646 m .52425 .34826 L .52425 .34825 L F
.52642 .34409 m .52648 .34361 L p .52639 .34404 L F P
0 g
s
.52898 .34528 m .52897 .34528 L .52874 .34503 L .672 .728 .891 r
F
.52435 .34435 m .52409 .34414 L .52497 .3444 L F
.5248 .35763 m .5236 .35754 L p .52483 .35022 L F P
0 g
s
.52361 .34967 m .52326 .3504 L .52365 .34953 L .672 .728 .891 r
F
.51901 .3566 m .52525 .34667 L p .51909 .35646 L F P
0 g
s
.51909 .35646 m .52525 .34667 L .52525 .34666 L .672 .728 .891 r
F
.52525 .34667 m .52572 .3456 L .52527 .34662 L F
.52642 .34399 m .52663 .34351 L .52642 .34399 L F
.52662 .34355 m .52655 .3437 L .5267 .34353 L F
.52662 .34355 m .5267 .34353 L .53487 .33345 L F
.52663 .34352 m .52663 .34351 L p .52663 .34352 L F P
0 g
s
.52957 .34538 m .53248 .34598 L .52957 .34537 L .672 .728 .891 r
F
.52809 .3451 m .53097 .34532 L p .52809 .3451 L F P
0 g
s
.53097 .34532 m .54513 .3464 L p .53099 .34532 L .672 .728 .891 r
F P
0 g
s
.53376 .33311 m .53262 .33281 L p .52711 .34243 L .672 .728 .891 r
F P
0 g
s
.52711 .34243 m .52669 .34339 L .53376 .33311 L .672 .728 .891 r
F
.53284 .34576 m .53303 .34582 L .54469 .34801 L F
.5379 .34843 m .53046 .34591 L .5431 .3508 L F
.52424 .34898 m .52422 .349 L p .52472 .34788 L F P
0 g
s
.52424 .34898 m .52472 .34788 L .52472 .34788 L .672 .728 .891 r
F
.52784 .34507 m .52903 .34529 L .52915 .34525 L F
.52803 .34505 m .52915 .34525 L .52929 .34521 L F
.52525 .34667 m .51901 .3566 L p .525 .34678 L F P
0 g
s
.52663 .34351 m .5269 .34227 L p .52653 .34328 L .672 .728 .891 r
F P
0 g
s
.52552 .34604 m .51787 .35633 L p .52551 .34604 L .672 .728 .891 r
F P
0 g
s
.52435 .34435 m .51541 .34155 L p .52409 .34414 L .672 .728 .891 r
F P
0 g
s
.52326 .3504 m .52009 .35696 L .5229 .35092 L .672 .728 .891 r
F
.5431 .3508 m .54347 .35032 L p .5379 .34843 L F P
0 g
s
.52376 .35029 m .52124 .35721 L .52404 .34992 L .672 .728 .891 r
F
.51901 .3566 m .51897 .35667 L p .519 .35661 L F P
0 g
s
.54495 .34721 m .54495 .3472 L p .54485 .3472 L .672 .728 .891 r
F P
0 g
s
.54495 .3472 m .54513 .3464 L p .54485 .3472 L .672 .728 .891 r
F P
0 g
s
.54395 .34957 m .54384 .34954 L p .54391 .34956 L .672 .728 .891 r
F P
0 g
s
.54347 .35032 m .54395 .34957 L p .53146 .34599 L .672 .728 .891 r
F P
0 g
s
.52926 .34534 m .54377 .34952 L .54372 .3495 L .672 .728 .891 r
F
.52929 .34521 m .53227 .34568 L .53335 .34573 L F
.52915 .34525 m .53227 .34568 L .52929 .34521 L F
.52903 .34529 m .53227 .34568 L p .52915 .34525 L F P
0 g
s
.53227 .34568 m .54495 .34721 L p .53335 .34573 L .672 .728 .891 r
F P
0 g
s
.52422 .349 m .52009 .35696 L p .52326 .3504 L .672 .728 .891 r
F P
0 g
s
.52242 .3574 m .52124 .35721 L p .52424 .34897 L .672 .728 .891 r
F P
0 g
s
.52246 .35724 m .52242 .3574 L .52424 .34897 L .672 .728 .891 r
F
.52242 .3574 m .52244 .35732 L p .52242 .35737 L F P
0 g
s
.53262 .33281 m .53146 .33256 L p .52721 .34221 L .672 .728 .891 r
F P
0 g
s
.52806 .33691 m .52907 .33221 L .5284 .33216 L p .672 .728 .891 r
F P
0 g
s
.5284 .33216 m .52785 .33212 L p .52806 .33691 L .672 .728 .891 r
F P
0 g
s
.53248 .34598 m .54469 .34801 L p .53475 .3462 L .672 .728 .891 r
F P
0 g
s
.51727 .34293 m .50821 .34111 L .51744 .34296 L .672 .728 .891 r
F
.50789 .3419 m .50821 .34111 L p .52168 .34381 L F P
0 g
s
.5236 .35754 m .52242 .3574 L p .52479 .34843 L .672 .728 .891 r
F P
0 g
s
.51541 .34155 m .50908 .33957 L .50937 .33917 L p .672 .728 .891 r
F P
0 g
s
.50937 .33917 m .50962 .33884 L p .51541 .34155 L .672 .728 .891 r
F P
0 g
s
.35286 .80921 m .3519 .77646 L .368 .7838 L p .848 .56 .501 r
F P
0 g
s
.368 .7838 m .36902 .81645 L .35286 .80921 L p .848 .56 .501 r
F P
0 g
s
.55984 .83152 m .55927 .86204 L .54048 .86487 L p .626 .356 .489 r
F P
0 g
s
.55927 .86204 m .55984 .83152 L .57849 .82792 L p .61 .346 .493 r
F P
0 g
s
.35364 .38155 m .39226 .36757 L .39422 .37334 L p .762 .772 .861 r
F P
0 g
s
.39422 .37334 m .35641 .38899 L .35364 .38155 L p .762 .772 .861 r
F P
0 g
s
.43262 .36202 m .39422 .37334 L .39226 .36757 L p .726 .756 .876 r
F P
0 g
s
.42516 .86282 m .42277 .8326 L .44205 .83577 L p .752 .444 .464 r
F P
0 g
s
.44205 .83577 m .444 .86585 L .42516 .86282 L p .752 .444 .464 r
F P
0 g
s
.50847 .34917 m .47265 .3586 L .47149 .35626 L p .682 .733 .889 r
F P
0 g
s
.47265 .3586 m .50847 .34917 L .50892 .34994 L p .682 .732 .888 r
F P
0 g
s
.73179 .41235 m .7648 .43772 L .76916 .42792 L p .496 .533 .824 r
F P
0 g
s
.76916 .42792 m .73546 .40377 L .73179 .41235 L p .496 .533 .824 r
F P
0 g
s
.69895 .73215 m .70012 .76424 L .71723 .75923 L p .555 .346 .552 r
F P
0 g
s
.71723 .75923 m .716 .72689 L .69895 .73215 L p .555 .346 .552 r
F P
0 g
s
.64908 .77845 m .64916 .81054 L .63195 .81509 L p .573 .349 .537 r
F P
0 g
s
.64916 .81054 m .64908 .77845 L .6661 .77378 L p .566 .343 .536 r
F P
0 g
s
.31715 .40063 m .35364 .38155 L .35641 .38899 L p .803 .787 .838 r
F P
0 g
s
.35641 .38899 m .32086 .40965 L .31715 .40063 L p .803 .787 .838 r
F P
0 g
s
.58059 .35745 m .54435 .3488 L .54395 .34957 L p .665 .719 .889 r
F P
0 g
s
.54435 .3488 m .58059 .35745 L .58164 .35509 L p .665 .719 .889 r
F P
0 g
s
.39226 .36757 m .43133 .35795 L .43262 .36202 L p .726 .756 .876 r
F P
0 g
s
.47055 .35388 m .43262 .36202 L .43133 .35795 L p .699 .743 .885 r
F P
0 g
s
.43262 .36202 m .47055 .35388 L .47149 .35626 L p .699 .741 .884 r
F P
0 g
s
.77513 .63271 m .7804 .66708 L .79592 .65843 L p .481 .321 .588 r
F P
0 g
s
.79592 .65843 m .79003 .62367 L .77513 .63271 L p .481 .321 .588 r
F P
0 g
s
.25751 .56357 m .26881 .52972 L .27817 .53966 L p .918 .732 .634 r
F P
0 g
s
.27817 .53966 m .26748 .57369 L .25751 .56357 L p .918 .732 .634 r
F P
0 g
s
.62074 .35994 m .65967 .37017 L .66131 .36447 L p .625 .68 .882 r
F P
0 g
s
.65967 .37017 m .6984 .38454 L .70062 .37728 L p .588 .643 .873 r
F P
0 g
s
.70062 .37728 m .66131 .36447 L .65967 .37017 L p .588 .643 .873 r
F P
0 g
s
.5081 .34839 m .47149 .35626 L .47055 .35388 L p .682 .733 .889 r
F P
0 g
s
.47149 .35626 m .5081 .34839 L .50847 .34917 L p .682 .733 .889 r
F P
0 g
s
.7476 .68215 m .7502 .71515 L .7671 .70845 L p .521 .331 .564 r
F P
0 g
s
.7671 .70845 m .76421 .67497 L .7476 .68215 L p .521 .331 .564 r
F P
0 g
s
.27819 .65846 m .28215 .62597 L .29329 .63499 L p .925 .687 .559 r
F P
0 g
s
.29329 .63499 m .2894 .66766 L .27819 .65846 L p .925 .687 .559 r
F P
0 g
s
.57849 .82792 m .57768 .85865 L .55927 .86204 L p .61 .346 .493 r
F P
0 g
s
.57768 .85865 m .57849 .82792 L .59669 .82388 L p .595 .337 .496 r
F P
0 g
s
.62074 .35994 m .58247 .35269 L .58164 .35509 L p .651 .704 .886 r
F P
0 g
s
.58247 .35269 m .62074 .35994 L .62183 .35587 L p .649 .705 .887 r
F P
0 g
s
.66131 .36447 m .62183 .35587 L .62074 .35994 L p .625 .68 .882 r
F P
0 g
s
.58164 .35509 m .54469 .34801 L .54435 .3488 L p .665 .719 .889 r
F P
0 g
s
.54469 .34801 m .58164 .35509 L .58247 .35269 L p .664 .719 .89 r
F P
0 g
s
.79413 .57846 m .80399 .61392 L .81674 .60348 L p .431 .32 .626 r
F P
0 g
s
.81674 .60348 m .80608 .56797 L .79413 .57846 L p .431 .32 .626 r
F P
0 g
s
.6984 .38454 m .73546 .40377 L .73823 .39509 L p .539 .594 .857 r
F P
0 g
s
.73823 .39509 m .70062 .37728 L .6984 .38454 L p .539 .594 .857 r
F P
0 g
s
.40685 .8587 m .40407 .82828 L .42277 .8326 L p .775 .463 .459 r
F P
0 g
s
.42277 .8326 m .42516 .86282 L .40685 .8587 L p .775 .463 .459 r
F P
0 g
s
.43133 .35795 m .46984 .35145 L .47055 .35388 L p .699 .743 .885 r
F P
0 g
s
.50781 .3476 m .47055 .35388 L .46984 .35145 L p .682 .734 .889 r
F P
0 g
s
.47055 .35388 m .50781 .3476 L .5081 .34839 L p .682 .733 .889 r
F P
0 g
s
.39082 .3617 m .43043 .35381 L .43133 .35795 L p .726 .759 .879 r
F P
0 g
s
.43133 .35795 m .39226 .36757 L .39082 .3617 L p .726 .759 .879 r
F P
0 g
s
.46984 .35145 m .43133 .35795 L .43043 .35381 L p .699 .744 .887 r
F P
0 g
s
.35154 .37396 m .39082 .3617 L .39226 .36757 L p .762 .777 .866 r
F P
0 g
s
.39226 .36757 m .35364 .38155 L .35154 .37396 L p .762 .777 .866 r
F P
0 g
s
.58247 .35269 m .54495 .34721 L .54469 .34801 L p .664 .719 .89 r
F P
0 g
s
.54495 .34721 m .58247 .35269 L .58307 .35025 L p .664 .719 .89 r
F P
0 g
s
.62183 .35587 m .58307 .35025 L .58247 .35269 L p .649 .705 .887 r
F P
0 g
s
.26349 .46462 m .28939 .43515 L .29495 .44517 L p .882 .788 .753 r
F P
0 g
s
.29495 .44517 m .27016 .47559 L .26349 .46462 L p .882 .788 .753 r
F P
0 g
s
.28464 .42478 m .31715 .40063 L .32086 .40965 L p .846 .798 .804 r
F P
0 g
s
.32086 .40965 m .28939 .43515 L .28464 .42478 L p .846 .798 .804 r
F P
0 g
s
.716 .72689 m .71723 .75923 L .73438 .75392 L p .545 .337 .549 r
F P
0 g
s
.73438 .75392 m .73311 .72126 L .716 .72689 L p .545 .337 .549 r
F P
0 g
s
.6661 .77378 m .66621 .80595 L .64916 .81054 L p .566 .343 .536 r
F P
0 g
s
.6661 .77378 m .66621 .80595 L .68319 .80135 L p .56 .338 .535 r
F P
0 g
s
.68319 .80135 m .68309 .76906 L .6661 .77378 L p .56 .338 .535 r
F P
0 g
s
.59669 .82388 m .5957 .85484 L .57768 .85865 L p .595 .337 .496 r
F P
0 g
s
.5957 .85484 m .59669 .82388 L .61449 .81956 L p .583 .33 .499 r
F P
0 g
s
.58307 .35025 m .62183 .35587 L .62253 .35175 L p .648 .706 .889 r
F P
0 g
s
.62183 .35587 m .66131 .36447 L .66239 .35871 L p .622 .681 .885 r
F P
0 g
s
.66239 .35871 m .62253 .35175 L .62183 .35587 L p .622 .681 .885 r
F P
0 g
s
.43043 .35381 m .46936 .349 L .46984 .35145 L p .699 .744 .887 r
F P
0 g
s
.50759 .34679 m .46984 .35145 L .46936 .349 L p .682 .734 .89 r
F P
0 g
s
.46984 .35145 m .50759 .34679 L .50781 .3476 L p .682 .734 .889 r
F P
0 g
s
.30948 .75101 m .31076 .71816 L .3238 .72692 L p .901 .635 .526 r
F P
0 g
s
.3238 .72692 m .32271 .75991 L .30948 .75101 L p .901 .635 .526 r
F P
0 g
s
.26076 .60693 m .26748 .57369 L .27776 .58333 L p .927 .709 .587 r
F P
0 g
s
.27776 .58333 m .27134 .61662 L .26076 .60693 L p .927 .709 .587 r
F P
0 g
s
.7648 .43772 m .79312 .46715 L .79803 .45638 L p .431 .459 .788 r
F P
0 g
s
.79803 .45638 m .76916 .42792 L .7648 .43772 L p .431 .459 .788 r
F P
0 g
s
.66131 .36447 m .70062 .37728 L .7021 .36996 L p .582 .645 .878 r
F P
0 g
s
.7021 .36996 m .66239 .35871 L .66131 .36447 L p .582 .645 .878 r
F P
0 g
s
.78688 .47777 m .80903 .51087 L .81591 .49955 L p .398 .39 .734 r
F P
0 g
s
.81591 .49955 m .79312 .46715 L .78688 .47777 L p .398 .39 .734 r
F P
0 g
s
.25153 .50824 m .27016 .47559 L .27753 .48608 L p .908 .767 .694 r
F P
0 g
s
.27753 .48608 m .25991 .51925 L .25153 .50824 L p .908 .767 .694 r
F P
0 g
s
.33765 .80128 m .33682 .76845 L .3519 .77646 L p .867 .579 .497 r
F P
0 g
s
.3519 .77646 m .35286 .80921 L .33765 .80128 L p .867 .579 .497 r
F P
0 g
s
.31423 .3914 m .35154 .37396 L .35364 .38155 L p .804 .795 .844 r
F P
0 g
s
.35364 .38155 m .31715 .40063 L .31423 .3914 L p .804 .795 .844 r
F P
0 g
s
.58307 .35025 m .54513 .3464 L .54495 .34721 L p .664 .719 .89 r
F P
0 g
s
.54513 .3464 m .58307 .35025 L .58343 .34779 L p .664 .72 .891 r
F P
0 g
s
.62253 .35175 m .58343 .34779 L .58307 .35025 L p .648 .706 .889 r
F P
0 g
s
.73546 .40377 m .76916 .42792 L .77239 .41803 L p .477 .529 .833 r
F P
0 g
s
.77239 .41803 m .73823 .39509 L .73546 .40377 L p .477 .529 .833 r
F P
0 g
s
.3892 .85354 m .38612 .82286 L .40407 .82828 L p .798 .482 .454 r
F P
0 g
s
.40407 .82828 m .40685 .8587 L .3892 .85354 L p .798 .482 .454 r
F P
0 g
s
.38993 .35577 m .42991 .34963 L .43043 .35381 L p .725 .762 .882 r
F P
0 g
s
.43043 .35381 m .39082 .3617 L .38993 .35577 L p .725 .762 .882 r
F P
0 g
s
.46936 .349 m .43043 .35381 L .42991 .34963 L p .698 .745 .888 r
F P
0 g
s
.42991 .34963 m .46911 .34652 L .46936 .349 L p .698 .745 .888 r
F P
0 g
s
.50744 .34598 m .46936 .349 L .46911 .34652 L p .682 .735 .891 r
F P
0 g
s
.46936 .349 m .50744 .34598 L .50759 .34679 L p .682 .734 .89 r
F P
0 g
s
.28675 .69997 m .2894 .66766 L .30102 .67664 L p .922 .671 .541 r
F P
0 g
s
.30102 .67664 m .29846 .70915 L .28675 .69997 L p .922 .671 .541 r
F P
0 g
s
.80066 .52193 m .81669 .55696 L .82575 .54552 L p .383 .334 .678 r
F P
0 g
s
.82575 .54552 m .80903 .51087 L .80066 .52193 L p .383 .334 .678 r
F P
0 g
s
.58343 .34779 m .54524 .34558 L .54513 .3464 L p .664 .72 .891 r
F P
0 g
s
.76421 .67497 m .7671 .70845 L .78359 .70104 L p .498 .314 .562 r
F P
0 g
s
.78359 .70104 m .7804 .66708 L .76421 .67497 L p .498 .314 .562 r
F P
0 g
s
.79003 .62367 m .79592 .65843 L .81047 .649 L p .448 .301 .588 r
F P
0 g
s
.81047 .649 m .80399 .61392 L .79003 .62367 L p .448 .301 .588 r
F P
0 g
s
.54524 .34558 m .58343 .34779 L .58357 .34532 L p .663 .72 .891 r
F P
0 g
s
.58343 .34779 m .62253 .35175 L .62283 .34761 L p .647 .707 .89 r
F P
0 g
s
.62283 .34761 m .58357 .34532 L .58343 .34779 L p .647 .707 .89 r
F P
0 g
s
.35014 .36626 m .38993 .35577 L .39082 .3617 L p .761 .782 .871 r
F P
0 g
s
.39082 .3617 m .35154 .37396 L .35014 .36626 L p .761 .782 .871 r
F P
0 g
s
.46911 .34652 m .50738 .34516 L .50744 .34598 L p .682 .735 .891 r
F P
0 g
s
.62253 .35175 m .66239 .35871 L .66291 .35292 L p .619 .683 .888 r
F P
0 g
s
.66291 .35292 m .62283 .34761 L .62253 .35175 L p .619 .683 .888 r
F P
0 g
s
.70062 .37728 m .73823 .39509 L .74007 .38636 L p .528 .594 .864 r
F P
0 g
s
.74007 .38636 m .7021 .36996 L .70062 .37728 L p .528 .594 .864 r
F P
0 g
s
.58357 .34532 m .54526 .34476 L .54524 .34558 L p .663 .72 .891 r
F P
0 g
s
.61449 .81956 m .61336 .85073 L .5957 .85484 L p .583 .33 .499 r
F P
0 g
s
.61336 .85073 m .61449 .81956 L .63195 .81509 L p .572 .323 .5 r
F P
0 g
s
.46909 .34404 m .50739 .34434 L .50738 .34516 L p .682 .735 .891 r
F P
0 g
s
.50738 .34516 m .46911 .34652 L .46909 .34404 L p .682 .735 .891 r
F P
0 g
s
.42979 .34544 m .46909 .34404 L .46911 .34652 L p .697 .747 .89 r
F P
0 g
s
.46911 .34652 m .42991 .34963 L .42979 .34544 L p .697 .747 .89 r
F P
0 g
s
.54526 .34476 m .58357 .34532 L .58347 .34284 L p .663 .721 .892 r
F P
0 g
s
.58347 .34284 m .54521 .34394 L .54526 .34476 L p .663 .721 .892 r
F P
0 g
s
.24787 .55294 m .25991 .51925 L .26881 .52972 L p .924 .74 .636 r
F P
0 g
s
.26881 .52972 m .25751 .56357 L .24787 .55294 L p .924 .74 .636 r
F P
0 g
s
.46931 .34156 m .50748 .34352 L .50739 .34434 L p .681 .735 .892 r
F P
0 g
s
.50739 .34434 m .46909 .34404 L .46931 .34156 L p .681 .735 .892 r
F P
0 g
s
.54521 .34394 m .58347 .34284 L .58313 .34037 L p .663 .721 .892 r
F P
0 g
s
.58313 .34037 m .54509 .34313 L .54521 .34394 L p .663 .721 .892 r
F P
0 g
s
.68309 .76906 m .68319 .80135 L .70016 .79667 L p .553 .332 .533 r
F P
0 g
s
.70016 .79667 m .70012 .76424 L .68309 .76906 L p .553 .332 .533 r
F P
0 g
s
.58357 .34532 m .62283 .34761 L .62274 .34346 L p .646 .707 .892 r
F P
0 g
s
.62274 .34346 m .58347 .34284 L .58357 .34532 L p .646 .707 .892 r
F P
0 g
s
.38961 .3498 m .42979 .34544 L .42991 .34963 L p .724 .765 .885 r
F P
0 g
s
.42991 .34963 m .38993 .35577 L .38961 .3498 L p .724 .765 .885 r
F P
0 g
s
.46977 .33909 m .50765 .34271 L .50748 .34352 L p .681 .736 .892 r
F P
0 g
s
.50748 .34352 m .46931 .34156 L .46977 .33909 L p .681 .736 .892 r
F P
0 g
s
.66239 .35871 m .7021 .36996 L .70284 .36259 L p .576 .647 .883 r
F P
0 g
s
.70284 .36259 m .66291 .35292 L .66239 .35871 L p .576 .647 .883 r
F P
0 g
s
.54509 .34313 m .58313 .34037 L .58256 .33792 L p .662 .721 .893 r
F P
0 g
s
.58256 .33792 m .54488 .34232 L .54509 .34313 L p .662 .721 .893 r
F P
0 g
s
.26725 .64905 m .27134 .61662 L .28215 .62597 L p .93 .691 .555 r
F P
0 g
s
.28215 .62597 m .27819 .65846 L .26725 .64905 L p .93 .691 .555 r
F P
0 g
s
.73311 .72126 m .73438 .75392 L .75147 .74819 L p .531 .325 .546 r
F P
0 g
s
.75147 .74819 m .7502 .71515 L .73311 .72126 L p .531 .325 .546 r
F P
0 g
s
.47046 .33665 m .50789 .3419 L .50765 .34271 L p .68 .736 .893 r
F P
0 g
s
.50765 .34271 m .46977 .33909 L .47046 .33665 L p .68 .736 .893 r
F P
0 g
s
.43007 .34124 m .46931 .34156 L .46909 .34404 L p .697 .748 .891 r
F P
0 g
s
.46909 .34404 m .42979 .34544 L .43007 .34124 L p .697 .748 .891 r
F P
0 g
s
.54488 .34232 m .58256 .33792 L .58175 .33549 L p .662 .722 .893 r
F P
0 g
s
.58175 .33549 m .5446 .34152 L .54488 .34232 L p .662 .722 .893 r
F P
0 g
s
.80608 .56797 m .81674 .60348 L .82803 .59242 L p .388 .295 .628 r
F P
0 g
s
.82803 .59242 m .81669 .55696 L .80608 .56797 L p .388 .295 .628 r
F P
0 g
s
.28077 .41412 m .31423 .3914 L .31715 .40063 L p .848 .81 .813 r
F P
0 g
s
.31715 .40063 m .28464 .42478 L .28077 .41412 L p .848 .81 .813 r
F P
0 g
s
.47139 .33423 m .50821 .34111 L .50789 .3419 L p .68 .737 .893 r
F P
0 g
s
.50789 .3419 m .47046 .33665 L .47139 .33423 L p .68 .737 .893 r
F P
0 g
s
.5446 .34152 m .58175 .33549 L .58071 .3331 L p .662 .722 .894 r
F P
0 g
s
.58071 .3331 m .54424 .34073 L .5446 .34152 L p .662 .722 .894 r
F P
0 g
s
.62283 .34761 m .66291 .35292 L .66287 .3471 L p .616 .685 .891 r
F P
0 g
s
.66287 .3471 m .62274 .34346 L .62283 .34761 L p .616 .685 .891 r
F P
0 g
s
.31216 .38202 m .35014 .36626 L .35154 .37396 L p .803 .804 .852 r
F P
0 g
s
.35154 .37396 m .31423 .3914 L .31216 .38202 L p .803 .804 .852 r
F P
0 g
s
.37232 .84744 m .36902 .81645 L .38612 .82286 L p .82 .501 .449 r
F P
0 g
s
.38612 .82286 m .3892 .85354 L .37232 .84744 L p .82 .501 .449 r
F P
0 g
s
.58347 .34284 m .62274 .34346 L .62224 .33931 L p .645 .709 .893 r
F P
0 g
s
.62224 .33931 m .58313 .34037 L .58347 .34284 L p .645 .709 .893 r
F P
0 g
s
.25763 .45322 m .28464 .42478 L .28939 .43515 L p .886 .802 .76 r
F P
0 g
s
.28939 .43515 m .26349 .46462 L .25763 .45322 L p .886 .802 .76 r
F P
0 g
s
.47254 .33186 m .50861 .34033 L .50821 .34111 L p .68 .737 .894 r
F P
0 g
s
.50821 .34111 m .47139 .33423 L .47254 .33186 L p .68 .737 .894 r
F P
0 g
s
.54424 .34073 m .58071 .3331 L .57945 .33076 L p .662 .723 .894 r
F P
0 g
s
.57945 .33076 m .54381 .33996 L .54424 .34073 L p .662 .723 .894 r
F P
0 g
s
.63195 .81509 m .6307 .84646 L .61336 .85073 L p .572 .323 .5 r
F P
0 g
s
.6307 .84646 m .63195 .81509 L .64916 .81054 L p .562 .316 .501 r
F P
0 g
s
.47392 .32955 m .50908 .33957 L .50861 .34033 L p .679 .737 .895 r
F P
0 g
s
.50861 .34033 m .47254 .33186 L .47392 .32955 L p .679 .737 .895 r
F P
0 g
s
.34947 .3585 m .38961 .3498 L .38993 .35577 L p .759 .788 .876 r
F P
0 g
s
.38993 .35577 m .35014 .36626 L .34947 .3585 L p .759 .788 .876 r
F P
0 g
s
.43075 .33705 m .46977 .33909 L .46931 .34156 L p .696 .749 .893 r
F P
0 g
s
.46931 .34156 m .43007 .34124 L .43075 .33705 L p .696 .749 .893 r
F P
0 g
s
.54381 .33996 m .57945 .33076 L .57796 .32847 L p .662 .724 .895 r
F P
0 g
s
.57796 .32847 m .54331 .33921 L .54381 .33996 L p .662 .724 .895 r
F P
0 g
s
.47552 .3273 m .50962 .33884 L .50908 .33957 L p .679 .738 .895 r
F P
0 g
s
.50908 .33957 m .47392 .32955 L .47552 .3273 L p .679 .738 .895 r
F P
0 g
s
.32337 .79282 m .32271 .75991 L .33682 .76845 L p .885 .596 .494 r
F P
0 g
s
.33682 .76845 m .33765 .80128 L .32337 .79282 L p .885 .596 .494 r
F P
0 g
s
.38985 .34382 m .43007 .34124 L .42979 .34544 L p .722 .768 .889 r
F P
0 g
s
.42979 .34544 m .38961 .3498 L .38985 .34382 L p .722 .768 .889 r
F P
0 g
s
.54331 .33921 m .57796 .32847 L .57626 .32625 L p .662 .724 .895 r
F P
0 g
s
.57626 .32625 m .54274 .33849 L .54331 .33921 L p .662 .724 .895 r
F P
0 g
s
.297 .74187 m .29846 .70915 L .31076 .71816 L p .914 .648 .523 r
F P
0 g
s
.31076 .71816 m .30948 .75101 L .297 .74187 L p .914 .648 .523 r
F P
0 g
s
.47734 .32512 m .51022 .33812 L .50962 .33884 L p .678 .738 .896 r
F P
0 g
s
.50962 .33884 m .47552 .3273 L .47734 .32512 L p .678 .738 .896 r
F P
0 g
s
.58313 .34037 m .62224 .33931 L .62135 .33518 L p .644 .71 .895 r
F P
0 g
s
.62135 .33518 m .58256 .33792 L .58313 .34037 L p .644 .71 .895 r
F P
0 g
s
.25036 .59683 m .25751 .56357 L .26748 .57369 L p .932 .714 .586 r
F P
0 g
s
.26748 .57369 m .26076 .60693 L .25036 .59683 L p .932 .714 .586 r
F P
0 g
s
.76916 .42792 m .79803 .45638 L .80159 .44552 L p .398 .448 .796 r
F P
0 g
s
.80159 .44552 m .77239 .41803 L .76916 .42792 L p .398 .448 .796 r
F P
0 g
s
.73823 .39509 m .77239 .41803 L .77449 .4081 L p .455 .526 .841 r
F P
0 g
s
.77449 .4081 m .74007 .38636 L .73823 .39509 L p .455 .526 .841 r
F P
0 g
s
.24379 .49671 m .26349 .46462 L .27016 .47559 L p .914 .78 .7 r
F P
0 g
s
.27016 .47559 m .25153 .50824 L .24379 .49671 L p .914 .78 .7 r
F P
0 g
s
.54274 .33849 m .57626 .32625 L .57434 .32411 L p .662 .725 .896 r
F P
0 g
s
.57434 .32411 m .54209 .33779 L .54274 .33849 L p .662 .725 .896 r
F P
0 g
s
.47936 .32302 m .5109 .33744 L .51022 .33812 L p .677 .738 .896 r
F P
0 g
s
.51022 .33812 m .47734 .32512 L .47936 .32302 L p .677 .738 .896 r
F P
0 g
s
.7021 .36996 m .74007 .38636 L .74099 .37759 L p .515 .595 .872 r
F P
0 g
s
.74099 .37759 m .70284 .36259 L .7021 .36996 L p .515 .595 .872 r
F P
0 g
s
.54209 .33779 m .57434 .32411 L .57222 .32205 L p .662 .725 .896 r
F P
0 g
s
.57222 .32205 m .54139 .33712 L .54209 .33779 L p .662 .725 .896 r
F P
0 g
s
.43184 .33291 m .47046 .33665 L .46977 .33909 L p .695 .751 .895 r
F P
0 g
s
.46977 .33909 m .43075 .33705 L .43184 .33291 L p .695 .751 .895 r
F P
0 g
s
.79312 .46715 m .81591 .49955 L .82123 .48806 L p .354 .372 .74 r
F P
0 g
s
.82123 .48806 m .79803 .45638 L .79312 .46715 L p .354 .372 .74 r
F P
0 g
s
.48159 .32101 m .51164 .33678 L .5109 .33744 L p .677 .738 .897 r
F P
0 g
s
.5109 .33744 m .47936 .32302 L .48159 .32101 L p .677 .738 .897 r
F P
0 g
s
.70012 .76424 m .70016 .79667 L .71712 .79185 L p .545 .324 .53 r
F P
0 g
s
.71712 .79185 m .71723 .75923 L .70012 .76424 L p .545 .324 .53 r
F P
0 g
s
.62274 .34346 m .66287 .3471 L .66226 .34129 L p .614 .686 .894 r
F P
0 g
s
.66226 .34129 m .62224 .33931 L .62274 .34346 L p .614 .686 .894 r
F P
0 g
s
.66291 .35292 m .70284 .36259 L .70285 .35521 L p .57 .648 .888 r
F P
0 g
s
.70285 .35521 m .66287 .3471 L .66291 .35292 L p .57 .648 .888 r
F P
0 g
s
.7804 .66708 m .78359 .70104 L .7994 .69286 L p .469 .294 .56 r
F P
0 g
s
.7994 .69286 m .79592 .65843 L .7804 .66708 L p .469 .294 .56 r
F P
0 g
s
.54139 .33712 m .57222 .32205 L .5699 .32008 L p .662 .726 .897 r
F P
0 g
s
.5699 .32008 m .54062 .33648 L .54139 .33712 L p .662 .726 .897 r
F P
0 g
s
.484 .31911 m .51244 .33616 L .51164 .33678 L p .676 .738 .897 r
F P
0 g
s
.51164 .33678 m .48159 .32101 L .484 .31911 L p .676 .738 .897 r
F P
0 g
s
.54062 .33648 m .5699 .32008 L .5674 .31822 L p .663 .727 .897 r
F P
0 g
s
.5674 .31822 m .53979 .33587 L .54062 .33648 L p .663 .727 .897 r
F P
0 g
s
.58256 .33792 m .62135 .33518 L .62007 .33109 L p .644 .711 .896 r
F P
0 g
s
.62007 .33109 m .58175 .33549 L .58256 .33792 L p .644 .711 .896 r
F P
0 g
s
.4866 .31731 m .5133 .33558 L .51244 .33616 L p .676 .738 .897 r
F P
0 g
s
.51244 .33616 m .484 .31911 L .4866 .31731 L p .676 .738 .897 r
F P
0 g
s
.53979 .33587 m .5674 .31822 L .56472 .31647 L p .663 .727 .897 r
F P
0 g
s
.56472 .31647 m .5389 .33531 L .53979 .33587 L p .663 .727 .897 r
F P
0 g
s
.27544 .69065 m .27819 .65846 L .2894 .66766 L p .929 .678 .537 r
F P
0 g
s
.2894 .66766 m .28675 .69997 L .27544 .69065 L p .929 .678 .537 r
F P
0 g
s
.80399 .61392 m .81047 .649 L .82376 .6388 L p .406 .274 .587 r
F P
0 g
s
.82376 .6388 m .81674 .60348 L .80399 .61392 L p .406 .274 .587 r
F P
0 g
s
.48936 .31562 m .51421 .33503 L .5133 .33558 L p .675 .738 .898 r
F P
0 g
s
.5133 .33558 m .4866 .31731 L .48936 .31562 L p .675 .738 .898 r
F P
0 g
s
.5389 .33531 m .56472 .31647 L .56188 .31484 L p .663 .728 .898 r
F P
0 g
s
.56188 .31484 m .53796 .33478 L .5389 .33531 L p .663 .728 .898 r
F P
0 g
s
.7502 .71515 m .75147 .74819 L .76836 .7419 L p .511 .309 .543 r
F P
0 g
s
.76836 .7419 m .7671 .70845 L .7502 .71515 L p .511 .309 .543 r
F P
0 g
s
.39067 .33786 m .43075 .33705 L .43007 .34124 L p .72 .771 .893 r
F P
0 g
s
.43007 .34124 m .38985 .34382 L .39067 .33786 L p .72 .771 .893 r
F P
0 g
s
.48444 .8948 m .4826 .86852 L .50205 .86823 L p .669 .337 .403 r
F P
0 g
s
.50205 .86823 m .50304 .89467 L .48444 .8948 L p .669 .337 .403 r
F P
0 g
s
.50304 .89467 m .50205 .86823 L .52138 .86698 L p .648 .324 .41 r
F P
0 g
s
.43332 .32881 m .47139 .33423 L .47046 .33665 L p .693 .752 .896 r
F P
0 g
s
.47046 .33665 m .43184 .33291 L .43332 .32881 L p .693 .752 .896 r
F P
0 g
s
.49229 .31407 m .51518 .33452 L .51421 .33503 L p .675 .738 .898 r
F P
0 g
s
.51421 .33503 m .48936 .31562 L .49229 .31407 L p .675 .738 .898 r
F P
0 g
s
.64916 .81054 m .64778 .84208 L .6307 .84646 L p .562 .316 .501 r
F P
0 g
s
.64778 .84208 m .64916 .81054 L .66621 .80595 L p .553 .309 .5 r
F P
0 g
s
.52138 .86698 m .52158 .89366 L .50304 .89467 L p .648 .324 .41 r
F P
0 g
s
.52158 .89366 m .52138 .86698 L .54048 .86487 L p .629 .312 .416 r
F P
0 g
s
.53796 .33478 m .56188 .31484 L .55888 .31333 L p .663 .729 .898 r
F P
0 g
s
.55888 .31333 m .53697 .33429 L .53796 .33478 L p .663 .729 .898 r
F P
0 g
s
.80903 .51087 m .82575 .54552 L .83313 .53375 L p .331 .307 .681 r
F P
0 g
s
.83313 .53375 m .81591 .49955 L .80903 .51087 L p .331 .307 .681 r
F P
0 g
s
.49536 .31264 m .51619 .33406 L .51518 .33452 L p .674 .738 .898 r
F P
0 g
s
.51518 .33452 m .49229 .31407 L .49536 .31264 L p .674 .738 .898 r
F P
0 g
s
.53697 .33429 m .55888 .31333 L .55574 .31196 L p .664 .729 .898 r
F P
0 g
s
.55574 .31196 m .53594 .33385 L .53697 .33429 L p .664 .729 .898 r
F P
0 g
s
.4659 .89398 m .4632 .86774 L .4826 .86852 L p .691 .352 .396 r
F P
0 g
s
.4826 .86852 m .48444 .8948 L .4659 .89398 L p .691 .352 .396 r
F P
0 g
s
.34955 .35071 m .38985 .34382 L .38961 .3498 L p .757 .794 .883 r
F P
0 g
s
.38961 .3498 m .34947 .3585 L .34955 .35071 L p .757 .794 .883 r
F P
0 g
s
.49856 .31134 m .51724 .33364 L .51619 .33406 L p .673 .738 .899 r
F P
0 g
s
.51619 .33406 m .49536 .31264 L .49856 .31134 L p .673 .738 .899 r
F P
0 g
s
.35627 .84053 m .35286 .80921 L .36902 .81645 L p .842 .52 .445 r
F P
0 g
s
.36902 .81645 m .37232 .84744 L .35627 .84053 L p .842 .52 .445 r
F P
0 g
s
.31098 .37253 m .34947 .3585 L .35014 .36626 L p .803 .814 .86 r
F P
0 g
s
.35014 .36626 m .31216 .38202 L .31098 .37253 L p .803 .814 .86 r
F P
0 g
s
.58175 .33549 m .62007 .33109 L .61838 .32705 L p .643 .712 .898 r
F P
0 g
s
.61838 .32705 m .58071 .3331 L .58175 .33549 L p .643 .712 .898 r
F P
0 g
s
.53594 .33385 m .55574 .31196 L .55248 .31074 L p .664 .73 .899 r
F P
0 g
s
.55248 .31074 m .53487 .33345 L .53594 .33385 L p .664 .73 .899 r
F P
0 g
s
.23864 .54176 m .25153 .50824 L .25991 .51925 L p .93 .751 .638 r
F P
0 g
s
.25991 .51925 m .24787 .55294 L .23864 .54176 L p .93 .751 .638 r
F P
0 g
s
.49856 .31134 m .51724 .33364 L .51833 .33327 L p .673 .737 .899 r
F P
0 g
s
.54048 .86487 m .53994 .89187 L .52158 .89366 L p .629 .312 .416 r
F P
0 g
s
.53994 .89187 m .54048 .86487 L .55927 .86204 L p .61 .302 .422 r
F P
0 g
s
.53487 .33345 m .55248 .31074 L .5491 .30965 L p .665 .731 .899 r
F P
0 g
s
.5491 .30965 m .53376 .33311 L .53487 .33345 L p .665 .731 .899 r
F P
0 g
s
.50189 .31019 m .51833 .33327 L .51946 .33295 L p .672 .737 .899 r
F P
0 g
s
.51833 .33327 m .50189 .31019 L .49856 .31134 L p .673 .737 .899 r
F P
0 g
s
.27786 .40324 m .31216 .38202 L .31423 .3914 L p .849 .823 .822 r
F P
0 g
s
.31423 .3914 m .28077 .41412 L .27786 .40324 L p .849 .823 .822 r
F P
0 g
s
.53376 .33311 m .5491 .30965 L .54562 .30872 L p .665 .731 .899 r
F P
0 g
s
.54562 .30872 m .53262 .33281 L .53376 .33311 L p .665 .731 .899 r
F P
0 g
s
.62224 .33931 m .66226 .34129 L .66108 .3355 L p .611 .688 .897 r
F P
0 g
s
.66108 .3355 m .62135 .33518 L .62224 .33931 L p .611 .688 .897 r
F P
0 g
s
.50532 .30919 m .51946 .33295 L .52061 .33267 L p .671 .737 .899 r
F P
0 g
s
.51946 .33295 m .50532 .30919 L .50189 .31019 L p .672 .737 .899 r
F P
0 g
s
.53262 .33281 m .54562 .30872 L .54206 .30795 L p .666 .732 .899 r
F P
0 g
s
.54206 .30795 m .53146 .33256 L .53262 .33281 L p .666 .732 .899 r
F P
0 g
s
.50884 .30833 m .52061 .33267 L .52179 .33245 L p .671 .737 .899 r
F P
0 g
s
.52061 .33267 m .50884 .30833 L .50532 .30919 L p .671 .737 .899 r
F P
0 g
s
.4352 .32479 m .47254 .33186 L .47139 .33423 L p .692 .753 .898 r
F P
0 g
s
.47139 .33423 m .43332 .32881 L .4352 .32479 L p .692 .753 .898 r
F P
0 g
s
.53146 .33256 m .54206 .30795 L .53843 .30734 L p .666 .732 .899 r
F P
0 g
s
.53843 .30734 m .53027 .33236 L .53146 .33256 L p .666 .732 .899 r
F P
0 g
s
.51244 .30764 m .52179 .33245 L .52298 .33228 L p .67 .736 .9 r
F P
0 g
s
.52179 .33245 m .51244 .30764 L .50884 .30833 L p .671 .737 .899 r
F P
0 g
s
.44755 .89217 m .444 .86585 L .4632 .86774 L p .714 .367 .389 r
F P
0 g
s
.4632 .86774 m .4659 .89398 L .44755 .89217 L p .714 .367 .389 r
F P
0 g
s
.53027 .33236 m .53843 .30734 L .53474 .30688 L p .667 .733 .899 r
F P
0 g
s
.53474 .30688 m .52907 .33221 L .53027 .33236 L p .667 .733 .899 r
F P
0 g
s
.5161 .3071 m .52298 .33228 L .52419 .33216 L p .67 .736 .9 r
F P
0 g
s
.52298 .33228 m .5161 .3071 L .51244 .30764 L p .67 .736 .9 r
F P
0 g
s
.52907 .33221 m .53474 .30688 L .53102 .3066 L p .667 .734 .9 r
F P
0 g
s
.53102 .3066 m .52785 .33212 L .52907 .33221 L p .667 .734 .9 r
F P
0 g
s
.51981 .30673 m .52419 .33216 L .52541 .33209 L p .669 .735 .9 r
F P
0 g
s
.52419 .33216 m .51981 .30673 L .5161 .3071 L p .67 .736 .9 r
F P
0 g
s
.52785 .33212 m .53102 .3066 L .52728 .30647 L p .668 .734 .9 r
F P
0 g
s
.52728 .30647 m .52663 .33208 L .52785 .33212 L p .668 .734 .9 r
F P
0 g
s
.52354 .30652 m .52541 .33209 L .52663 .33208 L p .668 .735 .9 r
F P
0 g
s
.52541 .33209 m .52354 .30652 L .51981 .30673 L p .669 .735 .9 r
F P
0 g
s
.52663 .33208 m .52728 .30647 L .52354 .30652 L p .668 .735 .9 r
F P
0 g
s
.25647 .63939 m .26076 .60693 L .27134 .61662 L p .934 .695 .553 r
F P
0 g
s
.27134 .61662 m .26725 .64905 L .25647 .63939 L p .934 .695 .553 r
F P
0 g
s
.55927 .86204 m .55806 .88941 L .53994 .89187 L p .61 .302 .422 r
F P
0 g
s
.55806 .88941 m .55927 .86204 L .57768 .85865 L p .594 .292 .427 r
F P
0 g
s
.58071 .3331 m .61838 .32705 L .61632 .32308 L p .643 .714 .899 r
F P
0 g
s
.61632 .32308 m .57945 .33076 L .58071 .3331 L p .643 .714 .899 r
F P
0 g
s
.66287 .3471 m .70285 .35521 L .70212 .34782 L p .564 .651 .893 r
F P
0 g
s
.70212 .34782 m .66226 .34129 L .66287 .3471 L p .564 .651 .893 r
F P
0 g
s
.2527 .44146 m .28077 .41412 L .28464 .42478 L p .89 .817 .769 r
F P
0 g
s
.28464 .42478 m .25763 .45322 L .2527 .44146 L p .89 .817 .769 r
F P
0 g
s
.39207 .33195 m .43184 .33291 L .43075 .33705 L p .718 .774 .896 r
F P
0 g
s
.43075 .33705 m .39067 .33786 L .39207 .33195 L p .718 .774 .896 r
F P
0 g
s
.71723 .75923 m .71712 .79185 L .73406 .78677 L p .532 .312 .526 r
F P
0 g
s
.73406 .78677 m .73438 .75392 L .71723 .75923 L p .532 .312 .526 r
F P
0 g
s
.81669 .55696 m .82803 .59242 L .83762 .58083 L p .333 .263 .627 r
F P
0 g
s
.83762 .58083 m .82575 .54552 L .81669 .55696 L p .333 .263 .627 r
F P
0 g
s
.43746 .32086 m .47392 .32955 L .47254 .33186 L p .691 .754 .9 r
F P
0 g
s
.47254 .33186 m .4352 .32479 L .43746 .32086 L p .691 .754 .9 r
F P
0 g
s
.70284 .36259 m .74099 .37759 L .74099 .36881 L p .503 .595 .879 r
F P
0 g
s
.74099 .36881 m .70285 .35521 L .70284 .36259 L p .503 .595 .879 r
F P
0 g
s
.42953 .88935 m .42516 .86282 L .444 .86585 L p .737 .384 .382 r
F P
0 g
s
.444 .86585 m .44755 .89217 L .42953 .88935 L p .737 .384 .382 r
F P
0 g
s
.30994 .78399 m .30948 .75101 L .32271 .75991 L p .9 .613 .492 r
F P
0 g
s
.32271 .75991 m .32337 .79282 L .30994 .78399 L p .9 .613 .492 r
F P
0 g
s
.74007 .38636 m .77449 .4081 L .77546 .39816 L p .432 .522 .85 r
F P
0 g
s
.77546 .39816 m .74099 .37759 L .74007 .38636 L p .432 .522 .85 r
F P
0 g
s
.57945 .33076 m .61632 .32308 L .61387 .31919 L p .642 .715 .901 r
F P
0 g
s
.61387 .31919 m .57796 .32847 L .57945 .33076 L p .642 .715 .901 r
F P
0 g
s
.66621 .80595 m .66466 .83766 L .68141 .8332 L p .544 .301 .498 r
F P
0 g
s
.68141 .8332 m .68319 .80135 L .66621 .80595 L p .544 .301 .498 r
F P
0 g
s
.66621 .80595 m .66466 .83766 L .64778 .84208 L p .553 .309 .5 r
F P
0 g
s
.62135 .33518 m .66108 .3355 L .65934 .32974 L p .609 .69 .9 r
F P
0 g
s
.65934 .32974 m .62007 .33109 L .62135 .33518 L p .609 .69 .9 r
F P
0 g
s
.57768 .85865 m .57589 .88642 L .55806 .88941 L p .594 .292 .427 r
F P
0 g
s
.57589 .88642 m .57768 .85865 L .5957 .85484 L p .578 .283 .431 r
F P
0 g
s
.3504 .34296 m .39067 .33786 L .38985 .34382 L p .755 .8 .889 r
F P
0 g
s
.38985 .34382 m .34955 .35071 L .3504 .34296 L p .755 .8 .889 r
F P
0 g
s
.28512 .7326 m .28675 .69997 L .29846 .70915 L p .923 .659 .52 r
F P
0 g
s
.29846 .70915 m .297 .74187 L .28512 .7326 L p .923 .659 .52 r
F P
0 g
s
.44012 .31703 m .47552 .3273 L .47392 .32955 L p .689 .755 .902 r
F P
0 g
s
.47392 .32955 m .43746 .32086 L .44012 .31703 L p .689 .755 .902 r
F P
0 g
s
.23683 .48467 m .25763 .45322 L .26349 .46462 L p .92 .796 .706 r
F P
0 g
s
.26349 .46462 m .24379 .49671 L .23683 .48467 L p .92 .796 .706 r
F P
0 g
s
.77239 .41803 m .80159 .44552 L .80379 .43465 L p .361 .436 .804 r
F P
0 g
s
.80379 .43465 m .77449 .4081 L .77239 .41803 L p .361 .436 .804 r
F P
0 g
s
.24017 .58628 m .24787 .55294 L .25751 .56357 L p .937 .721 .586 r
F P
0 g
s
.25751 .56357 m .25036 .59683 L .24017 .58628 L p .937 .721 .586 r
F P
0 g
s
.79592 .65843 m .7994 .69286 L .81424 .68384 L p .431 .267 .557 r
F P
0 g
s
.81424 .68384 m .81047 .649 L .79592 .65843 L p .431 .267 .557 r
F P
0 g
s
.39406 .32612 m .43332 .32881 L .43184 .33291 L p .716 .776 .9 r
F P
0 g
s
.43184 .33291 m .39207 .33195 L .39406 .32612 L p .716 .776 .9 r
F P
0 g
s
.57796 .32847 m .61387 .31919 L .61104 .3154 L p .642 .717 .902 r
F P
0 g
s
.61104 .3154 m .57626 .32625 L .57796 .32847 L p .642 .717 .902 r
F P
0 g
s
.7671 .70845 m .76836 .7419 L .78481 .73494 L p .486 .289 .538 r
F P
0 g
s
.78481 .73494 m .78359 .70104 L .7671 .70845 L p .486 .289 .538 r
F P
0 g
s
.31074 .36301 m .34955 .35071 L .34947 .3585 L p .801 .824 .869 r
F P
0 g
s
.34947 .3585 m .31098 .37253 L .31074 .36301 L p .801 .824 .869 r
F P
0 g
s
.44314 .31333 m .47734 .32512 L .47552 .3273 L p .687 .755 .903 r
F P
0 g
s
.47552 .3273 m .44012 .31703 L .44314 .31333 L p .687 .755 .903 r
F P
0 g
s
.34109 .83295 m .33765 .80128 L .35286 .80921 L p .861 .539 .44 r
F P
0 g
s
.35286 .80921 m .35627 .84053 L .34109 .83295 L p .861 .539 .44 r
F P
0 g
s
.79803 .45638 m .82123 .48806 L .82496 .47648 L p .301 .348 .744 r
F P
0 g
s
.82496 .47648 m .80159 .44552 L .79803 .45638 L p .301 .348 .744 r
F P
0 g
s
.41196 .88553 m .40685 .8587 L .42516 .86282 L p .76 .401 .374 r
F P
0 g
s
.42516 .86282 m .42953 .88935 L .41196 .88553 L p .76 .401 .374 r
F P
0 g
s
.66226 .34129 m .70212 .34782 L .70066 .34045 L p .558 .653 .899 r
F P
0 g
s
.70066 .34045 m .66108 .3355 L .66226 .34129 L p .558 .653 .899 r
F P
0 g
s
.5957 .85484 m .59339 .88301 L .57589 .88642 L p .578 .283 .431 r
F P
0 g
s
.59339 .88301 m .5957 .85484 L .61336 .85073 L p .564 .274 .434 r
F P
0 g
s
.62007 .33109 m .65934 .32974 L .65705 .32404 L p .608 .693 .903 r
F P
0 g
s
.65705 .32404 m .61838 .32705 L .62007 .33109 L p .608 .693 .903 r
F P
0 g
s
.57626 .32625 m .61104 .3154 L .60786 .31173 L p .642 .718 .903 r
F P
0 g
s
.60786 .31173 m .57434 .32411 L .57626 .32625 L p .642 .718 .903 r
F P
0 g
s
.26439 .68123 m .26725 .64905 L .27819 .65846 L p .934 .682 .534 r
F P
0 g
s
.27819 .65846 m .27544 .69065 L .26439 .68123 L p .934 .682 .534 r
F P
0 g
s
.81674 .60348 m .82376 .6388 L .83551 .62789 L p .354 .241 .584 r
F P
0 g
s
.83551 .62789 m .82803 .59242 L .81674 .60348 L p .354 .241 .584 r
F P
0 g
s
.27601 .39222 m .31098 .37253 L .31216 .38202 L p .85 .837 .833 r
F P
0 g
s
.31216 .38202 m .27786 .40324 L .27601 .39222 L p .85 .837 .833 r
F P
0 g
s
.44652 .30977 m .47936 .32302 L .47734 .32512 L p .686 .756 .905 r
F P
0 g
s
.47734 .32512 m .44314 .31333 L .44652 .30977 L p .686 .756 .905 r
F P
0 g
s
.73438 .75392 m .73406 .78677 L .75087 .78131 L p .516 .297 .52 r
F P
0 g
s
.75087 .78131 m .75147 .74819 L .73438 .75392 L p .516 .297 .52 r
F P
0 g
s
.39662 .3204 m .4352 .32479 L .43332 .32881 L p .713 .779 .904 r
F P
0 g
s
.43332 .32881 m .39406 .32612 L .39662 .3204 L p .713 .779 .904 r
F P
0 g
s
.68319 .80135 m .68141 .8332 L .69807 .82866 L p .535 .293 .495 r
F P
0 g
s
.69807 .82866 m .70016 .79667 L .68319 .80135 L p .535 .293 .495 r
F P
0 g
s
.22996 .53003 m .24379 .49671 L .25153 .50824 L p .937 .764 .642 r
F P
0 g
s
.25153 .50824 m .23864 .54176 L .22996 .53003 L p .937 .764 .642 r
F P
0 g
s
.57434 .32411 m .60786 .31173 L .60432 .3082 L p .643 .72 .904 r
F P
0 g
s
.60432 .3082 m .57222 .32205 L .57434 .32411 L p .643 .72 .904 r
F P
0 g
s
.35202 .33527 m .39207 .33195 L .39067 .33786 L p .752 .806 .896 r
F P
0 g
s
.39067 .33786 m .3504 .34296 L .35202 .33527 L p .752 .806 .896 r
F P
0 g
s
.70285 .35521 m .74099 .36881 L .74009 .36003 L p .49 .596 .886 r
F P
0 g
s
.74009 .36003 m .70212 .34782 L .70285 .35521 L p .49 .596 .886 r
F P
0 g
s
.81591 .49955 m .83313 .53375 L .83871 .52177 L p .267 .273 .68 r
F P
0 g
s
.83871 .52177 m .82123 .48806 L .81591 .49955 L p .267 .273 .68 r
F P
0 g
s
.45025 .30636 m .48159 .32101 L .47936 .32302 L p .684 .756 .906 r
F P
0 g
s
.47936 .32302 m .44652 .30977 L .45025 .30636 L p .684 .756 .906 r
F P
0 g
s
.24884 .42939 m .27786 .40324 L .28077 .41412 L p .895 .835 .78 r
F P
0 g
s
.28077 .41412 m .2527 .44146 L .24884 .42939 L p .895 .835 .78 r
F P
0 g
s
.61336 .85073 m .61058 .87929 L .59339 .88301 L p .564 .274 .434 r
F P
0 g
s
.61058 .87929 m .61336 .85073 L .6307 .84646 L p .551 .266 .435 r
F P
0 g
s
.61838 .32705 m .65705 .32404 L .6542 .31842 L p .606 .695 .906 r
F P
0 g
s
.6542 .31842 m .61632 .32308 L .61838 .32705 L p .606 .695 .906 r
F P
0 g
s
.2458 .62944 m .25036 .59683 L .26076 .60693 L p .938 .7 .551 r
F P
0 g
s
.26076 .60693 m .25647 .63939 L .2458 .62944 L p .938 .7 .551 r
F P
0 g
s
.57222 .32205 m .60432 .3082 L .60044 .30482 L p .643 .722 .906 r
F P
0 g
s
.60044 .30482 m .5699 .32008 L .57222 .32205 L p .643 .722 .906 r
F P
0 g
s
.39496 .88079 m .3892 .85354 L .40685 .8587 L p .783 .418 .366 r
F P
0 g
s
.40685 .8587 m .41196 .88553 L .39496 .88079 L p .783 .418 .366 r
F P
0 g
s
.74099 .37759 m .77546 .39816 L .77534 .38823 L p .407 .518 .858 r
F P
0 g
s
.77534 .38823 m .74099 .36881 L .74099 .37759 L p .407 .518 .858 r
F P
0 g
s
.45432 .30311 m .484 .31911 L .48159 .32101 L p .683 .756 .907 r
F P
0 g
s
.48159 .32101 m .45025 .30636 L .45432 .30311 L p .683 .756 .907 r
F P
0 g
s
.66108 .3355 m .70066 .34045 L .69848 .33311 L p .553 .656 .904 r
F P
0 g
s
.69848 .33311 m .65934 .32974 L .66108 .3355 L p .553 .656 .904 r
F P
0 g
s
.39976 .31482 m .43746 .32086 L .4352 .32479 L p .71 .781 .908 r
F P
0 g
s
.4352 .32479 m .39662 .3204 L .39976 .31482 L p .71 .781 .908 r
F P
0 g
s
.29724 .77494 m .297 .74187 L .30948 .75101 L p .912 .627 .49 r
F P
0 g
s
.30948 .75101 m .30994 .78399 L .29724 .77494 L p .912 .627 .49 r
F P
0 g
s
.31148 .35352 m .3504 .34296 L .34955 .35071 L p .798 .834 .879 r
F P
0 g
s
.34955 .35071 m .31074 .36301 L .31148 .35352 L p .798 .834 .879 r
F P
0 g
s
.5699 .32008 m .60044 .30482 L .59624 .3016 L p .644 .724 .907 r
F P
0 g
s
.59624 .3016 m .5674 .31822 L .5699 .32008 L p .644 .724 .907 r
F P
0 g
s
.82575 .54552 m .83762 .58083 L .84534 .56883 L p .263 .222 .622 r
F P
0 g
s
.84534 .56883 m .83313 .53375 L .82575 .54552 L p .263 .222 .622 r
F P
0 g
s
.45869 .30005 m .4866 .31731 L .484 .31911 L p .681 .757 .908 r
F P
0 g
s
.484 .31911 m .45432 .30311 L .45869 .30005 L p .681 .757 .908 r
F P
0 g
s
.78359 .70104 m .78481 .73494 L .80059 .72721 L p .453 .263 .532 r
F P
0 g
s
.80059 .72721 m .7994 .69286 L .78359 .70104 L p .453 .263 .532 r
F P
0 g
s
.23082 .47219 m .2527 .44146 L .25763 .45322 L p .927 .815 .714 r
F P
0 g
s
.25763 .45322 m .23683 .48467 L .23082 .47219 L p .927 .815 .714 r
F P
0 g
s
.61632 .32308 m .6542 .31842 L .65082 .3129 L p .605 .698 .909 r
F P
0 g
s
.65082 .3129 m .61387 .31919 L .61632 .32308 L p .605 .698 .909 r
F P
0 g
s
.27366 .72326 m .27544 .69065 L .28675 .69997 L p .93 .667 .518 r
F P
0 g
s
.28675 .69997 m .28512 .7326 L .27366 .72326 L p .93 .667 .518 r
F P
0 g
s
.5674 .31822 m .59624 .3016 L .59172 .29857 L p .644 .726 .908 r
F P
0 g
s
.59172 .29857 m .56472 .31647 L .5674 .31822 L p .644 .726 .908 r
F P
0 g
s
.77449 .4081 m .80379 .43465 L .80466 .4238 L p .318 .422 .81 r
F P
0 g
s
.80466 .4238 m .77546 .39816 L .77449 .4081 L p .318 .422 .81 r
F P
0 g
s
.35444 .32771 m .39406 .32612 L .39207 .33195 L p .748 .812 .903 r
F P
0 g
s
.39207 .33195 m .35202 .33527 L .35444 .32771 L p .748 .812 .903 r
F P
0 g
s
.32676 .82485 m .32337 .79282 L .33765 .80128 L p .879 .557 .437 r
F P
0 g
s
.33765 .80128 m .34109 .83295 L .32676 .82485 L p .879 .557 .437 r
F P
0 g
s
.81047 .649 m .81424 .68384 L .82779 .674 L p .383 .233 .551 r
F P
0 g
s
.82779 .674 m .82376 .6388 L .81047 .649 L p .383 .233 .551 r
F P
0 g
s
.23028 .57521 m .23864 .54176 L .24787 .55294 L p .943 .731 .587 r
F P
0 g
s
.24787 .55294 m .24017 .58628 L .23028 .57521 L p .943 .731 .587 r
F P
0 g
s
.6307 .84646 m .62747 .87536 L .61058 .87929 L p .551 .266 .435 r
F P
0 g
s
.62747 .87536 m .6307 .84646 L .64778 .84208 L p .539 .257 .435 r
F P
0 g
s
.70016 .79667 m .69807 .82866 L .71463 .82397 L p .524 .281 .489 r
F P
0 g
s
.71463 .82397 m .71712 .79185 L .70016 .79667 L p .524 .281 .489 r
F P
0 g
s
.46337 .29717 m .48936 .31562 L .4866 .31731 L p .68 .757 .909 r
F P
0 g
s
.4866 .31731 m .45869 .30005 L .46337 .29717 L p .68 .757 .909 r
F P
0 g
s
.27529 .38113 m .31074 .36301 L .31098 .37253 L p .85 .853 .844 r
F P
0 g
s
.31098 .37253 m .27601 .39222 L .27529 .38113 L p .85 .853 .844 r
F P
0 g
s
.56472 .31647 m .59172 .29857 L .58692 .29574 L p .645 .728 .909 r
F P
0 g
s
.58692 .29574 m .56188 .31484 L .56472 .31647 L p .645 .728 .909 r
F P
0 g
s
.40345 .30939 m .44012 .31703 L .43746 .32086 L p .707 .784 .912 r
F P
0 g
s
.43746 .32086 m .39976 .31482 L .40345 .30939 L p .707 .784 .912 r
F P
0 g
s
.75147 .74819 m .75087 .78131 L .76742 .77535 L p .494 .277 .513 r
F P
0 g
s
.76742 .77535 m .76836 .7419 L .75147 .74819 L p .494 .277 .513 r
F P
0 g
s
.70212 .34782 m .74009 .36003 L .73831 .35128 L p .477 .597 .894 r
F P
0 g
s
.73831 .35128 m .70066 .34045 L .70212 .34782 L p .477 .597 .894 r
F P
0 g
s
.37862 .87519 m .37232 .84744 L .3892 .85354 L p .805 .437 .359 r
F P
0 g
s
.3892 .85354 m .39496 .88079 L .37862 .87519 L p .805 .437 .359 r
F P
0 g
s
.46832 .2945 m .49229 .31407 L .48936 .31562 L p .678 .757 .91 r
F P
0 g
s
.48936 .31562 m .46337 .29717 L .46832 .2945 L p .678 .757 .91 r
F P
0 g
s
.65934 .32974 m .69848 .33311 L .6956 .32583 L p .549 .659 .909 r
F P
0 g
s
.6956 .32583 m .65705 .32404 L .65934 .32974 L p .549 .659 .909 r
F P
0 g
s
.56188 .31484 m .58692 .29574 L .58185 .29312 L p .646 .729 .909 r
F P
0 g
s
.58185 .29312 m .55888 .31333 L .56188 .31484 L p .646 .729 .909 r
F P
0 g
s
.80159 .44552 m .82496 .47648 L .8271 .4649 L p .238 .319 .745 r
F P
0 g
s
.8271 .4649 m .80379 .43465 L .80159 .44552 L p .238 .319 .745 r
F P
0 g
s
.25347 .67166 m .25647 .63939 L .26725 .64905 L p .937 .686 .532 r
F P
0 g
s
.26725 .64905 m .26439 .68123 L .25347 .67166 L p .937 .686 .532 r
F P
0 g
s
.61387 .31919 m .65082 .3129 L .6469 .30749 L p .605 .701 .912 r
F P
0 g
s
.6469 .30749 m .61104 .3154 L .61387 .31919 L p .605 .701 .912 r
F P
0 g
s
.47353 .29205 m .49536 .31264 L .49229 .31407 L p .677 .756 .911 r
F P
0 g
s
.49229 .31407 m .46832 .2945 L .47353 .29205 L p .677 .756 .911 r
F P
0 g
s
.82803 .59242 m .83551 .62789 L .84545 .61634 L p .286 .197 .576 r
F P
0 g
s
.84545 .61634 m .83762 .58083 L .82803 .59242 L p .286 .197 .576 r
F P
0 g
s
.55888 .31333 m .58185 .29312 L .57653 .29074 L p .647 .731 .91 r
F P
0 g
s
.57653 .29074 m .55574 .31196 L .55888 .31333 L p .647 .731 .91 r
F P
0 g
s
.22199 .51775 m .23683 .48467 L .24379 .49671 L p .945 .781 .647 r
F P
0 g
s
.24379 .49671 m .22996 .53003 L .22199 .51775 L p .945 .781 .647 r
F P
0 g
s
.47897 .28982 m .49856 .31134 L .49536 .31264 L p .675 .756 .912 r
F P
0 g
s
.49536 .31264 m .47353 .29205 L .47897 .28982 L p .675 .756 .912 r
F P
0 g
s
.31322 .34412 m .35202 .33527 L .3504 .34296 L p .795 .845 .889 r
F P
0 g
s
.3504 .34296 m .31148 .35352 L .31322 .34412 L p .795 .845 .889 r
F P
0 g
s
.40769 .30414 m .44314 .31333 L .44012 .31703 L p .703 .786 .915 r
F P
0 g
s
.44012 .31703 m .40345 .30939 L .40769 .30414 L p .703 .786 .915 r
F P
0 g
s
.35764 .32029 m .39662 .3204 L .39406 .32612 L p .743 .817 .91 r
F P
0 g
s
.39406 .32612 m .35444 .32771 L .35764 .32029 L p .743 .817 .91 r
F P
0 g
s
.24617 .41713 m .27601 .39222 L .27786 .40324 L p .898 .855 .791 r
F P
0 g
s
.27786 .40324 m .24884 .42939 L .24617 .41713 L p .898 .855 .791 r
F P
0 g
s
.64778 .84208 m .64409 .87129 L .62747 .87536 L p .539 .257 .435 r
F P
0 g
s
.64409 .87129 m .64778 .84208 L .66466 .83766 L p .526 .246 .433 r
F P
0 g
s
.55574 .31196 m .57653 .29074 L .57098 .2886 L p .649 .733 .911 r
F P
0 g
s
.57098 .2886 m .55248 .31074 L .55574 .31196 L p .649 .733 .911 r
F P
0 g
s
.74099 .36881 m .77534 .38823 L .77416 .37833 L p .381 .513 .866 r
F P
0 g
s
.77416 .37833 m .74009 .36003 L .74099 .36881 L p .381 .513 .866 r
F P
0 g
s
.47897 .28982 m .49856 .31134 L .50189 .31019 L p .673 .756 .913 r
F P
0 g
s
.55248 .31074 m .57098 .2886 L .56523 .28672 L p .65 .735 .912 r
F P
0 g
s
.56523 .28672 m .5491 .30965 L .55248 .31074 L p .65 .735 .912 r
F P
0 g
s
.82123 .48806 m .83871 .52177 L .84247 .50968 L p .186 .229 .675 r
F P
0 g
s
.84247 .50968 m .82496 .47648 L .82123 .48806 L p .186 .229 .675 r
F P
0 g
s
.61104 .3154 m .6469 .30749 L .64247 .30222 L p .604 .705 .915 r
F P
0 g
s
.64247 .30222 m .60786 .31173 L .61104 .3154 L p .604 .705 .915 r
F P
0 g
s
.23524 .61911 m .24017 .58628 L .25036 .59683 L p .943 .706 .55 r
F P
0 g
s
.25036 .59683 m .2458 .62944 L .23524 .61911 L p .943 .706 .55 r
F P
0 g
s
.71712 .79185 m .71463 .82397 L .73105 .81905 L p .509 .266 .482 r
F P
0 g
s
.73105 .81905 m .73406 .78677 L .71712 .79185 L p .509 .266 .482 r
F P
0 g
s
.48463 .28783 m .50189 .31019 L .50532 .30919 L p .671 .755 .913 r
F P
0 g
s
.50189 .31019 m .48463 .28783 L .47897 .28982 L p .673 .756 .913 r
F P
0 g
s
.5491 .30965 m .56523 .28672 L .5593 .2851 L p .651 .737 .912 r
F P
0 g
s
.5593 .2851 m .54562 .30872 L .5491 .30965 L p .651 .737 .912 r
F P
0 g
s
.28516 .76576 m .28512 .7326 L .297 .74187 L p .922 .639 .488 r
F P
0 g
s
.297 .74187 m .29724 .77494 L .28516 .76576 L p .922 .639 .488 r
F P
0 g
s
.49047 .28609 m .50532 .30919 L .50884 .30833 L p .669 .754 .914 r
F P
0 g
s
.50532 .30919 m .49047 .28609 L .48463 .28783 L p .671 .755 .913 r
F P
0 g
s
.65705 .32404 m .6956 .32583 L .69201 .31861 L p .544 .663 .914 r
F P
0 g
s
.69201 .31861 m .6542 .31842 L .65705 .32404 L p .544 .663 .914 r
F P
0 g
s
.41245 .2991 m .44652 .30977 L .44314 .31333 L p .7 .787 .918 r
F P
0 g
s
.44314 .31333 m .40769 .30414 L .41245 .2991 L p .7 .787 .918 r
F P
0 g
s
.54562 .30872 m .5593 .2851 L .55322 .28376 L p .653 .739 .913 r
F P
0 g
s
.55322 .28376 m .54206 .30795 L .54562 .30872 L p .653 .739 .913 r
F P
0 g
s
.36301 .86884 m .35627 .84053 L .37232 .84744 L p .826 .455 .351 r
F P
0 g
s
.37232 .84744 m .37862 .87519 L .36301 .86884 L p .826 .455 .351 r
F P
0 g
s
.7994 .69286 m .80059 .72721 L .81539 .71863 L p .41 .23 .523 r
F P
0 g
s
.81539 .71863 m .81424 .68384 L .7994 .69286 L p .41 .23 .523 r
F P
0 g
s
.49647 .2846 m .50884 .30833 L .51244 .30764 L p .668 .753 .914 r
F P
0 g
s
.50884 .30833 m .49647 .2846 L .49047 .28609 L p .669 .754 .914 r
F P
0 g
s
.70066 .34045 m .73831 .35128 L .73567 .34254 L p .465 .599 .901 r
F P
0 g
s
.73567 .34254 m .69848 .33311 L .70066 .34045 L p .465 .599 .901 r
F P
0 g
s
.31323 .81637 m .30994 .78399 L .32337 .79282 L p .894 .574 .434 r
F P
0 g
s
.32337 .79282 m .32676 .82485 L .31323 .81637 L p .894 .574 .434 r
F P
0 g
s
.54206 .30795 m .55322 .28376 L .54702 .2827 L p .654 .74 .913 r
F P
0 g
s
.54702 .2827 m .53843 .30734 L .54206 .30795 L p .654 .74 .913 r
F P
0 g
s
.50261 .28338 m .51244 .30764 L .5161 .3071 L p .666 .752 .914 r
F P
0 g
s
.51244 .30764 m .50261 .28338 L .49647 .2846 L p .668 .753 .914 r
F P
0 g
s
.53843 .30734 m .54702 .2827 L .54072 .28193 L p .656 .742 .914 r
F P
0 g
s
.54072 .28193 m .53474 .30688 L .53843 .30734 L p .656 .742 .914 r
F P
0 g
s
.76836 .7419 m .76742 .77535 L .7835 .76875 L p .465 .251 .503 r
F P
0 g
s
.7835 .76875 m .78481 .73494 L .76836 .7419 L p .465 .251 .503 r
F P
0 g
s
.27576 .37008 m .31148 .35352 L .31074 .36301 L p .848 .87 .857 r
F P
0 g
s
.31074 .36301 m .27529 .38113 L .27576 .37008 L p .848 .87 .857 r
F P
0 g
s
.50886 .28243 m .5161 .3071 L .51981 .30673 L p .664 .75 .915 r
F P
0 g
s
.5161 .3071 m .50886 .28243 L .50261 .28338 L p .666 .752 .914 r
F P
0 g
s
.22594 .45933 m .24884 .42939 L .2527 .44146 L p .934 .837 .724 r
F P
0 g
s
.2527 .44146 m .23082 .47219 L .22594 .45933 L p .934 .837 .724 r
F P
0 g
s
.60786 .31173 m .64247 .30222 L .63753 .29713 L p .605 .708 .917 r
F P
0 g
s
.63753 .29713 m .60432 .3082 L .60786 .31173 L p .605 .708 .917 r
F P
0 g
s
.53474 .30688 m .54072 .28193 L .53436 .28145 L p .657 .744 .914 r
F P
0 g
s
.53436 .28145 m .53102 .3066 L .53474 .30688 L p .657 .744 .914 r
F P
0 g
s
.77546 .39816 m .80466 .4238 L .80425 .41299 L p .271 .405 .814 r
F P
0 g
s
.80425 .41299 m .77534 .38823 L .77546 .39816 L p .271 .405 .814 r
F P
0 g
s
.26248 .71388 m .26439 .68123 L .27544 .69065 L p .935 .674 .516 r
F P
0 g
s
.27544 .69065 m .27366 .72326 L .26248 .71388 L p .935 .674 .516 r
F P
0 g
s
.51518 .28175 m .51981 .30673 L .52354 .30652 L p .662 .749 .915 r
F P
0 g
s
.51981 .30673 m .51518 .28175 L .50886 .28243 L p .664 .75 .915 r
F P
0 g
s
.53102 .3066 m .53436 .28145 L .52797 .28126 L p .659 .746 .914 r
F P
0 g
s
.52797 .28126 m .52728 .30647 L .53102 .3066 L p .659 .746 .914 r
F P
0 g
s
.52156 .28136 m .52354 .30652 L .52728 .30647 L p .66 .747 .914 r
F P
0 g
s
.52354 .30652 m .52156 .28136 L .51518 .28175 L p .662 .749 .915 r
F P
0 g
s
.36161 .31308 m .39976 .31482 L .39662 .3204 L p .738 .822 .917 r
F P
0 g
s
.39662 .3204 m .35764 .32029 L .36161 .31308 L p .738 .822 .917 r
F P
0 g
s
.52728 .30647 m .52797 .28126 L .52156 .28136 L p .66 .747 .914 r
F P
0 g
s
.66466 .83766 m .66048 .86712 L .67667 .86286 L p .514 .235 .43 r
F P
0 g
s
.67667 .86286 m .68141 .8332 L .66466 .83766 L p .514 .235 .43 r
F P
0 g
s
.66466 .83766 m .66048 .86712 L .64409 .87129 L p .526 .246 .433 r
F P
0 g
s
.22082 .5636 m .22996 .53003 L .23864 .54176 L p .951 .744 .589 r
F P
0 g
s
.23864 .54176 m .23028 .57521 L .22082 .5636 L p .951 .744 .589 r
F P
0 g
s
.82376 .6388 m .82779 .674 L .83976 .66335 L p .321 .19 .541 r
F P
0 g
s
.83976 .66335 m .83551 .62789 L .82376 .6388 L p .321 .19 .541 r
F P
0 g
s
.83313 .53375 m .84534 .56883 L .85108 .55654 L p .174 .168 .611 r
F P
0 g
s
.85108 .55654 m .83871 .52177 L .83313 .53375 L p .174 .168 .611 r
F P
0 g
s
.50459 .91553 m .50304 .89467 L .52158 .89366 L p .612 .225 .285 r
F P
0 g
s
.52158 .89366 m .52189 .91483 L .50459 .91553 L p .612 .225 .285 r
F P
0 g
s
.52189 .91483 m .52158 .89366 L .53994 .89187 L p .592 .214 .294 r
F P
0 g
s
.48728 .91546 m .48444 .8948 L .50304 .89467 L p .633 .236 .275 r
F P
0 g
s
.50304 .89467 m .50459 .91553 L .48728 .91546 L p .633 .236 .275 r
F P
0 g
s
.41773 .29427 m .45025 .30636 L .44652 .30977 L p .696 .788 .922 r
F P
0 g
s
.44652 .30977 m .41245 .2991 L .41773 .29427 L p .696 .788 .922 r
F P
0 g
s
.31597 .33489 m .35444 .32771 L .35202 .33527 L p .79 .856 .9 r
F P
0 g
s
.35202 .33527 m .31322 .34412 L .31597 .33489 L p .79 .856 .9 r
F P
0 g
s
.53994 .89187 m .53907 .91345 L .52189 .91483 L p .592 .214 .294 r
F P
0 g
s
.53907 .91345 m .53994 .89187 L .55806 .88941 L p .573 .204 .302 r
F P
0 g
s
.47004 .91459 m .4659 .89398 L .48444 .8948 L p .654 .249 .263 r
F P
0 g
s
.48444 .8948 m .48728 .91546 L .47004 .91459 L p .654 .249 .263 r
F P
0 g
s
.60432 .3082 m .63753 .29713 L .6321 .29222 L p .605 .712 .92 r
F P
0 g
s
.6321 .29222 m .60044 .30482 L .60432 .3082 L p .605 .712 .92 r
F P
0 g
s
.6542 .31842 m .69201 .31861 L .68774 .31148 L p .541 .667 .919 r
F P
0 g
s
.68774 .31148 m .65082 .3129 L .6542 .31842 L p .541 .667 .919 r
F P
0 g
s
.24264 .6619 m .2458 .62944 L .25647 .63939 L p .941 .691 .53 r
F P
0 g
s
.25647 .63939 m .25347 .67166 L .24264 .6619 L p .941 .691 .53 r
F P
0 g
s
.55806 .88941 m .55608 .91148 L .53907 .91345 L p .573 .204 .302 r
F P
0 g
s
.55608 .91148 m .55806 .88941 L .57589 .88642 L p .556 .194 .309 r
F P
0 g
s
.45297 .91288 m .44755 .89217 L .4659 .89398 L p .676 .262 .251 r
F P
0 g
s
.4659 .89398 m .47004 .91459 L .45297 .91288 L p .676 .262 .251 r
F P
0 g
s
.73406 .78677 m .73105 .81905 L .74727 .81379 L p .489 .246 .473 r
F P
0 g
s
.74727 .81379 m .75087 .78131 L .73406 .78677 L p .489 .246 .473 r
F P
0 g
s
.80379 .43465 m .8271 .4649 L .8277 .45337 L p .165 .284 .741 r
F P
0 g
s
.8277 .45337 m .80466 .4238 L .80379 .43465 L p .165 .284 .741 r
F P
0 g
s
.74009 .36003 m .77416 .37833 L .77196 .36845 L p .354 .508 .873 r
F P
0 g
s
.77196 .36845 m .73831 .35128 L .74009 .36003 L p .354 .508 .873 r
F P
0 g
s
.42348 .28967 m .45432 .30311 L .45025 .30636 L p .693 .789 .924 r
F P
0 g
s
.45025 .30636 m .41773 .29427 L .42348 .28967 L p .693 .789 .924 r
F P
0 g
s
.24483 .40477 m .27529 .38113 L .27601 .39222 L p .9 .878 .804 r
F P
0 g
s
.27601 .39222 m .24617 .41713 L .24483 .40477 L p .9 .878 .804 r
F P
0 g
s
.21496 .50496 m .23082 .47219 L .23683 .48467 L p .955 .802 .652 r
F P
0 g
s
.23683 .48467 m .22199 .51775 L .21496 .50496 L p .955 .802 .652 r
F P
0 g
s
.36634 .30608 m .40345 .30939 L .39976 .31482 L p .733 .827 .923 r
F P
0 g
s
.39976 .31482 m .36161 .31308 L .36634 .30608 L p .733 .827 .923 r
F P
0 g
s
.34815 .86187 m .34109 .83295 L .35627 .84053 L p .846 .473 .344 r
F P
0 g
s
.35627 .84053 m .36301 .86884 L .34815 .86187 L p .846 .473 .344 r
F P
0 g
s
.69848 .33311 m .73567 .34254 L .73219 .33384 L p .454 .601 .907 r
F P
0 g
s
.73219 .33384 m .6956 .32583 L .69848 .33311 L p .454 .601 .907 r
F P
0 g
s
.57589 .88642 m .57287 .90901 L .55608 .91148 L p .556 .194 .309 r
F P
0 g
s
.57287 .90901 m .57589 .88642 L .59339 .88301 L p .539 .184 .314 r
F P
0 g
s
.60044 .30482 m .6321 .29222 L .6262 .28753 L p .606 .716 .922 r
F P
0 g
s
.6262 .28753 m .59624 .3016 L .60044 .30482 L p .606 .716 .922 r
F P
0 g
s
.83762 .58083 m .84545 .61634 L .85341 .60427 L p .197 .14 .562 r
F P
0 g
s
.85341 .60427 m .84534 .56883 L .83762 .58083 L p .197 .14 .562 r
F P
0 g
s
.68141 .8332 m .67667 .86286 L .69268 .85848 L p .501 .223 .424 r
F P
0 g
s
.69268 .85848 m .69807 .82866 L .68141 .8332 L p .501 .223 .424 r
F P
0 g
s
.43619 .91031 m .42953 .88935 L .44755 .89217 L p .699 .275 .239 r
F P
0 g
s
.44755 .89217 m .45297 .91288 L .43619 .91031 L p .699 .275 .239 r
F P
0 g
s
.22489 .60833 m .23028 .57521 L .24017 .58628 L p .949 .714 .549 r
F P
0 g
s
.24017 .58628 m .23524 .61911 L .22489 .60833 L p .949 .714 .549 r
F P
0 g
s
.42969 .28533 m .45869 .30005 L .45432 .30311 L p .69 .79 .927 r
F P
0 g
s
.45432 .30311 m .42348 .28967 L .42969 .28533 L p .69 .79 .927 r
F P
0 g
s
.27354 .75654 m .27366 .72326 L .28512 .7326 L p .93 .649 .487 r
F P
0 g
s
.28512 .7326 m .28516 .76576 L .27354 .75654 L p .93 .649 .487 r
F P
0 g
s
.30042 .80765 m .29724 .77494 L .30994 .78399 L p .908 .589 .431 r
F P
0 g
s
.30994 .78399 m .31323 .81637 L .30042 .80765 L p .908 .589 .431 r
F P
0 g
s
.65082 .3129 m .68774 .31148 L .68279 .30446 L p .539 .671 .923 r
F P
0 g
s
.68279 .30446 m .6469 .30749 L .65082 .3129 L p .539 .671 .923 r
F P
0 g
s
.27749 .35915 m .31322 .34412 L .31148 .35352 L p .845 .888 .871 r
F P
0 g
s
.31148 .35352 m .27576 .37008 L .27749 .35915 L p .845 .888 .871 r
F P
0 g
s
.78481 .73494 m .7835 .76875 L .79889 .76141 L p .427 .218 .492 r
F P
0 g
s
.79889 .76141 m .80059 .72721 L .78481 .73494 L p .427 .218 .492 r
F P
0 g
s
.59339 .88301 m .5894 .90612 L .57287 .90901 L p .539 .184 .314 r
F P
0 g
s
.5894 .90612 m .59339 .88301 L .61058 .87929 L p .522 .174 .317 r
F P
0 g
s
.31974 .32588 m .35764 .32029 L .35444 .32771 L p .783 .866 .911 r
F P
0 g
s
.35444 .32771 m .31597 .33489 L .31974 .32588 L p .783 .866 .911 r
F P
0 g
s
.82496 .47648 m .84247 .50968 L .84442 .49758 L p .088 .174 .66 r
F P
0 g
s
.84442 .49758 m .8271 .4649 L .82496 .47648 L p .088 .174 .66 r
F P
0 g
s
.81424 .68384 m .81539 .71863 L .82891 .70919 L p .356 .188 .511 r
F P
0 g
s
.82891 .70919 m .82779 .674 L .81424 .68384 L p .356 .188 .511 r
F P
0 g
s
.59624 .3016 m .6262 .28753 L .61984 .2831 L p .608 .72 .924 r
F P
0 g
s
.61984 .2831 m .59172 .29857 L .59624 .3016 L p .608 .72 .924 r
F P
0 g
s
.77534 .38823 m .80425 .41299 L .80264 .40224 L p .219 .385 .816 r
F P
0 g
s
.80264 .40224 m .77416 .37833 L .77534 .38823 L p .219 .385 .816 r
F P
0 g
s
.41979 .9069 m .41196 .88553 L .42953 .88935 L p .721 .29 .226 r
F P
0 g
s
.42953 .88935 m .43619 .91031 L .41979 .9069 L p .721 .29 .226 r
F P
0 g
s
.22239 .44621 m .24617 .41713 L .24884 .42939 L p .941 .862 .734 r
F P
0 g
s
.24884 .42939 m .22594 .45933 L .22239 .44621 L p .941 .862 .734 r
F P
0 g
s
.43634 .28125 m .46337 .29717 L .45869 .30005 L p .686 .79 .929 r
F P
0 g
s
.45869 .30005 m .42969 .28533 L .43634 .28125 L p .686 .79 .929 r
F P
0 g
s
.3718 .29934 m .40769 .30414 L .40345 .30939 L p .726 .832 .93 r
F P
0 g
s
.40345 .30939 m .36634 .30608 L .3718 .29934 L p .726 .832 .93 r
F P
0 g
s
.25147 .70445 m .25347 .67166 L .26439 .68123 L p .94 .679 .514 r
F P
0 g
s
.26439 .68123 m .26248 .71388 L .25147 .70445 L p .94 .679 .514 r
F P
0 g
s
.21203 .55142 m .22199 .51775 L .22996 .53003 L p .96 .761 .591 r
F P
0 g
s
.22996 .53003 m .22082 .5636 L .21203 .55142 L p .96 .761 .591 r
F P
0 g
s
.59172 .29857 m .61984 .2831 L .61305 .27894 L p .61 .724 .926 r
F P
0 g
s
.61305 .27894 m .58692 .29574 L .59172 .29857 L p .61 .724 .926 r
F P
0 g
s
.75087 .78131 m .74727 .81379 L .76314 .80805 L p .462 .22 .461 r
F P
0 g
s
.76314 .80805 m .76742 .77535 L .75087 .78131 L p .462 .22 .461 r
F P
0 g
s
.61058 .87929 m .60567 .90291 L .5894 .90612 L p .522 .174 .317 r
F P
0 g
s
.60567 .90291 m .61058 .87929 L .62747 .87536 L p .506 .162 .318 r
F P
0 g
s
.83551 .62789 m .83976 .66335 L .8499 .65198 L p .24 .134 .526 r
F P
0 g
s
.8499 .65198 m .84545 .61634 L .83551 .62789 L p .24 .134 .526 r
F P
0 g
s
.69807 .82866 m .69268 .85848 L .70849 .85393 L p .486 .207 .415 r
F P
0 g
s
.70849 .85393 m .71463 .82397 L .69807 .82866 L p .486 .207 .415 r
F P
0 g
s
.6956 .32583 m .73219 .33384 L .7279 .32519 L p .443 .604 .914 r
F P
0 g
s
.7279 .32519 m .69201 .31861 L .6956 .32583 L p .443 .604 .914 r
F P
0 g
s
.44338 .27745 m .46832 .2945 L .46337 .29717 L p .683 .791 .931 r
F P
0 g
s
.46337 .29717 m .43634 .28125 L .44338 .27745 L p .683 .791 .931 r
F P
0 g
s
.6469 .30749 m .68279 .30446 L .67718 .29757 L p .537 .676 .928 r
F P
0 g
s
.67718 .29757 m .64247 .30222 L .6469 .30749 L p .537 .676 .928 r
F P
0 g
s
.73831 .35128 m .77196 .36845 L .7688 .35859 L p .327 .503 .879 r
F P
0 g
s
.7688 .35859 m .73567 .34254 L .73831 .35128 L p .327 .503 .879 r
F P
0 g
s
.33406 .85439 m .32676 .82485 L .34109 .83295 L p .864 .49 .337 r
F P
0 g
s
.34109 .83295 m .34815 .86187 L .33406 .85439 L p .864 .49 .337 r
F P
0 g
s
.83871 .52177 m .85108 .55654 L .8548 .54409 L p .06 .099 .588 r
F P
0 g
s
.8548 .54409 m .84247 .50968 L .83871 .52177 L p .06 .099 .588 r
F P
0 g
s
.58692 .29574 m .61305 .27894 L .60586 .27509 L p .612 .728 .928 r
F P
0 g
s
.60586 .27509 m .58185 .29312 L .58692 .29574 L p .612 .728 .928 r
F P
0 g
s
.23189 .65186 m .23524 .61911 L .2458 .62944 L p .946 .696 .528 r
F P
0 g
s
.2458 .62944 m .24264 .6619 L .23189 .65186 L p .946 .696 .528 r
F P
0 g
s
.24491 .39243 m .27576 .37008 L .27529 .38113 L p .9 .902 .818 r
F P
0 g
s
.27529 .38113 m .24483 .40477 L .24491 .39243 L p .9 .902 .818 r
F P
0 g
s
.40387 .90269 m .39496 .88079 L .41196 .88553 L p .742 .305 .212 r
F P
0 g
s
.41196 .88553 m .41979 .9069 L .40387 .90269 L p .742 .305 .212 r
F P
0 g
s
.37797 .29288 m .41245 .2991 L .40769 .30414 L p .72 .835 .936 r
F P
0 g
s
.40769 .30414 m .3718 .29934 L .37797 .29288 L p .72 .835 .936 r
F P
0 g
s
.4508 .27394 m .47353 .29205 L .46832 .2945 L p .679 .79 .933 r
F P
0 g
s
.46832 .2945 m .44338 .27745 L .4508 .27394 L p .679 .79 .933 r
F P
0 g
s
.32452 .31715 m .36161 .31308 L .35764 .32029 L p .775 .877 .921 r
F P
0 g
s
.35764 .32029 m .31974 .32588 L .32452 .31715 L p .775 .877 .921 r
F P
0 g
s
.80466 .4238 m .8277 .45337 L .82685 .44193 L p .08 .242 .73 r
F P
0 g
s
.82685 .44193 m .80425 .41299 L .80466 .4238 L p .08 .242 .73 r
F P
0 g
s
.62747 .87536 m .62166 .89945 L .60567 .90291 L p .506 .162 .318 r
F P
0 g
s
.62166 .89945 m .62747 .87536 L .64409 .87129 L p .49 .149 .316 r
F P
0 g
s
.20911 .49173 m .22594 .45933 L .23082 .47219 L p .964 .826 .658 r
F P
0 g
s
.23082 .47219 m .21496 .50496 L .20911 .49173 L p .964 .826 .658 r
F P
0 g
s
.58185 .29312 m .60586 .27509 L .59829 .27157 L p .614 .732 .93 r
F P
0 g
s
.59829 .27157 m .57653 .29074 L .58185 .29312 L p .614 .732 .93 r
F P
0 g
s
.28048 .34844 m .31597 .33489 L .31322 .34412 L p .838 .906 .884 r
F P
0 g
s
.31322 .34412 m .27749 .35915 L .28048 .34844 L p .838 .906 .884 r
F P
0 g
s
.45855 .27073 m .47897 .28982 L .47353 .29205 L p .676 .79 .935 r
F P
0 g
s
.47353 .29205 m .4508 .27394 L .45855 .27073 L p .676 .79 .935 r
F P
0 g
s
.28823 .7988 m .28516 .76576 L .29724 .77494 L p .919 .602 .429 r
F P
0 g
s
.29724 .77494 m .30042 .80765 L .28823 .7988 L p .919 .602 .429 r
F P
0 g
s
.64247 .30222 m .67718 .29757 L .67092 .29086 L p .536 .682 .932 r
F P
0 g
s
.67092 .29086 m .63753 .29713 L .64247 .30222 L p .536 .682 .932 r
F P
0 g
s
.80059 .72721 m .79889 .76141 L .81331 .75325 L p .378 .177 .476 r
F P
0 g
s
.81331 .75325 m .81539 .71863 L .80059 .72721 L p .378 .177 .476 r
F P
0 g
s
.26226 .74732 m .26248 .71388 L .27366 .72326 L p .937 .657 .485 r
F P
0 g
s
.27366 .72326 m .27354 .75654 L .26226 .74732 L p .937 .657 .485 r
F P
0 g
s
.21492 .59705 m .22082 .5636 L .23028 .57521 L p .957 .726 .548 r
F P
0 g
s
.23028 .57521 m .22489 .60833 L .21492 .59705 L p .957 .726 .548 r
F P
0 g
s
.57653 .29074 m .59829 .27157 L .59038 .26842 L p .617 .736 .931 r
F P
0 g
s
.59038 .26842 m .57098 .2886 L .57653 .29074 L p .617 .736 .931 r
F P
0 g
s
.84534 .56883 m .85341 .60427 L .85925 .59182 L p .083 .065 .537 r
F P
0 g
s
.85925 .59182 m .85108 .55654 L .84534 .56883 L p .083 .065 .537 r
F P
0 g
s
.71463 .82397 m .70849 .85393 L .72407 .84915 L p .466 .186 .404 r
F P
0 g
s
.72407 .84915 m .73105 .81905 L .71463 .82397 L p .466 .186 .404 r
F P
0 g
s
.69201 .31861 m .7279 .32519 L .72281 .31658 L p .434 .608 .921 r
F P
0 g
s
.72281 .31658 m .68774 .31148 L .69201 .31861 L p .434 .608 .921 r
F P
0 g
s
.45855 .27073 m .47897 .28982 L .48463 .28783 L p .672 .789 .936 r
F P
0 g
s
.82779 .674 m .82891 .70919 L .84088 .69889 L p .284 .134 .494 r
F P
0 g
s
.84088 .69889 m .83976 .66335 L .82779 .674 L p .284 .134 .494 r
F P
0 g
s
.3885 .89775 m .37862 .87519 L .39496 .88079 L p .763 .32 .199 r
F P
0 g
s
.39496 .88079 m .40387 .90269 L .3885 .89775 L p .763 .32 .199 r
F P
0 g
s
.38482 .2867 m .41773 .29427 L .41245 .2991 L p .713 .838 .942 r
F P
0 g
s
.41245 .2991 m .37797 .29288 L .38482 .2867 L p .713 .838 .942 r
F P
0 g
s
.76742 .77535 m .76314 .80805 L .7785 .80174 L p .428 .188 .446 r
F P
0 g
s
.7785 .80174 m .7835 .76875 L .76742 .77535 L p .428 .188 .446 r
F P
0 g
s
.77416 .37833 m .80264 .40224 L .79992 .39154 L p .164 .364 .815 r
F P
0 g
s
.79992 .39154 m .77196 .36845 L .77416 .37833 L p .164 .364 .815 r
F P
0 g
s
.57098 .2886 m .59038 .26842 L .58216 .26564 L p .62 .741 .933 r
F P
0 g
s
.58216 .26564 m .56523 .28672 L .57098 .2886 L p .62 .741 .933 r
F P
0 g
s
.64409 .87129 m .63739 .89579 L .62166 .89945 L p .49 .149 .316 r
F P
0 g
s
.63739 .89579 m .64409 .87129 L .66048 .86712 L p .472 .134 .311 r
F P
0 g
s
.22034 .43294 m .24483 .40477 L .24617 .41713 L p .946 .891 .744 r
F P
0 g
s
.24617 .41713 m .22239 .44621 L .22034 .43294 L p .946 .891 .744 r
F P
0 g
s
.8271 .4649 m .84442 .49758 L .84464 .48555 L p 0 .106 .632 r
F P
0 g
s
.84464 .48555 m .8277 .45337 L .8271 .4649 L p 0 .106 .632 r
F P
0 g
s
.24058 .6949 m .24264 .6619 L .25347 .67166 L p .944 .683 .511 r
F P
0 g
s
.25347 .67166 m .25147 .70445 L .24058 .6949 L p .944 .683 .511 r
F P
0 g
s
.46662 .26784 m .48463 .28783 L .49047 .28609 L p .668 .787 .938 r
F P
0 g
s
.48463 .28783 m .46662 .26784 L .45855 .27073 L p .672 .789 .936 r
F P
0 g
s
.32069 .84654 m .31323 .81637 L .32676 .82485 L p .879 .506 .331 r
F P
0 g
s
.32676 .82485 m .33406 .85439 L .32069 .84654 L p .879 .506 .331 r
F P
0 g
s
.73567 .34254 m .7688 .35859 L .76473 .34875 L p .3 .499 .885 r
F P
0 g
s
.76473 .34875 m .73219 .33384 L .73567 .34254 L p .3 .499 .885 r
F P
0 g
s
.56523 .28672 m .58216 .26564 L .57367 .26327 L p .623 .745 .934 r
F P
0 g
s
.57367 .26327 m .5593 .2851 L .56523 .28672 L p .623 .745 .934 r
F P
0 g
s
.33027 .30872 m .36634 .30608 L .36161 .31308 L p .765 .886 .932 r
F P
0 g
s
.36161 .31308 m .32452 .31715 L .33027 .30872 L p .765 .886 .932 r
F P
0 g
s
.63753 .29713 m .67092 .29086 L .66402 .28436 L p .537 .688 .937 r
F P
0 g
s
.66402 .28436 m .6321 .29222 L .63753 .29713 L p .537 .688 .937 r
F P
0 g
s
.20415 .53869 m .21496 .50496 L .22199 .51775 L p .971 .782 .592 r
F P
0 g
s
.22199 .51775 m .21203 .55142 L .20415 .53869 L p .971 .782 .592 r
F P
0 g
s
.47496 .26529 m .49047 .28609 L .49647 .2846 L p .664 .785 .939 r
F P
0 g
s
.49047 .28609 m .47496 .26529 L .46662 .26784 L p .668 .787 .938 r
F P
0 g
s
.5593 .2851 m .57367 .26327 L .56496 .26132 L p .626 .749 .936 r
F P
0 g
s
.56496 .26132 m .55322 .28376 L .5593 .2851 L p .626 .749 .936 r
F P
0 g
s
.48354 .26309 m .49647 .2846 L .50261 .28338 L p .659 .783 .94 r
F P
0 g
s
.49647 .2846 m .48354 .26309 L .47496 .26529 L p .664 .785 .939 r
F P
0 g
s
.2465 .38023 m .27749 .35915 L .27576 .37008 L p .896 .928 .831 r
F P
0 g
s
.27576 .37008 m .24491 .39243 L .2465 .38023 L p .896 .928 .831 r
F P
0 g
s
.3923 .28084 m .42348 .28967 L .41773 .29427 L p .706 .841 .947 r
F P
0 g
s
.41773 .29427 m .38482 .2867 L .3923 .28084 L p .706 .841 .947 r
F P
0 g
s
.55322 .28376 m .56496 .26132 L .55606 .2598 L p .629 .754 .937 r
F P
0 g
s
.55606 .2598 m .54702 .2827 L .55322 .28376 L p .629 .754 .937 r
F P
0 g
s
.84545 .61634 m .8499 .65198 L .85799 .63998 L p .134 .06 .501 r
F P
0 g
s
.85799 .63998 m .85341 .60427 L .84545 .61634 L p .134 .06 .501 r
F P
0 g
s
.28476 .33802 m .31974 .32588 L .31597 .33489 L p .828 .923 .898 r
F P
0 g
s
.31597 .33489 m .28048 .34844 L .28476 .33802 L p .828 .923 .898 r
F P
0 g
s
.22132 .64146 m .22489 .60833 L .23524 .61911 L p .952 .704 .524 r
F P
0 g
s
.23524 .61911 m .23189 .65186 L .22132 .64146 L p .952 .704 .524 r
F P
0 g
s
.49232 .26125 m .50261 .28338 L .50886 .28243 L p .655 .78 .94 r
F P
0 g
s
.50261 .28338 m .49232 .26125 L .48354 .26309 L p .659 .783 .94 r
F P
0 g
s
.54702 .2827 m .55606 .2598 L .54701 .25871 L p .632 .758 .938 r
F P
0 g
s
.54701 .25871 m .54072 .28193 L .54702 .2827 L p .632 .758 .938 r
F P
0 g
s
.66048 .86712 m .65286 .89196 L .66807 .88798 L p .455 .117 .304 r
F P
0 g
s
.66807 .88798 m .67667 .86286 L .66048 .86712 L p .455 .117 .304 r
F P
0 g
s
.66048 .86712 m .65286 .89196 L .63739 .89579 L p .472 .134 .311 r
F P
0 g
s
.37374 .89215 m .36301 .86884 L .37862 .87519 L p .783 .335 .185 r
F P
0 g
s
.37862 .87519 m .3885 .89775 L .37374 .89215 L p .783 .335 .185 r
F P
0 g
s
.68774 .31148 m .72281 .31658 L .71694 .30805 L p .426 .613 .927 r
F P
0 g
s
.71694 .30805 m .68279 .30446 L .68774 .31148 L p .426 .613 .927 r
F P
0 g
s
.50127 .25979 m .50886 .28243 L .51518 .28175 L p .651 .777 .94 r
F P
0 g
s
.50886 .28243 m .50127 .25979 L .49232 .26125 L p .655 .78 .94 r
F P
0 g
s
.54072 .28193 m .54701 .25871 L .53787 .25807 L p .636 .762 .939 r
F P
0 g
s
.53787 .25807 m .53436 .28145 L .54072 .28193 L p .636 .762 .939 r
F P
0 g
s
.84247 .50968 m .8548 .54409 L .85652 .53161 L p 0 .011 .548 r
F P
0 g
s
.85652 .53161 m .84442 .49758 L .84247 .50968 L p 0 .011 .548 r
F P
0 g
s
.73105 .81905 m .72407 .84915 L .73933 .84403 L p .44 .159 .389 r
F P
0 g
s
.73933 .84403 m .74727 .81379 L .73105 .81905 L p .44 .159 .389 r
F P
0 g
s
.6321 .29222 m .66402 .28436 L .65649 .2781 L p .538 .695 .941 r
F P
0 g
s
.65649 .2781 m .6262 .28753 L .6321 .29222 L p .538 .695 .941 r
F P
0 g
s
.51034 .25873 m .51518 .28175 L .52156 .28136 L p .647 .773 .94 r
F P
0 g
s
.51518 .28175 m .51034 .25873 L .50127 .25979 L p .651 .777 .94 r
F P
0 g
s
.53436 .28145 m .53787 .25807 L .52868 .25786 L p .64 .766 .94 r
F P
0 g
s
.52868 .25786 m .52797 .28126 L .53436 .28145 L p .64 .766 .94 r
F P
0 g
s
.51949 .25808 m .52156 .28136 L .52797 .28126 L p .643 .77 .94 r
F P
0 g
s
.52156 .28136 m .51949 .25808 L .51034 .25873 L p .647 .773 .94 r
F P
0 g
s
.52797 .28126 m .52868 .25786 L .51949 .25808 L p .643 .77 .94 r
F P
0 g
s
.80425 .41299 m .82685 .44193 L .82469 .43058 L p 0 .193 .711 r
F P
0 g
s
.82469 .43058 m .80264 .40224 L .80425 .41299 L p 0 .193 .711 r
F P
0 g
s
.27656 .7899 m .27354 .75654 L .28516 .76576 L p .928 .614 .426 r
F P
0 g
s
.28516 .76576 m .28823 .7988 L .27656 .7899 L p .928 .614 .426 r
F P
0 g
s
.20469 .47816 m .22239 .44621 L .22594 .45933 L p .973 .855 .663 r
F P
0 g
s
.22594 .45933 m .20911 .49173 L .20469 .47816 L p .973 .855 .663 r
F P
0 g
s
.40037 .27528 m .42969 .28533 L .42348 .28967 L p .698 .843 .952 r
F P
0 g
s
.42348 .28967 m .3923 .28084 L .40037 .27528 L p .698 .843 .952 r
F P
0 g
s
.33696 .30063 m .3718 .29934 L .36634 .30608 L p .753 .894 .941 r
F P
0 g
s
.36634 .30608 m .33027 .30872 L .33696 .30063 L p .753 .894 .941 r
F P
0 g
s
.81539 .71863 m .81331 .75325 L .82651 .74424 L p .314 .125 .456 r
F P
0 g
s
.82651 .74424 m .82891 .70919 L .81539 .71863 L p .314 .125 .456 r
F P
0 g
s
.25125 .73808 m .25147 .70445 L .26248 .71388 L p .942 .664 .482 r
F P
0 g
s
.26248 .71388 m .26226 .74732 L .25125 .73808 L p .942 .664 .482 r
F P
0 g
s
.7835 .76875 m .7785 .80174 L .79315 .79474 L p .383 .146 .426 r
F P
0 g
s
.79315 .79474 m .79889 .76141 L .7835 .76875 L p .383 .146 .426 r
F P
0 g
s
.20556 .58522 m .21203 .55142 L .22082 .5636 L p .967 .742 .545 r
F P
0 g
s
.22082 .5636 m .21492 .59705 L .20556 .58522 L p .967 .742 .545 r
F P
0 g
s
.73219 .33384 m .76473 .34875 L .75977 .33891 L p .275 .496 .89 r
F P
0 g
s
.75977 .33891 m .7279 .32519 L .73219 .33384 L p .275 .496 .89 r
F P
0 g
s
.77196 .36845 m .79992 .39154 L .79617 .38086 L p .107 .342 .81 r
F P
0 g
s
.79617 .38086 m .7688 .35859 L .77196 .36845 L p .107 .342 .81 r
F P
0 g
s
.30802 .83843 m .30042 .80765 L .31323 .81637 L p .893 .52 .325 r
F P
0 g
s
.31323 .81637 m .32069 .84654 L .30802 .83843 L p .893 .52 .325 r
F P
0 g
s
.6262 .28753 m .65649 .2781 L .64836 .27214 L p .54 .702 .945 r
F P
0 g
s
.64836 .27214 m .61984 .2831 L .6262 .28753 L p .54 .702 .945 r
F P
0 g
s
.67667 .86286 m .66807 .88798 L .68302 .88383 L p .436 .099 .293 r
F P
0 g
s
.68302 .88383 m .69268 .85848 L .67667 .86286 L p .436 .099 .293 r
F P
0 g
s
.83976 .66335 m .84088 .69889 L .85103 .6878 L p .19 .064 .468 r
F P
0 g
s
.85103 .6878 m .8499 .65198 L .83976 .66335 L p .19 .064 .468 r
F P
0 g
s
.85108 .55654 m .85925 .59182 L .86292 .57914 L p 0 0 .493 r
F P
0 g
s
.86292 .57914 m .8548 .54409 L .85108 .55654 L p 0 0 .493 r
F P
0 g
s
.21994 .41967 m .24491 .39243 L .24483 .40477 L p .946 .921 .753 r
F P
0 g
s
.24483 .40477 m .22034 .43294 L .21994 .41967 L p .946 .921 .753 r
F P
0 g
s
.22982 .68518 m .23189 .65186 L .24264 .6619 L p .949 .689 .507 r
F P
0 g
s
.24264 .6619 m .24058 .6949 L .22982 .68518 L p .949 .689 .507 r
F P
0 g
s
.68279 .30446 m .71694 .30805 L .71029 .29962 L p .42 .619 .934 r
F P
0 g
s
.71029 .29962 m .67718 .29757 L .68279 .30446 L p .42 .619 .934 r
F P
0 g
s
.35963 .88598 m .34815 .86187 L .36301 .86884 L p .8 .35 .172 r
F P
0 g
s
.36301 .86884 m .37374 .89215 L .35963 .88598 L p .8 .35 .172 r
F P
0 g
s
.40901 .27005 m .43634 .28125 L .42969 .28533 L p .691 .844 .956 r
F P
0 g
s
.42969 .28533 m .40037 .27528 L .40901 .27005 L p .691 .844 .956 r
F P
0 g
s
.50673 .92902 m .50459 .91553 L .52189 .91483 L p .517 .034 .048 r
F P
0 g
s
.52189 .91483 m .52232 .92864 L .50673 .92902 L p .517 .034 .048 r
F P
0 g
s
.52232 .92864 m .52189 .91483 L .53907 .91345 L p .498 .025 .063 r
F P
0 g
s
.49115 .92877 m .48728 .91546 L .50459 .91553 L p .535 .042 .031 r
F P
0 g
s
.50459 .91553 m .50673 .92902 L .49115 .92877 L p .535 .042 .031 r
F P
0 g
s
.53907 .91345 m .53785 .92769 L .52232 .92864 L p .498 .025 .063 r
F P
0 g
s
.53785 .92769 m .53907 .91345 L .55608 .91148 L p .48 .016 .075 r
F P
0 g
s
.29029 .32796 m .32452 .31715 L .31974 .32588 L p .814 .94 .91 r
F P
0 g
s
.31974 .32588 m .28476 .33802 L .29029 .32796 L p .814 .94 .91 r
F P
0 g
s
.8277 .45337 m .84464 .48555 L .84327 .47364 L p 0 .026 .587 r
F P
0 g
s
.84327 .47364 m .82685 .44193 L .8277 .45337 L p 0 .026 .587 r
F P
0 g
s
.47565 .92787 m .47004 .91459 L .48728 .91546 L p .554 .05 .012 r
F P
0 g
s
.48728 .91546 m .49115 .92877 L .47565 .92787 L p .554 .05 .012 r
F P
0 g
s
.24965 .3683 m .28048 .34844 L .27749 .35915 L p .887 .953 .843 r
F P
0 g
s
.27749 .35915 m .2465 .38023 L .24965 .3683 L p .887 .953 .843 r
F P
0 g
s
.55608 .91148 m .55327 .92623 L .53785 .92769 L p .48 .016 .075 r
F P
0 g
s
.55327 .92623 m .55608 .91148 L .57287 .90901 L p .461 .007 .085 r
F P
0 g
s
.61984 .2831 m .64836 .27214 L .63964 .26653 L p .542 .71 .949 r
F P
0 g
s
.63964 .26653 m .61305 .27894 L .61984 .2831 L p .542 .71 .949 r
F P
0 g
s
.74727 .81379 m .73933 .84403 L .75417 .83849 L p .406 .124 .369 r
F P
0 g
s
.75417 .83849 m .76314 .80805 L .74727 .81379 L p .406 .124 .369 r
F P
0 g
s
.19748 .52546 m .20911 .49173 L .21496 .50496 L p .982 .807 .591 r
F P
0 g
s
.21496 .50496 m .20415 .53869 L .19748 .52546 L p .982 .807 .591 r
F P
0 g
s
.34455 .29291 m .37797 .29288 L .3718 .29934 L p .74 .901 .95 r
F P
0 g
s
.3718 .29934 m .33696 .30063 L .34455 .29291 L p .74 .901 .95 r
F P
0 g
s
.46032 .92628 m .45297 .91288 L .47004 .91459 L p .573 .059 0 r
F P
0 g
s
.47004 .91459 m .47565 .92787 L .46032 .92628 L p .573 .059 0 r
F P
0 g
s
.57287 .90901 m .56852 .92431 L .55327 .92623 L p .461 .007 .085 r
F P
0 g
s
.56852 .92431 m .57287 .90901 L .5894 .90612 L p .442 0 .091 r
F P
0 g
s
.21111 .63062 m .21492 .59705 L .22489 .60833 L p .961 .714 .519 r
F P
0 g
s
.22489 .60833 m .22132 .64146 L .21111 .63062 L p .961 .714 .519 r
F P
0 g
s
.41817 .26516 m .44338 .27745 L .43634 .28125 L p .684 .844 .96 r
F P
0 g
s
.43634 .28125 m .40901 .27005 L .41817 .26516 L p .684 .844 .96 r
F P
0 g
s
.69268 .85848 m .68302 .88383 L .69769 .87947 L p .414 .075 .279 r
F P
0 g
s
.69769 .87947 m .70849 .85393 L .69268 .85848 L p .414 .075 .279 r
F P
0 g
s
.85341 .60427 m .85799 .63998 L .86392 .6275 L p 0 0 .459 r
F P
0 g
s
.86392 .6275 m .85925 .59182 L .85341 .60427 L p 0 0 .459 r
F P
0 g
s
.26532 .78098 m .26226 .74732 L .27354 .75654 L p .936 .623 .422 r
F P
0 g
s
.27354 .75654 m .27656 .7899 L .26532 .78098 L p .936 .623 .422 r
F P
0 g
s
.61305 .27894 m .63964 .26653 L .63036 .26131 L p .546 .718 .952 r
F P
0 g
s
.63036 .26131 m .60586 .27509 L .61305 .27894 L p .546 .718 .952 r
F P
0 g
s
.67718 .29757 m .71029 .29962 L .70287 .29133 L p .415 .626 .94 r
F P
0 g
s
.70287 .29133 m .67092 .29086 L .67718 .29757 L p .415 .626 .94 r
F P
0 g
s
.7279 .32519 m .75977 .33891 L .75397 .32908 L p .251 .495 .894 r
F P
0 g
s
.75397 .32908 m .72281 .31658 L .7279 .32519 L p .251 .495 .894 r
F P
0 g
s
.44522 .92401 m .43619 .91031 L .45297 .91288 L p .591 .067 0 r
F P
0 g
s
.45297 .91288 m .46032 .92628 L .44522 .92401 L p .591 .067 0 r
F P
0 g
s
.5894 .90612 m .58358 .922 L .56852 .92431 L p .442 0 .091 r
F P
0 g
s
.58358 .922 m .5894 .90612 L .60567 .90291 L p .423 0 .094 r
F P
0 g
s
.80264 .40224 m .82469 .43058 L .82133 .41932 L p 0 .139 .681 r
F P
0 g
s
.82133 .41932 m .79992 .39154 L .80264 .40224 L p 0 .139 .681 r
F P
0 g
s
.20193 .46439 m .22034 .43294 L .22239 .44621 L p .979 .887 .665 r
F P
0 g
s
.22239 .44621 m .20469 .47816 L .20193 .46439 L p .979 .887 .665 r
F P
0 g
s
.79889 .76141 m .79315 .79474 L .80686 .78698 L p .324 .093 .401 r
F P
0 g
s
.80686 .78698 m .81331 .75325 L .79889 .76141 L p .324 .093 .401 r
F P
0 g
s
.84442 .49758 m .85652 .53161 L .85636 .51918 L p 0 0 .484 r
F P
0 g
s
.85636 .51918 m .84464 .48555 L .84442 .49758 L p 0 0 .484 r
F P
0 g
s
.24044 .72879 m .24058 .6949 L .25147 .70445 L p .948 .669 .477 r
F P
0 g
s
.25147 .70445 m .25125 .73808 L .24044 .72879 L p .948 .669 .477 r
F P
0 g
s
.34617 .87935 m .33406 .85439 L .34815 .86187 L p .816 .364 .159 r
F P
0 g
s
.34815 .86187 m .35963 .88598 L .34617 .87935 L p .816 .364 .159 r
F P
0 g
s
.29597 .83015 m .28823 .7988 L .30042 .80765 L p .905 .533 .319 r
F P
0 g
s
.30042 .80765 m .30802 .83843 L .29597 .83015 L p .905 .533 .319 r
F P
0 g
s
.42781 .26061 m .4508 .27394 L .44338 .27745 L p .677 .844 .963 r
F P
0 g
s
.44338 .27745 m .41817 .26516 L .42781 .26061 L p .677 .844 .963 r
F P
0 g
s
.82891 .70919 m .82651 .74424 L .83821 .73436 L p .231 .057 .428 r
F P
0 g
s
.83821 .73436 m .84088 .69889 L .82891 .70919 L p .231 .057 .428 r
F P
0 g
s
.7688 .35859 m .79617 .38086 L .79147 .37019 L p .05 .319 .803 r
F P
0 g
s
.79147 .37019 m .76473 .34875 L .7688 .35859 L p .05 .319 .803 r
F P
0 g
s
.35297 .28557 m .38482 .2867 L .37797 .29288 L p .726 .907 .958 r
F P
0 g
s
.37797 .29288 m .34455 .29291 L .35297 .28557 L p .726 .907 .958 r
F P
0 g
s
.19709 .57283 m .20415 .53869 L .21203 .55142 L p .979 .762 .54 r
F P
0 g
s
.21203 .55142 m .20556 .58522 L .19709 .57283 L p .979 .762 .54 r
F P
0 g
s
.60586 .27509 m .63036 .26131 L .62056 .25653 L p .55 .726 .956 r
F P
0 g
s
.62056 .25653 m .59829 .27157 L .60586 .27509 L p .55 .726 .956 r
F P
0 g
s
.29705 .31831 m .33027 .30872 L .32452 .31715 L p .795 .954 .92 r
F P
0 g
s
.32452 .31715 m .29029 .32796 L .29705 .31831 L p .795 .954 .92 r
F P
0 g
s
.60567 .90291 m .59842 .91936 L .58358 .922 L p .423 0 .094 r
F P
0 g
s
.59842 .91936 m .60567 .90291 L .62166 .89945 L p .402 0 .092 r
F P
0 g
s
.43045 .92107 m .41979 .9069 L .43619 .91031 L p .608 .076 0 r
F P
0 g
s
.43619 .91031 m .44522 .92401 L .43045 .92107 L p .608 .076 0 r
F P
0 g
s
.22132 .40654 m .2465 .38023 L .24491 .39243 L p .939 .952 .758 r
F P
0 g
s
.24491 .39243 m .21994 .41967 L .22132 .40654 L p .939 .952 .758 r
F P
0 g
s
.43789 .25642 m .45855 .27073 L .4508 .27394 L p .67 .843 .966 r
F P
0 g
s
.4508 .27394 m .42781 .26061 L .43789 .25642 L p .67 .843 .966 r
F P
0 g
s
.76314 .80805 m .75417 .83849 L .76846 .83243 L p .362 .08 .343 r
F P
0 g
s
.76846 .83243 m .7785 .80174 L .76314 .80805 L p .362 .08 .343 r
F P
0 g
s
.21928 .67518 m .22132 .64146 L .23189 .65186 L p .956 .696 .5 r
F P
0 g
s
.23189 .65186 m .22982 .68518 L .21928 .67518 L p .956 .696 .5 r
F P
0 g
s
.25436 .35673 m .28476 .33802 L .28048 .34844 L p .868 .976 .851 r
F P
0 g
s
.28048 .34844 m .24965 .3683 L .25436 .35673 L p .868 .976 .851 r
F P
0 g
s
.67092 .29086 m .70287 .29133 L .69468 .28322 L p .413 .635 .947 r
F P
0 g
s
.69468 .28322 m .66402 .28436 L .67092 .29086 L p .413 .635 .947 r
F P
0 g
s
.70849 .85393 m .69769 .87947 L .71204 .87486 L p .385 .044 .259 r
F P
0 g
s
.71204 .87486 m .72407 .84915 L .70849 .85393 L p .385 .044 .259 r
F P
0 g
s
.8499 .65198 m .85103 .6878 L .85917 .67601 L p .065 0 .429 r
F P
0 g
s
.85917 .67601 m .85799 .63998 L .8499 .65198 L p .065 0 .429 r
F P
0 g
s
.59829 .27157 m .62056 .25653 L .61028 .25224 L p .554 .734 .959 r
F P
0 g
s
.61028 .25224 m .59038 .26842 L .59829 .27157 L p .554 .734 .959 r
F P
0 g
s
.8548 .54409 m .86292 .57914 L .86448 .56635 L p 0 0 .423 r
F P
0 g
s
.86448 .56635 m .85652 .53161 L .8548 .54409 L p 0 0 .423 r
F P
0 g
s
.62166 .89945 m .61301 .91643 L .59842 .91936 L p .402 0 .092 r
F P
0 g
s
.61301 .91643 m .62166 .89945 L .63739 .89579 L p .379 0 .086 r
F P
0 g
s
.41606 .91747 m .40387 .90269 L .41979 .9069 L p .624 .085 0 r
F P
0 g
s
.41979 .9069 m .43045 .92107 L .41606 .91747 L p .624 .085 0 r
F P
0 g
s
.43789 .25642 m .45855 .27073 L .46662 .26784 L p .662 .841 .969 r
F P
0 g
s
.82685 .44193 m .84327 .47364 L .84048 .46187 L p 0 0 .524 r
F P
0 g
s
.84048 .46187 m .82469 .43058 L .82685 .44193 L p 0 0 .524 r
F P
0 g
s
.72281 .31658 m .75397 .32908 L .74732 .31925 L p .23 .495 .899 r
F P
0 g
s
.74732 .31925 m .71694 .30805 L .72281 .31658 L p .23 .495 .899 r
F P
0 g
s
.19231 .51183 m .20469 .47816 L .20911 .49173 L p .992 .836 .586 r
F P
0 g
s
.20911 .49173 m .19748 .52546 L .19231 .51183 L p .992 .836 .586 r
F P
0 g
s
.36218 .2786 m .3923 .28084 L .38482 .2867 L p .711 .91 .965 r
F P
0 g
s
.38482 .2867 m .35297 .28557 L .36218 .2786 L p .711 .91 .965 r
F P
0 g
s
.59038 .26842 m .61028 .25224 L .59957 .24849 L p .559 .743 .962 r
F P
0 g
s
.59957 .24849 m .58216 .26564 L .59038 .26842 L p .559 .743 .962 r
F P
0 g
s
.33338 .87235 m .32069 .84654 L .33406 .85439 L p .83 .377 .145 r
F P
0 g
s
.33406 .85439 m .34617 .87935 L .33338 .87235 L p .83 .377 .145 r
F P
0 g
s
.20149 .61928 m .20556 .58522 L .21492 .59705 L p .971 .728 .511 r
F P
0 g
s
.21492 .59705 m .21111 .63062 L .20149 .61928 L p .971 .728 .511 r
F P
0 g
s
.25445 .77205 m .25125 .73808 L .26226 .74732 L p .943 .63 .416 r
F P
0 g
s
.26226 .74732 m .26532 .78098 L .25445 .77205 L p .943 .63 .416 r
F P
0 g
s
.44837 .2526 m .46662 .26784 L .47496 .26529 L p .654 .838 .971 r
F P
0 g
s
.46662 .26784 m .44837 .2526 L .43789 .25642 L p .662 .841 .969 r
F P
0 g
s
.28449 .82178 m .27656 .7899 L .28823 .7988 L p .914 .544 .311 r
F P
0 g
s
.28823 .7988 m .29597 .83015 L .28449 .82178 L p .914 .544 .311 r
F P
0 g
s
.58216 .26564 m .59957 .24849 L .58847 .24529 L p .565 .752 .965 r
F P
0 g
s
.58847 .24529 m .57367 .26327 L .58216 .26564 L p .565 .752 .965 r
F P
0 g
s
.63739 .89579 m .62735 .91325 L .61301 .91643 L p .379 0 .086 r
F P
0 g
s
.62735 .91325 m .63739 .89579 L .65286 .89196 L p .353 0 .075 r
F P
0 g
s
.30496 .30912 m .33696 .30063 L .33027 .30872 L p .77 .964 .927 r
F P
0 g
s
.33027 .30872 m .29705 .31831 L .30496 .30912 L p .77 .964 .927 r
F P
0 g
s
.66402 .28436 m .69468 .28322 L .68572 .27536 L p .412 .645 .953 r
F P
0 g
s
.68572 .27536 m .65649 .2781 L .66402 .28436 L p .412 .645 .953 r
F P
0 g
s
.79992 .39154 m .82133 .41932 L .81692 .40812 L p 0 .083 .643 r
F P
0 g
s
.81692 .40812 m .79617 .38086 L .79992 .39154 L p 0 .083 .643 r
F P
0 g
s
.81331 .75325 m .80686 .78698 L .81941 .77842 L p .247 .025 .366 r
F P
0 g
s
.81941 .77842 m .82651 .74424 L .81331 .75325 L p .247 .025 .366 r
F P
0 g
s
.76473 .34875 m .79147 .37019 L .78589 .35949 L p 0 .298 .793 r
F P
0 g
s
.78589 .35949 m .75977 .33891 L .76473 .34875 L p 0 .298 .793 r
F P
0 g
s
.40212 .91328 m .3885 .89775 L .40387 .90269 L p .638 .094 0 r
F P
0 g
s
.40387 .90269 m .41606 .91747 L .40212 .91328 L p .638 .094 0 r
F P
0 g
s
.22987 .71939 m .22982 .68518 L .24058 .6949 L p .954 .675 .469 r
F P
0 g
s
.24058 .6949 m .24044 .72879 L .22987 .71939 L p .954 .675 .469 r
F P
0 g
s
.45922 .24918 m .47496 .26529 L .48354 .26309 L p .645 .834 .973 r
F P
0 g
s
.47496 .26529 m .45922 .24918 L .44837 .2526 L p .654 .838 .971 r
F P
0 g
s
.85925 .59182 m .86392 .6275 L .86762 .6147 L p 0 0 .393 r
F P
0 g
s
.86762 .6147 m .86292 .57914 L .85925 .59182 L p 0 0 .393 r
F P
0 g
s
.20103 .45055 m .21994 .41967 L .22034 .43294 L p .976 .919 .66 r
F P
0 g
s
.22034 .43294 m .20193 .46439 L .20103 .45055 L p .976 .919 .66 r
F P
0 g
s
.57367 .26327 m .58847 .24529 L .57705 .2427 L p .571 .761 .968 r
F P
0 g
s
.57705 .2427 m .56496 .26132 L .57367 .26327 L p .571 .761 .968 r
F P
0 g
s
.72407 .84915 m .71204 .87486 L .72599 .86994 L p .349 .005 .232 r
F P
0 g
s
.72599 .86994 m .73933 .84403 L .72407 .84915 L p .349 .005 .232 r
F P
0 g
s
.84088 .69889 m .83821 .73436 L .84818 .72366 L p .12 0 .387 r
F P
0 g
s
.84818 .72366 m .85103 .6878 L .84088 .69889 L p .12 0 .387 r
F P
0 g
s
.7785 .80174 m .76846 .83243 L .78203 .82577 L p .305 .023 .31 r
F P
0 g
s
.78203 .82577 m .79315 .79474 L .7785 .80174 L p .305 .023 .31 r
F P
0 g
s
.37211 .27201 m .40037 .27528 L .3923 .28084 L p .695 .913 .97 r
F P
0 g
s
.3923 .28084 m .36218 .2786 L .37211 .27201 L p .695 .913 .97 r
F P
0 g
s
.47039 .24617 m .48354 .26309 L .49232 .26125 L p .636 .829 .975 r
F P
0 g
s
.48354 .26309 m .47039 .24617 L .45922 .24918 L p .645 .834 .973 r
F P
0 g
s
.84464 .48555 m .85636 .51918 L .85448 .50689 L p 0 0 .394 r
F P
0 g
s
.85448 .50689 m .84327 .47364 L .84464 .48555 L p 0 0 .394 r
F P
0 g
s
.56496 .26132 m .57705 .2427 L .56536 .24071 L p .577 .769 .97 r
F P
0 g
s
.56536 .24071 m .55606 .2598 L .56496 .26132 L p .577 .769 .97 r
F P
0 g
s
.18985 .5599 m .19748 .52546 L .20415 .53869 L p .991 .786 .531 r
F P
0 g
s
.20415 .53869 m .19709 .57283 L .18985 .5599 L p .991 .786 .531 r
F P
0 g
s
.2606 .34561 m .29029 .32796 L .28476 .33802 L p .838 .993 .853 r
F P
0 g
s
.28476 .33802 m .25436 .35673 L .2606 .34561 L p .838 .993 .853 r
F P
0 g
s
.48184 .24361 m .49232 .26125 L .50127 .25979 L p .628 .824 .976 r
F P
0 g
s
.49232 .26125 m .48184 .24361 L .47039 .24617 L p .636 .829 .975 r
F P
0 g
s
.71694 .30805 m .74732 .31925 L .73983 .30945 L p .212 .498 .903 r
F P
0 g
s
.73983 .30945 m .71029 .29962 L .71694 .30805 L p .212 .498 .903 r
F P
0 g
s
.22454 .39369 m .24965 .3683 L .2465 .38023 L p .918 .978 .755 r
F P
0 g
s
.2465 .38023 m .22132 .40654 L .22454 .39369 L p .918 .978 .755 r
F P
0 g
s
.65286 .89196 m .64141 .90985 L .65519 .90624 L p .326 0 .06 r
F P
0 g
s
.65519 .90624 m .66807 .88798 L .65286 .89196 L p .326 0 .06 r
F P
0 g
s
.65286 .89196 m .64141 .90985 L .62735 .91325 L p .353 0 .075 r
F P
0 g
s
.55606 .2598 m .56536 .24071 L .55349 .23935 L p .583 .778 .972 r
F P
0 g
s
.55349 .23935 m .54701 .25871 L .55606 .2598 L p .583 .778 .972 r
F P
0 g
s
.20914 .66481 m .21111 .63062 L .22132 .64146 L p .965 .705 .49 r
F P
0 g
s
.22132 .64146 m .21928 .67518 L .20914 .66481 L p .965 .705 .49 r
F P
0 g
s
.65649 .2781 m .68572 .27536 L .676 .26781 L p .412 .656 .959 r
F P
0 g
s
.676 .26781 m .64836 .27214 L .65649 .2781 L p .412 .656 .959 r
F P
0 g
s
.49352 .24153 m .50127 .25979 L .51034 .25873 L p .62 .817 .976 r
F P
0 g
s
.50127 .25979 m .49352 .24153 L .48184 .24361 L p .628 .824 .976 r
F P
0 g
s
.54701 .25871 m .55349 .23935 L .54149 .23861 L p .59 .787 .974 r
F P
0 g
s
.54149 .23861 m .53787 .25807 L .54701 .25871 L p .59 .787 .974 r
F P
0 g
s
.32124 .86508 m .30802 .83843 L .32069 .84654 L p .841 .388 .131 r
F P
0 g
s
.32069 .84654 m .33338 .87235 L .32124 .86508 L p .841 .388 .131 r
F P
0 g
s
.38869 .90853 m .37374 .89215 L .3885 .89775 L p .65 .102 0 r
F P
0 g
s
.3885 .89775 m .40212 .91328 L .38869 .90853 L p .65 .102 0 r
F P
0 g
s
.50538 .23996 m .51034 .25873 L .51949 .25808 L p .612 .811 .976 r
F P
0 g
s
.51034 .25873 m .50538 .23996 L .49352 .24153 L p .62 .817 .976 r
F P
0 g
s
.53787 .25807 m .54149 .23861 L .52942 .23847 L p .597 .795 .975 r
F P
0 g
s
.52942 .23847 m .52868 .25786 L .53787 .25807 L p .597 .795 .975 r
F P
0 g
s
.51737 .23893 m .51949 .25808 L .52868 .25786 L p .604 .803 .976 r
F P
0 g
s
.51949 .25808 m .51737 .23893 L .50538 .23996 L p .612 .811 .976 r
F P
0 g
s
.52868 .25786 m .52942 .23847 L .51737 .23893 L p .604 .803 .976 r
F P
0 g
s
.85799 .63998 m .85917 .67601 L .86517 .66365 L p 0 0 .37 r
F P
0 g
s
.86517 .66365 m .86392 .6275 L .85799 .63998 L p 0 0 .37 r
F P
0 g
s
.31395 .3004 m .34455 .29291 L .33696 .30063 L p .74 .97 .931 r
F P
0 g
s
.33696 .30063 m .30496 .30912 L .31395 .3004 L p .74 .97 .931 r
F P
0 g
s
.38271 .26579 m .40901 .27005 L .40037 .27528 L p .678 .914 .974 r
F P
0 g
s
.40037 .27528 m .37211 .27201 L .38271 .26579 L p .678 .914 .974 r
F P
0 g
s
.82469 .43058 m .84048 .46187 L .83645 .45023 L p 0 0 .445 r
F P
0 g
s
.83645 .45023 m .82133 .41932 L .82469 .43058 L p 0 0 .445 r
F P
0 g
s
.85652 .53161 m .86448 .56635 L .86405 .5536 L p 0 0 .323 r
F P
0 g
s
.86405 .5536 m .85636 .51918 L .85652 .53161 L p 0 0 .323 r
F P
0 g
s
.18894 .49791 m .20193 .46439 L .20469 .47816 L p .995 .866 .574 r
F P
0 g
s
.20469 .47816 m .19231 .51183 L .18894 .49791 L p .995 .866 .574 r
F P
0 g
s
.24392 .76309 m .24044 .72879 L .25125 .73808 L p .949 .636 .406 r
F P
0 g
s
.25125 .73808 m .25445 .77205 L .24392 .76309 L p .949 .636 .406 r
F P
0 g
s
.27353 .81336 m .26532 .78098 L .27656 .7899 L p .922 .553 .301 r
F P
0 g
s
.27656 .7899 m .28449 .82178 L .27353 .81336 L p .922 .553 .301 r
F P
0 g
s
.73933 .84403 m .72599 .86994 L .73946 .86462 L p .302 0 .198 r
F P
0 g
s
.73946 .86462 m .75417 .83849 L .73933 .84403 L p .302 0 .198 r
F P
0 g
s
.66807 .88798 m .65519 .90624 L .66866 .90241 L p .298 0 .04 r
F P
0 g
s
.66866 .90241 m .68302 .88383 L .66807 .88798 L p .298 0 .04 r
F P
0 g
s
.75977 .33891 m .78589 .35949 L .77946 .34874 L p 0 .279 .782 r
F P
0 g
s
.77946 .34874 m .75397 .32908 L .75977 .33891 L p 0 .279 .782 r
F P
0 g
s
.19277 .60738 m .19709 .57283 L .20556 .58522 L p .983 .746 .498 r
F P
0 g
s
.20556 .58522 m .20149 .61928 L .19277 .60738 L p .983 .746 .498 r
F P
0 g
s
.64836 .27214 m .676 .26781 L .66553 .26065 L p .414 .668 .965 r
F P
0 g
s
.66553 .26065 m .63964 .26653 L .64836 .27214 L p .414 .668 .965 r
F P
0 g
s
.79617 .38086 m .81692 .40812 L .81159 .39691 L p 0 .029 .598 r
F P
0 g
s
.81159 .39691 m .79147 .37019 L .79617 .38086 L p 0 .029 .598 r
F P
0 g
s
.71029 .29962 m .73983 .30945 L .7315 .29973 L p .197 .503 .908 r
F P
0 g
s
.7315 .29973 m .70287 .29133 L .71029 .29962 L p .197 .503 .908 r
F P
0 g
s
.82651 .74424 m .81941 .77842 L .83057 .76904 L p .145 0 .32 r
F P
0 g
s
.83057 .76904 m .83821 .73436 L .82651 .74424 L p .145 0 .32 r
F P
0 g
s
.37579 .9033 m .35963 .88598 L .37374 .89215 L p .66 .11 0 r
F P
0 g
s
.37374 .89215 m .38869 .90853 L .37579 .9033 L p .66 .11 0 r
F P
0 g
s
.21962 .70978 m .21928 .67518 L .22982 .68518 L p .962 .681 .457 r
F P
0 g
s
.22982 .68518 m .22987 .71939 L .21962 .70978 L p .962 .681 .457 r
F P
0 g
s
.79315 .79474 m .78203 .82577 L .7947 .81843 L p .23 0 .267 r
F P
0 g
s
.7947 .81843 m .80686 .78698 L .79315 .79474 L p .23 0 .267 r
F P
0 g
s
.39392 .25993 m .41817 .26516 L .40901 .27005 L p .662 .913 .978 r
F P
0 g
s
.40901 .27005 m .38271 .26579 L .39392 .25993 L p .662 .913 .978 r
F P
0 g
s
.20216 .43683 m .22132 .40654 L .21994 .41967 L p .956 .945 .643 r
F P
0 g
s
.21994 .41967 m .20103 .45055 L .20216 .43683 L p .956 .945 .643 r
F P
0 g
s
.26832 .33503 m .29705 .31831 L .29029 .32796 L p .791 .999 .843 r
F P
0 g
s
.29029 .32796 m .2606 .34561 L .26832 .33503 L p .791 .999 .843 r
F P
0 g
s
.30971 .8576 m .29597 .83015 L .30802 .83843 L p .85 .397 .116 r
F P
0 g
s
.30802 .83843 m .32124 .86508 L .30971 .8576 L p .85 .397 .116 r
F P
0 g
s
.86292 .57914 m .86762 .6147 L .86915 .60171 L p 0 0 .297 r
F P
0 g
s
.86915 .60171 m .86448 .56635 L .86292 .57914 L p 0 0 .297 r
F P
0 g
s
.63964 .26653 m .66553 .26065 L .65433 .25397 L p .418 .681 .971 r
F P
0 g
s
.65433 .25397 m .63036 .26131 L .63964 .26653 L p .418 .681 .971 r
F P
0 g
s
.85103 .6878 m .84818 .72366 L .85625 .71223 L p 0 0 .329 r
F P
0 g
s
.85625 .71223 m .85917 .67601 L .85103 .6878 L p 0 0 .329 r
F P
0 g
s
.32394 .29214 m .35297 .28557 L .34455 .29291 L p .704 .971 .929 r
F P
0 g
s
.34455 .29291 m .31395 .3004 L .32394 .29214 L p .704 .971 .929 r
F P
0 g
s
.22962 .38127 m .25436 .35673 L .24965 .3683 L p .873 .991 .737 r
F P
0 g
s
.24965 .3683 m .22454 .39369 L .22962 .38127 L p .873 .991 .737 r
F P
0 g
s
.68302 .88383 m .66866 .90241 L .68179 .89835 L p .263 0 .012 r
F P
0 g
s
.68179 .89835 m .69769 .87947 L .68302 .88383 L p .263 0 .012 r
F P
0 g
s
.84889 .4888 m .84327 .47364 L .85319 .50224 L 0 0 .286 r
F
.8511 .49477 m .84048 .46187 L .84327 .47364 L p F P
0 g
s
.84646 .48283 m .83645 .45023 L .83796 .4546 L p .712 .405 0 r
F P
0 g
s
.83796 .4546 m .84048 .46187 L p .8421 .46756 L .712 .405 0 r
F P
0 g
s
.84646 .48283 m .83796 .4546 L .8421 .46756 L .712 .405 0 r
F
.84327 .47364 m .85448 .50689 L .85319 .50224 L p 0 0 .286 r
F P
0 g
s
.85319 .50224 m .8511 .49477 L p .84889 .4888 L 0 0 .286 r
F P
0 g
s
.18416 .5465 m .19231 .51183 L .19748 .52546 L p .999 .811 .514 r
F P
0 g
s
.19748 .52546 m .18985 .5599 L .18416 .5465 L p .999 .811 .514 r
F P
0 g
s
.50673 .92902 m .52232 .92864 L p .50966 .93397 L .262 0 0 r
F P
0 g
s
.52232 .92864 m .52286 .93396 L .50939 .93408 L p .262 0 0 r
F P
0 g
s
.52286 .93396 m .52232 .92864 L .53785 .92769 L p .249 0 0 r
F P
0 g
s
.52348 .9308 m .51247 .93074 L p .52259 .93388 L .163 .695 .852 r
F P
0 g
s
.52286 .93396 m .52287 .93388 L p .52259 .93388 L .163 .695 .852 r
F P
0 g
s
.52287 .93388 m .52348 .9308 L p .52259 .93388 L .163 .695 .852 r
F P
0 g
s
.50939 .93408 m .50933 .93397 L p .50966 .93397 L .262 0 0 r
F P
0 g
s
.50933 .93397 m .50673 .92902 L p .50966 .93397 L .262 0 0 r
F P
0 g
s
.19961 .654 m .20149 .61928 L .21111 .63062 L p .976 .716 .475 r
F P
0 g
s
.21111 .63062 m .20914 .66481 L .19961 .654 L p .976 .716 .475 r
F P
0 g
s
.53785 .92769 m .5363 .93339 L .52286 .93396 L p .249 0 0 r
F P
0 g
s
.5363 .93339 m .53785 .92769 L .55327 .92623 L p .234 0 0 r
F P
0 g
s
.49115 .92877 m .50673 .92902 L p .49613 .93362 L .274 0 0 r
F P
0 g
s
.50673 .92902 m .50939 .93408 L .49595 .9337 L p .274 0 0 r
F P
0 g
s
.51247 .93074 m .50149 .93032 L p .50923 .934 L .156 .686 .862 r
F P
0 g
s
.50939 .93408 m .50946 .93401 L p .50923 .934 L .156 .686 .862 r
F P
0 g
s
.50946 .93401 m .51247 .93074 L p .50923 .934 L .156 .686 .862 r
F P
0 g
s
.49595 .9337 m .49587 .93362 L p .49613 .93362 L .274 0 0 r
F P
0 g
s
.49587 .93362 m .49115 .92877 L p .49613 .93362 L .274 0 0 r
F P
0 g
s
.4057 .25445 m .42781 .26061 L .41817 .26516 L p .646 .911 .981 r
F P
0 g
s
.41817 .26516 m .39392 .25993 L .4057 .25445 L p .646 .911 .981 r
F P
0 g
s
.55327 .92623 m .54967 .93238 L .5363 .93339 L p .234 0 0 r
F P
0 g
s
.54967 .93238 m .55327 .92623 L .56852 .92431 L p .217 0 0 r
F P
0 g
s
.4826 .93281 m .47565 .92787 L .49115 .92877 L p .284 0 0 r
F P
0 g
s
.49115 .92877 m .49595 .9337 L .4826 .93281 L p .284 0 0 r
F P
0 g
s
.75417 .83849 m .73946 .86462 L .75235 .85886 L p .241 0 .154 r
F P
0 g
s
.75235 .85886 m .76846 .83243 L .75417 .83849 L p .241 0 .154 r
F P
0 g
s
.36346 .89766 m .34617 .87935 L .35963 .88598 L p .668 .116 0 r
F P
0 g
s
.35963 .88598 m .37579 .9033 L .36346 .89766 L p .668 .116 0 r
F P
0 g
s
.70287 .29133 m .7315 .29973 L .7223 .29012 L p .185 .511 .913 r
F P
0 g
s
.7223 .29012 m .69468 .28322 L .70287 .29133 L p .185 .511 .913 r
F P
0 g
s
.75397 .32908 m .77946 .34874 L .77221 .33792 L p 0 .264 .77 r
F P
0 g
s
.77221 .33792 m .74732 .31925 L .75397 .32908 L p 0 .264 .77 r
F P
0 g
s
.63036 .26131 m .65433 .25397 L .64244 .24783 L p .423 .695 .977 r
F P
0 g
s
.64244 .24783 m .62056 .25653 L .63036 .26131 L p .423 .695 .977 r
F P
0 g
s
.56852 .92431 m .56293 .93098 L .54967 .93238 L p .217 0 0 r
F P
0 g
s
.56293 .93098 m .56852 .92431 L .58358 .922 L p .197 0 0 r
F P
0 g
s
.26305 .80491 m .25445 .77205 L .26532 .78098 L p .929 .558 .287 r
F P
0 g
s
.26532 .78098 m .27353 .81336 L .26305 .80491 L p .929 .558 .287 r
F P
0 g
s
.4694 .9314 m .46032 .92628 L .47565 .92787 L p .292 0 0 r
F P
0 g
s
.47565 .92787 m .4826 .93281 L .4694 .9314 L p .292 0 0 r
F P
0 g
s
.23377 .75406 m .22987 .71939 L .24044 .72879 L p .956 .641 .392 r
F P
0 g
s
.24044 .72879 m .24392 .76309 L .23377 .75406 L p .956 .641 .392 r
F P
0 g
s
.82133 .41932 m .83645 .45023 L .83137 .43868 L p 0 0 .361 r
F P
0 g
s
.83137 .43868 m .81692 .40812 L .82133 .41932 L p 0 0 .361 r
F P
0 g
s
.86392 .6275 m .86517 .66365 L .86899 .65087 L p 0 0 .282 r
F P
0 g
s
.86899 .65087 m .86762 .6147 L .86392 .6275 L p 0 0 .282 r
F P
0 g
s
.58358 .922 m .57604 .92922 L .56293 .93098 L p .197 0 0 r
F P
0 g
s
.57604 .92922 m .58358 .922 L .59842 .91936 L p .174 0 0 r
F P
0 g
s
.41801 .24933 m .43789 .25642 L .42781 .26061 L p .631 .908 .983 r
F P
0 g
s
.42781 .26061 m .4057 .25445 L .41801 .24933 L p .631 .908 .983 r
F P
0 g
s
.1876 .48387 m .20103 .45055 L .20193 .46439 L p .982 .891 .547 r
F P
0 g
s
.20193 .46439 m .18894 .49791 L .1876 .48387 L p .982 .891 .547 r
F P
0 g
s
.79147 .37019 m .81159 .39691 L .80542 .38566 L p 0 0 .552 r
F P
0 g
s
.80542 .38566 m .78589 .35949 L .79147 .37019 L p 0 0 .552 r
F P
0 g
s
.69769 .87947 m .68179 .89835 L .69454 .89402 L p .219 0 0 r
F P
0 g
s
.69454 .89402 m .71204 .87486 L .69769 .87947 L p .219 0 0 r
F P
0 g
s
.45639 .92947 m .44522 .92401 L .46032 .92628 L p .299 0 0 r
F P
0 g
s
.46032 .92628 m .4694 .9314 L .45639 .92947 L p .299 0 0 r
F P
0 g
s
.33483 .28434 m .36218 .2786 L .35297 .28557 L p .664 .966 .923 r
F P
0 g
s
.35297 .28557 m .32394 .29214 L .33483 .28434 L p .664 .966 .923 r
F P
0 g
s
.85636 .51918 m .86405 .5536 L .86238 .54418 L p 0 0 .201 r
F P
0 g
s
.86086 .53718 m .85636 .51918 L .86238 .54418 L 0 0 .201 r
F
.86181 .54096 m .85448 .50689 L .85636 .51918 L p F P
0 g
s
.85802 .52852 m .8511 .49477 L .85368 .504 L p .764 .494 0 r
F P
0 g
s
.85368 .504 m .85448 .50689 L p .85504 .51028 L .764 .494 0 r
F P
0 g
s
.85802 .52852 m .85368 .504 L .85504 .51028 L .764 .494 0 r
F
.86238 .54418 m .86181 .54096 L p .86086 .53718 L 0 0 .201 r
F P
0 g
s
.18529 .59495 m .18985 .5599 L .19709 .57283 L p .994 .765 .478 r
F P
0 g
s
.19709 .57283 m .19277 .60738 L .18529 .59495 L p .994 .765 .478 r
F P
0 g
s
.27742 .32501 m .30496 .30912 L .29705 .31831 L p .726 .989 .82 r
F P
0 g
s
.29705 .31831 m .26832 .33503 L .27742 .32501 L p .726 .989 .82 r
F P
0 g
s
.62056 .25653 m .64244 .24783 L .6299 .24232 L p .428 .709 .982 r
F P
0 g
s
.6299 .24232 m .61028 .25224 L .62056 .25653 L p .428 .709 .982 r
F P
0 g
s
.80686 .78698 m .7947 .81843 L .8063 .81037 L p .131 0 .209 r
F P
0 g
s
.8063 .81037 m .81941 .77842 L .80686 .78698 L p .131 0 .209 r
F P
0 g
s
.29879 .84998 m .28449 .82178 L .29597 .83015 L p .856 .403 .097 r
F P
0 g
s
.29597 .83015 m .30971 .8576 L .29879 .84998 L p .856 .403 .097 r
F P
0 g
s
.83821 .73436 m .83057 .76904 L .84015 .75887 L p .011 0 .256 r
F P
0 g
s
.84015 .75887 m .84818 .72366 L .83821 .73436 L p .011 0 .256 r
F P
0 g
s
.20984 .69988 m .20914 .66481 L .21928 .67518 L p .97 .688 .439 r
F P
0 g
s
.21928 .67518 m .21962 .70978 L .20984 .69988 L p .97 .688 .439 r
F P
0 g
s
.59842 .91936 m .58897 .92713 L .57604 .92922 L p .174 0 0 r
F P
0 g
s
.58897 .92713 m .59842 .91936 L .61301 .91643 L p .147 0 0 r
F P
0 g
s
.44364 .92702 m .43045 .92107 L .44522 .92401 L p .305 0 0 r
F P
0 g
s
.44522 .92401 m .45639 .92947 L .44364 .92702 L p .305 0 0 r
F P
0 g
s
.41801 .24933 m .43789 .25642 L .44837 .2526 L p .614 .903 .985 r
F P
0 g
s
.35171 .89167 m .33338 .87235 L .34617 .87935 L p .672 .121 0 r
F P
0 g
s
.34617 .87935 m .36346 .89766 L .35171 .89167 L p .672 .121 0 r
F P
0 g
s
.2054 .4234 m .22454 .39369 L .22132 .40654 L p .903 .951 .603 r
F P
0 g
s
.22132 .40654 m .20216 .43683 L .2054 .4234 L p .903 .951 .603 r
F P
0 g
s
.69468 .28322 m .7223 .29012 L .71221 .28072 L p .176 .521 .918 r
F P
0 g
s
.71221 .28072 m .68572 .27536 L .69468 .28322 L p .176 .521 .918 r
F P
0 g
s
.23651 .36939 m .2606 .34561 L .25436 .35673 L p .795 .977 .694 r
F P
0 g
s
.25436 .35673 m .22962 .38127 L .23651 .36939 L p .795 .977 .694 r
F P
0 g
s
.61028 .25224 m .6299 .24232 L .61676 .23751 L p .435 .724 .987 r
F P
0 g
s
.61676 .23751 m .59957 .24849 L .61028 .25224 L p .435 .724 .987 r
F P
0 g
s
.61301 .91643 m .60168 .92475 L .58897 .92713 L p .147 0 0 r
F P
0 g
s
.60168 .92475 m .61301 .91643 L .62735 .91325 L p .116 0 0 r
F P
0 g
s
.76846 .83243 m .75235 .85886 L .76453 .85257 L p .162 0 .096 r
F P
0 g
s
.76453 .85257 m .78203 .82577 L .76846 .83243 L p .162 0 .096 r
F P
0 g
s
.74732 .31925 m .77221 .33792 L .76413 .32704 L p 0 .253 .759 r
F P
0 g
s
.76413 .32704 m .73983 .30945 L .74732 .31925 L p 0 .253 .759 r
F P
0 g
s
.85917 .67601 m .85625 .71223 L .8623 .70017 L p 0 0 .246 r
F P
0 g
s
.8623 .70017 m .86517 .66365 L .85917 .67601 L p 0 0 .246 r
F P
0 g
s
.4308 .2446 m .44837 .2526 L .45922 .24918 L p .596 .896 .988 r
F P
0 g
s
.44837 .2526 m .4308 .2446 L .41801 .24933 L p .614 .903 .985 r
F P
0 g
s
.86448 .56635 m .86915 .60171 L .86864 .58869 L p 0 0 .176 r
F P
0 g
s
.86864 .58869 m .86405 .5536 L .86448 .56635 L p 0 0 .176 r
F P
0 g
s
.43121 .92407 m .41606 .91747 L .43045 .92107 L p .308 0 0 r
F P
0 g
s
.43045 .92107 m .44364 .92702 L .43121 .92407 L p .308 0 0 r
F P
0 g
s
.84048 .46187 m .8511 .49477 L .84646 .48283 L p .712 .405 0 r
F P
0 g
s
.18036 .53276 m .18894 .49791 L .19231 .51183 L p .996 .834 .483 r
F P
0 g
s
.19231 .51183 m .18416 .5465 L .18036 .53276 L p .996 .834 .483 r
F P
0 g
s
.34654 .27697 m .37211 .27201 L .36218 .2786 L p .621 .955 .913 r
F P
0 g
s
.36218 .2786 m .33483 .28434 L .34654 .27697 L p .621 .955 .913 r
F P
0 g
s
.71204 .87486 m .69454 .89402 L .70685 .88939 L p .164 0 0 r
F P
0 g
s
.70685 .88939 m .72599 .86994 L .71204 .87486 L p .164 0 0 r
F P
0 g
s
.191 .64268 m .19277 .60738 L .20149 .61928 L p .986 .73 .452 r
F P
0 g
s
.20149 .61928 m .19961 .654 L .191 .64268 L p .986 .73 .452 r
F P
0 g
s
.59957 .24849 m .61676 .23751 L .60311 .23346 L p .443 .74 .991 r
F P
0 g
s
.60311 .23346 m .58847 .24529 L .59957 .24849 L p .443 .74 .991 r
F P
0 g
s
.25305 .79641 m .24392 .76309 L .25445 .77205 L p .933 .561 .267 r
F P
0 g
s
.25445 .77205 m .26305 .80491 L .25305 .79641 L p .933 .561 .267 r
F P
0 g
s
.62735 .91325 m .61416 .9221 L .60168 .92475 L p .116 0 0 r
F P
0 g
s
.61416 .9221 m .62735 .91325 L .64141 .90985 L p .08 0 0 r
F P
0 g
s
.44403 .24028 m .45922 .24918 L .47039 .24617 L p .578 .888 .99 r
F P
0 g
s
.45922 .24918 m .44403 .24028 L .4308 .2446 L p .596 .896 .988 r
F P
0 g
s
.22406 .74487 m .21962 .70978 L .22987 .71939 L p .962 .645 .37 r
F P
0 g
s
.22987 .71939 m .23377 .75406 L .22406 .74487 L p .962 .645 .37 r
F P
0 g
s
.28778 .31557 m .31395 .3004 L .30496 .30912 L p .643 .959 .78 r
F P
0 g
s
.30496 .30912 m .27742 .32501 L .28778 .31557 L p .643 .959 .78 r
F P
0 g
s
.68572 .27536 m .71221 .28072 L .70122 .27162 L p .169 .533 .923 r
F P
0 g
s
.70122 .27162 m .676 .26781 L .68572 .27536 L p .169 .533 .923 r
F P
0 g
s
.81692 .40812 m .83137 .43868 L .82543 .42716 L p .659 .295 0 r
F P
0 g
s
.82543 .42716 m .81159 .39691 L .81692 .40812 L p .659 .295 0 r
F P
0 g
s
.78589 .35949 m .80542 .38566 L .79848 .37431 L p 0 0 .507 r
F P
0 g
s
.79848 .37431 m .77946 .34874 L .78589 .35949 L p 0 0 .507 r
F P
0 g
s
.58847 .24529 m .60311 .23346 L .58902 .23021 L p .451 .755 .994 r
F P
0 g
s
.58902 .23021 m .57705 .2427 L .58847 .24529 L p .451 .755 .994 r
F P
0 g
s
.41914 .92065 m .40212 .91328 L .41606 .91747 L p .31 0 0 r
F P
0 g
s
.41606 .91747 m .43121 .92407 L .41914 .92065 L p .31 0 0 r
F P
0 g
s
.34056 .88539 m .32124 .86508 L .33338 .87235 L p .672 .123 0 r
F P
0 g
s
.33338 .87235 m .35171 .89167 L .34056 .88539 L p .672 .123 0 r
F P
0 g
s
.28844 .84227 m .27353 .81336 L .28449 .82178 L p .858 .405 .074 r
F P
0 g
s
.28449 .82178 m .29879 .84998 L .28844 .84227 L p .858 .405 .074 r
F P
0 g
s
.45766 .23641 m .47039 .24617 L .48184 .24361 L p .561 .878 .992 r
F P
0 g
s
.47039 .24617 m .45766 .23641 L .44403 .24028 L p .578 .888 .99 r
F P
0 g
s
.1885 .46989 m .20216 .43683 L .20103 .45055 L p .935 .896 .494 r
F P
0 g
s
.20103 .45055 m .1876 .48387 L .1885 .46989 L p .935 .896 .494 r
F P
0 g
s
.81941 .77842 m .8063 .81037 L .81665 .80159 L p .002 0 .133 r
F P
0 g
s
.81665 .80159 m .83057 .76904 L .81941 .77842 L p .002 0 .133 r
F P
0 g
s
.57705 .2427 m .58902 .23021 L .57458 .2278 L p .46 .771 .997 r
F P
0 g
s
.57458 .2278 m .56536 .24071 L .57705 .2427 L p .46 .771 .997 r
F P
0 g
s
.86762 .6147 m .86899 .65087 L .87066 .63783 L p 0 0 .167 r
F P
0 g
s
.87066 .63783 m .86915 .60171 L .86762 .6147 L p 0 0 .167 r
F P
0 g
s
.64141 .90985 m .62637 .9192 L .63829 .91605 L p .041 0 0 r
F P
0 g
s
.63829 .91605 m .65519 .90624 L .64141 .90985 L p .041 0 0 r
F P
0 g
s
.64141 .90985 m .62637 .9192 L .61416 .9221 L p .08 0 0 r
F P
0 g
s
.35899 .27 m .38271 .26579 L .37211 .27201 L p .578 .941 .9 r
F P
0 g
s
.37211 .27201 m .34654 .27697 L .35899 .27 L p .578 .941 .9 r
F P
0 g
s
.17938 .58201 m .18416 .5465 L .18985 .5599 L p .998 .785 .445 r
F P
0 g
s
.18985 .5599 m .18529 .59495 L .17938 .58201 L p .998 .785 .445 r
F P
0 g
s
.47166 .23303 m .48184 .24361 L .49352 .24153 L p .545 .868 .994 r
F P
0 g
s
.48184 .24361 m .47166 .23303 L .45766 .23641 L p .561 .878 .992 r
F P
0 g
s
.85448 .50689 m .86181 .54096 L .85802 .52852 L p .764 .494 0 r
F P
0 g
s
.20075 .68961 m .19961 .654 L .20914 .66481 L p .978 .696 .414 r
F P
0 g
s
.20914 .66481 m .20984 .69988 L .20075 .68961 L p .978 .696 .414 r
F P
0 g
s
.84818 .72366 m .84015 .75887 L .84799 .74797 L p 0 0 .169 r
F P
0 g
s
.84799 .74797 m .85625 .71223 L .84818 .72366 L p 0 0 .169 r
F P
0 g
s
.56536 .24071 m .57458 .2278 L .55989 .22622 L p .47 .787 .999 r
F P
0 g
s
.55989 .22622 m .55349 .23935 L .56536 .24071 L p .47 .787 .999 r
F P
0 g
s
.73983 .30945 m .76413 .32704 L .75518 .31613 L p 0 .247 .749 r
F P
0 g
s
.75518 .31613 m .7315 .29973 L .73983 .30945 L p 0 .247 .749 r
F P
0 g
s
.72599 .86994 m .70685 .88939 L .71865 .88441 L p .095 0 0 r
F P
0 g
s
.71865 .88441 m .73946 .86462 L .72599 .86994 L p .095 0 0 r
F P
0 g
s
.24514 .35813 m .26832 .33503 L .2606 .34561 L p .677 .926 .621 r
F P
0 g
s
.2606 .34561 m .23651 .36939 L .24514 .35813 L p .677 .926 .621 r
F P
0 g
s
.78203 .82577 m .76453 .85257 L .77588 .84572 L p .061 0 .023 r
F P
0 g
s
.77588 .84572 m .7947 .81843 L .78203 .82577 L p .061 0 .023 r
F P
0 g
s
.48596 .23019 m .49352 .24153 L .50538 .23996 L p .531 .856 .996 r
F P
0 g
s
.49352 .24153 m .48596 .23019 L .47166 .23303 L p .545 .868 .994 r
F P
0 g
s
.40747 .91679 m .38869 .90853 L .40212 .91328 L p .309 0 0 r
F P
0 g
s
.40212 .91328 m .41914 .92065 L .40747 .91679 L p .309 0 0 r
F P
0 g
s
.21078 .41041 m .22962 .38127 L .22454 .39369 L p .799 .917 .528 r
F P
0 g
s
.22454 .39369 m .2054 .4234 L .21078 .41041 L p .799 .917 .528 r
F P
0 g
s
.55349 .23935 m .55989 .22622 L .54505 .22549 L p .481 .802 1 r
F P
0 g
s
.54505 .22549 m .54149 .23861 L .55349 .23935 L p .481 .802 1 r
F P
0 g
s
.676 .26781 m .70122 .27162 L .6893 .26292 L p .165 .547 .928 r
F P
0 g
s
.6893 .26292 m .66553 .26065 L .676 .26781 L p .165 .547 .928 r
F P
0 g
s
.50053 .22797 m .50538 .23996 L .51737 .23893 L p .517 .844 .998 r
F P
0 g
s
.50538 .23996 m .50053 .22797 L .48596 .23019 L p .531 .856 .996 r
F P
0 g
s
.54149 .23861 m .54505 .22549 L .53015 .22556 L p .492 .817 1 r
F P
0 g
s
.53015 .22556 m .52942 .23847 L .54149 .23861 L p .492 .817 1 r
F P
0 g
s
.51528 .2264 m .51737 .23893 L .52942 .23847 L p .504 .831 .999 r
F P
0 g
s
.51737 .23893 m .51528 .2264 L .50053 .22797 L p .517 .844 .998 r
F P
0 g
s
.52942 .23847 m .53015 .22556 L .51528 .2264 L p .504 .831 .999 r
F P
0 g
s
.65519 .90624 m .63829 .91605 L .64989 .91266 L p 0 0 0 r
F P
0 g
s
.64989 .91266 m .66866 .90241 L .65519 .90624 L p 0 0 0 r
F P
0 g
s
.29927 .3067 m .32394 .29214 L .31395 .3004 L p .547 .91 .725 r
F P
0 g
s
.31395 .3004 m .28778 .31557 L .29927 .3067 L p .547 .91 .725 r
F P
0 g
s
.33 .87889 m .30971 .8576 L .32124 .86508 L p .668 .122 0 r
F P
0 g
s
.32124 .86508 m .34056 .88539 L .33 .87889 L p .668 .122 0 r
F P
0 g
s
.83645 .45023 m .84646 .48283 L .8408 .47103 L p .801 .469 0 r
F P
0 g
s
.8408 .47103 m .83137 .43868 L .83645 .45023 L p .801 .469 0 r
F P
0 g
s
.37211 .2634 m .39392 .25993 L .38271 .26579 L p .535 .924 .886 r
F P
0 g
s
.38271 .26579 m .35899 .27 L .37211 .2634 L p .535 .924 .886 r
F P
0 g
s
.24356 .78784 m .23377 .75406 L .24392 .76309 L p .935 .56 .24 r
F P
0 g
s
.24392 .76309 m .25305 .79641 L .24356 .78784 L p .935 .56 .24 r
F P
0 g
s
.86517 .66365 m .8623 .70017 L .86628 .68763 L p 0 0 .136 r
F P
0 g
s
.86628 .68763 m .86899 .65087 L .86517 .66365 L p 0 0 .136 r
F P
0 g
s
.18363 .63083 m .18529 .59495 L .19277 .60738 L p .993 .743 .418 r
F P
0 g
s
.19277 .60738 m .191 .64268 L .18363 .63083 L p .993 .743 .418 r
F P
0 g
s
.86405 .5536 m .86864 .58869 L .86629 .57576 L p .751 .53 0 r
F P
0 g
s
.86629 .57576 m .86181 .54096 L .86405 .5536 L p .751 .53 0 r
F P
0 g
s
.17871 .51881 m .1876 .48387 L .18894 .49791 L p .965 .843 .427 r
F P
0 g
s
.18894 .49791 m .18036 .53276 L .17871 .51881 L p .965 .843 .427 r
F P
0 g
s
.77946 .34874 m .79848 .37431 L .7908 .36283 L p 0 0 .467 r
F P
0 g
s
.7908 .36283 m .77221 .33792 L .77946 .34874 L p 0 0 .467 r
F P
0 g
s
.39624 .91253 m .37579 .9033 L .38869 .90853 L p .306 0 0 r
F P
0 g
s
.38869 .90853 m .40747 .91679 L .39624 .91253 L p .306 0 0 r
F P
0 g
s
.27867 .83448 m .26305 .80491 L .27353 .81336 L p .856 .402 .045 r
F P
0 g
s
.27353 .81336 m .28844 .84227 L .27867 .83448 L p .856 .402 .045 r
F P
0 g
s
.21493 .73545 m .20984 .69988 L .21962 .70978 L p .967 .646 .34 r
F P
0 g
s
.21962 .70978 m .22406 .74487 L .21493 .73545 L p .967 .646 .34 r
F P
0 g
s
.81159 .39691 m .82543 .42716 L .81874 .41561 L p .727 .342 0 r
F P
0 g
s
.81874 .41561 m .80542 .38566 L .81159 .39691 L p .727 .342 0 r
F P
0 g
s
.66553 .26065 m .6893 .26292 L .67648 .25475 L p .163 .564 .932 r
F P
0 g
s
.67648 .25475 m .65433 .25397 L .66553 .26065 L p .163 .564 .932 r
F P
0 g
s
.73946 .86462 m .71865 .88441 L .72988 .87905 L p .01 0 0 r
F P
0 g
s
.72988 .87905 m .75235 .85886 L .73946 .86462 L p .01 0 0 r
F P
0 g
s
.7315 .29973 m .75518 .31613 L .74531 .30526 L p 0 .245 .74 r
F P
0 g
s
.74531 .30526 m .7223 .29012 L .7315 .29973 L p 0 .245 .74 r
F P
0 g
s
.66866 .90241 m .64989 .91266 L .66113 .90902 L p 0 0 0 r
F P
0 g
s
.66113 .90902 m .68179 .89835 L .66866 .90241 L p 0 0 0 r
F P
0 g
s
.83057 .76904 m .81665 .80159 L .82559 .7921 L p 0 0 .035 r
F P
0 g
s
.82559 .7921 m .84015 .75887 L .83057 .76904 L p 0 0 .035 r
F P
0 g
s
.38585 .25715 m .4057 .25445 L .39392 .25993 L p .494 .905 .872 r
F P
0 g
s
.39392 .25993 m .37211 .2634 L .38585 .25715 L p .494 .905 .872 r
F P
0 g
s
.19174 .45615 m .2054 .4234 L .20216 .43683 L p .828 .857 .403 r
F P
0 g
s
.20216 .43683 m .1885 .46989 L .19174 .45615 L p .828 .857 .403 r
F P
0 g
s
.7947 .81843 m .77588 .84572 L .78626 .83828 L p 0 0 0 r
F P
0 g
s
.78626 .83828 m .8063 .81037 L .7947 .81843 L p 0 0 0 r
F P
0 g
s
.25536 .34755 m .27742 .32501 L .26832 .33503 L p .527 .835 .519 r
F P
0 g
s
.26832 .33503 m .24514 .35813 L .25536 .34755 L p .527 .835 .519 r
F P
0 g
s
.86915 .60171 m .87066 .63783 L .87031 .62469 L p 0 0 .039 r
F P
0 g
s
.87031 .62469 m .86864 .58869 L .86915 .60171 L p 0 0 .039 r
F P
0 g
s
.3855 .90792 m .36346 .89766 L .37579 .9033 L p .3 0 0 r
F P
0 g
s
.37579 .9033 m .39624 .91253 L .3855 .90792 L p .3 0 0 r
F P
0 g
s
.1926 .67888 m .191 .64268 L .19961 .654 L p .984 .702 .376 r
F P
0 g
s
.19961 .654 m .20075 .68961 L .1926 .67888 L p .984 .702 .376 r
F P
0 g
s
.8511 .49477 m .85802 .52852 L .85295 .51628 L p .855 .556 .025 r
F P
0 g
s
.85295 .51628 m .84646 .48283 L .8511 .49477 L p .855 .556 .025 r
F P
0 g
s
.31176 .29836 m .33483 .28434 L .32394 .29214 L p .444 .847 .659 r
F P
0 g
s
.32394 .29214 m .29927 .3067 L .31176 .29836 L p .444 .847 .659 r
F P
0 g
s
.1754 .56865 m .18036 .53276 L .18416 .5465 L p .983 .795 .392 r
F P
0 g
s
.18416 .5465 m .17938 .58201 L .1754 .56865 L p .983 .795 .392 r
F P
0 g
s
.65433 .25397 m .67648 .25475 L .66277 .24722 L p .163 .581 .935 r
F P
0 g
s
.66277 .24722 m .64244 .24783 L .65433 .25397 L p .163 .581 .935 r
F P
0 g
s
.85625 .71223 m .84799 .74797 L .854 .73644 L p 0 0 .057 r
F P
0 g
s
.854 .73644 m .8623 .70017 L .85625 .71223 L p 0 0 .057 r
F P
0 g
s
.32004 .87221 m .29879 .84998 L .30971 .8576 L p .659 .116 0 r
F P
0 g
s
.30971 .8576 m .33 .87889 L .32004 .87221 L p .659 .116 0 r
F P
0 g
s
.21825 .39801 m .23651 .36939 L .22962 .38127 L p .636 .826 .413 r
F P
0 g
s
.22962 .38127 m .21078 .41041 L .21825 .39801 L p .636 .826 .413 r
F P
0 g
s
.51247 .93074 m .50939 .93408 L .52286 .93396 L p .163 .695 .852 r
F P
0 g
s
.52348 .9308 m .52286 .93396 L .5363 .93339 L p .172 .704 .843 r
F P
0 g
s
.68179 .89835 m .66113 .90902 L .67198 .90512 L p 0 0 0 r
F P
0 g
s
.67198 .90512 m .69454 .89402 L .68179 .89835 L p 0 0 0 r
F P
0 g
s
.5363 .93339 m .5345 .93049 L .52348 .9308 L p .172 .704 .843 r
F P
0 g
s
.5345 .93049 m .5363 .93339 L .54967 .93238 L p .183 .714 .836 r
F P
0 g
s
.50149 .93032 m .49595 .9337 L .50939 .93408 L p .156 .686 .862 r
F P
0 g
s
.40015 .25125 m .41801 .24933 L .4057 .25445 L p .456 .886 .859 r
F P
0 g
s
.4057 .25445 m .38585 .25715 L .40015 .25125 L p .456 .886 .859 r
F P
0 g
s
.54967 .93238 m .54547 .92984 L .5345 .93049 L p .183 .714 .836 r
F P
0 g
s
.54547 .92984 m .54967 .93238 L .56293 .93098 L p .197 .725 .831 r
F P
0 g
s
.77221 .33792 m .7908 .36283 L .78235 .3512 L p 0 0 .432 r
F P
0 g
s
.78235 .3512 m .76413 .32704 L .77221 .33792 L p 0 0 .432 r
F P
0 g
s
.23465 .77914 m .22406 .74487 L .23377 .75406 L p .933 .554 .201 r
F P
0 g
s
.23377 .75406 m .24356 .78784 L .23465 .77914 L p .933 .554 .201 r
F P
0 g
s
.49059 .92951 m .4826 .93281 L .49595 .9337 L p .15 .677 .871 r
F P
0 g
s
.49595 .9337 m .50149 .93032 L .49059 .92951 L p .15 .677 .871 r
F P
0 g
s
.7223 .29012 m .74531 .30526 L .73447 .29451 L p 0 .247 .731 r
F P
0 g
s
.73447 .29451 m .71221 .28072 L .7223 .29012 L p 0 .247 .731 r
F P
0 g
s
.26948 .82661 m .25305 .79641 L .26305 .80491 L p .848 .392 .006 r
F P
0 g
s
.26305 .80491 m .27867 .83448 L .26948 .82661 L p .848 .392 .006 r
F P
0 g
s
.56293 .93098 m .55636 .92887 L .54547 .92984 L p .197 .725 .831 r
F P
0 g
s
.55636 .92887 m .56293 .93098 L .57604 .92922 L p .213 .737 .827 r
F P
0 g
s
.75235 .85886 m .72988 .87905 L .74043 .87327 L p 0 0 0 r
F P
0 g
s
.74043 .87327 m .76453 .85257 L .75235 .85886 L p 0 0 0 r
F P
0 g
s
.83137 .43868 m .8408 .47103 L .83433 .45931 L p .857 .511 0 r
F P
0 g
s
.83433 .45931 m .82543 .42716 L .83137 .43868 L p .857 .511 0 r
F P
0 g
s
.64244 .24783 m .66277 .24722 L .64821 .24047 L p .165 .6 .937 r
F P
0 g
s
.64821 .24047 m .6299 .24232 L .64244 .24783 L p .165 .6 .937 r
F P
0 g
s
.47981 .92832 m .4694 .9314 L .4826 .93281 L p .146 .669 .881 r
F P
0 g
s
.4826 .93281 m .49059 .92951 L .47981 .92832 L p .146 .669 .881 r
F P
0 g
s
.37525 .903 m .35171 .89167 L .36346 .89766 L p 0 .284 .651 r
F P
0 g
s
.36346 .89766 m .3855 .90792 L .37525 .903 L p 0 .284 .651 r
F P
0 g
s
.86899 .65087 m .86628 .68763 L .86822 .67475 L p 0 0 .009 r
F P
0 g
s
.86822 .67475 m .87066 .63783 L .86899 .65087 L p 0 0 .009 r
F P
0 g
s
.57604 .92922 m .56714 .92759 L .55636 .92887 L p .213 .737 .827 r
F P
0 g
s
.56714 .92759 m .57604 .92922 L .58897 .92713 L p .233 .751 .827 r
F P
0 g
s
.80542 .38566 m .81874 .41561 L .8114 .40394 L p .773 .374 0 r
F P
0 g
s
.8114 .40394 m .79848 .37431 L .80542 .38566 L p .773 .374 0 r
F P
0 g
s
.17784 .61848 m .17938 .58201 L .18529 .59495 L p .988 .751 .365 r
F P
0 g
s
.18529 .59495 m .18363 .63083 L .17784 .61848 L p .988 .751 .365 r
F P
0 g
s
.17944 .50482 m .1885 .46989 L .1876 .48387 L p .879 .814 .334 r
F P
0 g
s
.1876 .48387 m .17871 .51881 L .17944 .50482 L p .879 .814 .334 r
F P
0 g
s
.86181 .54096 m .86629 .57576 L .86237 .56301 L p .859 .598 .062 r
F P
0 g
s
.86237 .56301 m .85802 .52852 L .86181 .54096 L p .859 .598 .062 r
F P
0 g
s
.20657 .72571 m .20075 .68961 L .20984 .69988 L p .967 .644 .297 r
F P
0 g
s
.20984 .69988 m .21493 .73545 L .20657 .72571 L p .967 .644 .297 r
F P
0 g
s
.46919 .92675 m .45639 .92947 L .4694 .9314 L p .142 .66 .89 r
F P
0 g
s
.4694 .9314 m .47981 .92832 L .46919 .92675 L p .142 .66 .89 r
F P
0 g
s
.40015 .25125 m .41801 .24933 L .4308 .2446 L p .418 .866 .848 r
F P
0 g
s
.32512 .2905 m .34654 .27697 L .33483 .28434 L p 0 0 0 r
F P
0 g
s
.33483 .28434 m .31176 .29836 L .32512 .2905 L p 0 0 0 r
F P
0 g
s
.58897 .92713 m .57777 .92601 L .56714 .92759 L p .233 .751 .827 r
F P
0 g
s
.57777 .92601 m .58897 .92713 L .60168 .92475 L p .255 .766 .83 r
F P
0 g
s
.26701 .33766 m .28778 .31557 L .27742 .32501 L p 0 0 0 r
F P
0 g
s
.27742 .32501 m .25536 .34755 L .26701 .33766 L p 0 0 0 r
F P
0 g
s
.69454 .89402 m .67198 .90512 L .68239 .90094 L p 0 0 0 r
F P
0 g
s
.68239 .90094 m .70685 .88939 L .69454 .89402 L p 0 0 0 r
F P
0 g
s
.31068 .86539 m .28844 .84227 L .29879 .84998 L p .642 .104 0 r
F P
0 g
s
.29879 .84998 m .32004 .87221 L .31068 .86539 L p .642 .104 0 r
F P
0 g
s
.8063 .81037 m .78626 .83828 L .79553 .83022 L p 0 0 0 r
F P
0 g
s
.79553 .83022 m .81665 .80159 L .8063 .81037 L p 0 0 0 r
F P
0 g
s
.6299 .24232 m .64821 .24047 L .63288 .23459 L p .167 .62 .936 r
F P
0 g
s
.63288 .23459 m .61676 .23751 L .6299 .24232 L p .167 .62 .936 r
F P
0 g
s
.84015 .75887 m .82559 .7921 L .833 .78194 L p 0 0 0 r
F P
0 g
s
.833 .78194 m .84799 .74797 L .84015 .75887 L p 0 0 0 r
F P
0 g
s
.45878 .9248 m .44364 .92702 L .45639 .92947 L p .14 .651 .898 r
F P
0 g
s
.45639 .92947 m .46919 .92675 L .45878 .9248 L p .14 .651 .898 r
F P
0 g
s
.60168 .92475 m .58822 .92417 L .57777 .92601 L p .255 .766 .83 r
F P
0 g
s
.58822 .92417 m .60168 .92475 L .61416 .9221 L p .282 .784 .836 r
F P
0 g
s
.2054 .4234 m .19174 .45615 L .19735 .44283 L p 0 0 0 r
F P
0 g
s
.19735 .44283 m .21078 .41041 L .2054 .4234 L p 0 0 0 r
F P
0 g
s
.41498 .24569 m .4308 .2446 L .44403 .24028 L p .379 .844 .839 r
F P
0 g
s
.4308 .2446 m .41498 .24569 L .40015 .25125 L p .418 .866 .848 r
F P
0 g
s
.71221 .28072 m .73447 .29451 L .72261 .28401 L p 0 .253 .721 r
F P
0 g
s
.72261 .28401 m .70122 .27162 L .71221 .28072 L p 0 .253 .721 r
F P
0 g
s
.22769 .3863 m .24514 .35813 L .23651 .36939 L p 0 0 0 r
F P
0 g
s
.23651 .36939 m .21825 .39801 L .22769 .3863 L p 0 0 0 r
F P
0 g
s
.36552 .89781 m .34056 .88539 L .35171 .89167 L p 0 .285 .673 r
F P
0 g
s
.35171 .89167 m .37525 .903 L .36552 .89781 L p 0 .285 .673 r
F P
0 g
s
.84646 .48283 m .85295 .51628 L .84688 .50424 L p .907 .593 .105 r
F P
0 g
s
.84688 .50424 m .8408 .47103 L .84646 .48283 L p .907 .593 .105 r
F P
0 g
s
.44862 .92248 m .43121 .92407 L .44364 .92702 L p .138 .642 .905 r
F P
0 g
s
.44364 .92702 m .45878 .9248 L .44862 .92248 L p .138 .642 .905 r
F P
0 g
s
.18569 .66768 m .18363 .63083 L .191 .64268 L p .981 .703 .321 r
F P
0 g
s
.191 .64268 m .1926 .67888 L .18569 .66768 L p .981 .703 .321 r
F P
0 g
s
.86864 .58869 m .87031 .62469 L .86813 .61157 L p .834 .626 .078 r
F P
0 g
s
.86813 .61157 m .86629 .57576 L .86864 .58869 L p .834 .626 .078 r
F P
0 g
s
.76413 .32704 m .78235 .3512 L .77308 .33945 L p .59 .122 0 r
F P
0 g
s
.77308 .33945 m .75518 .31613 L .76413 .32704 L p .59 .122 0 r
F P
0 g
s
.61676 .23751 m .63288 .23459 L .61687 .22969 L p .172 .639 .933 r
F P
0 g
s
.61687 .22969 m .60311 .23346 L .61676 .23751 L p .172 .639 .933 r
F P
0 g
s
.8623 .70017 m .854 .73644 L .85811 .7244 L p 0 0 0 r
F P
0 g
s
.85811 .7244 m .86628 .68763 L .8623 .70017 L p 0 0 0 r
F P
0 g
s
.17362 .55501 m .17871 .51881 L .18036 .53276 L p .927 .78 .305 r
F P
0 g
s
.18036 .53276 m .1754 .56865 L .17362 .55501 L p .927 .78 .305 r
F P
0 g
s
.76453 .85257 m .74043 .87327 L .75022 .86703 L p 0 0 0 r
F P
0 g
s
.75022 .86703 m .77588 .84572 L .76453 .85257 L p 0 0 0 r
F P
0 g
s
.61416 .9221 m .59847 .92206 L .58822 .92417 L p .282 .784 .836 r
F P
0 g
s
.59847 .92206 m .61416 .9221 L .62637 .9192 L p .312 .803 .846 r
F P
0 g
s
.2609 .81865 m .24356 .78784 L .25305 .79641 L p .832 .375 0 r
F P
0 g
s
.25305 .79641 m .26948 .82661 L .2609 .81865 L p .832 .375 0 r
F P
0 g
s
.43032 .24051 m .44403 .24028 L .45766 .23641 L p .345 .823 .835 r
F P
0 g
s
.44403 .24028 m .43032 .24051 L .41498 .24569 L p .379 .844 .839 r
F P
0 g
s
.33924 .28306 m .35899 .27 L .34654 .27697 L p 0 0 0 r
F P
0 g
s
.34654 .27697 m .32512 .2905 L .33924 .28306 L p 0 0 0 r
F P
0 g
s
.22643 .77025 m .21493 .73545 L .22406 .74487 L p .923 .541 .148 r
F P
0 g
s
.22406 .74487 m .23465 .77914 L .22643 .77025 L p .923 .541 .148 r
F P
0 g
s
.69231 .89646 m .71865 .88441 L .70685 .88939 L p 0 0 0 r
F P
0 g
s
.72988 .87905 m .71865 .88441 L p .71209 .88722 L .328 .791 .671 r
F P
0 g
s
.70685 .88939 m .68455 .89992 L p .69704 .89416 L 0 0 0 r
F P
0 g
s
.70168 .89166 m .72711 .88029 L p .71209 .88722 L .328 .791 .671 r
F P
0 g
s
.72711 .88029 m .72988 .87905 L p .71209 .88722 L .328 .791 .671 r
F P
0 g
s
.68239 .90094 m .69231 .89646 L p .69704 .89416 L 0 0 0 r
F P
0 g
s
.68455 .89992 m .68239 .90094 L p .69704 .89416 L 0 0 0 r
F P
0 g
s
.43874 .91981 m .41914 .92065 L .43121 .92407 L p .138 .633 .911 r
F P
0 g
s
.43121 .92407 m .44862 .92248 L .43874 .91981 L p .138 .633 .911 r
F P
0 g
s
.82543 .42716 m .83433 .45931 L .82722 .44759 L p .891 .536 .056 r
F P
0 g
s
.82722 .44759 m .81874 .41561 L .82543 .42716 L p .891 .536 .056 r
F P
0 g
s
.60311 .23346 m .61687 .22969 L .60028 .22583 L p .178 .658 .928 r
F P
0 g
s
.60028 .22583 m .58902 .23021 L .60311 .23346 L p .178 .658 .928 r
F P
0 g
s
.79848 .37431 m .8114 .40394 L .80343 .3921 L p .804 .394 0 r
F P
0 g
s
.80343 .3921 m .7908 .36283 L .79848 .37431 L p .804 .394 0 r
F P
0 g
s
.44613 .23575 m .45766 .23641 L .47166 .23303 L p .314 .805 .835 r
F P
0 g
s
.45766 .23641 m .44613 .23575 L .43032 .24051 L p .345 .823 .835 r
F P
0 g
s
.62637 .9192 m .60848 .91969 L .61822 .91709 L p .341 .821 .856 r
F P
0 g
s
.61822 .91709 m .63829 .91605 L .62637 .9192 L p .341 .821 .856 r
F P
0 g
s
.62637 .9192 m .60848 .91969 L .59847 .92206 L p .312 .803 .846 r
F P
0 g
s
.2799 .32843 m .29927 .3067 L .28778 .31557 L p 0 0 0 r
F P
0 g
s
.28778 .31557 m .26701 .33766 L .2799 .32843 L p 0 0 0 r
F P
0 g
s
.30193 .85845 m .27867 .83448 L .28844 .84227 L p .616 .086 0 r
F P
0 g
s
.28844 .84227 m .31068 .86539 L .30193 .85845 L p .616 .086 0 r
F P
0 g
s
.70122 .27162 m .72261 .28401 L .70966 .2739 L p 0 .261 .709 r
F P
0 g
s
.70966 .2739 m .6893 .26292 L .70122 .27162 L p 0 .261 .709 r
F P
0 g
s
.58902 .23021 m .60028 .22583 L .58325 .22305 L p .185 .677 .921 r
F P
0 g
s
.58325 .22305 m .57458 .2278 L .58902 .23021 L p .185 .677 .921 r
F P
0 g
s
.35634 .89239 m .33 .87889 L .34056 .88539 L p 0 .29 .695 r
F P
0 g
s
.34056 .88539 m .36552 .89781 L .35634 .89239 L p 0 .29 .695 r
F P
0 g
s
.87066 .63783 m .86822 .67475 L .86823 .6617 L p .795 .664 .113 r
F P
0 g
s
.86823 .6617 m .87031 .62469 L .87066 .63783 L p .795 .664 .113 r
F P
0 g
s
.85802 .52852 m .86237 .56301 L .85715 .55048 L p .918 .634 .146 r
F P
0 g
s
.85715 .55048 m .85295 .51628 L .85802 .52852 L p .918 .634 .146 r
F P
0 g
s
.1992 .7156 m .1926 .67888 L .20075 .68961 L p .958 .635 .235 r
F P
0 g
s
.20075 .68961 m .20657 .72571 L .1992 .7156 L p .958 .635 .235 r
F P
0 g
s
.18267 .491 m .19174 .45615 L .1885 .46989 L p .713 .722 .199 r
F P
0 g
s
.1885 .46989 m .17944 .50482 L .18267 .491 L p .713 .722 .199 r
F P
0 g
s
.17395 .60567 m .1754 .56865 L .17938 .58201 L p .953 .742 .284 r
F P
0 g
s
.17938 .58201 m .17784 .61848 L .17395 .60567 L p .953 .742 .284 r
F P
0 g
s
.42919 .91681 m .40747 .91679 L .41914 .92065 L p .138 .624 .917 r
F P
0 g
s
.41914 .92065 m .43874 .91981 L .42919 .91681 L p .138 .624 .917 r
F P
0 g
s
.46239 .23149 m .47166 .23303 L .48596 .23019 L p .288 .788 .839 r
F P
0 g
s
.47166 .23303 m .46239 .23149 L .44613 .23575 L p .314 .805 .835 r
F P
0 g
s
.81665 .80159 m .79553 .83022 L .8036 .82157 L p 0 0 0 r
F P
0 g
s
.8036 .82157 m .82559 .7921 L .81665 .80159 L p 0 0 0 r
F P
0 g
s
.57458 .2278 m .58325 .22305 L .5659 .22136 L p .193 .695 .911 r
F P
0 g
s
.55989 .22622 m .57458 .2278 L p .56608 .22149 L .193 .695 .911 r
F P
0 g
s
.5909 .22758 m .5712 .22588 L p .58304 .2231 L .261 0 0 r
F P
0 g
s
.58325 .22305 m .58339 .22313 L p .58304 .2231 L .261 0 0 r
F P
0 g
s
.58339 .22313 m .5909 .22758 L p .58304 .2231 L .261 0 0 r
F P
0 g
s
.5659 .22136 m .56578 .22147 L p .56608 .22149 L .193 .695 .911 r
F P
0 g
s
.56578 .22147 m .55989 .22622 L p .56608 .22149 L .193 .695 .911 r
F P
0 g
s
.35403 .27598 m .37211 .2634 L .35899 .27 L p 0 0 0 r
F P
0 g
s
.35899 .27 m .33924 .28306 L .35403 .27598 L p 0 0 0 r
F P
0 g
s
.63829 .91605 m .61822 .91709 L .62766 .91425 L p .371 .838 .868 r
F P
0 g
s
.62766 .91425 m .64989 .91266 L .63829 .91605 L p .371 .838 .868 r
F P
0 g
s
.84799 .74797 m .833 .78194 L .8388 .7712 L p 0 0 0 r
F P
0 g
s
.8388 .7712 m .854 .73644 L .84799 .74797 L p 0 0 0 r
F P
0 g
s
.47905 .2278 m .48596 .23019 L .50053 .22797 L p .266 .772 .848 r
F P
0 g
s
.48596 .23019 m .47905 .2278 L .46239 .23149 L p .288 .788 .839 r
F P
0 g
s
.75518 .31613 m .77308 .33945 L .76289 .32763 L p .615 .129 0 r
F P
0 g
s
.76289 .32763 m .74531 .30526 L .75518 .31613 L p .615 .129 0 r
F P
0 g
s
.55989 .22622 m .5659 .22136 L .54839 .22075 L p .204 .712 .899 r
F P
0 g
s
.54505 .22549 m .55989 .22622 L p .54874 .22092 L .204 .712 .899 r
F P
0 g
s
.5712 .22588 m .55131 .2255 L p .56553 .22147 L .246 0 0 r
F P
0 g
s
.5659 .22136 m .56605 .22148 L p .56553 .22147 L .246 0 0 r
F P
0 g
s
.56605 .22148 m .5712 .22588 L p .56553 .22147 L .246 0 0 r
F P
0 g
s
.54839 .22075 m .54828 .2209 L p .54874 .22092 L .204 .712 .899 r
F P
0 g
s
.54828 .2209 m .54505 .22549 L p .54874 .22092 L .204 .712 .899 r
F P
0 g
s
.71865 .88441 m .69231 .89646 L .70168 .89166 L p .328 .791 .671 r
F P
0 g
s
.23891 .37534 m .25536 .34755 L .24514 .35813 L p 0 0 0 r
F P
0 g
s
.24514 .35813 m .22769 .3863 L .23891 .37534 L p 0 0 0 r
F P
0 g
s
.77588 .84572 m .75022 .86703 L .75724 .86177 L p 0 0 0 r
F P
0 g
s
.7613 .85846 m .77588 .84572 L .75724 .86177 L 0 0 0 r
F
.75916 .86032 m .78626 .83828 L .77588 .84572 L p F P
0 g
s
.76716 .85314 m .79553 .83022 L .78921 .83572 L p .495 .847 .585 r
F P
0 g
s
.78921 .83572 m .78626 .83828 L p .78193 .84164 L .495 .847 .585 r
F P
0 g
s
.76716 .85314 m .78921 .83572 L .78193 .84164 L .495 .847 .585 r
F
.75724 .86177 m .75916 .86032 L p .7613 .85846 L 0 0 0 r
F P
0 g
s
.49606 .22479 m .50053 .22797 L .51528 .2264 L p .246 .757 .859 r
F P
0 g
s
.50053 .22797 m .49606 .22479 L .47905 .2278 L p .266 .772 .848 r
F P
0 g
s
.20527 .43009 m .21825 .39801 L .21078 .41041 L p 0 0 0 r
F P
0 g
s
.21078 .41041 m .19735 .44283 L .20527 .43009 L p 0 0 0 r
F P
0 g
s
.54505 .22549 m .54839 .22075 L .53083 .22117 L p .216 .727 .885 r
F P
0 g
s
.53015 .22556 m .54505 .22549 L p .53137 .22133 L .216 .727 .885 r
F P
0 g
s
.55131 .2255 m .53142 .22637 L p .54784 .22093 L .23 0 0 r
F P
0 g
s
.54839 .22075 m .54849 .22091 L p .54784 .22093 L .23 0 0 r
F P
0 g
s
.54849 .22091 m .55131 .2255 L p .54784 .22093 L .23 0 0 r
F P
0 g
s
.53083 .22117 m .5308 .22135 L p .53137 .22133 L .216 .727 .885 r
F P
0 g
s
.5308 .22135 m .53015 .22556 L p .53137 .22133 L .216 .727 .885 r
F P
0 g
s
.51335 .22254 m .51528 .2264 L .53015 .22556 L p .23 .742 .872 r
F P
0 g
s
.51528 .2264 m .51335 .22254 L .49606 .22479 L p .246 .757 .859 r
F P
0 g
s
.53015 .22556 m .53083 .22117 L .51335 .22254 L p .23 .742 .872 r
F P
0 g
s
.41999 .9135 m .39624 .91253 L .40747 .91679 L p .14 .616 .922 r
F P
0 g
s
.40747 .91679 m .42919 .91681 L .41999 .9135 L p .14 .616 .922 r
F P
0 g
s
.8408 .47103 m .84688 .50424 L .84005 .49233 L p .934 .612 .162 r
F P
0 g
s
.84005 .49233 m .83433 .45931 L .8408 .47103 L p .934 .612 .162 r
F P
0 g
s
.6893 .26292 m .70966 .2739 L .69561 .26435 L p 0 .271 .695 r
F P
0 g
s
.69561 .26435 m .67648 .25475 L .6893 .26292 L p 0 .271 .695 r
F P
0 g
s
.25301 .81057 m .23465 .77914 L .24356 .78784 L p .803 .347 0 r
F P
0 g
s
.24356 .78784 m .2609 .81865 L .25301 .81057 L p .803 .347 0 r
F P
0 g
s
.86629 .57576 m .86813 .61157 L .86438 .5986 L p .912 .668 .168 r
F P
0 g
s
.86438 .5986 m .86237 .56301 L .86629 .57576 L p .912 .668 .168 r
F P
0 g
s
.18033 .65598 m .17784 .61848 L .18363 .63083 L p .955 .69 .241 r
F P
0 g
s
.18363 .63083 m .18569 .66768 L .18033 .65598 L p .955 .69 .241 r
F P
0 g
s
.86628 .68763 m .85811 .7244 L .86036 .712 L p .758 .726 .198 r
F P
0 g
s
.86036 .712 m .86822 .67475 L .86628 .68763 L p .758 .726 .198 r
F P
0 g
s
.64989 .91266 m .62766 .91425 L .63677 .91117 L p .403 .856 .882 r
F P
0 g
s
.63677 .91117 m .66113 .90902 L .64989 .91266 L p .403 .856 .882 r
F P
0 g
s
.34772 .88677 m .32004 .87221 L .33 .87889 L p 0 .298 .718 r
F P
0 g
s
.33 .87889 m .35634 .89239 L .34772 .88677 L p 0 .298 .718 r
F P
0 g
s
.29384 .31981 m .31176 .29836 L .29927 .3067 L p 0 0 0 r
F P
0 g
s
.29927 .3067 m .2799 .32843 L .29384 .31981 L p 0 0 0 r
F P
0 g
s
.17428 .54125 m .17944 .50482 L .17871 .51881 L p .798 .712 .177 r
F P
0 g
s
.17871 .51881 m .17362 .55501 L .17428 .54125 L p .798 .712 .177 r
F P
0 g
s
.7908 .36283 m .80343 .3921 L .79481 .38005 L p .825 .405 0 r
F P
0 g
s
.79481 .38005 m .78235 .3512 L .7908 .36283 L p .825 .405 0 r
F P
0 g
s
.21904 .7611 m .20657 .72571 L .21493 .73545 L p .901 .517 .076 r
F P
0 g
s
.21493 .73545 m .22643 .77025 L .21904 .7611 L p .901 .517 .076 r
F P
0 g
s
.29382 .85139 m .26948 .82661 L .27867 .83448 L p .579 .059 0 r
F P
0 g
s
.27867 .83448 m .30193 .85845 L .29382 .85139 L p .579 .059 0 r
F P
0 g
s
.81874 .41561 m .82722 .44759 L .81958 .43578 L p .91 .55 .096 r
F P
0 g
s
.81958 .43578 m .8114 .40394 L .81874 .41561 L p .91 .55 .096 r
F P
0 g
s
.36943 .2692 m .38585 .25715 L .37211 .2634 L p 0 0 0 r
F P
0 g
s
.37211 .2634 m .35403 .27598 L .36943 .2692 L p 0 0 0 r
F P
0 g
s
.41118 .9099 m .3855 .90792 L .39624 .91253 L p .144 .608 .926 r
F P
0 g
s
.39624 .91253 m .41999 .9135 L .41118 .9099 L p .144 .608 .926 r
F P
0 g
s
.72988 .87905 m .70168 .89166 L .71045 .88653 L p .415 .85 .73 r
F P
0 g
s
.71045 .88653 m .74043 .87327 L .72988 .87905 L p .415 .85 .73 r
F P
0 g
s
.74531 .30526 m .76289 .32763 L .75168 .31584 L p .634 .13 0 r
F P
0 g
s
.75168 .31584 m .73447 .29451 L .74531 .30526 L p .634 .13 0 r
F P
0 g
s
.67648 .25475 m .69561 .26435 L .68047 .25552 L p 0 .282 .677 r
F P
0 g
s
.68047 .25552 m .66277 .24722 L .67648 .25475 L p 0 .282 .677 r
F P
0 g
s
.66113 .90902 m .63677 .91117 L .64551 .90784 L p .438 .874 .896 r
F P
0 g
s
.64551 .90784 m .67198 .90512 L .66113 .90902 L p .438 .874 .896 r
F P
0 g
s
.82559 .7921 m .8036 .82157 L .81035 .81237 L p .58 .816 .431 r
F P
0 g
s
.81035 .81237 m .833 .78194 L .82559 .7921 L p .58 .816 .431 r
F P
0 g
s
.85295 .51628 m .85715 .55048 L .85093 .53818 L p .948 .65 .205 r
F P
0 g
s
.85093 .53818 m .84688 .50424 L .85295 .51628 L p .948 .65 .205 r
F P
0 g
s
.87031 .62469 m .86823 .6617 L .86647 .64862 L p .898 .718 .211 r
F P
0 g
s
.86647 .64862 m .86813 .61157 L .87031 .62469 L p .898 .718 .211 r
F P
0 g
s
.19305 .70507 m .18569 .66768 L .1926 .67888 L p .929 .611 .149 r
F P
0 g
s
.1926 .67888 m .1992 .7156 L .19305 .70507 L p .929 .611 .149 r
F P
0 g
s
.18844 .47754 m .19735 .44283 L .19174 .45615 L p 0 0 0 r
F P
0 g
s
.19174 .45615 m .18267 .491 L .18844 .47754 L p 0 0 0 r
F P
0 g
s
.78626 .83828 m .75916 .86032 L .76716 .85314 L p .495 .847 .585 r
F P
0 g
s
.38538 .2627 m .40015 .25125 L .38585 .25715 L p 0 0 0 r
F P
0 g
s
.38585 .25715 m .36943 .2692 L .38538 .2627 L p 0 0 0 r
F P
0 g
s
.17225 .5925 m .17362 .55501 L .1754 .56865 L p .861 .694 .165 r
F P
0 g
s
.1754 .56865 m .17395 .60567 L .17225 .5925 L p .861 .694 .165 r
F P
0 g
s
.2517 .36517 m .26701 .33766 L .25536 .34755 L p 0 0 0 r
F P
0 g
s
.25536 .34755 m .23891 .37534 L .2517 .36517 L p 0 0 0 r
F P
0 g
s
.33968 .88098 m .31068 .86539 L .32004 .87221 L p 0 .309 .743 r
F P
0 g
s
.32004 .87221 m .34772 .88677 L .33968 .88098 L p 0 .309 .743 r
F P
0 g
s
.40278 .90604 m .37525 .903 L .3855 .90792 L p .149 .601 .93 r
F P
0 g
s
.3855 .90792 m .41118 .9099 L .40278 .90604 L p .149 .601 .93 r
F P
0 g
s
.854 .73644 m .8388 .7712 L .84294 .75997 L p .737 .813 .343 r
F P
0 g
s
.84294 .75997 m .85811 .7244 L .854 .73644 L p .737 .813 .343 r
F P
0 g
s
.21537 .41807 m .22769 .3863 L .21825 .39801 L p 0 0 .026 r
F P
0 g
s
.21825 .39801 m .20527 .43009 L .21537 .41807 L p 0 0 .026 r
F P
0 g
s
.30865 .31171 m .32512 .2905 L .31176 .29836 L p .027 0 0 r
F P
0 g
s
.31176 .29836 m .29384 .31981 L .30865 .31171 L p .027 0 0 r
F P
0 g
s
.5158 .92021 m .51247 .93074 L .52348 .9308 L p .444 .81 .995 r
F P
0 g
s
.52348 .9308 m .52417 .92033 L .5158 .92021 L p .444 .81 .995 r
F P
0 g
s
.52417 .92033 m .52348 .9308 L .5345 .93049 L p .45 .818 .994 r
F P
0 g
s
.5345 .93049 m .53253 .92019 L .52417 .92033 L p .45 .818 .994 r
F P
0 g
s
.53253 .92019 m .5345 .93049 L .54547 .92984 L p .458 .826 .993 r
F P
0 g
s
.50747 .91982 m .50149 .93032 L .51247 .93074 L p .438 .802 .995 r
F P
0 g
s
.51247 .93074 m .5158 .92021 L .50747 .91982 L p .438 .802 .995 r
F P
0 g
s
.54547 .92984 m .54088 .91979 L .53253 .92019 L p .458 .826 .993 r
F P
0 g
s
.54088 .91979 m .54547 .92984 L .55636 .92887 L p .467 .833 .993 r
F P
0 g
s
.83433 .45931 m .84005 .49233 L .83265 .4805 L p .949 .622 .2 r
F P
0 g
s
.83265 .4805 m .82722 .44759 L .83433 .45931 L p .949 .622 .2 r
F P
0 g
s
.24588 .80232 m .22643 .77025 L .23465 .77914 L p .756 .305 0 r
F P
0 g
s
.23465 .77914 m .25301 .81057 L .24588 .80232 L p .756 .305 0 r
F P
0 g
s
.66277 .24722 m .68047 .25552 L .66426 .24759 L p 0 .293 .655 r
F P
0 g
s
.66426 .24759 m .64821 .24047 L .66277 .24722 L p 0 .293 .655 r
F P
0 g
s
.49921 .91916 m .49059 .92951 L .50149 .93032 L p .432 .794 .996 r
F P
0 g
s
.50149 .93032 m .50747 .91982 L .49921 .91916 L p .432 .794 .996 r
F P
0 g
s
.67198 .90512 m .64551 .90784 L .65386 .90428 L p .475 .892 .911 r
F P
0 g
s
.65386 .90428 m .68239 .90094 L .67198 .90512 L p .475 .892 .911 r
F P
0 g
s
.28639 .84422 m .2609 .81865 L .26948 .82661 L p .528 .023 0 r
F P
0 g
s
.26948 .82661 m .29382 .85139 L .29348 .85106 L p .528 .023 0 r
F P
0 g
s
.26948 .82661 m .29348 .85106 L .28062 .83821 L .528 .023 0 r
F
.27968 .83692 m .25301 .81057 L .25569 .81331 L p 0 .022 .535 r
F P
0 g
s
.25569 .81331 m .2609 .81865 L p .26604 .82365 L 0 .022 .535 r
F P
0 g
s
.26604 .82365 m .27968 .83692 L .25569 .81331 L 0 .022 .535 r
F
.29348 .85106 m .28639 .84422 L p .28062 .83821 L .528 .023 0 r
F P
0 g
s
.55636 .92887 m .54916 .91915 L .54088 .91979 L p .467 .833 .993 r
F P
0 g
s
.54916 .91915 m .55636 .92887 L .56714 .92759 L p .476 .841 .992 r
F P
0 g
s
.78235 .3512 m .79481 .38005 L .78544 .36781 L p .838 .409 0 r
F P
0 g
s
.78544 .36781 m .77308 .33945 L .78235 .3512 L p .838 .409 0 r
F P
0 g
s
.49104 .91823 m .47981 .92832 L .49059 .92951 L p .428 .786 .996 r
F P
0 g
s
.49059 .92951 m .49921 .91916 L .49104 .91823 L p .428 .786 .996 r
F P
0 g
s
.56714 .92759 m .55737 .91826 L .54916 .91915 L p .476 .841 .992 r
F P
0 g
s
.55737 .91826 m .56714 .92759 L .57777 .92601 L p .487 .848 .992 r
F P
0 g
s
.86237 .56301 m .86438 .5986 L .85932 .58585 L p .952 .684 .232 r
F P
0 g
s
.85932 .58585 m .85715 .55048 L .86237 .56301 L p .952 .684 .232 r
F P
0 g
s
.38538 .2627 m .40015 .25125 L .41498 .24569 L p 0 0 0 r
F P
0 g
s
.74043 .87327 m .71045 .88653 L .71855 .88106 L p .501 .902 .784 r
F P
0 g
s
.71855 .88106 m .75022 .86703 L .74043 .87327 L p .501 .902 .784 r
F P
0 g
s
.8114 .40394 m .81958 .43578 L .81144 .4238 L p .921 .557 .125 r
F P
0 g
s
.81144 .4238 m .80343 .3921 L .8114 .40394 L p .921 .557 .125 r
F P
0 g
s
.73447 .29451 m .75168 .31584 L .73935 .30424 L p .647 .127 0 r
F P
0 g
s
.73935 .30424 m .72261 .28401 L .73447 .29451 L p .647 .127 0 r
F P
0 g
s
.86822 .67475 m .86036 .712 L .86082 .69936 L p .882 .79 .299 r
F P
0 g
s
.86082 .69936 m .86823 .6617 L .86822 .67475 L p .882 .79 .299 r
F P
0 g
s
.17681 .64382 m .17395 .60567 L .17784 .61848 L p .884 .647 .126 r
F P
0 g
s
.17784 .61848 m .18033 .65598 L .17681 .64382 L p .884 .647 .126 r
F P
0 g
s
.483 .91703 m .46919 .92675 L .47981 .92832 L p .423 .778 .996 r
F P
0 g
s
.47981 .92832 m .49104 .91823 L .483 .91703 L p .423 .778 .996 r
F P
0 g
s
.21266 .75165 m .1992 .7156 L .20657 .72571 L p .854 .476 0 r
F P
0 g
s
.20657 .72571 m .21904 .7611 L .21266 .75165 L p .854 .476 0 r
F P
0 g
s
.39483 .90195 m .36552 .89781 L .37525 .903 L p .157 .596 .934 r
F P
0 g
s
.37525 .903 m .40278 .90604 L .39483 .90195 L p .157 .596 .934 r
F P
0 g
s
.57777 .92601 m .56546 .91713 L .55737 .91826 L p .487 .848 .992 r
F P
0 g
s
.56546 .91713 m .57777 .92601 L .58822 .92417 L p .498 .855 .991 r
F P
0 g
s
.17751 .52754 m .18267 .491 L .17944 .50482 L p 0 0 0 r
F P
0 g
s
.17944 .50482 m .17428 .54125 L .17751 .52754 L p 0 0 0 r
F P
0 g
s
.47512 .91557 m .45878 .9248 L .46919 .92675 L p .419 .771 .996 r
F P
0 g
s
.46919 .92675 m .483 .91703 L .47512 .91557 L p .419 .771 .996 r
F P
0 g
s
.64821 .24047 m .66426 .24759 L .64708 .24072 L p .286 0 0 r
F P
0 g
s
.64708 .24072 m .63288 .23459 L .64821 .24047 L p .286 0 0 r
F P
0 g
s
.33224 .87504 m .30193 .85845 L .31068 .86539 L p 0 .324 .768 r
F P
0 g
s
.31068 .86539 m .33968 .88098 L .33224 .87504 L p 0 .324 .768 r
F P
0 g
s
.58822 .92417 m .57341 .91577 L .56546 .91713 L p .498 .855 .991 r
F P
0 g
s
.57341 .91577 m .58822 .92417 L .59847 .92206 L p .511 .861 .991 r
F P
0 g
s
.68239 .90094 m .65386 .90428 L .66176 .90048 L p .513 .908 .925 r
F P
0 g
s
.66176 .90048 m .69231 .89646 L .68239 .90094 L p .513 .908 .925 r
F P
0 g
s
.3242 .30405 m .33924 .28306 L .32512 .2905 L p .108 0 0 r
F P
0 g
s
.32512 .2905 m .30865 .31171 L .3242 .30405 L p .108 0 0 r
F P
0 g
s
.40188 .25647 m .41498 .24569 L .43032 .24051 L p .039 0 0 r
F P
0 g
s
.41498 .24569 m .40188 .25647 L .38538 .2627 L p 0 0 0 r
F P
0 g
s
.79553 .83022 m .76716 .85314 L .77414 .8455 L p .623 .926 .672 r
F P
0 g
s
.77414 .8455 m .8036 .82157 L .79553 .83022 L p .623 .926 .672 r
F P
0 g
s
.833 .78194 m .81035 .81237 L .81573 .80266 L p .731 .908 .537 r
F P
0 g
s
.81573 .80266 m .8388 .7712 L .833 .78194 L p .731 .908 .537 r
F P
0 g
s
.26581 .35574 m .2799 .32843 L .26701 .33766 L p .074 0 .077 r
F P
0 g
s
.26701 .33766 m .2517 .36517 L .26581 .35574 L p .074 0 .077 r
F P
0 g
s
.46742 .91386 m .44862 .92248 L .45878 .9248 L p .416 .763 .995 r
F P
0 g
s
.45878 .9248 m .47512 .91557 L .46742 .91386 L p .416 .763 .995 r
F P
0 g
s
.84688 .50424 m .85093 .53818 L .84395 .52609 L p .962 .657 .245 r
F P
0 g
s
.84395 .52609 m .84005 .49233 L .84688 .50424 L p .962 .657 .245 r
F P
0 g
s
.59847 .92206 m .58119 .91419 L .57341 .91577 L p .511 .861 .991 r
F P
0 g
s
.58119 .91419 m .59847 .92206 L .60848 .91969 L p .525 .868 .991 r
F P
0 g
s
.86813 .61157 m .86647 .64862 L .86317 .63564 L p .953 .737 .279 r
F P
0 g
s
.86317 .63564 m .86438 .5986 L .86813 .61157 L p .953 .737 .279 r
F P
0 g
s
.19667 .4646 m .20527 .43009 L .19735 .44283 L p 0 0 .103 r
F P
0 g
s
.19735 .44283 m .18844 .47754 L .19667 .4646 L p 0 0 .103 r
F P
0 g
s
.18838 .69409 m .18033 .65598 L .18569 .66768 L p .86 .561 .033 r
F P
0 g
s
.18569 .66768 m .19305 .70507 L .18838 .69409 L p .86 .561 .033 r
F P
0 g
s
.38734 .89764 m .35634 .89239 L .36552 .89781 L p .167 .592 .937 r
F P
0 g
s
.36552 .89781 m .39483 .90195 L .38734 .89764 L p .167 .592 .937 r
F P
0 g
s
.63288 .23459 m .64708 .24072 L .62902 .23504 L p .285 0 0 r
F P
0 g
s
.62902 .23504 m .61687 .22969 L .63288 .23459 L p .285 0 0 r
F P
0 g
s
.2274 .40684 m .23891 .37534 L .22769 .3863 L p 0 0 .137 r
F P
0 g
s
.22769 .3863 m .21537 .41807 L .2274 .40684 L p 0 0 .137 r
F P
0 g
s
.45994 .91189 m .43874 .91981 L .44862 .92248 L p .413 .755 .995 r
F P
0 g
s
.44862 .92248 m .46742 .91386 L .45994 .91189 L p .413 .755 .995 r
F P
0 g
s
.85811 .7244 m .84294 .75997 L .84542 .74837 L p .864 .877 .439 r
F P
0 g
s
.84542 .74837 m .86036 .712 L .85811 .7244 L p .864 .877 .439 r
F P
0 g
s
.77308 .33945 m .78544 .36781 L .77519 .35541 L p .846 .407 0 r
F P
0 g
s
.77519 .35541 m .76289 .32763 L .77308 .33945 L p .846 .407 0 r
F P
0 g
s
.72261 .28401 m .73935 .30424 L .7258 .29298 L p .656 .122 0 r
F P
0 g
s
.7258 .29298 m .70966 .2739 L .72261 .28401 L p .656 .122 0 r
F P
0 g
s
.75022 .86703 m .71855 .88106 L .72592 .87524 L p .582 .943 .83 r
F P
0 g
s
.72592 .87524 m .75916 .86032 L .75022 .86703 L p .582 .943 .83 r
F P
0 g
s
.41892 .25053 m .43032 .24051 L .44613 .23575 L p .078 0 0 r
F P
0 g
s
.43032 .24051 m .41892 .25053 L .40188 .25647 L p .039 0 0 r
F P
0 g
s
.17295 .57913 m .17428 .54125 L .17362 .55501 L p 0 0 0 r
F P
0 g
s
.17362 .55501 m .17225 .5925 L .17295 .57913 L p 0 0 0 r
F P
0 g
s
.2609 .81865 m .28639 .84422 L .27968 .83692 L p 0 .022 .535 r
F P
0 g
s
.82722 .44759 m .83265 .4805 L .82481 .46863 L p .956 .627 .227 r
F P
0 g
s
.82481 .46863 m .81958 .43578 L .82722 .44759 L p .956 .627 .227 r
F P
0 g
s
.60848 .91969 m .58878 .9124 L .59614 .9104 L p .538 .873 .991 r
F P
0 g
s
.59614 .9104 m .61822 .91709 L .60848 .91969 L p .538 .873 .991 r
F P
0 g
s
.60848 .91969 m .58878 .9124 L .58119 .91419 L p .525 .868 .991 r
F P
0 g
s
.23962 .79387 m .21904 .7611 L .22643 .77025 L p .684 .247 0 r
F P
0 g
s
.22643 .77025 m .24588 .80232 L .23962 .79387 L p .684 .247 0 r
F P
0 g
s
.69231 .89646 m .66176 .90048 L .66919 .89642 L p .552 .922 .938 r
F P
0 g
s
.66919 .89642 m .70168 .89166 L .69231 .89646 L p .552 .922 .938 r
F P
0 g
s
.80343 .3921 m .81144 .4238 L .80275 .41162 L p .927 .558 .146 r
F P
0 g
s
.80275 .41162 m .79481 .38005 L .80343 .3921 L p .927 .558 .146 r
F P
0 g
s
.45271 .90969 m .42919 .91681 L .43874 .91981 L p .411 .747 .994 r
F P
0 g
s
.43874 .91981 m .45994 .91189 L .45271 .90969 L p .411 .747 .994 r
F P
0 g
s
.61687 .22969 m .62902 .23504 L .61024 .23064 L p .28 0 0 r
F P
0 g
s
.61024 .23064 m .60028 .22583 L .61687 .22969 L p .28 0 0 r
F P
0 g
s
.34036 .29672 m .35403 .27598 L .33924 .28306 L p .169 0 .006 r
F P
0 g
s
.33924 .28306 m .3242 .30405 L .34036 .29672 L p .169 0 .006 r
F P
0 g
s
.43648 .24495 m .44613 .23575 L .46239 .23149 L p .111 0 0 r
F P
0 g
s
.44613 .23575 m .43648 .24495 L .41892 .25053 L p .078 0 0 r
F P
0 g
s
.32544 .86897 m .29382 .85139 L .30193 .85845 L p 0 .342 .793 r
F P
0 g
s
.30193 .85845 m .33224 .87504 L .32544 .86897 L p 0 .342 .793 r
F P
0 g
s
.85715 .55048 m .85932 .58585 L .85323 .57335 L p .969 .688 .274 r
F P
0 g
s
.85323 .57335 m .85093 .53818 L .85715 .55048 L p .969 .688 .274 r
F P
0 g
s
.61822 .91709 m .59614 .9104 L .60326 .90819 L p .55 .877 .992 r
F P
0 g
s
.60326 .90819 m .62766 .91425 L .61822 .91709 L p .55 .877 .992 r
F P
0 g
s
.38034 .89314 m .34772 .88677 L .35634 .89239 L p .179 .589 .94 r
F P
0 g
s
.35634 .89239 m .38734 .89764 L .38034 .89314 L p .179 .589 .94 r
F P
0 g
s
.86823 .6617 m .86082 .69936 L .85962 .68665 L p .951 .813 .369 r
F P
0 g
s
.85962 .68665 m .86647 .64862 L .86823 .6617 L p .951 .813 .369 r
F P
0 g
s
.20747 .74185 m .19305 .70507 L .1992 .7156 L p .772 .411 0 r
F P
0 g
s
.1992 .7156 m .21266 .75165 L .20747 .74185 L p .772 .411 0 r
F P
0 g
s
.28099 .34698 m .29384 .31981 L .2799 .32843 L p .174 0 .146 r
F P
0 g
s
.2799 .32843 m .26581 .35574 L .28099 .34698 L p .174 0 .146 r
F P
0 g
s
.60028 .22583 m .61024 .23064 L .5909 .22758 L p .272 0 0 r
F P
0 g
s
.5909 .22758 m .58325 .22305 L .60028 .22583 L p .272 0 0 r
F P
0 g
s
.17538 .63128 m .17225 .5925 L .17395 .60567 L p .744 .557 0 r
F P
0 g
s
.17395 .60567 m .17681 .64382 L .17538 .63128 L p .744 .557 0 r
F P
0 g
s
.44575 .90726 m .41999 .9135 L .42919 .91681 L p .409 .74 .993 r
F P
0 g
s
.42919 .91681 m .45271 .90969 L .44575 .90726 L p .409 .74 .993 r
F P
0 g
s
.45457 .23981 m .46239 .23149 L .47905 .2278 L p .14 0 0 r
F P
0 g
s
.46239 .23149 m .45457 .23981 L .43648 .24495 L p .111 0 0 r
F P
0 g
s
.8036 .82157 m .77414 .8455 L .78003 .83742 L p .729 .975 .737 r
F P
0 g
s
.78003 .83742 m .81035 .81237 L .8036 .82157 L p .729 .975 .737 r
F P
0 g
s
.18335 .51408 m .18844 .47754 L .18267 .491 L p 0 0 .132 r
F P
0 g
s
.18267 .491 m .17751 .52754 L .18335 .51408 L p 0 0 .132 r
F P
0 g
s
.70966 .2739 m .7258 .29298 L .71097 .28229 L p .66 .114 0 r
F P
0 g
s
.71097 .28229 m .69561 .26435 L .70966 .2739 L p .66 .114 0 r
F P
0 g
s
.62766 .91425 m .60326 .90819 L .61011 .90579 L p .563 .881 .992 r
F P
0 g
s
.61011 .90579 m .63677 .91117 L .62766 .91425 L p .563 .881 .992 r
F P
0 g
s
.8388 .7712 m .81573 .80266 L .8197 .79253 L p .841 .955 .612 r
F P
0 g
s
.8197 .79253 m .84294 .75997 L .8388 .7712 L p .841 .955 .612 r
F P
0 g
s
.70168 .89166 m .66919 .89642 L .67611 .89212 L p .589 .933 .948 r
F P
0 g
s
.67611 .89212 m .71045 .88653 L .70168 .89166 L p .589 .933 .948 r
F P
0 g
s
.5712 .22588 m .5659 .22136 L .58325 .22305 L p .261 0 0 r
F P
0 g
s
.84005 .49233 m .84395 .52609 L .83643 .51414 L p .968 .659 .271 r
F P
0 g
s
.83643 .51414 m .83265 .4805 L .84005 .49233 L p .968 .659 .271 r
F P
0 g
s
.47317 .23525 m .47905 .2278 L .49606 .22479 L p .166 0 0 r
F P
0 g
s
.47905 .2278 m .47317 .23525 L .45457 .23981 L p .14 0 0 r
F P
0 g
s
.75916 .86032 m .72592 .87524 L .73251 .86908 L p .654 .971 .864 r
F P
0 g
s
.73251 .86908 m .76716 .85314 L .75916 .86032 L p .654 .971 .864 r
F P
0 g
s
.76289 .32763 m .77519 .35541 L .76392 .34297 L p .85 .401 0 r
F P
0 g
s
.76392 .34297 m .75168 .31584 L .76289 .32763 L p .85 .401 0 r
F P
0 g
s
.35707 .28965 m .36943 .2692 L .35403 .27598 L p .216 0 .041 r
F P
0 g
s
.35403 .27598 m .34036 .29672 L .35707 .28965 L p .216 0 .041 r
F P
0 g
s
.43909 .90462 m .41118 .9099 L .41999 .9135 L p .409 .733 .991 r
F P
0 g
s
.41999 .9135 m .44575 .90726 L .43909 .90462 L p .409 .733 .991 r
F P
0 g
s
.55131 .2255 m .54839 .22075 L .5659 .22136 L p .246 0 0 r
F P
0 g
s
.49223 .23138 m .49606 .22479 L .51335 .22254 L p .189 0 0 r
F P
0 g
s
.49606 .22479 m .49223 .23138 L .47317 .23525 L p .166 0 0 r
F P
0 g
s
.24112 .39644 m .2517 .36517 L .23891 .37534 L p .126 0 .217 r
F P
0 g
s
.23891 .37534 m .2274 .40684 L .24112 .39644 L p .126 0 .217 r
F P
0 g
s
.20722 .45234 m .21537 .41807 L .20527 .43009 L p 0 0 .212 r
F P
0 g
s
.20527 .43009 m .19667 .4646 L .20722 .45234 L p 0 0 .212 r
F P
0 g
s
.86438 .5986 m .86317 .63564 L .85855 .62285 L p .978 .738 .324 r
F P
0 g
s
.85855 .62285 m .85932 .58585 L .86438 .5986 L p .978 .738 .324 r
F P
0 g
s
.27375 .82948 m .24588 .80232 L .25301 .81057 L p 0 .075 .601 r
F P
0 g
s
.25301 .81057 m .27968 .83692 L .27375 .82948 L p 0 .075 .601 r
F P
0 g
s
.53142 .22637 m .53083 .22117 L .54839 .22075 L p .23 0 0 r
F P
0 g
s
.51168 .22837 m .51335 .22254 L .53083 .22117 L p .21 0 0 r
F P
0 g
s
.51335 .22254 m .51168 .22837 L .49223 .23138 L p .189 0 0 r
F P
0 g
s
.37385 .88848 m .33968 .88098 L .34772 .88677 L p .195 .587 .943 r
F P
0 g
s
.34772 .88677 m .38034 .89314 L .37385 .88848 L p .195 .587 .943 r
F P
0 g
s
.53083 .22117 m .53142 .22637 L .51168 .22837 L p .21 0 0 r
F P
0 g
s
.63677 .91117 m .61011 .90579 L .61665 .90319 L p .576 .884 .991 r
F P
0 g
s
.61665 .90319 m .64551 .90784 L .63677 .91117 L p .576 .884 .991 r
F P
0 g
s
.81958 .43578 m .82481 .46863 L .81656 .45667 L p .959 .628 .244 r
F P
0 g
s
.81656 .45667 m .81144 .4238 L .81958 .43578 L p .959 .628 .244 r
F P
0 g
s
.18544 .68268 m .17681 .64382 L .18033 .65598 L p .734 .473 0 r
F P
0 g
s
.18443 .67089 m .17538 .63128 L .17648 .64093 L p 0 0 .259 r
F P
0 g
s
.17648 .64093 m .17681 .64382 L p .17809 .64837 L 0 0 .259 r
F P
0 g
s
.18033 .65598 m .18838 .69409 L .18594 .68462 L p .734 .473 0 r
F P
0 g
s
.18033 .65598 m .18594 .68462 L .18483 .67951 L .734 .473 0 r
F
.17809 .64837 m .18443 .67089 L .17648 .64093 L 0 0 .259 r
F
.18594 .68462 m .18544 .68268 L p .18483 .67951 L .734 .473 0 r
F P
0 g
s
.86036 .712 m .84542 .74837 L .8463 .73652 L p .94 .898 .502 r
F P
0 g
s
.8463 .73652 m .86082 .69936 L .86036 .712 L p .94 .898 .502 r
F P
0 g
s
.31929 .86276 m .28639 .84422 L .29382 .85139 L p 0 .364 .818 r
F P
0 g
s
.29382 .85139 m .32544 .86897 L .31929 .86276 L p 0 .364 .818 r
F P
0 g
s
.21904 .7611 m .23962 .79387 L .23435 .78517 L p 0 0 .39 r
F P
0 g
s
.23435 .78517 m .21266 .75165 L .21904 .7611 L p 0 0 .39 r
F P
0 g
s
.79481 .38005 m .80275 .41162 L .79341 .39921 L p .93 .555 .163 r
F P
0 g
s
.79341 .39921 m .78544 .36781 L .79481 .38005 L p .93 .555 .163 r
F P
0 g
s
.1762 .5657 m .17751 .52754 L .17428 .54125 L p 0 0 .145 r
F P
0 g
s
.17428 .54125 m .17295 .57913 L .1762 .5657 L p 0 0 .145 r
F P
0 g
s
.43275 .90177 m .40278 .90604 L .41118 .9099 L p .409 .726 .99 r
F P
0 g
s
.41118 .9099 m .43909 .90462 L .43275 .90177 L p .409 .726 .99 r
F P
0 g
s
.69561 .26435 m .71097 .28229 L .69482 .27237 L p .658 .104 0 r
F P
0 g
s
.69482 .27237 m .68047 .25552 L .69561 .26435 L p .658 .104 0 r
F P
0 g
s
.29703 .3388 m .30865 .31171 L .29384 .31981 L p .248 0 .197 r
F P
0 g
s
.29384 .31981 m .28099 .34698 L .29703 .3388 L p .248 0 .197 r
F P
0 g
s
.71045 .88653 m .67611 .89212 L .68247 .88757 L p .625 .941 .955 r
F P
0 g
s
.68247 .88757 m .71855 .88106 L .71045 .88653 L p .625 .941 .955 r
F P
0 g
s
.85093 .53818 m .85323 .57335 L .84636 .5611 L p .976 .686 .301 r
F P
0 g
s
.84636 .5611 m .84395 .52609 L .85093 .53818 L p .976 .686 .301 r
F P
0 g
s
.37429 .28276 m .38538 .2627 L .36943 .2692 L p .252 0 .065 r
F P
0 g
s
.36943 .2692 m .35707 .28965 L .37429 .28276 L p .252 0 .065 r
F P
0 g
s
.64551 .90784 m .61665 .90319 L .62287 .9004 L p .59 .886 .991 r
F P
0 g
s
.62287 .9004 m .65386 .90428 L .64551 .90784 L p .59 .886 .991 r
F P
0 g
s
.81035 .81237 m .78003 .83742 L .78478 .82896 L p .806 .997 .778 r
F P
0 g
s
.78478 .82896 m .81573 .80266 L .81035 .81237 L p .806 .997 .778 r
F P
0 g
s
.86647 .64862 m .85962 .68665 L .85693 .67397 L p .984 .812 .414 r
F P
0 g
s
.85693 .67397 m .86317 .63564 L .86647 .64862 L p .984 .812 .414 r
F P
0 g
s
.76716 .85314 m .73251 .86908 L .73827 .86258 L p .713 .985 .886 r
F P
0 g
s
.73827 .86258 m .77414 .8455 L .76716 .85314 L p .713 .985 .886 r
F P
0 g
s
.19305 .70507 m .20747 .74185 L .20367 .73168 L p 0 0 .271 r
F P
0 g
s
.20367 .73168 m .18838 .69409 L .19305 .70507 L p 0 0 .271 r
F P
0 g
s
.3679 .88366 m .33224 .87504 L .33968 .88098 L p .213 .587 .945 r
F P
0 g
s
.33968 .88098 m .37385 .88848 L .3679 .88366 L p .213 .587 .945 r
F P
0 g
s
.75168 .31584 m .76392 .34297 L .75146 .33064 L p .849 .392 .017 r
F P
0 g
s
.75146 .33064 m .73935 .30424 L .75168 .31584 L p .849 .392 .017 r
F P
0 g
s
.42675 .89874 m .39483 .90195 L .40278 .90604 L p .41 .72 .988 r
F P
0 g
s
.40278 .90604 m .43275 .90177 L .42675 .89874 L p .41 .72 .988 r
F P
0 g
s
.19172 .50104 m .19667 .4646 L .18844 .47754 L p 0 0 .248 r
F P
0 g
s
.18844 .47754 m .18335 .51408 L .19172 .50104 L p 0 0 .248 r
F P
0 g
s
.84294 .75997 m .8197 .79253 L .82224 .78207 L p .909 .967 .657 r
F P
0 g
s
.82224 .78207 m .84542 .74837 L .84294 .75997 L p .909 .967 .657 r
F P
0 g
s
.51926 .90442 m .5158 .92021 L .52417 .92033 L p .556 .809 .992 r
F P
0 g
s
.52417 .92033 m .52487 .90453 L .51926 .90442 L p .556 .809 .992 r
F P
0 g
s
.52487 .90453 m .52417 .92033 L .53253 .92019 L p .56 .812 .993 r
F P
0 g
s
.17624 .61845 m .17295 .57913 L .17225 .5925 L p 0 0 .177 r
F P
0 g
s
.17225 .5925 m .17538 .63128 L .17624 .61845 L p 0 0 .177 r
F P
0 g
s
.53253 .92019 m .53049 .90448 L .52487 .90453 L p .56 .812 .993 r
F P
0 g
s
.53049 .90448 m .53253 .92019 L .54088 .91979 L p .564 .816 .993 r
F P
0 g
s
.83265 .4805 m .83643 .51414 L .82849 .50227 L p .971 .659 .288 r
F P
0 g
s
.82849 .50227 m .82481 .46863 L .83265 .4805 L p .971 .659 .288 r
F P
0 g
s
.51367 .90413 m .50747 .91982 L .5158 .92021 L p .553 .805 .992 r
F P
0 g
s
.5158 .92021 m .51926 .90442 L .51367 .90413 L p .553 .805 .992 r
F P
0 g
s
.54088 .91979 m .5361 .90425 L .53049 .90448 L p .564 .816 .993 r
F P
0 g
s
.5361 .90425 m .54088 .91979 L .54916 .91915 L p .568 .82 .993 r
F P
0 g
s
.25621 .38684 m .26581 .35574 L .2517 .36517 L p .228 0 .275 r
F P
0 g
s
.2517 .36517 m .24112 .39644 L .25621 .38684 L p .228 0 .275 r
F P
0 g
s
.50813 .90366 m .49921 .91916 L .50747 .91982 L p .55 .801 .991 r
F P
0 g
s
.50747 .91982 m .51367 .90413 L .50813 .90366 L p .55 .801 .991 r
F P
0 g
s
.68047 .25552 m .69482 .27237 L .67739 .26345 L p .651 .094 0 r
F P
0 g
s
.67739 .26345 m .66426 .24759 L .68047 .25552 L p .651 .094 0 r
F P
0 g
s
.54916 .91915 m .54166 .90384 L .5361 .90425 L p .568 .82 .993 r
F P
0 g
s
.54166 .90384 m .54916 .91915 L .55737 .91826 L p .572 .823 .992 r
F P
0 g
s
.65386 .90428 m .62287 .9004 L .62873 .89742 L p .604 .888 .99 r
F P
0 g
s
.62873 .89742 m .66176 .90048 L .65386 .90428 L p .604 .888 .99 r
F P
0 g
s
.26867 .82187 m .23962 .79387 L .24588 .80232 L p 0 .133 .664 r
F P
0 g
s
.24588 .80232 m .27375 .82948 L .26867 .82187 L p 0 .133 .664 r
F P
0 g
s
.31384 .85643 m .27968 .83692 L .28639 .84422 L p 0 .387 .84 r
F P
0 g
s
.28639 .84422 m .31929 .86276 L .31384 .85643 L p 0 .387 .84 r
F P
0 g
s
.50265 .90303 m .49104 .91823 L .49921 .91916 L p .547 .797 .991 r
F P
0 g
s
.49921 .91916 m .50813 .90366 L .50265 .90303 L p .547 .797 .991 r
F P
0 g
s
.37429 .28276 m .38538 .2627 L .40188 .25647 L p .285 0 .084 r
F P
0 g
s
.55737 .91826 m .54717 .90327 L .54166 .90384 L p .572 .823 .992 r
F P
0 g
s
.54717 .90327 m .55737 .91826 L .56546 .91713 L p .577 .826 .992 r
F P
0 g
s
.21981 .44086 m .2274 .40684 L .21537 .41807 L p .115 0 .289 r
F P
0 g
s
.21537 .41807 m .20722 .45234 L .21981 .44086 L p .115 0 .289 r
F P
0 g
s
.71855 .88106 m .68247 .88757 L .68824 .88277 L p .658 .945 .959 r
F P
0 g
s
.68824 .88277 m .72592 .87524 L .71855 .88106 L p .658 .945 .959 r
F P
0 g
s
.85932 .58585 m .85855 .62285 L .85285 .61031 L p .987 .732 .352 r
F P
0 g
s
.85285 .61031 m .85323 .57335 L .85932 .58585 L p .987 .732 .352 r
F P
0 g
s
.31373 .33106 m .3242 .30405 L .30865 .31171 L p .301 0 .235 r
F P
0 g
s
.30865 .31171 m .29703 .3388 L .31373 .33106 L p .301 0 .235 r
F P
0 g
s
.49727 .90222 m .483 .91703 L .49104 .91823 L p .544 .793 .99 r
F P
0 g
s
.49104 .91823 m .50265 .90303 L .49727 .90222 L p .544 .793 .99 r
F P
0 g
s
.81144 .4238 m .81656 .45667 L .80784 .44454 L p .96 .626 .258 r
F P
0 g
s
.80784 .44454 m .80275 .41162 L .81144 .4238 L p .96 .626 .258 r
F P
0 g
s
.78544 .36781 m .79341 .39921 L .78325 .3866 L p .929 .548 .178 r
F P
0 g
s
.78325 .3866 m .77519 .35541 L .78544 .36781 L p .929 .548 .178 r
F P
0 g
s
.56546 .91713 m .5526 .90254 L .54717 .90327 L p .577 .826 .992 r
F P
0 g
s
.5526 .90254 m .56546 .91713 L .57341 .91577 L p .582 .829 .992 r
F P
0 g
s
.42112 .89554 m .38734 .89764 L .39483 .90195 L p .412 .715 .986 r
F P
0 g
s
.39483 .90195 m .42675 .89874 L .42112 .89554 L p .412 .715 .986 r
F P
0 g
s
.49199 .90124 m .47512 .91557 L .483 .91703 L p .542 .789 .989 r
F P
0 g
s
.483 .91703 m .49727 .90222 L .49199 .90124 L p .542 .789 .989 r
F P
0 g
s
.86082 .69936 m .8463 .73652 L .84566 .72456 L p .977 .894 .54 r
F P
0 g
s
.84566 .72456 m .85962 .68665 L .86082 .69936 L p .977 .894 .54 r
F P
0 g
s
.57341 .91577 m .55794 .90164 L .5526 .90254 L p .582 .829 .992 r
F P
0 g
s
.55794 .90164 m .57341 .91577 L .58119 .91419 L p .588 .832 .991 r
F P
0 g
s
.23021 .77621 m .20747 .74185 L .21266 .75165 L p 0 0 .494 r
F P
0 g
s
.21266 .75165 m .23435 .78517 L .23021 .77621 L p 0 0 .494 r
F P
0 g
s
.36251 .8787 m .32544 .86897 L .33224 .87504 L p .234 .589 .947 r
F P
0 g
s
.33224 .87504 m .3679 .88366 L .36251 .8787 L p .234 .589 .947 r
F P
0 g
s
.17681 .64382 m .18544 .68268 L .18443 .67089 L p 0 0 .259 r
F P
0 g
s
.48684 .9001 m .46742 .91386 L .47512 .91557 L p .54 .785 .989 r
F P
0 g
s
.47512 .91557 m .49199 .90124 L .48684 .9001 L p .54 .785 .989 r
F P
0 g
s
.66176 .90048 m .62873 .89742 L .63422 .89426 L p .619 .89 .989 r
F P
0 g
s
.63422 .89426 m .66919 .89642 L .66176 .90048 L p .619 .89 .989 r
F P
0 g
s
.66426 .24759 m .67739 .26345 L .65875 .25574 L p .639 .082 0 r
F P
0 g
s
.65875 .25574 m .64708 .24072 L .66426 .24759 L p .639 .082 0 r
F P
0 g
s
.39201 .27605 m .40188 .25647 L .41892 .25053 L p .316 0 .096 r
F P
0 g
s
.40188 .25647 m .39201 .27605 L .37429 .28276 L p .285 0 .084 r
F P
0 g
s
.58119 .91419 m .56315 .90059 L .55794 .90164 L p .588 .832 .991 r
F P
0 g
s
.56315 .90059 m .58119 .91419 L .58878 .9124 L p .593 .834 .99 r
F P
0 g
s
.18201 .5524 m .18335 .51408 L .17751 .52754 L p 0 0 .271 r
F P
0 g
s
.17751 .52754 m .1762 .5657 L .18201 .5524 L p 0 0 .271 r
F P
0 g
s
.77414 .8455 m .73827 .86258 L .74314 .85578 L p .76 .988 .897 r
F P
0 g
s
.74314 .85578 m .78003 .83742 L .77414 .8455 L p .76 .988 .897 r
F P
0 g
s
.73935 .30424 m .75146 .33064 L .73766 .31861 L p .844 .38 .041 r
F P
0 g
s
.73766 .31861 m .7258 .29298 L .73935 .30424 L p .844 .38 .041 r
F P
0 g
s
.84395 .52609 m .84636 .5611 L .83889 .54908 L p .978 .683 .318 r
F P
0 g
s
.83889 .54908 m .83643 .51414 L .84395 .52609 L p .978 .683 .318 r
F P
0 g
s
.81573 .80266 m .78478 .82896 L .78836 .82016 L p .858 .997 .8 r
F P
0 g
s
.78836 .82016 m .8197 .79253 L .81573 .80266 L p .858 .997 .8 r
F P
0 g
s
.48184 .8988 m .45994 .91189 L .46742 .91386 L p .538 .78 .988 r
F P
0 g
s
.46742 .91386 m .48684 .9001 L .48184 .8988 L p .538 .78 .988 r
F P
0 g
s
.41589 .89218 m .38034 .89314 L .38734 .89764 L p .416 .71 .984 r
F P
0 g
s
.38734 .89764 m .42112 .89554 L .41589 .89218 L p .416 .71 .984 r
F P
0 g
s
.58878 .9124 m .56823 .89938 L .57315 .89801 L p .599 .836 .989 r
F P
0 g
s
.57315 .89801 m .59614 .9104 L .58878 .9124 L p .599 .836 .989 r
F P
0 g
s
.58878 .9124 m .56823 .89938 L .56315 .90059 L p .593 .834 .99 r
F P
0 g
s
.86317 .63564 m .85693 .67397 L .85294 .66145 L p .996 .801 .441 r
F P
0 g
s
.85294 .66145 m .85855 .62285 L .86317 .63564 L p .996 .801 .441 r
F P
0 g
s
.72592 .87524 m .68824 .88277 L .69338 .87774 L p .687 .945 .96 r
F P
0 g
s
.69338 .87774 m .73251 .86908 L .72592 .87524 L p .687 .945 .96 r
F P
0 g
s
.27237 .37796 m .28099 .34698 L .26581 .35574 L p .301 .025 .317 r
F P
0 g
s
.26581 .35574 m .25621 .38684 L .27237 .37796 L p .301 .025 .317 r
F P
0 g
s
.33095 .32365 m .34036 .29672 L .3242 .30405 L p .341 .017 .262 r
F P
0 g
s
.3242 .30405 m .31373 .33106 L .33095 .32365 L p .341 .017 .262 r
F P
0 g
s
.47702 .89734 m .45271 .90969 L .45994 .91189 L p .536 .777 .986 r
F P
0 g
s
.45994 .91189 m .48184 .8988 L .47702 .89734 L p .536 .777 .986 r
F P
0 g
s
.30913 .84997 m .27375 .82948 L .27968 .83692 L p .031 .41 .859 r
F P
0 g
s
.27968 .83692 m .31384 .85643 L .30913 .84997 L p .031 .41 .859 r
F P
0 g
s
.41027 .26952 m .41892 .25053 L .43648 .24495 L p .343 0 .101 r
F P
0 g
s
.41892 .25053 m .41027 .26952 L .39201 .27605 L p .316 0 .096 r
F P
0 g
s
.82481 .46863 m .82849 .50227 L .82015 .49038 L p .971 .658 .3 r
F P
0 g
s
.82015 .49038 m .81656 .45667 L .82481 .46863 L p .971 .658 .3 r
F P
0 g
s
.66919 .89642 m .63422 .89426 L .6393 .89092 L p .633 .89 .987 r
F P
0 g
s
.6393 .89092 m .67611 .89212 L .66919 .89642 L p .633 .89 .987 r
F P
0 g
s
.20144 .72113 m .18544 .68268 L .18838 .69409 L p 0 0 .401 r
F P
0 g
s
.18838 .69409 m .20367 .73168 L .20144 .72113 L p 0 0 .401 r
F P
0 g
s
.84542 .74837 m .82224 .78207 L .8234 .77137 L p .947 .958 .681 r
F P
0 g
s
.8234 .77137 m .8463 .73652 L .84542 .74837 L p .947 .958 .681 r
F P
0 g
s
.59614 .9104 m .57315 .89801 L .57789 .89651 L p .604 .837 .988 r
F P
0 g
s
.57789 .89651 m .60326 .90819 L .59614 .9104 L p .604 .837 .988 r
F P
0 g
s
.64708 .24072 m .65875 .25574 L .63905 .2494 L p .621 .07 0 r
F P
0 g
s
.63905 .2494 m .62902 .23504 L .64708 .24072 L p .621 .07 0 r
F P
0 g
s
.20246 .4886 m .20722 .45234 L .19667 .4646 L p .059 0 .328 r
F P
0 g
s
.19667 .4646 m .19172 .50104 L .20246 .4886 L p .059 0 .328 r
F P
0 g
s
.26454 .81407 m .23435 .78517 L .23962 .79387 L p 0 .192 .719 r
F P
0 g
s
.23962 .79387 m .26867 .82187 L .26454 .81407 L p 0 .192 .719 r
F P
0 g
s
.23416 .4302 m .24112 .39644 L .2274 .40684 L p .226 0 .342 r
F P
0 g
s
.2274 .40684 m .21981 .44086 L .23416 .4302 L p .226 0 .342 r
F P
0 g
s
.47237 .89574 m .44575 .90726 L .45271 .90969 L p .534 .773 .985 r
F P
0 g
s
.45271 .90969 m .47702 .89734 L .47237 .89574 L p .534 .773 .985 r
F P
0 g
s
.35771 .87361 m .31929 .86276 L .32544 .86897 L p .256 .591 .948 r
F P
0 g
s
.32544 .86897 m .36251 .8787 L .35771 .87361 L p .256 .591 .948 r
F P
0 g
s
.77519 .35541 m .78325 .3866 L .77207 .37391 L p .926 .538 .194 r
F P
0 g
s
.77207 .37391 m .76392 .34297 L .77519 .35541 L p .926 .538 .194 r
F P
0 g
s
.1795 .60549 m .1762 .5657 L .17295 .57913 L p 0 0 .31 r
F P
0 g
s
.17295 .57913 m .17624 .61845 L .1795 .60549 L p 0 0 .31 r
F P
0 g
s
.80275 .41162 m .80784 .44454 L .79854 .43221 L p .96 .622 .27 r
F P
0 g
s
.79854 .43221 m .79341 .39921 L .80275 .41162 L p .96 .622 .27 r
F P
0 g
s
.41106 .88867 m .37385 .88848 L .38034 .89314 L p .421 .705 .981 r
F P
0 g
s
.38034 .89314 m .41589 .89218 L .41106 .88867 L p .421 .705 .981 r
F P
0 g
s
.85323 .57335 m .85285 .61031 L .8463 .59805 L p .989 .725 .37 r
F P
0 g
s
.8463 .59805 m .84636 .5611 L .85323 .57335 L p .989 .725 .37 r
F P
0 g
s
.60326 .90819 m .57789 .89651 L .58244 .89486 L p .608 .838 .987 r
F P
0 g
s
.58244 .89486 m .61011 .90579 L .60326 .90819 L p .608 .838 .987 r
F P
0 g
s
.42911 .26325 m .43648 .24495 L .45457 .23981 L p .368 0 .1 r
F P
0 g
s
.43648 .24495 m .42911 .26325 L .41027 .26952 L p .343 0 .101 r
F P
0 g
s
.7258 .29298 m .73766 .31861 L .7224 .30713 L p .834 .365 .067 r
F P
0 g
s
.7224 .30713 m .71097 .28229 L .7258 .29298 L p .834 .365 .067 r
F P
0 g
s
.46794 .89399 m .43909 .90462 L .44575 .90726 L p .533 .769 .984 r
F P
0 g
s
.44575 .90726 m .47237 .89574 L .46794 .89399 L p .533 .769 .984 r
F P
0 g
s
.62902 .23504 m .63905 .2494 L .61846 .24458 L p .6 .057 0 r
F P
0 g
s
.61846 .24458 m .61024 .23064 L .62902 .23504 L p .6 .057 0 r
F P
0 g
s
.85962 .68665 m .84566 .72456 L .84362 .7126 L p .993 .877 .561 r
F P
0 g
s
.84362 .7126 m .85693 .67397 L .85962 .68665 L p .993 .877 .561 r
F P
0 g
s
.78003 .83742 m .74314 .85578 L .7471 .84869 L p .795 .981 .9 r
F P
0 g
s
.7471 .84869 m .78478 .82896 L .78003 .83742 L p .795 .981 .9 r
F P
0 g
s
.67611 .89212 m .6393 .89092 L .64396 .88742 L p .647 .889 .984 r
F P
0 g
s
.64396 .88742 m .68247 .88757 L .67611 .89212 L p .647 .889 .984 r
F P
0 g
s
.34862 .31644 m .35707 .28965 L .34036 .29672 L p .37 .047 .281 r
F P
0 g
s
.34036 .29672 m .33095 .32365 L .34862 .31644 L p .37 .047 .281 r
F P
0 g
s
.22734 .76695 m .20367 .73168 L .20747 .74185 L p 0 .011 .585 r
F P
0 g
s
.20747 .74185 m .23021 .77621 L .22734 .76695 L p 0 .011 .585 r
F P
0 g
s
.61011 .90579 m .58244 .89486 L .58677 .89308 L p .614 .839 .986 r
F P
0 g
s
.58677 .89308 m .61665 .90319 L .61011 .90579 L p .614 .839 .986 r
F P
0 g
s
.73251 .86908 m .69338 .87774 L .69786 .87249 L p .712 .942 .958 r
F P
0 g
s
.69786 .87249 m .73827 .86258 L .73251 .86908 L p .712 .942 .958 r
F P
0 g
s
.44853 .25736 m .45457 .23981 L .47317 .23525 L p .393 0 .095 r
F P
0 g
s
.45457 .23981 m .44853 .25736 L .42911 .26325 L p .368 0 .1 r
F P
0 g
s
.83643 .51414 m .83889 .54908 L .83095 .53723 L p .979 .681 .331 r
F P
0 g
s
.83095 .53723 m .82849 .50227 L .83643 .51414 L p .979 .681 .331 r
F P
0 g
s
.8197 .79253 m .78836 .82016 L .79076 .81109 L p .89 .984 .808 r
F P
0 g
s
.79076 .81109 m .82224 .78207 L .8197 .79253 L p .89 .984 .808 r
F P
0 g
s
.28935 .36969 m .29703 .3388 L .28099 .34698 L p .354 .077 .347 r
F P
0 g
s
.28099 .34698 m .27237 .37796 L .28935 .36969 L p .354 .077 .347 r
F P
0 g
s
.46373 .89211 m .43275 .90177 L .43909 .90462 L p .533 .765 .983 r
F P
0 g
s
.43909 .90462 m .46794 .89399 L .46373 .89211 L p .533 .765 .983 r
F P
0 g
s
.18552 .65881 m .17624 .61845 L .17538 .63128 L p 0 0 .385 r
F P
0 g
s
.17538 .63128 m .18443 .67089 L .18552 .65881 L p 0 0 .385 r
F P
0 g
s
.61024 .23064 m .61846 .24458 L .59722 .24133 L p .576 .045 0 r
F P
0 g
s
.59722 .24133 m .5909 .22758 L .61024 .23064 L p .576 .045 0 r
F P
0 g
s
.40667 .88503 m .3679 .88366 L .37385 .88848 L p .427 .701 .979 r
F P
0 g
s
.37385 .88848 m .41106 .88867 L .40667 .88503 L p .427 .701 .979 r
F P
0 g
s
.19034 .53941 m .19172 .50104 L .18335 .51408 L p 0 0 .358 r
F P
0 g
s
.18335 .51408 m .18201 .5524 L .19034 .53941 L p 0 0 .358 r
F P
0 g
s
.30521 .84337 m .26867 .82187 L .27375 .82948 L p .089 .433 .874 r
F P
0 g
s
.27375 .82948 m .30913 .84997 L .30521 .84337 L p .089 .433 .874 r
F P
0 g
s
.61665 .90319 m .58677 .89308 L .59088 .89116 L p .619 .839 .984 r
F P
0 g
s
.59088 .89116 m .62287 .9004 L .61665 .90319 L p .619 .839 .984 r
F P
0 g
s
.35353 .8684 m .31384 .85643 L .31929 .86276 L p .28 .594 .948 r
F P
0 g
s
.31929 .86276 m .35771 .87361 L .35353 .8684 L p .28 .594 .948 r
F P
0 g
s
.46857 .25199 m .47317 .23525 L .49223 .23138 L p .418 0 .084 r
F P
0 g
s
.47317 .23525 m .46857 .25199 L .44853 .25736 L p .393 0 .095 r
F P
0 g
s
.85855 .62285 m .85294 .66145 L .84783 .64916 L p .999 .787 .458 r
F P
0 g
s
.84783 .64916 m .85285 .61031 L .85855 .62285 L p .999 .787 .458 r
F P
0 g
s
.5909 .22758 m .59722 .24133 L .57555 .23969 L p .55 .032 0 r
F P
0 g
s
.57555 .23969 m .5712 .22588 L .5909 .22758 L p .55 .032 0 r
F P
0 g
s
.81656 .45667 m .82015 .49038 L .81139 .47842 L p .971 .656 .311 r
F P
0 g
s
.81139 .47842 m .80784 .44454 L .81656 .45667 L p .971 .656 .311 r
F P
0 g
s
.45975 .8901 m .42675 .89874 L .43275 .90177 L p .532 .761 .981 r
F P
0 g
s
.43275 .90177 m .46373 .89211 L .45975 .8901 L p .532 .761 .981 r
F P
0 g
s
.68247 .88757 m .64396 .88742 L .64816 .88376 L p .661 .888 .98 r
F P
0 g
s
.64816 .88376 m .68824 .88277 L .68247 .88757 L p .661 .888 .98 r
F P
0 g
s
.76392 .34297 m .77207 .37391 L .75965 .36127 L p .919 .526 .212 r
F P
0 g
s
.75965 .36127 m .75146 .33064 L .76392 .34297 L p .919 .526 .212 r
F P
0 g
s
.8463 .73652 m .8234 .77137 L .8232 .76055 L p .964 .938 .692 r
F P
0 g
s
.8232 .76055 m .84566 .72456 L .8463 .73652 L p .964 .938 .692 r
F P
0 g
s
.24992 .42035 m .25621 .38684 L .24112 .39644 L p .307 .067 .378 r
F P
0 g
s
.24112 .39644 m .23416 .4302 L .24992 .42035 L p .307 .067 .378 r
F P
0 g
s
.71097 .28229 m .7224 .30713 L .70564 .29644 L p .819 .349 .094 r
F P
0 g
s
.70564 .29644 m .69482 .27237 L .71097 .28229 L p .819 .349 .094 r
F P
0 g
s
.4892 .24733 m .49223 .23138 L .51168 .22837 L p .443 0 .07 r
F P
0 g
s
.49223 .23138 m .4892 .24733 L .46857 .25199 L p .418 0 .084 r
F P
0 g
s
.21531 .47686 m .21981 .44086 L .20722 .45234 L p .188 0 .38 r
F P
0 g
s
.20722 .45234 m .20246 .4886 L .21531 .47686 L p .188 0 .38 r
F P
0 g
s
.26144 .80607 m .23021 .77621 L .23435 .78517 L p 0 .248 .762 r
F P
0 g
s
.23435 .78517 m .26454 .81407 L .26144 .80607 L p 0 .248 .762 r
F P
0 g
s
.36671 .30935 m .37429 .28276 L .35707 .28965 L p .391 .069 .294 r
F P
0 g
s
.35707 .28965 m .34862 .31644 L .36671 .30935 L p .391 .069 .294 r
F P
0 g
s
.5712 .22588 m .57555 .23969 L .5537 .23959 L p .522 .02 .004 r
F P
0 g
s
.5537 .23959 m .55131 .2255 L .5712 .22588 L p .522 .02 .004 r
F P
0 g
s
.62287 .9004 m .59088 .89116 L .59473 .88912 L p .625 .84 .982 r
F P
0 g
s
.59473 .88912 m .62873 .89742 L .62287 .9004 L p .625 .84 .982 r
F P
0 g
s
.79341 .39921 m .79854 .43221 L .78846 .41971 L p .957 .615 .283 r
F P
0 g
s
.78846 .41971 m .78325 .3866 L .79341 .39921 L p .957 .615 .283 r
F P
0 g
s
.20094 .71025 m .18443 .67089 L .18544 .68268 L p 0 0 .506 r
F P
0 g
s
.18544 .68268 m .20144 .72113 L .20094 .71025 L p 0 0 .506 r
F P
0 g
s
.51034 .24358 m .51168 .22837 L .53142 .22637 L p .469 0 .051 r
F P
0 g
s
.51168 .22837 m .51034 .24358 L .4892 .24733 L p .443 0 .07 r
F P
0 g
s
.55131 .2255 m .5537 .23959 L .53189 .24094 L p .495 .009 .029 r
F P
0 g
s
.53189 .24094 m .53142 .22637 L .55131 .2255 L p .495 .009 .029 r
F P
0 g
s
.53142 .22637 m .53189 .24094 L .51034 .24358 L p .469 0 .051 r
F P
0 g
s
.40273 .88127 m .36251 .8787 L .3679 .88366 L p .434 .698 .976 r
F P
0 g
s
.3679 .88366 m .40667 .88503 L .40273 .88127 L p .434 .698 .976 r
F P
0 g
s
.73827 .86258 m .69786 .87249 L .70166 .86703 L p .733 .936 .954 r
F P
0 g
s
.70166 .86703 m .74314 .85578 L .73827 .86258 L p .733 .936 .954 r
F P
0 g
s
.84636 .5611 m .8463 .59805 L .83905 .58607 L p .988 .718 .383 r
F P
0 g
s
.83905 .58607 m .83889 .54908 L .84636 .5611 L p .988 .718 .383 r
F P
0 g
s
.45604 .88797 m .42112 .89554 L .42675 .89874 L p .533 .758 .979 r
F P
0 g
s
.42675 .89874 m .45975 .8901 L .45604 .88797 L p .533 .758 .979 r
F P
0 g
s
.78478 .82896 m .7471 .84869 L .75011 .84137 L p .82 .969 .898 r
F P
0 g
s
.75011 .84137 m .78836 .82016 L .78478 .82896 L p .82 .969 .898 r
F P
0 g
s
.18521 .59255 m .18201 .5524 L .1762 .5657 L p 0 0 .401 r
F P
0 g
s
.1762 .5657 m .1795 .60549 L .18521 .59255 L p 0 0 .401 r
F P
0 g
s
.30691 .3619 m .31373 .33106 L .29703 .3388 L p .392 .115 .369 r
F P
0 g
s
.29703 .3388 m .28935 .36969 L .30691 .3619 L p .392 .115 .369 r
F P
0 g
s
.62873 .89742 m .59473 .88912 L .59833 .88697 L p .63 .84 .98 r
F P
0 g
s
.59833 .88697 m .63422 .89426 L .62873 .89742 L p .63 .84 .98 r
F P
0 g
s
.85693 .67397 m .84362 .7126 L .84031 .70075 L p .996 .858 .572 r
F P
0 g
s
.84031 .70075 m .85294 .66145 L .85693 .67397 L p .996 .858 .572 r
F P
0 g
s
.68824 .88277 m .64816 .88376 L .65189 .87994 L p .673 .885 .976 r
F P
0 g
s
.65189 .87994 m .69338 .87774 L .68824 .88277 L p .673 .885 .976 r
F P
0 g
s
.34998 .86308 m .30913 .84997 L .31384 .85643 L p .306 .597 .947 r
F P
0 g
s
.31384 .85643 m .35353 .8684 L .34998 .86308 L p .306 .597 .947 r
F P
0 g
s
.52276 .88536 m .51926 .90442 L .52487 .90453 L p .6 .794 .973 r
F P
0 g
s
.52487 .90453 m .52559 .88543 L .52276 .88536 L p .6 .794 .973 r
F P
0 g
s
.52559 .88543 m .52487 .90453 L .53049 .90448 L p .602 .795 .973 r
F P
0 g
s
.53049 .90448 m .52842 .88541 L .52559 .88543 L p .602 .795 .973 r
F P
0 g
s
.52842 .88541 m .53049 .90448 L .5361 .90425 L p .604 .797 .973 r
F P
0 g
s
.51995 .88521 m .51367 .90413 L .51926 .90442 L p .599 .792 .973 r
F P
0 g
s
.51926 .90442 m .52276 .88536 L .51995 .88521 L p .599 .792 .973 r
F P
0 g
s
.5361 .90425 m .53124 .8853 L .52842 .88541 L p .604 .797 .973 r
F P
0 g
s
.53124 .8853 m .5361 .90425 L .54166 .90384 L p .605 .798 .973 r
F P
0 g
s
.51716 .88497 m .50813 .90366 L .51367 .90413 L p .598 .791 .973 r
F P
0 g
s
.51367 .90413 m .51995 .88521 L .51716 .88497 L p .598 .791 .973 r
F P
0 g
s
.36671 .30935 m .37429 .28276 L .39201 .27605 L p .411 .087 .303 r
F P
0 g
s
.54166 .90384 m .53405 .8851 L .53124 .8853 L p .605 .798 .973 r
F P
0 g
s
.53405 .8851 m .54166 .90384 L .54717 .90327 L p .607 .799 .973 r
F P
0 g
s
.82224 .78207 m .79076 .81109 L .79198 .80184 L p .908 .964 .807 r
F P
0 g
s
.79198 .80184 m .8234 .77137 L .82224 .78207 L p .908 .964 .807 r
F P
0 g
s
.22586 .7574 m .20144 .72113 L .20367 .73168 L p 0 .1 .653 r
F P
0 g
s
.20367 .73168 m .22734 .76695 L .22586 .7574 L p 0 .1 .653 r
F P
0 g
s
.82849 .50227 m .83095 .53723 L .82256 .52548 L p .978 .679 .341 r
F P
0 g
s
.82256 .52548 m .82015 .49038 L .82849 .50227 L p .978 .679 .341 r
F P
0 g
s
.45259 .88573 m .41589 .89218 L .42112 .89554 L p .533 .755 .978 r
F P
0 g
s
.42112 .89554 m .45604 .88797 L .45259 .88573 L p .533 .755 .978 r
F P
0 g
s
.5144 .88464 m .50265 .90303 L .50813 .90366 L p .597 .789 .973 r
F P
0 g
s
.50813 .90366 m .51716 .88497 L .5144 .88464 L p .597 .789 .973 r
F P
0 g
s
.30214 .83663 m .26454 .81407 L .26867 .82187 L p .147 .455 .884 r
F P
0 g
s
.26867 .82187 m .30521 .84337 L .30214 .83663 L p .147 .455 .884 r
F P
0 g
s
.54717 .90327 m .53682 .88482 L .53405 .8851 L p .607 .799 .973 r
F P
0 g
s
.53682 .88482 m .54717 .90327 L .5526 .90254 L p .609 .8 .973 r
F P
0 g
s
.69482 .27237 m .70564 .29644 L .68738 .28681 L p .798 .331 .121 r
F P
0 g
s
.68738 .28681 m .67739 .26345 L .69482 .27237 L p .798 .331 .121 r
F P
0 g
s
.5117 .88423 m .49727 .90222 L .50265 .90303 L p .595 .788 .972 r
F P
0 g
s
.50265 .90303 m .5144 .88464 L .5117 .88423 L p .595 .788 .972 r
F P
0 g
s
.5526 .90254 m .53955 .88445 L .53682 .88482 L p .609 .8 .973 r
F P
0 g
s
.53955 .88445 m .5526 .90254 L .55794 .90164 L p .611 .801 .973 r
F P
0 g
s
.39925 .8774 m .35771 .87361 L .36251 .8787 L p .443 .695 .973 r
F P
0 g
s
.36251 .8787 m .40273 .88127 L .39925 .8774 L p .443 .695 .973 r
F P
0 g
s
.50905 .88374 m .49199 .90124 L .49727 .90222 L p .594 .786 .972 r
F P
0 g
s
.49727 .90222 m .5117 .88423 L .50905 .88374 L p .594 .786 .972 r
F P
0 g
s
.63422 .89426 m .59833 .88697 L .60164 .8847 L p .636 .839 .978 r
F P
0 g
s
.60164 .8847 m .6393 .89092 L .63422 .89426 L p .636 .839 .978 r
F P
0 g
s
.20101 .52687 m .20246 .4886 L .19172 .50104 L p .128 0 .412 r
F P
0 g
s
.19172 .50104 m .19034 .53941 L .20101 .52687 L p .128 0 .412 r
F P
0 g
s
.55794 .90164 m .54223 .88399 L .53955 .88445 L p .611 .801 .973 r
F P
0 g
s
.54223 .88399 m .55794 .90164 L .56315 .90059 L p .613 .802 .972 r
F P
0 g
s
.75146 .33064 m .75965 .36127 L .74581 .3489 L p .908 .51 .232 r
F P
0 g
s
.74581 .3489 m .73766 .31861 L .75146 .33064 L p .908 .51 .232 r
F P
0 g
s
.26676 .41127 m .27237 .37796 L .25621 .38684 L p .365 .12 .404 r
F P
0 g
s
.25621 .38684 m .24992 .42035 L .26676 .41127 L p .365 .12 .404 r
F P
0 g
s
.18881 .64652 m .1795 .60549 L .17624 .61845 L p 0 0 .474 r
F P
0 g
s
.17624 .61845 m .18552 .65881 L .18881 .64652 L p 0 0 .474 r
F P
0 g
s
.50647 .88316 m .48684 .9001 L .49199 .90124 L p .593 .784 .971 r
F P
0 g
s
.49199 .90124 m .50905 .88374 L .50647 .88316 L p .593 .784 .971 r
F P
0 g
s
.85285 .61031 m .84783 .64916 L .84177 .63715 L p .997 .774 .468 r
F P
0 g
s
.84177 .63715 m .8463 .59805 L .85285 .61031 L p .997 .774 .468 r
F P
0 g
s
.80784 .44454 m .81139 .47842 L .80204 .46636 L p .971 .654 .323 r
F P
0 g
s
.80204 .46636 m .79854 .43221 L .80784 .44454 L p .971 .654 .323 r
F P
0 g
s
.56315 .90059 m .54485 .88346 L .54223 .88399 L p .613 .802 .972 r
F P
0 g
s
.54485 .88346 m .56315 .90059 L .56823 .89938 L p .615 .803 .972 r
F P
0 g
s
.74314 .85578 m .70166 .86703 L .70473 .8614 L p .751 .928 .947 r
F P
0 g
s
.70473 .8614 m .7471 .84869 L .74314 .85578 L p .751 .928 .947 r
F P
0 g
s
.44943 .88339 m .41106 .88867 L .41589 .89218 L p .535 .751 .976 r
F P
0 g
s
.41589 .89218 m .45259 .88573 L .44943 .88339 L p .535 .751 .976 r
F P
0 g
s
.22994 .4659 m .23416 .4302 L .21981 .44086 L p .28 .076 .414 r
F P
0 g
s
.21981 .44086 m .21531 .47686 L .22994 .4659 L p .28 .076 .414 r
F P
0 g
s
.50396 .8825 m .48184 .8988 L .48684 .9001 L p .593 .783 .971 r
F P
0 g
s
.48684 .9001 m .50647 .88316 L .50396 .8825 L p .593 .783 .971 r
F P
0 g
s
.84566 .72456 m .8232 .76055 L .82173 .74971 L p .97 .915 .695 r
F P
0 g
s
.82173 .74971 m .84362 .7126 L .84566 .72456 L p .97 .915 .695 r
F P
0 g
s
.3249 .35444 m .33095 .32365 L .31373 .33106 L p .42 .143 .385 r
F P
0 g
s
.31373 .33106 m .30691 .3619 L .3249 .35444 L p .42 .143 .385 r
F P
0 g
s
.69338 .87774 m .65189 .87994 L .65512 .87599 L p .685 .882 .971 r
F P
0 g
s
.65512 .87599 m .69786 .87249 L .69338 .87774 L p .685 .882 .971 r
F P
0 g
s
.25944 .79787 m .22734 .76695 L .23021 .77621 L p .018 .298 .792 r
F P
0 g
s
.23021 .77621 m .26144 .80607 L .25944 .79787 L p .018 .298 .792 r
F P
0 g
s
.56823 .89938 m .5474 .88284 L .54986 .88215 L p .617 .804 .971 r
F P
0 g
s
.54986 .88215 m .57315 .89801 L .56823 .89938 L p .617 .804 .971 r
F P
0 g
s
.56823 .89938 m .5474 .88284 L .54485 .88346 L p .615 .803 .972 r
F P
0 g
s
.78325 .3866 m .78846 .41971 L .77736 .40712 L p .952 .606 .298 r
F P
0 g
s
.77736 .40712 m .77207 .37391 L .78325 .3866 L p .952 .606 .298 r
F P
0 g
s
.38526 .30235 m .39201 .27605 L .41027 .26952 L p .432 .104 .308 r
F P
0 g
s
.39201 .27605 m .38526 .30235 L .36671 .30935 L p .411 .087 .303 r
F P
0 g
s
.78836 .82016 m .75011 .84137 L .75217 .83386 L p .837 .954 .891 r
F P
0 g
s
.75217 .83386 m .79076 .81109 L .78836 .82016 L p .837 .954 .891 r
F P
0 g
s
.50155 .88177 m .47702 .89734 L .48184 .8988 L p .592 .781 .97 r
F P
0 g
s
.48184 .8988 m .50396 .8825 L .50155 .88177 L p .592 .781 .97 r
F P
0 g
s
.6393 .89092 m .60164 .8847 L .60466 .88232 L p .642 .838 .976 r
F P
0 g
s
.60466 .88232 m .64396 .88742 L .6393 .89092 L p .642 .838 .976 r
F P
0 g
s
.57315 .89801 m .54986 .88215 L .55223 .88138 L p .619 .804 .971 r
F P
0 g
s
.55223 .88138 m .57789 .89651 L .57315 .89801 L p .619 .804 .971 r
F P
0 g
s
.34712 .85766 m .30521 .84337 L .30913 .84997 L p .331 .601 .945 r
F P
0 g
s
.30913 .84997 m .34998 .86308 L .34712 .85766 L p .331 .601 .945 r
F P
0 g
s
.67739 .26345 m .68738 .28681 L .66771 .27849 L p .774 .311 .147 r
F P
0 g
s
.66771 .27849 m .65875 .25574 L .67739 .26345 L p .774 .311 .147 r
F P
0 g
s
.83889 .54908 m .83905 .58607 L .83122 .57435 L p .987 .713 .392 r
F P
0 g
s
.83122 .57435 m .83095 .53723 L .83889 .54908 L p .987 .713 .392 r
F P
0 g
s
.49923 .88096 m .47237 .89574 L .47702 .89734 L p .591 .78 .97 r
F P
0 g
s
.47702 .89734 m .50155 .88177 L .49923 .88096 L p .591 .78 .97 r
F P
0 g
s
.39626 .87344 m .35353 .8684 L .35771 .87361 L p .452 .693 .969 r
F P
0 g
s
.35771 .87361 m .39925 .8774 L .39626 .87344 L p .452 .693 .969 r
F P
0 g
s
.2023 .69909 m .18552 .65881 L .18443 .67089 L p 0 .03 .577 r
F P
0 g
s
.18443 .67089 m .20094 .71025 L .2023 .69909 L p 0 .03 .577 r
F P
0 g
s
.44657 .88095 m .40667 .88503 L .41106 .88867 L p .537 .748 .974 r
F P
0 g
s
.41106 .88867 m .44943 .88339 L .44657 .88095 L p .537 .748 .974 r
F P
0 g
s
.57789 .89651 m .55223 .88138 L .55449 .88054 L p .621 .805 .97 r
F P
0 g
s
.55449 .88054 m .58244 .89486 L .57789 .89651 L p .621 .805 .97 r
F P
0 g
s
.49702 .88008 m .46794 .89399 L .47237 .89574 L p .591 .778 .969 r
F P
0 g
s
.47237 .89574 m .49923 .88096 L .49702 .88008 L p .591 .778 .969 r
F P
0 g
s
.1933 .57978 m .19034 .53941 L .18201 .5524 L p .068 0 .458 r
F P
0 g
s
.18201 .5524 m .18521 .59255 L .1933 .57978 L p .068 0 .458 r
F P
0 g
s
.85294 .66145 m .84031 .70075 L .83587 .68909 L p .994 .839 .578 r
F P
0 g
s
.83587 .68909 m .84783 .64916 L .85294 .66145 L p .994 .839 .578 r
F P
0 g
s
.40431 .29544 m .41027 .26952 L .42911 .26325 L p .451 .118 .31 r
F P
0 g
s
.41027 .26952 m .40431 .29544 L .38526 .30235 L p .432 .104 .308 r
F P
0 g
s
.29995 .82976 m .26144 .80607 L .26454 .81407 L p .202 .474 .89 r
F P
0 g
s
.26454 .81407 m .30214 .83663 L .29995 .82976 L p .202 .474 .89 r
F P
0 g
s
.8234 .77137 m .79198 .80184 L .79204 .79247 L p .918 .943 .803 r
F P
0 g
s
.79204 .79247 m .8232 .76055 L .8234 .77137 L p .918 .943 .803 r
F P
0 g
s
.64396 .88742 m .60466 .88232 L .60738 .87985 L p .648 .837 .973 r
F P
0 g
s
.60738 .87985 m .64816 .88376 L .64396 .88742 L p .648 .837 .973 r
F P
0 g
s
.58244 .89486 m .55449 .88054 L .55665 .87963 L p .623 .805 .97 r
F P
0 g
s
.55665 .87963 m .58677 .89308 L .58244 .89486 L p .623 .805 .97 r
F P
0 g
s
.82015 .49038 m .82256 .52548 L .81369 .5138 L p .978 .678 .352 r
F P
0 g
s
.81369 .5138 m .81139 .47842 L .82015 .49038 L p .978 .678 .352 r
F P
0 g
s
.69786 .87249 m .65512 .87599 L .65784 .87191 L p .696 .878 .966 r
F P
0 g
s
.65784 .87191 m .70166 .86703 L .69786 .87249 L p .696 .878 .966 r
F P
0 g
s
.28437 .40283 m .28935 .36969 L .27237 .37796 L p .406 .158 .422 r
F P
0 g
s
.27237 .37796 m .26676 .41127 L .28437 .40283 L p .406 .158 .422 r
F P
0 g
s
.73766 .31861 m .74581 .3489 L .73038 .33704 L p .892 .492 .252 r
F P
0 g
s
.73038 .33704 m .7224 .30713 L .73766 .31861 L p .892 .492 .252 r
F P
0 g
s
.49493 .87914 m .46373 .89211 L .46794 .89399 L p .59 .776 .969 r
F P
0 g
s
.46794 .89399 m .49702 .88008 L .49493 .87914 L p .59 .776 .969 r
F P
0 g
s
.7471 .84869 m .70473 .8614 L .70707 .85561 L p .765 .918 .94 r
F P
0 g
s
.70707 .85561 m .75011 .84137 L .7471 .84869 L p .765 .918 .94 r
F P
0 g
s
.34323 .34718 m .34862 .31644 L .33095 .32365 L p .439 .163 .396 r
F P
0 g
s
.33095 .32365 m .3249 .35444 L .34323 .34718 L p .439 .163 .396 r
F P
0 g
s
.22588 .74758 m .20094 .71025 L .20144 .72113 L p 0 .176 .698 r
F P
0 g
s
.20144 .72113 m .22586 .7574 L .22588 .74758 L p 0 .176 .698 r
F P
0 g
s
.44402 .87843 m .40273 .88127 L .40667 .88503 L p .539 .746 .971 r
F P
0 g
s
.40667 .88503 m .44657 .88095 L .44402 .87843 L p .539 .746 .971 r
F P
0 g
s
.58677 .89308 m .55665 .87963 L .55868 .87865 L p .625 .805 .969 r
F P
0 g
s
.55868 .87865 m .59088 .89116 L .58677 .89308 L p .625 .805 .969 r
F P
0 g
s
.65875 .25574 m .66771 .27849 L .64678 .27169 L p .746 .291 .172 r
F P
0 g
s
.64678 .27169 m .63905 .2494 L .65875 .25574 L p .746 .291 .172 r
F P
0 g
s
.21377 .51494 m .21531 .47686 L .20246 .4886 L p .236 .073 .446 r
F P
0 g
s
.20246 .4886 m .20101 .52687 L .21377 .51494 L p .236 .073 .446 r
F P
0 g
s
.49296 .87813 m .45975 .8901 L .46373 .89211 L p .59 .775 .968 r
F P
0 g
s
.46373 .89211 m .49493 .87914 L .49296 .87813 L p .59 .775 .968 r
F P
0 g
s
.39378 .86938 m .34998 .86308 L .35353 .8684 L p .462 .691 .966 r
F P
0 g
s
.35353 .8684 m .39626 .87344 L .39378 .86938 L p .462 .691 .966 r
F P
0 g
s
.8463 .59805 m .84177 .63715 L .83489 .62546 L p .994 .764 .476 r
F P
0 g
s
.83489 .62546 m .83905 .58607 L .8463 .59805 L p .994 .764 .476 r
F P
0 g
s
.79854 .43221 m .80204 .46636 L .79193 .45421 L p .968 .649 .338 r
F P
0 g
s
.79193 .45421 m .78846 .41971 L .79854 .43221 L p .968 .649 .338 r
F P
0 g
s
.24601 .45573 m .24992 .42035 L .23416 .4302 L p .347 .131 .436 r
F P
0 g
s
.23416 .4302 m .22994 .4659 L .24601 .45573 L p .347 .131 .436 r
F P
0 g
s
.42396 .2887 m .42911 .26325 L .44853 .25736 L p .47 .131 .308 r
F P
0 g
s
.42911 .26325 m .42396 .2887 L .40431 .29544 L p .451 .118 .31 r
F P
0 g
s
.64816 .88376 m .60738 .87985 L .60977 .8773 L p .653 .836 .97 r
F P
0 g
s
.60977 .8773 m .65189 .87994 L .64816 .88376 L p .653 .836 .97 r
F P
0 g
s
.59088 .89116 m .55868 .87865 L .56059 .87762 L p .627 .805 .968 r
F P
0 g
s
.56059 .87762 m .59473 .88912 L .59088 .89116 L p .627 .805 .968 r
F P
0 g
s
.34495 .85214 m .30214 .83663 L .30521 .84337 L p .357 .605 .942 r
F P
0 g
s
.30521 .84337 m .34712 .85766 L .34495 .85214 L p .357 .605 .942 r
F P
0 g
s
.77207 .37391 m .77736 .40712 L .76501 .39458 L p .944 .593 .316 r
F P
0 g
s
.76501 .39458 m .75965 .36127 L .77207 .37391 L p .944 .593 .316 r
F P
0 g
s
.79076 .81109 m .75217 .83386 L .75326 .8262 L p .848 .937 .883 r
F P
0 g
s
.75326 .8262 m .79198 .80184 L .79076 .81109 L p .848 .937 .883 r
F P
0 g
s
.19432 .63418 m .18521 .59255 L .1795 .60549 L p .032 .035 .527 r
F P
0 g
s
.1795 .60549 m .18881 .64652 L .19432 .63418 L p .032 .035 .527 r
F P
0 g
s
.84362 .7126 m .82173 .74971 L .81906 .73893 L p .97 .892 .694 r
F P
0 g
s
.81906 .73893 m .84031 .70075 L .84362 .7126 L p .97 .892 .694 r
F P
0 g
s
.49112 .87705 m .45604 .88797 L .45975 .8901 L p .59 .773 .967 r
F P
0 g
s
.45975 .8901 m .49296 .87813 L .49112 .87705 L p .59 .773 .967 r
F P
0 g
s
.25864 .78946 m .22586 .7574 L .22734 .76695 L p .11 .341 .809 r
F P
0 g
s
.22734 .76695 m .25944 .79787 L .25864 .78946 L p .11 .341 .809 r
F P
0 g
s
.4418 .87584 m .39925 .8774 L .40273 .88127 L p .542 .743 .969 r
F P
0 g
s
.40273 .88127 m .44402 .87843 L .4418 .87584 L p .542 .743 .969 r
F P
0 g
s
.59473 .88912 m .56059 .87762 L .56236 .87652 L p .629 .805 .967 r
F P
0 g
s
.56236 .87652 m .59833 .88697 L .59473 .88912 L p .629 .805 .967 r
F P
0 g
s
.63905 .2494 m .64678 .27169 L .62481 .26657 L p .716 .271 .195 r
F P
0 g
s
.62481 .26657 m .61846 .24458 L .63905 .2494 L p .716 .271 .195 r
F P
0 g
s
.70166 .86703 m .65784 .87191 L .66003 .86773 L p .705 .873 .961 r
F P
0 g
s
.66003 .86773 m .70473 .8614 L .70166 .86703 L p .705 .873 .961 r
F P
0 g
s
.44426 .28225 m .44853 .25736 L .46857 .25199 L p .491 .143 .304 r
F P
0 g
s
.44853 .25736 m .44426 .28225 L .42396 .2887 L p .47 .131 .308 r
F P
0 g
s
.83095 .53723 m .83122 .57435 L .82283 .56285 L p .985 .709 .402 r
F P
0 g
s
.82283 .56285 m .82256 .52548 L .83095 .53723 L p .985 .709 .402 r
F P
0 g
s
.3619 .34002 m .36671 .30935 L .34862 .31644 L p .453 .177 .403 r
F P
0 g
s
.34862 .31644 m .34323 .34718 L .3619 .34002 L p .453 .177 .403 r
F P
0 g
s
.48942 .87593 m .45259 .88573 L .45604 .88797 L p .59 .772 .966 r
F P
0 g
s
.45604 .88797 m .49112 .87705 L .48942 .87593 L p .59 .772 .966 r
F P
0 g
s
.30251 .3949 m .30691 .3619 L .28935 .36969 L p .436 .186 .435 r
F P
0 g
s
.28935 .36969 m .28437 .40283 L .30251 .3949 L p .436 .186 .435 r
F P
0 g
s
.65189 .87994 m .60977 .8773 L .61183 .87466 L p .659 .834 .967 r
F P
0 g
s
.61183 .87466 m .65512 .87599 L .65189 .87994 L p .659 .834 .967 r
F P
0 g
s
.75011 .84137 m .70707 .85561 L .70867 .84969 L p .775 .908 .932 r
F P
0 g
s
.70867 .84969 m .75217 .83386 L .75011 .84137 L p .775 .908 .932 r
F P
0 g
s
.7224 .30713 m .73038 .33704 L .71328 .32597 L p .871 .472 .273 r
F P
0 g
s
.71328 .32597 m .70564 .29644 L .7224 .30713 L p .871 .472 .273 r
F P
0 g
s
.59833 .88697 m .56236 .87652 L .56399 .87537 L p .631 .805 .966 r
F P
0 g
s
.56399 .87537 m .60164 .8847 L .59833 .88697 L p .631 .805 .966 r
F P
0 g
s
.2987 .82275 m .25944 .79787 L .26144 .80607 L p .254 .491 .891 r
F P
0 g
s
.26144 .80607 m .29995 .82976 L .2987 .82275 L p .254 .491 .891 r
F P
0 g
s
.39182 .86526 m .34712 .85766 L .34998 .86308 L p .472 .689 .962 r
F P
0 g
s
.34998 .86308 m .39378 .86938 L .39182 .86526 L p .472 .689 .962 r
F P
0 g
s
.20559 .68772 m .18881 .64652 L .18552 .65881 L p .04 .118 .619 r
F P
0 g
s
.18552 .65881 m .2023 .69909 L .20559 .68772 L p .04 .118 .619 r
F P
0 g
s
.8232 .76055 m .79204 .79247 L .79097 .78306 L p .921 .921 .796 r
F P
0 g
s
.79097 .78306 m .82173 .74971 L .8232 .76055 L p .921 .921 .796 r
F P
0 g
s
.84783 .64916 m .83587 .68909 L .83041 .67769 L p .99 .822 .582 r
F P
0 g
s
.83041 .67769 m .84177 .63715 L .84783 .64916 L p .99 .822 .582 r
F P
0 g
s
.61846 .24458 m .62481 .26657 L .60208 .26321 L p .684 .252 .216 r
F P
0 g
s
.60208 .26321 m .59722 .24133 L .61846 .24458 L p .684 .252 .216 r
F P
0 g
s
.48788 .87475 m .44943 .88339 L .45259 .88573 L p .591 .77 .965 r
F P
0 g
s
.45259 .88573 m .48942 .87593 L .48788 .87475 L p .591 .77 .965 r
F P
0 g
s
.46526 .27629 m .46857 .25199 L .4892 .24733 L p .513 .155 .297 r
F P
0 g
s
.46857 .25199 m .46526 .27629 L .44426 .28225 L p .491 .143 .304 r
F P
0 g
s
.43991 .87318 m .39626 .87344 L .39925 .8774 L p .545 .741 .967 r
F P
0 g
s
.39925 .8774 m .4418 .87584 L .43991 .87318 L p .545 .741 .967 r
F P
0 g
s
.20363 .56734 m .20101 .52687 L .19034 .53941 L p .189 .081 .491 r
F P
0 g
s
.19034 .53941 m .1933 .57978 L .20363 .56734 L p .189 .081 .491 r
F P
0 g
s
.81139 .47842 m .81369 .5138 L .80421 .50213 L p .977 .676 .366 r
F P
0 g
s
.80421 .50213 m .80204 .46636 L .81139 .47842 L p .977 .676 .366 r
F P
0 g
s
.60164 .8847 m .56399 .87537 L .56546 .87417 L p .634 .805 .965 r
F P
0 g
s
.56546 .87417 m .60466 .88232 L .60164 .8847 L p .634 .805 .965 r
F P
0 g
s
.26317 .44631 m .26676 .41127 L .24992 .42035 L p .396 .171 .452 r
F P
0 g
s
.24992 .42035 m .24601 .45573 L .26317 .44631 L p .396 .171 .452 r
F P
0 g
s
.34351 .84653 m .29995 .82976 L .30214 .83663 L p .382 .608 .938 r
F P
0 g
s
.30214 .83663 m .34495 .85214 L .34351 .84653 L p .382 .608 .938 r
F P
0 g
s
.48698 .27102 m .4892 .24733 L .51034 .24358 L p .537 .168 .288 r
F P
0 g
s
.4892 .24733 m .48698 .27102 L .46526 .27629 L p .513 .155 .297 r
F P
0 g
s
.59722 .24133 m .60208 .26321 L .57888 .26164 L p .653 .233 .234 r
F P
0 g
s
.57888 .26164 m .57555 .23969 L .59722 .24133 L p .653 .233 .234 r
F P
0 g
s
.65512 .87599 m .61183 .87466 L .61355 .87196 L p .664 .833 .964 r
F P
0 g
s
.61355 .87196 m .65784 .87191 L .65512 .87599 L p .664 .833 .964 r
F P
0 g
s
.48648 .87353 m .44657 .88095 L .44943 .88339 L p .591 .769 .964 r
F P
0 g
s
.44943 .88339 m .48788 .87475 L .48648 .87353 L p .591 .769 .964 r
F P
0 g
s
.70473 .8614 m .66003 .86773 L .66168 .86345 L p .713 .868 .955 r
F P
0 g
s
.66168 .86345 m .70707 .85561 L .70473 .8614 L p .713 .868 .955 r
F P
0 g
s
.22831 .50369 m .22994 .4659 L .21531 .47686 L p .314 .132 .467 r
F P
0 g
s
.21531 .47686 m .21377 .51494 L .22831 .50369 L p .314 .132 .467 r
F P
0 g
s
.3619 .34002 m .36671 .30935 L .38526 .30235 L p .466 .189 .408 r
F P
0 g
s
.22748 .73754 m .2023 .69909 L .20094 .71025 L p .096 .239 .722 r
F P
0 g
s
.20094 .71025 m .22588 .74758 L .22748 .73754 L p .096 .239 .722 r
F P
0 g
s
.79198 .80184 m .75326 .8262 L .75339 .81847 L p .855 .921 .874 r
F P
0 g
s
.75339 .81847 m .79204 .79247 L .79198 .80184 L p .855 .921 .874 r
F P
0 g
s
.78846 .41971 m .79193 .45421 L .78079 .44202 L p .963 .642 .356 r
F P
0 g
s
.78079 .44202 m .77736 .40712 L .78846 .41971 L p .963 .642 .356 r
F P
0 g
s
.75965 .36127 m .76501 .39458 L .75116 .38228 L p .931 .578 .335 r
F P
0 g
s
.75116 .38228 m .74581 .3489 L .75965 .36127 L p .931 .578 .335 r
F P
0 g
s
.83905 .58607 m .83489 .62546 L .82729 .61407 L p .99 .756 .483 r
F P
0 g
s
.82729 .61407 m .83122 .57435 L .83905 .58607 L p .99 .756 .483 r
F P
0 g
s
.60466 .88232 m .56546 .87417 L .56678 .87292 L p .636 .805 .964 r
F P
0 g
s
.56678 .87292 m .60738 .87985 L .60466 .88232 L p .636 .805 .964 r
F P
0 g
s
.52559 .88543 m .52632 .86432 L .52276 .88536 L closepath p .619 .784 .96 r
F P
0 g
s
.52842 .88541 m .52632 .86432 L .52559 .88543 L closepath p .62 .784 .96 r
F P
0 g
s
.53124 .8853 m .52632 .86432 L .52842 .88541 L closepath p .62 .785 .96 r
F P
0 g
s
.50935 .26668 m .51034 .24358 L .53189 .24094 L p .563 .182 .278 r
F P
0 g
s
.51034 .24358 m .50935 .26668 L .48698 .27102 L p .537 .168 .288 r
F P
0 g
s
.52276 .88536 m .52632 .86432 L .51995 .88521 L closepath p .619 .784 .96 r
F P
0 g
s
.53405 .8851 m .52632 .86432 L .53124 .8853 L closepath p .621 .785 .96 r
F P
0 g
s
.57555 .23969 m .57888 .26164 L .55551 .26179 L p .622 .215 .251 r
F P
0 g
s
.55551 .26179 m .5537 .23959 L .57555 .23969 L p .622 .215 .251 r
F P
0 g
s
.51995 .88521 m .52632 .86432 L .51716 .88497 L closepath p .619 .783 .96 r
F P
0 g
s
.53682 .88482 m .52632 .86432 L .53405 .8851 L closepath p .621 .785 .96 r
F P
0 g
s
.51716 .88497 m .52632 .86432 L .5144 .88464 L closepath p .618 .783 .96 r
F P
0 g
s
.43836 .87046 m .39378 .86938 L .39626 .87344 L p .549 .739 .964 r
F P
0 g
s
.39626 .87344 m .43991 .87318 L .43836 .87046 L p .549 .739 .964 r
F P
0 g
s
.53955 .88445 m .52632 .86432 L .53682 .88482 L closepath p .622 .785 .96 r
F P
0 g
s
.5144 .88464 m .52632 .86432 L .5117 .88423 L closepath p .618 .782 .96 r
F P
0 g
s
.32101 .38735 m .3249 .35444 L .30691 .3619 L p .457 .206 .444 r
F P
0 g
s
.30691 .3619 m .30251 .3949 L .32101 .38735 L p .457 .206 .444 r
F P
0 g
s
.53225 .26353 m .53189 .24094 L .5537 .23959 L p .592 .198 .265 r
F P
0 g
s
.53189 .24094 m .53225 .26353 L .50935 .26668 L p .563 .182 .278 r
F P
0 g
s
.84031 .70075 m .81906 .73893 L .81527 .72831 L p .966 .872 .692 r
F P
0 g
s
.81527 .72831 m .83587 .68909 L .84031 .70075 L p .966 .872 .692 r
F P
0 g
s
.5537 .23959 m .55551 .26179 L .53225 .26353 L p .592 .198 .265 r
F P
0 g
s
.54223 .88399 m .52632 .86432 L .53955 .88445 L closepath p .622 .786 .96 r
F P
0 g
s
.48525 .87226 m .44402 .87843 L .44657 .88095 L p .592 .767 .963 r
F P
0 g
s
.44657 .88095 m .48648 .87353 L .48525 .87226 L p .592 .767 .963 r
F P
0 g
s
.5117 .88423 m .52632 .86432 L .50905 .88374 L closepath p .618 .782 .96 r
F P
0 g
s
.3904 .86107 m .34495 .85214 L .34712 .85766 L p .483 .688 .958 r
F P
0 g
s
.34712 .85766 m .39182 .86526 L .3904 .86107 L p .483 .688 .958 r
F P
0 g
s
.54485 .88346 m .52632 .86432 L .54223 .88399 L closepath p .623 .786 .96 r
F P
0 g
s
.50905 .88374 m .52632 .86432 L .50647 .88316 L closepath p .617 .782 .96 r
F P
0 g
s
.25909 .78086 m .22588 .74758 L .22586 .7574 L p .19 .376 .817 r
F P
0 g
s
.22586 .7574 m .25864 .78946 L .25909 .78086 L p .19 .376 .817 r
F P
0 g
s
.70564 .29644 m .71328 .32597 L .6945 .31598 L p .846 .45 .293 r
F P
0 g
s
.6945 .31598 m .68738 .28681 L .70564 .29644 L p .846 .45 .293 r
F P
0 g
s
.75217 .83386 m .70867 .84969 L .7095 .84369 L p .783 .897 .924 r
F P
0 g
s
.7095 .84369 m .75326 .8262 L .75217 .83386 L p .783 .897 .924 r
F P
0 g
s
.5474 .88284 m .52632 .86432 L .54485 .88346 L closepath p .623 .786 .96 r
F P
0 g
s
.20202 .62191 m .1933 .57978 L .18521 .59255 L p .157 .116 .557 r
F P
0 g
s
.18521 .59255 m .19432 .63418 L .20202 .62191 L p .157 .116 .557 r
F P
0 g
s
.50647 .88316 m .52632 .86432 L .50396 .8825 L closepath p .617 .781 .96 r
F P
0 g
s
.60738 .87985 m .56678 .87292 L .56793 .87164 L p .638 .804 .963 r
F P
0 g
s
.56793 .87164 m .60977 .8773 L .60738 .87985 L p .638 .804 .963 r
F P
0 g
s
.52632 .86432 m .54986 .88215 L .5474 .88284 L closepath p .623 .786 .96 r
F P
0 g
s
.65784 .87191 m .61355 .87196 L .61492 .86919 L p .669 .83 .961 r
F P
0 g
s
.61492 .86919 m .66003 .86773 L .65784 .87191 L p .669 .83 .961 r
F P
0 g
s
.50396 .8825 m .52632 .86432 L .50155 .88177 L closepath p .617 .781 .96 r
F P
0 g
s
.82256 .52548 m .82283 .56285 L .81385 .55154 L p .983 .707 .413 r
F P
0 g
s
.81385 .55154 m .81369 .5138 L .82256 .52548 L p .983 .707 .413 r
F P
0 g
s
.52632 .86432 m .55223 .88138 L .54986 .88215 L closepath p .624 .786 .96 r
F P
0 g
s
.48418 .87096 m .4418 .87584 L .44402 .87843 L p .593 .766 .962 r
F P
0 g
s
.44402 .87843 m .48525 .87226 L .48418 .87096 L p .593 .766 .962 r
F P
0 g
s
.38095 .33289 m .38526 .30235 L .40431 .29544 L p .48 .2 .41 r
F P
0 g
s
.38526 .30235 m .38095 .33289 L .3619 .34002 L p .466 .189 .408 r
F P
0 g
s
.50155 .88177 m .52632 .86432 L .49923 .88096 L closepath p .617 .78 .959 r
F P
0 g
s
.29843 .81562 m .25864 .78946 L .25944 .79787 L p .301 .505 .889 r
F P
0 g
s
.25944 .79787 m .2987 .82275 L .29843 .81562 L p .301 .505 .889 r
F P
0 g
s
.52632 .86432 m .55449 .88054 L .55223 .88138 L closepath p .624 .787 .959 r
F P
0 g
s
.70707 .85561 m .66168 .86345 L .66278 .85911 L p .72 .862 .949 r
F P
0 g
s
.66278 .85911 m .70867 .84969 L .70707 .85561 L p .72 .862 .949 r
F P
0 g
s
.49923 .88096 m .52632 .86432 L .49702 .88008 L closepath p .617 .78 .959 r
F P
0 g
s
.82173 .74971 m .79097 .78306 L .78882 .7737 L p .921 .901 .789 r
F P
0 g
s
.78882 .7737 m .81906 .73893 L .82173 .74971 L p .921 .901 .789 r
F P
0 g
s
.43717 .86769 m .39182 .86526 L .39378 .86938 L p .552 .737 .962 r
F P
0 g
s
.39378 .86938 m .43836 .87046 L .43717 .86769 L p .552 .737 .962 r
F P
0 g
s
.52632 .86432 m .55665 .87963 L .55449 .88054 L closepath p .625 .787 .959 r
F P
0 g
s
.60977 .8773 m .56793 .87164 L .56892 .87032 L p .64 .804 .961 r
F P
0 g
s
.56892 .87032 m .61183 .87466 L .60977 .8773 L p .64 .804 .961 r
F P
0 g
s
.2811 .43757 m .28437 .40283 L .26676 .41127 L p .431 .201 .462 r
F P
0 g
s
.26676 .41127 m .26317 .44631 L .2811 .43757 L p .431 .201 .462 r
F P
0 g
s
.84177 .63715 m .83041 .67769 L .82402 .6666 L p .985 .808 .585 r
F P
0 g
s
.82402 .6666 m .83489 .62546 L .84177 .63715 L p .985 .808 .585 r
F P
0 g
s
.49702 .88008 m .52632 .86432 L .49493 .87914 L closepath p .617 .779 .959 r
F P
0 g
s
.34282 .84084 m .2987 .82275 L .29995 .82976 L p .406 .611 .933 r
F P
0 g
s
.29995 .82976 m .34351 .84653 L .34282 .84084 L p .406 .611 .933 r
F P
0 g
s
.52632 .86432 m .55868 .87865 L .55665 .87963 L closepath p .625 .787 .959 r
F P
0 g
s
.21597 .55538 m .21377 .51494 L .20101 .52687 L p .278 .142 .51 r
F P
0 g
s
.20101 .52687 m .20363 .56734 L .21597 .55538 L p .278 .142 .51 r
F P
0 g
s
.48328 .86962 m .43991 .87318 L .4418 .87584 L p .594 .765 .961 r
F P
0 g
s
.4418 .87584 m .48418 .87096 L .48328 .86962 L p .594 .765 .961 r
F P
0 g
s
.80204 .46636 m .80421 .50213 L .79391 .49048 L p .973 .673 .383 r
F P
0 g
s
.79391 .49048 m .79193 .45421 L .80204 .46636 L p .973 .673 .383 r
F P
0 g
s
.49493 .87914 m .52632 .86432 L .49296 .87813 L closepath p .617 .779 .959 r
F P
0 g
s
.21083 .67626 m .19432 .63418 L .18881 .64652 L p .157 .186 .641 r
F P
0 g
s
.18881 .64652 m .20559 .68772 L .21083 .67626 L p .157 .186 .641 r
F P
0 g
s
.33978 .38003 m .34323 .34718 L .3249 .35444 L p .471 .22 .451 r
F P
0 g
s
.3249 .35444 m .32101 .38735 L .33978 .38003 L p .471 .22 .451 r
F P
0 g
s
.52632 .86432 m .56059 .87762 L .55868 .87865 L closepath p .626 .787 .959 r
F P
0 g
s
.66003 .86773 m .61492 .86919 L .61593 .86639 L p .673 .828 .958 r
F P
0 g
s
.61593 .86639 m .66168 .86345 L .66003 .86773 L p .673 .828 .958 r
F P
0 g
s
.38952 .85682 m .34351 .84653 L .34495 .85214 L p .494 .687 .953 r
F P
0 g
s
.34495 .85214 m .3904 .86107 L .38952 .85682 L p .494 .687 .953 r
F P
0 g
s
.24431 .49317 m .24601 .45573 L .22994 .4659 L p .371 .175 .48 r
F P
0 g
s
.22994 .4659 m .22831 .50369 L .24431 .49317 L p .371 .175 .48 r
F P
0 g
s
.79204 .79247 m .75339 .81847 L .75257 .8107 L p .858 .904 .865 r
F P
0 g
s
.75257 .8107 m .79097 .78306 L .79204 .79247 L p .858 .904 .865 r
F P
0 g
s
.49296 .87813 m .52632 .86432 L .49112 .87705 L closepath p .617 .779 .959 r
F P
0 g
s
.61183 .87466 m .56892 .87032 L .56973 .86897 L p .642 .803 .96 r
F P
0 g
s
.56973 .86897 m .61355 .87196 L .61183 .87466 L p .642 .803 .96 r
F P
0 g
s
.68738 .28681 m .6945 .31598 L .67413 .30733 L p .818 .427 .312 r
F P
0 g
s
.67413 .30733 m .66771 .27849 L .68738 .28681 L p .818 .427 .312 r
F P
0 g
s
.74581 .3489 m .75116 .38228 L .73564 .37047 L p .913 .559 .354 r
F P
0 g
s
.73564 .37047 m .73038 .33704 L .74581 .3489 L p .913 .559 .354 r
F P
0 g
s
.52632 .86432 m .56236 .87652 L .56059 .87762 L closepath p .626 .787 .959 r
F P
0 g
s
.40048 .32582 m .40431 .29544 L .42396 .2887 L p .495 .21 .411 r
F P
0 g
s
.40431 .29544 m .40048 .32582 L .38095 .33289 L p .48 .2 .41 r
F P
0 g
s
.49112 .87705 m .52632 .86432 L .48942 .87593 L closepath p .617 .778 .958 r
F P
0 g
s
.77736 .40712 m .78079 .44202 L .76838 .4299 L p .954 .631 .376 r
F P
0 g
s
.76838 .4299 m .76501 .39458 L .77736 .40712 L p .954 .631 .376 r
F P
0 g
s
.75326 .8262 m .7095 .84369 L .70958 .83764 L p .789 .887 .915 r
F P
0 g
s
.70958 .83764 m .75339 .81847 L .75326 .8262 L p .789 .887 .915 r
F P
0 g
s
.43634 .86489 m .3904 .86107 L .39182 .86526 L p .557 .736 .959 r
F P
0 g
s
.39182 .86526 m .43717 .86769 L .43634 .86489 L p .557 .736 .959 r
F P
0 g
s
.48255 .86826 m .43836 .87046 L .43991 .87318 L p .595 .764 .96 r
F P
0 g
s
.43991 .87318 m .48328 .86962 L .48255 .86826 L p .595 .764 .96 r
F P
0 g
s
.52632 .86432 m .56399 .87537 L .56236 .87652 L closepath p .627 .787 .958 r
F P
0 g
s
.83122 .57435 m .82729 .61407 L .81898 .60299 L p .986 .749 .491 r
F P
0 g
s
.81898 .60299 m .82283 .56285 L .83122 .57435 L p .986 .749 .491 r
F P
0 g
s
.23072 .72733 m .20559 .68772 L .2023 .69909 L p .192 .287 .733 r
F P
0 g
s
.2023 .69909 m .22748 .73754 L .23072 .72733 L p .192 .287 .733 r
F P
0 g
s
.48942 .87593 m .52632 .86432 L .48788 .87475 L closepath p .617 .778 .958 r
F P
0 g
s
.70867 .84969 m .66278 .85911 L .66332 .85472 L p .726 .857 .943 r
F P
0 g
s
.66332 .85472 m .7095 .84369 L .70867 .84969 L p .726 .857 .943 r
F P
0 g
s
.83587 .68909 m .81527 .72831 L .81044 .71791 L p .961 .854 .689 r
F P
0 g
s
.81044 .71791 m .83041 .67769 L .83587 .68909 L p .961 .854 .689 r
F P
0 g
s
.52632 .86432 m .56546 .87417 L .56399 .87537 L closepath p .627 .787 .958 r
F P
0 g
s
.61355 .87196 m .56973 .86897 L .57037 .8676 L p .644 .802 .959 r
F P
0 g
s
.57037 .8676 m .61492 .86919 L .61355 .87196 L p .644 .802 .959 r
F P
0 g
s
.48788 .87475 m .52632 .86432 L .48648 .87353 L closepath p .617 .778 .958 r
F P
0 g
s
.66168 .86345 m .61593 .86639 L .61658 .86354 L p .677 .825 .955 r
F P
0 g
s
.61658 .86354 m .66278 .85911 L .66168 .86345 L p .677 .825 .955 r
F P
0 g
s
.52632 .86432 m .56678 .87292 L .56546 .87417 L closepath p .628 .787 .958 r
F P
0 g
s
.26086 .77212 m .22748 .73754 L .22588 .74758 L p .259 .404 .818 r
F P
0 g
s
.22588 .74758 m .25909 .78086 L .26086 .77212 L p .259 .404 .818 r
F P
0 g
s
.48201 .86688 m .43717 .86769 L .43836 .87046 L p .596 .763 .959 r
F P
0 g
s
.43836 .87046 m .48255 .86826 L .48201 .86688 L p .596 .763 .959 r
F P
0 g
s
.29954 .4294 m .30251 .3949 L .28437 .40283 L p .456 .222 .469 r
F P
0 g
s
.28437 .40283 m .2811 .43757 L .29954 .4294 L p .456 .222 .469 r
F P
0 g
s
.48648 .87353 m .52632 .86432 L .48525 .87226 L closepath p .617 .777 .958 r
F P
0 g
s
.21176 .60985 m .20363 .56734 L .1933 .57978 L p .252 .176 .572 r
F P
0 g
s
.1933 .57978 m .20202 .62191 L .21176 .60985 L p .252 .176 .572 r
F P
0 g
s
.4206 .31886 m .42396 .2887 L .44426 .28225 L p .51 .22 .409 r
F P
0 g
s
.42396 .2887 m .4206 .31886 L .40048 .32582 L p .495 .21 .411 r
F P
0 g
s
.35882 .37284 m .3619 .34002 L .34323 .34718 L p .481 .229 .455 r
F P
0 g
s
.34323 .34718 m .33978 .38003 L .35882 .37284 L p .481 .229 .455 r
F P
0 g
s
.29918 .80838 m .25909 .78086 L .25864 .78946 L p .343 .517 .884 r
F P
0 g
s
.25864 .78946 m .29843 .81562 L .29918 .80838 L p .343 .517 .884 r
F P
0 g
s
.81369 .5138 m .81385 .55154 L .80415 .54038 L p .98 .704 .428 r
F P
0 g
s
.80415 .54038 m .80421 .50213 L .81369 .5138 L p .98 .704 .428 r
F P
0 g
s
.52632 .86432 m .56793 .87164 L .56678 .87292 L closepath p .629 .787 .958 r
F P
0 g
s
.3429 .83509 m .29843 .81562 L .2987 .82275 L p .429 .614 .927 r
F P
0 g
s
.2987 .82275 m .34282 .84084 L .3429 .83509 L p .429 .614 .927 r
F P
0 g
s
.38921 .85254 m .34282 .84084 L .34351 .84653 L p .504 .686 .949 r
F P
0 g
s
.34351 .84653 m .38952 .85682 L .38921 .85254 L p .504 .686 .949 r
F P
0 g
s
.61492 .86919 m .57037 .8676 L .57083 .8662 L p .646 .801 .957 r
F P
0 g
s
.57083 .8662 m .61593 .86639 L .61492 .86919 L p .646 .801 .957 r
F P
0 g
s
.66771 .27849 m .67413 .30733 L .65234 .30028 L p .787 .403 .329 r
F P
0 g
s
.65234 .30028 m .64678 .27169 L .66771 .27849 L p .787 .403 .329 r
F P
0 g
s
.43587 .86206 m .38952 .85682 L .3904 .86107 L p .561 .734 .957 r
F P
0 g
s
.3904 .86107 m .43634 .86489 L .43587 .86206 L p .561 .734 .957 r
F P
0 g
s
.48525 .87226 m .52632 .86432 L .48418 .87096 L closepath p .617 .777 .957 r
F P
0 g
s
.81906 .73893 m .78882 .7737 L .78563 .76446 L p .919 .883 .783 r
F P
0 g
s
.78563 .76446 m .81527 .72831 L .81906 .73893 L p .919 .883 .783 r
F P
0 g
s
.52632 .86432 m .56892 .87032 L .56793 .87164 L closepath p .629 .786 .957 r
F P
0 g
s
.48164 .86548 m .43634 .86489 L .43717 .86769 L p .597 .762 .958 r
F P
0 g
s
.43717 .86769 m .48201 .86688 L .48164 .86548 L p .597 .762 .958 r
F P
0 g
s
.48418 .87096 m .52632 .86432 L .48328 .86962 L closepath p .617 .777 .957 r
F P
0 g
s
.83489 .62546 m .82402 .6666 L .81678 .65584 L p .979 .797 .588 r
F P
0 g
s
.81678 .65584 m .82729 .61407 L .83489 .62546 L p .979 .797 .588 r
F P
0 g
s
.26141 .48338 m .26317 .44631 L .24601 .45573 L p .414 .207 .488 r
F P
0 g
s
.24601 .45573 m .24431 .49317 L .26141 .48338 L p .414 .207 .488 r
F P
0 g
s
.23005 .54399 m .22831 .50369 L .21377 .51494 L p .343 .188 .521 r
F P
0 g
s
.21377 .51494 m .21597 .55538 L .23005 .54399 L p .343 .188 .521 r
F P
0 g
s
.52632 .86432 m .56973 .86897 L .56892 .87032 L closepath p .63 .786 .957 r
F P
0 g
s
.66278 .85911 m .61658 .86354 L .61686 .86068 L p .68 .823 .952 r
F P
0 g
s
.61686 .86068 m .66332 .85472 L .66278 .85911 L p .68 .823 .952 r
F P
0 g
s
.79097 .78306 m .75257 .8107 L .75081 .80296 L p .86 .889 .857 r
F P
0 g
s
.75081 .80296 m .78882 .7737 L .79097 .78306 L p .86 .889 .857 r
F P
0 g
s
.7095 .84369 m .66332 .85472 L .66329 .8503 L p .73 .851 .938 r
F P
0 g
s
.66329 .8503 m .70958 .83764 L .7095 .84369 L p .73 .851 .938 r
F P
0 g
s
.73038 .33704 m .73564 .37047 L .71834 .35942 L p .89 .538 .373 r
F P
0 g
s
.71834 .35942 m .71328 .32597 L .73038 .33704 L p .89 .538 .373 r
F P
0 g
s
.79193 .45421 m .79391 .49048 L .78258 .4789 L p .967 .668 .404 r
F P
0 g
s
.78258 .4789 m .78079 .44202 L .79193 .45421 L p .967 .668 .404 r
F P
0 g
s
.75339 .81847 m .70958 .83764 L .70889 .83157 L p .793 .876 .908 r
F P
0 g
s
.70889 .83157 m .75257 .8107 L .75339 .81847 L p .793 .876 .908 r
F P
0 g
s
.61593 .86639 m .57083 .8662 L .57111 .8648 L p .648 .8 .956 r
F P
0 g
s
.57111 .8648 m .61658 .86354 L .61593 .86639 L p .648 .8 .956 r
F P
0 g
s
.48328 .86962 m .52632 .86432 L .48255 .86826 L closepath p .618 .776 .957 r
F P
0 g
s
.44142 .31214 m .44426 .28225 L .46526 .27629 L p .529 .231 .406 r
F P
0 g
s
.44426 .28225 m .44142 .31214 L .4206 .31886 L p .51 .22 .409 r
F P
0 g
s
.52632 .86432 m .57037 .8676 L .56973 .86897 L closepath p .63 .786 .957 r
F P
0 g
s
.21798 .6648 m .20202 .62191 L .19432 .63418 L p .248 .238 .651 r
F P
0 g
s
.19432 .63418 m .21083 .67626 L .21798 .6648 L p .248 .238 .651 r
F P
0 g
s
.48255 .86826 m .52632 .86432 L .48201 .86688 L closepath p .618 .776 .957 r
F P
0 g
s
.48146 .86407 m .43587 .86206 L .43634 .86489 L p .599 .761 .956 r
F P
0 g
s
.43634 .86489 m .48164 .86548 L .48146 .86407 L p .599 .761 .956 r
F P
0 g
s
.43578 .85922 m .38921 .85254 L .38952 .85682 L p .565 .733 .954 r
F P
0 g
s
.38952 .85682 m .43587 .86206 L .43578 .85922 L p .565 .733 .954 r
F P
0 g
s
.64678 .27169 m .65234 .30028 L .62938 .29498 L p .755 .379 .343 r
F P
0 g
s
.62938 .29498 m .62481 .26657 L .64678 .27169 L p .755 .379 .343 r
F P
0 g
s
.76501 .39458 m .76838 .4299 L .75445 .41804 L p .939 .617 .397 r
F P
0 g
s
.75445 .41804 m .75116 .38228 L .76501 .39458 L p .939 .617 .397 r
F P
0 g
s
.35882 .37284 m .3619 .34002 L .38095 .33289 L p .49 .237 .458 r
F P
0 g
s
.52632 .86432 m .57083 .8662 L .57037 .8676 L closepath p .63 .786 .956 r
F P
0 g
s
.31833 .42166 m .32101 .38735 L .30251 .3949 L p .474 .237 .474 r
F P
0 g
s
.30251 .3949 m .29954 .4294 L .31833 .42166 L p .474 .237 .474 r
F P
0 g
s
.82283 .56285 m .81898 .60299 L .80994 .5922 L p .982 .744 .501 r
F P
0 g
s
.80994 .5922 m .81385 .55154 L .82283 .56285 L p .982 .744 .501 r
F P
0 g
s
.38947 .84823 m .3429 .83509 L .34282 .84084 L p .515 .685 .944 r
F P
0 g
s
.34282 .84084 m .38921 .85254 L .38947 .84823 L p .515 .685 .944 r
F P
0 g
s
.48201 .86688 m .52632 .86432 L .48164 .86548 L closepath p .618 .776 .956 r
F P
0 g
s
.61658 .86354 m .57111 .8648 L .5712 .86338 L p .649 .799 .955 r
F P
0 g
s
.5712 .86338 m .61686 .86068 L .61658 .86354 L p .649 .799 .955 r
F P
0 g
s
.83041 .67769 m .81044 .71791 L .80464 .70778 L p .956 .839 .687 r
F P
0 g
s
.80464 .70778 m .82402 .6666 L .83041 .67769 L p .956 .839 .687 r
F P
0 g
s
.46304 .30588 m .46526 .27629 L .48698 .27102 L p .549 .244 .402 r
F P
0 g
s
.46526 .27629 m .46304 .30588 L .44142 .31214 L p .529 .231 .406 r
F P
0 g
s
.52632 .86432 m .57111 .8648 L .57083 .8662 L closepath p .631 .786 .956 r
F P
0 g
s
.66332 .85472 m .61686 .86068 L .61676 .8578 L p .683 .82 .949 r
F P
0 g
s
.61676 .8578 m .66329 .8503 L .66332 .85472 L p .683 .82 .949 r
F P
0 g
s
.23561 .71702 m .21083 .67626 L .20559 .68772 L p .27 .324 .735 r
F P
0 g
s
.20559 .68772 m .23072 .72733 L .23561 .71702 L p .27 .324 .735 r
F P
0 g
s
.34378 .82929 m .29918 .80838 L .29843 .81562 L p .451 .616 .92 r
F P
0 g
s
.29843 .81562 m .3429 .83509 L .34378 .82929 L p .451 .616 .92 r
F P
0 g
s
.48164 .86548 m .52632 .86432 L .48146 .86407 L closepath p .618 .776 .956 r
F P
0 g
s
.48146 .86266 m .43578 .85922 L .43587 .86206 L p .6 .76 .955 r
F P
0 g
s
.43587 .86206 m .48146 .86407 L .48146 .86266 L p .6 .76 .955 r
F P
0 g
s
.52632 .86432 m .5712 .86338 L .57111 .8648 L closepath p .631 .785 .956 r
F P
0 g
s
.30097 .80106 m .26086 .77212 L .25909 .78086 L p .381 .527 .877 r
F P
0 g
s
.25909 .78086 m .29918 .80838 L .30097 .80106 L p .381 .527 .877 r
F P
0 g
s
.26396 .76325 m .23072 .72733 L .22748 .73754 L p .317 .425 .814 r
F P
0 g
s
.22748 .73754 m .26086 .77212 L .26396 .76325 L p .317 .425 .814 r
F P
0 g
s
.62481 .26657 m .62938 .29498 L .60557 .29155 L p .722 .356 .356 r
F P
0 g
s
.60557 .29155 m .60208 .26321 L .62481 .26657 L p .722 .356 .356 r
F P
0 g
s
.70958 .83764 m .66329 .8503 L .6627 .84587 L p .734 .845 .933 r
F P
0 g
s
.6627 .84587 m .70889 .83157 L .70958 .83764 L p .734 .845 .933 r
F P
0 g
s
.48146 .86407 m .52632 .86432 L .48146 .86266 L closepath p .619 .775 .956 r
F P
0 g
s
.61686 .86068 m .5712 .86338 L .57111 .86197 L p .65 .798 .954 r
F P
0 g
s
.57111 .86197 m .61676 .8578 L .61686 .86068 L p .65 .798 .954 r
F P
0 g
s
.22339 .59815 m .21597 .55538 L .20363 .56734 L p .323 .22 .58 r
F P
0 g
s
.20363 .56734 m .21176 .60985 L .22339 .59815 L p .323 .22 .58 r
F P
0 g
s
.43606 .85637 m .38947 .84823 L .38921 .85254 L p .57 .732 .951 r
F P
0 g
s
.38921 .85254 m .43578 .85922 L .43606 .85637 L p .57 .732 .951 r
F P
0 g
s
.48546 .30029 m .48698 .27102 L .50935 .26668 L p .573 .258 .397 r
F P
0 g
s
.48698 .27102 m .48546 .30029 L .46304 .30588 L p .549 .244 .402 r
F P
0 g
s
.27931 .47428 m .2811 .43757 L .26317 .44631 L p .444 .23 .492 r
F P
0 g
s
.26317 .44631 m .26141 .48338 L .27931 .47428 L p .444 .23 .492 r
F P
0 g
s
.48202 .85984 m .52632 .86432 L .48257 .85845 L closepath p .62 .775 .955 r
F P
0 g
s
.48165 .86124 m .52632 .86432 L .48202 .85984 L closepath p .619 .775 .955 r
F P
0 g
s
.48146 .86266 m .52632 .86432 L .48165 .86124 L closepath p .619 .775 .955 r
F P
0 g
s
.52632 .86432 m .57111 .86197 L .5712 .86338 L closepath p .631 .785 .955 r
F P
0 g
s
.52632 .86432 m .57083 .86056 L .57111 .86197 L closepath p .632 .785 .955 r
F P
0 g
s
.52632 .86432 m .57037 .85916 L .57083 .86056 L closepath p .632 .785 .955 r
F P
0 g
s
.52632 .86432 m .56973 .85777 L .57037 .85916 L closepath p .632 .784 .955 r
F P
0 g
s
.52632 .86432 m .56891 .85641 L .56973 .85777 L closepath p .632 .784 .954 r
F P
0 g
s
.52632 .86432 m .56791 .85507 L .56891 .85641 L closepath p .633 .784 .954 r
F P
0 g
s
.52632 .86432 m .56673 .85377 L .56791 .85507 L closepath p .633 .783 .954 r
F P
0 g
s
.52632 .86432 m .56539 .85251 L .56673 .85377 L closepath p .633 .783 .953 r
F P
0 g
s
.52632 .86432 m .56388 .85129 L .56539 .85251 L closepath p .633 .783 .953 r
F P
0 g
s
.52632 .86432 m .56221 .85013 L .56388 .85129 L closepath p .633 .782 .953 r
F P
0 g
s
.52632 .86432 m .56039 .84901 L .56221 .85013 L closepath p .633 .782 .953 r
F P
0 g
s
.52632 .86432 m .55843 .84796 L .56039 .84901 L closepath p .633 .782 .953 r
F P
0 g
s
.52632 .86432 m .55633 .84697 L .55843 .84796 L closepath p .633 .781 .952 r
F P
0 g
s
.52632 .86432 m .5541 .84605 L .55633 .84697 L closepath p .633 .781 .952 r
F P
0 g
s
.52632 .86432 m .55175 .8452 L .5541 .84605 L closepath p .633 .78 .952 r
F P
0 g
s
.52632 .86432 m .5493 .84443 L .55175 .8452 L closepath p .633 .78 .952 r
F P
0 g
s
.52632 .86432 m .54674 .84374 L .5493 .84443 L closepath p .632 .78 .952 r
F P
0 g
s
.52632 .86432 m .5441 .84312 L .54674 .84374 L closepath p .632 .779 .952 r
F P
0 g
s
.52632 .86432 m .54139 .8426 L .5441 .84312 L closepath p .632 .779 .951 r
F P
0 g
s
.52632 .86432 m .5386 .84216 L .54139 .8426 L closepath p .632 .778 .951 r
F P
0 g
s
.52632 .86432 m .53577 .84181 L .5386 .84216 L closepath p .631 .778 .951 r
F P
0 g
s
.52632 .86432 m .53289 .84156 L .53577 .84181 L closepath p .631 .777 .951 r
F P
0 g
s
.52632 .86432 m .52999 .84139 L .53289 .84156 L closepath p .631 .777 .951 r
F P
0 g
s
.52632 .86432 m .52707 .84132 L .52999 .84139 L closepath p .63 .777 .951 r
F P
0 g
s
.52632 .86432 m .52415 .84134 L .52707 .84132 L closepath p .63 .776 .951 r
F P
0 g
s
.52632 .86432 m .52123 .84146 L .52415 .84134 L closepath p .629 .776 .951 r
F P
0 g
s
.52632 .86432 m .51834 .84167 L .52123 .84146 L closepath p .629 .776 .951 r
F P
0 g
s
.52632 .86432 m .51549 .84197 L .51834 .84167 L closepath p .628 .775 .951 r
F P
0 g
s
.52632 .86432 m .51268 .84236 L .51549 .84197 L closepath p .628 .775 .951 r
F P
0 g
s
.52632 .86432 m .50992 .84284 L .51268 .84236 L closepath p .628 .775 .951 r
F P
0 g
s
.52632 .86432 m .50724 .8434 L .50992 .84284 L closepath p .627 .775 .951 r
F P
0 g
s
.52632 .86432 m .50464 .84406 L .50724 .8434 L closepath p .627 .775 .952 r
F P
0 g
s
.49324 .84846 m .52632 .86432 L .49528 .84744 L closepath p .624 .774 .952 r
F P
0 g
s
.49135 .84955 m .52632 .86432 L .49324 .84846 L closepath p .624 .774 .953 r
F P
0 g
s
.4896 .85069 m .52632 .86432 L .49135 .84955 L closepath p .623 .774 .953 r
F P
0 g
s
.48801 .85189 m .52632 .86432 L .4896 .85069 L closepath p .623 .774 .953 r
F P
0 g
s
.48658 .85313 m .52632 .86432 L .48801 .85189 L closepath p .622 .774 .953 r
F P
0 g
s
.48531 .85441 m .52632 .86432 L .48658 .85313 L closepath p .622 .774 .954 r
F P
0 g
s
.48422 .85573 m .52632 .86432 L .48531 .85441 L closepath p .621 .774 .954 r
F P
0 g
s
.48331 .85707 m .52632 .86432 L .48422 .85573 L closepath p .621 .774 .954 r
F P
0 g
s
.48257 .85845 m .52632 .86432 L .48331 .85707 L closepath p .62 .775 .954 r
F P
0 g
s
.50214 .84479 m .52632 .86432 L .50464 .84406 L closepath p .626 .775 .952 r
F P
0 g
s
.49973 .8456 m .52632 .86432 L .50214 .84479 L closepath p .626 .774 .952 r
F P
0 g
s
.49744 .84649 m .52632 .86432 L .49973 .8456 L closepath p .625 .774 .952 r
F P
0 g
s
.49528 .84744 m .52632 .86432 L .49744 .84649 L closepath p .625 .774 .952 r
F P
0 g
s
.80421 .50213 m .80415 .54038 L .79359 .52937 L p .975 .701 .446 r
F P
0 g
s
.79359 .52937 m .79391 .49048 L .80421 .50213 L p .975 .701 .446 r
F P
0 g
s
.81527 .72831 m .78563 .76446 L .78143 .75538 L p .915 .867 .777 r
F P
0 g
s
.78143 .75538 m .81044 .71791 L .81527 .72831 L p .915 .867 .777 r
F P
0 g
s
.37819 .36572 m .38095 .33289 L .40048 .32582 L p .501 .245 .459 r
F P
0 g
s
.38095 .33289 m .37819 .36572 L .35882 .37284 L p .49 .237 .458 r
F P
0 g
s
.75257 .8107 m .70889 .83157 L .70744 .82551 L p .796 .866 .901 r
F P
0 g
s
.70744 .82551 m .75081 .80296 L .75257 .8107 L p .796 .866 .901 r
F P
0 g
s
.43578 .85922 m .48146 .86266 L .48165 .86124 L p .602 .76 .954 r
F P
0 g
s
.71328 .32597 m .71834 .35942 L .69923 .34942 L p .863 .514 .39 r
F P
0 g
s
.69923 .34942 m .6945 .31598 L .71328 .32597 L p .863 .514 .39 r
F P
0 g
s
.48165 .86124 m .43606 .85637 L .43578 .85922 L p .602 .76 .954 r
F P
0 g
s
.78882 .7737 m .75081 .80296 L .74813 .7953 L p .86 .875 .849 r
F P
0 g
s
.74813 .7953 m .78563 .76446 L .78882 .7737 L p .86 .875 .849 r
F P
0 g
s
.24558 .53324 m .24431 .49317 L .22831 .50369 L p .392 .221 .526 r
F P
0 g
s
.22831 .50369 m .23005 .54399 L .24558 .53324 L p .392 .221 .526 r
F P
0 g
s
.61676 .8578 m .57111 .86197 L .57083 .86056 L p .651 .797 .952 r
F P
0 g
s
.60208 .26321 m .60557 .29155 L .58126 .29001 L p .689 .334 .367 r
F P
0 g
s
.58126 .29001 m .57888 .26164 L .60208 .26321 L p .689 .334 .367 r
F P
0 g
s
.66329 .8503 m .61676 .8578 L .61629 .85493 L p .685 .817 .946 r
F P
0 g
s
.61629 .85493 m .6627 .84587 L .66329 .8503 L p .685 .817 .946 r
F P
0 g
s
.82729 .61407 m .81678 .65584 L .8087 .64542 L p .973 .787 .592 r
F P
0 g
s
.8087 .64542 m .81898 .60299 L .82729 .61407 L p .973 .787 .592 r
F P
0 g
s
.33736 .41425 m .33978 .38003 L .32101 .38735 L p .485 .247 .477 r
F P
0 g
s
.32101 .38735 m .31833 .42166 L .33736 .41425 L p .485 .247 .477 r
F P
0 g
s
.50866 .29566 m .50935 .26668 L .53225 .26353 L p .599 .275 .392 r
F P
0 g
s
.50935 .26668 m .50866 .29566 L .48546 .30029 L p .573 .258 .397 r
F P
0 g
s
.43606 .85637 m .48165 .86124 L .48202 .85984 L p .604 .759 .953 r
F P
0 g
s
.57083 .86056 m .61629 .85493 L .61676 .8578 L p .651 .797 .952 r
F P
0 g
s
.3903 .84391 m .34378 .82929 L .3429 .83509 L p .525 .685 .939 r
F P
0 g
s
.3429 .83509 m .38947 .84823 L .3903 .84391 L p .525 .685 .939 r
F P
0 g
s
.61629 .85493 m .57083 .86056 L .57037 .85916 L p .652 .796 .951 r
F P
0 g
s
.57888 .26164 m .58126 .29001 L .5568 .29029 L p .658 .313 .377 r
F P
0 g
s
.5568 .29029 m .55551 .26179 L .57888 .26164 L p .658 .313 .377 r
F P
0 g
s
.78079 .44202 m .78258 .4789 L .76995 .46746 L p .957 .658 .426 r
F P
0 g
s
.76995 .46746 m .76838 .4299 L .78079 .44202 L p .957 .658 .426 r
F P
0 g
s
.5325 .29224 m .53225 .26353 L .55551 .26179 L p .628 .293 .385 r
F P
0 g
s
.53225 .26353 m .5325 .29224 L .50866 .29566 L p .599 .275 .392 r
F P
0 g
s
.55551 .26179 m .5568 .29029 L .5325 .29224 L p .628 .293 .385 r
F P
0 g
s
.43671 .85352 m .48202 .85984 L .48257 .85845 L p .605 .758 .952 r
F P
0 g
s
.48202 .85984 m .43671 .85352 L .43606 .85637 L p .604 .759 .953 r
F P
0 g
s
.38947 .84823 m .43606 .85637 L .43671 .85352 L p .574 .731 .949 r
F P
0 g
s
.43671 .85352 m .3903 .84391 L .38947 .84823 L p .574 .731 .949 r
F P
0 g
s
.75116 .38228 m .75445 .41804 L .7388 .40665 L p .92 .599 .417 r
F P
0 g
s
.7388 .40665 m .73564 .37047 L .75116 .38228 L p .92 .599 .417 r
F P
0 g
s
.57037 .85916 m .61545 .85207 L .61629 .85493 L p .652 .796 .951 r
F P
0 g
s
.61545 .85207 m .57037 .85916 L .56973 .85777 L p .653 .795 .95 r
F P
0 g
s
.22697 .65349 m .21176 .60985 L .20202 .62191 L p .318 .276 .653 r
F P
0 g
s
.20202 .62191 m .21798 .6648 L .22697 .65349 L p .318 .276 .653 r
F P
0 g
s
.70889 .83157 m .6627 .84587 L .66154 .84146 L p .736 .839 .928 r
F P
0 g
s
.66154 .84146 m .70744 .82551 L .70889 .83157 L p .736 .839 .928 r
F P
0 g
s
.43774 .8507 m .48257 .85845 L .48331 .85707 L p .607 .758 .951 r
F P
0 g
s
.48257 .85845 m .43774 .8507 L .43671 .85352 L p .605 .758 .952 r
F P
0 g
s
.6627 .84587 m .61629 .85493 L .61545 .85207 L p .687 .815 .944 r
F P
0 g
s
.34545 .82347 m .30097 .80106 L .29918 .80838 L p .471 .618 .913 r
F P
0 g
s
.29918 .80838 m .34378 .82929 L .34545 .82347 L p .471 .618 .913 r
F P
0 g
s
.39801 .35867 m .40048 .32582 L .4206 .31886 L p .512 .254 .46 r
F P
0 g
s
.40048 .32582 m .39801 .35867 L .37819 .36572 L p .501 .245 .459 r
F P
0 g
s
.56973 .85777 m .61423 .84924 L .61545 .85207 L p .653 .795 .95 r
F P
0 g
s
.61423 .84924 m .56973 .85777 L .56891 .85641 L p .654 .794 .949 r
F P
0 g
s
.81385 .55154 m .80994 .5922 L .80008 .58167 L p .976 .738 .513 r
F P
0 g
s
.80008 .58167 m .80415 .54038 L .81385 .55154 L p .976 .738 .513 r
F P
0 g
s
.61545 .85207 m .66154 .84146 L .6627 .84587 L p .687 .815 .944 r
F P
0 g
s
.82402 .6666 m .80464 .70778 L .79789 .69796 L p .95 .826 .687 r
F P
0 g
s
.79789 .69796 m .81678 .65584 L .82402 .6666 L p .95 .826 .687 r
F P
0 g
s
.43914 .8479 m .48331 .85707 L .48422 .85573 L p .609 .757 .95 r
F P
0 g
s
.48331 .85707 m .43914 .8479 L .43774 .8507 L p .607 .758 .951 r
F P
0 g
s
.29777 .46579 m .29954 .4294 L .2811 .43757 L p .467 .246 .495 r
F P
0 g
s
.2811 .43757 m .27931 .47428 L .29777 .46579 L p .467 .246 .495 r
F P
0 g
s
.3903 .84391 m .43671 .85352 L .43774 .8507 L p .579 .73 .946 r
F P
0 g
s
.56891 .85641 m .61265 .84645 L .61423 .84924 L p .654 .794 .949 r
F P
0 g
s
.61265 .84645 m .56891 .85641 L .56791 .85507 L p .654 .793 .948 r
F P
0 g
s
.30383 .79368 m .26396 .76325 L .26086 .77212 L p .415 .535 .869 r
F P
0 g
s
.26086 .77212 m .30097 .80106 L .30383 .79368 L p .415 .535 .869 r
F P
0 g
s
.6945 .31598 m .69923 .34942 L .67841 .34075 L p .833 .49 .404 r
F P
0 g
s
.67841 .34075 m .67413 .30733 L .6945 .31598 L p .833 .49 .404 r
F P
0 g
s
.24212 .70671 m .21798 .6648 L .21083 .67626 L p .332 .353 .732 r
F P
0 g
s
.21083 .67626 m .23561 .71702 L .24212 .70671 L p .332 .353 .732 r
F P
0 g
s
.35665 .40705 m .35882 .37284 L .33978 .38003 L p .494 .254 .479 r
F P
0 g
s
.33978 .38003 m .33736 .41425 L .35665 .40705 L p .494 .254 .479 r
F P
0 g
s
.75081 .80296 m .70744 .82551 L .70524 .81952 L p .797 .857 .894 r
F P
0 g
s
.70524 .81952 m .74813 .7953 L .75081 .80296 L p .797 .857 .894 r
F P
0 g
s
.44091 .84514 m .48422 .85573 L .48531 .85441 L p .611 .757 .948 r
F P
0 g
s
.48422 .85573 m .44091 .84514 L .43914 .8479 L p .609 .757 .95 r
F P
0 g
s
.66154 .84146 m .61545 .85207 L .61423 .84924 L p .689 .812 .941 r
F P
0 g
s
.39171 .8396 m .34545 .82347 L .34378 .82929 L p .535 .684 .934 r
F P
0 g
s
.34378 .82929 m .3903 .84391 L .39171 .8396 L p .535 .684 .934 r
F P
0 g
s
.26841 .75434 m .23561 .71702 L .23072 .72733 L p .366 .443 .808 r
F P
0 g
s
.23072 .72733 m .26396 .76325 L .26841 .75434 L p .366 .443 .808 r
F P
0 g
s
.56791 .85507 m .6107 .84372 L .61265 .84645 L p .654 .793 .948 r
F P
0 g
s
.6107 .84372 m .56791 .85507 L .56673 .85377 L p .655 .791 .947 r
F P
0 g
s
.43774 .8507 m .39171 .8396 L .3903 .84391 L p .579 .73 .946 r
F P
0 g
s
.23668 .5869 m .23005 .54399 L .21597 .55538 L p .376 .252 .582 r
F P
0 g
s
.21597 .55538 m .22339 .59815 L .23668 .5869 L p .376 .252 .582 r
F P
0 g
s
.81044 .71791 m .78143 .75538 L .77627 .74653 L p .911 .852 .772 r
F P
0 g
s
.77627 .74653 m .80464 .70778 L .81044 .71791 L p .911 .852 .772 r
F P
0 g
s
.44305 .84244 m .48531 .85441 L .48658 .85313 L p .612 .757 .947 r
F P
0 g
s
.48531 .85441 m .44305 .84244 L .44091 .84514 L p .611 .757 .948 r
F P
0 g
s
.26224 .52317 m .26141 .48338 L .24431 .49317 L p .429 .245 .528 r
F P
0 g
s
.24431 .49317 m .24558 .53324 L .26224 .52317 L p .429 .245 .528 r
F P
0 g
s
.78563 .76446 m .74813 .7953 L .74456 .78777 L p .858 .863 .842 r
F P
0 g
s
.74456 .78777 m .78143 .75538 L .78563 .76446 L p .858 .863 .842 r
F P
0 g
s
.39171 .8396 m .43774 .8507 L .43914 .8479 L p .583 .729 .943 r
F P
0 g
s
.56673 .85377 m .6084 .84105 L .6107 .84372 L p .655 .791 .947 r
F P
0 g
s
.6084 .84105 m .56673 .85377 L .56539 .85251 L p .655 .79 .947 r
F P
0 g
s
.79391 .49048 m .79359 .52937 L .78194 .51854 L p .966 .694 .466 r
F P
0 g
s
.78194 .51854 m .78258 .4789 L .79391 .49048 L p .966 .694 .466 r
F P
0 g
s
.41843 .35174 m .4206 .31886 L .44142 .31214 L p .526 .263 .459 r
F P
0 g
s
.4206 .31886 m .41843 .35174 L .39801 .35867 L p .512 .254 .46 r
F P
0 g
s
.44554 .8398 m .48658 .85313 L .48801 .85189 L p .614 .757 .946 r
F P
0 g
s
.48658 .85313 m .44554 .8398 L .44305 .84244 L p .612 .757 .947 r
F P
0 g
s
.70744 .82551 m .66154 .84146 L .65981 .8371 L p .738 .834 .924 r
F P
0 g
s
.61423 .84924 m .65981 .8371 L .66154 .84146 L p .689 .812 .941 r
F P
0 g
s
.65981 .8371 m .70524 .81952 L .70744 .82551 L p .738 .834 .924 r
F P
0 g
s
.65981 .8371 m .61423 .84924 L .61265 .84645 L p .69 .809 .939 r
F P
0 g
s
.56539 .85251 m .60574 .83846 L .6084 .84105 L p .655 .79 .947 r
F P
0 g
s
.60574 .83846 m .56539 .85251 L .56388 .85129 L p .655 .789 .946 r
F P
0 g
s
.81898 .60299 m .8087 .64542 L .79976 .63535 L p .966 .779 .598 r
F P
0 g
s
.79976 .63535 m .80994 .5922 L .81898 .60299 L p .966 .779 .598 r
F P
0 g
s
.44838 .83724 m .48801 .85189 L .4896 .85069 L p .616 .756 .945 r
F P
0 g
s
.48801 .85189 m .44838 .83724 L .44554 .8398 L p .614 .757 .946 r
F P
0 g
s
.56388 .85129 m .60274 .83596 L .60574 .83846 L p .655 .789 .946 r
F P
0 g
s
.60274 .83596 m .56388 .85129 L .56221 .85013 L p .655 .788 .945 r
F P
0 g
s
.3937 .83532 m .43914 .8479 L .44091 .84514 L p .588 .728 .941 r
F P
0 g
s
.43914 .8479 m .3937 .83532 L .39171 .8396 L p .583 .729 .943 r
F P
0 g
s
.34793 .81764 m .30383 .79368 L .30097 .80106 L p .489 .619 .906 r
F P
0 g
s
.30097 .80106 m .34545 .82347 L .34793 .81764 L p .489 .619 .906 r
F P
0 g
s
.76838 .4299 m .76995 .46746 L .7558 .45632 L p .941 .644 .449 r
F P
0 g
s
.7558 .45632 m .75445 .41804 L .76838 .4299 L p .941 .644 .449 r
F P
0 g
s
.73564 .37047 m .7388 .40665 L .72132 .39598 L p .896 .577 .435 r
F P
0 g
s
.72132 .39598 m .71834 .35942 L .73564 .37047 L p .896 .577 .435 r
F P
0 g
s
.31662 .45782 m .31833 .42166 L .29954 .4294 L p .482 .258 .496 r
F P
0 g
s
.29954 .4294 m .29777 .46579 L .31662 .45782 L p .482 .258 .496 r
F P
0 g
s
.34545 .82347 m .39171 .8396 L .3937 .83532 L p .545 .683 .929 r
F P
0 g
s
.45155 .83478 m .4896 .85069 L .49135 .84955 L p .618 .756 .944 r
F P
0 g
s
.4896 .85069 m .45155 .83478 L .44838 .83724 L p .616 .756 .945 r
F P
0 g
s
.35665 .40705 m .35882 .37284 L .37819 .36572 L p .501 .26 .481 r
F P
0 g
s
.67413 .30733 m .67841 .34075 L .65605 .33365 L p .802 .464 .417 r
F P
0 g
s
.65605 .33365 m .65234 .30028 L .67413 .30733 L p .802 .464 .417 r
F P
0 g
s
.56221 .85013 m .59941 .83356 L .60274 .83596 L p .655 .788 .945 r
F P
0 g
s
.59941 .83356 m .56221 .85013 L .56039 .84901 L p .655 .786 .944 r
F P
0 g
s
.61265 .84645 m .65752 .83279 L .65981 .8371 L p .69 .809 .939 r
F P
0 g
s
.65752 .83279 m .61265 .84645 L .6107 .84372 L p .691 .806 .937 r
F P
0 g
s
.45505 .83241 m .49135 .84955 L .49324 .84846 L p .62 .756 .943 r
F P
0 g
s
.49135 .84955 m .45505 .83241 L .45155 .83478 L p .618 .756 .944 r
F P
0 g
s
.3937 .83532 m .34793 .81764 L .34545 .82347 L p .545 .683 .929 r
F P
0 g
s
.23764 .64242 m .22339 .59815 L .21176 .60985 L p .372 .305 .651 r
F P
0 g
s
.21176 .60985 m .22697 .65349 L .23764 .64242 L p .372 .305 .651 r
F P
0 g
s
.43958 .34507 m .44142 .31214 L .46304 .30588 L p .543 .275 .459 r
F P
0 g
s
.44142 .31214 m .43958 .34507 L .41843 .35174 L p .526 .263 .459 r
F P
0 g
s
.56039 .84901 m .59577 .83128 L .59941 .83356 L p .655 .786 .944 r
F P
0 g
s
.59577 .83128 m .56039 .84901 L .55843 .84796 L p .655 .785 .944 r
F P
0 g
s
.74813 .7953 m .70524 .81952 L .70229 .81361 L p .798 .848 .889 r
F P
0 g
s
.70229 .81361 m .74456 .78777 L .74813 .7953 L p .798 .848 .889 r
F P
0 g
s
.70524 .81952 m .65981 .8371 L .65752 .83279 L p .74 .829 .92 r
F P
0 g
s
.45886 .83016 m .49324 .84846 L .49528 .84744 L p .622 .756 .943 r
F P
0 g
s
.49324 .84846 m .45886 .83016 L .45505 .83241 L p .62 .756 .943 r
F P
0 g
s
.39627 .83107 m .44091 .84514 L .44305 .84244 L p .592 .727 .938 r
F P
0 g
s
.44091 .84514 m .39627 .83107 L .3937 .83532 L p .588 .728 .941 r
F P
0 g
s
.81678 .65584 m .79789 .69796 L .79022 .68848 L p .943 .814 .687 r
F P
0 g
s
.79022 .68848 m .8087 .64542 L .81678 .65584 L p .943 .814 .687 r
F P
0 g
s
.55843 .84796 m .59182 .82911 L .59577 .83128 L p .655 .785 .944 r
F P
0 g
s
.59182 .82911 m .55843 .84796 L .55633 .84697 L p .654 .783 .943 r
F P
0 g
s
.80415 .54038 m .80008 .58167 L .78927 .57142 L p .968 .731 .527 r
F P
0 g
s
.78927 .57142 m .79359 .52937 L .80415 .54038 L p .968 .731 .527 r
F P
0 g
s
.30775 .7863 m .26841 .75434 L .26396 .76325 L p .444 .541 .861 r
F P
0 g
s
.26396 .76325 m .30383 .79368 L .30775 .7863 L p .444 .541 .861 r
F P
0 g
s
.46297 .82803 m .49528 .84744 L .49744 .84649 L p .623 .756 .942 r
F P
0 g
s
.49528 .84744 m .46297 .82803 L .45886 .83016 L p .622 .756 .943 r
F P
0 g
s
.65752 .83279 m .70229 .81361 L .70524 .81952 L p .74 .829 .92 r
F P
0 g
s
.27977 .51378 m .27931 .47428 L .26141 .48338 L p .457 .263 .528 r
F P
0 g
s
.26141 .48338 m .26224 .52317 L .27977 .51378 L p .457 .263 .528 r
F P
0 g
s
.6107 .84372 m .65468 .82857 L .65752 .83279 L p .691 .806 .937 r
F P
0 g
s
.65468 .82857 m .6107 .84372 L .6084 .84105 L p .691 .804 .935 r
F P
0 g
s
.55633 .84697 m .58758 .82707 L .59182 .82911 L p .654 .783 .943 r
F P
0 g
s
.58758 .82707 m .55633 .84697 L .5541 .84605 L p .654 .782 .942 r
F P
0 g
s
.46735 .82604 m .49744 .84649 L .49973 .8456 L p .625 .757 .941 r
F P
0 g
s
.49744 .84649 m .46735 .82604 L .46297 .82803 L p .623 .756 .942 r
F P
0 g
s
.34793 .81764 m .3937 .83532 L .39627 .83107 L p .554 .682 .924 r
F P
0 g
s
.25137 .5762 m .24558 .53324 L .23005 .54399 L p .418 .277 .581 r
F P
0 g
s
.23005 .54399 m .23668 .5869 L .25137 .5762 L p .418 .277 .581 r
F P
0 g
s
.2502 .69649 m .22697 .65349 L .21798 .6648 L p .382 .375 .727 r
F P
0 g
s
.21798 .6648 m .24212 .70671 L .2502 .69649 L p .382 .375 .727 r
F P
0 g
s
.78143 .75538 m .74456 .78777 L .7401 .78041 L p .856 .851 .837 r
F P
0 g
s
.7401 .78041 m .77627 .74653 L .78143 .75538 L p .856 .851 .837 r
F P
0 g
s
.5541 .84605 m .58308 .82518 L .58758 .82707 L p .654 .782 .942 r
F P
0 g
s
.58308 .82518 m .5541 .84605 L .55175 .8452 L p .653 .78 .941 r
F P
0 g
s
.80464 .70778 m .77627 .74653 L .77017 .73794 L p .906 .84 .769 r
F P
0 g
s
.77017 .73794 m .79789 .69796 L .80464 .70778 L p .906 .84 .769 r
F P
0 g
s
.27419 .74543 m .24212 .70671 L .23561 .71702 L p .407 .456 .799 r
F P
0 g
s
.23561 .71702 m .26841 .75434 L .27419 .74543 L p .407 .456 .799 r
F P
0 g
s
.3994 .82689 m .44305 .84244 L .44554 .8398 L p .596 .727 .935 r
F P
0 g
s
.44305 .84244 m .3994 .82689 L .39627 .83107 L p .592 .727 .938 r
F P
0 g
s
.47199 .8242 m .49973 .8456 L .50214 .84479 L p .627 .757 .94 r
F P
0 g
s
.49973 .8456 m .47199 .8242 L .46735 .82604 L p .625 .757 .941 r
F P
0 g
s
.46158 .33884 m .46304 .30588 L .48546 .30029 L p .564 .289 .458 r
F P
0 g
s
.46304 .30588 m .46158 .33884 L .43958 .34507 L p .543 .275 .459 r
F P
0 g
s
.65234 .30028 m .65605 .33365 L .63243 .3283 L p .769 .439 .427 r
F P
0 g
s
.63243 .3283 m .62938 .29498 L .65234 .30028 L p .769 .439 .427 r
F P
0 g
s
.37625 .40002 m .37819 .36572 L .39801 .35867 L p .509 .267 .482 r
F P
0 g
s
.37819 .36572 m .37625 .40002 L .35665 .40705 L p .501 .26 .481 r
F P
0 g
s
.55175 .8452 m .57832 .82343 L .58308 .82518 L p .653 .78 .941 r
F P
0 g
s
.57832 .82343 m .55175 .8452 L .5493 .84443 L p .653 .779 .941 r
F P
0 g
s
.33576 .45029 m .33736 .41425 L .31833 .42166 L p .494 .266 .497 r
F P
0 g
s
.31833 .42166 m .31662 .45782 L .33576 .45029 L p .494 .266 .497 r
F P
0 g
s
.47687 .82251 m .50214 .84479 L .50464 .84406 L p .629 .758 .94 r
F P
0 g
s
.50214 .84479 m .47687 .82251 L .47199 .8242 L p .627 .757 .94 r
F P
0 g
s
.70229 .81361 m .65752 .83279 L .65468 .82857 L p .74 .824 .916 r
F P
0 g
s
.6084 .84105 m .65129 .82446 L .65468 .82857 L p .691 .804 .935 r
F P
0 g
s
.65129 .82446 m .6084 .84105 L .60574 .83846 L p .691 .801 .933 r
F P
0 g
s
.5493 .84443 m .57333 .82183 L .57832 .82343 L p .653 .779 .941 r
F P
0 g
s
.57333 .82183 m .5493 .84443 L .54674 .84374 L p .652 .777 .94 r
F P
0 g
s
.50464 .84406 m .48197 .82099 L .47687 .82251 L p .629 .758 .94 r
F P
0 g
s
.48727 .81963 m .50724 .8434 L .50464 .84406 L p .631 .758 .939 r
F P
0 g
s
.50464 .84406 m .48197 .82099 L .48727 .81963 L p .631 .758 .939 r
F P
0 g
s
.78258 .4789 m .78194 .51854 L .76901 .50795 L p .954 .683 .486 r
F P
0 g
s
.76901 .50795 m .76995 .46746 L .78258 .4789 L p .954 .683 .486 r
F P
0 g
s
.35122 .81184 m .30775 .7863 L .30383 .79368 L p .506 .62 .899 r
F P
0 g
s
.30383 .79368 m .34793 .81764 L .35122 .81184 L p .506 .62 .899 r
F P
0 g
s
.54674 .84374 m .56813 .8204 L .57333 .82183 L p .652 .777 .94 r
F P
0 g
s
.56813 .8204 m .54674 .84374 L .5441 .84312 L p .651 .775 .94 r
F P
0 g
s
.39627 .83107 m .35122 .81184 L .34793 .81764 L p .554 .682 .924 r
F P
0 g
s
.49275 .81846 m .50992 .84284 L .50724 .8434 L p .632 .759 .939 r
F P
0 g
s
.50724 .8434 m .48727 .81963 L .49275 .81846 L p .632 .759 .939 r
F P
0 g
s
.40309 .8228 m .44554 .8398 L .44838 .83724 L p .6 .726 .933 r
F P
0 g
s
.44554 .8398 m .40309 .8228 L .3994 .82689 L p .596 .727 .935 r
F P
0 g
s
.5441 .84312 m .56274 .81914 L .56813 .8204 L p .651 .775 .94 r
F P
0 g
s
.56274 .81914 m .5441 .84312 L .54139 .8426 L p .65 .774 .939 r
F P
0 g
s
.71834 .35942 m .72132 .39598 L .70198 .3863 L p .869 .554 .451 r
F P
0 g
s
.70198 .3863 m .69923 .34942 L .71834 .35942 L p .869 .554 .451 r
F P
0 g
s
.49837 .81746 m .51268 .84236 L .50992 .84284 L p .634 .759 .938 r
F P
0 g
s
.50992 .84284 m .49275 .81846 L .49837 .81746 L p .634 .759 .938 r
F P
0 g
s
.80994 .5922 m .79976 .63535 L .7899 .62562 L p .958 .769 .606 r
F P
0 g
s
.7899 .62562 m .80008 .58167 L .80994 .5922 L p .958 .769 .606 r
F P
0 g
s
.54139 .8426 m .55719 .81805 L .56274 .81914 L p .65 .774 .939 r
F P
0 g
s
.55719 .81805 m .54139 .8426 L .5386 .84216 L p .648 .772 .939 r
F P
0 g
s
.50412 .81666 m .51549 .84197 L .51268 .84236 L p .635 .76 .938 r
F P
0 g
s
.51268 .84236 m .49837 .81746 L .50412 .81666 L p .635 .76 .938 r
F P
0 g
s
.35122 .81184 m .39627 .83107 L .3994 .82689 L p .562 .682 .92 r
F P
0 g
s
.48446 .3333 m .48546 .30029 L .50866 .29566 L p .588 .306 .456 r
F P
0 g
s
.48546 .30029 m .48446 .3333 L .46158 .33884 L p .564 .289 .458 r
F P
0 g
s
.5386 .84216 m .5515 .81713 L .55719 .81805 L p .648 .772 .939 r
F P
0 g
s
.5515 .81713 m .5386 .84216 L .53577 .84181 L p .647 .77 .938 r
F P
0 g
s
.74456 .78777 m .70229 .81361 L .69861 .80783 L p .797 .84 .884 r
F P
0 g
s
.69861 .80783 m .7401 .78041 L .74456 .78777 L p .797 .84 .884 r
F P
0 g
s
.50997 .81604 m .51834 .84167 L .51549 .84197 L p .637 .761 .938 r
F P
0 g
s
.51549 .84197 m .50412 .81666 L .50997 .81604 L p .637 .761 .938 r
F P
0 g
s
.60574 .83846 m .64736 .82046 L .65129 .82446 L p .691 .801 .933 r
F P
0 g
s
.64736 .82046 m .60574 .83846 L .60274 .83596 L p .691 .798 .931 r
F P
0 g
s
.53577 .84181 m .54569 .81641 L .5515 .81713 L p .647 .77 .938 r
F P
0 g
s
.54569 .81641 m .53577 .84181 L .53289 .84156 L p .646 .769 .938 r
F P
0 g
s
.5159 .81562 m .52123 .84146 L .51834 .84167 L p .638 .762 .938 r
F P
0 g
s
.51834 .84167 m .50997 .81604 L .5159 .81562 L p .638 .762 .938 r
F P
0 g
s
.65468 .82857 m .69861 .80783 L .70229 .81361 L p .74 .824 .916 r
F P
0 g
s
.75445 .41804 m .7558 .45632 L .73995 .44563 L p .921 .627 .469 r
F P
0 g
s
.73995 .44563 m .7388 .40665 L .75445 .41804 L p .921 .627 .469 r
F P
0 g
s
.62938 .29498 m .63243 .3283 L .60791 .32481 L p .737 .414 .435 r
F P
0 g
s
.60791 .32481 m .60557 .29155 L .62938 .29498 L p .737 .414 .435 r
F P
0 g
s
.53289 .84156 m .5398 .81586 L .54569 .81641 L p .646 .769 .938 r
F P
0 g
s
.5398 .81586 m .53289 .84156 L .52999 .84139 L p .644 .767 .938 r
F P
0 g
s
.52187 .81539 m .52415 .84134 L .52123 .84146 L p .64 .763 .938 r
F P
0 g
s
.52123 .84146 m .5159 .81562 L .52187 .81539 L p .64 .763 .938 r
F P
0 g
s
.52999 .84139 m .53385 .81551 L .5398 .81586 L p .644 .767 .938 r
F P
0 g
s
.53385 .81551 m .52999 .84139 L .52707 .84132 L p .643 .766 .938 r
F P
0 g
s
.52786 .81535 m .52707 .84132 L .52415 .84134 L p .641 .764 .938 r
F P
0 g
s
.52415 .84134 m .52187 .81539 L .52786 .81535 L p .641 .764 .938 r
F P
0 g
s
.52707 .84132 m .52786 .81535 L .53385 .81551 L p .643 .766 .938 r
F P
0 g
s
.40733 .81881 m .44838 .83724 L .45155 .83478 L p .604 .726 .93 r
F P
0 g
s
.44838 .83724 m .40733 .81881 L .40309 .8228 L p .6 .726 .933 r
F P
0 g
s
.29793 .50504 m .29777 .46579 L .27931 .47428 L p .477 .276 .528 r
F P
0 g
s
.27931 .47428 m .27977 .51378 L .29793 .50504 L p .477 .276 .528 r
F P
0 g
s
.69861 .80783 m .65468 .82857 L .65129 .82446 L p .74 .819 .913 r
F P
0 g
s
.24984 .63171 m .23668 .5869 L .22339 .59815 L p .414 .327 .648 r
F P
0 g
s
.22339 .59815 m .23764 .64242 L .24984 .63171 L p .414 .327 .648 r
F P
0 g
s
.39631 .39314 m .39801 .35867 L .41843 .35174 L p .52 .275 .484 r
F P
0 g
s
.39801 .35867 m .39631 .39314 L .37625 .40002 L p .509 .267 .482 r
F P
0 g
s
.5082 .3287 m .50866 .29566 L .5325 .29224 L p .614 .324 .454 r
F P
0 g
s
.50866 .29566 m .5082 .3287 L .48446 .3333 L p .588 .306 .456 r
F P
0 g
s
.60274 .83596 m .6429 .81661 L .64736 .82046 L p .691 .798 .931 r
F P
0 g
s
.6429 .81661 m .60274 .83596 L .59941 .83356 L p .691 .796 .93 r
F P
0 g
s
.31272 .77895 m .27419 .74543 L .26841 .75434 L p .47 .546 .852 r
F P
0 g
s
.26841 .75434 m .30775 .7863 L .31272 .77895 L p .47 .546 .852 r
F P
0 g
s
.35519 .4431 m .35665 .40705 L .33736 .41425 L p .502 .272 .498 r
F P
0 g
s
.33736 .41425 m .33576 .45029 L .35519 .4431 L p .502 .272 .498 r
F P
0 g
s
.60557 .29155 m .60791 .32481 L .58285 .32321 L p .704 .39 .442 r
F P
0 g
s
.58285 .32321 m .58126 .29001 L .60557 .29155 L p .704 .39 .442 r
F P
0 g
s
.8087 .64542 m .79022 .68848 L .78162 .67936 L p .936 .803 .689 r
F P
0 g
s
.78162 .67936 m .79976 .63535 L .8087 .64542 L p .936 .803 .689 r
F P
0 g
s
.26721 .56611 m .26224 .52317 L .24558 .53324 L p .449 .295 .579 r
F P
0 g
s
.24558 .53324 m .25137 .5762 L .26721 .56611 L p .449 .295 .579 r
F P
0 g
s
.77627 .74653 m .7401 .78041 L .73478 .77326 L p .853 .84 .832 r
F P
0 g
s
.73478 .77326 m .77017 .73794 L .77627 .74653 L p .853 .84 .832 r
F P
0 g
s
.4121 .81496 m .45155 .83478 L .45505 .83241 L p .608 .725 .928 r
F P
0 g
s
.45155 .83478 m .4121 .81496 L .40733 .81881 L p .604 .726 .93 r
F P
0 g
s
.3553 .8061 m .3994 .82689 L .40309 .8228 L p .571 .681 .915 r
F P
0 g
s
.3994 .82689 m .3553 .8061 L .35122 .81184 L p .562 .682 .92 r
F P
0 g
s
.30775 .7863 m .35122 .81184 L .3553 .8061 L p .522 .621 .891 r
F P
0 g
s
.79359 .52937 m .78927 .57142 L .77735 .56145 L p .957 .722 .542 r
F P
0 g
s
.77735 .56145 m .78194 .51854 L .79359 .52937 L p .957 .722 .542 r
F P
0 g
s
.53267 .32533 m .5325 .29224 L .5568 .29029 L p .643 .345 .451 r
F P
0 g
s
.5325 .29224 m .53267 .32533 L .5082 .3287 L p .614 .324 .454 r
F P
0 g
s
.58126 .29001 m .58285 .32321 L .55765 .32343 L p .673 .367 .447 r
F P
0 g
s
.55765 .32343 m .5568 .29029 L .58126 .29001 L p .673 .367 .447 r
F P
0 g
s
.79789 .69796 m .77017 .73794 L .76313 .72966 L p .9 .828 .766 r
F P
0 g
s
.76313 .72966 m .79022 .68848 L .79789 .69796 L p .9 .828 .766 r
F P
0 g
s
.25974 .68646 m .23764 .64242 L .22697 .65349 L p .422 .392 .72 r
F P
0 g
s
.22697 .65349 m .2502 .69649 L .25974 .68646 L p .422 .392 .72 r
F P
0 g
s
.5568 .29029 m .55765 .32343 L .53267 .32533 L p .643 .345 .451 r
F P
0 g
s
.59941 .83356 m .63794 .81292 L .6429 .81661 L p .691 .796 .93 r
F P
0 g
s
.63794 .81292 m .59941 .83356 L .59577 .83128 L p .69 .793 .928 r
F P
0 g
s
.28126 .7366 m .2502 .69649 L .24212 .70671 L p .441 .467 .791 r
F P
0 g
s
.24212 .70671 m .27419 .74543 L .28126 .7366 L p .441 .467 .791 r
F P
0 g
s
.3553 .8061 m .31272 .77895 L .30775 .7863 L p .522 .621 .891 r
F P
0 g
s
.65129 .82446 m .6942 .8022 L .69861 .80783 L p .74 .819 .913 r
F P
0 g
s
.6942 .8022 m .65129 .82446 L .64736 .82046 L p .74 .814 .91 r
F P
0 g
s
.7401 .78041 m .69861 .80783 L .6942 .8022 L p .796 .832 .879 r
F P
0 g
s
.41737 .81125 m .45505 .83241 L .45886 .83016 L p .612 .725 .926 r
F P
0 g
s
.45505 .83241 m .41737 .81125 L .4121 .81496 L p .608 .725 .928 r
F P
0 g
s
.69923 .34942 m .70198 .3863 L .68087 .37786 L p .839 .529 .464 r
F P
0 g
s
.68087 .37786 m .67841 .34075 L .69923 .34942 L p .839 .529 .464 r
F P
0 g
s
.41697 .38646 m .41843 .35174 L .43958 .34507 L p .533 .285 .486 r
F P
0 g
s
.41843 .35174 m .41697 .38646 L .39631 .39314 L p .52 .275 .484 r
F P
0 g
s
.6942 .8022 m .73478 .77326 L .7401 .78041 L p .796 .832 .879 r
F P
0 g
s
.59577 .83128 m .63248 .8094 L .63794 .81292 L p .69 .793 .928 r
F P
0 g
s
.63248 .8094 m .59577 .83128 L .59182 .82911 L p .689 .79 .927 r
F P
0 g
s
.31657 .49689 m .31662 .45782 L .29777 .46579 L p .493 .285 .526 r
F P
0 g
s
.29777 .46579 m .29793 .50504 L .31657 .49689 L p .493 .285 .526 r
F P
0 g
s
.76995 .46746 m .76901 .50795 L .75458 .49769 L p .937 .669 .506 r
F P
0 g
s
.75458 .49769 m .7558 .45632 L .76995 .46746 L p .937 .669 .506 r
F P
0 g
s
.36017 .80045 m .40309 .8228 L .40733 .81881 L p .578 .681 .91 r
F P
0 g
s
.40309 .8228 m .36017 .80045 L .3553 .8061 L p .571 .681 .915 r
F P
0 g
s
.35519 .4431 m .35665 .40705 L .37625 .40002 L p .509 .278 .499 r
F P
0 g
s
.42313 .80772 m .45886 .83016 L .46297 .82803 L p .616 .725 .924 r
F P
0 g
s
.45886 .83016 m .42313 .80772 L .41737 .81125 L p .612 .725 .926 r
F P
0 g
s
.80008 .58167 m .7899 .62562 L .77903 .61624 L p .948 .759 .614 r
F P
0 g
s
.77903 .61624 m .78927 .57142 L .80008 .58167 L p .948 .759 .614 r
F P
0 g
s
.7388 .40665 m .73995 .44563 L .72229 .43563 L p .897 .606 .486 r
F P
0 g
s
.72229 .43563 m .72132 .39598 L .7388 .40665 L p .897 .606 .486 r
F P
0 g
s
.59182 .82911 m .62654 .80607 L .63248 .8094 L p .689 .79 .927 r
F P
0 g
s
.62654 .80607 m .59182 .82911 L .58758 .82707 L p .688 .786 .925 r
F P
0 g
s
.31272 .77895 m .3553 .8061 L .36017 .80045 L p .536 .622 .884 r
F P
0 g
s
.64736 .82046 m .68908 .79675 L .6942 .8022 L p .74 .814 .91 r
F P
0 g
s
.68908 .79675 m .64736 .82046 L .6429 .81661 L p .739 .809 .907 r
F P
0 g
s
.26338 .62146 m .25137 .5762 L .23668 .5869 L p .448 .343 .643 r
F P
0 g
s
.23668 .5869 m .24984 .63171 L .26338 .62146 L p .448 .343 .643 r
F P
0 g
s
.42935 .80438 m .46297 .82803 L .46735 .82604 L p .62 .726 .922 r
F P
0 g
s
.46297 .82803 m .42935 .80438 L .42313 .80772 L p .616 .725 .924 r
F P
0 g
s
.28399 .55667 m .27977 .51378 L .26224 .52317 L p .474 .309 .576 r
F P
0 g
s
.26224 .52317 m .26721 .56611 L .28399 .55667 L p .474 .309 .576 r
F P
0 g
s
.31871 .77168 m .28126 .7366 L .27419 .74543 L p .492 .55 .843 r
F P
0 g
s
.27419 .74543 m .31272 .77895 L .31871 .77168 L p .492 .55 .843 r
F P
0 g
s
.73478 .77326 m .6942 .8022 L .68908 .79675 L p .794 .825 .876 r
F P
0 g
s
.77017 .73794 m .73478 .77326 L .72861 .76634 L p .849 .83 .828 r
F P
0 g
s
.72861 .76634 m .76313 .72966 L .77017 .73794 L p .849 .83 .828 r
F P
0 g
s
.43837 .38011 m .43958 .34507 L .46158 .33884 L p .55 .299 .487 r
F P
0 g
s
.43958 .34507 m .43837 .38011 L .41697 .38646 L p .533 .285 .486 r
F P
0 g
s
.58758 .82707 m .62015 .80294 L .62654 .80607 L p .688 .786 .925 r
F P
0 g
s
.62015 .80294 m .58758 .82707 L .58308 .82518 L p .686 .783 .924 r
F P
0 g
s
.36579 .79492 m .40733 .81881 L .4121 .81496 L p .586 .68 .906 r
F P
0 g
s
.40733 .81881 m .36579 .79492 L .36017 .80045 L p .578 .681 .91 r
F P
0 g
s
.36017 .80045 m .31871 .77168 L .31272 .77895 L p .536 .622 .884 r
F P
0 g
s
.79976 .63535 m .78162 .67936 L .77206 .67061 L p .927 .792 .691 r
F P
0 g
s
.77206 .67061 m .7899 .62562 L .79976 .63535 L p .927 .792 .691 r
F P
0 g
s
.43601 .80125 m .46735 .82604 L .47199 .8242 L p .624 .726 .92 r
F P
0 g
s
.46735 .82604 m .43601 .80125 L .42935 .80438 L p .62 .726 .922 r
F P
0 g
s
.67841 .34075 m .68087 .37786 L .65817 .3709 L p .808 .503 .474 r
F P
0 g
s
.65817 .3709 m .65605 .33365 L .67841 .34075 L p .808 .503 .474 r
F P
0 g
s
.79022 .68848 m .76313 .72966 L .75517 .7217 L p .894 .816 .764 r
F P
0 g
s
.75517 .7217 m .78162 .67936 L .79022 .68848 L p .894 .816 .764 r
F P
0 g
s
.6429 .81661 m .68325 .7915 L .68908 .79675 L p .739 .809 .907 r
F P
0 g
s
.68325 .7915 m .6429 .81661 L .63794 .81292 L p .737 .804 .905 r
F P
0 g
s
.58308 .82518 m .61333 .80002 L .62015 .80294 L p .686 .783 .924 r
F P
0 g
s
.61333 .80002 m .58308 .82518 L .57832 .82343 L p .685 .779 .923 r
F P
0 g
s
.27065 .67671 m .24984 .63171 L .23764 .64242 L p .455 .405 .713 r
F P
0 g
s
.23764 .64242 m .25974 .68646 L .27065 .67671 L p .455 .405 .713 r
F P
0 g
s
.68908 .79675 m .72861 .76634 L .73478 .77326 L p .794 .825 .876 r
F P
0 g
s
.3356 .48928 m .33576 .45029 L .31662 .45782 L p .504 .293 .525 r
F P
0 g
s
.31662 .45782 m .31657 .49689 L .3356 .48928 L p .504 .293 .525 r
F P
0 g
s
.28957 .72792 m .25974 .68646 L .2502 .69649 L p .469 .475 .782 r
F P
0 g
s
.2502 .69649 m .28126 .7366 L .28957 .72792 L p .469 .475 .782 r
F P
0 g
s
.37497 .43622 m .37625 .40002 L .39631 .39314 L p .517 .284 .5 r
F P
0 g
s
.37625 .40002 m .37497 .43622 L .35519 .4431 L p .509 .278 .499 r
F P
0 g
s
.78194 .51854 m .77735 .56145 L .76416 .5518 L p .942 .709 .557 r
F P
0 g
s
.76416 .5518 m .76901 .50795 L .78194 .51854 L p .942 .709 .557 r
F P
0 g
s
.44307 .79835 m .47199 .8242 L .47687 .82251 L p .628 .727 .919 r
F P
0 g
s
.47199 .8242 m .44307 .79835 L .43601 .80125 L p .624 .726 .92 r
F P
0 g
s
.31871 .77168 m .36017 .80045 L .36579 .79492 L p .549 .622 .877 r
F P
0 g
s
.57832 .82343 m .60611 .79732 L .61333 .80002 L p .685 .779 .923 r
F P
0 g
s
.60611 .79732 m .57832 .82343 L .57333 .82183 L p .683 .776 .921 r
F P
0 g
s
.37215 .78955 m .4121 .81496 L .41737 .81125 L p .593 .68 .902 r
F P
0 g
s
.4121 .81496 m .37215 .78955 L .36579 .79492 L p .586 .68 .906 r
F P
0 g
s
.46065 .37425 m .46158 .33884 L .48446 .3333 L p .571 .315 .489 r
F P
0 g
s
.46158 .33884 m .46065 .37425 L .43837 .38011 L p .55 .299 .487 r
F P
0 g
s
.45051 .7957 m .47687 .82251 L .48197 .82099 L p .631 .728 .917 r
F P
0 g
s
.47687 .82251 m .45051 .7957 L .44307 .79835 L p .628 .727 .919 r
F P
0 g
s
.72861 .76634 m .68908 .79675 L .68325 .7915 L p .792 .817 .872 r
F P
0 g
s
.57333 .82183 m .59851 .79486 L .60611 .79732 L p .683 .776 .921 r
F P
0 g
s
.59851 .79486 m .57333 .82183 L .56813 .8204 L p .68 .772 .92 r
F P
0 g
s
.63794 .81292 m .67674 .78647 L .68325 .7915 L p .737 .804 .905 r
F P
0 g
s
.67674 .78647 m .63794 .81292 L .63248 .8094 L p .736 .799 .902 r
F P
0 g
s
.3015 .54787 m .29793 .50504 L .27977 .51378 L p .493 .319 .573 r
F P
0 g
s
.27977 .51378 m .28399 .55667 L .3015 .54787 L p .493 .319 .573 r
F P
0 g
s
.7558 .45632 m .75458 .49769 L .73852 .48791 L p .916 .652 .523 r
F P
0 g
s
.73852 .48791 m .73995 .44563 L .7558 .45632 L p .916 .652 .523 r
F P
0 g
s
.48197 .82099 m .45829 .79332 L .45051 .7957 L p .631 .728 .917 r
F P
0 g
s
.46639 .7912 m .48727 .81963 L .48197 .82099 L p .635 .729 .916 r
F P
0 g
s
.48197 .82099 m .45829 .79332 L .46639 .7912 L p .635 .729 .916 r
F P
0 g
s
.72132 .39598 m .72229 .43563 L .70279 .42652 L p .869 .583 .5 r
F P
0 g
s
.70279 .42652 m .70198 .3863 L .72132 .39598 L p .869 .583 .5 r
F P
0 g
s
.27806 .61174 m .26721 .56611 L .25137 .5762 L p .475 .356 .638 r
F P
0 g
s
.25137 .5762 m .26338 .62146 L .27806 .61174 L p .475 .356 .638 r
F P
0 g
s
.65605 .33365 m .65817 .3709 L .63418 .36559 L p .776 .477 .481 r
F P
0 g
s
.63418 .36559 m .63243 .3283 L .65605 .33365 L p .776 .477 .481 r
F P
0 g
s
.56813 .8204 m .59057 .79264 L .59851 .79486 L p .68 .772 .92 r
F P
0 g
s
.59057 .79264 m .56813 .8204 L .56274 .81914 L p .678 .768 .919 r
F P
0 g
s
.3257 .76456 m .28957 .72792 L .28126 .7366 L p .512 .553 .834 r
F P
0 g
s
.28126 .7366 m .31871 .77168 L .3257 .76456 L p .512 .553 .834 r
F P
0 g
s
.78927 .57142 m .77903 .61624 L .76706 .60722 L p .936 .747 .623 r
F P
0 g
s
.76706 .60722 m .77735 .56145 L .78927 .57142 L p .936 .747 .623 r
F P
0 g
s
.36579 .79492 m .3257 .76456 L .31871 .77168 L p .549 .622 .877 r
F P
0 g
s
.47476 .78937 m .49275 .81846 L .48727 .81963 L p .638 .73 .915 r
F P
0 g
s
.48727 .81963 m .46639 .7912 L .47476 .78937 L p .638 .73 .915 r
F P
0 g
s
.37921 .78439 m .41737 .81125 L .42313 .80772 L p .6 .68 .898 r
F P
0 g
s
.41737 .81125 m .37921 .78439 L .37215 .78955 L p .593 .68 .902 r
F P
0 g
s
.39522 .42963 m .39631 .39314 L .41697 .38646 L p .527 .293 .503 r
F P
0 g
s
.39631 .39314 m .39522 .42963 L .37497 .43622 L p .517 .284 .5 r
F P
0 g
s
.76313 .72966 m .72861 .76634 L .72159 .7597 L p .845 .82 .825 r
F P
0 g
s
.72159 .7597 m .75517 .7217 L .76313 .72966 L p .845 .82 .825 r
F P
0 g
s
.35501 .48216 m .35519 .4431 L .33576 .45029 L p .514 .299 .525 r
F P
0 g
s
.33576 .45029 m .3356 .48928 L .35501 .48216 L p .514 .299 .525 r
F P
0 g
s
.48384 .36909 m .48446 .3333 L .5082 .3287 L p .595 .334 .491 r
F P
0 g
s
.48446 .3333 m .48384 .36909 L .46065 .37425 L p .571 .315 .489 r
F P
0 g
s
.56274 .81914 m .58232 .79068 L .59057 .79264 L p .678 .768 .919 r
F P
0 g
s
.58232 .79068 m .56274 .81914 L .55719 .81805 L p .675 .764 .918 r
F P
0 g
s
.48338 .78784 m .49837 .81746 L .49275 .81846 L p .64 .732 .915 r
F P
0 g
s
.49275 .81846 m .47476 .78937 L .48338 .78784 L p .64 .732 .915 r
F P
0 g
s
.3257 .76456 m .36579 .79492 L .37215 .78955 L p .561 .623 .871 r
F P
0 g
s
.68325 .7915 m .72159 .7597 L .72861 .76634 L p .792 .817 .872 r
F P
0 g
s
.55719 .81805 m .57381 .78898 L .58232 .79068 L p .675 .764 .918 r
F P
0 g
s
.57381 .78898 m .55719 .81805 L .5515 .81713 L p .672 .76 .917 r
F P
0 g
s
.63248 .8094 m .66956 .78168 L .67674 .78647 L p .736 .799 .902 r
F P
0 g
s
.66956 .78168 m .63248 .8094 L .62654 .80607 L p .733 .793 .9 r
F P
0 g
s
.4922 .7866 m .50412 .81666 L .49837 .81746 L p .643 .733 .914 r
F P
0 g
s
.49837 .81746 m .48338 .78784 L .4922 .7866 L p .643 .733 .914 r
F P
0 g
s
.5515 .81713 m .56507 .78755 L .57381 .78898 L p .672 .76 .917 r
F P
0 g
s
.56507 .78755 m .5515 .81713 L .54569 .81641 L p .669 .756 .916 r
F P
0 g
s
.7899 .62562 m .77206 .67061 L .76149 .66223 L p .917 .78 .694 r
F P
0 g
s
.76149 .66223 m .77903 .61624 L .7899 .62562 L p .917 .78 .694 r
F P
0 g
s
.28278 .66733 m .26338 .62146 L .24984 .63171 L p .481 .415 .706 r
F P
0 g
s
.24984 .63171 m .27065 .67671 L .28278 .66733 L p .481 .415 .706 r
F P
0 g
s
.63243 .3283 m .63418 .36559 L .60924 .36205 L p .744 .451 .486 r
F P
0 g
s
.60924 .36205 m .60791 .32481 L .63243 .3283 L p .744 .451 .486 r
F P
0 g
s
.29903 .71947 m .27065 .67671 L .25974 .68646 L p .494 .482 .773 r
F P
0 g
s
.25974 .68646 m .28957 .72792 L .29903 .71947 L p .494 .482 .773 r
F P
0 g
s
.50118 .78566 m .50997 .81604 L .50412 .81666 L p .646 .735 .914 r
F P
0 g
s
.50412 .81666 m .4922 .7866 L .50118 .78566 L p .646 .735 .914 r
F P
0 g
s
.78162 .67936 m .75517 .7217 L .74627 .71408 L p .886 .805 .763 r
F P
0 g
s
.74627 .71408 m .77206 .67061 L .78162 .67936 L p .886 .805 .763 r
F P
0 g
s
.72159 .7597 m .68325 .7915 L .67674 .78647 L p .789 .81 .869 r
F P
0 g
s
.54569 .81641 m .55614 .7864 L .56507 .78755 L p .669 .756 .916 r
F P
0 g
s
.55614 .7864 m .54569 .81641 L .5398 .81586 L p .666 .753 .915 r
F P
0 g
s
.38693 .77946 m .42313 .80772 L .42935 .80438 L p .606 .68 .894 r
F P
0 g
s
.42313 .80772 m .38693 .77946 L .37921 .78439 L p .6 .68 .898 r
F P
0 g
s
.51028 .78503 m .5159 .81562 L .50997 .81604 L p .65 .738 .914 r
F P
0 g
s
.50997 .81604 m .50118 .78566 L .51028 .78503 L p .65 .738 .914 r
F P
0 g
s
.50793 .36488 m .5082 .3287 L .53267 .32533 L p .622 .355 .492 r
F P
0 g
s
.5082 .3287 m .50793 .36488 L .48384 .36909 L p .595 .334 .491 r
F P
0 g
s
.5398 .81586 m .54707 .78553 L .55614 .7864 L p .666 .753 .915 r
F P
0 g
s
.54707 .78553 m .5398 .81586 L .53385 .81551 L p .663 .749 .915 r
F P
0 g
s
.51947 .7847 m .52187 .81539 L .5159 .81562 L p .653 .74 .914 r
F P
0 g
s
.5159 .81562 m .51028 .78503 L .51947 .7847 L p .653 .74 .914 r
F P
0 g
s
.53385 .81551 m .53791 .78496 L .54707 .78553 L p .663 .749 .915 r
F P
0 g
s
.53791 .78496 m .53385 .81551 L .52786 .81535 L p .659 .746 .914 r
F P
0 g
s
.52869 .78468 m .52786 .81535 L .52187 .81539 L p .656 .743 .914 r
F P
0 g
s
.52187 .81539 m .51947 .7847 L .52869 .78468 L p .656 .743 .914 r
F P
0 g
s
.52786 .81535 m .52869 .78468 L .53791 .78496 L p .659 .746 .914 r
F P
0 g
s
.31961 .53972 m .31657 .49689 L .29793 .50504 L p .509 .327 .57 r
F P
0 g
s
.29793 .50504 m .3015 .54787 L .31961 .53972 L p .509 .327 .57 r
F P
0 g
s
.76901 .50795 m .76416 .5518 L .74956 .54254 L p .924 .694 .571 r
F P
0 g
s
.74956 .54254 m .75458 .49769 L .76901 .50795 L p .924 .694 .571 r
F P
0 g
s
.62654 .80607 m .66172 .77715 L .66956 .78168 L p .733 .793 .9 r
F P
0 g
s
.66172 .77715 m .62654 .80607 L .62015 .80294 L p .731 .788 .898 r
F P
0 g
s
.41609 .42338 m .41697 .38646 L .43837 .38011 L p .541 .305 .506 r
F P
0 g
s
.41697 .38646 m .41609 .42338 L .39522 .42963 L p .527 .293 .503 r
F P
0 g
s
.60791 .32481 m .60924 .36205 L .58377 .36029 L p .712 .426 .49 r
F P
0 g
s
.58377 .36029 m .58285 .32321 L .60791 .32481 L p .712 .426 .49 r
F P
0 g
s
.53277 .36187 m .53267 .32533 L .55765 .32343 L p .651 .377 .492 r
F P
0 g
s
.53267 .32533 m .53277 .36187 L .50793 .36488 L p .622 .355 .492 r
F P
0 g
s
.29372 .6026 m .28399 .55667 L .26721 .56611 L p .497 .366 .633 r
F P
0 g
s
.26721 .56611 m .27806 .61174 L .29372 .6026 L p .497 .366 .633 r
F P
0 g
s
.35501 .48216 m .35519 .4431 L .37497 .43622 L p .523 .305 .526 r
F P
0 g
s
.33363 .75762 m .37215 .78955 L .37921 .78439 L p .572 .623 .865 r
F P
0 g
s
.37215 .78955 m .33363 .75762 L .3257 .76456 L p .561 .623 .871 r
F P
0 g
s
.28957 .72792 m .3257 .76456 L .33363 .75762 L p .53 .556 .826 r
F P
0 g
s
.70198 .3863 m .70279 .42652 L .68153 .41854 L p .84 .558 .511 r
F P
0 g
s
.68153 .41854 m .68087 .37786 L .70198 .3863 L p .84 .558 .511 r
F P
0 g
s
.39529 .77479 m .42935 .80438 L .43601 .80125 L p .613 .681 .891 r
F P
0 g
s
.42935 .80438 m .39529 .77479 L .38693 .77946 L p .606 .68 .894 r
F P
0 g
s
.58285 .32321 m .58377 .36029 L .55815 .36027 L p .681 .401 .492 r
F P
0 g
s
.55815 .36027 m .55765 .32343 L .58285 .32321 L p .681 .401 .492 r
F P
0 g
s
.55765 .32343 m .55815 .36027 L .53277 .36187 L p .651 .377 .492 r
F P
0 g
s
.33363 .75762 m .29903 .71947 L .28957 .72792 L p .53 .556 .826 r
F P
0 g
s
.73995 .44563 m .73852 .48791 L .72073 .47875 L p .891 .631 .537 r
F P
0 g
s
.72073 .47875 m .72229 .43563 L .73995 .44563 L p .891 .631 .537 r
F P
0 g
s
.75517 .7217 m .72159 .7597 L .71373 .75334 L p .84 .811 .822 r
F P
0 g
s
.67674 .78647 m .71373 .75334 L .72159 .7597 L p .789 .81 .869 r
F P
0 g
s
.71373 .75334 m .74627 .71408 L .75517 .7217 L p .84 .811 .822 r
F P
0 g
s
.71373 .75334 m .67674 .78647 L .66956 .78168 L p .785 .802 .866 r
F P
0 g
s
.62015 .80294 m .65325 .7729 L .66172 .77715 L p .731 .788 .898 r
F P
0 g
s
.65325 .7729 m .62015 .80294 L .61333 .80002 L p .727 .782 .896 r
F P
0 g
s
.77735 .56145 m .76706 .60722 L .75388 .59858 L p .921 .733 .631 r
F P
0 g
s
.75388 .59858 m .76416 .5518 L .77735 .56145 L p .921 .733 .631 r
F P
0 g
s
.40424 .77043 m .43601 .80125 L .44307 .79835 L p .619 .682 .888 r
F P
0 g
s
.43601 .80125 m .40424 .77043 L .39529 .77479 L p .613 .681 .891 r
F P
0 g
s
.43771 .41756 m .43837 .38011 L .46065 .37425 L p .559 .32 .51 r
F P
0 g
s
.43837 .38011 m .43771 .41756 L .41609 .42338 L p .541 .305 .506 r
F P
0 g
s
.296 .6584 m .27806 .61174 L .26338 .62146 L p .504 .424 .699 r
F P
0 g
s
.26338 .62146 m .28278 .66733 L .296 .6584 L p .504 .424 .699 r
F P
0 g
s
.33822 .5322 m .3356 .48928 L .31657 .49689 L p .521 .335 .568 r
F P
0 g
s
.31657 .49689 m .31961 .53972 L .33822 .5322 L p .521 .335 .568 r
F P
0 g
s
.30957 .71133 m .28278 .66733 L .27065 .67671 L p .514 .488 .765 r
F P
0 g
s
.27065 .67671 m .29903 .71947 L .30957 .71133 L p .514 .488 .765 r
F P
0 g
s
.34246 .75094 m .37921 .78439 L .38693 .77946 L p .582 .624 .859 r
F P
0 g
s
.37921 .78439 m .34246 .75094 L .33363 .75762 L p .572 .623 .865 r
F P
0 g
s
.61333 .80002 m .64416 .76892 L .65325 .7729 L p .727 .782 .896 r
F P
0 g
s
.64416 .76892 m .61333 .80002 L .60611 .79732 L p .724 .775 .894 r
F P
0 g
s
.77206 .67061 m .74627 .71408 L .73642 .70682 L p .878 .793 .763 r
F P
0 g
s
.73642 .70682 m .76149 .66223 L .77206 .67061 L p .878 .793 .763 r
F P
0 g
s
.37485 .4755 m .37497 .43622 L .39522 .42963 L p .531 .312 .527 r
F P
0 g
s
.37497 .43622 m .37485 .4755 L .35501 .48216 L p .523 .305 .526 r
F P
0 g
s
.77903 .61624 m .76149 .66223 L .74985 .65424 L p .906 .767 .697 r
F P
0 g
s
.74985 .65424 m .76706 .60722 L .77903 .61624 L p .906 .767 .697 r
F P
0 g
s
.29903 .71947 m .33363 .75762 L .34246 .75094 L p .545 .558 .819 r
F P
0 g
s
.41375 .76639 m .44307 .79835 L .45051 .7957 L p .625 .683 .885 r
F P
0 g
s
.44307 .79835 m .41375 .76639 L .40424 .77043 L p .619 .682 .888 r
F P
0 g
s
.31019 .59409 m .3015 .54787 L .28399 .55667 L p .515 .375 .629 r
F P
0 g
s
.28399 .55667 m .29372 .6026 L .31019 .59409 L p .515 .375 .629 r
F P
0 g
s
.68087 .37786 m .68153 .41854 L .65872 .41188 L p .81 .532 .519 r
F P
0 g
s
.65872 .41188 m .65817 .3709 L .68087 .37786 L p .81 .532 .519 r
F P
0 g
s
.66956 .78168 m .70504 .74729 L .71373 .75334 L p .785 .802 .866 r
F P
0 g
s
.70504 .74729 m .66956 .78168 L .66172 .77715 L p .781 .794 .863 r
F P
0 g
s
.34246 .75094 m .30957 .71133 L .29903 .71947 L p .545 .558 .819 r
F P
0 g
s
.60611 .79732 m .63451 .76525 L .64416 .76892 L p .724 .775 .894 r
F P
0 g
s
.63451 .76525 m .60611 .79732 L .59851 .79486 L p .719 .769 .892 r
F P
0 g
s
.75458 .49769 m .74956 .54254 L .73343 .53376 L p .904 .676 .583 r
F P
0 g
s
.73343 .53376 m .73852 .48791 L .75458 .49769 L p .904 .676 .583 r
F P
0 g
s
.74627 .71408 m .71373 .75334 L .70504 .74729 L p .833 .8 .82 r
F P
0 g
s
.46019 .41231 m .46065 .37425 L .48384 .36909 L p .58 .338 .515 r
F P
0 g
s
.46065 .37425 m .46019 .41231 L .43771 .41756 L p .559 .32 .51 r
F P
0 g
s
.42376 .7627 m .45051 .7957 L .45829 .79332 L p .63 .685 .883 r
F P
0 g
s
.45051 .7957 m .42376 .7627 L .41375 .76639 L p .625 .683 .885 r
F P
0 g
s
.35213 .74455 m .38693 .77946 L .39529 .77479 L p .591 .625 .854 r
F P
0 g
s
.38693 .77946 m .35213 .74455 L .34246 .75094 L p .582 .624 .859 r
F P
0 g
s
.70504 .74729 m .73642 .70682 L .74627 .71408 L p .833 .8 .82 r
F P
0 g
s
.72229 .43563 m .72073 .47875 L .7012 .47041 L p .865 .608 .549 r
F P
0 g
s
.7012 .47041 m .70279 .42652 L .72229 .43563 L p .865 .608 .549 r
F P
0 g
s
.35733 .52527 m .35501 .48216 L .3356 .48928 L p .533 .342 .567 r
F P
0 g
s
.3356 .48928 m .33822 .5322 L .35733 .52527 L p .533 .342 .567 r
F P
0 g
s
.59851 .79486 m .62431 .76189 L .63451 .76525 L p .719 .769 .892 r
F P
0 g
s
.62431 .76189 m .59851 .79486 L .59057 .79264 L p .715 .762 .89 r
F P
0 g
s
.39519 .4693 m .39522 .42963 L .41609 .42338 L p .542 .322 .531 r
F P
0 g
s
.39522 .42963 m .39519 .4693 L .37485 .4755 L p .531 .312 .527 r
F P
0 g
s
.45829 .79332 m .43425 .75939 L .42376 .7627 L p .63 .685 .883 r
F P
0 g
s
.44516 .75647 m .46639 .7912 L .45829 .79332 L p .635 .687 .881 r
F P
0 g
s
.45829 .79332 m .43425 .75939 L .44516 .75647 L p .635 .687 .881 r
F P
0 g
s
.31018 .64998 m .29372 .6026 L .27806 .61174 L p .522 .431 .693 r
F P
0 g
s
.27806 .61174 m .296 .6584 L .31018 .64998 L p .522 .431 .693 r
F P
0 g
s
.66172 .77715 m .69552 .74157 L .70504 .74729 L p .781 .794 .863 r
F P
0 g
s
.69552 .74157 m .66172 .77715 L .65325 .7729 L p .776 .785 .861 r
F P
0 g
s
.3211 .70356 m .296 .6584 L .28278 .66733 L p .532 .493 .758 r
F P
0 g
s
.28278 .66733 m .30957 .71133 L .3211 .70356 L p .532 .493 .758 r
F P
0 g
s
.65817 .3709 m .65872 .41188 L .63462 .4067 L p .779 .507 .524 r
F P
0 g
s
.63462 .4067 m .63418 .36559 L .65817 .3709 L p .779 .507 .524 r
F P
0 g
s
.30957 .71133 m .34246 .75094 L .35213 .74455 L p .559 .56 .812 r
F P
0 g
s
.76416 .5518 m .75388 .59858 L .73939 .59037 L p .904 .717 .639 r
F P
0 g
s
.73939 .59037 m .74956 .54254 L .76416 .5518 L p .904 .717 .639 r
F P
0 g
s
.59057 .79264 m .61361 .75886 L .62431 .76189 L p .715 .762 .89 r
F P
0 g
s
.61361 .75886 m .59057 .79264 L .58232 .79068 L p .71 .755 .888 r
F P
0 g
s
.48357 .4078 m .48384 .36909 L .50793 .36488 L p .604 .359 .519 r
F P
0 g
s
.48384 .36909 m .48357 .4078 L .46019 .41231 L p .58 .338 .515 r
F P
0 g
s
.32736 .58622 m .31961 .53972 L .3015 .54787 L p .53 .382 .625 r
F P
0 g
s
.3015 .54787 m .31019 .59409 L .32736 .58622 L p .53 .382 .625 r
F P
0 g
s
.45645 .75395 m .47476 .78937 L .46639 .7912 L p .64 .689 .88 r
F P
0 g
s
.46639 .7912 m .44516 .75647 L .45645 .75395 L p .64 .689 .88 r
F P
0 g
s
.36259 .73851 m .39529 .77479 L .40424 .77043 L p .6 .626 .849 r
F P
0 g
s
.39529 .77479 m .36259 .73851 L .35213 .74455 L p .591 .625 .854 r
F P
0 g
s
.76149 .66223 m .73642 .70682 L .72561 .69993 L p .868 .781 .762 r
F P
0 g
s
.72561 .69993 m .74985 .65424 L .76149 .66223 L p .868 .781 .762 r
F P
0 g
s
.73642 .70682 m .70504 .74729 L .69552 .74157 L p .826 .79 .817 r
F P
0 g
s
.35213 .74455 m .3211 .70356 L .30957 .71133 L p .559 .56 .812 r
F P
0 g
s
.58232 .79068 m .60246 .75616 L .61361 .75886 L p .71 .755 .888 r
F P
0 g
s
.60246 .75616 m .58232 .79068 L .57381 .78898 L p .705 .749 .886 r
F P
0 g
s
.76706 .60722 m .74985 .65424 L .7371 .64665 L p .892 .753 .7 r
F P
0 g
s
.7371 .64665 m .75388 .59858 L .76706 .60722 L p .892 .753 .7 r
F P
0 g
s
.46809 .75185 m .48338 .78784 L .47476 .78937 L p .645 .692 .879 r
F P
0 g
s
.47476 .78937 m .45645 .75395 L .46809 .75185 L p .645 .692 .879 r
F P
0 g
s
.65325 .7729 m .68519 .73618 L .69552 .74157 L p .776 .785 .861 r
F P
0 g
s
.68519 .73618 m .65325 .7729 L .64416 .76892 L p .77 .776 .858 r
F P
0 g
s
.35733 .52527 m .35501 .48216 L .37485 .4755 L p .542 .349 .568 r
F P
0 g
s
.63418 .36559 m .63462 .4067 L .60959 .4031 L p .748 .481 .527 r
F P
0 g
s
.60959 .4031 m .60924 .36205 L .63418 .36559 L p .748 .481 .527 r
F P
0 g
s
.41617 .46359 m .41609 .42338 L .43771 .41756 L p .556 .335 .535 r
F P
0 g
s
.41609 .42338 m .41617 .46359 L .39519 .4693 L p .542 .322 .531 r
F P
0 g
s
.50782 .40424 m .50793 .36488 L .53277 .36187 L p .63 .382 .523 r
F P
0 g
s
.50793 .36488 m .50782 .40424 L .48357 .4078 L p .604 .359 .519 r
F P
0 g
s
.57381 .78898 m .59093 .75381 L .60246 .75616 L p .705 .749 .886 r
F P
0 g
s
.59093 .75381 m .57381 .78898 L .56507 .78755 L p .699 .742 .884 r
F P
0 g
s
.69552 .74157 m .72561 .69993 L .73642 .70682 L p .826 .79 .817 r
F P
0 g
s
.48001 .75017 m .4922 .7866 L .48338 .78784 L p .649 .695 .878 r
F P
0 g
s
.48338 .78784 m .46809 .75185 L .48001 .75017 L p .649 .695 .878 r
F P
0 g
s
.73852 .48791 m .73343 .53376 L .71572 .52557 L p .881 .656 .593 r
F P
0 g
s
.71572 .52557 m .72073 .47875 L .73852 .48791 L p .881 .656 .593 r
F P
0 g
s
.70279 .42652 m .7012 .47041 L .68002 .46304 L p .837 .584 .557 r
F P
0 g
s
.68002 .46304 m .68153 .41854 L .70279 .42652 L p .837 .584 .557 r
F P
0 g
s
.3211 .70356 m .35213 .74455 L .36259 .73851 L p .571 .563 .806 r
F P
0 g
s
.37377 .73287 m .40424 .77043 L .41375 .76639 L p .608 .628 .845 r
F P
0 g
s
.40424 .77043 m .37377 .73287 L .36259 .73851 L p .6 .626 .849 r
F P
0 g
s
.56507 .78755 m .57905 .75182 L .59093 .75381 L p .699 .742 .884 r
F P
0 g
s
.57905 .75182 m .56507 .78755 L .55614 .7864 L p .694 .735 .883 r
F P
0 g
s
.49218 .74892 m .50118 .78566 L .4922 .7866 L p .654 .698 .878 r
F P
0 g
s
.4922 .7866 m .48001 .75017 L .49218 .74892 L p .654 .698 .878 r
F P
0 g
s
.32522 .64213 m .31019 .59409 L .29372 .6026 L p .538 .437 .688 r
F P
0 g
s
.29372 .6026 m .31018 .64998 L .32522 .64213 L p .538 .437 .688 r
F P
0 g
s
.53281 .40182 m .53277 .36187 L .55815 .36027 L p .658 .405 .526 r
F P
0 g
s
.53277 .36187 m .53281 .40182 L .50782 .40424 L p .63 .382 .523 r
F P
0 g
s
.60924 .36205 m .60959 .4031 L .58402 .40113 L p .718 .455 .528 r
F P
0 g
s
.58402 .40113 m .58377 .36029 L .60924 .36205 L p .718 .455 .528 r
F P
0 g
s
.33352 .69622 m .31018 .64998 L .296 .6584 L p .548 .497 .751 r
F P
0 g
s
.296 .6584 m .3211 .70356 L .33352 .69622 L p .548 .497 .751 r
F P
0 g
s
.55614 .7864 m .56691 .7502 L .57905 .75182 L p .694 .735 .883 r
F P
0 g
s
.56691 .7502 m .55614 .7864 L .54707 .78553 L p .688 .729 .881 r
F P
0 g
s
.34515 .57902 m .33822 .5322 L .31961 .53972 L p .543 .389 .622 r
F P
0 g
s
.31961 .53972 m .32736 .58622 L .34515 .57902 L p .543 .389 .622 r
F P
0 g
s
.50453 .74809 m .51028 .78503 L .50118 .78566 L p .66 .702 .878 r
F P
0 g
s
.50118 .78566 m .49218 .74892 L .50453 .74809 L p .66 .702 .878 r
F P
0 g
s
.54707 .78553 m .55457 .74897 L .56691 .7502 L p .688 .729 .881 r
F P
0 g
s
.55457 .74897 m .54707 .78553 L .53791 .78496 L p .682 .723 .88 r
F P
0 g
s
.517 .74769 m .51947 .7847 L .51028 .78503 L p .665 .706 .878 r
F P
0 g
s
.51028 .78503 m .50453 .74809 L .517 .74769 L p .665 .706 .878 r
F P
0 g
s
.55831 .40073 m .55815 .36027 L .58377 .36029 L p .688 .43 .528 r
F P
0 g
s
.55815 .36027 m .55831 .40073 L .53281 .40182 L p .658 .405 .526 r
F P
0 g
s
.64416 .76892 m .67406 .73115 L .68519 .73618 L p .77 .776 .858 r
F P
0 g
s
.67406 .73115 m .64416 .76892 L .63451 .76525 L p .763 .767 .856 r
F P
0 g
s
.58377 .36029 m .58402 .40113 L .55831 .40073 L p .688 .43 .528 r
F P
0 g
s
.72561 .69993 m .69552 .74157 L .68519 .73618 L p .819 .779 .815 r
F P
0 g
s
.53791 .78496 m .54209 .74814 L .55457 .74897 L p .682 .723 .88 r
F P
0 g
s
.54209 .74814 m .53791 .78496 L .52869 .78468 L p .676 .717 .879 r
F P
0 g
s
.52955 .74771 m .52869 .78468 L .51947 .7847 L p .671 .711 .879 r
F P
0 g
s
.51947 .7847 m .517 .74769 L .52955 .74771 L p .671 .711 .879 r
F P
0 g
s
.52869 .78468 m .52955 .74771 L .54209 .74814 L p .676 .717 .879 r
F P
0 g
s
.36259 .73851 m .33352 .69622 L .3211 .70356 L p .571 .563 .806 r
F P
0 g
s
.43788 .45843 m .43771 .41756 L .46019 .41231 L p .573 .351 .54 r
F P
0 g
s
.43771 .41756 m .43788 .45843 L .41617 .46359 L p .556 .335 .535 r
F P
0 g
s
.38563 .72765 m .41375 .76639 L .42376 .7627 L p .616 .63 .842 r
F P
0 g
s
.41375 .76639 m .38563 .72765 L .37377 .73287 L p .608 .628 .845 r
F P
0 g
s
.37694 .51894 m .37485 .4755 L .39519 .4693 L p .552 .356 .569 r
F P
0 g
s
.37485 .4755 m .37694 .51894 L .35733 .52527 L p .542 .349 .568 r
F P
0 g
s
.74956 .54254 m .73939 .59037 L .72352 .58263 L p .885 .699 .645 r
F P
0 g
s
.72352 .58263 m .73343 .53376 L .74956 .54254 L p .885 .699 .645 r
F P
0 g
s
.74985 .65424 m .72561 .69993 L .71381 .69343 L p .858 .768 .762 r
F P
0 g
s
.71381 .69343 m .7371 .64665 L .74985 .65424 L p .858 .768 .762 r
F P
0 g
s
.33352 .69622 m .36259 .73851 L .37377 .73287 L p .583 .565 .8 r
F P
0 g
s
.75388 .59858 m .7371 .64665 L .72318 .63949 L p .878 .737 .703 r
F P
0 g
s
.72318 .63949 m .73939 .59037 L .75388 .59858 L p .878 .737 .703 r
F P
0 g
s
.63451 .76525 m .66216 .72649 L .67406 .73115 L p .763 .767 .856 r
F P
0 g
s
.66216 .72649 m .63451 .76525 L .62431 .76189 L p .756 .757 .853 r
F P
0 g
s
.68519 .73618 m .71381 .69343 L .72561 .69993 L p .819 .779 .815 r
F P
0 g
s
.68153 .41854 m .68002 .46304 L .65737 .45681 L p .809 .56 .562 r
F P
0 g
s
.65737 .45681 m .65872 .41188 L .68153 .41854 L p .809 .56 .562 r
F P
0 g
s
.34102 .63489 m .32736 .58622 L .31019 .59409 L p .552 .443 .683 r
F P
0 g
s
.31019 .59409 m .32522 .64213 L .34102 .63489 L p .552 .443 .683 r
F P
0 g
s
.39811 .7229 m .42376 .7627 L .43425 .75939 L p .624 .633 .839 r
F P
0 g
s
.42376 .7627 m .39811 .7229 L .38563 .72765 L p .616 .63 .842 r
F P
0 g
s
.36353 .57248 m .35733 .52527 L .33822 .5322 L p .555 .396 .621 r
F P
0 g
s
.33822 .5322 m .34515 .57902 L .36353 .57248 L p .555 .396 .621 r
F P
0 g
s
.34677 .68936 m .32522 .64213 L .31018 .64998 L p .562 .502 .746 r
F P
0 g
s
.31018 .64998 m .33352 .69622 L .34677 .68936 L p .562 .502 .746 r
F P
0 g
s
.72073 .47875 m .71572 .52557 L .69643 .51809 L p .856 .634 .6 r
F P
0 g
s
.69643 .51809 m .7012 .47041 L .72073 .47875 L p .856 .634 .6 r
F P
0 g
s
.71381 .69343 m .68519 .73618 L .67406 .73115 L p .81 .767 .813 r
F P
0 g
s
.46041 .45393 m .46019 .41231 L .48357 .4078 L p .593 .369 .546 r
F P
0 g
s
.46019 .41231 m .46041 .45393 L .43788 .45843 L p .573 .351 .54 r
F P
0 g
s
.37377 .73287 m .34677 .68936 L .33352 .69622 L p .583 .565 .8 r
F P
0 g
s
.39712 .51321 m .39519 .4693 L .41617 .46359 L p .563 .366 .572 r
F P
0 g
s
.39519 .4693 m .39712 .51321 L .37694 .51894 L p .552 .356 .569 r
F P
0 g
s
.62431 .76189 m .64953 .7222 L .66216 .72649 L p .756 .757 .853 r
F P
0 g
s
.64953 .7222 m .62431 .76189 L .61361 .75886 L p .749 .747 .851 r
F P
0 g
s
.34677 .68936 m .37377 .73287 L .38563 .72765 L p .593 .568 .795 r
F P
0 g
s
.43425 .75939 m .41117 .71864 L .39811 .7229 L p .624 .633 .839 r
F P
0 g
s
.42475 .71489 m .44516 .75647 L .43425 .75939 L p .631 .636 .837 r
F P
0 g
s
.43425 .75939 m .41117 .71864 L .42475 .71489 L p .631 .636 .837 r
F P
0 g
s
.65872 .41188 m .65737 .45681 L .6335 .45186 L p .78 .535 .565 r
F P
0 g
s
.6335 .45186 m .63462 .4067 L .65872 .41188 L p .78 .535 .565 r
F P
0 g
s
.7371 .64665 m .71381 .69343 L .70103 .68734 L p .846 .754 .761 r
F P
0 g
s
.70103 .68734 m .72318 .63949 L .7371 .64665 L p .846 .754 .761 r
F P
0 g
s
.48378 .45022 m .48357 .4078 L .50782 .40424 L p .616 .39 .551 r
F P
0 g
s
.48357 .4078 m .48378 .45022 L .46041 .45393 L p .593 .369 .546 r
F P
0 g
s
.61361 .75886 m .63621 .71832 L .64953 .7222 L p .749 .747 .851 r
F P
0 g
s
.63621 .71832 m .61361 .75886 L .60246 .75616 L p .741 .737 .848 r
F P
0 g
s
.36353 .57248 m .35733 .52527 L .37694 .51894 L p .565 .403 .62 r
F P
0 g
s
.3575 .62828 m .34515 .57902 L .32736 .58622 L p .565 .449 .68 r
F P
0 g
s
.32736 .58622 m .34102 .63489 L .3575 .62828 L p .565 .449 .68 r
F P
0 g
s
.73343 .53376 m .72352 .58263 L .70627 .57544 L p .865 .68 .65 r
F P
0 g
s
.70627 .57544 m .71572 .52557 L .73343 .53376 L p .865 .68 .65 r
F P
0 g
s
.67406 .73115 m .70103 .68734 L .71381 .69343 L p .81 .767 .813 r
F P
0 g
s
.43882 .71167 m .45645 .75395 L .44516 .75647 L p .637 .639 .835 r
F P
0 g
s
.44516 .75647 m .42475 .71489 L .43882 .71167 L p .637 .639 .835 r
F P
0 g
s
.70103 .68734 m .67406 .73115 L .66216 .72649 L p .8 .755 .811 r
F P
0 g
s
.36077 .68304 m .34102 .63489 L .32522 .64213 L p .574 .506 .741 r
F P
0 g
s
.32522 .64213 m .34677 .68936 L .36077 .68304 L p .574 .506 .741 r
F P
0 g
s
.73939 .59037 m .72318 .63949 L .70808 .6328 L p .861 .72 .705 r
F P
0 g
s
.70808 .6328 m .72352 .58263 L .73939 .59037 L p .861 .72 .705 r
F P
0 g
s
.41793 .50809 m .41617 .46359 L .43788 .45843 L p .576 .378 .576 r
F P
0 g
s
.41617 .46359 m .41793 .50809 L .39712 .51321 L p .563 .366 .572 r
F P
0 g
s
.36077 .68304 m .38563 .72765 L .39811 .7229 L p .603 .572 .792 r
F P
0 g
s
.38563 .72765 m .36077 .68304 L .34677 .68936 L p .593 .568 .795 r
F P
0 g
s
.7012 .47041 m .69643 .51809 L .67565 .51144 L p .831 .611 .605 r
F P
0 g
s
.67565 .51144 m .68002 .46304 L .7012 .47041 L p .831 .611 .605 r
F P
0 g
s
.60246 .75616 m .62228 .71485 L .63621 .71832 L p .741 .737 .848 r
F P
0 g
s
.62228 .71485 m .60246 .75616 L .59093 .75381 L p .733 .727 .846 r
F P
0 g
s
.45332 .70899 m .46809 .75185 L .45645 .75395 L p .644 .643 .834 r
F P
0 g
s
.45645 .75395 m .43882 .71167 L .45332 .70899 L p .644 .643 .834 r
F P
0 g
s
.50793 .44743 m .50782 .40424 L .53281 .40182 L p .641 .413 .556 r
F P
0 g
s
.50782 .40424 m .50793 .44743 L .48378 .45022 L p .616 .39 .551 r
F P
0 g
s
.63462 .4067 m .6335 .45186 L .60875 .44826 L p .751 .51 .566 r
F P
0 g
s
.60875 .44826 m .60959 .4031 L .63462 .4067 L p .751 .51 .566 r
F P
0 g
s
.59093 .75381 m .60779 .71182 L .62228 .71485 L p .733 .727 .846 r
F P
0 g
s
.60779 .71182 m .59093 .75381 L .57905 .75182 L p .724 .717 .844 r
F P
0 g
s
.46821 .70686 m .48001 .75017 L .46809 .75185 L p .65 .647 .834 r
F P
0 g
s
.46809 .75185 m .45332 .70899 L .46821 .70686 L p .65 .647 .834 r
F P
0 g
s
.38248 .5666 m .37694 .51894 L .39712 .51321 L p .575 .41 .621 r
F P
0 g
s
.37694 .51894 m .38248 .5666 L .36353 .57248 L p .565 .403 .62 r
F P
0 g
s
.66216 .72649 m .68726 .68167 L .70103 .68734 L p .8 .755 .811 r
F P
0 g
s
.68726 .68167 m .66216 .72649 L .64953 .7222 L p .79 .742 .808 r
F P
0 g
s
.53276 .44573 m .53281 .40182 L .55831 .40073 L p .668 .436 .561 r
F P
0 g
s
.53281 .40182 m .53276 .44573 L .50793 .44743 L p .641 .413 .556 r
F P
0 g
s
.37462 .62233 m .36353 .57248 L .34515 .57902 L p .577 .456 .678 r
F P
0 g
s
.34515 .57902 m .3575 .62828 L .37462 .62233 L p .577 .456 .678 r
F P
0 g
s
.60959 .4031 m .60875 .44826 L .58348 .44606 L p .723 .485 .566 r
F P
0 g
s
.58348 .44606 m .58402 .40113 L .60959 .4031 L p .723 .485 .566 r
F P
0 g
s
.37545 .67728 m .39811 .7229 L .41117 .71864 L p .613 .576 .789 r
F P
0 g
s
.39811 .7229 m .37545 .67728 L .36077 .68304 L p .603 .572 .792 r
F P
0 g
s
.37545 .67728 m .3575 .62828 L .34102 .63489 L p .586 .511 .737 r
F P
0 g
s
.34102 .63489 m .36077 .68304 L .37545 .67728 L p .586 .511 .737 r
F P
0 g
s
.43944 .50364 m .43788 .45843 L .46041 .45393 L p .592 .393 .581 r
F P
0 g
s
.43788 .45843 m .43944 .50364 L .41793 .50809 L p .576 .378 .576 r
F P
0 g
s
.72318 .63949 m .70103 .68734 L .68726 .68167 L p .833 .739 .76 r
F P
0 g
s
.48343 .70528 m .49218 .74892 L .48001 .75017 L p .657 .653 .834 r
F P
0 g
s
.48001 .75017 m .46821 .70686 L .48343 .70528 L p .657 .653 .834 r
F P
0 g
s
.57905 .75182 m .59285 .70925 L .60779 .71182 L p .724 .717 .844 r
F P
0 g
s
.59285 .70925 m .57905 .75182 L .56691 .7502 L p .715 .708 .841 r
F P
0 g
s
.55803 .44523 m .55831 .40073 L .58402 .40113 L p .695 .461 .564 r
F P
0 g
s
.55831 .40073 m .55803 .44523 L .53276 .44573 L p .668 .436 .561 r
F P
0 g
s
.68726 .68167 m .70808 .6328 L .72318 .63949 L p .833 .739 .76 r
F P
0 g
s
.58402 .40113 m .58348 .44606 L .55803 .44523 L p .695 .461 .564 r
F P
0 g
s
.71572 .52557 m .70627 .57544 L .68765 .56887 L p .843 .659 .654 r
F P
0 g
s
.68765 .56887 m .69643 .51809 L .71572 .52557 L p .843 .659 .654 r
F P
0 g
s
.49891 .70425 m .50453 .74809 L .49218 .74892 L p .665 .658 .834 r
F P
0 g
s
.49218 .74892 m .48343 .70528 L .49891 .70425 L p .665 .658 .834 r
F P
0 g
s
.56691 .7502 m .57754 .70714 L .59285 .70925 L p .715 .708 .841 r
F P
0 g
s
.57754 .70714 m .56691 .7502 L .55457 .74897 L p .707 .698 .84 r
F P
0 g
s
.68002 .46304 m .67565 .51144 L .65355 .50575 L p .805 .588 .608 r
F P
0 g
s
.65355 .50575 m .65737 .45681 L .68002 .46304 L p .805 .588 .608 r
F P
0 g
s
.51459 .70377 m .517 .74769 L .50453 .74809 L p .673 .665 .834 r
F P
0 g
s
.50453 .74809 m .49891 .70425 L .51459 .70377 L p .673 .665 .834 r
F P
0 g
s
.55457 .74897 m .56196 .70553 L .57754 .70714 L p .707 .698 .84 r
F P
0 g
s
.56196 .70553 m .55457 .74897 L .54209 .74814 L p .698 .689 .838 r
F P
0 g
s
.72352 .58263 m .70808 .6328 L .69181 .6266 L p .844 .702 .706 r
F P
0 g
s
.69181 .6266 m .70627 .57544 L .72352 .58263 L p .844 .702 .706 r
F P
0 g
s
.41117 .71864 m .39077 .67211 L .37545 .67728 L p .613 .576 .789 r
F P
0 g
s
.40669 .66756 m .42475 .71489 L .41117 .71864 L p .621 .58 .786 r
F P
0 g
s
.41117 .71864 m .39077 .67211 L .40669 .66756 L p .621 .58 .786 r
F P
0 g
s
.53039 .70383 m .52955 .74771 L .517 .74769 L p .681 .672 .835 r
F P
0 g
s
.517 .74769 m .51459 .70377 L .53039 .70383 L p .681 .672 .835 r
F P
0 g
s
.64953 .7222 m .67256 .67644 L .68726 .68167 L p .79 .742 .808 r
F P
0 g
s
.67256 .67644 m .64953 .7222 L .63621 .71832 L p .779 .729 .806 r
F P
0 g
s
.54209 .74814 m .54621 .70442 L .56196 .70553 L p .698 .689 .838 r
F P
0 g
s
.54621 .70442 m .54209 .74814 L .52955 .74771 L p .689 .68 .836 r
F P
0 g
s
.52955 .74771 m .53039 .70383 L .54621 .70442 L p .689 .68 .836 r
F P
0 g
s
.40204 .56141 m .39712 .51321 L .41793 .50809 L p .586 .42 .623 r
F P
0 g
s
.39712 .51321 m .40204 .56141 L .38248 .5666 L p .575 .41 .621 r
F P
0 g
s
.37462 .62233 m .36353 .57248 L .38248 .5666 L p .587 .462 .677 r
F P
0 g
s
.4617 .49992 m .46041 .45393 L .48378 .45022 L p .611 .411 .586 r
F P
0 g
s
.46041 .45393 m .4617 .49992 L .43944 .50364 L p .592 .393 .581 r
F P
0 g
s
.39077 .67211 m .37462 .62233 L .3575 .62828 L p .597 .516 .734 r
F P
0 g
s
.3575 .62828 m .37545 .67728 L .39077 .67211 L p .597 .516 .734 r
F P
0 g
s
.70808 .6328 m .68726 .68167 L .67256 .67644 L p .819 .723 .759 r
F P
0 g
s
.42317 .66364 m .43882 .71167 L .42475 .71489 L p .629 .584 .785 r
F P
0 g
s
.42475 .71489 m .40669 .66756 L .42317 .66364 L p .629 .584 .785 r
F P
0 g
s
.67256 .67644 m .69181 .6266 L .70808 .6328 L p .819 .723 .759 r
F P
0 g
s
.63621 .71832 m .65695 .67169 L .67256 .67644 L p .779 .729 .806 r
F P
0 g
s
.65695 .67169 m .63621 .71832 L .62228 .71485 L p .768 .716 .803 r
F P
0 g
s
.65737 .45681 m .65355 .50575 L .63037 .50111 L p .779 .565 .609 r
F P
0 g
s
.63037 .50111 m .6335 .45186 L .65737 .45681 L p .779 .565 .609 r
F P
0 g
s
.69643 .51809 m .68765 .56887 L .66775 .56301 L p .821 .638 .656 r
F P
0 g
s
.66775 .56301 m .67565 .51144 L .69643 .51809 L p .821 .638 .656 r
F P
0 g
s
.48469 .49701 m .48378 .45022 L .50793 .44743 L p .632 .43 .591 r
F P
0 g
s
.48378 .45022 m .48469 .49701 L .4617 .49992 L p .611 .411 .586 r
F P
0 g
s
.42221 .55692 m .41793 .50809 L .43944 .50364 L p .599 .431 .626 r
F P
0 g
s
.41793 .50809 m .42221 .55692 L .40204 .56141 L p .586 .42 .623 r
F P
0 g
s
.39235 .61706 m .38248 .5666 L .40204 .56141 L p .597 .469 .677 r
F P
0 g
s
.38248 .5666 m .39235 .61706 L .37462 .62233 L p .587 .462 .677 r
F P
0 g
s
.44016 .66037 m .45332 .70899 L .43882 .71167 L p .637 .59 .784 r
F P
0 g
s
.43882 .71167 m .42317 .66364 L .44016 .66037 L p .637 .59 .784 r
F P
0 g
s
.39235 .61706 m .40669 .66756 L .39077 .67211 L p .606 .522 .733 r
F P
0 g
s
.39077 .67211 m .37462 .62233 L .39235 .61706 L p .606 .522 .733 r
F P
0 g
s
.70627 .57544 m .69181 .6266 L .67441 .62095 L p .826 .684 .706 r
F P
0 g
s
.67441 .62095 m .68765 .56887 L .70627 .57544 L p .826 .684 .706 r
F P
0 g
s
.62228 .71485 m .64052 .66743 L .65695 .67169 L p .768 .716 .803 r
F P
0 g
s
.64052 .66743 m .62228 .71485 L .60779 .71182 L p .756 .702 .801 r
F P
0 g
s
.69181 .6266 m .67256 .67644 L .65695 .67169 L p .805 .707 .758 r
F P
0 g
s
.6335 .45186 m .63037 .50111 L .60636 .49759 L p .753 .541 .609 r
F P
0 g
s
.60636 .49759 m .60875 .44826 L .6335 .45186 L p .753 .541 .609 r
F P
0 g
s
.50837 .495 m .50793 .44743 L .53276 .44573 L p .654 .451 .596 r
F P
0 g
s
.50793 .44743 m .50837 .495 L .48469 .49701 L p .632 .43 .591 r
F P
0 g
s
.45764 .65776 m .46821 .70686 L .45332 .70899 L p .645 .596 .784 r
F P
0 g
s
.45332 .70899 m .44016 .66037 L .45764 .65776 L p .645 .596 .784 r
F P
0 g
s
.44304 .55314 m .43944 .50364 L .4617 .49992 L p .613 .444 .629 r
F P
0 g
s
.43944 .50364 m .44304 .55314 L .42221 .55692 L p .599 .431 .626 r
F P
0 g
s
.65695 .67169 m .67441 .62095 L .69181 .6266 L p .805 .707 .758 r
F P
0 g
s
.60779 .71182 m .62336 .6637 L .64052 .66743 L p .756 .702 .801 r
F P
0 g
s
.62336 .6637 m .60779 .71182 L .59285 .70925 L p .744 .689 .798 r
F P
0 g
s
.53259 .49399 m .53276 .44573 L .55803 .44523 L p .678 .473 .601 r
F P
0 g
s
.53276 .44573 m .53259 .49399 L .50837 .495 L p .654 .451 .596 r
F P
0 g
s
.41069 .61248 m .42317 .66364 L .40669 .66756 L p .615 .527 .732 r
F P
0 g
s
.40669 .66756 m .39235 .61706 L .41069 .61248 L p .615 .527 .732 r
F P
0 g
s
.60875 .44826 m .60636 .49759 L .58186 .49524 L p .728 .518 .607 r
F P
0 g
s
.58186 .49524 m .58348 .44606 L .60875 .44826 L p .728 .518 .607 r
F P
0 g
s
.41069 .61248 m .40204 .56141 L .42221 .55692 L p .607 .477 .677 r
F P
0 g
s
.40204 .56141 m .41069 .61248 L .39235 .61706 L p .597 .469 .677 r
F P
0 g
s
.67565 .51144 m .66775 .56301 L .64672 .55792 L p .798 .617 .656 r
F P
0 g
s
.64672 .55792 m .65355 .50575 L .67565 .51144 L p .798 .617 .656 r
F P
0 g
s
.47555 .6558 m .48343 .70528 L .46821 .70686 L p .654 .603 .785 r
F P
0 g
s
.46821 .70686 m .45764 .65776 L .47555 .6558 L p .654 .603 .785 r
F P
0 g
s
.55717 .49404 m .55803 .44523 L .58348 .44606 L p .703 .495 .605 r
F P
0 g
s
.55803 .44523 m .55717 .49404 L .53259 .49399 L p .678 .473 .601 r
F P
0 g
s
.58348 .44606 m .58186 .49524 L .55717 .49404 L p .703 .495 .605 r
F P
0 g
s
.59285 .70925 m .60559 .66054 L .62336 .6637 L p .744 .689 .798 r
F P
0 g
s
.60559 .66054 m .59285 .70925 L .57754 .70714 L p .732 .676 .796 r
F P
0 g
s
.67441 .62095 m .65695 .67169 L .64052 .66743 L p .79 .691 .756 r
F P
0 g
s
.68765 .56887 m .67441 .62095 L .65596 .61589 L p .807 .665 .706 r
F P
0 g
s
.65596 .61589 m .66775 .56301 L .68765 .56887 L p .807 .665 .706 r
F P
0 g
s
.49383 .65452 m .49891 .70425 L .48343 .70528 L p .664 .611 .785 r
F P
0 g
s
.48343 .70528 m .47555 .6558 L .49383 .65452 L p .664 .611 .785 r
F P
0 g
s
.46451 .55013 m .4617 .49992 L .48469 .49701 L p .63 .459 .633 r
F P
0 g
s
.4617 .49992 m .46451 .55013 L .44304 .55314 L p .613 .444 .629 r
F P
0 g
s
.42961 .6086 m .44016 .66037 L .42317 .66364 L p .624 .534 .732 r
F P
0 g
s
.42317 .66364 m .41069 .61248 L .42961 .6086 L p .624 .534 .732 r
F P
0 g
s
.57754 .70714 m .58735 .65795 L .60559 .66054 L p .732 .676 .796 r
F P
0 g
s
.58735 .65795 m .57754 .70714 L .56196 .70553 L p .72 .664 .794 r
F P
0 g
s
.5124 .6539 m .51459 .70377 L .49891 .70425 L p .674 .62 .786 r
F P
0 g
s
.49891 .70425 m .49383 .65452 L .5124 .6539 L p .674 .62 .786 r
F P
0 g
s
.42961 .6086 m .42221 .55692 L .44304 .55314 L p .619 .486 .679 r
F P
0 g
s
.42221 .55692 m .42961 .6086 L .41069 .61248 L p .607 .477 .677 r
F P
0 g
s
.56196 .70553 m .56877 .65598 L .58735 .65795 L p .72 .664 .794 r
F P
0 g
s
.56877 .65598 m .56196 .70553 L .54621 .70442 L p .708 .652 .792 r
F P
0 g
s
.53116 .65394 m .53039 .70383 L .51459 .70377 L p .685 .63 .788 r
F P
0 g
s
.51459 .70377 m .5124 .6539 L .53116 .65394 L p .685 .63 .788 r
F P
0 g
s
.64052 .66743 m .65596 .61589 L .67441 .62095 L p .79 .691 .756 r
F P
0 g
s
.65355 .50575 m .64672 .55792 L .62475 .5537 L p .776 .596 .656 r
F P
0 g
s
.62475 .5537 m .63037 .50111 L .65355 .50575 L p .776 .596 .656 r
F P
0 g
s
.54621 .70442 m .54999 .65464 L .56877 .65598 L p .708 .652 .792 r
F P
0 g
s
.54999 .65464 m .54621 .70442 L .53039 .70383 L p .696 .64 .79 r
F P
0 g
s
.53039 .70383 m .53116 .65394 L .54999 .65464 L p .696 .64 .79 r
F P
0 g
s
.65596 .61589 m .64052 .66743 L .62336 .6637 L p .774 .675 .754 r
F P
0 g
s
.4866 .54793 m .48469 .49701 L .50837 .495 L p .648 .476 .638 r
F P
0 g
s
.48469 .49701 m .4866 .54793 L .46451 .55013 L p .63 .459 .633 r
F P
0 g
s
.4491 .60544 m .45764 .65776 L .44016 .66037 L p .634 .542 .732 r
F P
0 g
s
.44016 .66037 m .42961 .6086 L .4491 .60544 L p .634 .542 .732 r
F P
0 g
s
.66775 .56301 m .65596 .61589 L .63658 .61147 L p .788 .646 .705 r
F P
0 g
s
.63658 .61147 m .64672 .55792 L .66775 .56301 L p .788 .646 .705 r
F P
0 g
s
.4491 .60544 m .44304 .55314 L .46451 .55013 L p .631 .498 .681 r
F P
0 g
s
.44304 .55314 m .4491 .60544 L .42961 .6086 L p .619 .486 .679 r
F P
0 g
s
.63037 .50111 m .62475 .5537 L .60207 .55037 L p .753 .575 .654 r
F P
0 g
s
.60207 .55037 m .60636 .49759 L .63037 .50111 L p .753 .575 .654 r
F P
0 g
s
.62336 .6637 m .63658 .61147 L .65596 .61589 L p .774 .675 .754 r
F P
0 g
s
.63658 .61147 m .62336 .6637 L .60559 .66054 L p .759 .659 .751 r
F P
0 g
s
.50923 .54657 m .50837 .495 L .53259 .49399 L p .667 .494 .642 r
F P
0 g
s
.50837 .495 m .50923 .54657 L .4866 .54793 L p .648 .476 .638 r
F P
0 g
s
.46913 .60302 m .47555 .6558 L .45764 .65776 L p .645 .551 .733 r
F P
0 g
s
.45764 .65776 m .4491 .60544 L .46913 .60302 L p .645 .551 .733 r
F P
0 g
s
.60636 .49759 m .60207 .55037 L .57893 .548 L p .731 .554 .652 r
F P
0 g
s
.57893 .548 m .58186 .49524 L .60636 .49759 L p .731 .554 .652 r
F P
0 g
s
.53228 .54611 m .53259 .49399 L .55717 .49404 L p .688 .514 .646 r
F P
0 g
s
.53259 .49399 m .53228 .54611 L .50923 .54657 L p .667 .494 .642 r
F P
0 g
s
.46913 .60302 m .46451 .55013 L .4866 .54793 L p .646 .51 .684 r
F P
0 g
s
.46451 .55013 m .46913 .60302 L .4491 .60544 L p .631 .498 .681 r
F P
0 g
s
.48965 .60136 m .49383 .65452 L .47555 .6558 L p .657 .561 .735 r
F P
0 g
s
.47555 .6558 m .46913 .60302 L .48965 .60136 L p .657 .561 .735 r
F P
0 g
s
.64672 .55792 m .63658 .61147 L .61643 .60774 L p .769 .628 .703 r
F P
0 g
s
.61643 .60774 m .62475 .5537 L .64672 .55792 L p .769 .628 .703 r
F P
0 g
s
.60559 .66054 m .61643 .60774 L .63658 .61147 L p .759 .659 .751 r
F P
0 g
s
.61643 .60774 m .60559 .66054 L .58735 .65795 L p .743 .643 .749 r
F P
0 g
s
.58186 .49524 m .57893 .548 L .55558 .54658 L p .709 .534 .649 r
F P
0 g
s
.55558 .54658 m .55717 .49404 L .58186 .49524 L p .709 .534 .649 r
F P
0 g
s
.55717 .49404 m .55558 .54658 L .53228 .54611 L p .688 .514 .646 r
F P
0 g
s
.51058 .60046 m .5124 .6539 L .49383 .65452 L p .67 .573 .737 r
F P
0 g
s
.49383 .65452 m .48965 .60136 L .51058 .60046 L p .67 .573 .737 r
F P
0 g
s
.58735 .65795 m .59568 .60474 L .61643 .60774 L p .743 .643 .749 r
F P
0 g
s
.59568 .60474 m .58735 .65795 L .56877 .65598 L p .728 .628 .746 r
F P
0 g
s
.48965 .60136 m .4866 .54793 L .50923 .54657 L p .661 .525 .687 r
F P
0 g
s
.4866 .54793 m .48965 .60136 L .46913 .60302 L p .646 .51 .684 r
F P
0 g
s
.5318 .60035 m .53116 .65394 L .5124 .6539 L p .684 .585 .739 r
F P
0 g
s
.5124 .6539 m .51058 .60046 L .5318 .60035 L p .684 .585 .739 r
F P
0 g
s
.62475 .5537 m .61643 .60774 L .59568 .60474 L p .75 .609 .701 r
F P
0 g
s
.59568 .60474 m .60207 .55037 L .62475 .5537 L p .75 .609 .701 r
F P
0 g
s
.56877 .65598 m .57453 .6025 L .59568 .60474 L p .728 .628 .746 r
F P
0 g
s
.57453 .6025 m .56877 .65598 L .54999 .65464 L p .713 .613 .744 r
F P
0 g
s
.55317 .60103 m .54999 .65464 L .53116 .65394 L p .698 .599 .741 r
F P
0 g
s
.53116 .65394 m .5318 .60035 L .55317 .60103 L p .698 .599 .741 r
F P
0 g
s
.54999 .65464 m .55317 .60103 L .57453 .6025 L p .713 .613 .744 r
F P
0 g
s
.51058 .60046 m .50923 .54657 L .53228 .54611 L p .677 .54 .69 r
F P
0 g
s
.50923 .54657 m .51058 .60046 L .48965 .60136 L p .661 .525 .687 r
F P
0 g
s
.60207 .55037 m .59568 .60474 L .57453 .6025 L p .731 .591 .699 r
F P
0 g
s
.57453 .6025 m .57893 .548 L .60207 .55037 L p .731 .591 .699 r
F P
0 g
s
.5318 .60035 m .53228 .54611 L .55558 .54658 L p .695 .556 .693 r
F P
0 g
s
.53228 .54611 m .5318 .60035 L .51058 .60046 L p .677 .54 .69 r
F P
0 g
s
.57893 .548 m .57453 .6025 L .55317 .60103 L p .713 .573 .696 r
F P
0 g
s
.55317 .60103 m .55558 .54658 L .57893 .548 L p .713 .573 .696 r
F P
0 g
s
.55558 .54658 m .55317 .60103 L .5318 .60035 L p .695 .556 .693 r
F P
0 g
s
.25 Mabswid
.67243 0 m
.92713 .415 L
s
.92713 .415 m
1 .94815 L
s
1 .94815 m
.70641 .58544 L
s
.70641 .58544 m
.67243 0 L
s
.08845 .24554 m
0 .80371 L
s
0 .80371 m
.70641 .58544 L
s
.70641 .58544 m
.67243 0 L
s
.67243 0 m
.08845 .24554 L
s
.08845 .24554 m
.67243 0 L
s
.1204 .23211 m
.12544 .23737 L
s
[(-0.002)] .11032 .22158 .95826 1 Mshowa
.23898 .18225 m
.24379 .18773 L
s
[(-0.001)] .22936 .1713 .87773 1 Mshowa
.36357 .12986 m
.36812 .13556 L
s
[(0)] .35449 .11847 .7972 1 Mshowa
.49465 .07475 m
.49889 .08068 L
s
[(0.001)] .48616 .0629 .71666 1 Mshowa
.63273 .01669 m
.63664 .02284 L
s
[(0.002)] .62491 .0044 .63613 1 Mshowa
.125 Mabswid
.14366 .22233 m
.14666 .22551 L
s
.16714 .21246 m
.17011 .21567 L
s
.19085 .20249 m
.19379 .20572 L
s
.2148 .19242 m
.21771 .19568 L
s
.2634 .17198 m
.26626 .17529 L
s
.28807 .16161 m
.29089 .16495 L
s
.31298 .15113 m
.31578 .1545 L
s
.33815 .14055 m
.34091 .14395 L
s
.38925 .11907 m
.39195 .12251 L
s
.4152 .10816 m
.41785 .11163 L
s
.44141 .09714 m
.44403 .10064 L
s
.46789 .086 m
.47048 .08953 L
s
.52169 .06338 m
.5242 .06696 L
s
.54901 .0519 m
.55148 .0555 L
s
.57662 .04029 m
.57905 .04392 L
s
.60453 .02855 m
.60692 .03222 L
s
.09737 .24179 m
.10042 .24492 L
s
.66124 .00471 m
.66354 .00843 L
s
.25 Mabswid
0 .80371 m
.4004 1.0855 L
s
.02993 .82478 m
.03101 .81757 L
s
[(-0.002)] .02779 .8392 .14851 -1 Mshowa
.13067 .89567 m
.13151 .88843 L
s
[(-0.001)] .12899 .91015 .11591 -1 Mshowa
.22184 .95984 m
.22248 .95258 L
s
[(0)] .22057 .97436 .08755 -1 Mshowa
.30476 1.01819 m
.30521 1.01092 L
s
[(0.001)] .30384 1.03274 .06266 -1 Mshowa
.38048 1.07149 m
.38078 1.0642 L
s
[(0.002)] .37989 1.08605 .04063 -1 Mshowa
.125 Mabswid
.05092 .83955 m
.05153 .83522 L
s
.07147 .85401 m
.07205 .84968 L
s
.0916 .86818 m
.09216 .86384 L
s
.11133 .88207 m
.11186 .87773 L
s
.14962 .90901 m
.1501 .90467 L
s
.16821 .92209 m
.16866 .91774 L
s
.18643 .93492 m
.18686 .93057 L
s
.20431 .9475 m
.20471 .94314 L
s
.23905 .97195 m
.23941 .96759 L
s
.25593 .98383 m
.25627 .97947 L
s
.27251 .9955 m
.27282 .99114 L
s
.28878 1.00695 m
.28907 1.00259 L
s
.32044 1.02923 m
.3207 1.02487 L
s
.33585 1.04008 m
.33609 1.03571 L
s
.35099 1.05073 m
.35121 1.04636 L
s
.36587 1.0612 m
.36606 1.05683 L
s
.00851 .8097 m
.00918 .80538 L
s
.39485 1.08159 m
.39501 1.07722 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{265.125, 287.75},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 264.125}, {286.75, 0}} -> {-0.0684718, -0.0615238, \
0.00369026, 0.00369026}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics3D", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"],

Cell[BoxData["\<\"TiN.pdf\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"epsnn", " ", "normal"}], ")"}], "/.", " ", "austenite"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot3D", "[", " ", 
  RowBox[{
   RowBox[{"Evaluate", "[", "%", "]"}], "  ", ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "0", ",", "  ", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"p", ",", " ", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], " ", ",", " ", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", " ", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "50"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<austenite.pdf\>\"", ",", "%"}], "]"}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.08568 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567931 1.16636 0 1.16636 [
[.17327 .19475 -28.7258 -9 ]
[.17327 .19475 1.27425 0 ]
[.35423 .11836 -5.39227 -9 ]
[.35423 .11836 .60773 0 ]
[.54918 .03613 -20.1576 -9 ]
[.54918 .03613 3.84245 0 ]
[.08385 .87807 -16.9517 0 ]
[.08385 .87807 13.0483 9 ]
[.22086 .97424 -3.26208 0 ]
[.22086 .97424 2.73792 9 ]
[.3401 1.05793 -12.6243 0 ]
[.3401 1.05793 11.3757 9 ]
[.0614 .33523 -30 -2.68293 ]
[.0614 .33523 0 6.31707 ]
[.03472 .5025 -6 -2.8322 ]
[.03472 .5025 0 6.1678 ]
[.00471 .69065 -24 -3.00214 ]
[.00471 .69065 0 5.99786 ]
[ 0 0 0 0 ]
[ 1 1.08568 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08828 .24537 m
.67201 0 L
s
.18312 .20551 m
.18804 .21088 L
s
[(-0.01)] .17327 .19475 .91505 1 Mshowa
.36332 .12976 m
.36786 .13546 L
s
[(0)] .35423 .11836 .79742 1 Mshowa
.55738 .04818 m
.56148 .05421 L
s
[(0.01)] .54918 .03613 .6798 1 Mshowa
.125 Mabswid
.21812 .19079 m
.22103 .19406 L
s
.25363 .17587 m
.2565 .17917 L
s
.28966 .16072 m
.29248 .16406 L
s
.32622 .14535 m
.32899 .14873 L
s
.40097 .11393 m
.40365 .11739 L
s
.43919 .09786 m
.44182 .10136 L
s
.47799 .08156 m
.48056 .08509 L
s
.51738 .065 m
.5199 .06857 L
s
.14861 .22001 m
.1516 .2232 L
s
.11459 .23431 m
.11762 .23746 L
s
.598 .03111 m
.60039 .03477 L
s
.63925 .01377 m
.64159 .01747 L
s
.25 Mabswid
0 .80321 m
.40091 1.08568 L
s
.08573 .86361 m
.08667 .85638 L
s
[(-0.01)] .08385 .87807 .13011 -1 Mshowa
.22213 .95971 m
.22276 .95245 L
s
[(0)] .22086 .97424 .08736 -1 Mshowa
.34085 1.04337 m
.34123 1.03609 L
s
[(0.01)] .3401 1.05793 .05202 -1 Mshowa
.125 Mabswid
.11461 .88396 m
.11513 .87962 L
s
.14265 .90372 m
.14314 .89937 L
s
.1699 .92292 m
.17035 .91857 L
s
.19638 .94157 m
.19679 .93722 L
s
.24717 .97736 m
.24752 .973 L
s
.27154 .99453 m
.27185 .99017 L
s
.29526 1.01124 m
.29554 1.00688 L
s
.31835 1.02751 m
.31861 1.02315 L
s
.05597 .84265 m
.05658 .83832 L
s
.02531 .82104 m
.02596 .81672 L
s
.36278 1.05881 m
.36298 1.05444 L
s
.38415 1.07387 m
.38432 1.0695 L
s
.25 Mabswid
.08828 .24537 m
0 .80321 L
s
.07492 .32977 m
.08168 .32704 L
s
[(-0.01)] .0614 .33523 1 -0.40379 Mshowa
.04839 .49744 m
.05522 .4949 L
s
[(0)] .03472 .5025 1 -0.37062 Mshowa
.01854 .68604 m
.02546 .68374 L
s
[(0.01)] .00471 .69065 1 -0.33286 Mshowa
.125 Mabswid
.06985 .3618 m
.07392 .36018 L
s
.06467 .39455 m
.06874 .39296 L
s
.05937 .42806 m
.06345 .42649 L
s
.05394 .46234 m
.05803 .4608 L
s
.0427 .53336 m
.04681 .53187 L
s
.03688 .57015 m
.041 .56869 L
s
.03092 .60784 m
.03505 .6064 L
s
.02481 .64646 m
.02895 .64505 L
s
.07988 .29845 m
.08393 .29679 L
s
.08473 .2678 m
.08877 .26612 L
s
.01212 .72663 m
.01628 .72528 L
s
.00553 .76825 m
.0097 .76693 L
s
.25 Mabswid
.08828 .24537 m
0 .80321 L
s
0 .80321 m
.40091 1.08568 L
s
.40091 1.08568 m
.41842 .58207 L
s
.41842 .58207 m
.08828 .24537 L
s
.67201 0 m
.92731 .41559 L
s
.92731 .41559 m
1 .94836 L
s
1 .94836 m
.70577 .58502 L
s
.70577 .58502 m
.67201 0 L
s
.08828 .24537 m
0 .80321 L
s
0 .80321 m
.70577 .58502 L
s
.70577 .58502 m
.67201 0 L
s
.67201 0 m
.08828 .24537 L
s
.41842 .58207 m
.92731 .41559 L
s
.92731 .41559 m
1 .94836 L
s
1 .94836 m
.40091 1.08568 L
s
.40091 1.08568 m
.41842 .58207 L
s
0 0 m
1 0 L
1 1.08568 L
0 1.08568 L
closepath
clip
newpath
.5 Mabswid
.60767 .74211 m .60549 .71044 L .62511 .71192 L p .743 .525 .599 r
F P
0 g
s
.62511 .71192 m .62787 .74477 L .60767 .74211 L p .743 .525 .599 r
F P
0 g
s
.61587 .67333 m .62511 .71192 L .60549 .71044 L p .745 .607 .704 r
F P
0 g
s
.62787 .74477 m .62511 .71192 L .6441 .71093 L p .691 .486 .605 r
F P
0 g
s
.62511 .71192 m .61587 .67333 L .63304 .67176 L p .705 .58 .713 r
F P
0 g
s
.63304 .67176 m .6441 .71093 L .62511 .71192 L p .705 .58 .713 r
F P
0 g
s
.6441 .71093 m .64741 .7445 L .62787 .74477 L p .691 .486 .605 r
F P
0 g
s
.64741 .7445 m .6441 .71093 L .66156 .70742 L p .628 .44 .608 r
F P
0 g
s
.6441 .71093 m .63304 .67176 L .64883 .66828 L p .657 .551 .723 r
F P
0 g
s
.64883 .66828 m .66156 .70742 L .6441 .71093 L p .657 .551 .723 r
F P
0 g
s
.61694 .63384 m .63304 .67176 L .61587 .67333 L p .712 .647 .783 r
F P
0 g
s
.63304 .67176 m .61694 .63384 L .63029 .63062 L p .672 .626 .795 r
F P
0 g
s
.63029 .63062 m .64883 .66828 L .63304 .67176 L p .672 .626 .795 r
F P
0 g
s
.60549 .71044 m .59811 .67299 L .61587 .67333 L p .745 .607 .704 r
F P
0 g
s
.6024 .63577 m .61587 .67333 L .59811 .67299 L p .747 .668 .773 r
F P
0 g
s
.61587 .67333 m .6024 .63577 L .61694 .63384 L p .712 .647 .783 r
F P
0 g
s
.58772 .73682 m .5861 .70669 L .60549 .71044 L p .787 .56 .593 r
F P
0 g
s
.60549 .71044 m .60767 .74211 L .58772 .73682 L p .787 .56 .593 r
F P
0 g
s
.59811 .67299 m .60549 .71044 L .5861 .70669 L p .781 .633 .697 r
F P
0 g
s
.66156 .70742 m .66538 .74122 L .64741 .7445 L p .628 .44 .608 r
F P
0 g
s
.64883 .66828 m .66156 .70742 L .67667 .70152 L p .598 .518 .735 r
F P
0 g
s
.66156 .70742 m .66538 .74122 L .68092 .73503 L p .546 .38 .608 r
F P
0 g
s
.68092 .73503 m .67667 .70152 L .66156 .70742 L p .546 .38 .608 r
F P
0 g
s
.63029 .63062 m .64883 .66828 L .66248 .66302 L p .621 .603 .811 r
F P
0 g
s
.67667 .70152 m .66248 .66302 L .64883 .66828 L p .598 .518 .735 r
F P
0 g
s
.5861 .70669 m .58054 .67087 L .59811 .67299 L p .781 .633 .697 r
F P
0 g
s
.58736 .63639 m .59811 .67299 L .58054 .67087 L p .779 .689 .765 r
F P
0 g
s
.59811 .67299 m .58736 .63639 L .6024 .63577 L p .747 .668 .773 r
F P
0 g
s
.5688 .72934 m .5677 .70104 L .5861 .70669 L p .826 .592 .585 r
F P
0 g
s
.5861 .70669 m .58772 .73682 L .5688 .72934 L p .826 .592 .585 r
F P
0 g
s
.58054 .67087 m .5861 .70669 L .5677 .70104 L p .813 .658 .69 r
F P
0 g
s
.66248 .66302 m .64183 .62624 L .63029 .63062 L p .621 .603 .811 r
F P
0 g
s
.64183 .62624 m .66248 .66302 L .67335 .65621 L p .554 .575 .83 r
F P
0 g
s
.66248 .66302 m .67667 .70152 L .68872 .69348 L p .518 .475 .748 r
F P
0 g
s
.68872 .69348 m .67335 .65621 L .66248 .66302 L p .518 .475 .748 r
F P
0 g
s
.5677 .70104 m .56387 .66723 L .58054 .67087 L p .813 .658 .69 r
F P
0 g
s
.57247 .63575 m .58054 .67087 L .56387 .66723 L p .807 .711 .758 r
F P
0 g
s
.58054 .67087 m .57247 .63575 L .58736 .63639 L p .779 .689 .765 r
F P
0 g
s
.67667 .70152 m .68092 .73503 L .6933 .72621 L p .43 .299 .6 r
F P
0 g
s
.6933 .72621 m .68872 .69348 L .67667 .70152 L p .43 .299 .6 r
F P
0 g
s
.60401 .762 m .60767 .74211 L .62787 .74477 L p .725 .379 .393 r
F P
0 g
s
.62787 .74477 m .62333 .76564 L .60401 .762 L p .725 .379 .393 r
F P
0 g
s
.62333 .76564 m .62787 .74477 L .64741 .7445 L p .647 .306 .381 r
F P
0 g
s
.64741 .7445 m .64203 .7661 L .62333 .76564 L p .647 .306 .381 r
F P
0 g
s
.64203 .7661 m .64741 .7445 L .66538 .74122 L p .54 .206 .351 r
F P
0 g
s
.59953 .60221 m .61694 .63384 L .6024 .63577 L p .717 .7 .832 r
F P
0 g
s
.61694 .63384 m .59953 .60221 L .61025 .5994 L p .68 .683 .846 r
F P
0 g
s
.61025 .5994 m .63029 .63062 L .61694 .63384 L p .68 .683 .846 r
F P
0 g
s
.58787 .6043 m .6024 .63577 L .58736 .63639 L p .751 .717 .82 r
F P
0 g
s
.6024 .63577 m .58787 .6043 L .59953 .60221 L p .717 .7 .832 r
F P
0 g
s
.58493 .75551 m .58772 .73682 L .60767 .74211 L p .784 .434 .393 r
F P
0 g
s
.60767 .74211 m .60401 .762 L .58493 .75551 L p .784 .434 .393 r
F P
0 g
s
.61025 .5994 m .63029 .63062 L .64183 .62624 L p .631 .664 .864 r
F P
0 g
s
.66538 .74122 m .65919 .76326 L .64203 .7661 L p .54 .206 .351 r
F P
0 g
s
.66538 .74122 m .65919 .76326 L .674 .75719 L p .381 .061 .292 r
F P
0 g
s
.674 .75719 m .68092 .73503 L .66538 .74122 L p .381 .061 .292 r
F P
0 g
s
.5758 .6056 m .58736 .63639 L .57247 .63575 L p .781 .735 .811 r
F P
0 g
s
.58736 .63639 m .5758 .6056 L .58787 .6043 L p .751 .717 .82 r
F P
0 g
s
.55154 .7203 m .5509 .694 L .5677 .70104 L p .859 .621 .576 r
F P
0 g
s
.5677 .70104 m .5688 .72934 L .55154 .7203 L p .859 .621 .576 r
F P
0 g
s
.56387 .66723 m .5677 .70104 L .5509 .694 L p .842 .683 .685 r
F P
0 g
s
.52028 .44229 m .52219 .39694 L .52553 .39703 L p .719 .574 .69 r
F P
0 g
s
.52553 .39703 m .52514 .44237 L .52028 .44229 L p .719 .574 .69 r
F P
0 g
s
.52608 .35784 m .52553 .39703 L .52219 .39694 L p .71 .635 .771 r
F P
0 g
s
.52514 .44237 m .52553 .39703 L .52887 .39698 L p .709 .566 .69 r
F P
0 g
s
.52553 .39703 m .52608 .35784 L .52728 .35783 L p .703 .629 .771 r
F P
0 g
s
.52728 .35783 m .52887 .39698 L .52553 .39703 L p .703 .629 .771 r
F P
0 g
s
.52887 .39698 m .53001 .44223 L .52514 .44237 L p .709 .566 .69 r
F P
0 g
s
.53001 .44223 m .52887 .39698 L .5322 .39679 L p .699 .558 .691 r
F P
0 g
s
.52887 .39698 m .52728 .35783 L .52848 .35777 L p .696 .624 .771 r
F P
0 g
s
.52848 .35777 m .5322 .39679 L .52887 .39698 L p .696 .624 .771 r
F P
0 g
s
.51544 .44201 m .51888 .3967 L .52219 .39694 L p .729 .581 .69 r
F P
0 g
s
.52219 .39694 m .52028 .44229 L .51544 .44201 L p .729 .581 .69 r
F P
0 g
s
.52488 .3578 m .52219 .39694 L .51888 .3967 L p .717 .641 .771 r
F P
0 g
s
.52219 .39694 m .52488 .3578 L .52608 .35784 L p .71 .635 .771 r
F P
0 g
s
.5322 .39679 m .53487 .44189 L .53001 .44223 L p .699 .558 .691 r
F P
0 g
s
.53487 .44189 m .5322 .39679 L .53551 .39646 L p .689 .55 .692 r
F P
0 g
s
.5322 .39679 m .52848 .35777 L .52966 .35765 L p .689 .619 .772 r
F P
0 g
s
.52966 .35765 m .53551 .39646 L .5322 .39679 L p .689 .619 .772 r
F P
0 g
s
.51065 .4415 m .51559 .39632 L .51888 .3967 L p .738 .589 .69 r
F P
0 g
s
.51888 .3967 m .51544 .44201 L .51065 .4415 L p .738 .589 .69 r
F P
0 g
s
.52369 .35771 m .51888 .3967 L .51559 .39632 L p .723 .647 .772 r
F P
0 g
s
.51888 .3967 m .52369 .35771 L .52488 .3578 L p .717 .641 .771 r
F P
0 g
s
.53551 .39646 m .53971 .44134 L .53487 .44189 L p .689 .55 .692 r
F P
0 g
s
.53971 .44134 m .53551 .39646 L .53878 .396 L p .677 .542 .693 r
F P
0 g
s
.53551 .39646 m .52966 .35765 L .53084 .35748 L p .682 .613 .773 r
F P
0 g
s
.53084 .35748 m .53878 .396 L .53551 .39646 L p .682 .613 .773 r
F P
0 g
s
.50592 .44077 m .51234 .3958 L .51559 .39632 L p .747 .598 .691 r
F P
0 g
s
.51559 .39632 m .51065 .4415 L .50592 .44077 L p .747 .598 .691 r
F P
0 g
s
.52251 .35757 m .51559 .39632 L .51234 .3958 L p .73 .653 .773 r
F P
0 g
s
.51559 .39632 m .52251 .35757 L .52369 .35771 L p .723 .647 .772 r
F P
0 g
s
.53878 .396 m .5445 .44061 L .53971 .44134 L p .677 .542 .693 r
F P
0 g
s
.5445 .44061 m .53878 .396 L .542 .39539 L p .665 .534 .694 r
F P
0 g
s
.53878 .396 m .53084 .35748 L .53199 .35727 L p .674 .608 .774 r
F P
0 g
s
.53199 .35727 m .542 .39539 L .53878 .396 L p .674 .608 .774 r
F P
0 g
s
.5509 .694 m .54864 .66245 L .56387 .66723 L p .842 .683 .685 r
F P
0 g
s
.55832 .63402 m .56387 .66723 L .54864 .66245 L p .832 .732 .754 r
F P
0 g
s
.56387 .66723 m .55832 .63402 L .57247 .63575 L p .807 .711 .758 r
F P
0 g
s
.50127 .43983 m .50915 .39514 L .51234 .3958 L p .756 .606 .691 r
F P
0 g
s
.51234 .3958 m .50592 .44077 L .50127 .43983 L p .756 .606 .691 r
F P
0 g
s
.52134 .35738 m .51234 .3958 L .50915 .39514 L p .736 .659 .774 r
F P
0 g
s
.51234 .3958 m .52134 .35738 L .52251 .35757 L p .73 .653 .773 r
F P
0 g
s
.542 .39539 m .54923 .43969 L .5445 .44061 L p .665 .534 .694 r
F P
0 g
s
.54923 .43969 m .542 .39539 L .54517 .39466 L p .653 .525 .695 r
F P
0 g
s
.542 .39539 m .53199 .35727 L .53313 .357 L p .667 .604 .775 r
F P
0 g
s
.53313 .357 m .54517 .39466 L .542 .39539 L p .667 .604 .775 r
F P
0 g
s
.67335 .65621 m .65104 .62091 L .64183 .62624 L p .554 .575 .83 r
F P
0 g
s
.65104 .62091 m .67335 .65621 L .68102 .64821 L p .465 .54 .849 r
F P
0 g
s
.67335 .65621 m .68872 .69348 L .69722 .68372 L p .409 .419 .758 r
F P
0 g
s
.69722 .68372 m .68102 .64821 L .67335 .65621 L p .409 .419 .758 r
F P
0 g
s
.4967 .43867 m .50602 .39434 L .50915 .39514 L p .765 .615 .692 r
F P
0 g
s
.50915 .39514 m .50127 .43983 L .4967 .43867 L p .765 .615 .692 r
F P
0 g
s
.52019 .35714 m .50915 .39514 L .50602 .39434 L p .742 .666 .775 r
F P
0 g
s
.50915 .39514 m .52019 .35714 L .52134 .35738 L p .736 .659 .774 r
F P
0 g
s
.54517 .39466 m .55387 .4386 L .54923 .43969 L p .653 .525 .695 r
F P
0 g
s
.55387 .4386 m .54517 .39466 L .54826 .3938 L p .64 .517 .697 r
F P
0 g
s
.54517 .39466 m .53313 .357 L .53424 .35669 L p .659 .599 .777 r
F P
0 g
s
.53424 .35669 m .54826 .3938 L .54517 .39466 L p .659 .599 .777 r
F P
0 g
s
.68872 .69348 m .6933 .72621 L .702 .71521 L p .255 .178 .573 r
F P
0 g
s
.702 .71521 m .69722 .68372 L .68872 .69348 L p .255 .178 .573 r
F P
0 g
s
.56685 .74672 m .5688 .72934 L .58772 .73682 L p .833 .478 .384 r
F P
0 g
s
.58772 .73682 m .58493 .75551 L .56685 .74672 L p .833 .478 .384 r
F P
0 g
s
.49224 .4373 m .50297 .39341 L .50602 .39434 L p .774 .624 .694 r
F P
0 g
s
.50602 .39434 m .4967 .43867 L .49224 .4373 L p .774 .624 .694 r
F P
0 g
s
.51907 .35685 m .50602 .39434 L .50297 .39341 L p .748 .672 .777 r
F P
0 g
s
.50602 .39434 m .51907 .35685 L .52019 .35714 L p .742 .666 .775 r
F P
0 g
s
.54826 .3938 m .55841 .43733 L .55387 .4386 L p .64 .517 .697 r
F P
0 g
s
.55841 .43733 m .54826 .3938 L .55126 .39281 L p .626 .508 .699 r
F P
0 g
s
.54826 .3938 m .53424 .35669 L .53531 .35633 L p .651 .595 .779 r
F P
0 g
s
.53531 .35633 m .55126 .39281 L .54826 .3938 L p .651 .595 .779 r
F P
0 g
s
.52493 .4862 m .52514 .44237 L .53001 .44223 L p .714 .519 .625 r
F P
0 g
s
.53001 .44223 m .53061 .48587 L .52493 .4862 L p .714 .519 .625 r
F P
0 g
s
.53061 .48587 m .53001 .44223 L .53487 .44189 L p .702 .511 .626 r
F P
0 g
s
.51929 .48626 m .52028 .44229 L .52514 .44237 L p .725 .527 .623 r
F P
0 g
s
.52514 .44237 m .52493 .4862 L .51929 .48626 L p .725 .527 .623 r
F P
0 g
s
.53487 .44189 m .5363 .48531 L .53061 .48587 L p .702 .511 .626 r
F P
0 g
s
.5363 .48531 m .53487 .44189 L .53971 .44134 L p .689 .502 .628 r
F P
0 g
s
.5137 .48604 m .51544 .44201 L .52028 .44229 L p .735 .535 .622 r
F P
0 g
s
.52028 .44229 m .51929 .48626 L .5137 .48604 L p .735 .535 .622 r
F P
0 g
s
.4879 .43573 m .50002 .39235 L .50297 .39341 L p .783 .633 .695 r
F P
0 g
s
.50297 .39341 m .49224 .4373 L .4879 .43573 L p .783 .633 .695 r
F P
0 g
s
.51798 .35651 m .50297 .39341 L .50002 .39235 L p .754 .68 .779 r
F P
0 g
s
.50297 .39341 m .51798 .35651 L .51907 .35685 L p .748 .672 .777 r
F P
0 g
s
.53971 .44134 m .54199 .48452 L .5363 .48531 L p .689 .502 .628 r
F P
0 g
s
.54199 .48452 m .53971 .44134 L .5445 .44061 L p .675 .492 .63 r
F P
0 g
s
.50816 .48555 m .51065 .4415 L .51544 .44201 L p .745 .542 .621 r
F P
0 g
s
.51544 .44201 m .5137 .48604 L .50816 .48555 L p .745 .542 .621 r
F P
0 g
s
.64183 .62624 m .61955 .59596 L .61025 .5994 L p .631 .664 .864 r
F P
0 g
s
.61955 .59596 m .64183 .62624 L .65104 .62091 L p .567 .642 .884 r
F P
0 g
s
.55126 .39281 m .56282 .43591 L .55841 .43733 L p .626 .508 .699 r
F P
0 g
s
.53531 .35633 m .55126 .39281 L .55417 .3917 L p .642 .59 .781 r
F P
0 g
s
.55126 .39281 m .56282 .43591 L .56709 .43433 L p .612 .499 .701 r
F P
0 g
s
.56709 .43433 m .55417 .3917 L .55126 .39281 L p .612 .499 .701 r
F P
0 g
s
.5445 .44061 m .54765 .48351 L .54199 .48452 L p .675 .492 .63 r
F P
0 g
s
.54765 .48351 m .5445 .44061 L .54923 .43969 L p .66 .481 .631 r
F P
0 g
s
.50269 .48476 m .50592 .44077 L .51065 .4415 L p .754 .55 .62 r
F P
0 g
s
.51065 .4415 m .50816 .48555 L .50269 .48476 L p .754 .55 .62 r
F P
0 g
s
.4837 .43396 m .49716 .39116 L .50002 .39235 L p .792 .644 .697 r
F P
0 g
s
.50002 .39235 m .4879 .43573 L .4837 .43396 L p .792 .644 .697 r
F P
0 g
s
.51692 .35612 m .50002 .39235 L .49716 .39116 L p .76 .687 .781 r
F P
0 g
s
.50002 .39235 m .51692 .35612 L .51798 .35651 L p .754 .68 .779 r
F P
0 g
s
.54923 .43969 m .55325 .48232 L .54765 .48351 L p .66 .481 .631 r
F P
0 g
s
.55325 .48232 m .54923 .43969 L .55387 .4386 L p .643 .469 .633 r
F P
0 g
s
.55417 .3917 m .53635 .35592 L .53531 .35633 L p .642 .59 .781 r
F P
0 g
s
.53635 .35592 m .55417 .3917 L .55697 .39047 L p .634 .587 .783 r
F P
0 g
s
.55417 .3917 m .56709 .43433 L .57119 .4326 L p .598 .491 .702 r
F P
0 g
s
.57119 .4326 m .55697 .39047 L .55417 .3917 L p .598 .491 .702 r
F P
0 g
s
.49729 .48368 m .50127 .43983 L .50592 .44077 L p .763 .558 .62 r
F P
0 g
s
.50592 .44077 m .50269 .48476 L .49729 .48368 L p .763 .558 .62 r
F P
0 g
s
.56383 .60613 m .57247 .63575 L .55832 .63402 L p .808 .754 .803 r
F P
0 g
s
.57247 .63575 m .56383 .60613 L .5758 .6056 L p .781 .735 .811 r
F P
0 g
s
.47966 .43202 m .49442 .38985 L .49716 .39116 L p .802 .655 .7 r
F P
0 g
s
.49716 .39116 m .4837 .43396 L .47966 .43202 L p .802 .655 .7 r
F P
0 g
s
.51591 .35569 m .49716 .39116 L .49442 .38985 L p .766 .695 .784 r
F P
0 g
s
.49716 .39116 m .51591 .35569 L .51692 .35612 L p .76 .687 .781 r
F P
0 g
s
.55387 .4386 m .55875 .48096 L .55325 .48232 L p .643 .469 .633 r
F P
0 g
s
.55875 .48096 m .55387 .4386 L .55841 .43733 L p .625 .456 .634 r
F P
0 g
s
.68092 .73503 m .674 .75719 L .68576 .74816 L p .131 0 .179 r
F P
0 g
s
.68576 .74816 m .6933 .72621 L .68092 .73503 L p .131 0 .179 r
F P
0 g
s
.49197 .48231 m .4967 .43867 L .50127 .43983 L p .772 .566 .621 r
F P
0 g
s
.50127 .43983 m .49729 .48368 L .49197 .48231 L p .772 .566 .621 r
F P
0 g
s
.55697 .39047 m .53735 .35547 L .53635 .35592 L p .634 .587 .783 r
F P
0 g
s
.53735 .35547 m .55697 .39047 L .55965 .38913 L p .626 .583 .786 r
F P
0 g
s
.55697 .39047 m .57119 .4326 L .57511 .43073 L p .584 .482 .704 r
F P
0 g
s
.57511 .43073 m .55965 .38913 L .55697 .39047 L p .584 .482 .704 r
F P
0 g
s
.47579 .4299 m .49181 .38842 L .49442 .38985 L p .812 .667 .703 r
F P
0 g
s
.49442 .38985 m .47966 .43202 L .47579 .4299 L p .812 .667 .703 r
F P
0 g
s
.51493 .35522 m .49442 .38985 L .49181 .38842 L p .772 .703 .787 r
F P
0 g
s
.49442 .38985 m .51493 .35522 L .51591 .35569 L p .766 .695 .784 r
F P
0 g
s
.55841 .43733 m .56413 .47943 L .55875 .48096 L p .625 .456 .634 r
F P
0 g
s
.56413 .47943 m .55841 .43733 L .56282 .43591 L p .604 .442 .635 r
F P
0 g
s
.48675 .48066 m .49224 .4373 L .4967 .43867 L p .781 .575 .621 r
F P
0 g
s
.4967 .43867 m .49197 .48231 L .48675 .48066 L p .781 .575 .621 r
F P
0 g
s
.55965 .38913 m .5383 .35498 L .53735 .35547 L p .626 .583 .786 r
F P
0 g
s
.5383 .35498 m .55965 .38913 L .56219 .38768 L p .617 .579 .789 r
F P
0 g
s
.55965 .38913 m .57511 .43073 L .57884 .42872 L p .569 .473 .707 r
F P
0 g
s
.57884 .42872 m .56219 .38768 L .55965 .38913 L p .569 .473 .707 r
F P
0 g
s
.47211 .42763 m .48933 .38689 L .49181 .38842 L p .822 .679 .706 r
F P
0 g
s
.49181 .38842 m .47579 .4299 L .47211 .42763 L p .822 .679 .706 r
F P
0 g
s
.514 .35471 m .49181 .38842 L .48933 .38689 L p .778 .712 .79 r
F P
0 g
s
.49181 .38842 m .514 .35471 L .51493 .35522 L p .772 .703 .787 r
F P
0 g
s
.56282 .43591 m .56935 .47777 L .56413 .47943 L p .604 .442 .635 r
F P
0 g
s
.56282 .43591 m .56935 .47777 L .57438 .47598 L p .585 .428 .636 r
F P
0 g
s
.57438 .47598 m .56709 .43433 L .56282 .43591 L p .585 .428 .636 r
F P
0 g
s
.48163 .47874 m .4879 .43573 L .49224 .4373 L p .791 .585 .622 r
F P
0 g
s
.49224 .4373 m .48675 .48066 L .48163 .47874 L p .791 .585 .622 r
F P
0 g
s
.56219 .38768 m .53921 .35444 L .5383 .35498 L p .617 .579 .789 r
F P
0 g
s
.53921 .35444 m .56219 .38768 L .5646 .38612 L p .608 .576 .792 r
F P
0 g
s
.56219 .38768 m .57884 .42872 L .58235 .42657 L p .553 .464 .709 r
F P
0 g
s
.58235 .42657 m .5646 .38612 L .56219 .38768 L p .553 .464 .709 r
F P
0 g
s
.46864 .42521 m .48699 .38526 L .48933 .38689 L p .833 .693 .709 r
F P
0 g
s
.48933 .38689 m .47211 .42763 L .46864 .42521 L p .833 .693 .709 r
F P
0 g
s
.51312 .35415 m .48933 .38689 L .48699 .38526 L p .783 .721 .793 r
F P
0 g
s
.48933 .38689 m .51312 .35415 L .514 .35471 L p .778 .712 .79 r
F P
0 g
s
.53631 .71043 m .53606 .68615 L .5509 .694 L p .888 .646 .567 r
F P
0 g
s
.5509 .694 m .55154 .7203 L .53631 .71043 L p .888 .646 .567 r
F P
0 g
s
.54864 .66245 m .5509 .694 L .53606 .68615 L p .866 .706 .682 r
F P
0 g
s
.47663 .47656 m .4837 .43396 L .4879 .43573 L p .801 .596 .624 r
F P
0 g
s
.4879 .43573 m .48163 .47874 L .47663 .47656 L p .801 .596 .624 r
F P
0 g
s
.56709 .43433 m .57438 .47598 L .57918 .47406 L p .565 .414 .635 r
F P
0 g
s
.57918 .47406 m .57119 .4326 L .56709 .43433 L p .565 .414 .635 r
F P
0 g
s
.5646 .38612 m .54007 .35387 L .53921 .35444 L p .608 .576 .792 r
F P
0 g
s
.54007 .35387 m .5646 .38612 L .56685 .38447 L p .599 .573 .796 r
F P
0 g
s
.5646 .38612 m .58235 .42657 L .58564 .42428 L p .535 .455 .712 r
F P
0 g
s
.58564 .42428 m .56685 .38447 L .5646 .38612 L p .535 .455 .712 r
F P
0 g
s
.55036 .73631 m .55154 .7203 L .5688 .72934 L p .871 .512 .366 r
F P
0 g
s
.5688 .72934 m .56685 .74672 L .55036 .73631 L p .871 .512 .366 r
F P
0 g
s
.52583 .34494 m .52535 .34514 L .52534 .34512 L .672 .728 .891 r
F
.52613 .3453 m .51017 .3516 L p .52583 .34494 L F P
0 g
s
.52574 .34439 m .52646 .34529 L p .52559 .34451 L .672 .728 .891 r
F P
0 g
s
.52646 .34529 m .52638 .34529 L .52637 .34529 L .672 .728 .891 r
F
.52646 .34529 m .52637 .34529 L .52519 .34418 L F
.52646 .34529 m .52519 .34418 L .52521 .34417 L F
.50959 .35088 m .50908 .35015 L p .52464 .3453 L F P
0 g
s
.52672 .34562 m .52665 .34564 L .52665 .34563 L .672 .728 .891 r
F
.52672 .34562 m .52665 .34563 L .52474 .34377 L F
.52672 .34562 m .52474 .34377 L .52475 .34377 L F
.52704 .34601 m .52697 .34603 L .52696 .34602 L F
.52704 .34601 m .52696 .34602 L .52442 .34346 L F
.50864 .34939 m .50827 .34861 L p .51354 .3475 L F P
0 g
s
.52638 .34475 m .52638 .34477 L .5269 .3446 L .672 .728 .891 r
F
.52689 .34459 m .5269 .3446 L .54329 .33948 L F
.52638 .34475 m .5269 .3446 L .52689 .34459 L F
.52656 .3452 m .52656 .34519 L .52648 .34528 L F
.52656 .34519 m .5259 .34439 L .52647 .34528 L F
.52656 .34519 m .52647 .34528 L .52648 .34528 L F
.54272 .33876 m .54208 .33806 L p .52746 .34426 L F P
0 g
s
.52217 .33951 m .51736 .33394 L .52528 .34363 L .672 .728 .891 r
F
.52579 .34403 m .52561 .34404 L .5259 .34439 L F
.52609 .3444 m .5259 .34439 L .52656 .34519 L F
.52609 .3444 m .52656 .34519 L .52665 .3451 L F
.52579 .34403 m .5259 .34439 L .52609 .3444 L F
.52583 .34494 m .5272 .34493 L .5269 .3446 L F
.5272 .34493 m .54329 .33948 L p .5269 .3446 L F P
0 g
s
.52612 .34529 m .5272 .34493 L p .52583 .34494 L .672 .728 .891 r
F P
0 g
s
.5259 .34439 m .52586 .34439 L .52648 .34528 L .672 .728 .891 r
F
.52561 .34404 m .52558 .34404 L .52582 .34438 L F
.52585 .34438 m .52582 .34438 L .52648 .34528 L F
.52561 .34404 m .52582 .34438 L .52585 .34438 L F
.52514 .34364 m .52547 .34405 L p .52528 .34363 L F P
0 g
s
.52547 .34405 m .52672 .34562 L p .52556 .34402 L .672 .728 .891 r
F P
0 g
s
.52528 .34363 m .52547 .34405 L .52556 .34402 L .672 .728 .891 r
F
.52607 .34485 m .52585 .34496 L .52583 .34494 L F
.52495 .34529 m .50959 .35088 L .52464 .3453 L F
.50959 .35088 m .52612 .34529 L p .52583 .34494 L F P
0 g
s
.51017 .3516 m .50959 .35088 L p .52534 .34512 L .672 .728 .891 r
F P
0 g
s
.52535 .34514 m .51017 .3516 L .52534 .34512 L .672 .728 .891 r
F
.52578 .34529 m .51796 .34805 L .52495 .34529 L F
.52558 .34547 m .51796 .34805 L p .52578 .34529 L F P
0 g
s
.5249 .34535 m .52069 .34713 L .5256 .34551 L .672 .728 .891 r
F
.51796 .34805 m .50959 .35088 L p .52495 .34529 L F P
0 g
s
.51017 .3516 m .52218 .34686 L p .52069 .34713 L .672 .728 .891 r
F P
0 g
s
.52218 .34686 m .5256 .34551 L p .52069 .34713 L .672 .728 .891 r
F P
0 g
s
.51081 .35228 m .51017 .3516 L p .51858 .34803 L .672 .728 .891 r
F P
0 g
s
.5249 .34535 m .52031 .34761 L .51858 .34803 L .672 .728 .891 r
F
.52031 .34761 m .51081 .35228 L .51858 .34803 L F
.52414 .34622 m .51081 .35228 L p .5249 .34535 L F P
0 g
s
.52464 .3453 m .513 .34892 L .52389 .34591 L .672 .728 .891 r
F
.50908 .35015 m .51434 .34864 L p .513 .34892 L F P
0 g
s
.51434 .34864 m .52389 .34591 L p .513 .34892 L .672 .728 .891 r
F P
0 g
s
.52389 .34591 m .5177 .34768 L p .5207 .34624 L .672 .728 .891 r
F P
0 g
s
.5177 .34768 m .51487 .3482 L .5207 .34624 L .672 .728 .891 r
F
.5249 .34535 m .5256 .34551 L .5258 .34532 L F
.5274 .34647 m .52715 .34658 L .52708 .34649 L F
.5274 .34647 m .52708 .34649 L .5256 .34465 L F
.52629 .3448 m .52604 .3452 L .52585 .34496 L F
.54272 .33876 m .52604 .3452 L .52629 .3448 L F
.54272 .33876 m .52613 .3453 L p .52604 .3452 L F P
0 g
s
.52191 .34593 m .52389 .34591 L .5207 .34624 L .672 .728 .891 r
F
.52715 .34658 m .52708 .3466 L .527 .3465 L F
.52708 .34649 m .527 .3465 L .5256 .34465 L F
.52715 .34658 m .527 .3465 L .52708 .34649 L F
.5256 .34465 m .527 .3465 L .52442 .34346 L F
.527 .3465 m .52708 .3466 L .527 .3465 L F
.527 .3465 m .527 .3465 L .52442 .34346 L F
.52611 .34524 m .52612 .34529 L .52586 .34529 L F
.52509 .34437 m .52542 .34475 L .5254 .34478 L F
.52509 .34437 m .52535 .34471 L .52512 .34436 L F
.52612 .34529 m .52558 .34547 L p .52578 .34529 L F P
0 g
s
.5256 .34551 m .52613 .3453 L p .5258 .34532 L .672 .728 .891 r
F P
0 g
s
.5254 .34478 m .53007 .35022 L .53424 .35669 L .672 .728 .891 r
F
.52535 .34471 m .52578 .34529 L .52537 .34471 L F
.52535 .34471 m .52537 .34471 L .52512 .34436 L F
.52481 .34392 m .53531 .35633 L .52478 .34394 L F
.52611 .34524 m .52586 .34529 L .52578 .34529 L F
.52611 .34524 m .52578 .34529 L .52582 .34525 L F
.52578 .34529 m .5258 .34532 L .52588 .3452 L F
.5258 .34532 m .52613 .3453 L .52586 .34525 L F
.54329 .33948 m .54272 .33876 L p .52612 .34484 L F P
0 g
s
.52725 .34448 m .52683 .34491 L .53456 .34198 L .672 .728 .891 r
F
.52717 .34489 m .53456 .34198 L p .52683 .34491 L F P
0 g
s
.53191 .34303 m .5272 .34493 L .52739 .34444 L .672 .728 .891 r
F
.54329 .33948 m .53076 .34372 L p .53191 .34303 L F P
0 g
s
.53076 .34372 m .5272 .34493 L p .53191 .34303 L .672 .728 .891 r
F P
0 g
s
.54208 .33806 m .54138 .3374 L p .54088 .33764 L .672 .728 .891 r
F P
0 g
s
.52776 .34481 m .52889 .34449 L p .5273 .34479 L .672 .728 .891 r
F P
0 g
s
.53557 .35622 m .53635 .35592 L p .52716 .34529 L .672 .728 .891 r
F P
0 g
s
.54272 .33876 m .52585 .34496 L .52607 .34485 L .672 .728 .891 r
F
.52716 .34529 m .52559 .34346 L .52694 .34546 L F
.52559 .34346 m .5254 .34354 L .52694 .34546 L F
.53456 .34198 m .54272 .33876 L p .52817 .34414 L F P
0 g
s
.52725 .34448 m .53456 .34198 L .52817 .34414 L .672 .728 .891 r
F
.52746 .34426 m .52725 .34448 L .54272 .33876 L F
.54379 .34023 m .54329 .33948 L p .53191 .34303 L F P
0 g
s
.53191 .34303 m .52739 .34444 L .53009 .34375 L .672 .728 .891 r
F
.53191 .34303 m .53009 .34375 L .54379 .34023 L F
.52739 .34444 m .52782 .34445 L .54379 .34023 L F
.54208 .33806 m .52864 .34418 L p .52827 .3442 L F P
0 g
s
.54208 .33806 m .52793 .34423 L p .52746 .34426 L .672 .728 .891 r
F P
0 g
s
.52634 .34514 m .52612 .34529 L .5261 .34488 L .672 .728 .891 r
F
.52634 .34514 m .52614 .34493 L .52615 .3449 L F
.52559 .34346 m .52217 .33951 L .5254 .34354 L F
.52547 .34362 m .52528 .34363 L .52561 .34404 L F
.52547 .34362 m .52561 .34404 L .52579 .34403 L F
.5259 .34439 m .52561 .34404 L .52586 .34439 L F
.52561 .34404 m .52528 .34363 L .52558 .34404 L F
.52602 .34474 m .5239 .3421 L .52627 .34452 L F
.52217 .33951 m .52528 .34363 L .52547 .34362 L F
.52442 .34346 m .52481 .34392 L .52478 .34394 L F
.51736 .33394 m .52475 .34316 L p .52442 .34346 L F P
0 g
s
.52163 .3397 m .52509 .34437 L .52066 .33811 L .672 .728 .891 r
F
.51736 .33394 m .52514 .34364 L p .52528 .34363 L F P
0 g
s
.52586 .344 m .52358 .3417 L .52099 .33848 L .672 .728 .891 r
F
.52163 .3397 m .52066 .33811 L .52055 .338 L F
.52163 .3397 m .52029 .3376 L .51964 .33678 L F
.52478 .34394 m .52512 .34434 L .52509 .34437 L F
.52509 .34437 m .52512 .34436 L .52038 .33771 L F
.52512 .34434 m .53531 .35633 L .52509 .34437 L F
.52578 .34529 m .52588 .3452 L .52557 .34477 L F
.52521 .34417 m .52519 .34418 L .52442 .34346 L F
.52455 .34334 m .52523 .34418 L .52442 .34346 L F
.52542 .34478 m .52557 .34477 L .52099 .33848 L F
.52578 .34529 m .52557 .34477 L .52542 .34478 L F
.52864 .34418 m .52764 .34463 L p .52746 .34426 L F P
0 g
s
.52795 .34603 m .52697 .34506 L .52786 .34608 L .672 .728 .891 r
F
.52707 .34465 m .52889 .34449 L .52782 .34445 L F
.52475 .34316 m .52574 .34439 L p .52523 .34418 L F P
0 g
s
.52574 .34439 m .52559 .34451 L .52523 .34418 L .672 .728 .891 r
F
.52475 .34316 m .52523 .34418 L .52455 .34334 L F
.5256 .34476 m .52602 .34474 L .5239 .34209 L F
.52598 .34476 m .5239 .3421 L .52602 .34474 L F
.52612 .34484 m .52583 .34494 L .52632 .34479 L F
.52615 .3449 m .52557 .34428 L .52614 .34494 L F
.52614 .34497 m .52683 .34491 L .52618 .34494 L F
.52614 .34507 m .52683 .34491 L .52614 .34497 L F
.52588 .3452 m .52618 .34494 L .52607 .34474 L F
.52614 .34494 m .52598 .34476 L p .52605 .34478 L F P
0 g
s
.52612 .34484 m .52632 .34479 L .52617 .34482 L .672 .728 .891 r
F
.52618 .34494 m .52605 .34478 L .52666 .34492 L F
.52614 .34494 m .52605 .34478 L .52618 .34494 L F
.52614 .34494 m .52615 .34494 L p .52615 .3449 L F P
0 g
s
.52614 .34493 m .5261 .34488 L .52615 .3449 L .672 .728 .891 r
F
.52504 .34426 m .52473 .34379 L .52471 .34379 L F
.52666 .34492 m .52627 .34452 L .52666 .34492 L F
.52471 .34379 m .52099 .33848 L .52038 .33771 L F
.52475 .34377 m .52474 .34377 L .52442 .34346 L F
.52473 .34379 m .52099 .33848 L .52471 .34379 L F
.52509 .34437 m .52038 .33771 L .52029 .3376 L F
.52217 .33951 m .52045 .33765 L .52007 .33708 L F
.52045 .33765 m .51964 .33678 L .52007 .33708 L F
.52557 .34477 m .5256 .34476 L .5239 .34209 L F
.5264 .34441 m .52033 .33765 L .52217 .33951 L F
.52055 .338 m .52066 .33811 L .52029 .3376 L F
.5263 .3445 m .52099 .33848 L .5264 .34441 L F
.51736 .33394 m .52163 .3397 L .51964 .33678 L F
.52099 .33848 m .5171 .33405 L .52033 .33765 L F
.52099 .33848 m .52033 .33765 L .5264 .34441 L F
.52007 .33708 m .51964 .33678 L .51736 .33394 L F
.51763 .33385 m .51736 .33394 L p .51964 .33678 L F P
0 g
s
.52376 .34192 m .5239 .34209 L .51844 .33357 L .672 .728 .891 r
F
.52557 .34477 m .5239 .34209 L .52376 .34192 L F
.52033 .33765 m .5171 .33405 L .51964 .33678 L F
.52033 .33765 m .51964 .33678 L .52217 .33951 L F
.52677 .34493 m .5263 .3445 L .52685 .34493 L F
.52685 .34493 m .5263 .3445 L .5264 .34441 L F
.52683 .34491 m .52665 .3451 L .52717 .34489 L F
.5272 .34493 m .52666 .34511 L p .52685 .34493 L F P
0 g
s
.52708 .34531 m .5263 .3445 L .52716 .34529 L .672 .728 .891 r
F
.52614 .34489 m .52683 .34491 L .52701 .34473 L F
.52614 .34489 m .52701 .34473 L .52688 .34465 L F
.52599 .34495 m .52719 .34454 L .52713 .34453 L F
.52617 .34482 m .52632 .34479 L .52638 .34477 L F
.52617 .34482 m .52638 .34477 L .52638 .34475 L F
.52598 .34476 m .52627 .34452 L .52666 .34492 L F
.5262 .34492 m .52607 .34474 L p .52618 .34494 L F P
0 g
s
.52099 .33848 m .52557 .34477 L .52376 .34192 L .672 .728 .891 r
F
.5239 .3421 m .51631 .33436 L .5239 .34209 L F
.5239 .34209 m .51631 .33436 L .52358 .3417 L F
.52358 .3417 m .51631 .33436 L .52099 .33848 L F
.52598 .34476 m .51631 .33436 L p .5239 .3421 L F P
0 g
s
.52339 .34146 m .51631 .33436 L .52304 .34157 L .672 .728 .891 r
F
.52688 .34465 m .52701 .34473 L .52719 .34454 L F
.52712 .34452 m .52713 .34453 L .52725 .34448 L F
.52713 .34453 m .52719 .34454 L .52725 .34448 L F
.52739 .34444 m .52696 .34472 L .52681 .34462 L F
.52583 .34495 m .52713 .34453 L .52712 .34452 L F
.52739 .34444 m .52638 .34475 L .52782 .34445 L F
.52638 .34475 m .52665 .34476 L .52782 .34445 L F
.52626 .34504 m .52665 .3451 L .52683 .34491 L F
.52588 .3452 m .52607 .34474 L .52607 .34474 L F
.52542 .34475 m .53531 .35633 L .5254 .34478 L F
.52639 .3452 m .52612 .34529 L p .52634 .34514 L F P
0 g
s
.52634 .34514 m .52665 .3451 L .52626 .34504 L .672 .728 .891 r
F
.52639 .3452 m .52634 .34514 L .52665 .34493 L F
.52614 .34494 m .52666 .34492 L .52618 .34494 L F
.52618 .34494 m .52683 .34491 L .52614 .34489 L F
.5262 .34492 m .5262 .34492 L p .52615 .3449 L F P
0 g
s
.52668 .34493 m .5263 .3445 L .52672 .34493 L .672 .728 .891 r
F
.52565 .34428 m .52556 .34427 L .52615 .3449 L F
.52339 .34146 m .52556 .34427 L .52565 .34428 L F
.52339 .34146 m .52304 .34157 L .52556 .34427 L F
.52557 .34428 m .52516 .34384 L .52556 .34428 L F
.52516 .34384 m .52304 .34157 L .52513 .34385 L F
.51631 .33436 m .52302 .34158 L p .52304 .34157 L F P
0 g
s
.52302 .34158 m .52513 .34385 L p .52304 .34157 L .672 .728 .891 r
F P
0 g
s
.52513 .34385 m .52614 .34494 L p .52516 .34384 L .672 .728 .891 r
F P
0 g
s
.52339 .34146 m .52565 .34428 L .52534 .34458 L .672 .728 .891 r
F
.52607 .34474 m .52607 .34473 L p .52607 .34474 L F P
0 g
s
.52627 .34452 m .5239 .3421 L .52627 .34452 L .672 .728 .891 r
F
.5239 .3421 m .5239 .34209 L .52627 .34452 L F
.52581 .34405 m .5239 .34209 L .52586 .344 L F
.5239 .34209 m .52358 .3417 L .52586 .344 L F
.52607 .34473 m .51844 .33357 L p .5239 .34209 L F P
0 g
s
.52602 .34474 m .52607 .34473 L .5239 .34209 L .672 .728 .891 r
F
.52569 .34422 m .5262 .34492 L .52615 .3449 L F
.52372 .34133 m .5257 .3442 L .52569 .34422 L F
.5257 .3442 m .5262 .34492 L .52569 .34422 L F
.52681 .34462 m .52674 .34475 L .5266 .34468 L F
.52674 .34475 m .52665 .34493 L .5266 .34468 L F
.52557 .34428 m .52556 .34428 L .52614 .34494 L F
.52565 .34428 m .52615 .3449 L .52547 .34463 L F
.52613 .34489 m .5261 .34488 L .5261 .34488 L F
.52613 .34489 m .5261 .34488 L .5261 .34484 L F
.52615 .3449 m .52613 .34489 L .5261 .34484 L F
.52608 .34487 m .52613 .34489 L .52614 .34489 L F
.52612 .34486 m .52614 .34489 L .52713 .34453 L F
.52608 .34487 m .52614 .34489 L .52612 .34486 L F
.5266 .34468 m .52665 .34493 L .5261 .34484 L F
.52665 .34493 m .52634 .34514 L .52618 .34494 L F
.5262 .34492 m .5262 .34492 L p .52618 .34494 L F P
0 g
s
.52618 .34494 m .52666 .34492 L .52668 .34493 L .672 .728 .891 r
F
.52665 .34493 m .52618 .34494 L .5261 .34484 L F
.52638 .34475 m .52615 .34482 L .52665 .34476 L F
.5261 .34484 m .52546 .34527 L .52542 .34515 L F
.52588 .3452 m .52607 .34473 L .5256 .34476 L F
.5261 .34484 m .52611 .34524 L .52546 .34527 L F
.52615 .34494 m .52614 .34494 L p .52618 .34494 L F P
0 g
s
.52599 .34495 m .52618 .34494 L .52615 .3449 L .672 .728 .891 r
F
.52599 .34495 m .52615 .3449 L .52614 .3449 L F
.52602 .34509 m .52614 .34507 L .52614 .34497 L F
.52602 .34509 m .52618 .34494 L .52599 .34495 L F
.52597 .34512 m .52597 .34515 L .52618 .34494 L F
.52588 .3452 m .52597 .34515 L .52597 .34512 L F
.52588 .3452 m .5259 .34522 L .52597 .34515 L F
.52464 .3453 m .52456 .34536 L .5249 .34525 L F
.52456 .34536 m .52389 .34591 L .5249 .34525 L F
.52487 .34516 m .52469 .34563 L .52191 .34593 L F
.52518 .34529 m .52634 .34514 L .52626 .34504 L F
.52601 .34512 m .52587 .3452 L .52601 .3451 L F
.52587 .3452 m .52488 .34579 L .52601 .3451 L F
.52488 .34579 m .52487 .34578 L .52601 .3451 L F
.52601 .3451 m .5242 .34618 L .52603 .34498 L F
.5242 .34618 m .5242 .34618 L .52603 .34498 L F
.52605 .34486 m .52593 .34534 L .52604 .34486 L F
.52613 .3453 m .5263 .34523 L p .52593 .34527 L F P
0 g
s
.5263 .34523 m .52639 .3452 L p .52593 .34527 L .672 .728 .891 r
F P
0 g
s
.52586 .34525 m .52593 .34527 L .52639 .3452 L .672 .728 .891 r
F
.5259 .34522 m .52623 .34568 L .52618 .34494 L F
.52623 .34568 m .52643 .34554 L .52618 .34494 L F
.52579 .34547 m .52575 .34545 L .52588 .3454 L F
.52575 .34545 m .52557 .34538 L .52588 .3454 L F
.52618 .34495 m .52597 .34532 L .52598 .34525 L F
.5262 .34492 m .52597 .34532 L .52618 .34495 L F
.5258 .34532 m .5259 .34522 L .52588 .3452 L F
.52582 .34525 m .52578 .34529 L .52464 .3453 L F
.52517 .34531 m .52639 .3452 L .52634 .34514 L F
.5249 .34535 m .52517 .34532 L .52517 .34531 L F
.52517 .34532 m .52639 .3452 L .52517 .34531 L F
.5262 .34492 m .52597 .34536 L .52597 .34532 L F
.5258 .34532 m .52607 .34569 L .5259 .34522 L F
.52588 .3454 m .52557 .34538 L .52601 .34512 L F
.52682 .34649 m .52717 .34639 L .52684 .3459 L F
.52661 .34599 m .52684 .3459 L .52618 .34494 L F
.52682 .34649 m .52684 .3459 L .52661 .34599 L F
.52639 .3452 m .52615 .34494 L p .52618 .34494 L F P
0 g
s
.52517 .34531 m .52634 .34514 L .52518 .34529 L .672 .728 .891 r
F
.52618 .34494 m .52653 .34545 L .52632 .34511 L F
.52639 .3452 m .52618 .34494 L .52652 .34493 L F
.52618 .34494 m .52632 .34511 L .5262 .34492 L F
.5262 .34492 m .52639 .3452 L p .52597 .34536 L F P
0 g
s
.52716 .34529 m .52694 .34546 L .53557 .35622 L .672 .728 .891 r
F
.52665 .3451 m .52656 .34519 L .53557 .35622 L F
.52685 .34555 m .52656 .3452 L .52672 .34562 L F
.52718 .34596 m .52685 .34555 L .52704 .34601 L F
.53531 .35633 m .53557 .35622 L p .52718 .34596 L F P
0 g
s
.52704 .34601 m .53531 .35633 L p .52718 .34596 L .672 .728 .891 r
F P
0 g
s
.53635 .35592 m .5266 .34543 L p .52693 .34539 L .672 .728 .891 r
F P
0 g
s
.52672 .34562 m .52704 .34601 L p .52685 .34555 L .672 .728 .891 r
F P
0 g
s
.52661 .3454 m .527 .34586 L .52702 .34584 L .672 .728 .891 r
F
.52656 .3452 m .52648 .34528 L .52672 .34562 L F
.5266 .34543 m .52639 .3452 L p .52693 .34539 L F P
0 g
s
.52615 .3449 m .5266 .34541 L .52661 .3454 L .672 .728 .891 r
F
.5266 .34541 m .527 .34586 L .52661 .3454 L F
.52685 .34493 m .52665 .34493 L .52719 .34457 L F
.52723 .34458 m .52719 .34457 L .52739 .34444 L F
.52685 .34493 m .52719 .34457 L .52723 .34458 L F
.52639 .3452 m .52665 .3451 L p .52634 .34514 L F P
0 g
s
.52666 .34511 m .52639 .3452 L p .52665 .34493 L .672 .728 .891 r
F P
0 g
s
.52666 .34511 m .52665 .34493 L .52685 .34493 L .672 .728 .891 r
F
.52374 .34132 m .52537 .34371 L p .52372 .34133 L F P
0 g
s
.5254 .34375 m .5262 .34492 L p .52539 .34375 L .672 .728 .891 r
F P
0 g
s
.52537 .34371 m .52536 .34371 L .52372 .34133 L .672 .728 .891 r
F
.52537 .34371 m .5254 .34375 L p .52536 .34371 L F P
0 g
s
.5254 .34375 m .52539 .34375 L .52536 .34371 L .672 .728 .891 r
F
.52099 .33848 m .52376 .34192 L .51844 .33357 L F
.52666 .34492 m .52581 .34405 L .52586 .344 L F
.52372 .34133 m .5257 .34424 L .52339 .34146 L F
.5257 .34424 m .52565 .34428 L .52339 .34146 L F
.5257 .34424 m .52615 .3449 L .52565 .34428 L F
.52621 .34429 m .5262 .3443 L .52621 .3443 L F
.52615 .34482 m .52623 .34485 L .52665 .34476 L F
.52674 .34469 m .5264 .34489 L .52643 .34471 L F
.5262 .34492 m .52598 .34525 L .52605 .34486 L F
.52601 .34512 m .52603 .34498 L .52615 .3449 L F
.52617 .34493 m .5268 .34482 L .52614 .3449 L F
.52643 .3449 m .52616 .34482 L .52643 .34492 L F
.52616 .34482 m .52615 .3449 L .52643 .34492 L F
.52619 .34495 m .52615 .3449 L .52623 .34484 L F
.52628 .34485 m .52623 .34484 L .52643 .34471 L F
.52627 .34486 m .5268 .34482 L .52665 .34476 L F
.52614 .3449 m .52632 .34488 L .52627 .34486 L F
.52632 .34488 m .5268 .34482 L .52627 .34486 L F
.52627 .34452 m .52627 .34452 L .52666 .34492 L F
.52693 .34539 m .52639 .3452 L .52652 .34493 L F
.52643 .34492 m .52661 .3454 L .52679 .34504 L F
.52553 .34413 m .52549 .34408 L .52539 .34447 L F
.52529 .34337 m .52524 .34336 L .52615 .3449 L F
.52565 .34428 m .52547 .34463 L .52534 .34458 L F
.52576 .34469 m .52557 .34378 L .52547 .34463 L F
.52518 .34326 m .52489 .34333 L .52615 .3449 L F
.52621 .34429 m .52529 .34337 L .52615 .3449 L F
.52549 .34408 m .52461 .34298 L .52604 .34424 L F
.52568 .34432 m .52557 .3438 L .52557 .3438 L F
.52576 .34469 m .52568 .34432 L .52568 .34432 L F
.52519 .34524 m .52602 .34509 L .52599 .34495 L F
.52583 .34495 m .52613 .34489 L .52608 .34487 L F
.5262 .34492 m .52604 .34486 L .52615 .3449 L F
.52614 .3449 m .52615 .3449 L .52614 .34489 L F
.52729 .34444 m .52583 .34495 L .52725 .34448 L F
.5261 .34484 m .52583 .34495 L .52729 .34444 L F
.5261 .34484 m .52514 .34528 L .52518 .34513 L F
.5261 .34484 m .52577 .34494 L .52584 .34493 L F
.52605 .34486 m .52604 .34486 L .52604 .34486 L F
.52615 .3449 m .52605 .34486 L .52605 .34486 L F
.52605 .34486 m .52604 .34486 L .52605 .34486 L F
.52542 .34515 m .52546 .34527 L .52514 .34528 L F
.5249 .34535 m .52517 .34531 L .52518 .34529 L F
.5249 .34535 m .52518 .34529 L .52519 .34524 L F
.52518 .34529 m .52602 .34509 L .52519 .34524 L F
.52583 .34495 m .5249 .34535 L .52599 .34495 L F
.5261 .34484 m .52508 .34556 L .5249 .34535 L F
.52508 .34556 m .52414 .34622 L .52482 .34545 L F
.52508 .34556 m .52482 .34545 L .5249 .34535 L F
.5383 .35498 m .53921 .35444 L p .53114 .34823 L F P
0 g
s
.52599 .34488 m .52584 .34493 L .52601 .34489 L .672 .728 .891 r
F
.52583 .34495 m .52599 .34495 L .52613 .34489 L F
.5249 .34535 m .5258 .34532 L .52586 .34525 L F
.52603 .34498 m .52453 .34597 L .52604 .34488 L F
.52453 .34597 m .52414 .34622 L .52451 .34596 L F
.52453 .34597 m .52451 .34596 L .52604 .34488 L F
.53921 .35444 m .54007 .35387 L p .53487 .35036 L F P
0 g
s
.52588 .3454 m .52601 .34512 L .52597 .34532 L .672 .728 .891 r
F
.52598 .34525 m .52593 .34534 L .52605 .34486 L F
.52599 .34488 m .52601 .34489 L .52603 .34489 L F
.52603 .34498 m .52604 .34488 L .5261 .34484 L F
.52604 .34487 m .52603 .34489 L .52612 .34487 L F
.52599 .34488 m .52603 .34489 L .52604 .34487 L F
.5261 .34484 m .52599 .34488 L .52612 .34487 L F
.52518 .34326 m .52339 .34146 L .52489 .34333 L F
.52529 .34337 m .52518 .34326 L .52524 .34336 L F
.52619 .34427 m .52439 .3427 L .52339 .34146 L F
.52463 .34301 m .52436 .34209 L .5239 .3416 L F
.52539 .34447 m .52499 .34345 L .52463 .34301 L F
.52328 .34181 m .52327 .3418 L .52449 .34283 L F
.5245 .34284 m .52449 .34283 L .52619 .34427 L F
.52339 .34146 m .52535 .3446 L .52439 .34271 L F
.52328 .34181 m .52449 .34283 L .5245 .34284 L F
.52535 .3446 m .52539 .34447 L .52463 .34301 L F
.5245 .34284 m .52463 .34301 L .52376 .34133 L F
.52535 .3446 m .52463 .34301 L .5245 .34284 L F
.52303 .3416 m .52309 .34158 L .52439 .3427 L F
.52449 .34283 m .52439 .3427 L .52619 .34427 L F
.52303 .3416 m .52439 .3427 L .52449 .34283 L F
.52439 .34271 m .52376 .34133 L .5237 .34135 L F
.52535 .3446 m .5245 .34284 L .52439 .34271 L F
.5245 .34284 m .52376 .34133 L .52439 .34271 L F
.52499 .34345 m .5241 .34121 L .52463 .34301 L F
.52328 .34181 m .52303 .3416 L .52327 .3418 L F
.52623 .34568 m .52682 .34649 L .52643 .34554 L F
.52607 .34569 m .52619 .34562 L .5259 .34522 L F
.5274 .34647 m .53531 .35633 L p .52708 .3466 L F P
0 g
s
.52682 .34649 m .53424 .35669 L .52717 .34639 L .672 .728 .891 r
F
.52653 .34545 m .52717 .34639 L .52654 .34544 L F
.53424 .35669 m .52719 .34638 L p .52717 .34639 L F P
0 g
s
.52719 .34638 m .52686 .34589 L p .52717 .34639 L .672 .728 .891 r
F P
0 g
s
.52646 .34529 m .52672 .34562 L p .52638 .34529 L .672 .728 .891 r
F P
0 g
s
.52686 .34589 m .5262 .34492 L p .52685 .3459 L .672 .728 .891 r
F P
0 g
s
.52717 .34639 m .52686 .34589 L .52685 .3459 L .672 .728 .891 r
F
.5322 .34383 m .53341 .34354 L p .53202 .34384 L F P
0 g
s
.53341 .34354 m .54422 .34099 L p .53255 .3436 L .672 .728 .891 r
F P
0 g
s
.53341 .34354 m .5322 .34383 L p .53488 .34297 L .672 .728 .891 r
F P
0 g
s
.52554 .34415 m .52604 .34424 L .52627 .34444 L .672 .728 .891 r
F
.5268 .34482 m .52706 .34479 L .52706 .34478 L F
.52597 .34532 m .52601 .34512 L .52622 .34499 L F
.52618 .34494 m .5268 .34483 L .52617 .34493 L F
.52615 .34494 m .52618 .34494 L .52668 .34493 L F
.53199 .35727 m .53084 .35748 L p .52755 .34954 L F P
0 g
s
.52601 .34512 m .52615 .3449 L .52619 .34495 L .672 .728 .891 r
F
.52556 .34512 m .52622 .34499 L .52568 .34502 L F
.52622 .34499 m .52755 .34474 L .52618 .34494 L F
.52622 .34499 m .52618 .34494 L .52568 .34502 L F
.52617 .34493 m .5268 .34483 L .5268 .34482 L F
.52643 .34492 m .52615 .3449 L .52661 .3454 L F
.5264 .34489 m .52622 .34499 L .52628 .34485 L F
.52622 .34499 m .52601 .34512 L .52619 .34495 L F
.52794 .34467 m .52793 .34465 L .52755 .34471 L F
.53313 .357 m .53199 .35727 L p .52671 .34706 L F P
0 g
s
.51938 .34685 m .52163 .34632 L p .5207 .34624 L .672 .728 .891 r
F P
0 g
s
.52518 .34513 m .52514 .34528 L .52464 .3453 L .672 .728 .891 r
F
.52389 .34591 m .52592 .34533 L p .5249 .34525 L F P
0 g
s
.52566 .34529 m .52469 .34563 L .52487 .34516 L .672 .728 .891 r
F
.52682 .34499 m .52661 .3454 L .52702 .34584 L F
.52788 .34629 m .52745 .34581 L .52802 .34628 L F
.51081 .35228 m .52414 .34622 L p .52244 .34662 L F P
0 g
s
.52051 .34826 m .51152 .35294 L p .52244 .34662 L .672 .728 .891 r
F P
0 g
s
.52051 .34826 m .52152 .34773 L p .519 .34878 L .672 .728 .891 r
F P
0 g
s
.52737 .34572 m .52668 .34493 L .52744 .34569 L .672 .728 .891 r
F
.52549 .34408 m .52604 .34424 L .52554 .34415 L F
.5262 .3443 m .52615 .3449 L .52621 .3443 L F
.52508 .34396 m .52627 .34444 L .52616 .34458 L F
.52568 .34432 m .52603 .34475 L .52557 .3438 L F
.52615 .34482 m .5261 .34484 L .52623 .34485 L F
.5261 .34484 m .52612 .34487 L .52623 .34485 L F
.52643 .34471 m .52615 .3449 L .5261 .34484 L F
.5268 .34484 m .5268 .34483 L .52568 .34502 L F
.52628 .34507 m .52622 .34499 L .52674 .34469 L F
.52615 .3449 m .52603 .34498 L .5261 .34484 L F
.52577 .34494 m .52568 .34502 L .52665 .34476 L F
.52616 .34482 m .52616 .34482 L .52643 .3449 L F
.52619 .34495 m .52623 .34484 L .52628 .34485 L F
.5264 .34489 m .52628 .34485 L .52643 .34471 L F
.52746 .34426 m .5261 .34484 L .52729 .34444 L F
.5264 .34471 m .52643 .34471 L .5261 .34484 L F
.52621 .3443 m .52616 .34482 L .52643 .3449 L F
.52668 .34493 m .52666 .34492 L .52666 .34492 L F
.52615 .34491 m .52603 .34475 L .52675 .34493 L F
.52603 .34475 m .52567 .3443 L .52611 .34456 L F
.52663 .34486 m .52657 .34483 L .52674 .34469 L F
.52657 .34494 m .52657 .34483 L .52663 .34486 L F
.52755 .34474 m .52755 .34473 L .5268 .34484 L F
.5268 .34485 m .5268 .34484 L .52568 .34502 L F
.5272 .34493 m .52685 .34493 L .52739 .34444 L F
.52755 .34474 m .5268 .34484 L .5268 .34485 L F
.52568 .34502 m .52618 .34494 L .52617 .34493 L F
.52602 .34493 m .52617 .34493 L .52614 .3449 L F
.52568 .34502 m .52602 .34496 L .52602 .34493 L F
.52602 .34496 m .52617 .34493 L .52602 .34493 L F
.52474 .3453 m .5207 .34624 L .52435 .34543 L F
.52557 .34477 m .52588 .3452 L .5256 .34476 L F
.52604 .34486 m .52592 .34533 L .52543 .3447 L F
.52546 .34464 m .52543 .3447 L .52536 .34461 L F
.52604 .34486 m .52543 .3447 L .52546 .34464 L F
.52625 .34503 m .52776 .34481 L .52622 .34499 L F
.5268 .34483 m .52706 .34479 L .5268 .34482 L F
.52657 .34494 m .52647 .34491 L .52657 .34483 L F
.52629 .34439 m .52643 .3449 L .52682 .34499 L F
.52643 .3449 m .52643 .34492 L .52662 .34495 L F
.52639 .3452 m .52579 .34547 L p .52632 .34511 L F P
0 g
s
.52597 .34532 m .52622 .34499 L .52628 .34507 L .672 .728 .891 r
F
.52615 .34494 m .52659 .34542 L p .52615 .3449 L F P
0 g
s
.52593 .34534 m .52592 .34533 L .52604 .34486 L .672 .728 .891 r
F
.52657 .34494 m .52632 .34511 L .52647 .34491 L F
.52632 .34511 m .52598 .34535 L .52629 .34507 L F
.52702 .34532 m .52652 .34493 L .52668 .34493 L F
.53635 .35592 m .52689 .34535 L .52702 .34532 L F
.52689 .34535 m .52652 .34493 L .52702 .34532 L F
.52598 .34535 m .52597 .34535 L .52647 .34491 L F
.52597 .34535 m .52597 .34532 L .52647 .34491 L F
.52598 .34525 m .52597 .34536 L .52591 .34536 L F
.52592 .34533 m .52639 .3452 L p .52599 .34508 L F P
0 g
s
.52626 .34504 m .52634 .34514 L .52648 .345 L .672 .728 .891 r
F
.52634 .34514 m .52639 .3452 L .52648 .345 L F
.52716 .34529 m .52677 .34493 L .52685 .34493 L F
.52639 .3452 m .52776 .34481 L p .52648 .345 L F P
0 g
s
.52634 .34514 m .52632 .34511 L .52649 .34499 L .672 .728 .891 r
F
.52622 .34499 m .52776 .34481 L .5273 .34479 L F
.52634 .34514 m .52649 .34499 L .52696 .34467 L F
.52639 .3452 m .52634 .34514 L .52696 .34467 L F
.52643 .3449 m .52662 .34495 L .52682 .34499 L F
.5268 .34482 m .52706 .34478 L .52681 .34477 L F
.52696 .34472 m .52665 .34493 L .52681 .34462 L F
.52665 .34476 m .52706 .34478 L .52707 .34465 L F
.52681 .34501 m .52665 .34496 L .52696 .34467 L F
.52655 .34497 m .52685 .34493 L .52665 .34493 L F
.52603 .34475 m .52615 .34491 L .52612 .34476 L F
.52622 .34499 m .52619 .34495 L .52628 .34485 L F
.52632 .34511 m .52629 .34507 L .52647 .34491 L F
.52528 .34517 m .52625 .34503 L .52622 .34499 L F
.52531 .34518 m .52776 .34481 L .52528 .34517 L F
.52621 .34498 m .52655 .34497 L .52637 .34491 L F
.52624 .34502 m .5259 .34521 L .52615 .34491 L F
.52603 .34475 m .52612 .34476 L .52557 .3438 L F
.52568 .34432 m .52557 .3438 L .52568 .34432 L F
.52553 .34413 m .52557 .34378 L .52549 .34408 L F
.52613 .34477 m .52557 .34377 L .52557 .34378 L F
.52624 .34438 m .52643 .34492 L .52629 .34439 L F
.52616 .34458 m .52627 .34444 L .52683 .34493 L F
.52697 .34494 m .52681 .34501 L p .52696 .34467 L F P
0 g
s
.52755 .34473 m .52755 .34471 L .5268 .34483 L .672 .728 .891 r
F
.52755 .34473 m .5268 .34483 L .5268 .34484 L F
.52706 .34479 m .52889 .34449 L .52707 .34465 L F
.52764 .34463 m .52697 .34494 L p .52696 .34467 L F P
0 g
s
.52681 .34501 m .52764 .34463 L p .52683 .34496 L .672 .728 .891 r
F P
0 g
s
.5261 .34484 m .52619 .34486 L .52612 .34483 L .672 .728 .891 r
F
.52619 .34486 m .52624 .34487 L .52619 .34485 L F
.52615 .34491 m .52618 .34487 L .52612 .34476 L F
.52619 .34486 m .52619 .34485 L .52612 .34483 L F
.5261 .34484 m .52615 .34491 L .52624 .34487 L F
.52615 .34491 m .52619 .34487 L .52618 .34487 L F
.52612 .34483 m .5262 .34486 L .52612 .34483 L F
.52615 .34478 m .52619 .34485 L p .52612 .34483 L F P
0 g
s
.52619 .34485 m .5262 .34486 L p .52612 .34483 L .672 .728 .891 r
F P
0 g
s
.52612 .34483 m .52624 .34487 L .52706 .34452 L .672 .728 .891 r
F
.52712 .34442 m .52706 .34452 L .53514 .34109 L F
.52789 .34464 m .53341 .34354 L .53255 .3436 L F
.52685 .34493 m .52631 .34439 L .52682 .34499 L F
.52631 .34439 m .52629 .34439 L .52682 .34499 L F
.52622 .3443 m .52621 .3443 L .52682 .34499 L F
.52616 .34458 m .52683 .34493 L .52675 .34493 L F
.5249 .34525 m .52592 .34533 L .52599 .34508 L F
.52592 .34533 m .52589 .34533 L .52543 .3447 L F
.52543 .3447 m .52543 .3447 L .52536 .34461 L F
.52592 .34533 m .52543 .3447 L .52543 .3447 L F
.52469 .34608 m .52051 .34826 L p .5248 .34588 L F P
0 g
s
.52745 .34581 m .52737 .34572 L .52754 .3458 L .672 .728 .891 r
F
.52737 .34572 m .52744 .34569 L .52754 .3458 L F
.53635 .35592 m .52788 .34629 L .52802 .34628 L F
.52734 .34559 m .52702 .34584 L .53635 .35592 L F
.53635 .35592 m .53735 .35547 L p .52795 .34603 L F P
0 g
s
.52795 .34603 m .52786 .34608 L .53635 .35592 L .672 .728 .891 r
F
.52745 .34581 m .52754 .3458 L .52802 .34628 L F
.52802 .34628 m .52708 .34531 L .52716 .34529 L F
.52697 .34506 m .52684 .34502 L .5278 .34612 L F
.52786 .34608 m .5278 .34612 L .53635 .35592 L F
.52697 .34506 m .5278 .34612 L .52786 .34608 L F
.52572 .34519 m .52566 .34529 L .52554 .34527 L F
.52572 .34519 m .52554 .34527 L .52516 .34521 L F
.52577 .34473 m .52576 .34469 L .52576 .34469 L F
.52589 .34531 m .52577 .34473 L .52589 .34532 L F
.52534 .34458 m .52589 .34533 L .5258 .34531 L F
.5259 .34491 m .52572 .34519 L .52516 .34521 L F
.52579 .34547 m .52414 .34622 L p .52557 .34538 L F P
0 g
s
.5242 .34618 m .52414 .34622 L .5242 .34618 L .672 .728 .891 r
F
.52414 .34622 m .52496 .34585 L p .52327 .34642 L F P
0 g
s
.52586 .34539 m .52628 .34596 L .52585 .34539 L .672 .728 .891 r
F
.52607 .34569 m .53424 .35669 L .52619 .34562 L F
.52628 .34596 m .53424 .35669 L .52627 .34596 L F
.52628 .34596 m .52627 .34596 L .52585 .34539 L F
.5258 .34531 m .52586 .34539 L .52585 .34539 L F
.52653 .34545 m .52654 .34544 L .5262 .34492 L F
.52639 .3452 m .52652 .34544 L .52597 .34536 L F
.52596 .34539 m .52639 .3452 L p .52591 .34539 L F P
0 g
s
.52501 .34574 m .52596 .34539 L .52591 .34539 L .672 .728 .891 r
F
.52463 .34542 m .52551 .34523 L .52464 .34541 L F
.52628 .34507 m .52655 .34497 L .52621 .34498 L F
.52659 .34496 m .52652 .34498 L .52639 .34494 L F
.52652 .34498 m .52601 .34517 L .52639 .34494 L F
.52601 .34517 m .5259 .34521 L .52601 .34514 L F
.52599 .34508 m .52639 .3452 L .52626 .34504 L F
.52601 .34517 m .52601 .34514 L .52639 .34494 L F
.52625 .3448 m .52615 .34491 L .52597 .34489 L F
.52615 .34491 m .52607 .34504 L .52621 .34498 L F
.52582 .34496 m .52605 .34503 L .52568 .34432 L F
.52607 .34504 m .52628 .34507 L .52621 .34498 L F
.52586 .34525 m .5249 .34557 L .5259 .34521 L F
.5249 .34557 m .52389 .34591 L .52491 .34555 L F
.5249 .34557 m .52491 .34555 L .5259 .34521 L F
.52582 .34496 m .52586 .34498 L .52587 .34497 L F
.52586 .34498 m .52603 .34505 L .52587 .34497 L F
.52587 .34497 m .52603 .34505 L .52605 .34503 L F
.52598 .34519 m .52628 .34507 L .52607 .34504 L F
.52592 .34533 m .52571 .3453 L .5263 .3451 L F
.52591 .34529 m .52667 .345 L .52594 .34524 L F
.52639 .3452 m .52592 .34533 L p .5263 .3451 L F P
0 g
s
.52603 .34528 m .52683 .34496 L .52603 .34527 L .672 .728 .891 r
F
.52592 .34533 m .52591 .34536 L .52589 .34533 L F
.52586 .34536 m .52603 .34529 L .52588 .34534 L F
.52603 .34529 m .52683 .34496 L .52603 .34528 L F
.52603 .34529 m .52603 .34528 L .52588 .34534 L F
.5269 .34499 m .52663 .34476 L .52691 .345 L F
.52613 .34477 m .52557 .34377 L .52613 .34477 L F
.52549 .34408 m .52557 .34378 L .52499 .34345 L F
.52603 .34423 m .52461 .34298 L .52619 .34427 L F
.52557 .3438 m .52557 .3438 L .52557 .34378 L F
.52558 .34378 m .52573 .34406 L p .52517 .34351 L F P
0 g
s
.52629 .34508 m .52667 .345 L .52655 .34497 L .672 .728 .891 r
F
.526 .3452 m .5263 .34509 L .5263 .34509 L F
.52594 .34524 m .52632 .34512 L .52629 .34508 L F
.52632 .34512 m .52667 .345 L .52629 .34508 L F
.526 .3452 m .526 .3452 L .5263 .34509 L F
.52643 .34492 m .52679 .34504 L .52682 .34499 L F
.52667 .345 m .52685 .34493 L .52655 .34497 L F
.52609 .34491 m .52615 .34491 L .52697 .34506 L F
.52685 .34493 m .52682 .34499 L .52684 .34502 L F
.52668 .345 m .52683 .34496 L .52685 .34493 L F
.52603 .34475 m .52611 .34456 L .52675 .34493 L F
.52637 .34491 m .52639 .34492 L .52691 .34481 L F
.52639 .34492 m .52655 .34497 L .52665 .34493 L F
.5268 .34482 m .52681 .34477 L .52665 .34476 L F
.52696 .34467 m .52657 .34494 L .52674 .34469 L F
.52639 .34492 m .52665 .34493 L .52691 .34481 L F
.52663 .34476 m .52666 .34478 L .52684 .34493 L F
.52689 .34503 m .52685 .34493 L .52684 .34502 L F
.52794 .34467 m .52755 .34471 L .52755 .34473 L F
.52755 .34474 m .52794 .34467 L .52755 .34473 L F
.52776 .34481 m .52639 .3452 L p .52842 .34441 L F P
0 g
s
.52889 .34449 m .54379 .34023 L p .52782 .34445 L .672 .728 .891 r
F P
0 g
s
.52849 .34443 m .52842 .34441 L .52888 .34422 L .672 .728 .891 r
F
.52776 .34481 m .52842 .34441 L .52849 .34443 L F
.52577 .34473 m .52576 .34469 L .52577 .34473 L F
.52539 .34447 m .52549 .34408 L .52499 .34345 L F
.52508 .34396 m .52549 .34408 L .52554 .34415 L F
.52605 .34503 m .52615 .34491 L .52568 .34432 L F
.52576 .34469 m .52557 .3438 L .52576 .34469 L F
.52609 .34491 m .52508 .34396 L .52567 .3443 L F
.52547 .34463 m .52553 .34413 L .52539 .34447 L F
.52586 .34525 m .5259 .34521 L .52628 .34507 L F
.52628 .34507 m .52629 .34508 L .52655 .34497 L F
.52629 .34508 m .52628 .34507 L .52659 .34496 L F
.52586 .34525 m .52628 .34507 L .52629 .34508 L F
.526 .3452 m .52586 .34525 L .526 .3452 L F
.52604 .34486 m .52536 .34461 L .52538 .34459 L F
.52586 .34537 m .52576 .34469 L .52547 .34463 L F
.52496 .34585 m .52596 .34539 L p .52501 .34574 L F P
0 g
s
.52589 .34533 m .52594 .34539 L .5258 .34531 L .672 .728 .891 r
F
.52598 .34535 m .52597 .34535 L .52597 .34535 L F
.52597 .34535 m .52579 .34547 L .52597 .34532 L F
.52639 .3452 m .52681 .34501 L p .52501 .34573 L F P
0 g
s
.52327 .34642 m .52501 .34574 L .52501 .34573 L .672 .728 .891 r
F
.52501 .34574 m .52639 .3452 L .52501 .34573 L F
.52607 .3449 m .52507 .34397 L p .52608 .3449 L F P
0 g
s
.52507 .34397 m .52509 .34397 L .526 .34482 L .672 .728 .891 r
F
.52589 .34532 m .52577 .34473 L .52586 .34537 L F
.52577 .34473 m .52576 .34469 L .52577 .34473 L F
.52577 .34473 m .52577 .34473 L .52586 .34537 L F
.52589 .34531 m .52606 .34506 L .52582 .34496 L F
.52615 .34491 m .52566 .34529 L .5259 .34491 L F
.52597 .34489 m .5259 .34491 L .52593 .34488 L F
.52615 .34491 m .5259 .34491 L .52597 .34489 L F
.52609 .34491 m .52567 .3443 L .52615 .34491 L F
.5261 .34484 m .52609 .34491 L .52615 .34491 L F
.52605 .34503 m .52607 .34504 L .52615 .34491 L F
.5259 .34521 m .52566 .34529 L .52615 .34491 L F
.52609 .34491 m .52607 .34504 L .52615 .34491 L F
.526 .34482 m .526 .34482 L .52609 .34491 L F
.52607 .34504 m .52633 .34513 L .52615 .34491 L F
.52609 .34491 m .52609 .34491 L .52633 .34513 L F
.526 .34482 m .52609 .34491 L .52609 .34491 L F
.52585 .34539 m .52627 .34596 L .52621 .34596 L F
.52594 .34539 m .52586 .34539 L .5258 .34531 L F
.52681 .34501 m .52639 .3452 L p .52665 .34496 L F P
0 g
s
.52593 .34534 m .52591 .34536 L .52592 .34533 L .672 .728 .891 r
F
.52631 .34439 m .52622 .3443 L .52629 .34439 L F
.52621 .34429 m .52624 .34438 L .52629 .34439 L F
.52691 .345 m .52619 .34437 L .52622 .3443 L F
.52674 .34493 m .52685 .34493 L .52688 .34488 L F
.52674 .34493 m .52688 .34488 L .52691 .34481 L F
.52663 .34476 m .52684 .34493 L .52684 .34493 L F
.52665 .34493 m .52674 .34493 L .52691 .34481 L F
.52746 .34426 m .52746 .34426 L .52746 .34426 L F
.52764 .34463 m .52674 .34469 L .52746 .34426 L F
.52691 .34481 m .52764 .34463 L .52813 .34427 L F
.52557 .34377 m .51956 .33325 L p .52557 .34378 L F P
0 g
s
.52376 .34133 m .5241 .34121 L .51956 .33325 L .672 .728 .891 r
F
.5239 .3416 m .5241 .34121 L .52376 .34133 L F
.52436 .34209 m .5241 .34121 L .5239 .3416 L F
.52461 .34298 m .5245 .34284 L .52619 .34427 L F
.52499 .34345 m .52557 .34378 L .5241 .34121 L F
.51956 .33325 m .52557 .34377 L p .52486 .34329 L F P
0 g
s
.52412 .34306 m .51531 .33482 L .52328 .34181 L .672 .728 .891 r
F
.52412 .34306 m .52328 .34181 L .52461 .34298 L F
.52458 .34295 m .51531 .33482 L .5245 .34298 L F
.52508 .34396 m .52412 .34306 L .52461 .34298 L F
.52458 .34295 m .5245 .34298 L .52486 .34329 L F
.51956 .33325 m .52486 .34329 L .52458 .34295 L F
.52344 .34075 m .52458 .34295 L .52413 .34141 L F
.52508 .34396 m .52461 .34298 L .52549 .34408 L F
.52458 .34295 m .52486 .34329 L .52471 .34319 L F
.52481 .34315 m .52458 .34295 L .52486 .34329 L F
.52486 .34329 m .52506 .34395 L .5254 .34397 L F
.52506 .34395 m .52533 .34421 L p .52518 .34396 L F P
0 g
s
.52507 .34397 m .526 .34482 L .526 .34482 L .672 .728 .891 r
F
.52533 .34421 m .52607 .34491 L p .52518 .34396 L F P
0 g
s
.5254 .34397 m .52518 .34396 L .52607 .34491 L .672 .728 .891 r
F
.52571 .34471 m .52561 .34468 L .52471 .34319 L F
.52458 .34295 m .52541 .34455 L .52494 .3434 L F
.52507 .34397 m .51531 .33482 L p .52509 .34397 L F P
0 g
s
.51531 .33482 m .52506 .34395 L p .52486 .34329 L .672 .728 .891 r
F P
0 g
s
.52597 .34479 m .52571 .34471 L .52486 .34329 L .672 .728 .891 r
F
.52552 .34439 m .52541 .34398 L .52528 .34382 L F
.52557 .34377 m .52558 .34378 L p .52486 .34329 L F P
0 g
s
.52614 .34432 m .52481 .34315 L .52613 .34444 L .672 .728 .891 r
F
.52517 .34351 m .52615 .34478 L .52486 .34329 L F
.52481 .34315 m .52486 .34329 L .5254 .34397 L F
.52541 .34455 m .52561 .34461 L .52473 .34251 L F
.52447 .34223 m .52473 .34251 L .52071 .33298 L F
.52486 .34329 m .52571 .34471 L .52471 .34319 L F
.52471 .34319 m .52561 .34468 L .52545 .34463 L F
.52541 .34455 m .52473 .34251 L .52447 .34223 L F
.52554 .34422 m .52322 .34238 L .52528 .34382 L F
.52609 .34469 m .52557 .34377 L .52607 .34465 L F
.52664 .34496 m .52659 .34496 L .52909 .34408 L F
.52615 .34491 m .5273 .3445 L .52716 .34448 L F
.52714 .34457 m .52615 .34491 L .52625 .3448 L F
.52615 .34491 m .52635 .34492 L .5273 .3445 L F
.52726 .34459 m .52615 .34491 L .52714 .34457 L F
.52615 .34491 m .52675 .34493 L .52686 .34499 L F
.52637 .34491 m .52691 .34481 L .52701 .34463 L F
.52726 .34459 m .52659 .34496 L .52615 .34491 L F
.52764 .34463 m .53277 .3423 L p .52813 .34427 L F P
0 g
s
.53277 .3423 m .54208 .33806 L p .53229 .34241 L .672 .728 .891 r
F P
0 g
s
.52813 .34427 m .53277 .3423 L .53229 .34241 L .672 .728 .891 r
F
.52931 .344 m .52749 .34464 L .52726 .34459 L F
.52749 .34464 m .52659 .34496 L .52726 .34459 L F
.52625 .3448 m .52632 .34481 L .5278 .34465 L F
.5278 .34465 m .5278 .34465 L .52789 .34464 L F
.52625 .3448 m .5278 .34465 L .5278 .34465 L F
.52697 .34506 m .52691 .345 L .52689 .34503 L F
.52691 .345 m .52685 .34493 L .52689 .34503 L F
.52684 .34493 m .52684 .34493 L .52691 .345 L F
.52701 .34463 m .52691 .34481 L .52921 .34378 L F
.52725 .34454 m .52625 .3448 L .52789 .34464 L F
.52691 .34499 m .52702 .34486 L .52888 .34422 L F
.52664 .34497 m .52664 .34496 L .5273 .34473 L F
.526 .3452 m .5273 .34473 L .5273 .34473 L F
.52683 .34496 m .52764 .34463 L .52691 .34481 L F
.52733 .34475 m .526 .3452 L .5273 .34473 L F
.52649 .34495 m .52809 .34467 L .52789 .34464 L F
.52625 .3448 m .5261 .34484 L .52632 .34481 L F
.52612 .34483 m .52608 .34485 L .5261 .34484 L F
.5254 .34397 m .52607 .3449 L .52608 .34482 L F
.52608 .34485 m .52597 .34489 L .52608 .34485 L F
.52607 .3449 m .52607 .34491 L .52608 .34485 L F
.52608 .34485 m .52608 .34485 L .52608 .34482 L F
.52607 .3449 m .52608 .34485 L .52608 .34485 L F
.52539 .34245 m .52188 .33276 L p .52528 .34279 L F P
0 g
s
.52609 .34469 m .52607 .34465 L .52613 .34477 L .672 .728 .891 r
F
.52619 .34485 m .52557 .34377 L p .52619 .34486 L F P
0 g
s
.52573 .34406 m .52615 .34478 L p .52517 .34351 L .672 .728 .891 r
F P
0 g
s
.52481 .34315 m .5261 .34469 L .52613 .34444 L .672 .728 .891 r
F
.52523 .34373 m .52522 .34374 L .52486 .34329 L F
.52619 .34436 m .52528 .34382 L .52458 .34295 L F
.52528 .34382 m .52541 .34398 L .52071 .33298 L F
.52611 .34483 m .5261 .34484 L .52611 .34483 L F
.52746 .34426 m .5261 .34484 L .52746 .34426 L F
.52746 .34426 m .52643 .34471 L .5264 .34471 L F
.52611 .34483 m .52611 .34483 L .52783 .34412 L F
.52746 .34426 m .52726 .34438 L .52643 .34471 L F
.52611 .34483 m .52783 .34412 L .52782 .34412 L F
.5308 .34255 m .52765 .34408 L .52979 .3433 L F
.52765 .34408 m .52611 .34483 L .52782 .34412 L F
.52765 .34408 m .52782 .34412 L .52979 .3433 L F
.52611 .34483 m .52611 .34483 L .52611 .34483 L F
.52613 .34484 m .52597 .34489 L .52612 .34483 L F
.5261 .34484 m .52611 .34485 L .52669 .34489 L F
.5261 .34486 m .52611 .34483 L .52611 .34483 L F
.52611 .34483 m .5261 .34484 L .5261 .34484 L F
.52611 .34483 m .52611 .34485 L .52608 .34482 L F
.5261 .34484 m .52669 .34489 L .52632 .34481 L F
.52612 .34483 m .52611 .34485 L .52611 .34483 L F
.52615 .34478 m .52522 .34374 L .52523 .34373 L F
.52481 .34315 m .5254 .34397 L .5261 .34469 L F
.52615 .34478 m .52612 .34483 L .52522 .34374 L F
.5254 .34397 m .52608 .34482 L .5261 .34469 L F
.52608 .34482 m .52608 .34482 L .5261 .34469 L F
.5261 .34484 m .52597 .34489 L .52593 .34488 L F
.52589 .34532 m .52577 .34473 L .52577 .34473 L F
.52578 .34529 m .52537 .34471 L .52537 .34471 L F
.52593 .34488 m .5259 .34491 L .52487 .34516 L F
.5249 .34525 m .52531 .34518 L .52528 .34517 L F
.52577 .34494 m .52464 .3453 L .52568 .34502 L F
.52464 .3453 m .52556 .34512 L .52568 .34502 L F
.5259 .34491 m .52516 .34521 L .52487 .34516 L F
.52608 .34484 m .52487 .34516 L .52474 .3453 L F
.5261 .34484 m .52608 .34484 L .52608 .34484 L F
.52608 .34484 m .52487 .34516 L .52608 .34484 L F
.52608 .34484 m .52608 .34482 L .52608 .34482 L F
.52607 .3449 m .52608 .34484 L .52608 .34484 L F
.52608 .34484 m .52608 .34482 L .52608 .34484 L F
.52488 .34579 m .52414 .34622 L .52487 .34578 L F
.52327 .34642 m .52496 .34585 L .52501 .34574 L F
.52448 .34562 m .52437 .34568 L .52449 .34564 L F
.52437 .34568 m .52292 .34638 L .52434 .34578 L F
.52292 .34638 m .52297 .34639 L .52351 .34615 L F
.52429 .3458 m .52389 .34591 L p .52453 .3457 L F P
0 g
s
.52429 .3458 m .52453 .3457 L .52571 .3453 L .672 .728 .891 r
F
.52592 .34533 m .52429 .3458 L p .52571 .3453 L F P
0 g
s
.52352 .34613 m .52351 .34615 L .52607 .34504 L .672 .728 .891 r
F
.52292 .34638 m .52351 .34615 L .52352 .34613 L F
.52353 .34614 m .52432 .34584 L .52433 .34579 L F
.52664 .34496 m .52909 .34408 L .5291 .34408 L F
.5273 .34473 m .5273 .34473 L .52931 .344 L F
.52888 .34422 m .52733 .34475 L .52931 .344 L F
.52733 .34475 m .5273 .34473 L .52931 .344 L F
.52889 .34449 m .52776 .34481 L p .53031 .34374 L F P
0 g
s
.52794 .34467 m .52889 .34449 L .52793 .34465 L .672 .728 .891 r
F
.52776 .34481 m .52888 .34422 L .53031 .34374 L F
.54379 .34023 m .52889 .34449 L p .53031 .34374 L F P
0 g
s
.52725 .34454 m .52789 .34464 L .52974 .34423 L .672 .728 .891 r
F
.53023 .34401 m .52974 .34423 L .53255 .3436 L F
.52725 .34454 m .52974 .34423 L .53023 .34401 L F
.5251 .34533 m .5241 .34598 L .52331 .3462 L F
.52677 .34493 m .52683 .34493 L .5269 .34499 L F
.52687 .34499 m .5269 .34499 L .52697 .34506 L F
.52677 .34493 m .5269 .34499 L .52687 .34499 L F
.52691 .345 m .52702 .34486 L .52691 .34499 L F
.52639 .3452 m .52679 .34498 L .52691 .345 L F
.52675 .34493 m .52677 .34493 L .52697 .34506 L F
.52679 .34498 m .52702 .34486 L .52691 .345 L F
.52668 .34493 m .52672 .34493 L .52785 .34611 L F
.52785 .34611 m .52785 .34611 L .52802 .34628 L F
.52668 .34493 m .52785 .34611 L .52785 .34611 L F
.51152 .35294 m .52051 .34826 L p .519 .34878 L F P
0 g
s
.51571 .35153 m .51229 .35356 L p .519 .34878 L .672 .728 .891 r
F P
0 g
s
.51571 .35153 m .51676 .35091 L p .51503 .35183 L .672 .728 .891 r
F P
0 g
s
.52682 .34499 m .52702 .34584 L .52734 .34559 L .672 .728 .891 r
F
.52795 .34603 m .52699 .34575 L .52697 .34506 L F
.53685 .35497 m .52726 .346 L .52795 .34603 L F
.52726 .346 m .52699 .34575 L .52795 .34603 L F
.52603 .34529 m .52681 .34501 L .52683 .34496 L F
.52586 .34525 m .52659 .34496 L .52664 .34496 L F
.52603 .34527 m .5267 .34501 L .52668 .345 L F
.5267 .34501 m .52683 .34496 L .52668 .345 L F
.52639 .3452 m .5263 .3451 L .52702 .34486 L F
.5263 .34509 m .5263 .34509 L .52664 .34496 L F
.5263 .34509 m .52664 .34496 L .52664 .34497 L F
.52615 .34491 m .52621 .34498 L .52635 .34492 L F
.52639 .34494 m .52624 .34502 L .52615 .34491 L F
.52698 .34549 m .52609 .34491 L .52697 .34506 L F
.52699 .34575 m .5267 .34547 L .52698 .34549 L F
.5267 .34547 m .52609 .34491 L .52698 .34549 L F
.52437 .34568 m .52434 .34578 L .52607 .34504 L F
.52432 .34584 m .52628 .34507 L .52433 .34579 L F
.52519 .34528 m .52493 .34564 L .5251 .34533 L F
.52175 .34606 m .52477 .34558 L .52469 .34553 L F
.52389 .34573 m .52389 .34572 L .52519 .34539 L F
.52614 .34477 m .52613 .34477 L .52633 .34513 L F
.52512 .34545 m .52598 .34519 L .52607 .34504 L F
.52633 .34513 m .52613 .34477 L .52613 .34477 L F
.5255 .34538 m .52542 .34535 L .52616 .34491 L F
.52611 .34485 m .52644 .34494 L .52669 .34489 L F
.52617 .34493 m .52616 .34491 L .5264 .34477 L F
.5261 .34484 m .52448 .34562 L .52607 .34504 L F
.5255 .34538 m .52616 .34491 L .52617 .34493 L F
.52575 .34538 m .52685 .34493 L .52572 .34537 L F
.52639 .3452 m .52607 .3449 L p .52633 .34513 L F P
0 g
s
.52603 .34532 m .52681 .34501 L .52603 .34529 L .672 .728 .891 r
F
.52596 .3452 m .52594 .34524 L .52629 .34508 L F
.52554 .34536 m .52629 .34508 L .52628 .34507 L F
.52594 .34553 m .52637 .34519 L .52606 .34506 L F
.52612 .34483 m .5262 .34497 L .52611 .34485 L F
.52638 .34519 m .52614 .34478 L .52633 .34513 L F
.52669 .3454 m .52671 .34533 L .52645 .34494 L F
.52637 .34477 m .5262 .3448 L .52628 .34477 L F
.52641 .34493 m .52645 .34494 L .52613 .34444 L F
.52669 .3454 m .52645 .34494 L .52641 .34493 L F
.52626 .34489 m .52669 .3454 L .52641 .34493 L F
.52628 .34506 m .52662 .34499 L .52623 .34501 L F
.52662 .34499 m .52688 .34493 L .52655 .34497 L F
.52662 .34499 m .52655 .34497 L .52623 .34501 L F
.52688 .34493 m .52809 .34467 L .52678 .34491 L F
.52688 .34493 m .52678 .34491 L .52623 .34501 L F
.52614 .34478 m .52613 .34476 L .52614 .34478 L F
.52614 .34478 m .52614 .34478 L .52633 .34513 L F
.52613 .34476 m .52609 .34469 L .52613 .34476 L F
.52613 .34476 m .52613 .34476 L .52633 .34513 L F
.52702 .34446 m .52709 .34447 L .52712 .34442 L F
.5275 .34432 m .52667 .34479 L .52717 .34432 L F
.52615 .34491 m .52686 .34499 L .52697 .34506 L F
.52628 .34507 m .52689 .34501 L .52691 .34494 L F
.52603 .34505 m .52637 .34519 L .52605 .34503 L F
.52648 .34548 m .52605 .34505 L .52608 .34494 L F
.52531 .34552 m .52591 .34529 L .52594 .34524 L F
.52244 .34662 m .52327 .34642 L .52432 .34596 L F
.52244 .34662 m .52432 .34596 L .52353 .34614 L F
.5241 .34598 m .52179 .3475 L .5232 .34629 L F
.5232 .34645 m .52269 .34673 L .52368 .34626 L F
.52292 .34638 m .52244 .34662 L .52297 .34639 L F
.52331 .3462 m .52051 .34826 L .52244 .34662 L F
.52269 .34673 m .519 .34878 L .52368 .34626 L F
.52327 .34642 m .52426 .34603 L .52426 .34602 L F
.52433 .34579 m .5251 .34551 L .52512 .34545 L F
.52448 .34562 m .52449 .34564 L .52607 .34504 L F
.52327 .34642 m .52448 .34592 L .52432 .34596 L F
.52353 .34614 m .52432 .34596 L .52565 .34537 L F
.52353 .34614 m .52565 .34537 L .52554 .34536 L F
.52493 .34564 m .5234 .34655 L .5251 .34533 L F
.5234 .34655 m .52179 .3475 L .52311 .34663 L F
.5234 .34655 m .52311 .34663 L .5251 .34533 L F
.52608 .34559 m .52651 .34544 L .52637 .34519 L F
.52676 .34585 m .52601 .34517 L .52604 .34507 L F
.52589 .34507 m .52493 .34564 L .5259 .34506 L F
.5259 .34506 m .52493 .34564 L .5259 .34505 L F
.5207 .34624 m .52562 .34527 L .52568 .3452 L F
.52395 .34563 m .52396 .34561 L .52494 .34534 L F
.52541 .34519 m .52597 .34513 L .526 .34506 L F
.5207 .34624 m .52549 .34523 L .52541 .34519 L F
.52538 .34534 m .52537 .34534 L .52609 .34485 L F
.52541 .34535 m .52538 .34534 L .5262 .3448 L F
.52549 .34523 m .52597 .34513 L .52541 .34519 L F
.5258 .34531 m .52635 .34612 L .52623 .34612 L F
.52448 .34592 m .52685 .34493 L .52432 .34596 L F
.52588 .34534 m .52603 .34528 L .52603 .34527 L F
.52594 .34553 m .52606 .34506 L .52589 .34531 L F
.52426 .34603 m .52681 .34501 L .52426 .34602 L F
.52575 .34538 m .52572 .34537 L .52505 .34564 L F
.52532 .34553 m .52667 .345 L .52531 .34552 L F
.52502 .34575 m .52498 .34574 L .52601 .34516 L F
.52607 .3449 m .52608 .3449 L .52633 .34513 L F
.52613 .34488 m .52614 .3449 L .52614 .34489 L F
.52609 .34485 m .52614 .3449 L .52613 .34488 L F
.52609 .34485 m .52607 .34491 L .52614 .3449 L F
.52609 .34485 m .52614 .34489 L .52611 .34485 L F
.52469 .34563 m .52389 .34591 L .52191 .34593 L F
.52163 .34632 m .52477 .34558 L p .52175 .34606 L F P
0 g
s
.52033 .34661 m .52021 .34663 L .5254 .34521 L .672 .728 .891 r
F
.52608 .34482 m .52607 .34492 L .52596 .34478 L F
.5261 .34486 m .52538 .34534 L .52609 .34485 L F
.52611 .34485 m .52609 .34485 L .52611 .34483 L F
.5261 .34486 m .52609 .34485 L .52611 .34485 L F
.52608 .34485 m .52608 .34485 L .5261 .34484 L F
.52608 .34495 m .52541 .34535 L .5261 .34486 L F
.52611 .34485 m .52608 .34494 L .52607 .34492 L F
.5261 .34484 m .52537 .34534 L .52519 .34528 L F
.5261 .34484 m .52537 .34534 L .5261 .34484 L F
.5261 .34484 m .52525 .34512 L .52602 .34503 L F
.52605 .34505 m .52602 .34502 L .52608 .34494 L F
.52589 .34507 m .5259 .34506 L .52608 .34495 L F
.52663 .34494 m .52646 .34495 L .52671 .34501 L F
.52646 .34491 m .52635 .34489 L .52651 .34478 L F
.52632 .34481 m .52669 .34489 L .52789 .34464 L F
.52629 .34488 m .5264 .34477 L .52645 .34478 L F
.5261 .34484 m .52709 .34447 L .52702 .34446 L F
.52726 .34438 m .52674 .34469 L .52643 .34471 L F
.52645 .34478 m .5264 .34477 L .52717 .34432 L F
.52616 .34448 m .52644 .34491 L .52663 .34494 L F
.52615 .34491 m .52633 .34513 L .52619 .34487 L F
.5262 .34486 m .52639 .3452 L p .52612 .34483 L F P
0 g
s
.52655 .34544 m .52722 .34641 L p .52594 .34539 L .672 .728 .891 r
F P
0 g
s
.52687 .34607 m .52638 .34519 L .52633 .34513 L .672 .728 .891 r
F
.52722 .34641 m .53424 .35669 L p .52675 .3465 L F P
0 g
s
.52594 .34539 m .52675 .3465 L .52586 .34539 L .672 .728 .891 r
F
.52675 .3465 m .53424 .35669 L .52669 .34651 L F
.52675 .3465 m .52669 .34651 L .52586 .34539 L F
.52626 .34489 m .52614 .34489 L .52667 .34544 L F
.52667 .34543 m .52667 .34544 L .52669 .34545 L F
.52626 .34489 m .52667 .34544 L .52667 .34543 L F
.5263 .34509 m .52677 .34503 L .52628 .34507 L F
.52646 .34495 m .52674 .34537 L .52671 .34501 L F
.52674 .34537 m .52699 .34577 L .5268 .34527 L F
.52674 .34537 m .5268 .34527 L .52671 .34501 L F
.52596 .34535 m .5263 .34509 L .52633 .34513 L F
.5264 .34546 m .52571 .34471 L .52648 .34548 L F
.52616 .34449 m .52645 .34494 L .52616 .34448 L F
.52645 .34494 m .52699 .34577 L .52646 .34495 L F
.52692 .34446 m .52623 .34487 L .52693 .34443 L F
.52607 .34491 m .52639 .3452 L p .52614 .34489 L F P
0 g
s
.52605 .34503 m .52637 .34519 L .52633 .34513 L .672 .728 .891 r
F
.52611 .34485 m .52652 .34549 L .52608 .34494 L F
.52623 .34487 m .52589 .34507 L .52622 .34487 L F
.52623 .34487 m .52622 .34487 L .52693 .34443 L F
.52645 .34494 m .52646 .34495 L .52644 .34491 L F
.52692 .34444 m .52637 .34477 L .52625 .34477 L F
.52643 .34491 m .52644 .34491 L .52616 .34448 L F
.52645 .34494 m .52644 .34491 L .52643 .34491 L F
.52639 .3452 m .52693 .34507 L p .52635 .34515 L F P
0 g
s
.52671 .34501 m .52699 .34577 L .52733 .34591 L .672 .728 .891 r
F
.52747 .34576 m .52733 .34591 L .52783 .34611 L F
.52671 .34501 m .52733 .34591 L .52747 .34576 L F
.52693 .34507 m .52639 .3452 L p .52695 .34504 L F P
0 g
s
.52639 .3452 m .52659 .34513 L .52695 .34504 L .672 .728 .891 r
F
.52722 .34641 m .52675 .3465 L .52594 .34539 L F
.52615 .3449 m .52659 .34542 L .5266 .34541 L F
.52701 .34578 m .52639 .3452 L p .52701 .34576 L F P
0 g
s
.52639 .3452 m .52633 .34513 L .52701 .34576 L .672 .728 .891 r
F
.52639 .3452 m .52699 .34577 L p .52648 .34524 L F P
0 g
s
.52638 .3452 m .52619 .34485 L .52638 .3452 L .672 .728 .891 r
F
.52656 .3455 m .52619 .34485 L .52656 .3455 L F
.52639 .3452 m .52622 .34499 L .52612 .34483 L F
.52614 .34489 m .52639 .3452 L .52648 .34524 L F
.52638 .3452 m .52619 .34485 L .52619 .34486 L F
.52656 .3455 m .52638 .3452 L .52638 .3452 L F
.53424 .35669 m .53313 .357 L p .52621 .34596 L F P
0 g
s
.52627 .34596 m .53424 .35669 L .52621 .34596 L .672 .728 .891 r
F
.53278 .35645 m .52656 .3455 L .52656 .3455 L F
.52601 .34518 m .52601 .34516 L .52667 .34479 L F
.52595 .34516 m .52631 .3451 L .52596 .34514 L F
.52631 .3451 m .52689 .34501 L .5263 .34509 L F
.52596 .34535 m .526 .34521 L .52628 .34506 L F
.52631 .3451 m .5263 .34509 L .52596 .34514 L F
.52625 .34487 m .52669 .34545 L .52671 .34542 L F
.5263 .34509 m .52628 .34506 L .52652 .34492 L F
.52596 .34535 m .52628 .34506 L .5263 .34509 L F
.52636 .34516 m .52633 .34513 L .52666 .34494 L F
.52634 .34513 m .52693 .34507 L .52682 .34504 L F
.52592 .34521 m .52635 .34515 L .52634 .34513 L F
.52635 .34515 m .52693 .34507 L .52634 .34513 L F
.5268 .34504 m .52679 .34503 L .5268 .34505 L F
.52697 .34506 m .5269 .34499 L .52691 .345 L F
.52633 .34513 m .52711 .34498 L .52631 .3451 L F
.52672 .34495 m .52671 .34501 L .52679 .34503 L F
.52662 .34499 m .5269 .34494 L .52688 .34493 L F
.52691 .34493 m .52639 .3452 L p .52691 .34486 L F P
0 g
s
.52639 .3452 m .52593 .34544 L p .52637 .34518 L .672 .728 .891 r
F P
0 g
s
.52659 .34504 m .5266 .34504 L .52628 .34507 L .672 .728 .891 r
F
.52677 .34503 m .5266 .34504 L .52659 .34504 L F
.52677 .34503 m .52676 .34503 L .5266 .34504 L F
.52639 .3452 m .52637 .34518 L .52691 .34486 L F
.52614 .34531 m .52666 .34494 L .52669 .34495 L F
.52665 .34494 m .52663 .34494 L .52671 .34501 L F
.52636 .34517 m .52691 .3448 L .52637 .34518 L F
.52639 .3452 m .52683 .34497 L p .52629 .34507 L F P
0 g
s
.52663 .34499 m .5269 .34494 L .52662 .34499 L .672 .728 .891 r
F
.52665 .34494 m .52671 .34501 L .52672 .34495 L F
.52622 .34499 m .52623 .34501 L .52649 .34495 L F
.52644 .34494 m .52649 .34495 L .52789 .34464 L F
.52622 .34499 m .52649 .34495 L .52644 .34494 L F
.52644 .34491 m .52646 .34495 L .52663 .34494 L F
.52665 .345 m .52663 .34499 L .52628 .34506 L F
.52628 .34506 m .52663 .34499 L .52662 .34499 L F
.52628 .34506 m .5269 .34494 L .52628 .34506 L F
.52633 .34513 m .52652 .34492 L .52666 .34494 L F
.52674 .34496 m .52691 .3448 L .52691 .34486 L F
.52637 .34518 m .52669 .34495 L .52674 .34496 L F
.52651 .34496 m .52809 .34467 L .52649 .34495 L F
.52669 .34495 m .52691 .3448 L .52674 .34496 L F
.52679 .34488 m .52678 .34487 L .52691 .3448 L F
.52669 .34495 m .52678 .34487 L .52679 .34488 L F
.52669 .34495 m .52666 .34494 L .52678 .34487 L F
.52623 .34501 m .52651 .34496 L .52649 .34495 L F
.52628 .34506 m .52626 .34505 L .52691 .34468 L F
.52691 .34469 m .52691 .34468 L .52753 .34432 L F
.52628 .34506 m .52691 .34468 L .52691 .34469 L F
.52663 .34476 m .52603 .34423 L .52666 .34478 L F
.52622 .34488 m .52614 .34489 L .52626 .34489 L F
.52611 .34485 m .52614 .34489 L .52622 .34488 L F
.52611 .34485 m .52622 .34499 L .52644 .34494 L F
.52625 .34487 m .52626 .34489 L .52639 .3449 L F
.52554 .34536 m .52594 .34524 L .52596 .3452 L F
.5261 .34484 m .52706 .34452 L .52709 .34447 L F
.5262 .34497 m .52653 .34549 L .52611 .34485 L F
.52608 .34559 m .52675 .34586 L .52651 .34544 L F
.52653 .34549 m .52676 .34585 L .52652 .34549 L F
.52653 .34549 m .52652 .34549 L .52611 .34485 L F
.5207 .34624 m .52163 .34632 L .52175 .34606 L F
.52563 .34542 m .52561 .34542 L .52626 .34505 L F
.52554 .34536 m .52565 .34537 L .52594 .34524 L F
.5251 .34551 m .52598 .34519 L .52512 .34545 L F
.52537 .34534 m .52493 .34564 L .52519 .34528 L F
.52341 .34571 m .52587 .34532 L .52592 .34521 L F
.5234 .34575 m .52587 .34532 L .52341 .34571 L F
.52267 .34589 m .52587 .34532 L .52266 .34588 L F
.52581 .34528 m .52586 .34517 L .52692 .34448 L F
.52581 .34528 m .52692 .34448 L .52692 .34449 L F
.52611 .34485 m .52622 .34488 L .52625 .34487 L F
.52607 .34496 m .52621 .34487 L .52622 .34487 L F
.5261 .34484 m .52602 .34503 L .52611 .34485 L F
.52612 .34483 m .52608 .34482 L .52522 .34374 L F
.52608 .34482 m .52607 .34491 L .52611 .34471 L F
.52609 .34483 m .52608 .34484 L .52608 .34482 L F
.52637 .34477 m .52608 .34495 L .5262 .3448 L F
.52625 .3448 m .52613 .34484 L .52612 .34483 L F
.52609 .34469 m .52613 .34477 L .52614 .34477 L F
.52625 .34477 m .5261 .34486 L .52611 .34483 L F
.52611 .34471 m .52609 .34485 L .52625 .34487 L F
.52611 .34485 m .52608 .34484 L .52609 .34483 L F
.52611 .34485 m .52607 .34492 L .52608 .34484 L F
.52622 .34526 m .52633 .34513 L .52636 .34516 L F
.52614 .34531 m .52619 .34527 L .52622 .34526 L F
.52619 .34527 m .52633 .34513 L .52622 .34526 L F
.52693 .34507 m .52815 .34478 L p .52682 .34504 L F P
0 g
s
.52693 .34507 m .52695 .34504 L .52697 .34503 L .672 .728 .891 r
F
.52762 .34561 m .52684 .34493 L .52754 .34569 L F
.52689 .34501 m .52711 .34498 L .52692 .34494 L F
.52696 .34503 m .52691 .34499 L .52691 .34499 L F
.52677 .34503 m .52689 .34501 L .52676 .34503 L F
.52684 .34493 m .5268 .34505 L .52684 .34509 L F
.52603 .34506 m .52602 .34506 L .52603 .34505 L F
.52605 .34504 m .52617 .34493 L .52619 .34495 L F
.52483 .34583 m .52606 .345 L .52605 .34504 L F
.52606 .345 m .52617 .34493 L .52605 .34504 L F
.52619 .34527 m .52612 .34526 L .52633 .34513 L F
.52652 .34549 m .52648 .34548 L .52608 .34494 L F
.52614 .34531 m .52636 .34517 L .52637 .34518 L F
.52655 .34544 m .52594 .34539 L .52591 .34536 L F
.52634 .34549 m .52617 .34547 L .52612 .34539 L F
.52627 .34543 m .52612 .34539 L .526 .34519 L F
.52634 .34549 m .52612 .34539 L .52627 .34543 L F
.52587 .34532 m .52639 .3452 L p .52592 .34521 L F P
0 g
s
.52622 .34524 m .52587 .34532 L p .52625 .34522 L .672 .728 .891 r
F P
0 g
s
.52469 .34608 m .526 .34521 L .52596 .34535 L .672 .728 .891 r
F
.52505 .34564 m .52532 .34553 L .52531 .34552 L F
.52327 .34642 m .52586 .34536 L .52588 .34534 L F
.52483 .34583 m .52542 .34535 L .5255 .34538 L F
.52469 .34553 m .52577 .34535 L .52587 .34532 L F
.52502 .34575 m .52601 .34516 L .52601 .34518 L F
.52538 .34534 m .52493 .34564 L .52537 .34534 L F
.52541 .34535 m .52493 .34564 L .52538 .34534 L F
.52477 .34558 m .52577 .34535 L p .52469 .34553 L F P
0 g
s
.52536 .34461 m .52536 .34461 L .52534 .34458 L .672 .728 .891 r
F
.52592 .34533 m .52536 .34461 L .52536 .34461 L F
.52538 .34459 m .52536 .34461 L .52534 .34458 L F
.52535 .3446 m .52594 .34553 L .52539 .34447 L F
.52587 .34532 m .52577 .34535 L p .52586 .34532 L F P
0 g
s
.52594 .34553 m .52608 .34559 L .52637 .34519 L .672 .728 .891 r
F
.52646 .34598 m .52598 .34528 L .52599 .34525 L F
.53797 .33507 m .53699 .33459 L p .53687 .3347 L F P
0 g
s
.52594 .34553 m .52747 .34798 L .52675 .34586 L .672 .728 .891 r
F
.52747 .34798 m .52813 .34902 L .5276 .3478 L F
.52747 .34798 m .5276 .3478 L .52675 .34586 L F
.5389 .3356 m .53797 .33507 L p .53475 .33771 L F P
0 g
s
.52645 .34597 m .52598 .34528 L .52646 .34598 L .672 .728 .891 r
F
.52592 .34521 m .52639 .3452 L .52635 .34515 L F
.52657 .34551 m .52654 .34551 L .52612 .34483 L F
.52622 .34524 m .52625 .34522 L .52659 .34513 L F
.52614 .34531 m .52613 .34529 L .52619 .34527 L F
.52613 .34529 m .52612 .34526 L .52619 .34527 L F
.52684 .34493 m .52679 .34503 L .5268 .34504 L F
.52577 .34535 m .52587 .34523 L .52669 .34502 L F
.52681 .34501 m .5267 .34492 L .52696 .34503 L F
.52679 .34503 m .52671 .34501 L .52729 .34558 L F
.52673 .34504 m .52669 .34502 L .52677 .345 L F
.52684 .34493 m .52684 .34509 L .52689 .34513 L F
.52693 .34507 m .52689 .34513 L .52711 .34533 L F
.52684 .34493 m .52689 .34513 L .52693 .34507 L F
.52684 .34493 m .52672 .34495 L .52682 .34497 L F
.52629 .34507 m .52683 .34497 L .52683 .34495 L F
.5267 .34492 m .52681 .34493 L .52696 .34503 L F
.52681 .34501 m .52677 .345 L .52701 .34494 L F
.52673 .34504 m .52677 .345 L .52681 .34501 L F
.52681 .34501 m .52701 .34494 L .5269 .34502 L F
.53084 .35748 m .52966 .35765 L p .52667 .34806 L F P
0 g
s
.52592 .34521 m .52778 .34486 L .52778 .34485 L .672 .728 .891 r
F
.52585 .34552 m .52254 .34749 L p .52576 .34549 L F P
0 g
s
.52813 .34902 m .52823 .34885 L .52675 .34586 L .672 .728 .891 r
F
.52906 .3505 m .52921 .35019 L .52675 .34586 L F
.52673 .34668 m .53313 .357 L .52671 .34706 L F
.52674 .34641 m .52645 .34597 L .52646 .34598 L F
.52674 .34641 m .52673 .34651 L .52649 .34612 L F
.52674 .34641 m .52649 .34612 L .52654 .34612 L F
.52639 .3452 m .52657 .34551 L p .52622 .34499 L F P
0 g
s
.52676 .34585 m .5264 .34546 L .52648 .34548 L .672 .728 .891 r
F
.52676 .34585 m .52674 .34641 L .52617 .34547 L F
.52906 .3505 m .53278 .35645 L .52921 .35019 L F
.53278 .35645 m .52688 .34607 L .52687 .34607 L F
.53302 .35681 m .52676 .34585 L p .53278 .35645 L F P
0 g
s
.53278 .35645 m .52676 .34585 L .52676 .34585 L .672 .728 .891 r
F
.52676 .34585 m .53313 .357 L p .52674 .34641 L F P
0 g
s
.52656 .34668 m .52693 .34708 L .52639 .3452 L .672 .728 .891 r
F
.52674 .34641 m .53313 .357 L .52673 .34651 L F
.5276 .34781 m .52719 .34692 L p .52693 .34708 L F P
0 g
s
.52719 .34692 m .52639 .3452 L p .52693 .34708 L .672 .728 .891 r
F P
0 g
s
.52635 .34612 m .52673 .34668 L .52623 .34612 L .672 .728 .891 r
F
.52813 .34902 m .52906 .3505 L .52823 .34885 L F
.53313 .357 m .53302 .35681 L p .53278 .35645 L F P
0 g
s
.52673 .34651 m .53313 .357 L .52673 .34668 L .672 .728 .891 r
F
.53199 .35727 m .5276 .34781 L p .52678 .3472 L F P
0 g
s
.52755 .34822 m .52755 .34846 L .5265 .34638 L .672 .728 .891 r
F
.52636 .34665 m .52755 .34846 L .52755 .34954 L F
.52577 .34535 m .52589 .3453 L .52589 .34531 L F
.52389 .34573 m .52519 .34539 L .52521 .34539 L F
.52577 .34535 m .52335 .34592 L p .52568 .34528 L F P
0 g
s
.52335 .34592 m .52031 .34663 L p .52372 .34577 L .672 .728 .891 r
F P
0 g
s
.52335 .34592 m .52372 .34577 L .52568 .34528 L .672 .728 .891 r
F
.52432 .34596 m .52504 .34567 L .52505 .34564 L F
.52483 .34583 m .52051 .34826 L .52493 .34564 L F
.52179 .3475 m .52051 .34826 L .52331 .3462 L F
.52152 .34773 m .52491 .34597 L p .52008 .34823 L F P
0 g
s
.52298 .34716 m .52305 .34693 L .5251 .34564 L .672 .728 .891 r
F
.52176 .34604 m .5234 .34575 L .52341 .34571 L F
.52267 .34589 m .52266 .34588 L .52176 .34604 L F
.52603 .34505 m .526 .34507 L .52601 .34504 L F
.52474 .3453 m .52469 .34535 L .52623 .34501 L F
.52525 .34512 m .52474 .3453 L .52536 .34517 L F
.5207 .34624 m .52463 .34542 L .52464 .34541 L F
.52487 .34516 m .5207 .34624 L .52474 .3453 L F
.52474 .3453 m .52435 .34543 L .52469 .34535 L F
.5254 .34521 m .51938 .34685 L .52492 .34508 L F
.52175 .34606 m .52267 .34589 L .52176 .34604 L F
.5207 .34624 m .52175 .34606 L .52176 .34604 L F
.50908 .35015 m .50864 .34939 L p .5207 .34624 L F P
0 g
s
.50864 .34939 m .51938 .34685 L p .5207 .34624 L .672 .728 .891 r
F P
0 g
s
.52492 .34508 m .51938 .34685 L .51354 .3475 L .672 .728 .891 r
F
.52033 .34661 m .5254 .34521 L .52542 .34521 L F
.51354 .3475 m .5245 .34556 L .52451 .34554 L F
.52316 .3458 m .52301 .34579 L .52323 .34575 L F
.52483 .34583 m .52493 .34564 L .52542 .34535 L F
.52602 .34503 m .52623 .34501 L .52622 .34499 L F
.52474 .3453 m .526 .34505 L .52602 .34503 L F
.526 .34505 m .52623 .34501 L .52602 .34503 L F
.52551 .34523 m .52628 .34507 L .5255 .34523 L F
.52547 .34467 m .52587 .34531 L .5258 .34531 L F
.52587 .34531 m .52589 .34533 L .52587 .34532 L F
.52426 .34602 m .52603 .34532 L .52603 .34529 L F
.52469 .34608 m .5248 .34588 L .526 .34521 L F
.52587 .34531 m .52587 .34532 L .5258 .34531 L F
.52545 .34463 m .52548 .34467 L .52547 .34467 L F
.52548 .34467 m .52589 .34533 L .52547 .34467 L F
.52374 .34671 m .52371 .34669 L .52494 .34587 L F
.52682 .34497 m .52672 .34495 L .52679 .34503 L F
.52678 .34506 m .52681 .34501 L .5269 .34502 L F
.52589 .34531 m .52673 .34504 L .52678 .34506 L F
.52667 .34479 m .52646 .34491 L .52651 .34478 L F
.52667 .34479 m .52651 .34478 L .52717 .34432 L F
.52638 .34486 m .52689 .34476 L .52696 .34458 L F
.52602 .34506 m .526 .34507 L .52603 .34505 L F
.52607 .34496 m .52608 .34495 L .52621 .34487 L F
.52602 .34502 m .52607 .34493 L .52608 .34494 L F
.52611 .34485 m .52602 .34503 L .52622 .34499 L F
.52626 .34489 m .52641 .34493 L .52639 .3449 L F
.5259 .34506 m .5259 .34505 L .52692 .34444 L F
.5261 .34469 m .52625 .34487 L .52613 .34444 L F
.52625 .34487 m .5264 .34477 L .52629 .34488 L F
.52628 .34477 m .5262 .3448 L .52625 .34477 L F
.52625 .34487 m .52639 .3449 L .52613 .34444 L F
.52642 .34492 m .52604 .34461 L .5267 .34492 L F
.52604 .34461 m .52554 .34422 L .52605 .34453 L F
.52604 .34461 m .52605 .34453 L .5267 .34492 L F
.52628 .34491 m .52654 .3449 L .52638 .34486 L F
.52601 .34516 m .52603 .34512 L .52635 .34489 L F
.52619 .34496 m .52645 .34492 L .52628 .34491 L F
.52646 .34491 m .52625 .34503 L .52635 .34489 L F
.52625 .34503 m .52622 .345 L .52635 .34489 L F
.52621 .34498 m .52648 .34492 L .52619 .34496 L F
.52573 .34535 m .52667 .34479 L .5267 .34479 L F
.5248 .34588 m .52572 .34534 L .52573 .34535 L F
.52572 .34534 m .52667 .34479 L .52573 .34535 L F
.52648 .34492 m .52654 .3449 L .52645 .34492 L F
.52621 .34439 m .52665 .34494 L .52672 .34495 L F
.52614 .34432 m .5262 .34439 L .52621 .34439 L F
.5262 .34439 m .52665 .34494 L .52621 .34439 L F
.52684 .34493 m .52623 .34439 L .52672 .34495 L F
.52716 .34448 m .5273 .3445 L .53514 .34109 L F
.52803 .34418 m .52921 .34378 L .54208 .33806 L F
.5308 .34255 m .52979 .3433 L .53514 .34109 L F
.53228 .34213 m .52894 .34387 L p .5308 .34255 L F P
0 g
s
.52931 .344 m .52726 .34459 L .52714 .34457 L .672 .728 .891 r
F
.52894 .34387 m .52691 .34493 L p .52873 .34382 L F P
0 g
s
.52894 .34387 m .52873 .34382 L .5308 .34255 L .672 .728 .891 r
F
.52691 .34493 m .52894 .34387 L p .52689 .34476 L F P
0 g
s
.52691 .34493 m .52691 .34486 L .52868 .3438 L .672 .728 .891 r
F
.52873 .34382 m .52868 .3438 L .5308 .34255 L F
.52701 .34463 m .52921 .34378 L .52803 .34418 L F
.52691 .34493 m .52868 .3438 L .52873 .34382 L F
.53356 .3433 m .52749 .34482 L .53385 .34319 L F
.52749 .34482 m .52775 .34474 L .53385 .34319 L F
.52809 .34467 m .53341 .34354 L .52789 .34464 L F
.5269 .34494 m .5322 .34383 L .52688 .34493 L F
.52854 .34462 m .52864 .34453 L .53356 .3433 L F
.52778 .34485 m .52815 .34478 L .52815 .34477 L F
.52778 .34486 m .52815 .34478 L .52778 .34485 L F
.52815 .34478 m .52841 .34472 L p .52815 .34477 L F P
0 g
s
.52688 .34493 m .5322 .34383 L .53202 .34384 L .672 .728 .891 r
F
.52841 .34472 m .5322 .34383 L p .52814 .34468 L F P
0 g
s
.5322 .34383 m .53198 .34388 L p .53356 .3433 L .672 .728 .891 r
F P
0 g
s
.53198 .34388 m .52705 .34504 L p .53162 .34382 L .672 .728 .891 r
F P
0 g
s
.53198 .34388 m .53162 .34382 L .53356 .3433 L .672 .728 .891 r
F
.52554 .34422 m .52586 .34427 L .52608 .34444 L F
.52605 .34453 m .52608 .34444 L .5267 .34492 L F
.52554 .34422 m .52608 .34444 L .52605 .34453 L F
.52623 .34439 m .52621 .34439 L .52672 .34495 L F
.52782 .34412 m .52783 .34412 L .52979 .3433 L F
.52666 .34494 m .52652 .34492 L .52843 .34386 L F
.52844 .34389 m .52843 .34386 L .52924 .34341 L F
.52666 .34494 m .52843 .34386 L .52844 .34389 L F
.52684 .34493 m .52691 .34493 L .52689 .34476 L F
.52691 .34494 m .52841 .34472 L .52814 .34468 L F
.52697 .34501 m .52701 .34494 L .52864 .34453 L F
.52711 .34498 m .52841 .34472 L .52691 .34494 L F
.52697 .34503 m .52766 .34481 L .52771 .34484 L F
.52601 .34516 m .52581 .34528 L .52603 .34512 L F
.52597 .34513 m .52648 .34598 L .52594 .34518 L F
.52648 .34598 m .52674 .34641 L .52646 .34598 L F
.52648 .34598 m .52646 .34598 L .52594 .34518 L F
.52589 .34531 m .52673 .34504 L .52589 .34531 L F
.52594 .34553 m .52589 .34532 L .52586 .34537 L F
.52594 .34553 m .52589 .34531 L .52589 .34532 L F
.52593 .34544 m .52469 .34608 L p .52596 .34535 L F P
0 g
s
.52587 .34543 m .52587 .34542 L .52585 .34538 L .672 .728 .891 r
F
.52598 .34528 m .52595 .34537 L .52589 .34527 L F
.52592 .34521 m .52594 .34517 L .52568 .3452 L F
.52568 .3452 m .52595 .34516 L .52596 .34514 L F
.52395 .3461 m .5242 .346 L .5242 .34599 L F
.52323 .34643 m .52397 .34611 L .52395 .3461 L F
.52323 .34643 m .52397 .34611 L .52323 .34643 L F
.52397 .34611 m .52598 .34523 L .52397 .34611 L F
.52397 .34611 m .52397 .34611 L .52323 .34643 L F
.51938 .34685 m .50864 .34939 L p .51354 .3475 L F P
0 g
s
.51267 .34778 m .5245 .34556 L p .51354 .3475 L .672 .728 .891 r
F P
0 g
s
.51267 .34778 m .51265 .34779 L .52328 .34578 L .672 .728 .891 r
F
.52368 .34626 m .52362 .34629 L .52374 .34623 L F
.52362 .34629 m .519 .34878 L .52374 .34623 L F
.52374 .34623 m .519 .34878 L .52488 .34579 L F
.5248 .34588 m .52051 .34826 L .52483 .34583 L F
.52388 .34607 m .52329 .34678 L .52371 .34616 L F
.52592 .34521 m .52589 .34527 L .52548 .34466 L F
.52599 .34525 m .52598 .34528 L .52561 .34468 L F
.52589 .34507 m .52608 .34495 L .52607 .34496 L F
.52602 .34502 m .52571 .34471 L .52607 .34493 L F
.52608 .34494 m .52571 .34471 L .52597 .34479 L F
.52608 .34482 m .52596 .34478 L .52486 .34329 L F
.52601 .34504 m .52597 .34513 L .52571 .34471 L F
.52594 .34515 m .52615 .34491 L .52561 .34423 L F
.52525 .34512 m .52536 .34517 L .52602 .34503 L F
.52621 .34498 m .52605 .34503 L .52618 .34495 L F
.52598 .34528 m .52589 .34527 L .52592 .34521 L F
.52594 .3453 m .52596 .34527 L .52592 .34518 L F
.52571 .34471 m .52597 .34513 L .52561 .34468 L F
.52597 .34513 m .52594 .34518 L .52561 .34468 L F
.5259 .3452 m .52592 .34518 L .52556 .34434 L F
.52594 .3453 m .52592 .34518 L .5259 .3452 L F
.5257 .3447 m .52569 .34469 L .52601 .34554 L F
.52599 .34482 m .52617 .34491 L .52611 .3449 L F
.52625 .34487 m .52622 .34488 L .52626 .34489 L F
.52619 .34495 m .52625 .34487 L .52629 .34488 L F
.52608 .34495 m .5261 .34486 L .5262 .3448 L F
.52529 .34428 m .5263 .34491 L .52616 .34491 L F
.52511 .34415 m .52529 .34427 L .52529 .34428 L F
.52571 .3447 m .52561 .34423 L .52556 .34434 L F
.52628 .34506 m .52563 .34542 L .52626 .34505 L F
.52601 .34517 m .526 .34519 L .52597 .34513 L F
.52633 .34513 m .52631 .3451 L .52568 .3452 L F
.52589 .34521 m .52631 .3451 L .52631 .3451 L F
.52521 .34539 m .52589 .34521 L .52589 .34521 L F
.52592 .34521 m .52633 .34513 L .52594 .34517 L F
.52589 .34521 m .52631 .3451 L .52589 .34521 L F
.52597 .34524 m .52594 .34515 L .52596 .34527 L F
.52594 .34515 m .52578 .3447 L .52593 .34517 L F
.52521 .34539 m .52519 .34539 L .52589 .34521 L F
.52589 .34521 m .52589 .34521 L .52631 .3451 L F
.52521 .34539 m .52589 .34521 L .52589 .34521 L F
.52594 .34515 m .52593 .34517 L .52596 .34527 L F
.52552 .34539 m .52601 .34517 L .52536 .34537 L F
.52625 .34503 m .52601 .34516 L .52622 .345 L F
.52601 .34517 m .52689 .34476 L .52605 .3451 L F
.52562 .34527 m .52592 .34521 L .52568 .3452 L F
.52601 .34517 m .52597 .34513 L .52604 .34507 L F
.52628 .34507 m .52628 .34506 L .5255 .34523 L F
.52596 .34514 m .5263 .34509 L .52628 .34507 L F
.526 .34506 m .52628 .34506 L .52623 .34501 L F
.52604 .34507 m .526 .34507 L .52603 .34506 L F
.52604 .34507 m .52597 .34513 L .526 .34507 L F
.52597 .34513 m .52628 .34506 L .526 .34506 L F
.52631 .3451 m .52589 .3452 L .52622 .34499 L F
.52464 .34541 m .52628 .34506 L .52628 .34506 L F
.52585 .34546 m .52593 .34544 L .5259 .34543 L F
.52452 .3461 m .52584 .34548 L .52585 .34546 L F
.52584 .34548 m .52593 .34544 L .52585 .34546 L F
.52591 .34551 m .52594 .34552 L .52588 .3454 L F
.52577 .34535 m .52589 .34531 L .52589 .34531 L F
.52589 .34533 m .52638 .34612 L .5258 .34531 L F
.52638 .34612 m .52673 .34668 L .52635 .34612 L F
.52638 .34612 m .52635 .34612 L .5258 .34531 L F
.52374 .34671 m .52298 .34716 L .52371 .34669 L F
.52298 .34716 m .51571 .35153 L .52305 .34693 L F
.52073 .34822 m .52245 .34746 L .52471 .34613 L F
.52587 .34542 m .52588 .3454 L .52582 .34528 L F
.52591 .34551 m .52582 .34528 L .52581 .3453 L F
.52584 .34538 m .52585 .34538 L .52581 .3453 L F
.52584 .34538 m .52581 .3453 L .52581 .3453 L F
.52587 .34543 m .52585 .34538 L .52584 .34538 L F
.5258 .34531 m .52587 .34543 L .52581 .3453 L F
.52456 .34609 m .52593 .34544 L .52452 .3461 L F
.52491 .34597 m .52593 .34544 L p .52493 .34591 L F P
0 g
s
.52585 .34544 m .52374 .34671 L .52588 .34527 L .672 .728 .891 r
F
.52581 .3453 m .52582 .34528 L .52548 .34457 L F
.52542 .34521 m .5254 .34521 L .52605 .34503 L F
.52605 .34503 m .52605 .34503 L .52621 .34498 L F
.52624 .34502 m .52654 .3449 L .52621 .34498 L F
.52622 .34498 m .52621 .34498 L .52637 .34494 L F
.52605 .34503 m .52621 .34498 L .52622 .34498 L F
.52589 .3452 m .52602 .34506 L .52622 .34499 L F
.52604 .34504 m .52604 .34504 L .52622 .34499 L F
.52605 .3451 m .52624 .34502 L .52611 .345 L F
.5239 .34571 m .52395 .34563 L .52493 .34535 L F
.52551 .34523 m .5255 .34523 L .52464 .34541 L F
.52595 .34537 m .52594 .34541 L .52589 .34533 L F
.52594 .34534 m .52589 .34533 L .52548 .34467 L F
.5258 .34531 m .52581 .3453 L .52548 .34457 L F
.52552 .34523 m .52547 .34522 L .52603 .34505 L F
.52602 .34506 m .52603 .34505 L .52622 .34499 L F
.52604 .34555 m .5257 .3447 L .52601 .34554 L F
.52561 .34468 m .52598 .34528 L .52545 .34463 L F
.52552 .34523 m .52603 .34505 L .52602 .34506 L F
.52588 .34539 m .52588 .34539 L .52584 .34527 L F
.52584 .34527 m .52584 .34527 L .52561 .34461 L F
.52588 .34539 m .52584 .34527 L .52584 .34527 L F
.52603 .34505 m .52604 .34504 L .52622 .34499 L F
.52612 .34483 m .52522 .34374 L .52522 .34373 L F
.52577 .34535 m .5269 .34502 L .52687 .34503 L F
.52631 .3451 m .52631 .3451 L .52672 .345 L F
.52628 .34507 m .52665 .345 L .52628 .34506 L F
.5263 .34509 m .52652 .34492 L .52633 .34513 L F
.52617 .34491 m .5269 .3453 L .5269 .34544 L F
.52618 .34495 m .5254 .34521 L .52617 .34493 L F
.52615 .34491 m .52611 .345 L .52619 .34496 L F
.52617 .34493 m .52625 .34487 L .52619 .34495 L F
.52615 .34491 m .52619 .34496 L .52628 .34491 L F
.52581 .3453 m .52581 .3453 L .52548 .34457 L F
.52617 .34493 m .5254 .34521 L .52525 .34517 L F
.5263 .34491 m .52634 .34494 L .52616 .34491 L F
.52625 .34492 m .52618 .34495 L .52623 .34492 L F
.52621 .34498 m .52618 .34495 L .52635 .34489 L F
.52587 .34523 m .52589 .34521 L .52775 .34474 L F
.52629 .34507 m .52691 .34493 L .52659 .34492 L F
.52691 .34499 m .52667 .34483 L .52691 .34499 L F
.52683 .34497 m .52684 .34497 L p .52683 .34497 L F P
0 g
s
.52684 .34497 m .52691 .34493 L p .52683 .34497 L .672 .728 .891 r
F P
0 g
s
.52665 .345 m .53078 .34413 L .52663 .34499 L .672 .728 .891 r
F
.52683 .34495 m .52683 .34497 L .52691 .34493 L F
.52669 .3454 m .52699 .34577 L .52671 .34533 L F
.5269 .34562 m .52675 .3455 L p .5269 .34552 L F P
0 g
s
.53717 .3553 m .52701 .34578 L p .53685 .35497 L .672 .728 .891 r
F P
0 g
s
.52701 .34578 m .52701 .34576 L .53685 .35497 L .672 .728 .891 r
F
.52699 .34577 m .53735 .35547 L p .52783 .34611 L F P
0 g
s
.52896 .34731 m .5269 .34562 L p .52805 .34634 L .672 .728 .891 r
F P
0 g
s
.53735 .35547 m .53717 .3553 L p .53685 .35497 L .672 .728 .891 r
F P
0 g
s
.52787 .34583 m .52729 .34558 L .53735 .35547 L .672 .728 .891 r
F
.5269 .34562 m .5269 .34544 L .52875 .34677 L F
.52675 .3455 m .52886 .34723 L p .52687 .3453 L F P
0 g
s
.52781 .34472 m .52631 .3451 L .52761 .34468 L .672 .728 .891 r
F
.52634 .34494 m .5269 .3453 L .52617 .34491 L F
.52577 .34535 m .52679 .34506 L .52682 .34507 L F
.52605 .34503 m .5261 .34497 L .52618 .34495 L F
.5261 .34501 m .52615 .34491 L .52605 .34502 L F
.52584 .34527 m .52587 .34523 L .52561 .34461 L F
.52612 .34495 m .52525 .34517 L .52616 .3449 L F
.52603 .34491 m .52611 .345 L .52615 .34491 L F
.52614 .34491 m .52525 .34517 L .52601 .34489 L F
.52597 .3449 m .52603 .34494 L .52603 .34491 L F
.52603 .34494 m .52611 .345 L .52603 .34491 L F
.52578 .3447 m .52561 .34423 L .52571 .3447 L F
.52529 .34427 m .5263 .34491 L .52529 .34428 L F
.5257 .3447 m .52556 .34435 L .52569 .34469 L F
.52601 .34489 m .52511 .34415 L p .52609 .3449 L F P
0 g
s
.52624 .34502 m .52621 .34498 L .52611 .345 L .672 .728 .891 r
F
.52611 .345 m .52621 .34498 L .52619 .34496 L F
.52589 .3453 m .52669 .34502 L .52589 .34531 L F
.52601 .34517 m .52629 .34507 L .52627 .34505 L F
.52598 .34523 m .52639 .3452 L .52629 .34507 L F
.52608 .34532 m .52639 .3452 L .52615 .34491 L F
.52691 .34499 m .52667 .34483 L .52669 .3448 L F
.52659 .34492 m .52684 .34493 L .52689 .34476 L F
.52642 .34492 m .5267 .34492 L .52681 .34501 L F
.52642 .34492 m .52681 .34501 L .5266 .34498 L F
.52627 .34505 m .52629 .34507 L .52689 .34476 L F
.52631 .3451 m .52622 .34499 L .52745 .34465 L F
.52757 .34467 m .52745 .34465 L .52845 .34437 L F
.52631 .3451 m .52745 .34465 L .52757 .34467 L F
.52366 .34324 m .52372 .34325 L .52554 .34428 L F
.52761 .34468 m .52884 .34427 L .52884 .34428 L F
.52631 .3451 m .52759 .34468 L .52761 .34468 L F
.52759 .34468 m .52884 .34427 L .52761 .34468 L F
.52553 .34442 m .52556 .34433 L .52552 .34439 L F
.52556 .34435 m .52556 .34433 L .52553 .34442 L F
.52552 .34439 m .52556 .34433 L .52541 .34398 L F
.52556 .34435 m .52556 .34434 L .52556 .34433 L F
.52529 .34426 m .52554 .34422 L .52647 .34496 L F
.52511 .34415 m .52532 .34418 L .52529 .34426 L F
.52532 .34418 m .52554 .34422 L .52529 .34426 L F
.52609 .3449 m .52599 .34482 L .52611 .3449 L F
.52614 .34491 m .52601 .34489 L .52611 .34485 L F
.52622 .34487 m .52621 .34487 L .52693 .34443 L F
.52614 .34432 m .52663 .34494 L .52665 .34494 L F
.5267 .34492 m .52589 .34429 L .52681 .34493 L F
.52614 .34432 m .52613 .34444 L .52663 .34494 L F
.52613 .34444 m .52616 .34449 L .52616 .34448 L F
.52589 .34429 m .52595 .34431 L .52618 .34447 L F
.52617 .34449 m .52618 .34447 L .52696 .34503 L F
.52589 .34429 m .52618 .34447 L .52617 .34449 L F
.52587 .34532 m .52586 .34532 L .52625 .34522 L F
.52565 .34527 m .52565 .34527 L .52672 .345 L F
.52601 .34517 m .52598 .34523 L .52629 .34507 L F
.52595 .34537 m .52589 .34533 L .52594 .34534 L F
.52593 .34544 m .52612 .34526 L .52614 .34531 L F
.52598 .34528 m .52649 .34612 L .52595 .34537 L F
.52649 .34612 m .52673 .34651 L .52647 .34612 L F
.52649 .34612 m .52647 .34612 L .52595 .34537 L F
.52654 .34612 m .52649 .34612 L .52598 .34528 L F
.52673 .34651 m .52673 .34668 L .52594 .34541 L F
.52673 .34651 m .52594 .34541 L .52595 .34537 L F
.52623 .34612 m .52673 .34668 L .52671 .34706 L F
.52656 .34668 m .52644 .34568 L .52609 .34557 L F
.52655 .34617 m .52653 .34628 L .52611 .34551 L F
.52589 .3452 m .52485 .34547 L .52602 .34506 L F
.52595 .34519 m .52596 .34513 L .52594 .34515 L F
.52597 .34524 m .52596 .34513 L .52595 .34519 L F
.52597 .34524 m .5261 .34501 L .52596 .34513 L F
.52592 .34521 m .52548 .34466 L .52548 .34466 L F
.52548 .34457 m .52588 .34539 L .52561 .34461 L F
.52504 .34567 m .52575 .34538 L .52505 .34564 L F
.52581 .34528 m .52483 .34583 L .52586 .34517 L F
.52601 .34517 m .52605 .3451 L .52536 .34537 L F
.52542 .34521 m .52637 .34494 L .52638 .34494 L F
.5261 .34501 m .52605 .34502 L .52594 .34515 L F
.5258 .34531 m .5258 .34531 L .52581 .3453 L F
.5258 .34531 m .52568 .34528 L .52581 .3453 L F
.52581 .3453 m .52568 .34528 L .52587 .34523 L F
.52577 .34535 m .52568 .34528 L .5258 .34531 L F
.5242 .34599 m .52598 .34523 L .52601 .34517 L F
.52528 .34558 m .5251 .34564 L .52608 .34503 L F
.52587 .34523 m .52389 .34573 L .52589 .34521 L F
.52567 .34527 m .52589 .34523 L .52566 .34526 L F
.5261 .34519 m .52615 .34491 L .52599 .3452 L F
.5261 .34519 m .52599 .3452 L .52597 .34524 L F
.52595 .34539 m .52596 .34535 L .526 .34533 L F
.52595 .34539 m .526 .34533 L .52612 .34526 L F
.52593 .34544 m .52595 .34539 L .52612 .34526 L F
.52587 .34542 m .52601 .34536 L .52597 .34524 L F
.52608 .34533 m .52639 .3452 L .5261 .34522 L F
.52597 .34524 m .526 .34523 L .52598 .34523 L F
.52605 .34547 m .5261 .34519 L .52597 .34524 L F
.52608 .34536 m .52639 .3452 L p .52607 .34535 L F P
0 g
s
.5259 .34543 m .52608 .34536 L .52607 .34535 L .672 .728 .891 r
F
.52593 .34544 m .52608 .34536 L p .5259 .34543 L F P
0 g
s
.52589 .34429 m .52528 .34382 L .52595 .34431 L .672 .728 .891 r
F
.52561 .34423 m .52528 .34382 L .52586 .34427 L F
.52541 .34398 m .52615 .34491 L .52576 .34405 L F
.52485 .34547 m .5239 .34571 L .5249 .3454 L F
.52401 .34562 m .52467 .34551 L .524 .34558 L F
.52499 .34545 m .5232 .34645 L .52532 .34539 L F
.52499 .34545 m .52532 .34539 L .52611 .345 L F
.52485 .34547 m .52547 .34522 L .52552 .34523 L F
.5249 .3454 m .52604 .34504 L .52603 .34505 L F
.52561 .34461 m .52556 .34435 L .52553 .34442 L F
.52601 .34554 m .52567 .34462 L .52561 .34461 L F
.52567 .34462 m .52556 .34435 L .52561 .34461 L F
.5297 .34453 m .53132 .34423 L .53132 .34423 L F
.52698 .34503 m .5297 .34453 L .5297 .34453 L F
.5297 .34453 m .53132 .34423 L .5297 .34453 L F
.52542 .34521 m .52605 .34503 L .52542 .34521 L F
.52542 .34521 m .52605 .34503 L .52605 .34503 L F
.52605 .34503 m .52599 .34505 L .52606 .34502 L F
.52545 .34519 m .5254 .34521 L .52546 .34519 L F
.52609 .34499 m .52608 .34498 L .5261 .34497 L F
.52597 .3449 m .52499 .34545 L .52611 .345 L F
.52605 .34547 m .52612 .34541 L .52608 .34532 L F
.52679 .34439 m .52686 .34439 L .54061 .33676 L F
.52767 .34389 m .52657 .34464 L .52757 .34389 L F
.52397 .34611 m .52598 .34523 L .52395 .3461 L F
.5232 .34645 m .52552 .34539 L .52536 .34537 L F
.52419 .34601 m .52488 .34579 L .52598 .34523 L F
.52417 .34607 m .52488 .34579 L .52419 .34601 L F
.52509 .34553 m .52475 .34576 L .52517 .34535 L F
.52475 .34576 m .52329 .34678 L .52452 .34585 L F
.52475 .34576 m .52452 .34585 L .52517 .34535 L F
.52599 .34482 m .526 .34479 L .52617 .34491 L F
.52614 .34491 m .52611 .34485 L .52615 .3449 L F
.52597 .3449 m .52615 .34491 L .5261 .34484 L F
.52603 .34487 m .52603 .34491 L .52612 .34488 L F
.52606 .3449 m .52609 .3449 L .52623 .34501 L F
.52606 .3449 m .52623 .34501 L .52683 .34547 L F
.52601 .34489 m .52606 .3449 L .52683 .34547 L F
.52603 .34491 m .52639 .3452 L p .52612 .34488 L F P
0 g
s
.5261 .34469 m .52608 .34482 L .52611 .34471 L .672 .728 .891 r
F
.52511 .34415 m .5264 .34492 L .5263 .34491 L F
.52556 .34434 m .52558 .3443 L .52549 .34418 L F
.52558 .3443 m .52561 .34423 L .52549 .34418 L F
.52549 .34418 m .52561 .34423 L .52541 .34398 L F
.53078 .34413 m .53198 .34388 L .53079 .34412 L F
.53078 .34413 m .53079 .34412 L .52663 .34499 L F
.53198 .34388 m .5322 .34383 L .53198 .34387 L F
.53198 .34388 m .53198 .34387 L .52663 .34499 L F
.53034 .34425 m .53066 .34434 L .53999 .34262 L F
.52705 .34504 m .52697 .34503 L .53351 .34332 L F
.53031 .34374 m .53255 .3436 L .54422 .34099 L F
.53351 .34332 m .53351 .34332 L .53356 .3433 L F
.52705 .34504 m .53351 .34332 L .53351 .34332 L F
.52391 .34345 m .52145 .34207 L .52416 .3435 L F
.52376 .34342 m .52145 .34207 L .52378 .34343 L F
.52495 .34416 m .52366 .34324 L p .52505 .34418 L F P
0 g
s
.52511 .34415 m .51435 .33532 L p .52554 .34422 L .672 .728 .891 r
F P
0 g
s
.52322 .34238 m .51435 .33532 L .52305 .34209 L .672 .728 .891 r
F
.52322 .34238 m .52305 .34209 L .52528 .34382 L F
.51435 .33532 m .52511 .34415 L p .52501 .34352 L F P
0 g
s
.52463 .34375 m .52403 .34327 L .52434 .34335 L .672 .728 .891 r
F
.52463 .34376 m .52403 .34327 L .52463 .34375 L F
.52463 .34376 m .52352 .34313 L .52403 .34327 L F
.52366 .34324 m .52491 .34414 L p .52346 .34264 L F P
0 g
s
.52515 .3437 m .52603 .34491 L .52604 .34478 L .672 .728 .891 r
F
.52614 .34485 m .52582 .34468 L .52611 .34479 L F
.52623 .34492 m .52618 .34495 L .52617 .34493 L F
.52616 .34491 m .52617 .34491 L .52617 .34491 L F
.52639 .3452 m .52611 .34494 L .52613 .34488 L F
.5261 .34484 m .52628 .34491 L .52722 .34444 L F
.52667 .34483 m .5254 .34391 L .52669 .3448 L F
.5254 .34391 m .52528 .34382 L .5254 .3439 L F
.5254 .34391 m .5254 .3439 L .52669 .3448 L F
.52622 .34484 m .52619 .34479 L p .52615 .34491 L F P
0 g
s
.52615 .3449 m .52618 .34485 L .5262 .34485 L .672 .728 .891 r
F
.52618 .34485 m .52619 .34482 L .5262 .34485 L F
.5262 .34485 m .52619 .34482 L .52622 .34484 L F
.52615 .34491 m .52618 .34475 L .52608 .34474 L F
.52615 .34491 m .52619 .34479 L .52617 .34478 L F
.52615 .34491 m .52628 .34491 L .5261 .34484 L F
.52634 .34494 m .52617 .34491 L .52616 .34491 L F
.52616 .3449 m .52614 .34491 L .52625 .3448 L F
.52589 .34531 m .52669 .34502 L .52673 .34504 L F
.52611 .3449 m .52617 .34491 L .5269 .34544 L F
.52639 .3452 m .52622 .34484 L p .52615 .34491 L F P
0 g
s
.52639 .3452 m .52615 .34485 L .52617 .34482 L .672 .728 .891 r
F
.52635 .34489 m .52625 .34492 L .52623 .34492 L F
.52648 .34492 m .52645 .34492 L .52619 .34496 L F
.5264 .34492 m .52647 .34496 L .5263 .34491 L F
.52642 .34492 m .52627 .34494 L .52635 .34489 L F
.52644 .34492 m .52627 .34494 L .52642 .34492 L F
.5263 .34491 m .52647 .34496 L .52634 .34494 L F
.52633 .34494 m .52621 .34498 L .52627 .34494 L F
.52644 .34492 m .52637 .34494 L .52633 .34494 L F
.52637 .34494 m .52621 .34498 L .52633 .34494 L F
.52645 .34492 m .52654 .3449 L .52628 .34491 L F
.52617 .34489 m .52634 .34493 L .52656 .3449 L F
.52625 .34489 m .52626 .34491 L .52646 .34491 L F
.52617 .34491 m .5269 .3453 L .52617 .34491 L F
.52565 .34527 m .52672 .345 L .52672 .345 L F
.52609 .3449 m .52611 .3449 L .5269 .34544 L F
.52626 .34491 m .52639 .3452 L .52645 .34496 L F
.52615 .3449 m .52611 .34485 L .52619 .34482 L F
.52639 .3452 m .52613 .34488 L .52615 .34485 L F
.5269 .34502 m .52698 .345 L .52691 .34502 L F
.52631 .3451 m .52672 .345 L .52673 .345 L F
.5269 .3453 m .52642 .34492 L .5269 .34508 L F
.52668 .34501 m .52653 .34498 L .52687 .3453 L F
.5269 .34544 m .5269 .3453 L .52875 .34677 L F
.52689 .34525 m .52687 .3453 L .52729 .34571 L F
.52668 .34501 m .52687 .3453 L .52689 .34525 L F
.5249 .3454 m .52493 .34535 L .52604 .34504 L F
.52536 .34537 m .52605 .3451 L .52611 .345 L F
.52609 .34557 m .52597 .34524 L .52596 .34527 L F
.52602 .34537 m .52598 .34535 L .52597 .34533 L F
.52596 .34527 m .52578 .3447 L .52571 .3447 L F
.52612 .34491 m .52547 .34541 L .52605 .34487 L F
.52608 .34503 m .52547 .34541 L .52612 .34491 L F
.52609 .34483 m .52509 .34553 L .52517 .34535 L F
.52531 .34511 m .52598 .34509 L .52591 .345 L F
.52537 .34555 m .52608 .34503 L .52606 .34509 L F
.52008 .34823 m .52456 .34609 L .52452 .3461 L F
.52298 .34716 m .52528 .34558 L .52537 .34555 L F
.52528 .34558 m .52608 .34503 L .52537 .34555 L F
.52589 .34523 m .52589 .34522 L .52566 .34526 L F
.52619 .34496 m .52612 .34491 L .52613 .34488 L F
.52612 .34491 m .52605 .34487 L .52613 .34488 L F
.52617 .34482 m .52525 .34517 L .52609 .34483 L F
.52619 .34482 m .52525 .34517 L .52617 .34482 L F
.5259 .3452 m .52556 .34434 L .5259 .3452 L F
.5259 .3452 m .52556 .34434 L .5259 .3452 L F
.52609 .34483 m .52525 .34517 L .52492 .34508 L F
.52613 .34488 m .52374 .34535 L .52606 .34498 L F
.52374 .34535 m .52323 .34545 L .52378 .34536 L F
.52374 .34535 m .52378 .34536 L .52606 .34498 L F
.54007 .35387 m .54086 .35327 L p .53009 .34686 L F P
0 g
s
.52515 .34371 m .52515 .34372 L .52517 .34374 L .672 .728 .891 r
F
.52515 .34372 m .52511 .34415 L .52517 .34374 L F
.52599 .34482 m .52511 .34415 L .526 .34479 L F
.52511 .34415 m .52603 .34491 L p .52517 .34374 L F P
0 g
s
.52509 .34359 m .52552 .34444 L .52547 .34449 L .672 .728 .891 r
F
.52366 .34324 m .52554 .34428 L .52551 .34427 L F
.52505 .34426 m .52473 .34379 L .52504 .34426 L F
.52505 .34418 m .52366 .34324 L .52551 .34427 L F
.52463 .34376 m .52434 .34335 L .52501 .34352 L F
.52346 .34264 m .52491 .34414 L .52544 .34426 L F
.52522 .34427 m .52145 .34207 L .52524 .34427 L F
.52524 .34427 m .52145 .34207 L .52542 .3443 L F
.52514 .34369 m .52603 .34491 L .52515 .3437 L F
.52618 .34475 m .52498 .34217 L p .52608 .34474 L F P
0 g
s
.52612 .34541 m .52639 .3452 L .52608 .34532 L .672 .728 .891 r
F
.52614 .34551 m .52639 .3452 L .52605 .34547 L F
.52639 .3452 m .5262 .34545 L .52604 .34513 L F
.52501 .3457 m .52509 .34553 L .52609 .34483 L F
.52611 .34494 m .52604 .34513 L .52582 .34468 L F
.52639 .3452 m .52604 .34513 L .52611 .34494 L F
.52602 .34537 m .52597 .34533 L .52598 .34529 L F
.52601 .34521 m .52601 .34521 L .52612 .3454 L F
.52604 .34555 m .52596 .34527 L .52594 .3453 L F
.52597 .34533 m .52598 .34535 L .52596 .34535 L F
.52596 .34535 m .52625 .34503 L .5263 .34509 L F
.52634 .34514 m .52606 .34531 L .5263 .34509 L F
.52589 .34523 m .52639 .3452 L .52635 .34515 L F
.52584 .34525 m .52635 .34515 L .52635 .34515 L F
.52619 .34496 m .52608 .34503 L .52612 .34491 L F
.52613 .34488 m .52606 .34498 L .52619 .34496 L F
.52609 .34483 m .52613 .34488 L .52616 .34484 L F
.5272 .34454 m .52628 .34506 L .52753 .34432 L F
.5272 .3446 m .52616 .3449 L .52625 .3448 L F
.52609 .34483 m .52656 .3449 L .5263 .34482 L F
.52616 .3448 m .52613 .34488 L .52609 .34483 L F
.52546 .34397 m .52576 .34405 L .52571 .34394 L F
.52599 .34431 m .52528 .34382 L .52619 .34436 L F
.52617 .34482 m .52531 .34364 L .52559 .34379 L F
.52613 .34488 m .52605 .34487 L .52609 .34483 L F
.52609 .34483 m .52602 .34485 L .52613 .34488 L F
.52604 .34478 m .52603 .34487 L .52612 .34488 L F
.52611 .34494 m .52582 .34468 L .52614 .34485 L F
.52552 .34444 m .52591 .3452 L .52547 .34449 L F
.52588 .3454 m .52592 .34534 L .52587 .34523 L F
.52588 .3454 m .52587 .34523 L .52584 .34527 L F
.52563 .34542 m .5248 .34588 L .52561 .34542 L F
.52588 .34539 m .52588 .3454 L .52588 .34539 L F
.5248 .34588 m .52483 .34583 L .52498 .34574 L F
.5248 .34588 m .52498 .34574 L .52502 .34575 L F
.52423 .34612 m .52587 .34542 L .52598 .34523 L F
.52585 .34544 m .52588 .34527 L .52602 .34518 L F
.52591 .3452 m .52597 .34533 L .5259 .34521 L F
.52591 .3452 m .5259 .34521 L .52547 .34449 L F
.52485 .34547 m .5249 .3454 L .52547 .34522 L F
.52395 .34563 m .52494 .34534 L .52493 .34535 L F
.52498 .34217 m .52441 .34094 L p .52495 .34218 L F P
0 g
s
.52608 .34474 m .52498 .34217 L .52495 .34218 L .672 .728 .891 r
F
.52608 .34474 m .52441 .34094 L .52438 .34095 L F
.52541 .34398 m .52576 .34405 L .52546 .34397 L F
.52541 .34398 m .52571 .34394 L .52541 .34395 L F
.52578 .3439 m .52587 .34408 L p .52559 .34379 L F P
0 g
s
.52619 .34479 m .52618 .34475 L p .52617 .34478 L .672 .728 .891 r
F P
0 g
s
.52587 .34408 m .52639 .3452 L p .52579 .34415 L .672 .728 .891 r
F P
0 g
s
.52511 .34263 m .52364 .33928 L .52356 .33922 L .672 .728 .891 r
F
.52615 .34491 m .52514 .34264 L .52511 .34263 L F
.52514 .34264 m .52364 .33928 L .52511 .34263 L F
.5271 .345 m .54014 .34261 L .53999 .34262 L F
.52703 .34502 m .52703 .34502 L .53092 .34427 L F
.52699 .34503 m .5335 .34384 L .52698 .34503 L F
.5335 .34384 m .53879 .34286 L .53349 .34383 L F
.5335 .34384 m .53349 .34383 L .52698 .34503 L F
.52691 .34502 m .52766 .34481 L .52697 .34503 L F
.52732 .34484 m .52697 .34502 L .52836 .34476 L F
.52682 .34507 m .52691 .34502 L .52697 .34503 L F
.5269 .34502 m .52691 .34502 L .52687 .34503 L F
.52787 .34583 m .52681 .34501 L .52696 .34503 L F
.52685 .34505 m .52699 .34503 L .52698 .34503 L F
.52634 .34494 m .52647 .34496 L .5269 .3453 L F
.52653 .34498 m .52675 .3455 L .52687 .3453 L F
.52634 .34493 m .52697 .34502 L .52656 .3449 L F
.52646 .34491 m .52649 .34497 L .52653 .34498 L F
.52649 .34497 m .52675 .3455 L .52653 .34498 L F
.52709 .34501 m .5271 .345 L .52683 .34505 L F
.52601 .34489 m .52683 .34547 L .52682 .34547 L F
.52639 .3452 m .52601 .34489 L p .5264 .34517 L F P
0 g
s
.52639 .3452 m .52622 .34524 L p .52659 .34513 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .5264 .34517 L .5269 .34552 L .672 .728 .891 r
F
.52675 .3455 m .52639 .3452 L p .5269 .34552 L F P
0 g
s
.5269 .34552 m .52609 .3449 L .5269 .34544 L .672 .728 .891 r
F
.52639 .3452 m .52672 .34547 L p .52649 .34497 L F P
0 g
s
.52585 .34552 m .52583 .34551 L .52595 .34544 L .672 .728 .891 r
F
.52606 .34498 m .52622 .34499 L .52619 .34496 L F
.52611 .34479 m .52531 .34364 L .52617 .34482 L F
.52604 .34477 m .52613 .34488 L .5261 .34456 L F
.52613 .34488 m .52639 .3452 L .52626 .34491 L F
.52612 .34495 m .52616 .3449 L .5272 .3446 L F
.52613 .34488 m .52619 .34496 L .52617 .34489 L F
.52613 .34488 m .52617 .34489 L .52616 .34484 L F
.52613 .34488 m .52626 .34491 L .52625 .34489 L F
.52622 .34484 m .52619 .34482 L .52625 .3448 L F
.52625 .3448 m .52619 .34482 L .52617 .34482 L F
.52624 .34475 m .52621 .34489 L .52613 .34488 L F
.52692 .34449 m .52692 .34448 L .52717 .34432 L F
.52692 .34444 m .5259 .34506 L .52692 .34444 L F
.5261 .34484 m .52722 .34444 L .52696 .34442 L F
.52617 .34482 m .52615 .34481 L .52617 .34482 L F
.52615 .34481 m .52615 .34481 L .52617 .34482 L F
.52615 .34485 m .52613 .34488 L .52614 .34485 L F
.52624 .34475 m .52613 .34488 L .52616 .3448 L F
.52615 .34481 m .52611 .34479 L .52615 .34481 L F
.52615 .34485 m .52611 .34479 L .52617 .34482 L F
.52613 .34488 m .52625 .34489 L .5261 .34456 L F
.52617 .34489 m .52619 .34496 L .52621 .3449 L F
.52621 .3449 m .52619 .34496 L .52634 .34493 L F
.52621 .34489 m .52619 .34496 L .52613 .34488 L F
.52645 .34496 m .52639 .3452 L .52649 .34497 L F
.52612 .3454 m .52568 .34463 L .52612 .3454 L F
.52622 .34499 m .52697 .34502 L .52619 .34496 L F
.5259 .34519 m .52606 .34509 L .52589 .34524 L F
.52626 .34491 m .52645 .34496 L .52646 .34491 L F
.52696 .3455 m .52687 .34543 L .52706 .34514 L F
.52606 .34509 m .52686 .34454 L .52604 .34514 L F
.52759 .34468 m .52845 .34437 L .52849 .34438 L F
.52631 .3451 m .52757 .34467 L .52759 .34468 L F
.52757 .34467 m .52845 .34437 L .52759 .34468 L F
.52615 .3444 m .52509 .34359 L .5261 .34456 L F
.52541 .34398 m .52538 .34322 L .52483 .34262 L F
.52582 .34468 m .52568 .34463 L .52509 .34359 L F
.52552 .34462 m .52563 .3444 L .52555 .34415 L F
.52541 .34395 m .52571 .34394 L .52538 .34322 L F
.52611 .34479 m .52582 .34468 L .52531 .34364 L F
.52615 .3444 m .5251 .34359 L .52509 .34359 L F
.52538 .34394 m .52555 .34415 L .5252 .34306 L F
.52568 .34463 m .52564 .34461 L .52509 .34359 L F
.52568 .34463 m .52568 .34463 L .52509 .34359 L F
.52554 .34422 m .52528 .34382 L .52561 .34423 L F
.52409 .34115 m .52513 .34328 L .52506 .3435 L F
.52522 .34373 m .52522 .34374 L .52486 .34329 L F
.52515 .34331 m .52558 .34419 L .52509 .34359 L F
.52506 .3435 m .52509 .34359 L .5252 .34306 L F
.52509 .34359 m .52507 .34359 L .52564 .34429 L F
.52509 .34359 m .52604 .34477 L .5261 .34456 L F
.52571 .34421 m .52554 .34414 L .52576 .3441 L F
.52564 .34461 m .5256 .3446 L .52509 .34359 L F
.52509 .34359 m .52552 .34462 L .52538 .34394 L F
.52509 .34359 m .52564 .34429 L .52566 .34429 L F
.52554 .34414 m .52463 .34376 L .52543 .344 L F
.52554 .34414 m .52543 .344 L .52576 .3441 L F
.52509 .34359 m .52538 .34394 L .52529 .34352 L F
.52559 .34379 m .52531 .34364 L .52409 .34115 L F
.52526 .34353 m .52529 .34352 L .52521 .34313 L F
.52526 .34353 m .52521 .34313 L .5252 .34306 L F
.52509 .34359 m .52526 .34353 L .5252 .34306 L F
.52528 .34382 m .51435 .33532 L .52458 .34295 L F
.52509 .34359 m .52501 .34352 L .52507 .34359 L F
.52566 .34429 m .52564 .34429 L .52639 .3452 L F
.52684 .34504 m .52697 .34502 L .52679 .34501 L F
.52679 .34506 m .52691 .34502 L .52682 .34507 L F
.52673 .34504 m .52681 .34501 L .52678 .34506 L F
.5266 .34498 m .52681 .34501 L .5269 .34508 L F
.52675 .34503 m .52669 .34501 L .52622 .34499 L F
.52687 .34495 m .52666 .34493 L .52675 .34503 L F
.52698 .34508 m .52675 .34503 L .52692 .34521 L F
.5267 .34508 m .52685 .34505 L .52685 .34505 L F
.52591 .345 m .52598 .34509 L .52606 .34498 L F
.52583 .34471 m .52604 .34513 L .52571 .34468 L F
.52323 .34545 m .52324 .34546 L .52606 .34498 L F
.52538 .34394 m .52542 .34408 L .52509 .34359 L F
.52558 .34419 m .52542 .34408 L .52538 .34394 L F
.52558 .34419 m .52582 .34468 L .52542 .34408 L F
.52552 .34462 m .52555 .34415 L .52538 .34394 L F
.52501 .34352 m .52514 .34369 L .52515 .3437 L F
.52501 .34352 m .52504 .34372 L .52515 .34371 L F
.52504 .34372 m .52511 .34415 L .52515 .34371 L F
.52576 .3441 m .52463 .34376 L .525 .34352 L F
.52646 .34491 m .52645 .34496 L .52649 .34497 L F
.52615 .34491 m .52609 .34483 L .5261 .34498 L F
.52607 .34509 m .526 .34469 L .52593 .34468 L F
.52582 .34468 m .52583 .34471 L .52568 .34463 L F
.5259 .3452 m .52556 .34434 L .52556 .34435 L F
.52596 .34512 m .52564 .34461 L .52568 .34463 L F
.52595 .34514 m .52564 .34461 L .52596 .34512 L F
.52598 .34529 m .52597 .34533 L .5256 .3446 L F
.52551 .34427 m .52554 .34428 L .52574 .34439 L F
.52575 .3444 m .52574 .34439 L .52599 .34453 L F
.52568 .34457 m .52569 .34433 L .52562 .34437 L F
.52551 .34427 m .52574 .34439 L .52575 .3444 L F
.52554 .34428 m .52463 .34376 L .52554 .34414 L F
.52567 .3443 m .52554 .34414 L .52614 .3444 L F
.52562 .34437 m .52528 .34279 L .5252 .34306 L F
.52554 .34428 m .52554 .34414 L .52567 .3443 L F
.52614 .3444 m .52577 .34424 L .52576 .3441 L F
.52589 .34459 m .52587 .34401 L .52576 .34418 L F
.52593 .34468 m .52592 .34462 L .52589 .34459 L F
.52569 .34433 m .52567 .3443 L .52562 .34437 L F
.52724 .34459 m .52609 .34483 L .5274 .34463 L F
.52686 .34454 m .52686 .34455 L .52604 .34514 L F
.52693 .34503 m .52684 .34493 L .52691 .34503 L F
.52693 .34503 m .52691 .34503 L .52729 .34558 L F
.52754 .34569 m .52693 .34503 L .52729 .34558 L F
.52709 .34501 m .52683 .34505 L .52684 .34505 L F
.52687 .34503 m .52692 .34502 L .52692 .34502 L F
.52692 .34502 m .52698 .345 L .52692 .34502 L F
.52692 .34502 m .52698 .345 L .52697 .34501 L F
.52705 .34504 m .52693 .34507 L p .52697 .34503 L F P
0 g
s
.52701 .34506 m .52687 .34495 L .52698 .34508 L .672 .728 .891 r
F
.52615 .3444 m .5261 .34456 L .52653 .34498 L F
.52614 .3444 m .5261 .34456 L .52615 .3444 L F
.52686 .34454 m .5269 .34452 L .52686 .34455 L F
.52631 .3451 m .52684 .34504 L .52622 .34499 L F
.52654 .3449 m .52685 .34477 L .52652 .3449 L F
.52638 .34494 m .52637 .34494 L .52905 .34421 L F
.52655 .34489 m .52656 .3449 L .52657 .34489 L F
.5291 .34408 m .52909 .34408 L .52931 .344 L F
.53031 .34374 m .52888 .34422 L .52931 .344 L F
.53031 .34374 m .52725 .34454 L .53255 .3436 L F
.52691 .34486 m .52691 .3448 L .52865 .34379 L F
.52868 .3438 m .52865 .34379 L .5308 .34255 L F
.52691 .34486 m .52865 .34379 L .52868 .3438 L F
.52781 .34472 m .52761 .34468 L .52851 .34438 L F
.52724 .34459 m .5274 .34463 L .52979 .34425 L F
.53385 .34319 m .52869 .3445 L .52905 .34421 L F
.52724 .34459 m .52979 .34425 L .52981 .34424 L F
.52724 .34459 m .53012 .34419 L .53001 .34416 L F
.52655 .34489 m .52657 .34489 L .52766 .34471 L F
.52652 .3449 m .52685 .34477 L .52638 .34486 L F
.52654 .3449 m .52689 .34476 L .52685 .34477 L F
.52905 .34421 m .52644 .34492 L .52635 .34489 L F
.5263 .34482 m .52655 .34489 L .52766 .34471 L F
.52713 .34445 m .52709 .34447 L .52718 .34441 L F
.5267 .34479 m .52667 .34479 L .52974 .34306 L F
.52634 .34514 m .52709 .34447 L .52713 .34445 L F
.52659 .34499 m .52697 .34502 L .52634 .34493 L F
.52661 .34492 m .52653 .34498 L .52668 .34501 L F
.52693 .34443 m .52692 .34444 L .52692 .34444 L F
.52704 .34431 m .52597 .3449 L .52701 .3444 L F
.52686 .34441 m .52648 .34478 L .52624 .34475 L F
.52704 .34431 m .52701 .3444 L .54138 .3374 L F
.52717 .34432 m .52692 .34446 L .52693 .34443 L F
.52872 .34337 m .52686 .34454 L .52686 .34441 L F
.52686 .34454 m .52648 .34478 L .52686 .34441 L F
.52623 .34439 m .52614 .34432 L .52621 .34439 L F
.52669 .3448 m .52599 .34431 L .52619 .34436 L F
.52615 .3444 m .52614 .3444 L .52615 .3444 L F
.52737 .34463 m .52612 .34495 L .5272 .3446 L F
.52609 .34483 m .52775 .34469 L .5274 .34463 L F
.52659 .34492 m .52652 .34492 L .52709 .34447 L F
.52614 .3444 m .525 .34352 L .52615 .3444 L F
.51951 .34184 m .5187 .34145 L p .52044 .342 L F P
0 g
s
.5187 .34145 m .51105 .33772 L p .52044 .342 L .672 .728 .891 r
F P
0 g
s
.52587 .34408 m .52579 .34415 L .52559 .34379 L .672 .728 .891 r
F
.52557 .34429 m .52554 .34428 L .52567 .3443 L F
.52391 .34345 m .52416 .3435 L .52515 .34403 L F
.52569 .34541 m .52642 .34491 L .52643 .34491 L F
.52557 .34548 m .52568 .34541 L .52569 .34541 L F
.52568 .34541 m .52642 .34491 L .52569 .34541 L F
.52677 .34548 m .52639 .3452 L p .52685 .34547 L F P
0 g
s
.52629 .3451 m .52631 .3451 L .5262 .34505 L .672 .728 .891 r
F
.52686 .3446 m .5269 .34452 L .52713 .34443 L F
.52609 .34483 m .52766 .34471 L .52769 .3447 L F
.52589 .34524 m .52686 .34455 L .52686 .3446 L F
.52686 .34455 m .5269 .34452 L .52686 .3446 L F
.52631 .3451 m .52622 .34499 L .52606 .34498 L F
.52557 .34548 m .5264 .34491 L .52642 .34491 L F
.52595 .34515 m .52629 .3451 L .52606 .34498 L F
.52585 .34524 m .52614 .34494 L .52617 .34493 L F
.52673 .345 m .52672 .345 L .52749 .3448 L F
.52631 .3451 m .52749 .3448 L .52749 .3448 L F
.52672 .345 m .52672 .345 L .52775 .34474 L F
.52689 .34501 m .52692 .34494 L .52691 .34494 L F
.52749 .34482 m .52587 .34523 L .52775 .34474 L F
.52656 .3449 m .5269 .345 L .52732 .34484 L F
.52687 .34495 m .52682 .34492 L .52682 .34494 L F
.52687 .34495 m .52682 .34492 L .52687 .34495 L F
.52682 .34492 m .52615 .3444 L .52682 .34494 L F
.52926 .34344 m .52924 .34341 L .5308 .34255 L F
.53001 .34299 m .5276 .34433 L .52974 .34306 L F
.5276 .34433 m .52753 .34432 L .52974 .34306 L F
.52974 .34306 m .5275 .34432 L .52717 .34432 L F
.54088 .33764 m .5308 .34255 L .53514 .34109 L F
.5308 .34255 m .53001 .34299 L .52974 .34306 L F
.54138 .3374 m .53228 .34213 L p .5308 .34255 L F P
0 g
s
.52696 .34442 m .52722 .34444 L .54138 .3374 L .672 .728 .891 r
F
.52666 .34494 m .52861 .34378 L .52865 .34379 L F
.5276 .34433 m .5272 .34454 L .52753 .34432 L F
.52753 .34432 m .52628 .34506 L .52753 .34432 L F
.52696 .34458 m .52689 .34476 L .53104 .34266 L F
.52689 .34476 m .52894 .34387 L .52807 .34417 L F
.52854 .34392 m .52686 .34492 L p .52853 .34389 L F P
0 g
s
.52684 .34504 m .52679 .34501 L .52669 .34501 L .672 .728 .891 r
F
.52875 .34677 m .5269 .3453 L .52787 .34583 L F
.52666 .34493 m .52729 .34571 L .52743 .34574 L F
.52743 .34574 m .52743 .34574 L .52744 .34574 L F
.52666 .34493 m .52743 .34574 L .52743 .34574 L F
.52711 .34533 m .52684 .34509 L .52729 .34558 L F
.52787 .34583 m .52762 .34561 L .52754 .34569 L F
.5269 .3453 m .5269 .34508 L .52787 .34583 L F
.52699 .34509 m .52692 .34521 L .52763 .34594 L F
.52766 .3459 m .52763 .34594 L .52811 .34645 L F
.52699 .34509 m .52763 .34594 L .52766 .3459 L F
.52615 .3444 m .52649 .34491 L .52661 .34492 L F
.52616 .34484 m .52617 .34489 L .52656 .3449 L F
.52648 .34478 m .52619 .34496 L .52624 .34475 L F
.52615 .3444 m .52661 .34492 L .52666 .34493 L F
.52619 .34496 m .52659 .34499 L .52634 .34493 L F
.5263 .34509 m .52625 .34503 L .52686 .34462 L F
.52686 .34465 m .52686 .34462 L .52718 .34441 L F
.5263 .34509 m .52686 .34462 L .52686 .34465 L F
.52699 .34509 m .52698 .34508 L .52699 .34509 L F
.52685 .34505 m .52699 .34503 L .52685 .34505 L F
.52701 .34506 m .52699 .34509 L .52811 .34645 L F
.52706 .34514 m .52687 .34503 L .52707 .34511 L F
.52684 .34504 m .52669 .34501 L .52675 .34503 L F
.52669 .34508 m .52708 .34507 L .52709 .34501 L F
.52687 .34495 m .52675 .34503 L .52698 .34508 L F
.52637 .34518 m .52688 .34482 L .52696 .34483 L F
.52639 .3452 m .52708 .34507 L p .52669 .34508 L F P
0 g
s
.52701 .34506 m .52698 .34508 L .52699 .34509 L .672 .728 .891 r
F
.52687 .34503 m .52687 .345 L .52697 .34505 L F
.52643 .34518 m .52662 .34512 L .52697 .34505 L F
.52727 .34526 m .52687 .34495 L .52687 .34495 L F
.52708 .34507 m .53673 .34325 L p .52709 .34501 L F P
0 g
s
.53673 .34325 m .53879 .34286 L p .53672 .34324 L .672 .728 .891 r
F P
0 g
s
.52709 .34501 m .53673 .34325 L .53672 .34324 L .672 .728 .891 r
F
.52702 .34506 m .52697 .34505 L .52846 .34476 L F
.52643 .34518 m .52697 .34505 L .52702 .34506 L F
.52606 .34509 m .52604 .34514 L .52589 .34524 L F
.52676 .34585 m .52617 .34547 L .52634 .34549 L F
.52676 .34585 m .526 .34519 L .52601 .34517 L F
.52644 .34568 m .52639 .3452 L .52609 .34557 L F
.52604 .34513 m .5265 .34606 L .52601 .34521 L F
.52602 .3452 m .52602 .34518 L .52608 .34514 L F
.52602 .3452 m .52608 .34514 L .52625 .34503 L F
.52619 .34552 m .52596 .34512 L .52596 .34512 L F
.52597 .34535 m .52602 .3452 L .52625 .34503 L F
.52596 .34512 m .52596 .34512 L .52601 .34521 L F
.52557 .34548 m .52548 .34551 L .52603 .34515 L F
.52603 .34517 m .52603 .34515 L .5264 .34491 L F
.52557 .34548 m .52603 .34515 L .52603 .34517 L F
.52604 .34555 m .5259 .3452 L .52604 .34555 L F
.52604 .34555 m .52609 .34557 L .52596 .34527 L F
.52636 .34638 m .52604 .34555 L .52604 .34555 L F
.52636 .34638 m .52656 .34668 L .52609 .34557 L F
.52636 .34638 m .52609 .34557 L .52604 .34555 L F
.52636 .34638 m .52604 .34555 L .52601 .34554 L F
.52588 .3454 m .52636 .34638 L .52592 .34534 L F
.52598 .34535 m .52669 .34676 L .52592 .34548 L F
.52452 .3461 m .52639 .3452 L .52423 .34612 L F
.52583 .34551 m .52636 .34516 L .52637 .34518 L F
.52598 .34543 m .52598 .34542 L .52588 .34547 L F
.52598 .34535 m .52592 .34548 L .52596 .34535 L F
.52592 .34548 m .52592 .34548 L .52592 .34548 L F
.52592 .34548 m .52592 .34548 L .52596 .34535 L F
.52493 .34594 m .5249 .34602 L .52583 .34547 L F
.52591 .34551 m .52588 .3454 L .52587 .34542 L F
.52587 .34543 m .52591 .34551 L .52587 .34542 L F
.52583 .34551 m .52585 .34544 L .52688 .34482 L F
.52595 .34538 m .52585 .34544 L .52596 .34535 L F
.5259 .3452 m .5259 .3452 L .52604 .34555 L F
.52604 .34555 m .5259 .3452 L .5259 .3452 L F
.52585 .34544 m .52602 .34518 L .52596 .34535 L F
.52596 .34535 m .52592 .34548 L .5258 .34529 L F
.52591 .34551 m .52636 .34638 L .52594 .34552 L F
.52587 .34547 m .52669 .34676 L .52636 .34665 L F
.5258 .34529 m .52591 .34548 L .52587 .34547 L F
.52591 .34548 m .52669 .34676 L .52587 .34547 L F
.52596 .34535 m .52596 .34535 L .52597 .34535 L F
.52596 .34535 m .52602 .3452 L .52597 .34535 L F
.52593 .34515 m .52605 .34503 L .52593 .34468 L F
.52612 .34514 m .52601 .3452 L .52634 .34514 L F
.52596 .34512 m .52597 .34514 L .52597 .34514 L F
.52597 .34514 m .52601 .34521 L .52597 .34514 L F
.52597 .34514 m .52601 .34521 L .52601 .34521 L F
.52604 .34513 m .52601 .34521 L .52571 .34468 L F
.52595 .34515 m .52601 .3452 L .52612 .34514 L F
.52609 .34539 m .52593 .34516 L .52595 .34514 L F
.52595 .34515 m .5259 .34522 L .52601 .3452 L F
.52626 .34504 m .52654 .34492 L .52647 .34492 L F
.52627 .34505 m .52654 .34492 L .52626 .34504 L F
.52687 .34503 m .52666 .34492 L .52687 .345 L F
.52666 .34492 m .52599 .34453 L .52671 .34492 L F
.52631 .3451 m .52634 .34514 L .52697 .34502 L F
.52661 .34492 m .52729 .34571 L .52666 .34493 L F
.52638 .34519 m .52686 .34489 L .52686 .34489 L F
.52638 .34519 m .52686 .34489 L .52638 .34519 L F
.52884 .34425 m .52737 .34463 L .5272 .3446 L F
.52686 .34492 m .52686 .34491 L .52853 .34389 L F
.52771 .34484 m .52864 .34453 L .52854 .34462 L F
.52766 .34481 m .52864 .34453 L .52771 .34484 L F
.52749 .3448 m .52749 .3448 L .52775 .34474 L F
.52656 .3449 m .52836 .34476 L .52836 .34465 L F
.52686 .34489 m .52686 .34489 L .52696 .34483 L F
.52684 .34505 m .52683 .34505 L .52566 .34526 L F
.52589 .34523 m .52669 .34508 L .5267 .34508 L F
.52585 .34552 m .52696 .34483 L .52698 .34483 L F
.52638 .34519 m .52771 .34442 L .52635 .34516 L F
.52771 .34442 m .52786 .34432 L .5277 .34442 L F
.52696 .34458 m .53104 .34266 L .53088 .3427 L F
.52865 .34379 m .52924 .34341 L .52926 .34344 L F
.52861 .34378 m .52924 .34341 L .52865 .34379 L F
.52696 .34458 m .53219 .34207 L .53183 .34215 L F
.52849 .34438 m .52845 .34437 L .52884 .34427 L F
.52884 .34428 m .52884 .34427 L .52905 .34421 L F
.52877 .34444 m .52851 .34438 L .52905 .34421 L F
.52905 .34421 m .52884 .34426 L .52884 .34425 L F
.52884 .34426 m .52737 .34463 L .52884 .34425 L F
.52968 .34407 m .52724 .34459 L .53001 .34416 L F
.54138 .3374 m .54061 .33676 L p .52704 .34431 L F P
0 g
s
.52698 .34483 m .52696 .34483 L .53176 .34192 L .672 .728 .891 r
F
.53176 .34192 m .53176 .34192 L .5332 .34104 L F
.52698 .34483 m .53176 .34192 L .53176 .34192 L F
.52703 .34502 m .53093 .34426 L .52703 .34502 L F
.52836 .34465 m .52836 .34476 L .53066 .34434 L F
.52862 .34471 m .53093 .34426 L .52862 .34471 L F
.52862 .34471 m .52862 .34471 L .52691 .34504 L F
.52709 .34501 m .54014 .34261 L .5271 .345 L F
.52691 .34504 m .52862 .34471 L .52691 .34504 L F
.5271 .345 m .54014 .34261 L .5271 .345 L F
.52834 .34483 m .52834 .34482 L .53131 .34426 L F
.52702 .34504 m .52703 .34502 L .53092 .34427 L F
.52941 .34463 m .52836 .34483 L p .52943 .34462 L F P
0 g
s
.52836 .34483 m .52639 .3452 L p .52835 .34483 L .672 .728 .891 r
F P
0 g
s
.52836 .34483 m .52835 .34483 L .52943 .34462 L .672 .728 .891 r
F
.52376 .34342 m .52378 .34343 L .52522 .34427 L F
.52771 .34442 m .5277 .34442 L .52635 .34516 L F
.52612 .3454 m .52611 .3454 L .52596 .34512 L F
.52608 .34538 m .52593 .34516 L .52609 .34539 L F
.52596 .34512 m .52612 .3454 L .52612 .3454 L F
.52606 .34531 m .52601 .34533 L .5263 .34509 L F
.52595 .34538 m .52596 .34535 L .5263 .34509 L F
.5259 .34521 m .52597 .34533 L .52584 .3453 L F
.52517 .34535 m .52452 .34585 L .52388 .34607 L F
.52467 .34551 m .52584 .3453 L .52462 .34548 L F
.5265 .34609 m .52595 .34514 L .52596 .34512 L F
.52655 .34617 m .5265 .34609 L .5265 .34609 L F
.5265 .34609 m .52595 .34514 L .5265 .34609 L F
.52633 .34513 m .52635 .34516 L .52677 .34492 L F
.52636 .34516 m .52688 .34482 L .52637 .34518 L F
.52635 .34515 m .52639 .3452 L .52669 .34508 L F
.52581 .34528 m .52676 .34507 L .52662 .34512 L F
.52569 .34427 m .52528 .34279 L .52562 .34437 L F
.52483 .34262 m .52538 .34322 L .52071 .33298 L F
.52578 .3439 m .52559 .34379 L .52409 .34115 L F
.52502 .34279 m .52585 .34375 L .52538 .34394 L F
.52576 .34418 m .52539 .34245 L .52528 .34279 L F
.52587 .34401 m .52539 .34245 L .52576 .34418 L F
.52534 .34269 m .52588 .34379 L .52502 .34279 L F
.52593 .34393 m .52539 .34245 L p .52587 .34401 L F P
0 g
s
.52441 .34094 m .52364 .33928 L p .52438 .34095 L .672 .728 .891 r
F P
0 g
s
.52364 .33928 m .52071 .33298 L p .52356 .33922 L .672 .728 .891 r
F P
0 g
s
.52071 .33298 m .52482 .34183 L p .52409 .34115 L .672 .728 .891 r
F P
0 g
s
.5252 .34306 m .52528 .34279 L .52188 .33276 L .672 .728 .891 r
F
.52482 .34183 m .52578 .3439 L p .52409 .34115 L F P
0 g
s
.52506 .3435 m .5252 .34306 L .52188 .33276 L .672 .728 .891 r
F
.5247 .34054 m .52588 .34379 L p .52436 .34069 L F P
0 g
s
.52436 .34069 m .52534 .34269 L .52502 .34279 L .672 .728 .891 r
F
.52588 .34379 m .52593 .34393 L p .52584 .34389 L F P
0 g
s
.526 .34374 m .52307 .33259 L p .52579 .34419 L .672 .728 .891 r
F P
0 g
s
.52541 .34338 m .52544 .34315 L .52539 .34327 L .672 .728 .891 r
F
.52574 .34439 m .52573 .34438 L .52599 .34452 L F
.52551 .34427 m .52599 .34454 L .52599 .34454 L F
.52577 .34424 m .52571 .34421 L .52572 .34419 L F
.52577 .34424 m .52572 .34419 L .52576 .3441 L F
.52551 .34427 m .52599 .34453 L .52599 .34454 L F
.52557 .34429 m .52567 .3443 L .52614 .3444 L F
.52577 .34461 m .52571 .34436 L .52568 .34457 L F
.52599 .34451 m .52572 .34437 L .526 .34437 L F
.52572 .34437 m .52557 .34429 L .52568 .34431 L F
.52572 .34437 m .52568 .34431 L .526 .34437 L F
.526 .34469 m .52587 .34401 L .52592 .34462 L F
.52598 .34469 m .52592 .34462 L .52593 .34468 L F
.52649 .34491 m .52653 .34498 L .52661 .34492 L F
.52634 .34514 m .52652 .34492 L .52659 .34492 L F
.52665 .34492 m .52657 .34492 L .52628 .34507 L F
.52606 .34509 m .52608 .34503 L .5269 .34452 L F
.5261 .34456 m .52625 .34489 L .52646 .34491 L F
.52682 .34494 m .52681 .34494 L .52686 .34491 L F
.52687 .34495 m .52672 .34492 L .52682 .34492 L F
.52869 .3445 m .52781 .34472 L .52851 .34438 L F
.52869 .3445 m .52851 .34438 L .52877 .34444 L F
.52656 .3449 m .53066 .34434 L .53034 .34425 L F
.5274 .34463 m .52775 .34469 L .53034 .34425 L F
.5295 .34454 m .52689 .34504 L .5287 .3444 L F
.52689 .34504 m .5268 .34506 L .52687 .34503 L F
.52687 .34503 m .52687 .34504 L .52687 .34503 L F
.52687 .34503 m .52687 .34503 L .52687 .34503 L F
.52689 .34504 m .52687 .34503 L .5287 .3444 L F
.5269 .34502 m .52701 .34494 L .52698 .345 L F
.5269 .345 m .52697 .34502 L .52732 .34484 L F
.52701 .34506 m .52687 .345 L .52687 .34495 L F
.52841 .34481 m .52834 .34482 L .52846 .34476 L F
.52834 .34482 m .52643 .34518 L .52823 .34481 L F
.52834 .34482 m .52823 .34481 L .52846 .34476 L F
.52639 .3452 m .5277 .34439 L .52771 .3444 L F
.52634 .34514 m .5263 .34509 L .52652 .34492 L F
.52596 .3453 m .52667 .34492 L .52665 .34492 L F
.52593 .34516 m .5256 .3446 L .52564 .34461 L F
.52547 .34449 m .5259 .34521 L .5258 .34529 L F
.524 .34558 m .52585 .34529 L .52589 .34523 L F
.52298 .34716 m .5259 .34519 L .52589 .34524 L F
.5259 .34521 m .52584 .3453 L .5258 .34529 L F
.52707 .34511 m .52697 .34505 L .52701 .34506 L F
.52697 .34505 m .52687 .345 L .52701 .34506 L F
.52687 .345 m .52672 .34492 L .52687 .34495 L F
.52571 .34436 m .52569 .34427 L .52569 .34433 L F
.52571 .34436 m .52569 .34433 L .52568 .34457 L F
.52505 .34418 m .52551 .34427 L .52575 .34441 L F
.52587 .34456 m .52575 .34441 L .52666 .34492 L F
.52505 .34418 m .52575 .34441 L .52587 .34456 L F
.52572 .34436 m .52586 .34454 L .52568 .34424 L F
.52586 .34454 m .52589 .34459 L .52568 .34424 L F
.52568 .34424 m .52589 .34459 L .52528 .34279 L F
.52547 .3433 m .52544 .34315 L .52541 .34338 L F
.52539 .34327 m .52507 .34113 L .52498 .34141 L F
.52544 .34315 m .52507 .34113 L .52539 .34327 L F
.52547 .34329 m .52555 .34317 L .52507 .34113 L F
.52547 .3433 m .52547 .34329 L .52507 .34113 L F
.52498 .34141 m .52507 .34113 L .52307 .33259 L F
.52307 .33259 m .52606 .34395 L p .52544 .34364 L F P
0 g
s
.52592 .34548 m .52591 .34548 L .5258 .34529 L .672 .728 .891 r
F
.52498 .34585 m .52609 .34532 L .5256 .34551 L F
.52073 .34822 m .52493 .34594 L .52498 .34585 L F
.52493 .34594 m .52609 .34532 L .52498 .34585 L F
.52592 .34538 m .52595 .34539 L .52593 .34536 L F
.52596 .34531 m .52598 .34535 L .52598 .34529 L F
.52593 .34537 m .52598 .34535 L .52596 .34531 L F
.50755 .3454 m .50756 .34458 L p .51971 .34472 L F P
0 g
s
.52545 .34517 m .52595 .34515 L .52598 .34509 L .672 .728 .891 r
F
.52285 .34552 m .52552 .3452 L .52545 .34517 L F
.52552 .3452 m .52595 .34515 L .52545 .34517 L F
.52605 .34558 m .52601 .34542 L .526 .34556 L F
.5259 .34542 m .5259 .34543 L .52609 .34532 L F
.52585 .34492 m .52585 .34493 L .52568 .34463 L F
.52596 .34512 m .52585 .34493 L .52585 .34492 L F
.52596 .34512 m .52596 .34512 L .52585 .34493 L F
.52596 .34512 m .52568 .34463 L .52596 .34512 L F
.5256 .34543 m .526 .34522 L .52557 .34543 L F
.52585 .34529 m .52639 .3452 L .52589 .34523 L F
.52582 .3453 m .52579 .34529 L .52662 .34512 L F
.52597 .34528 m .52593 .34515 L .52595 .34533 L F
.52593 .34515 m .52569 .34427 L .52591 .34518 L F
.52566 .34526 m .5271 .345 L .5271 .345 L F
.52639 .3452 m .52638 .34519 L .52686 .3449 L F
.52639 .3452 m .52686 .3449 L .52686 .34491 L F
.52595 .34515 m .52634 .34514 L .52631 .3451 L F
.52629 .3451 m .5262 .34505 L .52606 .34498 L F
.52585 .34524 m .52622 .345 L .52631 .3451 L F
.526 .34522 m .52657 .34492 L .52602 .3452 L F
.52767 .34421 m .52634 .34514 L .52718 .34441 L F
.52831 .34396 m .52769 .34433 L .52767 .34421 L F
.52769 .34433 m .52634 .34514 L .52767 .34421 L F
.52616 .34491 m .52626 .34504 L .52647 .34492 L F
.52622 .345 m .5264 .34488 L .52631 .3451 L F
.52602 .3452 m .52654 .34492 L .52603 .34517 L F
.52595 .34488 m .52687 .34545 L .52687 .34548 L F
.52593 .34515 m .52593 .34468 L .5259 .34468 L F
.52589 .34484 m .52595 .34488 L .52595 .34488 L F
.52657 .34492 m .52655 .34492 L .52602 .3452 L F
.52616 .34491 m .5259 .34459 L .52658 .34492 L F
.5262 .34496 m .52621 .34472 L .52613 .34471 L F
.52653 .34628 m .52592 .34518 L .52593 .34516 L F
.52578 .34532 m .52639 .3452 L p .52577 .34531 L F P
0 g
s
.52608 .34526 m .52584 .3453 L p .5261 .34525 L .672 .728 .891 r
F P
0 g
s
.52584 .3453 m .52639 .3452 L .52585 .34529 L .672 .728 .891 r
F
.52608 .34526 m .5261 .34525 L .52638 .34519 L F
.52639 .3452 m .52608 .34526 L p .52638 .34519 L F P
0 g
s
.52598 .34529 m .52609 .34532 L .52635 .34516 L .672 .728 .891 r
F
.52643 .34518 m .52582 .3453 L .52662 .34512 L F
.52636 .34558 m .52627 .34505 L .5262 .34496 L F
.52642 .34491 m .52698 .34452 L .52643 .34491 L F
.52642 .34491 m .5264 .34491 L .52698 .34452 L F
.52616 .34491 m .52647 .34492 L .52687 .34468 L F
.52696 .34483 m .52688 .34482 L .5363 .33916 L F
.52667 .34492 m .52677 .34492 L .52803 .34417 L F
.52863 .34441 m .52617 .34493 L .52616 .34491 L F
.52623 .34477 m .52621 .34472 L p .52622 .34479 L F P
0 g
s
.52657 .34492 m .52751 .34441 L .52655 .34492 L .672 .728 .891 r
F
.52667 .34492 m .52803 .34417 L .52665 .34492 L F
.52698 .34483 m .5332 .34104 L .5332 .34104 L F
.52698 .34483 m .53531 .33976 L .53531 .33976 L F
.52682 .34494 m .52615 .3444 L .52666 .34493 L F
.52615 .3444 m .52615 .3444 L .52615 .3444 L F
.52615 .3444 m .52615 .3444 L .52666 .34493 L F
.52622 .345 m .52617 .34493 L .5264 .34488 L F
.52682 .34494 m .52639 .3452 L p .52681 .34494 L F P
0 g
s
.52589 .34523 m .52669 .34508 L .52589 .34523 L .672 .728 .891 r
F
.52589 .34523 m .52634 .34514 L .52589 .34522 L F
.52634 .34514 m .52709 .34501 L .52634 .34514 L F
.52634 .34514 m .52634 .34514 L .52566 .34526 L F
.5268 .34506 m .52585 .34524 L .52666 .345 L F
.52635 .34515 m .5268 .34506 L .52679 .34506 L F
.52682 .34493 m .52682 .34493 L .52638 .34519 L F
.52638 .34519 m .52638 .34519 L .52577 .34554 L F
.52682 .34493 m .52638 .34519 L .52638 .34519 L F
.52634 .34515 m .5268 .34506 L .52635 .34515 L F
.52598 .34529 m .52677 .34492 L .52667 .34492 L F
.52678 .34506 m .52681 .34506 L .52678 .34506 L F
.52662 .34512 m .52693 .34505 L .52697 .34505 L F
.52649 .34501 m .52665 .34492 L .52644 .34501 L F
.52649 .34501 m .52644 .34501 L .52628 .34507 L F
.52631 .34511 m .52649 .34501 L .52628 .34507 L F
.52681 .34506 m .52681 .34506 L .52573 .34527 L F
.52687 .34503 m .52697 .34505 L .52688 .34504 L F
.52669 .34508 m .52699 .34503 L .5267 .34508 L F
.52703 .34502 m .52703 .34502 L .52573 .34527 L F
.52635 .34515 m .52635 .34515 L .52676 .34507 L F
.52676 .34507 m .52676 .34507 L .52703 .34502 L F
.52582 .34525 m .52676 .34507 L .52676 .34507 L F
.52573 .34527 m .52703 .34502 L .52703 .34502 L F
.52635 .34515 m .52691 .34504 L .52691 .34504 L F
.52573 .34527 m .52635 .34515 L .52635 .34515 L F
.52635 .34515 m .52691 .34504 L .52635 .34515 L F
.52495 .34416 m .52518 .34427 L .52518 .34431 L F
.52609 .34483 m .52605 .34478 L .5261 .34498 L F
.52617 .34493 m .52595 .34488 L .52616 .34491 L F
.52602 .34485 m .52323 .34544 L .52613 .34488 L F
.52323 .34544 m .52285 .34552 L .52323 .34545 L F
.52323 .34544 m .52323 .34545 L .52613 .34488 L F
.52616 .34492 m .52615 .34491 L .5261 .34498 L F
.52495 .34416 m .52621 .34498 L .52626 .34505 L F
.52966 .35765 m .52848 .35777 L p .52624 .34737 L F P
0 g
s
.52616 .34491 m .52658 .34492 L .52681 .34503 L .672 .728 .891 r
F
.52631 .3451 m .5264 .34488 L .52667 .345 L F
.52621 .34498 m .52616 .34492 L .52687 .34505 L F
.5261 .34473 m .52593 .34393 L .52587 .34401 L F
.52597 .34533 m .52596 .34535 L .5258 .34529 L F
.52582 .34533 m .52592 .34538 L .52587 .34522 L F
.52581 .34528 m .52587 .34522 L .5257 .34465 L F
.5245 .34556 m .52578 .34532 L p .52451 .34554 L F P
0 g
s
.52448 .34555 m .52445 .34555 L .52472 .3455 L .672 .728 .891 r
F
.52584 .3453 m .52585 .34529 L .52462 .34548 L F
.5247 .34551 m .52472 .3455 L .52662 .34512 L F
.52448 .34555 m .52472 .3455 L .5247 .34551 L F
.52572 .34434 m .52562 .34346 L .52559 .34343 L F
.52599 .34454 m .52687 .34503 L .52687 .34503 L F
.52686 .34492 m .52682 .34494 L p .52686 .34491 L F P
0 g
s
.52639 .3452 m .52771 .34442 L p .52638 .34519 L .672 .728 .891 r
F P
0 g
s
.52686 .34491 m .52686 .3449 L .5277 .34439 L .672 .728 .891 r
F
.52666 .34492 m .52671 .34492 L .52687 .345 L F
.52682 .34492 m .52686 .34494 L .52686 .34494 L F
.52682 .34493 m .52786 .34432 L .52682 .34493 L F
.52682 .34492 m .52682 .34492 L .52686 .34494 L F
.52687 .34495 m .52682 .34492 L .52682 .34492 L F
.52667 .345 m .5264 .34488 L .52872 .3444 L F
.52672 .34492 m .52557 .34429 L .52682 .34492 L F
.52645 .34487 m .52661 .34493 L .52707 .34488 L F
.5268 .34506 m .5276 .34472 L .52767 .34476 L F
.52645 .34487 m .52707 .34488 L .52794 .34479 L F
.52762 .34441 m .52786 .34432 L .52789 .34425 L F
.52635 .34516 m .5277 .34442 L .52762 .34441 L F
.5277 .34442 m .52786 .34432 L .52762 .34441 L F
.52568 .34465 m .5257 .34465 L .52563 .3444 L F
.5259 .34468 m .52593 .34468 L .52589 .34459 L F
.52593 .34515 m .52589 .34459 L .52572 .34436 L F
.5261 .34491 m .52505 .34418 L .5259 .34459 L F
.52596 .34489 m .52589 .34484 L p .52596 .34489 L F P
0 g
s
.52582 .34473 m .52579 .34469 L .52621 .34498 L .672 .728 .891 r
F
.52552 .34462 m .52582 .34533 L .52566 .34457 L F
.52557 .34453 m .52566 .34457 L .52563 .3444 L F
.52552 .34462 m .52566 .34457 L .52557 .34453 L F
.52592 .34538 m .52593 .34536 L .52563 .3444 L F
.52395 .34563 m .52604 .34504 L .52604 .34504 L F
.52395 .34563 m .52604 .34504 L .52395 .34563 L F
.52547 .34541 m .5254 .34539 L .52609 .34483 L F
.52493 .34535 m .52494 .34534 L .52604 .34504 L F
.52285 .34552 m .5259 .34522 L .52595 .34515 L F
.52544 .34516 m .52598 .34509 L .52531 .34511 L F
.52565 .34527 m .52567 .34527 L .52566 .34526 L F
.52567 .34527 m .52566 .34526 L .52566 .34526 L F
.52585 .34524 m .52475 .34545 L .52614 .34494 L F
.52285 .34552 m .52234 .34587 L .5259 .34522 L F
.52475 .34545 m .52369 .34565 L .52488 .34531 L F
.52475 .34545 m .52488 .34531 L .52614 .34494 L F
.52518 .34425 m .52666 .34492 L .52658 .34492 L F
.52505 .34418 m .52518 .34425 L .52518 .34425 L F
.52518 .34425 m .52666 .34492 L .52518 .34425 L F
.52599 .34451 m .526 .34437 L .52614 .3444 L F
.52608 .34453 m .52593 .34393 L .52602 .34436 L F
.52682 .34492 m .52599 .34451 L .52614 .3444 L F
.52608 .34453 m .52602 .34436 L .5261 .34473 L F
.52614 .34475 m .52608 .34453 L .5261 .34473 L F
.52626 .34472 m .52609 .34483 L .52623 .34478 L F
.52619 .34479 m .52616 .3448 L .5262 .34476 L F
.526 .34469 m .52592 .34462 L .52598 .34469 L F
.52599 .34453 m .52574 .34439 L .52599 .34452 L F
.52574 .34439 m .52557 .34429 L .52573 .34438 L F
.52609 .3447 m .52603 .3447 L .52605 .34478 L F
.52609 .3447 m .52587 .34401 L .52603 .3447 L F
.52585 .34524 m .52617 .34493 L .52622 .345 L F
.52611 .34502 m .52587 .34401 L .52607 .34509 L F
.52584 .34389 m .52619 .34479 L .52599 .34471 L F
.5262 .34496 m .52614 .34475 L .52615 .34491 L F
.52611 .34486 m .52661 .34493 L .52639 .34485 L F
.52592 .34518 m .5256 .3446 L .52593 .34516 L F
.52595 .34514 m .52593 .34516 L .52564 .34461 L F
.52615 .34493 m .52499 .34518 L .5259 .34487 L F
.52595 .34488 m .52596 .34488 L .52616 .34491 L F
.52601 .34491 m .526 .34491 L .52595 .34488 L F
.52596 .34488 m .52607 .34491 L .52601 .34491 L F
.52596 .34488 m .52596 .34484 L .52607 .34491 L F
.52616 .34491 m .52596 .34488 L .52609 .34483 L F
.52596 .34488 m .5259 .34487 L .52609 .34483 L F
.52609 .34483 m .52596 .34491 L .52616 .34491 L F
.52609 .34483 m .52608 .3449 L .52599 .34489 L F
.5262 .34476 m .52616 .3448 L .52609 .34483 L F
.52623 .34478 m .52609 .34483 L .52616 .34491 L F
.5261 .34491 m .5259 .34459 L .52616 .34491 L F
.52609 .34483 m .52603 .34485 L .5261 .34485 L F
.52662 .34482 m .52616 .34491 L .52623 .34484 L F
.52551 .34427 m .52687 .34504 L .52687 .34504 L F
.52626 .34472 m .52616 .34491 L .52735 .3444 L F
.52662 .34482 m .52623 .34484 L .52627 .3448 L F
.52638 .34519 m .52771 .34442 L .52771 .34442 L F
.52872 .3444 m .52662 .34482 L .52627 .3448 L F
.52643 .34491 m .52698 .34452 L .52698 .34454 L F
.52609 .34483 m .5261 .34485 L .52749 .34478 L F
.52627 .3448 m .52616 .34491 L .52609 .34483 L F
.52615 .34491 m .52609 .3447 L .52609 .34483 L F
.52616 .3448 m .52611 .34486 L .52609 .34483 L F
.52611 .34486 m .52608 .3449 L .52609 .34483 L F
.52612 .3454 m .52568 .34463 L .52568 .34463 L F
.52591 .34518 m .52577 .34461 L .52588 .3452 L F
.50797 .34782 m .50775 .34702 L p .52349 .34513 L F P
0 g
s
.52595 .34488 m .52601 .34491 L .52595 .34488 L .672 .728 .891 r
F
.52587 .34487 m .52614 .34489 L .52611 .34486 L F
.52623 .34484 m .5262 .34487 L .5262 .34496 L F
.52614 .34489 m .52661 .34493 L .52611 .34486 L F
.52665 .34492 m .5288 .34372 L .52657 .34492 L F
.52725 .34464 m .52609 .34483 L .52749 .34478 L F
.52618 .3448 m .52612 .34487 L .52616 .3448 L F
.51363 .3476 m .52525 .34536 L .52525 .34536 L F
.52525 .34536 m .52573 .34527 L .52525 .34536 L F
.52525 .34536 m .52573 .34527 L .52573 .34527 L F
.5239 .34571 m .52493 .34535 L .5249 .3454 L F
.52234 .34588 m .52589 .34523 L .52589 .34523 L F
.52234 .34588 m .52589 .34523 L .52234 .34588 L F
.5209 .34615 m .52589 .34523 L .5209 .34614 L F
.52491 .34592 m .52494 .34587 L .52548 .34551 L F
.52491 .34592 m .52548 .34551 L .52557 .34548 L F
.52298 .34716 m .5251 .34564 L .52528 .34558 L F
.52008 .34823 m .52491 .34597 L .52493 .34591 L F
.52073 .34822 m .5256 .34551 L .52513 .34569 L F
.52419 .34638 m .52417 .34631 L .52521 .34561 L F
.5257 .34545 m .52575 .34542 L .52575 .34542 L F
.52575 .34542 m .52596 .34531 L .52575 .34542 L F
.52575 .34542 m .52596 .34531 L .52596 .3453 L F
.52405 .34507 m .5237 .34531 L .52349 .34513 L F
.51939 .34642 m .52565 .34527 L .52566 .34526 L F
.51354 .3475 m .51939 .34642 L .51939 .34642 L F
.51939 .34642 m .52565 .34527 L .51939 .34642 L F
.52478 .34629 m .51312 .35415 L p .52459 .34622 L F P
0 g
s
.52425 .34664 m .5259 .34553 L p .5237 .34684 L .672 .728 .891 r
F P
0 g
s
.52343 .347 m .52367 .34689 L .5237 .34684 L .672 .728 .891 r
F
.52367 .34689 m .52425 .34664 L .5237 .34684 L F
.52615 .34491 m .52614 .34475 L .5261 .34473 L F
.52612 .34487 m .52611 .34486 L .52616 .3448 L F
.52587 .34487 m .52512 .34503 L .52516 .34498 L F
.52495 .34416 m .52505 .34418 L .52518 .34427 L F
.52479 .34419 m .52145 .34207 L p .52518 .34426 L F P
0 g
s
.52352 .34313 m .51344 .33587 L p .52501 .34352 L .672 .728 .891 r
F P
0 g
s
.52346 .34264 m .52457 .34355 L .52465 .34357 L .672 .728 .891 r
F
.52592 .34462 m .52587 .34401 L .52589 .34459 L F
.52569 .34433 m .52569 .34427 L .52567 .3443 L F
.52584 .34389 m .52599 .34471 L .52567 .34431 L F
.54061 .33676 m .53978 .33616 L p .52679 .34439 L F P
0 g
s
.52905 .34301 m .52759 .34398 L .52877 .34313 L .672 .728 .891 r
F
.52759 .34398 m .52758 .34396 L .52877 .34313 L F
.52771 .3444 m .5277 .34439 L .5363 .33916 L F
.5332 .34104 m .5332 .34104 L .53531 .33976 L F
.53531 .33976 m .53531 .33976 L .5363 .33916 L F
.53714 .33882 m .52854 .34392 L p .5363 .33916 L F P
0 g
s
.52854 .34392 m .52853 .34389 L .5363 .33916 L .672 .728 .891 r
F
.52945 .34328 m .52831 .34396 L .52872 .34337 L F
.5363 .33916 m .52945 .34328 L .52872 .34337 L F
.54061 .33676 m .53714 .33882 L p .5363 .33916 L F P
0 g
s
.52878 .34332 m .52879 .34357 L .54061 .33676 L .672 .728 .891 r
F
.52877 .34313 m .52767 .34389 L .52757 .34389 L F
.53114 .34182 m .52724 .34437 L .53065 .34194 L F
.52626 .34472 m .52735 .3444 L .52699 .34439 L F
.52713 .34443 m .5269 .34452 L .52872 .34337 L F
.52626 .34472 m .52879 .34357 L .52878 .34332 L F
.52698 .34454 m .52698 .34452 L .52872 .34337 L F
.52724 .34437 m .52677 .34456 L .53065 .34194 L F
.52677 .34456 m .52665 .34461 L .53065 .34194 L F
.53065 .34194 m .52905 .34301 L .52877 .34313 L F
.53978 .33616 m .53114 .34182 L .53065 .34194 L F
.5275 .3438 m .5283 .34377 L .53978 .33616 L F
.52789 .34352 m .5271 .34427 L .52789 .34352 L F
.52639 .34485 m .52645 .34487 L .52794 .34479 L F
.5268 .34506 m .52666 .345 L .52686 .34503 L F
.52658 .34492 m .52666 .34492 L .52706 .34514 L F
.52619 .34477 m .52619 .34479 L .52584 .34389 L F
.52618 .3448 m .52616 .3448 L .52619 .34479 L F
.52589 .34484 m .52596 .34484 L .52596 .34488 L F
.52609 .34483 m .5259 .34487 L .52587 .34487 L F
.52595 .34485 m .52598 .34486 L .526 .34486 L F
.52594 .34488 m .52599 .34491 L p .52599 .34471 L F P
0 g
s
.52619 .34479 m .5262 .34483 L .52559 .34454 L .672 .728 .891 r
F
.52617 .34493 m .52614 .34494 L .52615 .34493 L F
.52584 .34524 m .52678 .34506 L .52584 .34525 L F
.52616 .34491 m .52603 .34517 L .52626 .34504 L F
.52616 .34492 m .5261 .34498 L .52611 .34502 L F
.52542 .34533 m .52634 .34515 L .52635 .34515 L F
.52596 .34531 m .52667 .34492 L .52596 .3453 L F
.52597 .34544 m .52638 .34519 L .52638 .34519 L F
.52589 .34548 m .52639 .3452 L .52632 .34523 L F
.52575 .34528 m .52573 .34527 L .52676 .34507 L F
.52616 .34492 m .52611 .34502 L .52625 .34563 L F
.52616 .34492 m .52611 .34502 L .52616 .34492 L F
.5257 .34545 m .52596 .3453 L .5256 .34543 L F
.52583 .34526 m .52676 .34507 L .52581 .34528 L F
.52583 .3453 m .52582 .3453 L .52638 .34519 L F
.52584 .3453 m .52583 .3453 L .52638 .34519 L F
.52596 .3453 m .52631 .34511 L .52598 .34526 L F
.526 .34556 m .52591 .34518 L .52588 .3452 L F
.52596 .3453 m .52598 .34526 L .5256 .34543 L F
.52598 .34526 m .52607 .34509 L .52605 .34503 L F
.52596 .34526 m .52605 .34503 L .52593 .34515 L F
.52572 .34527 m .52584 .34524 L .52573 .34527 L F
.52584 .34524 m .52584 .34525 L .52573 .34527 L F
.52542 .34533 m .52541 .34532 L .52572 .34527 L F
.52542 .34533 m .52572 .34527 L .52572 .34527 L F
.52573 .34527 m .52573 .34527 L .52582 .34525 L F
.52573 .34527 m .52582 .34525 L .52582 .34525 L F
.52547 .34541 m .52501 .3457 L .5254 .34539 L F
.52597 .34544 m .52595 .34544 L .52686 .34489 L F
.52598 .34543 m .52682 .34493 L .52598 .34542 L F
.52636 .34558 m .5262 .34496 L .52615 .34491 L F
.52631 .3451 m .52631 .3451 L .526 .34491 L F
.52451 .34554 m .52578 .34532 L .52577 .34531 L F
.52582 .3453 m .52448 .34555 L .52579 .34529 L F
.5242 .346 m .52598 .34523 L .5242 .34599 L F
.5245 .34556 m .52582 .3453 L .52583 .3453 L F
.52584 .3453 m .5245 .34556 L p .52583 .3453 L F P
0 g
s
.52616 .34491 m .52516 .34549 L .52603 .34517 L .672 .728 .891 r
F
.52516 .34549 m .52414 .34606 L .52509 .34561 L F
.52516 .34549 m .52509 .34561 L .52603 .34517 L F
.52722 .3448 m .52794 .34479 L .52784 .34477 L F
.52611 .34485 m .52722 .34481 L .52722 .3448 L F
.52495 .34629 m .52495 .34629 L .52595 .34535 L F
.52583 .34471 m .52571 .34468 L .52568 .34463 L F
.52518 .34431 m .52579 .34469 L .52582 .34473 L F
.52518 .34431 m .52518 .34427 L .52579 .34469 L F
.52589 .34484 m .52585 .34477 L .5259 .34482 L F
.52589 .34484 m .52495 .34416 L p .52585 .34477 L F P
0 g
s
.52491 .34414 m .52594 .34488 L p .52544 .34426 L .672 .728 .891 r
F P
0 g
s
.52532 .34434 m .52534 .34434 L .52593 .34468 L .672 .728 .891 r
F
.52601 .34491 m .52631 .3451 L .526 .34491 L F
.52601 .34491 m .52607 .34491 L .52626 .34505 L F
.52572 .34527 m .52572 .34527 L .5268 .34506 L F
.52631 .34511 m .52628 .34507 L .5256 .34543 L F
.5263 .34521 m .52623 .34479 L .5263 .34521 L F
.52601 .34491 m .52626 .34505 L .52631 .3451 L F
.52598 .34529 m .52635 .34516 L .52633 .34513 L F
.52603 .34517 m .52627 .34505 L .52626 .34504 L F
.52639 .3452 m .52585 .34552 L p .52638 .34519 L F P
0 g
s
.50761 .34621 m .50755 .3454 L p .52009 .345 L .672 .728 .891 r
F P
0 g
s
.52678 .34506 m .52678 .34506 L .52573 .34527 L .672 .728 .891 r
F
.52626 .34505 m .52621 .34498 L .52706 .34556 L F
.52744 .34574 m .52729 .34571 L .52886 .34723 L F
.52702 .34555 m .52706 .34556 L .52839 .34648 L F
.52649 .34497 m .52672 .34547 L .52673 .34545 L F
.52626 .34505 m .52706 .34556 L .52702 .34555 L F
.52722 .34481 m .52794 .34479 L .52722 .3448 L F
.52643 .34519 m .52643 .34518 L .527 .34508 L F
.52643 .34519 m .527 .34508 L .527 .34508 L F
.52662 .34512 m .52676 .34507 L .52703 .34502 L F
.52687 .34543 m .52621 .34498 L .52687 .34505 L F
.5282 .34597 m .52701 .34506 L .52811 .34645 L F
.52735 .34535 m .52727 .34527 L .52727 .34526 L F
.52839 .34648 m .52727 .34527 L .52735 .34535 L F
.52839 .34648 m .52696 .3455 L .52727 .34527 L F
.52698 .34508 m .52692 .34521 L .52699 .34509 L F
.52687 .34543 m .52687 .34505 L .52706 .34514 L F
.52706 .34514 m .52706 .34514 L .52727 .34526 L F
.52727 .34526 m .52706 .34514 L .52707 .34511 L F
.52688 .34504 m .52697 .34505 L .52707 .34511 L F
.52706 .3451 m .53032 .34464 L p .52695 .34506 L F P
0 g
s
.53032 .34464 m .53377 .34415 L p .53032 .34461 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .52638 .34519 L .52943 .34462 L .672 .728 .891 r
F
.52695 .34506 m .53032 .34464 L .53032 .34461 L F
.53735 .35547 m .5383 .35498 L p .52787 .34583 L F P
0 g
s
.5383 .35498 m .53026 .34838 L p .52787 .34583 L .672 .728 .891 r
F P
0 g
s
.53114 .34823 m .5282 .34597 L .52886 .34723 L .672 .728 .891 r
F
.53026 .34838 m .52896 .34731 L p .52875 .34677 L F P
0 g
s
.52886 .34723 m .5383 .35498 L p .53114 .34823 L .672 .728 .891 r
F P
0 g
s
.53817 .35365 m .52887 .34699 L .52727 .34526 L .672 .728 .891 r
F
.53921 .35444 m .53802 .35358 L p .53817 .35365 L F P
0 g
s
.53802 .35358 m .52887 .34699 L p .53817 .35365 L .672 .728 .891 r
F P
0 g
s
.50765 .34377 m .50781 .34296 L p .51227 .3434 L .672 .728 .891 r
F P
0 g
s
.52709 .3451 m .52905 .34698 L .52914 .34685 L .672 .728 .891 r
F
.52623 .34479 m .52623 .34477 L .52623 .34478 L F
.52623 .34479 m .52623 .34478 L .52622 .34479 L F
.52623 .34484 m .52621 .34472 L .5262 .34487 L F
.52621 .34472 m .52593 .34393 L p .52613 .34471 L F P
0 g
s
.52624 .34479 m .52621 .34482 L .52584 .34389 L .672 .728 .891 r
F
.52626 .34472 m .52618 .3448 L .5262 .34476 L F
.52589 .34431 m .52561 .34431 L .52646 .34497 L F
.52654 .34499 m .52646 .34497 L .5267 .34516 L F
.52624 .34481 m .52624 .34482 L .52623 .34477 L F
.5263 .34521 m .52624 .34482 L .52624 .34481 L F
.52631 .3451 m .52626 .34505 L .52687 .34545 L F
.5263 .34521 m .52635 .34521 L .52624 .34482 L F
.52625 .34482 m .52625 .34482 L .52622 .34481 L F
.5263 .34521 m .52623 .34479 L .52622 .34479 L F
.52624 .34479 m .52625 .34482 L p .52622 .34481 L F P
0 g
s
.52636 .34474 m .52615 .3449 L .52626 .34472 L .672 .728 .891 r
F
.52582 .34533 m .5257 .34465 L .52568 .34465 L F
.52614 .34494 m .52499 .34518 L .52615 .34493 L F
.52612 .34491 m .52603 .34499 L .52616 .34491 L F
.52596 .34491 m .52603 .34499 L .52612 .34491 L F
.5247 .34551 m .52643 .34518 L .5247 .34551 L F
.5252 .34539 m .52516 .34547 L .52603 .34499 L F
.52596 .34491 m .5252 .34539 L .52603 .34499 L F
.52596 .34491 m .5254 .34544 L .5252 .34539 L F
.52481 .34517 m .52461 .34538 L .52567 .34524 L F
.52639 .3452 m .5276 .3478 L p .5262 .34545 L F P
0 g
s
.52632 .34523 m .52639 .3452 L .52638 .34519 L .672 .728 .891 r
F
.52652 .34557 m .52623 .34477 L p .52646 .34562 L F P
0 g
s
.52637 .34521 m .52635 .34522 L .5262 .34483 L .672 .728 .891 r
F
.5262 .34483 m .5262 .34483 L .52619 .34479 L F
.52637 .34521 m .5262 .34483 L .5262 .34483 L F
.52592 .34538 m .52632 .34655 L .52595 .34539 L F
.52598 .34543 m .52588 .34547 L .52589 .34548 L F
.52592 .34548 m .52592 .34548 L .52591 .34548 L F
.52585 .34552 m .52595 .34544 L .52597 .34544 L F
.52587 .34547 m .52632 .34655 L .52592 .34538 L F
.52653 .34628 m .5265 .34638 L .52598 .34535 L F
.52632 .34655 m .52605 .34558 L .526 .34556 L F
.52587 .34552 m .52647 .34605 L .52602 .34599 L F
.5247 .34551 m .52643 .34518 L .52643 .34519 L F
.52582 .34533 m .52587 .34522 L .52581 .34528 L F
.52593 .34515 m .52591 .34518 L .52595 .34533 L F
.52582 .34525 m .52582 .34525 L .52635 .34515 L F
.526 .34522 m .52602 .3452 L .52557 .34543 L F
.52597 .34528 m .52595 .34533 L .52596 .3454 L F
.52606 .34531 m .52595 .34538 L .52601 .34533 L F
.52617 .34551 m .52611 .34551 L .52593 .34516 L F
.52598 .34535 m .52609 .34532 L .52598 .34529 L F
.52557 .34543 m .52602 .3452 L .52603 .34517 L F
.52369 .34565 m .5239 .34541 L .52499 .34518 L F
.52324 .34546 m .52544 .34516 L .52531 .34511 L F
.52488 .34531 m .52499 .34518 L .52614 .34494 L F
.52369 .34565 m .52499 .34518 L .52488 .34531 L F
.52567 .3444 m .52547 .34329 L .52547 .3433 L F
.52693 .34505 m .52703 .34502 L .52697 .34505 L F
.52697 .34505 m .52703 .34502 L .52702 .34504 L F
.527 .34508 m .527 .34508 L .52834 .34482 L F
.52643 .34519 m .52834 .34482 L .52834 .34483 L F
.5268 .345 m .52695 .34506 L .52835 .34488 L F
.52707 .34508 m .5268 .3449 L .52706 .3451 L F
.52657 .34464 m .52641 .34475 L .52646 .34468 L F
.52644 .34475 m .52665 .34461 L .52648 .34475 L F
.5268 .3449 m .52592 .3443 L .5268 .34493 L F
.52686 .34503 m .52666 .345 L .5276 .34472 L F
.52631 .3451 m .52631 .34511 L .52595 .34488 L F
.52596 .34489 m .52641 .34518 L .52641 .34518 L F
.52639 .3452 m .52596 .34489 L p .52641 .34518 L F P
0 g
s
.52639 .34567 m .52616 .34492 L .52625 .34563 L .672 .728 .891 r
F
.52621 .34498 m .5261 .34491 L .52616 .34492 L F
.52616 .34492 m .52612 .34492 L .52621 .34498 L F
.52612 .34492 m .52599 .34491 L .52621 .34498 L F
.52596 .34489 m .52596 .34489 L .52641 .34518 L F
.52599 .34491 m .52639 .3452 L p .52621 .34498 L F P
0 g
s
.52628 .34502 m .52635 .34522 L .52614 .34503 L .672 .728 .891 r
F
.52644 .34475 m .52612 .34496 L .52641 .34475 L F
.52612 .34496 m .5254 .34544 L .52613 .34494 L F
.52627 .34505 m .52623 .34484 L .5262 .34496 L F
.5262 .34483 m .52628 .34502 L .52611 .34498 L F
.5262 .34483 m .52616 .34491 L .52614 .3449 L F
.52616 .34491 m .52611 .34498 L .52614 .3449 L F
.52599 .34486 m .52599 .34491 L .52616 .34492 L F
.52614 .3449 m .52616 .34492 L .52626 .34492 L F
.52603 .34485 m .52619 .34485 L .52619 .34484 L F
.5262 .34483 m .52614 .3449 L .52618 .34482 L F
.52615 .3449 m .52609 .3449 L .52626 .34472 L F
.52599 .34486 m .52616 .34492 L .52614 .3449 L F
.52641 .34475 m .52616 .34492 L .52638 .34474 L F
.52619 .34552 m .52618 .34552 L .52611 .3454 L F
.52619 .34552 m .52611 .3454 L .52612 .3454 L F
.52617 .34551 m .52608 .34538 L .52609 .34539 L F
.52625 .34563 m .52622 .34552 L .52621 .34551 L F
.52612 .3454 m .52612 .3454 L .52619 .34552 L F
.52619 .34552 m .52596 .34512 L .52619 .34552 L F
.52619 .34552 m .52612 .3454 L .52612 .3454 L F
.52651 .34562 m .52618 .34557 L .526 .34528 L F
.52599 .34489 m .52594 .34505 L .52596 .34491 L F
.52587 .34487 m .52578 .34502 L .52606 .34499 L F
.52613 .34494 m .5254 .34544 L .52614 .34491 L F
.52614 .3449 m .52611 .34498 L .52608 .34498 L F
.52635 .34522 m .52624 .3453 L .52607 .3451 L F
.52611 .34498 m .52611 .34499 L .52594 .34512 L F
.52617 .34493 m .52618 .34494 L .52594 .34512 L F
.52614 .3449 m .52594 .34505 L .52609 .3449 L F
.52614 .3449 m .52594 .34505 L .52614 .3449 L F
.52608 .3449 m .52594 .34505 L .52599 .34489 L F
.52587 .34487 m .52606 .34499 L .52611 .34494 L F
.52612 .34487 m .52594 .34505 L .52611 .34486 L F
.52595 .34488 m .5259 .34487 L .52596 .34488 L F
.52587 .34487 m .52611 .34494 L .52614 .34489 L F
.52616 .34492 m .52613 .34494 L .52615 .34491 L F
.52613 .34494 m .52614 .34491 L .52615 .34491 L F
.52615 .3449 m .52614 .3449 L .52614 .3449 L F
.52611 .34494 m .52621 .34497 L .52614 .3449 L F
.52611 .34494 m .52614 .3449 L .52614 .34489 L F
.52594 .34515 m .5261 .34501 L .52609 .34504 L F
.52611 .345 m .52607 .3451 L .52602 .34504 L F
.52587 .34487 m .52599 .34486 L .52598 .34486 L F
.52589 .34484 m .52591 .34481 L .52596 .34484 L F
.5259 .34482 m .52585 .34477 L .52591 .34481 L F
.52544 .34426 m .52594 .34488 L .52599 .34471 L F
.52599 .3447 m .52599 .34471 L .526 .34471 L F
.52544 .34426 m .52599 .34471 L .52599 .3447 L F
.52609 .34483 m .52595 .34485 L .52603 .34485 L F
.52595 .34485 m .526 .34486 L .52603 .34485 L F
.52602 .34475 m .52608 .34498 L .52559 .34454 L F
.52609 .3447 m .52605 .34478 L .52609 .34483 L F
.52618 .34482 m .52613 .34488 L .52602 .34475 L F
.52598 .34486 m .52611 .34486 L .52611 .34485 L F
.52603 .34485 m .526 .34486 L .52619 .34485 L F
.52599 .34471 m .52599 .34486 L .52626 .34492 L F
.52613 .34488 m .52608 .34498 L .52602 .34475 L F
.52595 .34485 m .52587 .34487 L .52598 .34486 L F
.52608 .34498 m .52602 .34504 L .52559 .34454 L F
.52501 .3457 m .52329 .34678 L .52509 .34553 L F
.5232 .34645 m .52417 .34607 L .52419 .34601 L F
.52452 .34585 m .52329 .34678 L .52388 .34607 L F
.52008 .34823 m .52452 .3461 L .52423 .34612 L F
.519 .34878 m .52152 .34773 L .52008 .34823 L F
.52329 .34678 m .51571 .35153 L .52371 .34616 L F
.52412 .34608 m .52073 .34822 L .52513 .34569 L F
.52479 .34587 m .52541 .34545 L .52478 .3459 L F
.52252 .34589 m .52572 .34527 L .52573 .34527 L F
.52541 .34545 m .52617 .34493 L .52543 .34545 L F
.52596 .34526 m .52598 .34526 L .52605 .34503 L F
.52628 .34502 m .52614 .34503 L .52611 .345 L F
.52628 .34502 m .52611 .345 L .52611 .34498 L F
.52637 .34521 m .5262 .34483 L .52621 .34482 L F
.52622 .34481 m .52639 .3452 L .52621 .34482 L F
.52625 .34482 m .52639 .3452 L p .52622 .34481 L F P
0 g
s
.52615 .34489 m .52621 .34497 L .52661 .34493 L .672 .728 .891 r
F
.52614 .34489 m .52614 .3449 L .52615 .34489 L F
.52626 .34492 m .52616 .34492 L .52687 .34547 L F
.52641 .34518 m .52641 .34518 L .52839 .34648 L F
.52682 .34547 m .52683 .34547 L .5269 .34552 L F
.52677 .34548 m .52685 .34547 L .52839 .34648 L F
.52688 .34543 m .52687 .34547 L .52826 .34655 L F
.52626 .34492 m .52687 .34547 L .52688 .34543 L F
.52635 .34522 m .52607 .3451 L .52611 .345 L F
.52641 .34491 m .52646 .34497 L .52646 .34491 L F
.52598 .34526 m .52612 .34524 L .52607 .34509 L F
.52594 .34515 m .52594 .34512 L .5261 .34501 L F
.52602 .34504 m .52607 .3451 L .52601 .34506 L F
.52607 .3451 m .52651 .34562 L .52606 .34512 L F
.52593 .34524 m .52593 .34516 L .52609 .34505 L F
.52625 .3449 m .52628 .34493 L .52638 .34491 L F
.52605 .34514 m .52609 .34505 L .52629 .3449 L F
.52682 .34492 m .52614 .3444 L .52682 .34492 L F
.52658 .34473 m .52614 .3444 L .52658 .34473 L F
.52658 .34473 m .52658 .34473 L .52682 .34492 L F
.52682 .34492 m .52658 .34473 L .52682 .34492 L F
.52616 .34491 m .52687 .34468 L .52688 .34461 L F
.52634 .3449 m .52629 .3449 L .52677 .34456 L F
.52616 .34492 m .52621 .34498 L .52623 .34497 L F
.52621 .34498 m .52639 .3452 L .52623 .34497 L F
.52639 .3452 m .52634 .34515 L .52621 .34482 L F
.52623 .34497 m .52639 .3452 L .5265 .34518 L F
.52621 .34498 m .52647 .34497 L .52621 .34497 L F
.52605 .34514 m .52629 .3449 L .52634 .3449 L F
.52593 .34524 m .52609 .34505 L .52605 .34514 L F
.52607 .3451 m .52606 .34512 L .52601 .34506 L F
.52604 .34516 m .52592 .3453 L .52593 .34524 L F
.52626 .34504 m .52602 .34523 L .52625 .34503 L F
.52625 .34503 m .52593 .34524 L .52623 .345 L F
.52621 .34551 m .52611 .34502 L .52607 .34509 L F
.52596 .34511 m .5263 .3451 L .526 .34507 L F
.52628 .34493 m .52678 .34534 L .52646 .34497 L F
.5263 .3451 m .52695 .34506 L .52628 .34507 L F
.5263 .3451 m .52628 .34507 L .526 .34507 L F
.52625 .34503 m .52602 .34523 L .52604 .34516 L F
.52657 .34517 m .52628 .34493 L .52628 .34493 L F
.52625 .34503 m .52623 .345 L .52634 .3449 L F
.52638 .34491 m .52634 .3449 L .52677 .34456 L F
.5261 .34491 m .52681 .34503 L .52687 .34505 L F
.52625 .34503 m .52634 .3449 L .52638 .34491 L F
.526 .34471 m .52599 .34471 L .52623 .3449 L F
.52623 .3449 m .52623 .3449 L .52688 .34543 L F
.526 .34471 m .52623 .3449 L .52623 .3449 L F
.52688 .34543 m .52688 .34543 L .52706 .34557 L F
.526 .34471 m .52688 .34543 L .52688 .34543 L F
.52625 .34502 m .5266 .345 L .52621 .34498 L F
.52643 .34491 m .52626 .34504 L .52625 .34503 L F
.52614 .3449 m .52621 .34497 L .52615 .34489 L F
.5266 .345 m .52647 .34497 L .52621 .34498 L F
.52621 .34497 m .52647 .34497 L .5264 .34495 L F
.52649 .34491 m .52627 .34506 L .52643 .34491 L F
.52627 .34506 m .52592 .3453 L .52626 .34504 L F
.52627 .34506 m .52626 .34504 L .52643 .34491 L F
.526 .34507 m .52627 .34505 L .52602 .34504 L F
.52627 .34505 m .5268 .345 L .52625 .34503 L F
.52627 .34505 m .52625 .34503 L .52602 .34504 L F
.52617 .34493 m .52617 .34493 L .52543 .34545 L F
.52475 .34601 m .52476 .34598 L .5262 .34496 L F
.5262 .34497 m .5262 .34496 L .52677 .34456 L F
.52513 .34569 m .5256 .34543 L .52557 .34543 L F
.52475 .34601 m .5262 .34496 L .5262 .34497 L F
.52611 .34673 m .52648 .34719 L .52624 .34737 L F
.52589 .34548 m .52588 .34547 L .52577 .34554 L F
.52579 .34554 m .52598 .34543 L .52577 .34554 L F
.52606 .34512 m .52592 .34515 L .52601 .34506 L F
.52657 .34517 m .52657 .34517 L .52628 .34493 L F
.526 .34507 m .52674 .34507 L .5268 .345 L F
.52603 .34485 m .52722 .3448 L .52722 .34479 L F
.52639 .3452 m .52635 .34516 L .52682 .34478 L F
.52647 .34492 m .52841 .34392 L .52821 .34391 L F
.52682 .34482 m .52682 .34478 L .52762 .34413 L F
.52681 .34506 m .5269 .34504 L .52681 .34506 L F
.5269 .34504 m .52703 .34502 L .5269 .34504 L F
.5269 .34504 m .5269 .34504 L .52681 .34506 L F
.52687 .34503 m .52706 .34514 L .52706 .34514 L F
.5268 .34505 m .52695 .34506 L .52685 .34502 L F
.52706 .3451 m .52675 .34503 L .5267 .34516 L F
.52679 .34506 m .5268 .34506 L .52848 .34473 L F
.52674 .34507 m .52688 .34506 L .5268 .34505 L F
.52688 .34506 m .52695 .34506 L .5268 .34505 L F
.52706 .34511 m .52706 .3451 L .5267 .34516 L F
.52674 .34507 m .52685 .34502 L .5268 .345 L F
.52687 .34504 m .52706 .34514 L .52687 .34503 L F
.52687 .34504 m .52687 .34504 L .52706 .34514 L F
.52706 .3451 m .52679 .34492 L .52675 .34503 L F
.52611 .34486 m .52722 .34481 L .52611 .34485 L F
.52599 .34486 m .52611 .34486 L .52598 .34486 L F
.52647 .34497 m .52835 .34488 L .5264 .34495 L F
.52646 .34491 m .52646 .34497 L .52654 .34499 L F
.52665 .34501 m .5266 .345 L .52602 .34504 L F
.52635 .34516 m .52627 .34506 L .52681 .34469 L F
.52688 .34461 m .52687 .34468 L .52735 .3444 L F
.52682 .34478 m .52681 .34469 L .52762 .34413 L F
.52635 .34516 m .52681 .34469 L .52682 .34478 L F
.52696 .3455 m .52706 .34514 L .52727 .34526 L F
.52709 .3451 m .5267 .34516 L .52789 .34608 L F
.52705 .34535 m .52685 .34524 L .52705 .34534 L F
.52625 .34502 m .52621 .34498 L .52606 .34499 L F
.52742 .34481 m .52794 .34479 L .52743 .34481 L F
.52676 .34585 m .52619 .34485 L p .52676 .34585 L F P
0 g
s
.52542 .34533 m .52848 .34473 L .52848 .34474 L .672 .728 .891 r
F
.5266 .345 m .52835 .34488 L .52647 .34497 L F
.52722 .34479 m .52722 .3448 L .52784 .34477 L F
.52725 .34464 m .52749 .34478 L .52764 .34472 L F
.52719 .34486 m .52721 .34482 L .52805 .34462 L F
.5268 .345 m .52835 .34488 L .52676 .34499 L F
.52638 .34519 m .52706 .3451 L .52637 .34518 L F
.52784 .34477 m .52794 .34479 L .52838 .34474 L F
.5264 .34495 m .52835 .34488 L .52794 .34479 L F
.52567 .34524 m .52696 .34511 L .52695 .34506 L F
.52696 .34511 m .52706 .3451 L .52699 .34508 L F
.52696 .34511 m .52699 .34508 L .52695 .34506 L F
.52481 .34517 m .52567 .34524 L .52547 .34514 L F
.526 .34508 m .526 .34508 L .52465 .34544 L F
.52465 .34544 m .52558 .34519 L .52562 .3452 L F
.52437 .34541 m .52572 .34526 L .52567 .34524 L F
.52465 .34543 m .526 .34508 L .52465 .34544 L F
.52591 .34548 m .52639 .3452 L .52589 .34548 L F
.5259 .34553 m .52627 .34506 L .52635 .34516 L F
.52609 .34557 m .52614 .34551 L .52605 .34547 L F
.52653 .34628 m .52598 .34535 L .52602 .34537 L F
.52632 .34655 m .52612 .34524 L .52596 .34526 L F
.52606 .34538 m .52618 .34557 L .52595 .3454 L F
.52582 .34533 m .52587 .34547 L .52592 .34538 L F
.5257 .34545 m .52593 .34537 L .52596 .34531 L F
.52573 .34545 m .52609 .34532 L .5257 .34545 L F
.52584 .34545 m .52584 .34546 L .5259 .34543 L F
.52584 .34545 m .5259 .34543 L .5259 .34542 L F
.52583 .34551 m .52576 .34549 L .52585 .34544 L F
.52581 .34547 m .52584 .34546 L .52584 .34545 L F
.52581 .34547 m .52583 .34547 L .52584 .34546 L F
.52478 .34613 m .52591 .34548 L .52589 .34548 L F
.52471 .34613 m .52638 .34519 L .52635 .34516 L F
.52482 .34613 m .52639 .3452 L p .52479 .34613 L F P
0 g
s
.5259 .34553 m .52478 .34629 L p .52592 .3453 L .672 .728 .891 r
F P
0 g
s
.52597 .34535 m .52595 .3454 L .52579 .34527 L .672 .728 .891 r
F
.52601 .34542 m .52597 .34528 L .52596 .3454 L F
.52606 .34538 m .52595 .3454 L .52597 .34535 L F
.52622 .34552 m .52611 .34502 L .52621 .34551 L F
.52474 .34613 m .52638 .34519 L .52471 .34613 L F
.52642 .34553 m .526 .34528 L .52606 .34512 L F
.52636 .34558 m .52646 .34562 L .52635 .34521 L F
.52651 .34562 m .52629 .34547 L .52642 .34553 L F
.52629 .34547 m .526 .34528 L .52642 .34553 L F
.52602 .34523 m .52592 .3453 L .52604 .34516 L F
.52603 .34518 m .526 .34528 L .52596 .34521 L F
.52579 .34527 m .52595 .3454 L .52587 .34552 L F
.52601 .34542 m .52596 .3454 L .526 .34556 L F
.52595 .3454 m .52618 .34557 L .5259 .34553 L F
.5259 .34553 m .52592 .3453 L .52601 .34524 L F
.5259 .34553 m .52601 .34524 L .5259 .34553 L F
.52595 .3454 m .5259 .34553 L .52587 .34552 L F
.5259 .34553 m .52601 .34524 L .52627 .34506 L F
.52412 .34608 m .52513 .34569 L .52603 .34517 L F
.52419 .34638 m .52594 .34512 L .52594 .34515 L F
.52585 .34524 m .52587 .34522 L .52567 .34524 L F
.52603 .34518 m .52596 .34521 L .52592 .34515 L F
.52606 .34512 m .52603 .34518 L .52592 .34515 L F
.52541 .34545 m .5254 .34544 L .52644 .34475 L F
.52547 .34514 m .52567 .34524 L .52634 .34515 L F
.5244 .3459 m .52442 .34591 L .52616 .34491 L F
.52594 .34505 m .5254 .34544 L .52596 .34491 L F
.52588 .3452 m .52577 .34461 L .52568 .34457 L F
.52602 .34504 m .52601 .34506 L .52557 .34457 L F
.52588 .34534 m .52587 .34456 L .52581 .34448 L F
.52594 .34538 m .52639 .3452 L .52598 .34535 L F
.52562 .34554 m .52593 .34541 L .52594 .34538 L F
.52593 .34541 m .52639 .3452 L .52594 .34538 L F
.52589 .34548 m .52589 .34534 L .52588 .34534 L F
.52587 .34552 m .5259 .34553 L .52593 .34541 L F
.5259 .34557 m .5259 .34547 L .52589 .34548 L F
.5259 .34547 m .52589 .34534 L .52589 .34548 L F
.52594 .3451 m .52611 .34498 L .52594 .34512 L F
.52601 .34506 m .52592 .34515 L .52557 .34457 L F
.52589 .34518 m .52587 .34462 L .52588 .34519 L F
.52567 .34431 m .52599 .34471 L .52559 .34454 L F
.526 .34471 m .526 .34469 L .52594 .34465 L F
.52527 .3436 m .52538 .34394 L .52541 .34338 L F
.52465 .34357 m .52594 .34465 L .52578 .34444 L F
.52538 .34394 m .52567 .34431 L .52557 .34457 L F
.52538 .34394 m .52588 .34379 L .52567 .34431 L F
.52589 .34431 m .52536 .34394 L .52561 .34431 L F
.52536 .34394 m .52346 .34264 L .52521 .344 L F
.52536 .34394 m .52521 .344 L .52561 .34431 L F
.52457 .34355 m .526 .34471 L .52465 .34357 L F
.5251 .34405 m .52515 .34403 L .52567 .3443 L F
.52709 .3451 m .52789 .34608 L .52798 .34595 L F
.52768 .3457 m .52725 .34545 L .52796 .34575 L F
.52725 .34545 m .52643 .34497 L .52735 .34544 L F
.52725 .34545 m .52735 .34544 L .52796 .34575 L F
.52499 .34518 m .52511 .34504 L .5259 .34487 L F
.52587 .34487 m .52516 .34498 L .52578 .34502 L F
.52541 .34545 m .52644 .34475 L .52644 .34475 L F
.52479 .34587 m .5254 .34545 L .52541 .34545 L F
.5254 .34545 m .52644 .34475 L .52541 .34545 L F
.52637 .34518 m .52706 .3451 L .52636 .34517 L F
.52671 .34515 m .52639 .3452 L p .52666 .34512 L F P
0 g
s
.52671 .34515 m .52666 .34512 L .52689 .34505 L .672 .728 .891 r
F
.52713 .34509 m .52671 .34515 L p .52689 .34505 L F P
0 g
s
.5268 .345 m .52676 .34499 L .5266 .345 L .672 .728 .891 r
F
.5268 .345 m .5266 .345 L .52665 .34501 L F
.52679 .34492 m .52646 .34491 L .5267 .34516 L F
.52685 .34524 m .52638 .34496 L .52685 .34522 L F
.52639 .3452 m .52668 .34492 L .52671 .34492 L F
.5263 .3451 m .52634 .34515 L .52664 .34511 L F
.52672 .34508 m .52664 .34511 L .52695 .34506 L F
.5263 .3451 m .52664 .34511 L .52672 .34508 L F
.52592 .34515 m .52606 .34538 L .52581 .34528 L F
.52585 .34524 m .52637 .34518 L .52587 .34522 L F
.52637 .34518 m .52636 .34517 L .52567 .34524 L F
.52578 .34529 m .52639 .3452 L p .52575 .34527 L F P
0 g
s
.52639 .3452 m .52706 .3451 L p .52642 .34519 L .672 .728 .891 r
F P
0 g
s
.52575 .34527 m .52639 .3452 L .52642 .34519 L .672 .728 .891 r
F
.52363 .34571 m .5247 .34551 L .52363 .34571 L F
.5247 .34551 m .52643 .34518 L .5247 .34551 L F
.5247 .34551 m .5247 .34551 L .52363 .34571 L F
.52599 .3447 m .52594 .34465 L .52518 .34401 L F
.5257 .34545 m .5256 .34543 L .52513 .34569 L F
.52593 .34524 m .52475 .34601 L .52593 .34516 L F
.52592 .34515 m .52581 .34528 L .52579 .34527 L F
.5268 .34455 m .52625 .34503 L .52677 .34456 L F
.52724 .34437 m .52681 .34466 L .5268 .34455 L F
.52619 .34484 m .52619 .34485 L .52722 .3448 L F
.52638 .34491 m .52628 .34493 L .52646 .34497 L F
.52681 .34466 m .52625 .34503 L .5268 .34455 L F
.52609 .34504 m .5261 .34501 L .52677 .34456 L F
.52621 .34482 m .52619 .34479 L .52619 .34477 L F
.5262 .34483 m .52619 .34479 L .52621 .34482 L F
.52617 .34493 m .52644 .34475 L .52617 .34493 L F
.52617 .34493 m .52644 .34475 L .52618 .34494 L F
.52616 .34492 m .52615 .34491 L .52638 .34474 L F
.52594 .34512 m .52644 .34475 L .52648 .34475 L F
.52578 .34444 m .52625 .3449 L .52638 .34491 L F
.52602 .34474 m .52601 .34473 L .52685 .34522 L F
.52685 .34522 m .52685 .34522 L .52705 .34534 L F
.52639 .3452 m .5268 .34492 L p .52598 .34535 L F P
0 g
s
.52639 .3452 m .52632 .34511 L .52666 .34501 L .672 .728 .891 r
F
.52683 .3449 m .52639 .3452 L p .52682 .34482 L F P
0 g
s
.52646 .34497 m .52678 .34534 L .52679 .34522 L .672 .728 .891 r
F
.52602 .34474 m .52685 .34522 L .52685 .34522 L F
.52624 .34501 m .52624 .34501 L .526 .34508 L F
.52641 .34497 m .526 .34508 L .526 .34508 L F
.52481 .34517 m .52596 .34511 L .526 .34507 L F
.52583 .345 m .52592 .34515 L .52591 .34517 L F
.52583 .345 m .52591 .34517 L .52579 .34527 L F
.52557 .34457 m .52583 .345 L .52579 .34527 L F
.526 .34507 m .52602 .34504 L .52537 .34509 L F
.52539 .3451 m .52537 .34509 L .52486 .34512 L F
.526 .34507 m .52537 .34509 L .52539 .3451 L F
.52587 .34533 m .52576 .34455 L .52586 .34533 L F
.52587 .34552 m .52584 .34531 L .52583 .34531 L F
.52587 .34553 m .5259 .34553 L .52587 .34552 L F
.52588 .34555 m .52587 .34552 L .52587 .34552 L F
.52587 .34552 m .52584 .34531 L .52587 .34552 L F
.5256 .34551 m .52573 .34545 L .5257 .34545 L F
.52564 .34549 m .52581 .34542 L .52597 .34531 L F
.52639 .3452 m .52581 .34528 L p .52632 .34511 L F P
0 g
s
.52547 .34514 m .52634 .34515 L .5263 .3451 L .672 .728 .891 r
F
.52558 .34519 m .52642 .34497 L .52562 .3452 L F
.52611 .34486 m .52742 .34481 L .52611 .34486 L F
.52679 .34439 m .52626 .34472 L .52686 .34439 L F
.52694 .34429 m .52636 .34474 L .52626 .34472 L F
.52599 .34453 m .52599 .34452 L .52687 .345 L F
.52599 .34454 m .52687 .34503 L .52599 .34454 L F
.52641 .34475 m .52638 .34474 L .52646 .34468 L F
.52599 .34454 m .52599 .34453 L .52687 .34504 L F
.52679 .34492 m .52589 .34431 L .52646 .34491 L F
.52671 .34492 m .52682 .34478 L .52682 .34482 L F
.52668 .34492 m .52682 .34478 L .52671 .34492 L F
.52589 .34431 m .52641 .34491 L .52646 .34491 L F
.5265 .34491 m .52593 .34459 L .5268 .3449 L F
.52577 .34435 m .52567 .3443 L .526 .34436 L F
.52574 .34439 m .52579 .34426 L .52573 .34433 L F
.52585 .34522 m .52581 .34447 L .52574 .34439 L F
.52571 .34436 m .52567 .3443 L .52592 .34444 L F
.52581 .34447 m .52579 .34426 L .52574 .34439 L F
.52593 .34459 m .52587 .34456 L .52592 .34453 L F
.52583 .34523 m .52572 .34437 L .52568 .34441 L F
.52572 .34437 m .52572 .34434 L .52571 .34436 L F
.52572 .34437 m .52571 .34436 L .52568 .34441 L F
.52505 .34433 m .52532 .34434 L .52603 .34475 L F
.52616 .34492 m .52626 .34504 L .52658 .34491 L F
.5267 .34491 m .52681 .34485 L .52681 .34485 L F
.52633 .34513 m .5268 .34492 L .52681 .34485 L F
.52588 .34539 m .52635 .34515 L .52633 .34513 L F
.52635 .34515 m .5268 .34492 L .52633 .34513 L F
.52626 .34505 m .52725 .34474 L .52721 .34482 L F
.52562 .3452 m .52625 .34503 L .52626 .34505 L F
.5263 .3451 m .52661 .34494 L .52647 .34498 L F
.52661 .34494 m .52681 .34484 L .52647 .34498 L F
.52593 .34459 m .52592 .34453 L .5268 .3449 L F
.52647 .34498 m .52681 .34484 L .52681 .34476 L F
.52742 .34481 m .52743 .34481 L .52611 .34486 L F
.52679 .34492 m .52679 .34492 L .52706 .34511 L F
.5268 .3449 m .5268 .34493 L .52706 .3451 L F
.52707 .34508 m .5265 .34491 L .5268 .3449 L F
.52709 .3451 m .52707 .34508 L .52706 .34511 L F
.52969 .34457 m .53131 .34426 L .53131 .34426 L F
.52643 .34519 m .52969 .34457 L .52969 .34457 L F
.52969 .34457 m .53131 .34426 L .52969 .34457 L F
.52632 .34511 m .52721 .34482 L .52719 .34486 L F
.52633 .34513 m .52671 .34491 L .52633 .34513 L F
.52633 .34512 m .52681 .34484 L .5263 .3451 L F
.52631 .3451 m .52662 .345 L .52632 .34511 L F
.52662 .345 m .52721 .34482 L .52663 .34501 L F
.52662 .345 m .52663 .34501 L .52632 .34511 L F
.52633 .34513 m .52671 .34491 L .5267 .34491 L F
.52587 .34462 m .52587 .34456 L .52587 .34462 L F
.52594 .34465 m .52628 .34493 L .52578 .34444 L F
.52593 .34465 m .52669 .34502 L .52658 .345 L F
.52592 .3453 m .52563 .3455 L .52593 .34524 L F
.52289 .34723 m .52479 .34613 L .52478 .34613 L F
.52254 .34749 m .52249 .34746 L .52576 .34549 L F
.52289 .34723 m .52579 .34554 L .52281 .34724 L F
.52579 .34554 m .52577 .34554 L .52281 .34724 L F
.52459 .34613 m .52471 .34613 L .5249 .34602 L F
.52459 .34613 m .5249 .34602 L .52493 .34594 L F
.52374 .34671 m .52494 .34587 L .52491 .34592 L F
.52073 .34822 m .52471 .34613 L .52459 .34613 L F
.52289 .34723 m .52482 .34613 L .52479 .34613 L F
.52563 .3455 m .51312 .35415 L .52557 .34549 L F
.52563 .3455 m .52557 .34549 L .52593 .34524 L F
.51354 .3475 m .5209 .34615 L .5209 .34614 L F
.52323 .34545 m .52285 .34552 L .52324 .34546 L F
.52594 .34534 m .52548 .34467 L .52548 .34466 L F
.5229 .34593 m .52604 .34504 L .5229 .34593 L F
.51354 .3475 m .52401 .34562 L .524 .34558 L F
.52561 .34493 m .5258 .34531 L .52564 .34493 L F
.52561 .34493 m .52564 .34493 L .52548 .34457 L F
.52548 .34466 m .52548 .34467 L .52545 .34463 L F
.52548 .34466 m .52548 .34466 L .52545 .34463 L F
.52545 .34463 m .52561 .34493 L .52548 .34457 L F
.52285 .34552 m .51354 .3475 L .52234 .34587 L F
.52602 .34298 m .52427 .33247 L p .52582 .34321 L F P
0 g
s
.5257 .343 m .52571 .34299 L .52551 .34152 L .672 .728 .891 r
F
.5252 .34249 m .52556 .34194 L .52551 .34152 L F
.52586 .34406 m .52594 .34403 L .52427 .33247 L F
.52427 .33247 m .52602 .34298 L p .52548 .34268 L F P
0 g
s
.52577 .34313 m .52595 .34282 L .52548 .3324 L .672 .728 .891 r
F
.52575 .34329 m .52575 .34329 L .52571 .34299 L F
.52618 .34396 m .52602 .34298 L p .52612 .34402 L F P
0 g
s
.52593 .34463 m .52669 .34502 L .52595 .34466 L .672 .728 .891 r
F
.52611 .34486 m .52611 .34486 L .52598 .34486 L F
.52611 .345 m .52602 .34504 L .52608 .34498 L F
.52614 .3449 m .52608 .34498 L .52618 .34482 L F
.526 .34508 m .52616 .34492 L .52587 .34456 L F
.52593 .34463 m .52595 .34466 L .52593 .34465 L F
.52593 .34463 m .52595 .34466 L .52593 .34463 L F
.53487 .35036 m .53095 .3477 L .53164 .34899 L F
.53095 .3477 m .52709 .3451 L .53068 .34817 L F
.53095 .3477 m .53068 .34817 L .53164 .34899 L F
.52604 .34399 m .52606 .34396 L .52604 .34397 L F
.52621 .34498 m .52607 .344 L .52604 .34399 L F
.52607 .344 m .52606 .34396 L .52604 .34399 L F
.52863 .34441 m .52617 .34493 L .52863 .34441 L F
.52869 .3444 m .52617 .34493 L .52869 .3444 L F
.52769 .3447 m .52766 .34471 L .52775 .34469 L F
.52767 .34476 m .5276 .34472 L .52872 .3444 L F
.52981 .34424 m .52979 .34425 L .53012 .34419 L F
.53001 .34416 m .53012 .34419 L .53999 .34262 L F
.53923 .34267 m .53814 .34288 L .53999 .34262 L F
.54422 .34099 m .53341 .34354 L p .53488 .34297 L F P
0 g
s
.53488 .34297 m .53814 .34288 L .53923 .34267 L .672 .728 .891 r
F
.5322 .34383 m .53356 .3433 L .53488 .34297 L F
.53488 .34297 m .53356 .3433 L .53385 .34319 L F
.53488 .34297 m .52968 .34407 L .53814 .34288 L F
.52968 .34407 m .53001 .34416 L .53999 .34262 L F
.53012 .34419 m .53034 .34425 L .53999 .34262 L F
.5274 .34463 m .53034 .34425 L .53012 .34419 L F
.53488 .34297 m .53999 .34262 L .54457 .34177 L F
.53976 .34257 m .5295 .34454 L .52872 .3444 L F
.52691 .34504 m .53093 .34426 L .53092 .34427 L F
.53083 .34432 m .52976 .34452 L .53092 .34427 L F
.53076 .34437 m .52976 .34452 L .53083 .34432 L F
.53076 .34437 m .52841 .34481 L .52976 .34452 L F
.52841 .34481 m .52846 .34476 L .53092 .34427 L F
.53078 .34437 m .52941 .34463 L p .53086 .34435 L F P
0 g
s
.52941 .34463 m .52943 .34462 L .53086 .34435 L .672 .728 .891 r
F
.52848 .34474 m .52848 .34473 L .53093 .34426 L F
.52771 .34456 m .52838 .34474 L .53377 .34415 L F
.52851 .34486 m .5279 .34476 L .52881 .3445 L F
.52794 .34479 m .52835 .34488 L .53377 .34415 L F
.53132 .34423 m .53879 .34286 L .53873 .34287 L F
.53132 .34423 m .53879 .34286 L .53132 .34423 L F
.53131 .34426 m .53131 .34426 L .5389 .34283 L F
.52869 .3444 m .52863 .34441 L .52863 .34441 L F
.52872 .3444 m .52869 .3444 L .52869 .3444 L F
.5295 .34454 m .5287 .3444 L .52872 .3444 L F
.53879 .34286 m .53078 .34437 L p .5389 .34283 L F P
0 g
s
.53078 .34437 m .53086 .34435 L .5389 .34283 L .672 .728 .891 r
F
.53092 .34427 m .53093 .34426 L .53976 .34257 L F
.5389 .34283 m .53076 .34437 L .53976 .34257 L F
.53076 .34437 m .53092 .34427 L .53976 .34257 L F
.53148 .34394 m .52771 .34456 L .53377 .34415 L F
.53377 .34415 m .54485 .34257 L p .53148 .34394 L F P
0 g
s
.54485 .34257 m .52848 .3449 L p .52881 .3445 L .672 .728 .891 r
F P
0 g
s
.52771 .34456 m .52725 .34464 L .52838 .34474 L .672 .728 .891 r
F
.52805 .34462 m .52753 .3447 L .52818 .34457 L F
.52753 .3447 m .52756 .34467 L .52818 .34457 L F
.52737 .34467 m .52728 .34468 L .52729 .34468 L F
.52725 .34464 m .52784 .34477 L .52838 .34474 L F
.52753 .34465 m .5274 .34467 L .52737 .34467 L F
.52818 .34457 m .52757 .34467 L .52753 .34465 L F
.52881 .3445 m .52805 .34462 L .52818 .34457 L F
.52881 .3445 m .52729 .34468 L .53029 .34482 L F
.52654 .34492 m .5288 .34372 L .52647 .34492 L F
.52766 .34435 m .52683 .3449 L p .52762 .34413 L F P
0 g
s
.52681 .34476 m .52773 .34429 L .52777 .34412 L .672 .728 .891 r
F
.52751 .34441 m .5275 .34441 L .52602 .3452 L F
.52683 .3449 m .52682 .34482 L .52762 .34413 L F
.52681 .34484 m .52773 .34429 L .52681 .34476 L F
.52831 .34396 m .52718 .34441 L .52872 .34337 L F
.52699 .34439 m .52735 .3444 L .52879 .34357 L F
.53978 .33616 m .52766 .34435 L p .52762 .34413 L F P
0 g
s
.5261 .34485 m .52631 .34492 L .52625 .34492 L .672 .728 .891 r
F
.52581 .34528 m .52579 .34527 L .52632 .34511 L F
.52579 .34527 m .52582 .34525 L .52632 .34511 L F
.5259 .34547 m .52602 .34521 L .526 .34508 L F
.52589 .34518 m .526 .34508 L .52587 .34456 L F
.52459 .34542 m .52575 .34527 L .52454 .34539 L F
.52575 .34527 m .52638 .34519 L .52573 .34526 L F
.52575 .34527 m .52573 .34526 L .52454 .34539 L F
.526 .34471 m .52623 .3449 L .526 .34469 L F
.52623 .3449 m .52657 .34517 L .52625 .3449 L F
.52623 .3449 m .52625 .3449 L .526 .34469 L F
.52612 .34496 m .52613 .34494 L .52619 .3449 L F
.5262 .3449 m .52619 .3449 L .52641 .34475 L F
.52612 .34496 m .52619 .3449 L .5262 .3449 L F
.5263 .34509 m .5263 .3451 L .52658 .34491 L F
.52582 .34525 m .52595 .34512 L .52626 .34505 L F
.5259 .34547 m .52592 .34536 L .52589 .34534 L F
.52588 .34539 m .52597 .34534 L .52588 .3454 L F
.52597 .34534 m .52766 .34435 L .52597 .34534 L F
.52597 .34534 m .52597 .34534 L .52588 .3454 L F
.52582 .34525 m .52626 .34505 L .52631 .3451 L F
.52582 .34525 m .52631 .3451 L .52632 .34511 L F
.52607 .34511 m .52599 .34527 L .5263 .34509 L F
.52588 .34539 m .52633 .34513 L .52633 .34513 L F
.52642 .34497 m .52644 .34497 L .52575 .34517 L F
.52575 .34516 m .52575 .34517 L .52562 .3452 L F
.52642 .34497 m .52575 .34517 L .52575 .34516 L F
.51312 .35415 m .51273 .35388 L p .52162 .34806 L F P
0 g
s
.5256 .34551 m .5257 .34545 L .52513 .34569 L .672 .728 .891 r
F
.52281 .34724 m .52322 .34701 L .52329 .34697 L F
.52322 .34701 m .52474 .34613 L .52329 .34697 L F
.52329 .34697 m .52474 .34613 L .52471 .34613 L F
.523 .34721 m .52482 .34613 L p .52289 .34723 L F P
0 g
s
.52593 .34524 m .52178 .34812 L .52162 .34806 L .672 .728 .891 r
F
.52178 .34812 m .51312 .35415 L .52162 .34806 L F
.52559 .34454 m .52602 .34504 L .52557 .34457 L F
.52584 .34535 m .52568 .34441 L .52568 .34442 L F
.52587 .34552 m .52588 .3455 L .52583 .34523 L F
.5259 .34557 m .52587 .34533 L .52586 .34533 L F
.52562 .34554 m .52594 .34538 L .52588 .34539 L F
.52594 .34538 m .52598 .34535 L .52595 .34537 L F
.52594 .34538 m .52595 .34537 L .52588 .34539 L F
.52587 .34552 m .52584 .34535 L .52584 .34535 L F
.52588 .34555 m .52587 .34552 L .52587 .34552 L F
.52587 .34552 m .52584 .34535 L .52587 .34552 L F
.52534 .34507 m .52602 .34504 L .52606 .34499 L F
.52486 .34512 m .52537 .34509 L .52534 .34507 L F
.52537 .34509 m .52602 .34504 L .52534 .34507 L F
.52584 .34535 m .52584 .34532 L .52584 .34535 L F
.52584 .34532 m .52568 .34441 L .52584 .34532 L F
.52584 .34532 m .52584 .34532 L .52584 .34535 L F
.52522 .34427 m .52593 .34463 L .52593 .34465 L F
.52522 .34427 m .52542 .3443 L .52587 .34456 L F
.52588 .34457 m .52587 .34456 L .52593 .34459 L F
.52583 .34531 m .52567 .3444 L .52564 .34443 L F
.52522 .34427 m .52587 .34456 L .52588 .34457 L F
.52538 .34394 m .52556 .34452 L .5255 .3441 L F
.52538 .34394 m .5255 .3441 L .52548 .3439 L F
.52522 .34427 m .52593 .34459 L .52593 .34463 L F
.52505 .34433 m .52603 .34475 L .5261 .34485 L F
.52576 .34455 m .52573 .34433 L .52575 .34454 L F
.52587 .34456 m .5255 .34435 L .52581 .34448 L F
.52587 .34462 m .52587 .34462 L .52588 .34519 L F
.52586 .34533 m .52576 .34455 L .52575 .34454 L F
.52328 .34578 m .52328 .34578 L .52364 .34571 L F
.52363 .34571 m .52364 .34571 L .52643 .34518 L F
.52178 .34625 m .5217 .34624 L .52396 .34561 L F
.52328 .34578 m .52364 .34571 L .52363 .34571 L F
.52574 .3433 m .52571 .34299 L .5257 .343 L F
.52562 .34471 m .52588 .34555 L .52571 .34477 L F
.52562 .34471 m .52571 .34477 L .52564 .34443 L F
.52556 .34452 m .52562 .34471 L .52564 .34443 L F
.52541 .34455 m .52545 .34463 L .52548 .34457 L F
.52537 .34471 m .52505 .34426 L .52504 .34426 L F
.52586 .34487 m .52503 .34434 L p .52608 .34491 L F P
0 g
s
.52503 .34434 m .52503 .34434 L .52608 .34491 L .672 .728 .891 r
F
.52607 .34511 m .5263 .34509 L .52626 .34504 L F
.52628 .34493 m .52628 .34493 L .526 .34469 L F
.52762 .34413 m .52649 .34491 L .52643 .34491 L F
.52593 .34468 m .52593 .34468 L .52685 .34521 L F
.52611 .34486 m .52658 .34491 L .52743 .34435 L F
.52582 .34524 m .52567 .3444 L .52582 .34525 L F
.52583 .34524 m .52583 .34523 L .52568 .34441 L F
.52615 .34491 m .52567 .34499 L .52611 .34485 L F
.52631 .3451 m .52626 .34505 L .52721 .34482 L F
.52626 .34504 m .5263 .34509 L .52658 .34491 L F
.52625 .34503 m .52644 .34497 L .52626 .34505 L F
.52641 .34497 m .52624 .34501 L .52624 .34501 L F
.52639 .3452 m .52658 .34507 L .52661 .34512 L F
.52608 .34491 m .52661 .34509 L .52651 .34514 L F
.52582 .34525 m .52567 .3444 L .52567 .3444 L F
.52505 .34433 m .52631 .34495 L .52608 .34491 L F
.52644 .34497 m .52649 .34498 L .52626 .34505 L F
.52641 .34497 m .52642 .34497 L .52624 .34501 L F
.52681 .34485 m .52681 .34485 L .52681 .34485 L F
.52591 .34467 m .52685 .34521 L .52685 .34522 L F
.52534 .34434 m .52591 .34467 L .52591 .34467 L F
.52701 .34429 m .52594 .34505 L .52694 .34429 L F
.52591 .34467 m .52685 .34521 L .52591 .34467 L F
.52641 .34497 m .52617 .34492 L .52725 .34474 L F
.52616 .34492 m .52617 .34492 L .52641 .34497 L F
.52532 .34434 m .52641 .34497 L .5264 .34496 L F
.52611 .34498 m .52617 .34493 L .52611 .34499 L F
.52602 .34504 m .52625 .34502 L .52606 .34499 L F
.52611 .34494 m .52606 .34499 L .52621 .34497 L F
.52611 .34498 m .52611 .345 L .52608 .34498 L F
.52606 .34499 m .52621 .34498 L .52621 .34497 L F
.526 .34508 m .52616 .34492 L .52641 .34497 L F
.526 .34471 m .52706 .34557 L .52706 .34557 L F
.52631 .34495 m .52661 .34509 L .52608 .34491 L F
.52639 .3452 m .52626 .34472 L p .52622 .34499 L F P
0 g
s
.52593 .34463 m .52593 .34459 L .52669 .34502 L .672 .728 .891 r
F
.52592 .34446 m .52592 .34444 L .5268 .3449 L F
.5259 .3446 m .52575 .34329 L .52574 .3433 L F
.52642 .34497 m .52685 .34522 L .52642 .34497 L F
.52567 .34499 m .52594 .34488 L .52599 .34489 L F
.52594 .34493 m .52596 .34493 L .52596 .34492 L F
.52602 .34521 m .52616 .34492 L .526 .34508 L F
.52636 .34558 m .52635 .34521 L .5263 .34521 L F
.52636 .34558 m .5263 .34521 L .5263 .34521 L F
.52635 .34522 m .52651 .34562 L .52624 .3453 L F
.5263 .34554 m .5262 .34485 L .5263 .34554 L F
.52593 .34393 m .52624 .34479 L p .52584 .34389 L F P
0 g
s
.5259 .3443 m .52679 .34492 L .52679 .34492 L .672 .728 .891 r
F
.52538 .34394 m .5259 .3443 L .5259 .3443 L F
.5259 .3443 m .52679 .34492 L .5259 .3443 L F
.5262 .34485 m .5262 .34485 L .5263 .34554 L F
.52576 .34514 m .52582 .34497 L .52616 .34492 L F
.52596 .34493 m .52613 .34499 L .52616 .34492 L F
.52613 .34499 m .52626 .34504 L .52616 .34492 L F
.52596 .34493 m .52626 .34504 L .52596 .34493 L F
.52599 .34527 m .52597 .34531 L .5263 .3451 L F
.526 .34508 m .52641 .34497 L .526 .34508 L F
.52613 .34499 m .52607 .34511 L .52626 .34504 L F
.5259 .34557 m .52587 .3452 L .52585 .34522 L F
.52588 .3454 m .52596 .34535 L .52581 .34542 L F
.52596 .34535 m .52681 .34484 L .52596 .34533 L F
.52596 .34535 m .52596 .34533 L .52581 .34542 L F
.52638 .34519 m .52637 .34518 L .52453 .34539 L F
.52454 .34539 m .52453 .34539 L .52437 .34541 L F
.52638 .34519 m .52453 .34539 L .52454 .34539 L F
.52581 .34542 m .52611 .34525 L .52611 .34522 L F
.52611 .34525 m .52633 .34512 L .52611 .34522 L F
.52611 .34522 m .52633 .34512 L .5263 .3451 L F
.52587 .34553 m .5259 .34553 L .5259 .34553 L F
.52618 .34557 m .52647 .34605 L .52587 .34552 L F
.52639 .3452 m .5259 .34553 L p .52635 .34516 L F P
0 g
s
.5259 .34553 m .52639 .3452 L p .52593 .34541 L .672 .728 .891 r
F P
0 g
s
.52655 .34617 m .52611 .34551 L .52617 .34551 L .672 .728 .891 r
F
.52618 .34586 m .52617 .34496 L .52602 .34521 L F
.52632 .34655 m .52663 .34674 L .52612 .34524 L F
.52647 .34605 m .52643 .34617 L .52602 .34599 L F
.52632 .34646 m .52625 .3458 L .52618 .34586 L F
.5265 .34606 m .52618 .34552 L .52619 .34552 L F
.52625 .3458 m .52617 .34496 L .52618 .34586 L F
.52639 .3452 m .52586 .34487 L p .52621 .34498 L F P
0 g
s
.52633 .34569 m .52639 .3452 L .52622 .34499 L .672 .728 .891 r
F
.52629 .34514 m .52629 .34514 L .52639 .3452 L F
.52597 .34528 m .5263 .3451 L .5263 .34509 L F
.5262 .34525 m .52621 .34498 L .52616 .34492 L F
.52625 .3458 m .52622 .34525 L .5262 .34525 L F
.52622 .34525 m .52621 .34498 L .5262 .34525 L F
.52596 .34492 m .52629 .34514 L .52629 .34514 L F
.52576 .34514 m .52616 .34492 L .52616 .34492 L F
.52576 .34514 m .52617 .34492 L .526 .34508 L F
.52594 .34493 m .52607 .34511 L .52613 .34499 L F
.52596 .34493 m .52629 .34514 L p .52596 .34492 L F P
0 g
s
.52617 .34496 m .52615 .34496 L .52602 .34521 L .672 .728 .891 r
F
.52594 .34493 m .52596 .34493 L .52596 .34493 L F
.5256 .34531 m .52535 .34527 L .52595 .34512 L F
.52594 .34493 m .52525 .34542 L .52607 .34511 L F
.52595 .34495 m .52595 .34509 L .52594 .34493 L F
.52596 .34492 m .52595 .34495 L .52594 .34493 L F
.52617 .34492 m .52499 .3451 L .52618 .3449 L F
.5259 .34487 m .52313 .34548 L .52587 .34487 L F
.52313 .34548 m .52127 .34588 L .52313 .34547 L F
.52313 .34548 m .52313 .34547 L .52587 .34487 L F
.5262 .3445 m .52588 .34436 L .526 .34436 L F
.52592 .3443 m .5259 .3443 L .52706 .34511 L F
.5268 .3449 m .52588 .34436 L .5262 .3445 L F
.5268 .3449 m .52577 .34435 L .52588 .34436 L F
.5262 .34485 m .52606 .34395 L .5262 .34485 L F
.52619 .34437 m .52603 .34423 L .52622 .3443 L F
.52626 .34472 m .52606 .34396 L p .5262 .34485 L F P
0 g
s
.52606 .34396 m .52606 .34395 L p .52606 .34396 L .672 .728 .891 r
F P
0 g
s
.5262 .34485 m .52606 .34396 L .52606 .34396 L .672 .728 .891 r
F
.52622 .34499 m .52626 .34472 L .5262 .34485 L F
.5261 .34485 m .52603 .34475 L .52631 .34492 L F
.52479 .34419 m .52532 .34434 L .52505 .34433 L F
.52564 .34443 m .52561 .34423 L .52559 .3442 L F
.5251 .34405 m .52567 .3443 L .52571 .34436 L F
.52556 .34452 m .52559 .3442 L .52553 .34414 L F
.52599 .3447 m .52518 .34401 L .52517 .34401 L F
.52521 .34426 m .52522 .34427 L .52535 .34434 L F
.52521 .34426 m .52535 .34434 L .52534 .34434 L F
.5255 .34435 m .52391 .34345 L .5257 .34435 L F
.52555 .34416 m .52507 .34437 L .52569 .34433 L F
.52523 .3443 m .52541 .3444 L .52523 .3443 L F
.52657 .34464 m .52646 .34468 L .52757 .34389 L F
.52594 .34489 m .52608 .34491 L .52621 .34498 L F
.52608 .34492 m .52608 .34492 L .52596 .34492 L F
.52596 .34493 m .52608 .34492 L .52596 .34492 L F
.52609 .34491 m .52595 .34509 L .52596 .34492 L F
.52579 .34527 m .52577 .34526 L .52582 .34525 L F
.52588 .3455 m .52585 .34522 L .52583 .34523 L F
.5259 .34557 m .52589 .34549 L .52588 .3455 L F
.52589 .34549 m .52585 .34522 L .52588 .3455 L F
.52564 .34549 m .52597 .34531 L .52597 .34528 L F
.52588 .34555 m .52582 .34524 L .52582 .34525 L F
.52588 .34555 m .52583 .34523 L .52583 .34524 L F
.52529 .34559 m .52521 .34561 L .52594 .34512 L F
.52478 .3459 m .52594 .3451 L .52594 .34512 L F
.52525 .34542 m .52564 .34549 L .52599 .34527 L F
.52589 .34534 m .526 .34508 L .52589 .34518 L F
.52592 .34536 m .526 .34508 L .52589 .34534 L F
.52589 .34529 m .52589 .34518 L .52588 .34529 L F
.52589 .34529 m .52588 .34529 L .52588 .34534 L F
.52589 .34534 m .52589 .34529 L .52588 .34534 L F
.52414 .34606 m .52414 .34607 L .52603 .34517 L F
.52589 .34518 m .52588 .34519 L .52588 .34534 L F
.52572 .34526 m .52585 .34524 L .52567 .34524 L F
.5209 .34614 m .52234 .34588 L .52234 .34588 L F
.52369 .34565 m .51252 .3478 L .5239 .34541 L F
.52285 .34552 m .52326 .34547 L .52324 .34546 L F
.52326 .34547 m .52598 .34509 L .52324 .34546 L F
.52499 .34518 m .51252 .3478 L .52511 .34504 L F
.52123 .34586 m .52578 .34529 L .52575 .34527 L F
.50827 .34861 m .51267 .34778 L p .51354 .3475 L F P
0 g
s
.52516 .34498 m .51252 .3478 L .50797 .34782 L .672 .728 .891 r
F
.51483 .34669 m .52124 .34587 L .52123 .34586 L F
.52124 .34587 m .52578 .34529 L .52123 .34586 L F
.52364 .34571 m .52583 .34526 L .52581 .34528 L F
.5257 .3453 m .5256 .34531 L p .52572 .34528 L F P
0 g
s
.52411 .34561 m .52573 .34527 L .52575 .34528 L .672 .728 .891 r
F
.5257 .3453 m .52572 .34528 L .52577 .34526 L F
.52581 .34528 m .5257 .3453 L p .52577 .34526 L F P
0 g
s
.52577 .34526 m .52595 .34512 L .52582 .34525 L .672 .728 .891 r
F
.5256 .34531 m .52572 .34525 L .52577 .34526 L F
.52584 .34531 m .52567 .3444 L .52583 .34531 L F
.52572 .34525 m .52595 .34512 L .52577 .34526 L F
.52525 .34542 m .52599 .34527 L .52607 .34511 L F
.52594 .34502 m .52551 .34552 L .52594 .34493 L F
.52595 .34509 m .52552 .34551 L .52594 .34502 L F
.52503 .34434 m .52505 .34433 L .52621 .34498 L F
.52502 .34433 m .52502 .34433 L .52503 .34434 L F
.52502 .34433 m .52505 .34433 L .52503 .34434 L F
.5265 .34606 m .52619 .34552 L .52619 .34552 L F
.5265 .34606 m .52649 .34607 L .52618 .34552 L F
.52678 .3472 m .52704 .34739 L .52656 .34668 L F
.52636 .34638 m .52678 .3472 L .52656 .34668 L F
.52669 .34676 m .52755 .34846 L .52636 .34665 L F
.5265 .34606 m .52655 .34617 L .52649 .34607 L F
.52768 .34984 m .52639 .34567 L .52625 .34563 L F
.52755 .34822 m .52697 .34719 L .52698 .34715 L F
.52697 .34719 m .5265 .34638 L .52698 .34715 L F
.52698 .34715 m .5265 .34638 L .52653 .34628 L F
.52632 .34655 m .52768 .34984 L .52663 .34674 L F
.52617 .34648 m .52704 .34699 L .52667 .34806 L F
.52602 .34599 m .52677 .34654 L .52617 .34648 L F
.52588 .34555 m .52653 .34762 L .52622 .34603 L F
.52653 .34762 m .52678 .34842 L .52657 .34752 L F
.52653 .34762 m .52657 .34752 L .52622 .34603 L F
.5259 .34557 m .52612 .34563 L .52602 .34521 L F
.52633 .34569 m .5263 .34554 L .5263 .34554 L F
.5259 .34557 m .52622 .34603 L .52612 .34563 L F
.5265 .34564 m .52614 .34607 L .52594 .34544 L F
.52503 .34434 m .52502 .34433 L p .52503 .34434 L F P
0 g
s
.52538 .34394 m .52346 .34264 L .52536 .34394 L .672 .728 .891 r
F
.52366 .34324 m .52352 .34313 L p .52372 .34325 L F P
0 g
s
.51344 .33587 m .52366 .34324 L p .52346 .34264 L .672 .728 .891 r
F P
0 g
s
.52538 .34394 m .52145 .34207 L .52335 .34257 L .672 .728 .891 r
F
.52145 .34207 m .51258 .33645 L p .52335 .34257 L F P
0 g
s
.51258 .33645 m .52477 .34418 L p .52397 .34327 L .672 .728 .891 r
F P
0 g
s
.52479 .34419 m .52518 .34426 L .52532 .34434 L .672 .728 .891 r
F
.52502 .34433 m .52479 .34419 L p .52505 .34433 L F P
0 g
s
.52516 .34429 m .52479 .34409 L .52503 .34434 L .672 .728 .891 r
F
.52555 .34416 m .52479 .34409 L .52516 .34429 L F
.52517 .34401 m .52518 .34401 L .52465 .34357 L F
.52567 .3443 m .52145 .34207 L .52552 .34412 L F
.52376 .34342 m .52522 .34427 L .52521 .34426 L F
.52532 .34434 m .52376 .34342 L .52534 .34434 L F
.52391 .34345 m .52515 .34403 L .5251 .34405 L F
.52552 .34412 m .52145 .34207 L .52538 .34394 L F
.52555 .34416 m .52387 .34316 L .52479 .34409 L F
.52477 .34418 m .52503 .34434 L p .52387 .34316 L F P
0 g
s
.52496 .34441 m .51179 .33707 L p .52535 .3444 L .672 .728 .891 r
F P
0 g
s
.52383 .34358 m .52385 .34358 L .52541 .3444 L .672 .728 .891 r
F
.52848 .3449 m .5279 .34476 L .52851 .34486 L F
.52721 .34482 m .52725 .34474 L .52805 .34462 L F
.52764 .34472 m .52749 .34478 L .52784 .34477 L F
.52639 .3452 m .52805 .34462 L .52881 .3445 L F
.52862 .34498 m .53029 .34482 L p .52729 .34468 L F P
0 g
s
.52723 .34497 m .52736 .34486 L .53141 .34441 L .672 .728 .891 r
F
.52862 .34498 m .52877 .34476 L .53141 .34441 L F
.53029 .34482 m .54506 .34337 L p .52881 .3445 L F P
0 g
s
.53081 .34477 m .53022 .34465 L .53125 .34451 L .672 .728 .891 r
F
.53081 .34477 m .52862 .34498 L p .53022 .34465 L F P
0 g
s
.53141 .34441 m .52895 .34468 L .52907 .34459 L .672 .728 .891 r
F
.54506 .34337 m .53081 .34477 L p .53141 .34441 L F P
0 g
s
.52946 .34504 m .53296 .34485 L p .52972 .34454 L .672 .728 .891 r
F P
0 g
s
.53066 .34465 m .52949 .3448 L .52941 .3447 L .672 .728 .891 r
F
.52608 .34492 m .52616 .34492 L .52608 .34492 L F
.52617 .34496 m .52616 .34492 L .52615 .34496 L F
.52616 .34491 m .52596 .34492 L .52639 .3452 L F
.5263 .34554 m .52622 .34499 L .52621 .34498 L F
.52658 .34573 m .52635 .34522 L .52637 .34521 L F
.52639 .3452 m .52649 .34559 L p .52609 .34498 L F P
0 g
s
.52599 .34489 m .5261 .34484 L .52611 .34485 L .672 .728 .891 r
F
.52608 .34482 m .52594 .34493 L .5261 .34485 L F
.52599 .34489 m .526 .34486 L .5261 .34484 L F
.52594 .34488 m .526 .34486 L .52599 .34489 L F
.52596 .34492 m .52616 .34492 L .52611 .34486 L F
.52648 .34475 m .52665 .34461 L .52677 .34456 L F
.5261 .34485 m .52743 .34435 L .5271 .34436 L F
.52599 .34489 m .52611 .34485 L .52611 .34485 L F
.52594 .34493 m .52611 .34486 L .5261 .34485 L F
.52644 .34475 m .52644 .34475 L .52665 .34461 L F
.52611 .34486 m .52743 .34435 L .5261 .34485 L F
.526 .34471 m .52594 .34465 L .52599 .3447 L F
.52643 .34497 m .52522 .34427 L .52658 .345 L F
.52611 .34485 m .52627 .3448 L .52628 .3448 L F
.52521 .34426 m .52642 .34497 L .52642 .34497 L F
.52638 .34496 m .52532 .34434 L .5264 .34496 L F
.52567 .3444 m .52547 .3433 L .52564 .34443 L F
.5255 .34435 m .5257 .34435 L .52571 .34436 L F
.52581 .34448 m .52571 .34436 L .5268 .3449 L F
.52571 .34436 m .52571 .34435 L .52568 .34441 L F
.52556 .34452 m .52564 .34443 L .52559 .3442 L F
.52568 .34442 m .52568 .34441 L .52547 .34329 L F
.52575 .34454 m .52573 .34433 L .52572 .34434 L F
.5255 .34435 m .52571 .34436 L .52581 .34448 L F
.52572 .34434 m .52571 .34435 L .52571 .34436 L F
.52621 .34498 m .526 .34374 L .52587 .34456 L F
.52611 .34485 m .52627 .3448 L .52611 .34485 L F
.52608 .34482 m .52609 .34491 L .52596 .34492 L F
.52594 .34488 m .52608 .34491 L .52594 .34489 L F
.52595 .34487 m .52596 .34492 L .52616 .34491 L F
.52613 .3449 m .52591 .34488 L .52614 .34493 L F
.52608 .34482 m .52595 .34487 L .52613 .3449 L F
.52595 .34487 m .52591 .34488 L .52613 .3449 L F
.52593 .34469 m .52593 .34468 L .52601 .34473 L F
.52593 .34469 m .52601 .34473 L .52602 .34474 L F
.52594 .34465 m .52595 .34487 L .52616 .34491 L F
.52616 .34491 m .52609 .34498 L .52584 .3446 L F
.52616 .34492 m .52658 .34491 L .52619 .34487 L F
.52618 .3449 m .52615 .34491 L .52628 .34481 L F
.52618 .3449 m .52628 .34481 L .52628 .34481 L F
.52627 .3448 m .52639 .3452 L .52619 .34488 L F
.52628 .34479 m .52628 .34481 L p .52627 .3448 L F P
0 g
s
.52625 .34492 m .52631 .34492 L .52661 .34509 L .672 .728 .891 r
F
.52628 .34481 m .52639 .3452 L p .52627 .3448 L F P
0 g
s
.52628 .34481 m .52628 .34481 L .52629 .3448 L .672 .728 .891 r
F
.52628 .3448 m .52627 .3448 L .52629 .3448 L F
.52618 .34491 m .52639 .3452 L .52627 .34491 L F
.52661 .34473 m .52642 .34491 L .52628 .34468 L F
.52616 .34492 m .52619 .34487 L .52611 .34486 L F
.52616 .34492 m .52616 .34492 L .52617 .34492 L F
.52621 .34486 m .52616 .34491 L .52678 .34505 L F
.52611 .34485 m .5261 .34484 L .52627 .3448 L F
.52615 .34491 m .52611 .34485 L .52628 .3448 L F
.52628 .34481 m .52628 .3448 L .52629 .3448 L F
.52615 .34491 m .52628 .3448 L .52628 .34481 L F
.52622 .34499 m .52607 .344 L .52621 .34498 L F
.52607 .344 m .52606 .34395 L .52607 .344 L F
.52607 .344 m .52607 .344 L .52621 .34498 L F
.52862 .34498 m .52825 .34483 L .52868 .3449 L F
.52959 .34478 m .5279 .34488 L .52946 .34504 L F
.52638 .34496 m .5264 .34496 L .52685 .34522 L F
.52657 .34517 m .52678 .34534 L .52657 .34517 L F
.52651 .34514 m .52661 .34509 L .53017 .34718 L F
.52632 .34495 m .52687 .34551 L .52652 .34499 L F
.52661 .34512 m .52666 .34501 L .52684 .34504 L F
.52658 .345 m .52669 .34502 L .52835 .34595 L F
.52597 .34528 m .52597 .34531 L .52599 .34527 L F
.52595 .34535 m .52612 .34487 L .52615 .34491 L F
.52608 .34482 m .52614 .34493 L .52616 .34491 L F
.52608 .34482 m .52616 .34491 L .52621 .34486 L F
.52595 .34535 m .52595 .34509 L .52612 .34487 L F
.52608 .34482 m .5261 .34485 L .5271 .34436 L F
.52629 .3448 m .52506 .34504 L .52517 .34493 L F
.52617 .34481 m .52608 .34482 L .52615 .34484 L F
.52617 .34481 m .52615 .34484 L .52678 .34505 L F
.52615 .34491 m .52612 .34487 L .52622 .34476 L F
.52538 .34394 m .52536 .34394 L .52679 .34492 L F
.52592 .3443 m .52538 .34394 L .5259 .3443 L F
.526 .34436 m .52552 .34412 L .52538 .34394 L F
.52553 .34414 m .52559 .3442 L .52552 .34389 L F
.52548 .3439 m .52552 .34389 L .52541 .34338 L F
.52567 .3444 m .52547 .34329 L .52567 .3444 L F
.52568 .34441 m .52562 .34386 L .52558 .34387 L F
.52561 .34423 m .52547 .3433 L .52559 .3442 L F
.52544 .34364 m .5258 .34423 L .52555 .34416 L F
.5262 .34478 m .52609 .34491 L .52608 .34482 L F
.52587 .34456 m .52581 .34448 L .52592 .34453 L F
.52572 .34434 m .52572 .34433 L .52571 .34435 L F
.52571 .34436 m .52592 .34444 L .52592 .34446 L F
.52581 .34448 m .52587 .34456 L .52579 .34419 L F
.5258 .34423 m .52639 .3452 L .52569 .34433 L F
.52572 .34433 m .52555 .34317 L .52568 .34441 L F
.52567 .3443 m .52552 .34412 L .526 .34436 L F
.52573 .34433 m .52579 .34419 L .52573 .34431 L F
.52579 .34426 m .52579 .34419 L .52573 .34433 L F
.5258 .34423 m .52569 .34433 L .52555 .34416 L F
.52617 .34481 m .52678 .34505 L .52679 .34505 L F
.52835 .34595 m .52669 .34502 L .52707 .34508 L F
.5268 .34505 m .52679 .34505 L .52684 .34506 L F
.52617 .34481 m .52679 .34505 L .5268 .34505 L F
.52629 .3448 m .52617 .34481 L .52695 .3451 L F
.52627 .3448 m .52619 .34488 L .52618 .34485 L F
.52672 .34437 m .52608 .34482 L .52706 .34436 L F
.52624 .34471 m .5262 .34478 L .52608 .34482 L F
.52606 .34396 m .52606 .34395 L .52606 .34395 L F
.52606 .34396 m .52606 .34395 L .52604 .34397 L F
.52585 .34375 m .52588 .34379 L .52538 .34394 L F
.52573 .34431 m .52579 .34419 L .52562 .34346 L F
.52587 .34456 m .526 .34374 L .52579 .34419 L F
.52606 .34395 m .52628 .34479 L p .52544 .34364 L F P
0 g
s
.52628 .34468 m .52622 .34476 L .52624 .34471 L .672 .728 .891 r
F
.52622 .34476 m .5262 .34478 L .52624 .34471 L F
.52573 .34433 m .52562 .34346 L .52572 .34434 L F
.52623 .34474 m .5261 .34472 L .52544 .34364 L F
.52627 .3448 m .52621 .34477 L .52623 .34474 L F
.52621 .34477 m .5261 .34472 L .52623 .34474 L F
.52621 .34477 m .52618 .34485 L .5261 .34472 L F
.52631 .34494 m .52631 .34495 L .52594 .34455 L F
.52627 .3448 m .52618 .34485 L .52621 .34477 L F
.5261 .34505 m .52622 .34476 L .52628 .34468 L F
.52611 .34503 m .52603 .34503 L .52608 .34498 L F
.5268 .34492 m .52766 .34435 L p .52681 .34485 L F P
0 g
s
.52729 .34468 m .52618 .3449 L .52629 .3448 L .672 .728 .891 r
F
.52644 .34497 m .52725 .34474 L .52649 .34498 L F
.52671 .34491 m .52681 .34485 L .5267 .34491 L F
.52642 .34497 m .52725 .34474 L .52644 .34497 L F
.52641 .34497 m .52725 .34474 L .52642 .34497 L F
.52753 .3447 m .52617 .34492 L .52756 .34467 L F
.52617 .34492 m .52618 .3449 L .52748 .34469 L F
.52748 .34469 m .52748 .34469 L .52756 .34467 L F
.52617 .34492 m .52748 .34469 L .52748 .34469 L F
.52598 .34535 m .5268 .34492 L .52588 .34539 L F
.52646 .34558 m .52608 .34509 L .52611 .34503 L F
.526 .34531 m .5261 .34505 L .52616 .34492 L F
.52552 .34551 m .52552 .34551 L .52594 .34502 L F
.52595 .34535 m .52622 .34476 L .5261 .34505 L F
.52608 .34509 m .52603 .34503 L .52611 .34503 L F
.52639 .3452 m .52612 .345 L .52616 .34491 L F
.52612 .345 m .52609 .34498 L .52616 .34491 L F
.52541 .34545 m .52543 .34545 L .52478 .3459 L F
.52493 .34594 m .52583 .34547 L .52581 .34547 L F
.52479 .34613 m .52639 .3452 L .52478 .34613 L F
.52478 .34629 m .52459 .34622 L .52592 .3453 L F
.52127 .34588 m .51252 .3478 L .52128 .34587 L F
.52512 .34503 m .51252 .3478 L .52516 .34498 L F
.5133 .34706 m .52006 .3461 L p .51483 .34669 L F P
0 g
s
.52006 .3461 m .52578 .34529 L p .51994 .34604 L .672 .728 .891 r
F P
0 g
s
.51483 .34669 m .52006 .3461 L .51994 .34604 L .672 .728 .891 r
F
.52587 .3452 m .52579 .34426 L .52585 .34522 L F
.52594 .34493 m .52579 .34514 L .5258 .34503 L F
.52419 .34638 m .52521 .34561 L .52529 .34559 L F
.52475 .34601 m .52419 .34638 L .52476 .34598 L F
.52044 .34883 m .52479 .34587 L .52478 .3459 L F
.52479 .34587 m .5248 .34584 L .5254 .34544 L F
.52479 .34587 m .5254 .34544 L .52541 .34545 L F
.52044 .34883 m .5248 .34584 L .52479 .34587 L F
.52419 .34638 m .52044 .34883 L .52417 .34631 L F
.52254 .34749 m .51571 .35153 L p .52249 .34746 L F P
0 g
s
.51694 .35071 m .51571 .35153 L .51614 .35118 L .672 .728 .891 r
F
.51694 .35071 m .51614 .35118 L .519 .34878 L F
.5232 .34645 m .52323 .34643 L .52323 .34643 L F
.52371 .34616 m .51694 .35071 L .519 .34878 L F
.51611 .3512 m .52289 .34723 L .52281 .34724 L F
.51676 .35091 m .523 .34721 L p .51611 .3512 L F P
0 g
s
.51611 .3512 m .523 .34721 L .52289 .34723 L .672 .728 .891 r
F
.5254 .34544 m .52387 .34646 L .5252 .34539 L F
.52525 .34542 m .51876 .3501 L .5257 .3455 L F
.52579 .34514 m .52495 .34629 L .5258 .34503 L F
.5258 .34503 m .52495 .34629 L .52525 .34542 L F
.52585 .34522 m .52572 .34434 L .52583 .34523 L F
.52453 .34547 m .52582 .34497 L .52576 .34514 L F
.5258 .34486 m .52563 .34518 L .5259 .34516 L F
.52627 .34505 m .526 .34531 L .52616 .34492 L F
.52627 .34578 m .52621 .34498 L .52625 .3458 L F
.52653 .34574 m .52639 .3452 L p .52633 .34569 L F P
0 g
s
.5265 .34564 m .52594 .34544 L .52608 .3451 L .672 .728 .891 r
F
.52606 .34501 m .5259 .34516 L .52628 .34514 L F
.5258 .34486 m .5259 .34516 L .52606 .34501 L F
.52649 .34559 m .52646 .34558 L .52608 .34498 L F
.52569 .34433 m .52586 .34487 L .52594 .34465 L F
.52609 .34498 m .52608 .34498 L .52555 .34416 L F
.52649 .34559 m .52608 .34498 L .52609 .34498 L F
.52597 .34531 m .52597 .34531 L .52599 .34527 L F
.526 .34531 m .52595 .34535 L .5261 .34505 L F
.5259 .34557 m .52602 .34521 L .5259 .34547 L F
.52595 .34535 m .526 .34531 L .526 .34531 L F
.52608 .3451 m .52598 .34535 L .52568 .34459 L F
.52588 .34555 m .52588 .3455 L .52587 .34552 L F
.52562 .34554 m .52587 .34553 L .52593 .34541 L F
.52592 .34549 m .5249 .34635 L .52599 .34531 L F
.52598 .34535 m .52594 .34544 L .5259 .34531 L F
.52595 .34535 m .52595 .34535 L .526 .34531 L F
.52481 .34517 m .526 .34507 L .52486 .34512 L F
.52598 .34535 m .5259 .34531 L .52568 .34459 L F
.52127 .34588 m .52128 .34587 L .52587 .34487 L F
.526 .34508 m .526 .34508 L .52465 .34544 L F
.51483 .34669 m .5244 .34545 L .52437 .34541 L F
.5237 .34531 m .50797 .34782 L .52349 .34513 L F
.52327 .3453 m .52288 .34561 L .52461 .34538 L F
.52327 .3453 m .51483 .34669 L .52288 .34561 L F
.50797 .34782 m .5133 .34706 L p .51483 .34669 L F P
0 g
s
.52453 .34547 m .50797 .34782 L p .52392 .34528 L .672 .728 .891 r
F P
0 g
s
.52327 .3453 m .52461 .34538 L .52481 .34517 L .672 .728 .891 r
F
.52563 .34518 m .51925 .34564 L .52562 .34519 L F
.52516 .34498 m .52531 .34506 L .52578 .34502 L F
.52499 .3451 m .525 .3451 L .52618 .3449 L F
.52516 .34498 m .52412 .34515 L .52531 .34506 L F
.52412 .34515 m .52419 .3452 L .52578 .34502 L F
.52327 .3453 m .52481 .34517 L .52486 .34512 L F
.52567 .34499 m .5238 .3453 L .526 .34486 L F
.5258 .34486 m .52517 .34493 L .52563 .34518 L F
.52499 .3451 m .5238 .3453 L .525 .3451 L F
.52412 .34515 m .52327 .3453 L .52419 .3452 L F
.5244 .34545 m .52459 .34542 L .52437 .34541 L F
.52459 .34542 m .52454 .34539 L .52437 .34541 L F
.52453 .34547 m .52392 .34528 L .52582 .34497 L F
.52517 .34493 m .5238 .3453 L .52405 .34507 L F
.52506 .34504 m .5238 .3453 L .52517 .34493 L F
.5238 .3453 m .5237 .34531 L .52405 .34507 L F
.52517 .34493 m .51925 .34564 L .52563 .34518 L F
.52532 .34434 m .52593 .34468 L .52593 .34469 L F
.52534 .34434 m .52535 .34434 L .52593 .34468 L F
.52534 .34434 m .52593 .34468 L .52593 .34468 L F
.52507 .34437 m .52586 .34487 L p .52569 .34433 L F P
0 g
s
.52607 .345 m .52634 .34514 L .52614 .34493 L .672 .728 .891 r
F
.52621 .34498 m .52609 .345 L .52619 .34495 L F
.52564 .34549 m .5257 .3455 L .52581 .34542 L F
.52562 .34554 m .52588 .3454 L .52581 .34542 L F
.52562 .34554 m .52588 .34539 L .52588 .3454 L F
.52343 .347 m .5259 .34553 L .52562 .34554 L F
.52595 .34535 m .52495 .34629 L .52595 .34509 L F
.52582 .34527 m .52594 .34541 L .52586 .34545 L F
.5259 .34531 m .52594 .34541 L .52582 .34527 L F
.52631 .3451 m .52687 .34545 L .52631 .34511 L F
.52679 .34522 m .52706 .34557 L .52727 .3456 L F
.52678 .34534 m .52706 .34557 L .52679 .34522 L F
.52639 .3452 m .52621 .34498 L .52802 .34598 L F
.52594 .34455 m .52682 .34547 L .52682 .34545 L F
.52639 .3452 m .52714 .34513 L p .52635 .34516 L F P
0 g
s
.52643 .34497 m .52658 .345 L .52835 .34595 L .672 .728 .891 r
F
.52685 .34524 m .52685 .34522 L .52705 .34534 L F
.52665 .34502 m .52659 .34501 L .52703 .34537 L F
.52642 .34497 m .52685 .34522 L .52685 .34522 L F
.52658 .34507 m .52666 .34501 L .52661 .34512 L F
.52684 .34521 m .52705 .34534 L .52685 .34522 L F
.52684 .34521 m .52685 .34522 L .5264 .34496 L F
.52641 .34497 m .52684 .34521 L .5264 .34496 L F
.5264 .34496 m .52705 .34534 L .52705 .34534 L F
.52646 .3449 m .52687 .34551 L .52722 .34552 L F
.52588 .34518 m .52714 .34513 L .527 .3451 L F
.52669 .34502 m .5265 .34491 L .52707 .34508 L F
.52629 .3448 m .52688 .34507 L .52704 .34509 L F
.52688 .34507 m .527 .3451 L .52704 .34509 L F
.52685 .34522 m .528 .34588 L .52685 .34522 L F
.52685 .34522 m .52685 .34521 L .528 .34588 L F
.52788 .34554 m .52679 .3449 L .52722 .34552 L F
.52688 .34507 m .52695 .3451 L .527 .3451 L F
.52728 .34468 m .52618 .3449 L .52729 .34468 L F
.5274 .34467 m .52618 .3449 L .52737 .34467 L F
.52757 .34467 m .52618 .3449 L .52753 .34465 L F
.52729 .34468 m .52629 .3448 L .52704 .34509 L F
.52679 .3449 m .52656 .3449 L .52672 .34497 L F
.52656 .3449 m .52653 .3449 L .52672 .34497 L F
.52672 .34497 m .52653 .3449 L .52667 .34502 L F
.52688 .34507 m .52667 .34502 L .52703 .34535 L F
.52684 .34504 m .52666 .34501 L .52805 .34462 L F
.52679 .3449 m .52667 .34502 L .52688 .34507 L F
.52706 .34529 m .52703 .34535 L .52722 .34552 L F
.52679 .3449 m .52703 .34535 L .52706 .34529 L F
.52683 .34508 m .5267 .34511 L .52695 .3451 L F
.52684 .34506 m .52678 .34505 L .52695 .3451 L F
.52682 .34511 m .52681 .34505 L .52788 .34554 L F
.52681 .34505 m .52681 .34503 L .52688 .34506 L F
.52681 .34505 m .52688 .34506 L .52788 .34554 L F
.52703 .34514 m .52639 .3452 L p .52689 .34506 L F P
0 g
s
.52713 .34509 m .52689 .34505 L .5279 .34476 L .672 .728 .891 r
F
.52707 .3451 m .52689 .34506 L .52722 .34497 L F
.52703 .34514 m .52689 .34506 L .52707 .3451 L F
.52725 .3449 m .52704 .34509 L .52722 .34508 L F
.52722 .34498 m .52722 .34497 L .52723 .34497 L F
.52703 .34514 m .52722 .34497 L .52722 .34498 L F
.52602 .34444 m .52703 .34537 L .52703 .34535 L F
.52607 .34532 m .52627 .34505 L .52611 .3453 L F
.5258 .34526 m .52639 .3452 L p .52588 .34518 L F P
0 g
s
.52594 .34465 m .52594 .34492 L .52596 .34492 L .672 .728 .891 r
F
.52586 .34487 m .52594 .34488 L .52594 .34489 L F
.52586 .34487 m .52594 .34492 L p .52594 .34486 L F P
0 g
s
.52594 .34465 m .52587 .34485 L .52594 .34486 L .672 .728 .891 r
F
.52587 .34485 m .52586 .34487 L .52594 .34486 L F
.52595 .34487 m .5258 .34486 L .52591 .34488 L F
.52608 .34482 m .52587 .34485 L .52595 .34487 L F
.52587 .34485 m .5258 .34486 L .52595 .34487 L F
.52608 .34498 m .52568 .34459 L .52585 .34462 L F
.52647 .34655 m .52621 .34498 L .52632 .34646 L F
.52611 .3453 m .52627 .34505 L .5263 .3451 L F
.52563 .34518 m .52566 .34519 L .52695 .3451 L F
.52581 .34523 m .52592 .34514 L .5263 .34509 L F
.52618 .34494 m .52666 .3451 L .52676 .34506 L F
.52631 .34494 m .52682 .34547 L .52631 .34495 L F
.52639 .3452 m .52641 .34518 L .52685 .34547 L F
.52639 .3452 m .52826 .34655 L p .5265 .34518 L F P
0 g
s
.52639 .3452 m .52682 .34547 L p .52627 .34491 L .672 .728 .891 r
F P
0 g
s
.52618 .34494 m .52634 .34514 L .5267 .34511 L .672 .728 .891 r
F
.52596 .34553 m .52663 .3449 L .5267 .3449 L F
.52679 .34489 m .52596 .34553 L p .52678 .34483 L F P
0 g
s
.52639 .3452 m .52678 .3449 L p .52632 .34512 L .672 .728 .891 r
F P
0 g
s
.526 .34531 m .526 .34531 L .52642 .34491 L .672 .728 .891 r
F
.52588 .34518 m .52639 .3452 L .52635 .34516 L F
.52597 .34509 m .52597 .3451 L .526 .34529 L F
.52586 .34558 m .52593 .34543 L .52591 .34515 L F
.52596 .34546 m .52607 .34532 L .52611 .3453 L F
.52582 .3454 m .52586 .34545 L .52583 .34546 L F
.52618 .34527 m .52592 .34549 L .52612 .3453 L F
.52596 .34553 m .52596 .34546 L .52663 .3449 L F
.52596 .3454 m .52599 .34531 L .52596 .34546 L F
.52596 .34553 m .52639 .3452 L p .52597 .34536 L F P
0 g
s
.52542 .34556 m .52588 .34553 L .52597 .34536 L .672 .728 .891 r
F
.52588 .34555 m .5259 .34557 L .52588 .3455 L F
.52657 .34623 m .52677 .34654 L .52602 .34599 L F
.52594 .34541 m .52648 .34719 L .52583 .34546 L F
.52592 .34549 m .52596 .3454 L .52596 .34546 L F
.52588 .34553 m .52596 .34553 L .52597 .34536 L F
.52606 .34578 m .526 .34529 L .52606 .34578 L F
.526 .34529 m .52591 .34461 L .526 .34529 L F
.526 .34529 m .526 .34529 L .52606 .34578 L F
.526 .34529 m .526 .34529 L .52606 .34578 L F
.52639 .3452 m .52578 .34526 L p .52634 .34514 L F P
0 g
s
.52302 .34538 m .5258 .34526 L .52588 .34518 L .672 .728 .891 r
F
.52299 .34538 m .52303 .34538 L .52302 .34538 L F
.52303 .34538 m .5258 .34526 L .52302 .34538 L F
.52578 .34526 m .52581 .34524 L .52634 .34514 L F
.52602 .34444 m .52555 .34416 L .52599 .34452 L F
.52602 .34444 m .52574 .34439 L .52555 .34416 L F
.52599 .34508 m .52594 .34403 L .52586 .34406 L F
.52594 .34492 m .52596 .34493 L p .52596 .34492 L F P
0 g
s
.5258 .34486 m .52607 .345 L .52614 .34493 L .672 .728 .891 r
F
.52616 .34491 m .52584 .3446 L .52594 .34465 L F
.52605 .34503 m .52594 .34403 L .52599 .34508 L F
.52597 .34509 m .526 .34529 L .526 .34529 L F
.52579 .34526 m .52586 .34545 L .52582 .3454 L F
.52563 .3445 m .52582 .34527 L .52579 .34526 L F
.52582 .34527 m .52586 .34545 L .52579 .34526 L F
.52579 .34526 m .52586 .3453 L .52586 .34454 L F
.52563 .34518 m .52601 .34507 L .52592 .34514 L F
.52303 .34542 m .52467 .34537 L .52464 .34533 L F
.52301 .34553 m .52555 .34514 L .52563 .34518 L F
.52555 .34514 m .52601 .34507 L .52563 .34518 L F
.52645 .34557 m .52568 .34459 L .52646 .34558 L F
.52591 .34461 m .52597 .3451 L .52597 .34509 L F
.52578 .34526 m .52557 .34528 L p .52581 .34524 L F P
0 g
s
.52577 .34524 m .52563 .34518 L .52592 .34514 L .672 .728 .891 r
F
.52586 .34519 m .52591 .34515 L .52586 .34454 L F
.52609 .345 m .52541 .34507 L .52613 .34496 L F
.52609 .345 m .52613 .34496 L .52619 .34495 L F
.52555 .34514 m .52609 .345 L .52601 .34507 L F
.52616 .34491 m .52614 .34493 L .52618 .34494 L F
.52018 .34939 m .52425 .34664 L p .51876 .3501 L F P
0 g
s
.51876 .3501 m .52425 .34664 L .52343 .347 L .672 .728 .891 r
F
.52044 .34883 m .5205 .3487 L .5248 .34584 L F
.5249 .34635 m .514 .35471 L p .52525 .34542 L F P
0 g
s
.52527 .34548 m .52495 .34574 L .52524 .34556 L .672 .728 .891 r
F
.52603 .34503 m .52568 .34459 L .52608 .34498 L F
.52607 .34502 m .52608 .34501 L .52604 .34477 L F
.52618 .34527 m .52612 .3453 L .52676 .34466 L F
.52676 .34466 m .52676 .34466 L .52692 .34449 L F
.52618 .34527 m .52676 .34466 L .52676 .34466 L F
.52639 .3452 m .52634 .34514 L .52682 .34504 L F
.52633 .34513 m .5263 .34509 L .52692 .34501 L F
.52642 .34497 m .52646 .345 L .52695 .3451 L F
.52616 .34491 m .52646 .345 L .52642 .34497 L F
.52616 .34491 m .52618 .34494 L .52646 .345 L F
.52642 .34491 m .52627 .34491 L .52628 .34468 L F
.52602 .34444 m .52638 .3448 L .52645 .34483 L F
.5263 .3451 m .52627 .34505 L .52642 .34491 L F
.52649 .3449 m .52642 .34491 L .5271 .34427 L F
.52639 .34496 m .52616 .34491 L .52639 .34497 L F
.52639 .34496 m .52639 .34497 L .52695 .3451 L F
.52678 .34505 m .52639 .34496 L .52695 .3451 L F
.52632 .34495 m .52652 .34499 L .52646 .3449 L F
.5263 .3451 m .52642 .34491 L .52649 .3449 L F
.52638 .3448 m .52649 .3449 L .52645 .34483 L F
.52649 .3449 m .52659 .34501 L .52651 .3449 L F
.52649 .3449 m .52651 .3449 L .52645 .34483 L F
.52678 .34478 m .52663 .3449 L .52676 .34466 L F
.52651 .3449 m .52659 .34501 L .52653 .3449 L F
.52663 .3449 m .52618 .34527 L .52653 .3449 L F
.52663 .3449 m .52653 .3449 L .52676 .34466 L F
.52653 .3449 m .52659 .34501 L .52665 .34502 L F
.52645 .34483 m .52651 .3449 L .52653 .3449 L F
.52576 .34433 m .52629 .34491 L .52646 .3449 L F
.52555 .34416 m .52572 .34433 L .52576 .34433 L F
.52572 .34433 m .52629 .34491 L .52576 .34433 L F
.52757 .34389 m .52701 .34429 L .52694 .34429 L F
.5275 .3438 m .52672 .34437 L .5283 .34377 L F
.52759 .34398 m .52644 .34475 L .52758 .34396 L F
.52644 .34475 m .52641 .34475 L .52842 .34337 L F
.52842 .34337 m .52842 .34337 L .52877 .34313 L F
.52644 .34475 m .52842 .34337 L .52842 .34337 L F
.5267 .3449 m .52663 .3449 L .52756 .34413 L F
.53978 .33616 m .5389 .3356 L p .5275 .3438 L F P
0 g
s
.52757 .34417 m .52756 .34413 L .53084 .3414 L .672 .728 .891 r
F
.5267 .3449 m .52756 .34413 L .52757 .34417 L F
.52629 .34491 m .52632 .34495 L .52646 .3449 L F
.52642 .34491 m .52627 .34505 L .52627 .34491 L F
.52623 .34501 m .52624 .34502 L .5264 .34491 L F
.52595 .34535 m .52642 .34491 L .52642 .34491 L F
.52642 .34491 m .52595 .34535 L .52642 .34491 L F
.52614 .34493 m .52634 .34514 L .52618 .34494 L F
.52601 .34507 m .52609 .345 L .52637 .34497 L F
.52702 .34503 m .5267 .3449 L .52674 .34489 L F
.52666 .3451 m .5267 .34511 L .52676 .34506 L F
.52627 .34505 m .52616 .34492 L .52628 .34468 L F
.52594 .34456 m .52618 .34491 L .52627 .34491 L F
.52581 .34523 m .5263 .34509 L .52633 .34513 L F
.52632 .34512 m .52678 .3449 L .52678 .34489 L F
.52596 .34529 m .52632 .34512 L .52632 .34512 L F
.52632 .34512 m .52678 .3449 L .52632 .34512 L F
.52657 .3449 m .52659 .3449 L .52692 .34507 L F
.52691 .34507 m .52692 .34507 L .52715 .34518 L F
.52657 .3449 m .52692 .34507 L .52691 .34507 L F
.52674 .34503 m .52736 .34486 L .52723 .34497 L F
.5263 .34509 m .52664 .34502 L .52674 .34503 L F
.52555 .34416 m .52594 .34456 L .52594 .34455 L F
.52642 .34491 m .52642 .34491 L .52675 .3446 L F
.52678 .3449 m .52602 .34444 L .52653 .3449 L F
.52679 .3449 m .52678 .34489 L .52678 .3449 L F
.52678 .34489 m .52602 .34444 L .52678 .3449 L F
.52604 .34477 m .52599 .34471 L .52639 .34491 L F
.52604 .34477 m .52639 .34491 L .52634 .34492 L F
.52656 .345 m .52587 .34464 L .52587 .34464 L F
.52683 .34514 m .52656 .345 L .52656 .345 L F
.52632 .34646 m .52627 .34578 L .52625 .3458 L F
.5276 .3478 m .52753 .34778 L .5262 .34545 L F
.52783 .34829 m .52759 .3483 L .5262 .34545 L F
.52678 .34842 m .52647 .34655 L .52632 .34646 L F
.52679 .34632 m .52656 .34567 L p .52663 .34644 L F P
0 g
s
.52663 .34644 m .52656 .34567 L .52636 .34558 L .672 .728 .891 r
F
.52651 .34562 m .52704 .34699 L .52618 .34557 L F
.52704 .34739 m .5276 .34781 L .52656 .34668 L F
.52655 .34617 m .52755 .34822 L .52653 .34628 L F
.52677 .34654 m .52704 .34699 L .52617 .34648 L F
.52755 .34846 m .53199 .35727 L .52755 .34954 L F
.52831 .3505 m .52679 .34632 L p .52768 .34984 L F P
0 g
s
.52768 .34984 m .52679 .34632 L .52663 .34644 L .672 .728 .891 r
F
.52755 .34822 m .53199 .35727 L .52755 .34846 L F
.53084 .35748 m .52831 .3505 L p .52768 .34984 L F P
0 g
s
.52704 .34699 m .53084 .35748 L p .52667 .34806 L .672 .728 .891 r
F P
0 g
s
.52761 .34983 m .52653 .34574 L p .52678 .34842 L .672 .728 .891 r
F P
0 g
s
.52647 .34605 m .52657 .34623 L .52643 .34617 L .672 .728 .891 r
F
.52678 .34842 m .52653 .34574 L .52633 .34569 L F
.52966 .35765 m .52761 .34983 L p .52678 .34842 L F P
0 g
s
.5265 .34564 m .52966 .35765 L p .52614 .34607 L .672 .728 .891 r
F P
0 g
s
.52702 .34503 m .5263 .34467 L .52629 .3446 L .672 .728 .891 r
F
.52602 .34444 m .52599 .34452 L .52659 .34501 L F
.5263 .34467 m .52574 .34439 L .52629 .3446 L F
.52629 .3446 m .52574 .34439 L .52602 .34444 L F
.52632 .34512 m .52678 .34489 L .52624 .34502 L F
.52595 .34535 m .52675 .3446 L .52595 .34535 L F
.52714 .34513 m .52862 .34498 L p .527 .3451 L F P
0 g
s
.52848 .3449 m .52713 .34509 L p .5279 .34476 L .672 .728 .891 r
F P
0 g
s
.52736 .34469 m .52722 .34508 L .52862 .34498 L .672 .728 .891 r
F
.52862 .34498 m .5272 .34512 L p .52825 .34483 L F P
0 g
s
.5272 .34512 m .52703 .34514 L p .52714 .34511 L .672 .728 .891 r
F P
0 g
s
.5272 .34512 m .52714 .34511 L .52825 .34483 L .672 .728 .891 r
F
.52688 .34506 m .52715 .34518 L .52717 .3452 L F
.52681 .34503 m .52688 .34506 L .52688 .34506 L F
.52688 .34506 m .52715 .34518 L .52688 .34506 L F
.5258 .34486 m .52628 .34514 L .52633 .34513 L F
.52601 .34507 m .52623 .34501 L .52625 .34503 L F
.52656 .345 m .52598 .3447 L .52656 .345 L F
.52672 .34437 m .52706 .34436 L .5283 .34377 L F
.52608 .34482 m .5271 .34436 L .52707 .34436 L F
.52789 .34352 m .52661 .34473 L .52628 .34468 L F
.52608 .34481 m .52677 .34461 L .52676 .34458 L F
.52656 .345 m .52656 .345 L .52587 .34464 L F
.52681 .34502 m .52715 .34518 L .52681 .34503 L F
.52788 .34554 m .52758 .34553 L .52799 .34575 L F
.52758 .34553 m .52722 .34552 L .52799 .34575 L F
.52803 .34583 m .528 .34577 L .52835 .34595 L F
.52768 .3457 m .528 .34577 L .52803 .34583 L F
.52768 .3457 m .52796 .34575 L .528 .34577 L F
.52685 .34522 m .528 .34588 L .528 .34588 L F
.52705 .34534 m .52705 .34534 L .52979 .34692 L F
.52705 .34535 m .52705 .34534 L .52979 .34692 L F
.52639 .3452 m .52802 .34598 L .52803 .34606 L F
.52799 .34575 m .52722 .34552 L .52835 .34644 L F
.52683 .34514 m .52937 .34647 L .52683 .34514 L F
.52835 .34609 m .52768 .3457 L .52835 .34595 L F
.52891 .34717 m .52805 .34634 L .52875 .34677 L F
.52896 .34731 m .52805 .34634 L .52891 .34717 L F
.5282 .34597 m .52811 .34645 L .52886 .34723 L F
.52798 .34595 m .52789 .34608 L .52905 .34698 L F
.52981 .34697 m .52705 .34535 L .52979 .34692 L F
.52803 .34606 m .52802 .34598 L .53017 .34718 L F
.528 .34588 m .528 .34588 L .52979 .34692 L F
.52979 .34692 m .52835 .34609 L .52835 .34595 L F
.53009 .34686 m .52788 .34554 L .52835 .34644 L F
.52914 .34685 m .52905 .34698 L .53164 .34899 L F
.53063 .34762 m .52639 .3452 L .53017 .34718 L F
.53147 .34842 m .5299 .34743 L p .53063 .34762 L F P
0 g
s
.52687 .34548 m .52687 .34545 L .52839 .34648 L .672 .728 .891 r
F
.52842 .34667 m .52677 .34548 L p .52839 .34648 L F P
0 g
s
.52706 .34557 m .52826 .34655 L .52727 .3456 L .672 .728 .891 r
F
.5299 .34743 m .52639 .3452 L p .53063 .34762 L F P
0 g
s
.53017 .34718 m .52981 .34697 L .52979 .34692 L .672 .728 .891 r
F
.53164 .34899 m .53921 .35444 L p .53487 .35036 L F P
0 g
s
.54007 .35387 m .53147 .34842 L p .53017 .34718 L .672 .728 .891 r
F P
0 g
s
.52835 .34644 m .54007 .35387 L p .53009 .34686 L .672 .728 .891 r
F P
0 g
s
.52702 .34546 m .52728 .34544 L .53194 .34796 L .672 .728 .891 r
F
.52949 .3448 m .52729 .34509 L .52941 .3447 L F
.52724 .34515 m .52675 .34507 L .52719 .34533 L F
.52628 .34507 m .5266 .34501 L .5263 .34509 L F
.52729 .34468 m .52704 .34509 L .52725 .3449 L F
.5266 .34501 m .52736 .34486 L .52664 .34502 L F
.5266 .34501 m .52664 .34502 L .5263 .34509 L F
.52617 .34493 m .52526 .34554 L .5262 .34497 L F
.52561 .3444 m .52563 .34449 L .52563 .3445 L F
.52594 .34456 m .52631 .34494 L .52594 .34455 L F
.52628 .34479 m .52627 .3448 L .52544 .34364 L F
.52622 .3443 m .52621 .34429 L .52621 .3443 L F
.52622 .3443 m .52603 .34423 L .52619 .34427 L F
.52621 .34498 m .52618 .34397 L .52612 .34402 L F
.52596 .34529 m .52678 .3449 L .52596 .34529 L F
.52629 .34514 m .52628 .34514 L .52629 .34514 L F
.52629 .34514 m .52629 .34514 L .52629 .34514 L F
.52629 .34514 m .52629 .34514 L .52634 .34514 L F
.52665 .34492 m .52803 .34417 L .52792 .34421 L F
.52588 .3454 m .52766 .34435 L .52764 .34435 L F
.52633 .34513 m .52629 .34514 L .52634 .34514 L F
.526 .34528 m .52639 .3452 L .52632 .34512 L F
.52596 .34546 m .52599 .34531 L .52627 .34505 L F
.52601 .34527 m .526 .34528 L .52632 .34512 L F
.52632 .34512 m .52632 .34512 L .52678 .3449 L F
.52601 .34527 m .52632 .34512 L .52632 .34512 L F
.52634 .34514 m .52677 .34504 L .52681 .34505 L F
.52577 .34524 m .52633 .34513 L .52634 .34514 L F
.52633 .34513 m .52677 .34504 L .52634 .34514 L F
.52632 .3462 m .52626 .34505 L .52621 .34498 L F
.52646 .34766 m .52635 .34614 L .52632 .3462 L F
.52635 .34614 m .52626 .34505 L .52632 .3462 L F
.5271 .34436 m .52743 .34435 L .5283 .34377 L F
.52679 .34489 m .52678 .34483 L .52958 .34246 L F
.52959 .34248 m .52958 .34246 L .53084 .3414 L F
.52679 .34489 m .52958 .34246 L .52959 .34248 L F
.53212 .34461 m .54518 .34419 L p .53141 .34441 L F P
0 g
s
.53125 .34451 m .53022 .34465 L .53141 .34441 L .672 .728 .891 r
F
.53155 .34445 m .52972 .34454 L .53296 .34485 L F
.54518 .34419 m .53043 .34498 L p .53066 .34465 L F P
0 g
s
.5263 .34509 m .52683 .3452 L .52685 .34528 L .672 .728 .891 r
F
.52726 .34515 m .52946 .34504 L p .52713 .34513 L F P
0 g
s
.5279 .34488 m .52832 .34508 L .52946 .34504 L .672 .728 .891 r
F
.52587 .34426 m .52575 .34329 L .52575 .34329 L F
.52597 .34414 m .52564 .3435 L .52576 .34353 L F
.5255 .34504 m .52538 .34506 L .52567 .34498 L F
.52547 .34502 m .52536 .34506 L .52599 .34506 L F
.52676 .34506 m .5267 .34511 L .52683 .34508 L F
.52639 .3452 m .52682 .34504 L .52723 .34497 L F
.52682 .34511 m .52665 .34502 L .52681 .34505 L F
.52563 .34449 m .52586 .34545 L .52563 .3445 L F
.52596 .34553 m .5249 .34635 L p .52596 .34546 L F P
0 g
s
.52495 .34629 m .5249 .34635 L .52495 .34629 L .672 .728 .891 r
F
.52495 .34629 m .5249 .34635 L .52497 .34616 L F
.52495 .34629 m .52497 .34616 L .52525 .34542 L F
.5249 .34635 m .52596 .34553 L p .52429 .34628 L F P
0 g
s
.52586 .34558 m .52588 .34559 L .52587 .34562 L .672 .728 .891 r
F
.52583 .34546 m .52588 .34559 L .52586 .34558 L F
.52588 .34559 m .52588 .34559 L .52586 .34558 L F
.52595 .34509 m .52495 .34629 L .52551 .34552 L F
.52595 .34535 m .52495 .34629 L .52595 .34535 L F
.52495 .34629 m .52595 .34535 L .52595 .34535 L F
.52495 .34629 m .52595 .34535 L .52595 .34535 L F
.52429 .34628 m .52584 .34558 L .5254 .34556 L F
.52584 .34558 m .52596 .34553 L .52566 .34555 L F
.52584 .34558 m .52566 .34555 L .5254 .34556 L F
.52592 .34514 m .52628 .34507 L .5263 .34509 L F
.52607 .34513 m .52632 .34512 L .52624 .34502 L F
.52583 .34528 m .52586 .34534 L .52586 .3453 L F
.52579 .34526 m .52586 .34534 L .52583 .34528 L F
.52579 .34526 m .52586 .34558 L .52586 .34534 L F
.52586 .34558 m .52591 .34515 L .52586 .34519 L F
.52601 .34507 m .52625 .34503 L .52592 .34514 L F
.52605 .34503 m .52604 .34477 L .52602 .34474 L F
.52615 .3459 m .52607 .34502 L .52605 .34503 L F
.52607 .34502 m .52604 .34477 L .52605 .34503 L F
.5254 .34556 m .52601 .34527 L .52607 .34513 L F
.52601 .34527 m .52632 .34512 L .52607 .34513 L F
.52586 .34454 m .52595 .34538 L .5259 .3446 L F
.52595 .34538 m .52611 .34672 L .52597 .34534 L F
.52595 .34538 m .52597 .34534 L .5259 .3446 L F
.52611 .34672 m .52611 .34676 L .52611 .34672 L F
.54161 .35263 m .54228 .35195 L p .52831 .34559 L F P
0 g
s
.52609 .34658 m .5261 .34658 L .5259 .3446 L .672 .728 .891 r
F
.52593 .34464 m .5259 .3446 L .52681 .34504 L F
.52555 .34416 m .5259 .34531 L .52582 .34527 L F
.52563 .34449 m .52586 .34545 L .52563 .34449 L F
.52563 .3445 m .52579 .34526 L .52586 .34454 L F
.526 .34534 m .52591 .34457 L .526 .34534 L F
.52591 .34457 m .52587 .34426 L .52591 .34457 L F
.52591 .34461 m .52591 .34461 L .526 .34534 L F
.52597 .3451 m .52587 .34426 L .52597 .3451 L F
.526 .34538 m .52591 .34461 L .5259 .3446 L F
.52537 .34471 m .52505 .34426 L .52537 .34471 L F
.52512 .34449 m .52611 .34485 L .52588 .34487 L F
.52589 .34458 m .52586 .34454 L .52659 .3449 L F
.52555 .34416 m .52594 .34465 L .52594 .34456 L F
.52591 .34457 m .52591 .34457 L .52591 .34461 L F
.52586 .34458 m .52586 .34457 L .52681 .34503 L F
.52591 .34457 m .52591 .34461 L .52591 .34461 L F
.52587 .34499 m .5255 .34504 L .52587 .34493 L F
.52587 .34499 m .52587 .34493 L .52599 .34489 L F
.52591 .34457 m .52588 .34425 L .52587 .34426 L F
.52613 .34501 m .52623 .34501 L .5262 .34497 L F
.52577 .34524 m .52592 .34514 L .52581 .34523 L F
.52601 .34538 m .52591 .34461 L .526 .34538 L F
.526 .34528 m .52592 .34457 L .526 .34529 L F
.52613 .34496 m .52587 .34499 L .52599 .34489 L F
.52592 .34495 m .52594 .34508 L .52617 .34493 L F
.52609 .34509 m .52623 .34501 L .52613 .34501 L F
.52594 .34494 m .52592 .34495 L .52617 .34493 L F
.5265 .34499 m .5266 .34501 L .52592 .34514 L F
.52609 .34509 m .52624 .34502 L .52623 .34501 L F
.52628 .34639 m .52621 .34498 L .52617 .34493 L F
.52639 .3452 m .52576 .34485 L p .52647 .34517 L F P
0 g
s
.52597 .34536 m .52639 .3452 L .526 .34528 L .672 .728 .891 r
F
.52625 .34503 m .52627 .34505 L .52592 .34514 L F
.52608 .34511 m .52624 .34502 L .52609 .34509 L F
.52612 .3453 m .52617 .34493 L .52608 .34501 L F
.52592 .34494 m .52639 .3452 L p .526 .34493 L F P
0 g
s
.52538 .34506 m .52526 .345 L .52632 .3448 L .672 .728 .891 r
F
.52674 .34489 m .52586 .34454 L .52574 .34439 L F
.52586 .34457 m .52681 .34502 L .52586 .34457 L F
.52608 .34501 m .52617 .34493 L .52604 .34477 L F
.52613 .34496 m .52599 .34489 L .52617 .34493 L F
.52595 .34514 m .52603 .34493 L .5261 .34493 L F
.5262 .34497 m .5264 .34491 L .52628 .34492 L F
.52611 .34485 m .52642 .34497 L .52617 .34493 L F
.52617 .34493 m .5262 .34497 L .52628 .34492 L F
.52621 .34498 m .52619 .34495 L .52626 .34494 L F
.52681 .34505 m .52586 .34458 L .52681 .34503 L F
.52586 .34457 m .52681 .34502 L .52681 .34503 L F
.52665 .34502 m .52593 .34464 L .52681 .34504 L F
.5264 .34491 m .52678 .34489 L .52677 .34468 L F
.52589 .34458 m .52659 .3449 L .52657 .3449 L F
.52642 .34491 m .52642 .34491 L .5271 .34427 L F
.52595 .34535 m .52595 .34535 L .52675 .3446 L F
.52675 .3446 m .52675 .3446 L .5271 .34427 L F
.52595 .34535 m .52675 .3446 L .52675 .3446 L F
.5254 .3444 m .52541 .3444 L .52683 .34514 L F
.52683 .34515 m .52683 .34514 L .52791 .34571 L F
.5264 .34491 m .52665 .34502 L .52656 .345 L F
.52541 .3444 m .52644 .34491 L .5264 .34491 L F
.52624 .34502 m .5265 .34496 L .5264 .34492 L F
.52652 .34495 m .52678 .34489 L .52644 .34491 L F
.5264 .34492 m .52644 .34491 L .5264 .34491 L F
.52644 .34491 m .52665 .34502 L .5264 .34491 L F
.52624 .34492 m .52628 .34492 L .52651 .34478 L F
.52624 .34492 m .52651 .34478 L .52692 .34453 L F
.52715 .34518 m .52659 .3449 L .52702 .34503 L F
.52659 .3449 m .52586 .34454 L .5267 .3449 L F
.52659 .3449 m .5267 .3449 L .52702 .34503 L F
.52617 .34493 m .52624 .34492 L .52692 .34453 L F
.52734 .34472 m .52623 .34494 L .52632 .3448 L F
.52623 .34494 m .52613 .34496 L .52617 .34493 L F
.52587 .34465 m .52655 .345 L .52655 .345 L F
.52585 .34462 m .52568 .34459 L .52555 .34416 L F
.5254 .3444 m .52587 .34465 L .52587 .34465 L F
.52587 .34465 m .52655 .345 L .52587 .34465 L F
.52623 .34501 m .52637 .34497 L .52625 .34503 L F
.52623 .34501 m .5264 .34491 L .5262 .34497 L F
.52637 .34497 m .52621 .34498 L .52626 .34494 L F
.52625 .34503 m .5265 .34499 L .52627 .34505 L F
.52625 .34503 m .52637 .34497 L .5265 .34499 L F
.52617 .34493 m .52642 .34497 L .5263 .34509 L F
.52623 .34494 m .52617 .34493 L .52628 .34487 L F
.52626 .34505 m .52624 .34477 L .52621 .34498 L F
.52576 .34485 m .52588 .34487 L .526 .34494 L F
.52591 .34487 m .52592 .34494 L .526 .34493 L F
.52611 .34485 m .52617 .34493 L .52588 .34487 L F
.52617 .34493 m .52599 .34489 L .52611 .34486 L F
.5267 .3449 m .52586 .34454 L .52674 .34489 L F
.52598 .3447 m .52683 .34514 L .52598 .3447 L F
.52624 .34478 m .52617 .34493 L .52657 .34471 L F
.52628 .34487 m .52617 .34493 L .52632 .3448 L F
.52608 .34481 m .52657 .34471 L .52648 .34469 L F
.52625 .34486 m .5263 .34465 L .52624 .34477 L F
.52591 .34461 m .52591 .34461 L .52597 .3451 L F
.52594 .34465 m .52639 .3452 L .52594 .34456 L F
.5251 .34446 m .52535 .3444 L .52642 .34497 L F
.52496 .34441 m .52506 .34441 L .5251 .34446 L F
.52506 .34441 m .52535 .3444 L .5251 .34446 L F
.52611 .34676 m .52628 .34754 L .52618 .34679 L F
.52617 .34493 m .52611 .34486 L .52617 .34493 L F
.52583 .3446 m .52584 .34458 L .52665 .34502 L F
.52621 .34498 m .52611 .344 L .52604 .34477 L F
.52608 .34481 m .52617 .34493 L .52624 .34478 L F
.52748 .34555 m .52604 .34477 L .52737 .34543 L F
.52624 .34477 m .5262 .34485 L .52621 .34498 L F
.52617 .34493 m .52611 .34486 L .52632 .3448 L F
.52608 .34481 m .52594 .34494 L .52617 .34493 L F
.5261 .34493 m .52603 .34493 L .52611 .34486 L F
.52608 .34481 m .5259 .34488 L .52577 .34484 L F
.52632 .3448 m .52594 .34487 L .52608 .34481 L F
.52594 .34487 m .5259 .34488 L .52608 .34481 L F
.52596 .34494 m .526 .34494 L .52647 .34517 L F
.52608 .34481 m .52577 .34484 L .5261 .34485 L F
.52577 .34484 m .52579 .34484 L .52625 .34485 L F
.5261 .34493 m .52611 .34486 L .52613 .34488 L F
.52579 .34484 m .52614 .34489 L .5261 .34485 L F
.52576 .34485 m .526 .34494 L .52596 .34494 L F
.5259 .34488 m .52574 .34491 L .52576 .34485 L F
.52576 .34485 m .52496 .34441 L p .52588 .34487 L F P
0 g
s
.5259 .34488 m .52576 .34485 L .52577 .34484 L .672 .728 .891 r
F
.52576 .34485 m .52592 .34494 L p .52585 .34485 L F P
0 g
s
.52579 .34479 m .52577 .34484 L .52585 .34485 L .672 .728 .891 r
F
.52577 .34484 m .52576 .34485 L .52585 .34485 L F
.52592 .34494 m .52592 .34494 L .526 .34493 L F
.52611 .3448 m .52595 .34494 L .52608 .34481 L F
.52563 .34518 m .52562 .34519 L .52566 .34519 L F
.52557 .34528 m .52563 .34518 L .52577 .34524 L F
.52592 .34495 m .52526 .34554 L .52594 .34508 L F
.52595 .34494 m .52523 .34557 L .52594 .34494 L F
.52588 .34487 m .52617 .34493 L .5263 .34509 L F
.52595 .34494 m .52594 .34494 L .52608 .34481 L F
.52595 .34488 m .52603 .34493 L .52601 .34489 L F
.52541 .34507 m .52538 .34506 L .52626 .34494 L F
.52587 .34562 m .52632 .34677 L .52611 .34673 L F
.52611 .34676 m .52618 .34679 L .52616 .3466 L F
.52611 .34672 m .52616 .3466 L .5259 .3446 L F
.52611 .34676 m .52616 .3466 L .52611 .34672 L F
.52588 .34559 m .52632 .34677 L .52587 .34562 L F
.526 .34623 m .52606 .34626 L .52586 .34454 L F
.52599 .34535 m .52489 .34651 L .52597 .34528 L F
.52585 .34567 m .52489 .34651 L p .52599 .34535 L F P
0 g
s
.52613 .34631 m .526 .34528 L .526 .34529 L .672 .728 .891 r
F
.52611 .34672 m .52611 .34672 L .5261 .34658 L F
.52611 .34672 m .5261 .34658 L .52609 .34658 L F
.52586 .34558 m .526 .34623 L .52593 .34543 L F
.52606 .34578 m .526 .34534 L .526 .34534 L F
.52613 .34631 m .52617 .34633 L .52593 .34464 L F
.52593 .34463 m .52593 .34464 L .52588 .34425 L F
.52613 .34631 m .52593 .34464 L .52593 .34463 L F
.52599 .3447 m .52671 .34508 L .52671 .34508 L F
.52561 .3444 m .52563 .34449 L .52561 .3444 L F
.52563 .34449 m .52563 .34449 L .52561 .3444 L F
.52593 .34464 m .52535 .34432 L .5259 .3446 L F
.52555 .34416 m .52561 .3444 L .52561 .3444 L F
.52594 .34465 m .52584 .3446 L .52555 .34416 L F
.52555 .34416 m .52563 .3445 L .52586 .34454 L F
.52586 .34458 m .52535 .34432 L .52586 .34457 L F
.52535 .34432 m .52586 .34457 L .52586 .34457 L F
.52587 .34464 m .52587 .34464 L .52541 .3444 L F
.52598 .3447 m .52598 .3447 L .52541 .3444 L F
.52535 .34432 m .52547 .34434 L .52586 .34454 L F
.52535 .34432 m .52586 .34454 L .52589 .34458 L F
.52541 .3444 m .52584 .34458 L .52583 .3446 L F
.52604 .34477 m .52486 .34413 L .52599 .34471 L F
.52486 .34413 m .52383 .34358 L .52484 .3441 L F
.52486 .34413 m .52484 .3441 L .52599 .34471 L F
.52553 .34436 m .52591 .34485 L .52588 .34457 L F
.52571 .34484 m .52589 .34486 L .52579 .34484 L F
.52385 .34358 m .52483 .34409 L .52483 .34409 L F
.5251 .34446 m .52611 .34485 L .52512 .34449 L F
.52358 .34326 m .52576 .34485 L .52579 .34479 L F
.52401 .34361 m .51179 .33707 L .52487 .34375 L F
.52335 .3431 m .52356 .34325 L .52358 .34326 L F
.52336 .34332 m .52344 .3433 L .52549 .3444 L F
.52356 .34325 m .52576 .34485 L .52358 .34326 L F
.52574 .34491 m .52414 .34521 L .52577 .34484 L F
.52577 .34484 m .52571 .34484 L .52579 .34484 L F
.52634 .34492 m .52639 .34491 L .52737 .34543 L F
.52683 .34514 m .52656 .345 L .52656 .345 L F
.5263 .34509 m .52642 .34497 L .52683 .3452 L F
.52656 .345 m .52665 .34502 L .52682 .34511 L F
.52668 .34503 m .52639 .3452 L .52675 .34507 L F
.52685 .34528 m .52683 .3452 L .52728 .34544 L F
.52703 .34535 m .52703 .34537 L .52722 .34552 L F
.52671 .34508 m .52714 .34531 L .52714 .34531 L F
.52675 .34507 m .52708 .34558 L .52719 .34533 L F
.52489 .34651 m .52503 .34613 L .52597 .34528 L F
.52489 .34651 m .52585 .34567 L p .52454 .34645 L F P
0 g
s
.52454 .34645 m .52585 .34567 L .52581 .34566 L .672 .728 .891 r
F
.52581 .34542 m .52586 .34566 L .52585 .34567 L F
.52584 .34566 m .52585 .34567 L .52584 .3457 L F
.52581 .34542 m .52585 .34567 L .52584 .34566 L F
.52608 .34572 m .52586 .34567 L .52581 .34542 L F
.52584 .34566 m .52585 .34547 L .52583 .34545 L F
.52584 .3457 m .52584 .34565 L .52584 .34566 L F
.52584 .34565 m .52585 .34547 L .52584 .34566 L F
.52584 .3457 m .52587 .3455 L .52585 .34547 L F
.52562 .34562 m .52589 .34556 L .52571 .34555 L F
.52601 .34534 m .52608 .34572 L .52581 .34542 L F
.52601 .34553 m .52585 .34567 L p .5259 .34555 L F P
0 g
s
.52601 .34553 m .5259 .34555 L .52599 .34535 L .672 .728 .891 r
F
.52589 .34556 m .52601 .34553 L .5259 .34554 L F
.52581 .34542 m .52584 .34566 L .52583 .34545 L F
.52589 .34556 m .5259 .34554 L .52571 .34555 L F
.52454 .34645 m .52581 .34566 L .52562 .34562 L F
.52584 .34566 m .52584 .34566 L .52583 .34545 L F
.52581 .34566 m .52601 .34553 L .52562 .34562 L F
.52584 .34566 m .52584 .3457 L .52584 .34566 L F
.52639 .3452 m .52632 .34479 L p .52626 .34505 L F P
0 g
s
.52655 .345 m .52683 .34514 L .52655 .345 L .672 .728 .891 r
F
.52639 .3452 m .52622 .34488 L .52624 .34486 L F
.52639 .3452 m .52627 .34505 L .5262 .34484 L F
.52616 .34492 m .52639 .3452 L .52668 .34503 L F
.52595 .34535 m .5271 .34427 L .5271 .34427 L F
.52648 .34469 m .52657 .34471 L .52677 .34461 L F
.52707 .34436 m .5271 .34436 L .52773 .34405 L F
.52608 .34482 m .52773 .34405 L .52772 .34405 L F
.5271 .34427 m .52675 .3446 L .5271 .34427 L F
.52675 .3446 m .52675 .3446 L .5271 .34427 L F
.52731 .34434 m .52692 .34449 L .5279 .34352 L F
.52608 .34481 m .52692 .34453 L .52813 .34378 L F
.52772 .34405 m .52773 .34405 L .5283 .34377 L F
.52857 .34352 m .52679 .34489 L p .5285 .34342 L F P
0 g
s
.52809 .34378 m .52813 .34378 L .52857 .34352 L .672 .728 .891 r
F
.52809 .34378 m .52857 .34352 L .52865 .34347 L F
.52806 .34377 m .52809 .34378 L .52865 .34347 L F
.52608 .34481 m .52813 .34378 L .52806 .34377 L F
.52616 .34492 m .52639 .3452 L .52616 .34492 L F
.52639 .34675 m .52639 .3452 L .52626 .34505 L F
.52646 .34766 m .52643 .34671 L .52639 .34675 L F
.52643 .34671 m .52639 .3452 L .52639 .34675 L F
.52646 .34562 m .52618 .34491 L .52621 .34488 L F
.52603 .34493 m .52639 .3452 L .52616 .34492 L F
.52495 .34574 m .52538 .34558 L .52607 .34513 L F
.52608 .34511 m .52607 .34513 L .52624 .34502 L F
.52495 .34574 m .52607 .34513 L .52608 .34511 L F
.526 .34529 m .52597 .3451 L .52597 .3451 L F
.526 .34534 m .526 .34529 L .526 .34529 L F
.526 .34529 m .52597 .3451 L .526 .34529 L F
.52634 .34643 m .52621 .34498 L .52628 .34639 L F
.52631 .34523 m .52614 .34498 L .52618 .34491 L F
.52624 .34688 m .52605 .34503 L .52599 .34508 L F
.52634 .34758 m .52626 .34686 L .52624 .34688 L F
.52626 .34686 m .52605 .34503 L .52624 .34688 L F
.53043 .34498 m .52946 .34504 L p .53066 .34465 L F P
0 g
s
.52946 .34504 m .5288 .34493 L .53066 .34465 L .672 .728 .891 r
F
.52679 .34506 m .52675 .34507 L .52724 .34515 L F
.52682 .34507 m .52694 .34513 L .52713 .34513 L F
.52686 .34507 m .52713 .34513 L .52832 .34508 L F
.52682 .34507 m .52713 .34513 L .52686 .34507 L F
.53536 .34936 m .52731 .34516 L .5359 .3503 L F
.52731 .34516 m .52697 .34499 L .52724 .34515 L F
.52731 .34516 m .52724 .34515 L .53591 .35031 L F
.5359 .3503 m .53591 .35031 L .54086 .35327 L F
.52731 .34516 m .53591 .35031 L .5359 .3503 L F
.52726 .34515 m .52729 .34509 L .53066 .34465 L F
.52975 .34517 m .53267 .34514 L p .5296 .34497 L F P
0 g
s
.53267 .34514 m .53653 .34509 L p .5296 .34497 L .672 .728 .891 r
F P
0 g
s
.52941 .3447 m .5296 .34497 L .53653 .34509 L .672 .728 .891 r
F
.53241 .34514 m .5282 .34518 L p .53257 .34486 L F P
0 g
s
.52604 .34521 m .52597 .34528 L .52607 .34515 L .672 .728 .891 r
F
.52615 .3459 m .52622 .346 L .52608 .34501 L F
.52615 .3459 m .52608 .34501 L .52607 .34502 L F
.52631 .34523 m .52601 .34534 L .526 .34531 L F
.5263 .34465 m .52618 .34396 L p .52624 .34477 L F P
0 g
s
.52628 .34465 m .52627 .3447 L .5263 .34465 L .672 .728 .891 r
F
.52628 .34465 m .52627 .3447 L .52628 .34465 L F
.52628 .34465 m .52627 .34471 L .52627 .3447 L F
.52624 .34477 m .52618 .34396 L .5262 .34485 L F
.52628 .34465 m .52608 .34481 L .52627 .34471 L F
.52618 .34397 m .52618 .34396 L .52618 .34397 L F
.52618 .34397 m .52618 .34397 L .52612 .34402 L F
.52606 .34395 m .526 .34374 L p .52604 .34397 L F P
0 g
s
.52618 .34396 m .52629 .34462 L p .52585 .34379 L .672 .728 .891 r
F P
0 g
s
.52678 .34478 m .52676 .34466 L .52692 .34449 L .672 .728 .891 r
F
.52628 .34492 m .5264 .34491 L .52709 .34447 L F
.52692 .34453 m .52709 .34447 L .52865 .34347 L F
.52596 .34546 m .5271 .34427 L .52714 .34427 L F
.52675 .3446 m .52642 .34491 L .52675 .3446 L F
.52628 .34492 m .52709 .34447 L .52692 .34453 L F
.52625 .34485 m .52661 .34495 L .52643 .34485 L F
.5261 .34485 m .52622 .34487 L .52625 .34485 L F
.52626 .34505 m .52632 .34479 L .52629 .34478 L F
.52622 .34487 m .52661 .34495 L .52625 .34485 L F
.52628 .34483 m .5263 .34465 L .52625 .34486 L F
.52632 .34479 m .5263 .34465 L p .52629 .34478 L F P
0 g
s
.52629 .34462 m .52632 .34479 L p .52623 .34477 L .672 .728 .891 r
F P
0 g
s
.52637 .34497 m .52626 .34494 L .52654 .34491 L .672 .728 .891 r
F
.52729 .34468 m .52722 .34508 L .52736 .34469 L F
.52659 .34494 m .52654 .34491 L .52907 .34459 L F
.52637 .34497 m .52654 .34491 L .52659 .34494 L F
.52632 .3448 m .52639 .3452 L .52625 .34485 L F
.52632 .34479 m .52632 .3448 L p .52632 .3448 L F P
0 g
s
.52756 .34478 m .52613 .34496 L .52759 .34472 L .672 .728 .891 r
F
.52768 .34474 m .52759 .34472 L .52784 .34468 L F
.52756 .34478 m .52759 .34472 L .52768 .34474 L F
.52624 .34473 m .52603 .34493 L .52627 .34467 L F
.52589 .34486 m .52616 .34492 L .52614 .34489 L F
.53211 .34825 m .52953 .34688 L .53194 .34796 L F
.52953 .34688 m .52976 .34687 L .53194 .34796 L F
.52639 .3452 m .52647 .34517 L .53194 .34796 L F
.52937 .34648 m .52937 .34647 L .53009 .34686 L F
.5301 .34697 m .52793 .34579 L .53009 .34686 L F
.52793 .34579 m .52791 .34571 L .53009 .34686 L F
.53194 .34796 m .5301 .34697 L .53009 .34686 L F
.54086 .35327 m .53223 .34846 L p .53194 .34796 L F P
0 g
s
.52945 .34647 m .52805 .34583 L .54086 .35327 L .672 .728 .891 r
F
.52714 .34531 m .52937 .34647 L .52937 .34648 L F
.53009 .34686 m .52791 .34569 L .52788 .34554 L F
.52726 .34516 m .52805 .34583 L .52945 .34647 L F
.52717 .3452 m .52715 .34518 L .52788 .34554 L F
.52683 .34514 m .52682 .34511 L .52937 .34647 L F
.52791 .34569 m .52682 .34511 L .52788 .34554 L F
.52714 .34531 m .52937 .34647 L .52714 .34531 L F
.52671 .34508 m .52937 .34647 L .52671 .34508 L F
.52788 .34554 m .52715 .34518 L .52702 .34503 L F
.52726 .34516 m .52719 .34533 L .52805 .34583 L F
.52953 .34688 m .52639 .3452 L .52976 .34687 L F
.53223 .34846 m .53181 .34822 L p .53211 .34825 L F P
0 g
s
.53181 .34822 m .52639 .3452 L p .53211 .34825 L .672 .728 .891 r
F P
0 g
s
.52793 .34579 m .52748 .34555 L .52791 .34571 L .672 .728 .891 r
F
.52748 .34555 m .52737 .34543 L .52791 .34571 L F
.52708 .34558 m .54086 .35327 L p .52719 .34533 L F P
0 g
s
.53019 .3468 m .52719 .34544 L .5302 .34667 L .672 .728 .891 r
F
.52598 .3447 m .52671 .34508 L .52599 .3447 L F
.52632 .3448 m .52608 .34481 L .52625 .34485 L F
.52632 .34479 m .52625 .34485 L .52623 .34477 L F
.52614 .34498 m .52616 .34492 L .52618 .34491 L F
.52616 .34492 m .52637 .34497 L .52614 .34489 L F
.52513 .34562 m .52609 .34509 L .52613 .34501 L F
.52597 .34528 m .52595 .34514 L .52616 .34491 L F
.52622 .34488 m .5262 .34484 L .52624 .34486 L F
.52623 .34477 m .52617 .34472 L .52621 .34474 L F
.52632 .3448 m .52639 .3452 L p .52632 .3448 L F P
0 g
s
.52626 .34505 m .52628 .34483 L .52625 .34486 L .672 .728 .891 r
F
.52619 .3449 m .52637 .34497 L .52661 .34495 L F
.52614 .34489 m .52618 .34491 L .52619 .3449 L F
.52618 .34491 m .52637 .34497 L .52619 .3449 L F
.52625 .34485 m .52621 .34481 L .52623 .34477 L F
.52639 .3452 m .52624 .34486 L .52625 .34485 L F
.52624 .34486 m .52621 .34481 L .52625 .34485 L F
.52621 .34481 m .52617 .34472 L .52623 .34477 L F
.5268 .34505 m .52681 .34504 L .52681 .34505 L F
.52681 .34505 m .52692 .34501 L .52682 .34504 L F
.52677 .34504 m .52692 .34501 L .52681 .34505 L F
.52682 .34504 m .52692 .34501 L .52723 .34497 L F
.52703 .34514 m .52723 .34497 L .52825 .34483 L F
.52661 .34495 m .52678 .34505 L .52817 .34508 L F
.52819 .34507 m .52817 .34508 L .52832 .34508 L F
.52661 .34495 m .52817 .34508 L .52819 .34507 L F
.52624 .34492 m .52616 .34492 L .52665 .34437 L F
.52616 .34492 m .52618 .34489 L .52665 .34437 L F
.5263 .34465 m .52627 .34471 L .52636 .34467 L F
.52635 .34463 m .52624 .34473 L .52631 .34462 L F
.52624 .34473 m .52627 .34467 L .52631 .34462 L F
.52614 .34489 m .52661 .34495 L .5261 .34485 L F
.52638 .3449 m .52625 .34492 L .52665 .34439 L F
.52621 .34474 m .52612 .34462 L .52617 .34463 L F
.52592 .34457 m .52588 .34425 L .52591 .34457 L F
.52624 .34486 m .5262 .34484 L .52621 .34481 L F
.52628 .34465 m .52636 .34467 L .52848 .34355 L F
.52618 .34489 m .52624 .34473 L .52674 .34427 L F
.52602 .34474 m .52604 .34477 L .52594 .34403 L F
.52714 .34427 m .5271 .34427 L .5279 .34352 L F
.52833 .34349 m .52731 .34434 L .5279 .34352 L F
.5271 .34427 m .5271 .34427 L .52789 .34352 L F
.5271 .34427 m .5271 .34427 L .52789 .34352 L F
.52707 .344 m .52628 .34465 L .52848 .34355 L F
.5279 .34352 m .52789 .34352 L .52789 .34352 L F
.53084 .3414 m .52833 .34349 L .5279 .34352 L F
.52881 .34258 m .52707 .344 L .52865 .34347 L F
.52707 .344 m .52848 .34355 L .52865 .34347 L F
.52675 .34488 m .52573 .34434 L .52645 .3449 L F
.52591 .34461 m .52575 .34329 L .52591 .34461 L F
.52597 .3451 m .52587 .34426 L .52587 .34426 L F
.52591 .34461 m .52575 .34329 L .5259 .3446 L F
.52587 .34426 m .52588 .34425 L .52575 .34329 L F
.5261 .34468 m .52588 .34457 L .52564 .3435 L F
.52586 .34454 m .52436 .34379 L .52555 .34416 L F
.52568 .34431 m .52553 .34436 L .52588 .34457 L F
.52588 .34457 m .52585 .34455 L .52585 .34453 L F
.52555 .34416 m .5259 .3446 L .52574 .3433 L F
.52588 .34457 m .52585 .34453 L .52564 .3435 L F
.52623 .34475 m .52621 .34476 L .52624 .34473 L F
.52586 .34456 m .52588 .34457 L .5261 .34468 L F
.52617 .34472 m .52612 .34462 L .52621 .34474 L F
.52618 .34491 m .52592 .34422 L .52621 .34488 L F
.52592 .34422 m .52591 .34418 L .52592 .34422 L F
.52604 .34477 m .52602 .34305 L .52582 .34321 L F
.52602 .34305 m .52602 .34298 L .52599 .34301 L F
.52602 .34305 m .52599 .34301 L .52582 .34321 L F
.52914 .34621 m .52737 .34544 L .52911 .34611 L F
.52719 .34544 m .52721 .34538 L .5302 .34667 L F
.52496 .34441 m .5251 .34446 L .52512 .34449 L F
.52421 .34399 m .52576 .34485 L p .52475 .34412 L F P
0 g
s
.5245 .34421 m .52454 .34422 L .52586 .34479 L .672 .728 .891 r
F
.5259 .34554 m .52601 .34553 L .52596 .34539 L F
.52584 .3457 m .52584 .3457 L .52584 .34568 L F
.52629 .34676 m .52634 .34703 L .52611 .34673 L F
.52632 .34677 m .52634 .34703 L .52629 .34676 L F
.52632 .34677 m .52648 .34719 L .52634 .34703 L F
.52634 .34758 m .52646 .34766 L .52622 .346 L F
.52634 .34758 m .52622 .346 L .52615 .3459 L F
.52628 .34754 m .52601 .34538 L .526 .34538 L F
.52628 .34754 m .52606 .34578 L .52606 .34578 L F
.526 .34623 m .52611 .34676 L .52606 .34626 L F
.52628 .34754 m .52634 .34758 L .52617 .34633 L F
.52628 .34754 m .52617 .34633 L .52613 .34631 L F
.52648 .34719 m .52966 .35765 L .52624 .34737 L F
.52723 .35028 m .52684 .34793 L p .52677 .34984 L F P
0 g
s
.52677 .34984 m .52684 .34793 L .52646 .34766 L .672 .728 .891 r
F
.52642 .34819 m .52655 .34827 L .52646 .34766 L F
.52642 .34819 m .52646 .34766 L .52634 .34758 L F
.52628 .34754 m .52642 .34819 L .52634 .34758 L F
.52642 .34819 m .52677 .34984 L .52655 .34827 L F
.52848 .35777 m .52723 .35028 L p .52677 .34984 L F P
0 g
s
.52608 .34572 m .52848 .35777 L .52586 .34567 L .672 .728 .891 r
F
.52584 .3457 m .52607 .34575 L .52584 .34568 L F
.52568 .34431 m .52588 .34457 L .52645 .3449 L F
.52621 .34471 m .5262 .34471 L .52645 .3449 L F
.52611 .344 m .52603 .34391 L .52604 .34477 L F
.52573 .34434 m .5262 .34471 L .52621 .34471 L F
.52573 .34434 m .52572 .34434 L .5262 .34471 L F
.52629 .34462 m .52623 .34477 L .52585 .34379 L F
.52675 .34488 m .52593 .34463 L .52593 .34445 L F
.52586 .34456 m .52585 .34455 L .52588 .34457 L F
.52483 .34409 m .52598 .3447 L .52599 .3447 L F
.52541 .3444 m .52598 .3447 L .52541 .3444 L F
.52541 .3444 m .52549 .3444 L .52584 .34458 L F
.52732 .34543 m .52733 .34543 L .5302 .34667 L F
.52737 .34544 m .52721 .34538 L .52729 .34535 L F
.52737 .34544 m .52729 .34535 L .52911 .34611 L F
.52619 .34527 m .52617 .34493 L .52612 .3453 L F
.52631 .34523 m .526 .34531 L .52614 .34498 L F
.52597 .34528 m .52616 .34491 L .5262 .34497 L F
.52614 .34497 m .52612 .34496 L .52615 .34493 L F
.52614 .34497 m .52615 .34493 L .52616 .34492 L F
.52614 .34498 m .52614 .34497 L .52616 .34492 L F
.52616 .34492 m .52616 .34491 L .52618 .34489 L F
.52608 .34481 m .5261 .34485 L .52625 .34485 L F
.52603 .34493 m .52602 .34493 L .52627 .34466 L F
.52627 .34467 m .52627 .34466 L .52631 .34462 L F
.52603 .34493 m .52627 .34466 L .52627 .34467 L F
.52616 .34484 m .52615 .34482 L .52621 .34476 L F
.52613 .34488 m .52615 .34482 L .52616 .34484 L F
.52613 .34488 m .52611 .34486 L .52615 .34482 L F
.52618 .34489 m .52595 .34466 L .5261 .34468 L F
.52595 .34466 m .52589 .34458 L .5261 .34468 L F
.52618 .34491 m .52617 .3449 L .52618 .34489 L F
.52617 .3449 m .52586 .34456 L .52618 .34489 L F
.5261 .34484 m .52609 .34483 L .52627 .34466 L F
.52627 .34466 m .52627 .34466 L .52631 .34462 L F
.5261 .34484 m .52627 .34466 L .52627 .34466 L F
.52631 .34462 m .52611 .3448 L .52608 .34481 L F
.52631 .34462 m .52609 .34483 L .52608 .34482 L F
.5262 .34484 m .52591 .34418 L .52597 .34414 L F
.52621 .34488 m .5262 .34484 L .5262 .34484 L F
.5262 .34484 m .52591 .34418 L .5262 .34484 L F
.52613 .34488 m .52621 .34476 L .52623 .34475 L F
.52621 .34481 m .5262 .34484 L .52612 .34462 L F
.52588 .34457 m .52616 .34492 L .52645 .3449 L F
.52588 .34457 m .52616 .34492 L .52588 .34457 L F
.52601 .34493 m .52599 .34494 L .52609 .34483 L F
.52593 .34502 m .52609 .34483 L .5261 .34484 L F
.52616 .34491 m .52624 .34473 L .52618 .34489 L F
.5254 .34556 m .52596 .34529 L .52596 .34529 L F
.52552 .34551 m .52551 .34552 L .52552 .34551 L F
.52542 .34556 m .52564 .34548 L .52568 .34543 L F
.52564 .34548 m .52597 .34536 L .52568 .34543 L F
.52568 .34543 m .52597 .34536 L .526 .34528 L F
.5254 .34556 m .526 .34528 L .52601 .34527 L F
.52597 .34528 m .52516 .34601 L .52595 .34514 L F
.52579 .34523 m .52601 .34534 L .52581 .34542 L F
.52603 .34493 m .52593 .34502 L .52602 .34493 L F
.52598 .34494 m .52598 .34494 L .52599 .34494 L F
.52593 .34502 m .52598 .34494 L .52598 .34494 L F
.52593 .34502 m .52593 .34499 L .52598 .34494 L F
.52593 .34502 m .52599 .34494 L .52601 .34493 L F
.5255 .34504 m .52567 .34498 L .52632 .3448 L F
.52571 .34484 m .52563 .34501 L .52609 .34498 L F
.52595 .34514 m .5261 .34493 L .52615 .34492 L F
.52609 .34498 m .52547 .34502 L .52603 .34503 L F
.52595 .34514 m .52593 .34502 L .52603 .34493 L F
.52124 .34553 m .52303 .34542 L .5212 .34551 L F
.52303 .34542 m .5258 .34526 L .52302 .34541 L F
.52303 .34542 m .52302 .34541 L .5212 .34551 L F
.52415 .34692 m .5249 .34635 L p .5248 .34633 L F P
0 g
s
.52429 .34628 m .52415 .34692 L .5248 .34633 L .672 .728 .891 r
F
.514 .35471 m .52415 .34692 L p .52429 .34628 L F P
0 g
s
.52489 .34651 m .51493 .35522 L p .52503 .34613 L .672 .728 .891 r
F P
0 g
s
.52301 .34844 m .52293 .34833 L .52429 .34683 L .672 .728 .891 r
F
.5261 .34493 m .52613 .34488 L .52615 .34492 L F
.52603 .34493 m .52616 .34492 L .52616 .34492 L F
.52615 .34492 m .52613 .34488 L .52616 .34491 L F
.52601 .34489 m .52616 .34492 L .52588 .34457 L F
.52603 .34493 m .52616 .34492 L .52601 .34489 L F
.52495 .34574 m .52608 .34511 L .52609 .34509 L F
.52614 .34498 m .526 .34531 L .52596 .34509 L F
.52513 .34564 m .52609 .34509 L .52513 .34562 L F
.52608 .34482 m .52532 .34559 L .52523 .34557 L F
.52571 .34484 m .52613 .34495 L .52616 .34493 L F
.52571 .34484 m .52609 .34498 L .52613 .34495 L F
.52579 .34479 m .52592 .34494 L .52591 .34487 L F
.52608 .34481 m .52523 .34557 L .52527 .34548 L F
.52571 .34484 m .52637 .34497 L .52589 .34486 L F
.52589 .34486 m .52614 .34489 L .52579 .34484 L F
.52591 .34485 m .52595 .34488 L .52588 .34457 L F
.526 .34529 m .52592 .34457 L .52591 .34457 L F
.52595 .34488 m .52601 .34489 L .52588 .34457 L F
.52612 .34496 m .52596 .34509 L .52585 .34455 L F
.52614 .34498 m .52596 .34509 L .52612 .34496 L F
.52616 .34493 m .52621 .34497 L .52617 .34493 L F
.52613 .34495 m .52621 .34497 L .52616 .34493 L F
.52559 .34343 m .52562 .34346 L .52555 .34317 L F
.52562 .34386 m .52555 .34317 L .52558 .34387 L F
.52559 .3442 m .52547 .3433 L .52541 .34338 L F
.52544 .34364 m .52564 .34374 L .52574 .3433 L F
.5256 .34327 m .52577 .34415 L .52556 .34329 L F
.52301 .34553 m .52257 .34539 L .52489 .34513 L F
.52477 .34523 m .52489 .34513 L .52609 .345 L F
.52302 .34541 m .5258 .34526 L .52299 .34538 L F
.52301 .34553 m .52489 .34513 L .52477 .34523 L F
.52604 .34521 m .52607 .34515 L .5262 .34497 L F
.52628 .34639 m .52619 .34527 L .52612 .3453 L F
.52646 .34562 m .52613 .34592 L .52601 .34534 L F
.52611 .34583 m .52614 .34587 L .52612 .34543 L F
.52312 .34552 m .52467 .34537 L p .52303 .34542 L F P
0 g
s
.52301 .34553 m .52547 .3451 L .52555 .34514 L .672 .728 .891 r
F
.52473 .34516 m .52479 .34522 L .5257 .34518 L F
.52625 .34503 m .52604 .34521 L .5262 .34497 L F
.52664 .34502 m .52736 .34486 L .52674 .34503 L F
.5265 .34499 m .52736 .34486 L .5266 .34501 L F
.5279 .34488 m .52661 .34495 L .52832 .34508 L F
.5265 .34499 m .52637 .34497 L .52736 .34486 L F
.52675 .34488 m .52645 .3449 L .52675 .34507 L F
.52639 .3452 m .52633 .34522 L .52627 .34505 L F
.52895 .34468 m .52637 .34497 L .52907 .34459 L F
.52643 .34485 m .52661 .34495 L .5279 .34488 L F
.52675 .34488 m .52639 .3452 L p .5267 .34462 L F P
0 g
s
.52646 .34562 m .52601 .34534 L .52631 .34523 L .672 .728 .891 r
F
.52639 .3452 m .52601 .34553 L p .52632 .34512 L F P
0 g
s
.52626 .34504 m .52676 .34507 L .52625 .34503 L .672 .728 .891 r
F
.52645 .3449 m .52616 .34492 L .52668 .34503 L F
.52665 .34502 m .52681 .34504 L .5268 .34505 L F
.52661 .34495 m .52609 .34498 L .52678 .34505 L F
.52639 .3452 m .52632 .34512 L .5267 .34462 L F
.52625 .34503 m .52676 .34507 L .52681 .34505 L F
.52603 .34503 m .52626 .34504 L .52625 .34503 L F
.52601 .34553 m .52597 .34528 L .52625 .34503 L F
.526 .34493 m .52639 .3452 L .52603 .34493 L F
.52609 .34498 m .52603 .34503 L .52678 .34505 L F
.52632 .34512 m .52625 .34503 L .5267 .34462 L F
.52601 .34553 m .52625 .34503 L .52632 .34512 L F
.52634 .34514 m .52653 .34515 L .52656 .34514 L F
.52564 .34515 m .52635 .34515 L .52634 .34514 L F
.52635 .34515 m .52653 .34515 L .52634 .34514 L F
.52601 .34553 m .52639 .3452 L p .52596 .34539 L F P
0 g
s
.5254 .34556 m .52542 .34556 L .526 .34528 L .672 .728 .891 r
F
.52516 .34601 m .52593 .34502 L .52595 .34514 L F
.52553 .34508 m .52564 .34515 L .52656 .34514 L F
.52655 .345 m .52683 .34514 L .52683 .34515 L F
.52683 .34514 m .52683 .34514 L .52656 .345 L F
.5263 .34509 m .52728 .34544 L .52702 .34546 L F
.52656 .345 m .52682 .34511 L .52683 .34514 L F
.52639 .3452 m .52708 .34558 L p .52675 .34507 L F P
0 g
s
.52661 .34512 m .52656 .34514 L .52694 .34513 L .672 .728 .891 r
F
.52553 .34508 m .52656 .34514 L .52661 .34512 L F
.52564 .34515 m .5257 .34518 L .52585 .34518 L F
.52589 .34515 m .52585 .34518 L .52653 .34515 L F
.52516 .34601 m .52504 .34585 L .52593 .34502 L F
.52564 .34515 m .52585 .34518 L .52589 .34515 L F
.52572 .3443 m .52596 .34509 L .52569 .34439 L F
.52577 .34428 m .52596 .34509 L .52572 .3443 L F
.52596 .34509 m .52593 .34511 L .52569 .34439 L F
.52596 .34509 m .52601 .34534 L .52593 .34511 L F
.52589 .34523 m .52579 .34523 L p .52617 .34493 L F P
0 g
s
.52613 .34495 m .52609 .34498 L .52621 .34497 L .672 .728 .891 r
F
.52676 .34507 m .52694 .34513 L .52682 .34507 L F
.52609 .34483 m .52532 .34559 L .52608 .34482 L F
.52547 .3451 m .52609 .345 L .52555 .34514 L F
.52848 .35777 m .52728 .35783 L p .526 .34707 L F P
0 g
s
.52615 .34711 m .52848 .35777 L .526 .34707 L .672 .728 .891 r
F
.52586 .34566 m .52848 .35777 L .52584 .3457 L F
.52646 .34766 m .52677 .34787 L .52639 .3452 L F
.52684 .34793 m .52682 .34782 L p .52677 .34787 L F P
0 g
s
.52682 .34782 m .52639 .3452 L p .52677 .34787 L .672 .728 .891 r
F P
0 g
s
.52646 .34766 m .52634 .34643 L .52628 .34639 L .672 .728 .891 r
F
.52646 .34562 m .52848 .35777 L p .52613 .34592 L F P
0 g
s
.52674 .35014 m .52642 .3456 L p .52634 .34989 L .672 .728 .891 r
F P
0 g
s
.52549 .34506 m .52661 .34512 L .52676 .34507 L .672 .728 .891 r
F
.52553 .34508 m .52661 .34512 L .52549 .34506 L F
.52605 .34532 m .52675 .34488 L .5267 .34489 L F
.52603 .34503 m .52599 .34506 L .52676 .34507 L F
.52639 .3452 m .52589 .34523 L p .52617 .34493 L F P
0 g
s
.52625 .34503 m .52622 .345 L .52797 .34579 L .672 .728 .891 r
F
.5279 .34578 m .52797 .34579 L .53224 .34774 L F
.52625 .34503 m .52797 .34579 L .5279 .34578 L F
.52638 .34512 m .52675 .34488 L .52638 .34511 L F
.5257 .34518 m .52639 .3452 L .52635 .34516 L F
.52638 .34512 m .52638 .34511 L .52605 .34532 L F
.52609 .34531 m .52638 .34512 L .52605 .34532 L F
.52656 .34514 m .52653 .34515 L .52694 .34513 L F
.52674 .34518 m .52726 .34515 L p .52667 .34516 L F P
0 g
s
.52635 .34516 m .52674 .34518 L .52667 .34516 L .672 .728 .891 r
F
.52639 .3452 m .52674 .34518 L p .52635 .34516 L F P
0 g
s
.52732 .34477 m .52613 .34496 L .52734 .34472 L .672 .728 .891 r
F
.52731 .34434 m .52678 .34478 L .52692 .34449 L F
.52678 .3449 m .52865 .34347 L p .52677 .34468 L F P
0 g
s
.52632 .3448 m .52625 .34485 L .5279 .34488 L .672 .728 .891 r
F
.52648 .3449 m .52683 .34465 L .52645 .34491 L F
.52648 .3449 m .52645 .34491 L .52606 .34518 L F
.52683 .34465 m .52683 .34465 L .52645 .34491 L F
.52645 .34491 m .52645 .34491 L .52606 .34518 L F
.52683 .34465 m .52645 .34491 L .52645 .34491 L F
.52592 .34422 m .52592 .34422 L .52621 .34488 L F
.52603 .34476 m .52604 .34387 L .526 .34396 L F
.52606 .34534 m .52605 .34478 L .52603 .34476 L F
.52641 .34491 m .52605 .34477 L .52675 .34488 L F
.5258 .34427 m .52601 .34534 L .52578 .34429 L F
.52547 .34502 m .52576 .34504 L .52576 .34502 L F
.52576 .34504 m .52599 .34506 L .52576 .34502 L F
.52576 .34502 m .52599 .34506 L .52603 .34503 L F
.5257 .34447 m .52593 .34511 L .52579 .34523 L F
.52579 .34443 m .5258 .34427 L .52579 .34428 L F
.52534 .34443 m .52591 .34485 L .52553 .34436 L F
.54086 .35327 m .54161 .35263 L p .53536 .34936 L F P
0 g
s
.53536 .34936 m .5359 .3503 L .54086 .35327 L .672 .728 .891 r
F
.52529 .34444 m .526 .34493 L .52533 .34443 L F
.52581 .34542 m .5258 .34447 L .52579 .34446 L F
.52588 .34457 m .52616 .34492 L .52616 .34492 L F
.52612 .34496 m .52586 .34456 L .52618 .34491 L F
.52608 .34481 m .52605 .34478 L .52606 .34539 L F
.52604 .34523 m .52648 .3449 L .52606 .34518 L F
.52516 .34601 m .51493 .35522 L .52504 .34585 L F
.52495 .34574 m .52513 .34564 L .52513 .34562 L F
.52495 .34574 m .52429 .34628 L .52538 .34558 L F
.52532 .34559 m .52136 .34926 L .52517 .34556 L F
.52517 .34564 m .52221 .34841 L .52576 .34543 L F
.52583 .34545 m .52584 .34526 L .52583 .34526 L F
.52517 .34564 m .52576 .34543 L .52606 .34518 L F
.52609 .34511 m .52606 .34518 L .52624 .34502 L F
.52593 .34511 m .52601 .34534 L .52579 .34523 L F
.52575 .34521 m .52639 .3452 L .5257 .34518 L F
.52579 .34523 m .52581 .34542 L .52581 .34524 L F
.52517 .34564 m .52606 .34518 L .52609 .34511 L F
.52571 .34555 m .52693 .34473 L .52699 .34456 L F
.52606 .34534 m .52606 .34518 L .52606 .34534 L F
.52606 .34518 m .52605 .34478 L .52606 .34519 L F
.52599 .34534 m .52656 .3449 L .52602 .34526 L F
.52656 .3449 m .52653 .3449 L .52595 .3453 L F
.52639 .3452 m .52675 .34488 L p .52609 .34531 L F P
0 g
s
.52679 .34505 m .52641 .34491 L .52675 .34488 L .672 .728 .891 r
F
.52661 .34512 m .52694 .34513 L .52676 .34507 L F
.52617 .34493 m .52621 .34497 L .52637 .34497 L F
.52587 .34456 m .52587 .34456 L .52583 .34526 L F
.52584 .34568 m .52603 .34476 L .52598 .3447 L F
.52586 .3448 m .52586 .34479 L .52621 .34494 L F
.52625 .34503 m .5262 .34497 L .52625 .34492 L F
.52702 .3451 m .52639 .3452 L .52617 .34493 L F
.52618 .34493 m .52621 .34494 L .52733 .34543 L F
.52605 .34477 m .52593 .34463 L .52675 .34488 L F
.52608 .34481 m .52608 .34462 L .52607 .34461 L F
.52609 .34511 m .52608 .34482 L .52609 .34512 L F
.52609 .34511 m .5261 .34508 L .5261 .34499 L F
.52609 .34511 m .5261 .34499 L .52609 .345 L F
.52587 .3455 m .52602 .34446 L .52585 .34547 L F
.52579 .34523 m .52578 .34523 L p .52617 .34493 L F P
0 g
s
.52581 .34542 m .52583 .34545 L .5258 .34427 L .672 .728 .891 r
F
.52457 .3453 m .52485 .34528 L p .52465 .34522 L F P
0 g
s
.52557 .34528 m .52529 .34523 L .52563 .34518 L .672 .728 .891 r
F
.52485 .34528 m .52639 .3452 L p .52479 .34522 L F P
0 g
s
.52465 .34522 m .52485 .34528 L .52479 .34522 L .672 .728 .891 r
F
.52221 .34841 m .52489 .34651 L .52454 .34645 L F
.52443 .34699 m .52434 .34689 L .5253 .34577 L F
.52586 .3448 m .52616 .34492 L .52617 .34493 L F
.52609 .34512 m .52608 .34482 L .52608 .34481 L F
.52609 .345 m .5261 .34499 L .52608 .34462 L F
.52597 .34538 m .52609 .34531 L .52605 .34532 L F
.52596 .34539 m .52609 .34531 L .52597 .34538 L F
.52585 .34567 m .52601 .34553 L p .52581 .34566 L F P
0 g
s
.52584 .34568 m .52607 .34575 L .52605 .3452 L .672 .728 .891 r
F
.52585 .34563 m .52605 .3452 L .52603 .34476 L F
.52584 .34568 m .52605 .3452 L .52585 .34563 L F
.52571 .34555 m .52596 .34539 L .52597 .34538 L F
.52617 .34493 m .52578 .34523 L .52607 .3448 L F
.52588 .34488 m .52588 .34488 L .52628 .34507 L F
.52617 .34493 m .52609 .34511 L .52624 .34502 L F
.5262 .34497 m .52616 .34492 L .52624 .34492 L F
.52638 .3449 m .52625 .34503 L .52625 .34492 L F
.52617 .34493 m .52624 .34502 L .52637 .34491 L F
.52617 .34493 m .52621 .34494 L .52618 .34493 L F
.52617 .34493 m .52618 .34493 L .52617 .34493 L F
.52618 .34493 m .52621 .34494 L .52617 .34493 L F
.52593 .34463 m .52593 .34463 L .52675 .34488 L F
.52613 .34488 m .52624 .34473 L .52616 .34491 L F
.52609 .34483 m .52626 .34474 L .52608 .34462 L F
.5261 .34508 m .52617 .34493 L .52609 .34483 L F
.52612 .34487 m .52605 .34477 L .52679 .34505 L F
.52617 .34493 m .52626 .34474 L .52609 .34483 L F
.52681 .34516 m .52612 .34487 L .52679 .34505 L F
.52588 .34449 m .52587 .34448 L .52583 .34526 L F
.52572 .34448 m .52593 .34511 L .5257 .34447 L F
.52569 .34439 m .52572 .34448 L .5257 .34447 L F
.52568 .34431 m .52579 .34523 L .52578 .34445 L F
.52629 .34894 m .52642 .3456 L .52612 .34543 L F
.52634 .34989 m .52636 .34871 L .52629 .34894 L F
.52636 .34871 m .52642 .3456 L .52629 .34894 L F
.52661 .34838 m .52607 .34776 L .52607 .34771 L F
.52584 .3457 m .52615 .34711 L .526 .34707 L F
.52621 .34882 m .52614 .34587 L .52611 .34583 L F
.52584 .3457 m .52621 .34882 L .52607 .34575 L F
.52647 .3479 m .52607 .34771 L .52583 .34573 L F
.52621 .34882 m .52629 .34888 L .52614 .34587 L F
.52661 .34838 m .52607 .34771 L .52647 .3479 L F
.52584 .34526 m .52587 .34456 L .52583 .34526 L F
.52593 .34463 m .52578 .34445 L .52593 .34445 L F
.52585 .34547 m .52589 .34424 L .52583 .34545 L F
.52593 .34502 m .52532 .34559 L .52593 .34499 L F
.52578 .34523 m .5255 .34507 L .52607 .3448 L F
.52577 .34484 m .52414 .34521 L .52384 .34509 L F
.52389 .34498 m .52384 .34509 L .52363 .345 L F
.52577 .34484 m .52384 .34509 L .52389 .34498 L F
.50775 .34702 m .50761 .34621 L p .52363 .345 L F P
0 g
s
.51925 .34564 m .52124 .34553 L .5212 .34551 L .672 .728 .891 r
F
.51761 .34606 m .52312 .34552 L p .51925 .34564 L F P
0 g
s
.51925 .34564 m .52312 .34552 L .52303 .34542 L .672 .728 .891 r
F
.50775 .34702 m .51761 .34606 L p .51925 .34564 L F P
0 g
s
.52414 .34521 m .50775 .34702 L .52363 .345 L .672 .728 .891 r
F
.54228 .35195 m .5429 .35125 L p .53099 .34655 L F P
0 g
s
.52571 .34484 m .52134 .34517 L .52563 .34501 L .672 .728 .891 r
F
.52553 .34501 m .5256 .34487 L .5257 .34485 L F
.52553 .34501 m .5257 .34485 L .52574 .34485 L F
.5255 .34507 m .52553 .34501 L .52574 .34485 L F
.5261 .34494 m .52562 .34472 L .52617 .34493 L F
.52562 .34472 m .5245 .34421 L .52563 .3447 L F
.526 .34493 m .52603 .34493 L .52444 .34376 L F
.52436 .34379 m .52401 .34361 L .52497 .34381 L F
.52444 .34376 m .52444 .34376 L .5243 .34365 L F
.52503 .34434 m .52507 .34437 L p .52555 .34416 L F P
0 g
s
.52336 .34332 m .52549 .3444 L .52541 .3444 L .672 .728 .891 r
F
.526 .34493 m .52444 .34376 L .52444 .34376 L F
.52562 .34472 m .52563 .3447 L .52617 .34493 L F
.52595 .34466 m .52586 .34456 L .52589 .34458 L F
.52585 .34547 m .52602 .34446 L .52589 .34443 L F
.5259 .34488 m .52574 .34485 L .52607 .3448 L F
.52617 .34493 m .52517 .34564 L .52609 .34511 L F
.52594 .34489 m .52622 .345 L .52625 .34503 L F
.52616 .34492 m .52621 .34494 L .52617 .34493 L F
.52619 .34493 m .52616 .34492 L .52619 .34493 L F
.52611 .34532 m .52626 .34474 L .5261 .34508 L F
.52612 .34543 m .52615 .3453 L .52611 .34532 L F
.52596 .34539 m .52639 .3452 L .52609 .34531 L F
.52615 .3453 m .52626 .34474 L .52611 .34532 L F
.52589 .3449 m .52628 .34507 L .5263 .3451 L F
.5259 .34496 m .52517 .34564 L .52617 .34493 L F
.52588 .34488 m .52628 .34507 L .52589 .3449 L F
.5267 .34462 m .52638 .3449 L .52665 .34439 L F
.52784 .34468 m .52732 .34477 L .52734 .34472 L F
.52754 .3447 m .52632 .3448 L .5279 .34488 L F
.52675 .34488 m .52593 .34463 L .52675 .34488 L F
.5389 .3356 m .53227 .34069 L p .53084 .3414 L F P
0 g
s
.53475 .33771 m .52881 .34258 L .53308 .34007 L .672 .728 .891 r
F
.53227 .34069 m .52857 .34352 L p .53084 .3414 L F P
0 g
s
.52857 .34352 m .5285 .34342 L .53084 .3414 L .672 .728 .891 r
F
.52865 .34347 m .53308 .34007 L p .52881 .34258 L F P
0 g
s
.53059 .34111 m .52712 .34425 L .52674 .34427 L .672 .728 .891 r
F
.52696 .34428 m .52782 .3437 L .52757 .34378 L F
.52712 .34425 m .5267 .34462 L .52674 .34427 L F
.52617 .34493 m .52705 .34427 L .52696 .34428 L F
.52705 .34427 m .52782 .3437 L .52696 .34428 L F
.5258 .34541 m .52603 .34525 L .52576 .34543 L F
.52603 .34525 m .52701 .34452 L .52604 .34523 L F
.52603 .34525 m .52604 .34523 L .52576 .34543 L F
.5261 .34541 m .52609 .34512 L .52606 .34539 L F
.52609 .34512 m .52608 .34481 L .52607 .34517 L F
.52609 .34512 m .52607 .34517 L .52606 .34539 L F
.52612 .34543 m .52626 .34504 L .52621 .34498 L F
.53026 .34145 m .5299 .34174 L .53059 .34111 L F
.52751 .34422 m .5299 .34174 L .53026 .34145 L F
.52751 .34422 m .52712 .34425 L .5299 .34174 L F
.53119 .341 m .52751 .34422 L p .53059 .34111 L F P
0 g
s
.53308 .34007 m .5389 .3356 L p .53475 .33771 L .672 .728 .891 r
F P
0 g
s
.53797 .33507 m .53119 .341 L p .53059 .34111 L .672 .728 .891 r
F P
0 g
s
.52667 .34432 m .52696 .34428 L .53512 .33756 L .672 .728 .891 r
F
.53686 .33472 m .52816 .34313 L .53512 .33756 L F
.53687 .3347 m .52816 .34313 L .53686 .33472 L F
.52608 .34462 m .52626 .34474 L .52622 .34409 L F
.52611 .344 m .52603 .34305 L .52603 .34391 L F
.52603 .34305 m .52602 .34298 L .52602 .34305 L F
.52604 .34388 m .52622 .34409 L .52548 .3324 L F
.52608 .34462 m .52622 .34409 L .52604 .34388 L F
.52634 .34456 m .52624 .34316 L p .52626 .34474 L F P
0 g
s
.52624 .34316 m .52548 .3324 L p .52616 .34305 L .672 .728 .891 r
F P
0 g
s
.52626 .34474 m .52624 .34316 L .52616 .34305 L .672 .728 .891 r
F
.53687 .3347 m .52733 .34362 L .52816 .34313 L F
.52733 .34362 m .52607 .3448 L .52762 .34356 L F
.52733 .34362 m .52762 .34356 L .52816 .34313 L F
.5267 .34462 m .52665 .34439 L .52674 .34427 L F
.52633 .3446 m .52626 .34474 L .52696 .34428 L F
.52626 .34474 m .52617 .34493 L .52651 .34465 L F
.52597 .34528 m .52665 .34437 L .52665 .34439 L F
.52626 .34474 m .52651 .34465 L .52696 .34428 L F
.52617 .34493 m .52637 .34491 L .52715 .34426 L F
.52607 .3448 m .52617 .34493 L .52633 .3446 L F
.52623 .34489 m .52635 .34479 L .52626 .34474 L F
.52635 .34479 m .52617 .34493 L .52607 .3448 L F
.52656 .3449 m .52687 .34466 L .52653 .3449 L F
.52687 .34466 m .52687 .34465 L .52595 .3453 L F
.52751 .34422 m .52675 .34488 L p .52712 .34425 L F P
0 g
s
.52675 .34488 m .52693 .34473 L p .5267 .34489 L .672 .728 .891 r
F P
0 g
s
.52699 .34456 m .52701 .34452 L .5258 .34541 L .672 .728 .891 r
F
.52785 .34475 m .52617 .34493 L .52635 .34479 L F
.52868 .3449 m .52825 .34483 L .52877 .34476 L F
.52754 .3447 m .5279 .34488 L .52959 .34478 L F
.52941 .3447 m .52796 .3448 L .52785 .34475 L F
.52796 .3448 m .52617 .34493 L .52785 .34475 L F
.52514 .34453 m .526 .3449 L .52594 .34489 L F
.52607 .3448 m .52574 .34485 L .52562 .34483 L F
.52563 .34482 m .52562 .34483 L .52558 .34482 L F
.52602 .34495 m .52514 .34453 L .52606 .34494 L F
.52607 .3448 m .52562 .34483 L .52563 .34482 L F
.52504 .34442 m .52502 .34439 L .52605 .34477 L F
.52579 .34523 m .52579 .34428 L .52578 .34428 L F
.52589 .34424 m .52589 .34424 L .52583 .34545 L F
.52605 .34477 m .52454 .34422 L .52593 .34463 L F
.52593 .34463 m .52454 .34422 L .52593 .34463 L F
.52383 .34358 m .52541 .3444 L .5254 .3444 L F
.52458 .34396 m .52523 .3443 L .52458 .34396 L F
.52523 .3443 m .52523 .3443 L .52385 .34358 L F
.52453 .34392 m .52529 .34444 L .5243 .34365 L F
.52529 .34444 m .52533 .34443 L .5243 .34365 L F
.52593 .34463 m .52533 .34445 L .52578 .34445 L F
.52541 .3444 m .52541 .3444 L .52523 .3443 L F
.52533 .34445 m .52454 .34422 L .52552 .34438 L F
.52533 .34445 m .52552 .34438 L .52593 .34445 L F
.52583 .34526 m .52587 .34455 L .52581 .34448 L F
.52616 .34492 m .52586 .34479 L .52612 .34487 L F
.52586 .34479 m .52454 .34422 L .52585 .34476 L F
.52586 .34479 m .52585 .34476 L .52612 .34487 L F
.52697 .34499 m .52675 .34488 L .52675 .34507 L F
.52681 .34505 m .52676 .34507 L .52832 .34508 L F
.52697 .34499 m .52679 .34506 L .52724 .34515 L F
.52726 .34514 m .52679 .34505 L .52675 .34488 L F
.5268 .34505 m .52679 .34505 L .52726 .34514 L F
.52739 .34484 m .52702 .3451 L .52617 .34493 L F
.52941 .3447 m .5273 .34505 L .52739 .34484 L F
.5273 .34505 m .52702 .3451 L .52739 .34484 L F
.52743 .34476 m .52635 .34479 L .52738 .34501 L F
.52763 .34487 m .52738 .34501 L .5282 .34518 L F
.52743 .34476 m .52738 .34501 L .52763 .34487 L F
.52611 .34583 m .52612 .34543 L .5261 .34541 L F
.52621 .34882 m .5261 .34541 L .52606 .34539 L F
.52646 .34562 m .52618 .34491 L .52646 .34562 L F
.52639 .3452 m .52646 .34562 L p .52633 .34522 L F P
0 g
s
.52639 .3452 m .52661 .34838 L p .52583 .34573 L .672 .728 .891 r
F P
0 g
s
.52598 .34563 m .52615 .34586 L .52619 .34529 L .672 .728 .891 r
F
.52606 .34539 m .52606 .34534 L .52606 .34534 L F
.52642 .3456 m .52639 .3452 L p .52612 .34543 L F P
0 g
s
.52621 .34498 m .52617 .34493 L .52683 .34522 L .672 .728 .891 r
F
.52619 .34493 m .52619 .34493 L .52667 .34511 L F
.52639 .3452 m .52636 .3448 L p .52626 .34505 L F P
0 g
s
.52612 .34543 m .52639 .3452 L .52626 .34505 L .672 .728 .891 r
F
.5261 .34494 m .52617 .34493 L .52617 .34493 L F
.5261 .34494 m .52617 .34493 L .52621 .34498 L F
.5261 .34541 m .52612 .34543 L .5261 .34508 L F
.52639 .3452 m .52583 .34573 L .526 .34532 L F
.52606 .34553 m .52581 .34578 L p .52602 .34537 L F P
0 g
s
.52639 .3452 m .52591 .34497 L p .5263 .3451 L .672 .728 .891 r
F P
0 g
s
.52592 .34502 m .52541 .34558 L .5259 .34496 L .672 .728 .891 r
F
.52541 .34558 m .52429 .34683 L .52534 .34561 L F
.52541 .34558 m .52534 .34561 L .5259 .34496 L F
.52591 .34497 m .5259 .34496 L .5263 .3451 L F
.52575 .34329 m .52571 .34299 L .52574 .3433 L F
.52558 .34387 m .52555 .34317 L .52547 .34329 L F
.52544 .34364 m .52574 .3433 L .52556 .34194 L F
.52618 .34396 m .52585 .34379 L .52548 .34268 L F
.52589 .34424 m .52595 .34282 L .52589 .34424 L F
.52589 .34443 m .52602 .34446 L .52595 .34282 L F
.52634 .34456 m .52615 .34453 L .52574 .34336 L F
.52635 .34479 m .52607 .3448 L .52626 .34487 L F
.52676 .34458 m .52677 .34461 L .52692 .34453 L F
.52675 .34488 m .5267 .34462 L .52712 .34425 L F
.52606 .34518 m .52701 .34452 L .5271 .3443 L F
.52636 .3448 m .52626 .34487 L .52669 .34501 L F
.52617 .34493 m .52715 .34426 L .52705 .34427 L F
.52621 .34498 m .52635 .34479 L .52623 .34489 L F
.52635 .34479 m .52626 .34487 L .52636 .3448 L F
.52626 .34474 m .52636 .3448 L .52634 .34456 L F
.52634 .34456 m .52636 .3448 L p .52624 .34477 L F P
0 g
s
.52636 .3448 m .52639 .3452 L p .52627 .34486 L .672 .728 .891 r
F P
0 g
s
.52636 .3448 m .52627 .34486 L .52624 .34477 L .672 .728 .891 r
F
.52631 .34459 m .52623 .3447 L .52631 .34459 L F
.52633 .34456 m .52624 .34477 L .52615 .34453 L F
.52634 .34456 m .52624 .34477 L .52633 .34456 L F
.52636 .34454 m .52631 .34459 L .52636 .34453 L F
.52631 .34459 m .52631 .34459 L .52636 .34453 L F
.52636 .34491 m .52623 .3447 L .52636 .34454 L F
.52612 .34487 m .52504 .34442 L .52605 .34477 L F
.52632 .34457 m .52597 .34496 L .52633 .34456 L F
.52608 .34481 m .52604 .34387 L .52605 .34478 L F
.52615 .34453 m .52624 .34477 L .52577 .34446 L F
.52616 .34492 m .52612 .34487 L .52723 .34533 L F
.52626 .34504 m .52635 .34479 L .52621 .34498 L F
.52626 .34504 m .52636 .3448 L .52635 .34479 L F
.52612 .34543 m .52626 .34505 L .52626 .34504 L F
.52626 .34505 m .52636 .3448 L .52626 .34504 L F
.5271 .34511 m .52639 .3452 L .52702 .3451 L F
.52684 .34528 m .52622 .345 L .52683 .34522 L F
.52622 .345 m .5261 .34494 L .52621 .34498 L F
.52622 .345 m .52621 .34498 L .52683 .34522 L F
.52658 .34502 m .52639 .3452 L .52667 .34508 L F
.52624 .34477 m .52627 .34486 L .52617 .34493 L F
.52617 .34493 m .52612 .34486 L .52623 .3447 L F
.52608 .34482 m .52608 .34462 L .52608 .34481 L F
.52587 .34456 m .52588 .34449 L .52587 .34456 L F
.52598 .3447 m .52603 .34476 L .52602 .34446 L F
.52624 .34477 m .52617 .34494 L .52577 .34446 L F
.52607 .3448 m .52616 .34492 L .52669 .34501 L F
.52636 .34491 m .52617 .34493 L .52623 .3447 L F
.52579 .34444 m .52618 .34493 L .52658 .34502 L F
.52627 .34486 m .52639 .3452 L .52617 .34493 L F
.52663 .34512 m .52619 .34493 L .52667 .34511 L F
.52618 .34493 m .52639 .3452 L .52658 .34502 L F
.52946 .34504 m .52726 .34515 L p .5288 .34493 L F P
0 g
s
.52915 .34517 m .52975 .34517 L p .52743 .34476 L .672 .728 .891 r
F P
0 g
s
.5282 .34518 m .5284 .34501 L .53257 .34486 L .672 .728 .891 r
F
.52941 .3447 m .52743 .34476 L .52975 .34517 L F
.53257 .34486 m .5284 .34501 L .52862 .34482 L F
.52924 .34482 m .52741 .3448 L .53097 .3453 L F
.52597 .34535 m .52599 .34534 L .52595 .3453 L F
.52571 .34555 m .5259 .34554 L .52596 .34539 L F
.52602 .34537 m .52495 .34646 L .526 .3453 L F
.52599 .34534 m .52602 .34526 L .52595 .3453 L F
.52576 .34543 m .52604 .34523 L .52606 .34518 L F
.52581 .34578 m .52578 .34581 L p .52596 .34542 L F P
0 g
s
.52596 .34535 m .52595 .3453 L .5258 .34541 L .672 .728 .891 r
F
.52597 .34535 m .52595 .3453 L .52596 .34535 L F
.52597 .34535 m .5258 .34541 L .52561 .34556 L F
.526 .34532 m .52583 .34573 L .52579 .34539 L F
.52603 .34527 m .52593 .34538 L .52617 .34493 L F
.52571 .34555 m .52597 .34535 L .52561 .34556 L F
.52593 .34538 m .52495 .34646 L .52576 .34545 L F
.52593 .34538 m .52576 .34545 L .52617 .34493 L F
.52636 .34453 m .52632 .34457 L .52633 .34456 L F
.52622 .34483 m .52641 .3444 L .52626 .34436 L F
.526 .3449 m .52622 .345 L .52594 .34489 L F
.52607 .3448 m .5259 .34496 L .52617 .34493 L F
.52633 .34456 m .52597 .34496 L .5259 .34496 L F
.52588 .34487 m .52589 .34496 L .52618 .34493 L F
.52579 .34523 m .52581 .34524 L .52579 .34428 L F
.5255 .34507 m .52574 .34485 L .5259 .34488 L F
.52582 .34486 m .52588 .34488 L .52589 .3449 L F
.52587 .34487 m .52588 .34488 L .52582 .34486 L F
.5261 .34541 m .52609 .34511 L .52609 .34512 L F
.52606 .34518 m .52606 .34519 L .52606 .34534 L F
.5261 .34541 m .5261 .34508 L .52609 .34511 L F
.52576 .34545 m .52566 .34548 L .52605 .34495 L F
.52578 .3452 m .52639 .3452 L .52579 .34539 L F
.52558 .34482 m .52614 .34495 L .52618 .34492 L F
.52597 .34496 m .52592 .34502 L .52591 .34497 L F
.5259 .34496 m .52599 .34495 L .5263 .3451 L F
.52589 .34496 m .5259 .34496 L .5259 .34496 L F
.5259 .34496 m .52599 .34495 L .5259 .34496 L F
.52602 .34495 m .52606 .34494 L .52625 .34503 L F
.52597 .34496 m .52591 .34497 L .5259 .34496 L F
.52602 .34495 m .52625 .34503 L .52627 .34506 L F
.52618 .34493 m .52611 .34494 L .52639 .3452 L F
.52591 .34497 m .52589 .34496 L p .5259 .34496 L F P
0 g
s
.52589 .34496 m .52591 .34497 L p .52611 .34494 L .672 .728 .891 r
F P
0 g
s
.52591 .34497 m .52639 .3452 L p .52611 .34494 L .672 .728 .891 r
F P
0 g
s
.52617 .34493 m .52597 .34519 L .52605 .34495 L .672 .728 .891 r
F
.52597 .34519 m .52576 .34545 L .52595 .34512 L F
.52597 .34519 m .52595 .34512 L .52605 .34495 L F
.52593 .34507 m .52592 .34504 L .52636 .34453 L F
.52607 .3448 m .52589 .34486 L .52616 .34492 L F
.52617 .34493 m .52605 .34495 L .52612 .34486 L F
.52563 .34482 m .52594 .34488 L .52616 .34492 L F
.52616 .34492 m .52616 .34492 L .52669 .34501 L F
.52563 .34482 m .52616 .34492 L .52616 .34492 L F
.52594 .3451 m .52593 .34507 L .52611 .34485 L F
.52612 .34486 m .52611 .34485 L .52636 .34453 L F
.52594 .3451 m .52611 .34485 L .52612 .34486 L F
.52581 .34445 m .52588 .34487 L .52617 .34493 L F
.52607 .3448 m .52563 .34482 L .52589 .34486 L F
.5258 .34447 m .52565 .34477 L .52574 .34484 L F
.52495 .34646 m .52503 .34622 L .52534 .34582 L F
.52495 .34646 m .52534 .34582 L .52538 .34587 L F
.52495 .34646 m .52443 .34699 L .52503 .34622 L F
.52578 .34581 m .51665 .35495 L p .52561 .34578 L F P
0 g
s
.51665 .35495 m .51591 .35569 L p .51661 .35497 L .672 .728 .891 r
F P
0 g
s
.51665 .35495 m .51661 .35497 L .52561 .34578 L .672 .728 .891 r
F
.52434 .34689 m .52429 .34683 L .52516 .34586 L F
.52484 .34675 m .52555 .34604 L p .52436 .34661 L F P
0 g
s
.52398 .34731 m .52489 .34651 L p .52431 .34693 L .672 .728 .891 r
F P
0 g
s
.52221 .34841 m .52398 .34731 L .52431 .34693 L .672 .728 .891 r
F
.52273 .3484 m .52398 .34731 L p .52221 .34841 L F P
0 g
s
.52301 .34844 m .52429 .34683 L .52434 .34689 L .672 .728 .891 r
F
.52443 .34699 m .52301 .34844 L .52434 .34689 L F
.52301 .34844 m .52071 .35079 L .52293 .34833 L F
.51493 .35522 m .52273 .3484 L p .52221 .34841 L F P
0 g
s
.52411 .34663 m .52071 .35079 L .52048 .35003 L .672 .728 .891 r
F
.52429 .34683 m .52071 .35079 L .52411 .34663 L F
.52136 .34926 m .51493 .35522 L .52129 .34874 L F
.52071 .35079 m .51616 .35544 L .52048 .35003 L F
.51616 .35544 m .51591 .35569 L .51612 .35543 L F
.51616 .35544 m .51612 .35543 L .52048 .35003 L F
.51591 .35569 m .52484 .34675 L p .52436 .34661 L F P
0 g
s
.52505 .34645 m .51692 .35612 L .52496 .3463 L .672 .728 .891 r
F
.52436 .34661 m .52555 .34604 L .52459 .3464 L F
.52505 .34645 m .52496 .3463 L .52526 .34593 L F
.52454 .34645 m .52571 .34555 L .52561 .34556 L F
.52443 .34699 m .5253 .34577 L .52534 .34582 L F
.52434 .34689 m .52516 .34586 L .52512 .34598 L F
.52555 .34604 m .52606 .34553 L p .52483 .34625 L F P
0 g
s
.52459 .3464 m .52479 .34632 L .52483 .34625 L .672 .728 .891 r
F
.52479 .34632 m .52555 .34604 L .52483 .34625 L F
.52228 .3432 m .52227 .34318 L .52599 .34495 L F
.52618 .34492 m .52617 .34493 L .52669 .34501 L F
.52616 .34493 m .52639 .3452 L .52578 .3452 L F
.52618 .34493 m .52617 .34493 L .52618 .34493 L F
.52617 .34493 m .52639 .3452 L .52617 .34494 L F
.52617 .34493 m .52619 .34496 L .52669 .34501 L F
.52636 .34491 m .52625 .34503 L .52617 .34493 L F
.52625 .34503 m .52603 .34527 L .52617 .34493 L F
.52627 .34506 m .52625 .34503 L .5279 .34578 L F
.52488 .3578 m .52369 .35771 L p .52549 .34691 L F P
0 g
s
.5263 .3451 m .52628 .34507 L .52971 .3467 L .672 .728 .891 r
F
.5263 .3451 m .52971 .3467 L .52971 .3467 L F
.5263 .3451 m .53028 .34697 L .53028 .34697 L F
.52728 .35783 m .52608 .35784 L p .5258 .34581 L F P
0 g
s
.52589 .34969 m .52596 .34897 L .52596 .34871 L .672 .728 .891 r
F
.53229 .34793 m .52708 .34545 L .53224 .34774 L F
.52708 .34545 m .52602 .34495 L .52713 .34544 L F
.52708 .34545 m .52713 .34544 L .53224 .34774 L F
.5255 .34507 m .52523 .34492 L .5256 .34487 L F
.52539 .34495 m .52631 .3451 L .52624 .34502 L F
.52498 .34491 m .52544 .34498 L .52539 .34495 L F
.52544 .34498 m .52631 .3451 L .52539 .34495 L F
.51526 .3458 m .52457 .3453 L p .51642 .34555 L F P
0 g
s
.51642 .34555 m .52457 .3453 L .52465 .34522 L .672 .728 .891 r
F
.52485 .34505 m .51642 .34555 L .52465 .34522 L F
.52574 .34485 m .52136 .34547 L .52558 .34482 L F
.52508 .34483 m .52498 .34491 L .52539 .34495 L F
.52526 .34486 m .52539 .34495 L .52676 .34506 L F
.52508 .34483 m .52539 .34495 L .52526 .34486 L F
.52602 .34537 m .52625 .34503 L .52627 .34505 L F
.52667 .34508 m .52661 .34511 L .52675 .34514 L F
.52635 .34516 m .52726 .34515 L .52713 .34513 L F
.52661 .34511 m .52639 .3452 L .52675 .34514 L F
.52586 .3448 m .52733 .34543 L .52732 .34543 L F
.52639 .3452 m .52772 .34585 L p .52675 .34514 L F P
0 g
s
.52624 .34502 m .52697 .3452 L .52676 .34506 L .672 .728 .891 r
F
.52631 .3451 m .52697 .3452 L .52624 .34502 L F
.53292 .34823 m .53519 .34931 L .53519 .34931 L F
.5263 .3451 m .53292 .34823 L .53292 .34823 L F
.53292 .34823 m .53519 .34931 L .53292 .34823 L F
.52621 .34882 m .52634 .34989 L .52629 .34888 L F
.52728 .35783 m .52674 .35014 L p .52634 .34989 L F P
0 g
s
.52661 .34838 m .52728 .35783 L p .52607 .34776 L .672 .728 .891 r
F P
0 g
s
.52583 .34573 m .52728 .35783 L .5258 .34581 L .672 .728 .891 r
F
.52627 .34984 m .52638 .34558 L p .52589 .34969 L F P
0 g
s
.5262 .34496 m .52676 .34506 L .5262 .34496 L .672 .728 .891 r
F
.52589 .34496 m .52356 .34382 L p .52599 .34495 L F P
0 g
s
.52587 .34487 m .52574 .34484 L .52589 .34496 L .672 .728 .891 r
F
.52534 .34582 m .52592 .34504 L .52593 .34507 L F
.5258 .34521 m .52639 .3452 L p .52544 .34498 L F P
0 g
s
.52663 .34512 m .52667 .34511 L .52723 .34533 L .672 .728 .891 r
F
.52726 .34515 m .52639 .3452 L p .5271 .34511 L F P
0 g
s
.52726 .34514 m .5271 .34511 L .52729 .34509 L .672 .728 .891 r
F
.52726 .34515 m .5271 .34511 L .52726 .34514 L F
.52681 .34516 m .52679 .34505 L .52782 .34543 L F
.52679 .34505 m .52679 .34505 L .5268 .34505 L F
.52679 .34505 m .5268 .34505 L .52782 .34543 L F
.52639 .3452 m .52697 .3452 L p .52657 .34514 L F P
0 g
s
.52544 .34498 m .52639 .3452 L .52657 .34514 L .672 .728 .891 r
F
.52617 .34493 m .52614 .34495 L .52619 .34496 L F
.52538 .34506 m .52414 .34521 L .52526 .345 L F
.52485 .34505 m .52553 .34508 L .52549 .34506 L F
.52485 .34505 m .52564 .34515 L .52553 .34508 L F
.52479 .34522 m .52575 .34521 L .5257 .34518 L F
.52465 .34522 m .52479 .34522 L .52479 .34522 L F
.52479 .34522 m .52639 .3452 L .52479 .34522 L F
.52473 .34516 m .5257 .34518 L .52564 .34515 L F
.52541 .34507 m .52414 .34521 L .52538 .34506 L F
.52485 .34505 m .52473 .34516 L .52564 .34515 L F
.52473 .34516 m .52465 .34522 L .52479 .34522 L F
.52547 .34502 m .52485 .34505 L .52536 .34506 L F
.52578 .34523 m .52136 .34547 L p .52523 .34492 L F P
0 g
s
.52491 .34497 m .5248 .34505 L .52571 .34519 L .672 .728 .891 r
F
.52491 .34497 m .52571 .34519 L .5258 .34521 L F
.52134 .34517 m .52177 .34523 L .52563 .34501 L F
.52498 .34491 m .52491 .34497 L .5258 .34521 L F
.52459 .34522 m .52498 .34522 L p .5248 .34505 L F P
0 g
s
.52498 .34522 m .5258 .34521 L p .5248 .34505 L .672 .728 .891 r
F P
0 g
s
.52534 .34561 m .52429 .34683 L .52511 .34569 L .672 .728 .891 r
F
.52532 .34559 m .52436 .34661 L .52545 .34558 L F
.52538 .34587 m .52534 .34582 L .52593 .34507 L F
.52538 .34587 m .52593 .34507 L .52594 .3451 L F
.52512 .34598 m .52516 .34586 L .52527 .34574 L F
.52512 .34598 m .52527 .34574 L .5253 .34577 L F
.52561 .34556 m .5258 .34541 L .52576 .34543 L F
.52576 .34545 m .52495 .34646 L .52566 .34548 L F
.52578 .34581 m .52561 .34578 L .52596 .34542 L F
.52579 .34539 m .52583 .34573 L .52581 .34578 L F
.5258 .34578 m .52581 .34578 L .5258 .34581 L F
.52579 .34539 m .52581 .34578 L .5258 .34578 L F
.52536 .34566 m .52606 .34553 L .52545 .34558 L F
.52493 .34607 m .52563 .34573 L .52536 .34566 L F
.52563 .34573 m .52606 .34553 L .52536 .34566 L F
.52459 .3464 m .52483 .34625 L .52493 .34607 L F
.52483 .34625 m .52606 .34553 L .52493 .34607 L F
.52592 .34512 m .5263 .34509 L .5263 .3451 L F
.52519 .34516 m .52593 .34511 L .52592 .34512 L F
.52593 .34511 m .5263 .34509 L .52592 .34512 L F
.52606 .34481 m .52616 .34493 L .52578 .3452 L F
.5253 .34577 m .52527 .34574 L .52541 .34558 L F
.52548 .34555 m .52541 .34558 L .52636 .34453 L F
.5253 .34577 m .52541 .34558 L .52548 .34555 L F
.5258 .34447 m .52574 .34484 L .52587 .34487 L F
.5258 .34447 m .52589 .34496 L .52581 .34445 L F
.52577 .34443 m .52578 .3452 L .52607 .3448 L F
.52508 .34483 m .52611 .34497 L .52614 .34495 L F
.52356 .34382 m .52355 .34379 L .52599 .34495 L F
.52389 .34395 m .52587 .34487 L .52582 .34486 L F
.52389 .34395 m .52588 .34488 L .52389 .34395 L F
.52363 .34382 m .52588 .34488 L .52362 .34383 L F
.52504 .34442 m .52454 .34422 L .52502 .34439 L F
.52154 .34284 m .52588 .34488 L .52588 .34488 L F
.52514 .34453 m .52517 .34451 L .52622 .345 L F
.52514 .34453 m .52395 .34396 L .52517 .34451 L F
.5245 .34421 m .52586 .34479 L .52586 .3448 L F
.52483 .34409 m .52598 .3447 L .52483 .34409 L F
.52454 .34422 m .52395 .34396 L .52593 .34445 L F
.52428 .34417 m .52589 .34496 L p .52487 .34415 L F P
0 g
s
.52458 .34396 m .52458 .34396 L .52385 .34358 L .672 .728 .891 r
F
.52385 .34358 m .52458 .34396 L .52385 .34358 L F
.52335 .3431 m .52421 .34399 L .52475 .34412 L F
.52573 .34434 m .52568 .34431 L .52572 .34434 L F
.52555 .34416 m .52436 .34379 L .52497 .34381 L F
.52568 .34431 m .52335 .3431 L .52553 .34436 L F
.52535 .34432 m .52436 .34379 L .52547 .34434 L F
.5243 .34365 m .52534 .34443 L .52553 .34436 L F
.52593 .34445 m .52395 .34396 L .52491 .34392 L F
.52445 .34383 m .52435 .34403 L .52487 .34415 L F
.5245 .34421 m .52395 .34396 L .52454 .34422 L F
.52435 .34403 m .52428 .34417 L .52487 .34415 L F
.52577 .34485 m .52576 .34485 L .52594 .34488 L F
.52563 .34482 m .52576 .34485 L .52577 .34485 L F
.52563 .34482 m .52558 .34482 L .52576 .34485 L F
.52558 .34482 m .52508 .34483 L .52555 .34489 L F
.52627 .34506 m .52856 .34607 L .52854 .34608 L F
.52639 .3452 m .5263 .3451 L .5359 .34965 L F
.52721 .34538 m .52723 .34533 L .52729 .34535 L F
.52724 .34515 m .52719 .34533 L .52726 .34516 L F
.52782 .34543 m .5268 .34505 L .52726 .34514 L F
.52785 .34558 m .52681 .34516 L .52782 .34543 L F
.52746 .3452 m .52696 .3451 L .52772 .34585 L F
.52697 .3452 m .52742 .34519 L p .52676 .34506 L F P
0 g
s
.52742 .34519 m .5282 .34518 L p .52682 .34507 L .672 .728 .891 r
F P
0 g
s
.52676 .34506 m .52742 .34519 L .52682 .34507 L .672 .728 .891 r
F
.52831 .34559 m .52746 .3452 L .52772 .34585 L F
.52743 .34476 m .5282 .34518 L .52755 .34479 L F
.52729 .34509 m .5273 .34505 L .52941 .3447 L F
.52789 .34503 m .52747 .34504 L .52773 .3449 L F
.52635 .34479 m .52669 .34501 L .52751 .34511 L F
.52754 .34504 m .52751 .34511 L .5282 .34518 L F
.52635 .34479 m .52751 .34511 L .52754 .34504 L F
.52714 .34491 m .52631 .34496 L .52741 .3448 L F
.52612 .3443 m .52623 .34427 L .52649 .34097 L F
.52587 .34426 m .52575 .34329 L .52587 .34426 L F
.52591 .34418 m .52564 .3435 L .52597 .34414 L F
.52603 .34305 m .52602 .34305 L .52604 .34477 L F
.52602 .34298 m .52618 .34396 L p .52548 .34268 L F P
0 g
s
.52577 .34322 m .52589 .34291 L .52577 .34313 L .672 .728 .891 r
F
.52581 .34438 m .52589 .34291 L .52577 .34322 L F
.52581 .34438 m .52595 .34282 L .52589 .34291 L F
.52626 .34345 m .52634 .34456 L p .52574 .34336 L F P
0 g
s
.52642 .344 m .52641 .34443 L p .52589 .34372 L .672 .728 .891 r
F P
0 g
s
.52617 .34463 m .52612 .34462 L .52585 .34379 L .672 .728 .891 r
F
.52605 .34478 m .52604 .34387 L .52603 .34476 L F
.52581 .34445 m .52617 .34493 L .52618 .34493 L F
.52588 .34449 m .52588 .34432 L .52587 .34448 L F
.52579 .34446 m .5258 .34444 L .52579 .34443 L F
.5258 .34447 m .5258 .34444 L .52579 .34446 L F
.5258 .34444 m .5258 .34427 L .52579 .34443 L F
.52581 .34448 m .52588 .34432 L .52581 .34438 L F
.52587 .34455 m .52588 .34432 L .52581 .34448 L F
.52607 .34461 m .52608 .34462 L .52604 .34387 L F
.52577 .34415 m .5258 .34427 L .52576 .34419 L F
.5258 .34427 m .52578 .34429 L .52576 .34419 L F
.52588 .34432 m .52595 .34282 L .52581 .34438 L F
.52579 .34428 m .5258 .34427 L .52578 .3435 L F
.52578 .34428 m .52579 .34428 L .52578 .34355 L F
.52575 .34353 m .52578 .34355 L .52578 .3435 L F
.52574 .34336 m .52615 .34453 L .52577 .34446 L F
.52579 .34444 m .5258 .34447 L .52581 .34445 L F
.52579 .34444 m .52445 .34383 L .52565 .34477 L F
.52576 .34419 m .52577 .34428 L .52572 .3443 L F
.52577 .34415 m .52576 .34419 L .52556 .34329 L F
.52568 .34431 m .52578 .34445 L .52578 .34355 L F
.52581 .34445 m .52577 .34443 L .52577 .34443 L F
.52577 .34443 m .52607 .3448 L .52616 .34396 L F
.526 .34396 m .52604 .34387 L .52548 .3324 L F
.52548 .3324 m .52626 .34345 L p .52574 .34336 L F P
0 g
s
.52593 .34366 m .52616 .34396 L .52649 .34097 L .672 .728 .891 r
F
.52577 .34443 m .52616 .34396 L .52593 .34366 L F
.52614 .34495 m .5262 .34496 L .5262 .34496 L F
.52631 .34496 m .52477 .34506 L .52611 .34492 L F
.52558 .34482 m .52136 .34547 L .52009 .345 L F
.52538 .34478 m .5248 .34505 L .52524 .34478 L F
.52574 .34485 m .5248 .34505 L .52538 .34478 L F
.52558 .34482 m .52555 .34489 L .52614 .34495 L F
.52644 .34499 m .52675 .34505 L .52669 .34501 L F
.52627 .34506 m .5279 .34578 L .52788 .34577 L F
.52719 .34544 m .52684 .34528 L .52721 .34538 L F
.52684 .34528 m .52683 .34522 L .52721 .34538 L F
.52721 .34538 m .52663 .34512 L .52723 .34533 L F
.52671 .34486 m .52642 .3449 L .5273 .34555 L F
.52733 .34547 m .5273 .34555 L .52772 .34585 L F
.52671 .34486 m .5273 .34555 L .52733 .34547 L F
.52742 .34518 m .52639 .3452 L .52715 .34513 L F
.52747 .34519 m .52742 .34519 L p .52742 .34518 L F P
0 g
s
.52742 .34519 m .52639 .3452 L p .52742 .34518 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .52669 .34477 L .5267 .3448 L .672 .728 .891 r
F
.52619 .34496 m .52675 .34505 L .52644 .34499 L F
.52614 .34495 m .5262 .34496 L .52619 .34496 L F
.5262 .34496 m .52675 .34505 L .52619 .34496 L F
.52606 .34553 m .52602 .34537 L .52629 .34508 L F
.52911 .34611 m .52785 .34558 L .52782 .34543 L F
.5302 .34667 m .52914 .34621 L .52911 .34611 L F
.52831 .34559 m .52791 .34577 L .531 .34701 L F
.52788 .34577 m .5279 .34578 L .52856 .34607 L F
.52791 .34577 m .52772 .34585 L .531 .34701 L F
.52971 .3467 m .52971 .3467 L .53028 .34697 L F
.53028 .34697 m .53028 .34697 L .53052 .34709 L F
.5305 .34709 m .53052 .34709 L .53519 .34931 L F
.5263 .3451 m .53052 .34709 L .5305 .34709 L F
.53519 .34931 m .53519 .34931 L .5359 .34965 L F
.52854 .34608 m .52856 .34607 L .53224 .34774 L F
.5361 .34994 m .53482 .34932 L p .5359 .34965 L F P
0 g
s
.53482 .34932 m .52639 .3452 L p .53549 .34946 L .672 .728 .891 r
F P
0 g
s
.53482 .34932 m .53549 .34946 L .5359 .34965 L .672 .728 .891 r
F
.53224 .34774 m .53019 .3468 L .5302 .34667 L F
.5359 .34965 m .53229 .34793 L .53224 .34774 L F
.54161 .35263 m .5361 .34994 L p .5359 .34965 L F P
0 g
s
.52772 .34585 m .54161 .35263 L p .531 .34701 L .672 .728 .891 r
F P
0 g
s
.53477 .34865 m .52685 .34534 L .53473 .34851 L .672 .728 .891 r
F
.52636 .34517 m .52629 .34508 L .52667 .3447 L F
.52611 .34497 m .52622 .34499 L .52614 .34495 L F
.52622 .34499 m .52676 .34506 L .5262 .34496 L F
.52622 .34499 m .5262 .34496 L .52614 .34495 L F
.52667 .3447 m .52629 .34508 L .52664 .34459 L F
.52629 .34508 m .52602 .34537 L .52627 .34505 L F
.52629 .34508 m .52627 .34505 L .52664 .34459 L F
.5263 .34509 m .5267 .34487 L .52618 .34494 L F
.52636 .34517 m .52667 .3447 L .52669 .34477 L F
.52647 .34489 m .52635 .34485 L .52642 .3449 L F
.52671 .34486 m .52635 .34485 L .52647 .34489 L F
.52671 .34486 m .52579 .34444 L .52635 .34485 L F
.52675 .345 m .5254 .34449 L .52672 .3449 L F
.52687 .34466 m .52699 .34456 L .52687 .34465 L F
.52683 .34465 m .52701 .34452 L .52683 .34465 L F
.52718 .34441 m .52672 .34487 L p .5271 .34427 L F P
0 g
s
.52672 .34487 m .52639 .3452 L p .5267 .3448 L .672 .728 .891 r
F P
0 g
s
.52672 .34487 m .5267 .3448 L .5271 .34427 L .672 .728 .891 r
F
.52528 .34518 m .52618 .34511 L .52622 .34513 L F
.52639 .3452 m .5258 .34521 L p .52633 .34512 L F P
0 g
s
.5251 .34455 m .52503 .34446 L .52659 .34502 L .672 .728 .891 r
F
.52605 .34503 m .52612 .34497 L .52631 .34496 L F
.52546 .34452 m .52546 .34452 L .52675 .345 L F
.52675 .345 m .52675 .345 L .52831 .34559 L F
.526 .34472 m .52675 .345 L .526 .34472 L F
.52575 .34463 m .52574 .34462 L .52691 .34506 L F
.5271 .34511 m .52702 .3451 L .5273 .34505 L F
.52742 .34519 m .52674 .34487 L .52696 .3451 L F
.52694 .34507 m .52694 .34507 L .52702 .3451 L F
.52729 .34509 m .5271 .34511 L .5273 .34505 L F
.52669 .34501 m .52676 .34506 L .5282 .34518 L F
.52674 .34487 m .52674 .34489 L .52772 .34585 L F
.52691 .34506 m .52694 .34507 L .52694 .34507 L F
.52691 .34506 m .52691 .34506 L .52694 .34507 L F
.52575 .34463 m .52691 .34506 L .52691 .34506 L F
.52613 .34461 m .5262 .34466 L .52623 .34427 L F
.52579 .34444 m .52565 .34477 L .5258 .34447 L F
.52674 .34487 m .52671 .34486 L .52674 .34489 L F
.52695 .34496 m .52573 .34459 L .52581 .34445 L F
.52607 .3448 m .5262 .34466 L .52613 .34461 L F
.52601 .34473 m .52601 .34473 L .52701 .3451 L F
.52627 .34505 m .52625 .34503 L .52664 .34459 L F
.52539 .34449 m .5254 .34449 L .52546 .34451 L F
.5258 .34521 m .52588 .34515 L .52633 .34512 L F
.52595 .3451 m .52594 .34528 L .526 .34507 L F
.5258 .34521 m .52594 .34528 L .52595 .3451 L F
.5258 .34521 m .52594 .3453 L .52594 .34528 L F
.52553 .3455 m .52605 .34522 L .52611 .34495 L F
.52602 .34537 m .526 .3453 L .52625 .34503 L F
.52595 .3451 m .52602 .34505 L .52652 .345 L F
.52503 .34446 m .52689 .34508 L .52659 .34502 L F
.52395 .34407 m .52501 .34444 L .52503 .34446 L F
.52501 .34444 m .52689 .34508 L .52503 .34446 L F
.52582 .34573 m .52601 .3453 L .52607 .3448 L F
.52606 .34553 m .52629 .34508 L .52636 .34517 L F
.52639 .3452 m .52636 .34517 L .52669 .34477 L F
.52578 .3452 m .5258 .34578 L .52594 .3453 L F
.5258 .34578 m .5258 .34581 L .52582 .34573 L F
.5258 .34578 m .52582 .34573 L .52594 .3453 L F
.52639 .3452 m .52606 .34553 L p .52636 .34517 L F P
0 g
s
.52606 .34553 m .52639 .3452 L p .52598 .34536 L .672 .728 .891 r
F P
0 g
s
.52545 .34558 m .5259 .34554 L .52598 .34536 L .672 .728 .891 r
F
.52581 .34578 m .52596 .34542 L .52602 .34537 L F
.5259 .34554 m .52606 .34553 L .52598 .34536 L F
.52639 .3452 m .52672 .34487 L p .52631 .3451 L F P
0 g
s
.52631 .3451 m .52632 .34512 L .52622 .34513 L .672 .728 .891 r
F
.5262 .34496 m .52676 .34506 L .52675 .34505 L F
.52672 .34507 m .52595 .3451 L .52673 .34498 L F
.52601 .3453 m .52618 .34494 L .52604 .34503 L F
.52598 .34536 m .52639 .3452 L .52603 .34525 L F
.52598 .34563 m .52618 .34494 L .52601 .3453 L F
.52603 .34525 m .52639 .3452 L .52631 .3451 L F
.52534 .34582 m .5253 .34577 L .52592 .34504 L F
.52545 .34558 m .52598 .34536 L .52603 .34525 L F
.52618 .34511 m .52631 .3451 L .52622 .34513 L F
.52631 .3451 m .52672 .34507 L .52632 .34512 L F
.52631 .3451 m .52672 .34487 L .5263 .3451 L F
.52594 .3453 m .52672 .34487 L .52594 .3453 L F
.52627 .34505 m .52652 .345 L .52655 .34501 L F
.52595 .3451 m .52626 .34505 L .52627 .34505 L F
.52626 .34505 m .52652 .345 L .52627 .34505 L F
.5263 .3451 m .52672 .34487 L .5267 .34487 L F
.52594 .3453 m .52631 .3451 L .5263 .3451 L F
.52545 .34558 m .52594 .3453 L .52594 .3453 L F
.52605 .34522 m .52616 .34498 L .52611 .34495 L F
.52604 .34503 m .52618 .34494 L .52607 .3448 L F
.52593 .34489 m .5251 .34455 L .52659 .34502 L F
.52616 .34492 m .52611 .34492 L .52606 .34479 L F
.52611 .34492 m .52574 .34485 L .52606 .34479 L F
.5258 .34521 m .526 .34507 L .52607 .3448 L F
.52606 .34479 m .52589 .34497 L .52615 .3449 L F
.5258 .34521 m .52459 .34522 L p .52588 .34515 L F P
0 g
s
.52578 .3452 m .5258 .34521 L .52607 .3448 L .672 .728 .891 r
F
.52589 .34497 m .52532 .34559 L .52609 .34495 L F
.52565 .34483 m .52593 .34489 L .52657 .34515 L F
.52589 .34497 m .52609 .34495 L .52615 .3449 L F
.52498 .34491 m .5258 .34521 L .52544 .34498 L F
.52506 .34513 m .52476 .34506 L .52612 .34497 L F
.52436 .34486 m .52459 .34522 L .52498 .34491 L F
.52476 .34506 m .52475 .34506 L .52477 .34506 L F
.52476 .34506 m .52477 .34506 L .52612 .34497 L F
.52605 .34522 m .5263 .34509 L .52616 .34498 L F
.52616 .34498 m .52618 .34494 L .52611 .34495 L F
.52605 .34503 m .52631 .34496 L .52642 .34499 L F
.5263 .34509 m .52618 .34494 L .52616 .34498 L F
.52639 .3452 m .5267 .3448 L .5267 .3448 L F
.52569 .34544 m .5267 .34487 L .52553 .3455 L F
.52598 .34563 m .52621 .34498 L .52618 .34494 L F
.52532 .34559 m .52545 .34558 L .52611 .34495 L F
.52601 .34473 m .52701 .3451 L .527 .3451 L F
.52675 .345 m .52672 .3449 L .52695 .34496 L F
.52523 .34512 m .52714 .34491 L .52701 .34496 L F
.52506 .34513 m .52524 .34511 L .52523 .34512 L F
.52532 .34559 m .52611 .34495 L .5261 .34495 L F
.52611 .34492 m .5248 .34505 L .52574 .34485 L F
.52596 .34496 m .52565 .34483 L .52597 .34496 L F
.5259 .34496 m .52534 .34561 L .52511 .34569 L F
.52528 .34518 m .52519 .34516 L .52672 .34507 L F
.52532 .34559 m .52615 .34491 L .52615 .3449 L F
.526 .34472 m .52675 .345 L .52675 .345 L F
.5264 .34491 m .52645 .3449 L .52689 .34508 L F
.52642 .34499 m .52631 .34496 L .52714 .34491 L F
.52707 .34511 m .52693 .34506 L .52695 .34496 L F
.52747 .34504 m .52672 .34507 L .52751 .34494 L F
.5268 .34506 m .52701 .34496 L .52773 .3449 L F
.5262 .34648 m .52636 .34516 L .52634 .34514 L F
.52621 .34647 m .52636 .34516 L .5262 .34648 L F
.52615 .34716 m .52636 .34516 L .52613 .34718 L F
.52506 .34513 m .52612 .34497 L .52605 .34503 L F
.52587 .34498 m .52596 .34496 L .52632 .34512 L F
.5258 .34581 m .52595 .34583 L .52601 .3453 L F
.5258 .34581 m .52583 .347 L .52595 .34583 L F
.52592 .34601 m .52593 .34689 L .52573 .34595 L F
.52638 .34558 m .52592 .34585 L .52591 .34554 L F
.52611 .34552 m .52574 .34595 L p .52602 .3453 L F P
0 g
s
.52608 .35784 m .52488 .3578 L p .52573 .34598 L .672 .728 .891 r
F P
0 g
s
.52573 .34597 m .52608 .35784 L .52573 .34598 L .672 .728 .891 r
F
.5256 .34779 m .52603 .34527 L .52595 .34545 L F
.5256 .34779 m .52604 .34539 L .52602 .3454 L F
.5258 .34581 m .52601 .3453 L .52582 .34573 L F
.52574 .34595 m .52572 .34598 L p .52602 .3453 L F P
0 g
s
.52572 .34598 m .52548 .34595 L .52602 .3453 L .672 .728 .891 r
F
.52577 .34537 m .52585 .3457 L .52573 .34595 L F
.52585 .3457 m .52592 .34601 L .52574 .34595 L F
.52585 .3457 m .52574 .34595 L .52573 .34595 L F
.52602 .3453 m .52547 .34595 L .52594 .3451 L F
.52591 .34533 m .52591 .34554 L .52577 .34537 L F
.52591 .34554 m .52592 .34601 L .52585 .3457 L F
.52591 .34554 m .52585 .3457 L .52577 .34537 L F
.52578 .34583 m .52586 .34548 L .52586 .34547 L F
.52572 .34598 m .51984 .35276 L p .52548 .34595 L F P
0 g
s
.51984 .35276 m .51965 .35288 L .52602 .3453 L .672 .728 .891 r
F
.52608 .34535 m .52619 .34529 L .52621 .34498 L F
.52607 .34507 m .52607 .34507 L .52638 .34519 L F
.52491 .34691 m .52572 .34598 L p .52458 .34673 L F P
0 g
s
.52545 .34558 m .52569 .34544 L .52553 .3455 L .672 .728 .891 r
F
.52631 .34496 m .52618 .34494 L .52741 .3448 L F
.52636 .34516 m .5264 .34481 L .5264 .34481 L F
.52542 .34479 m .52596 .34496 L .52587 .34498 L F
.52586 .34498 m .52542 .34479 L p .52587 .34498 L F P
0 g
s
.5248 .34505 m .52438 .34508 L .52524 .34478 L .672 .728 .891 r
F
.52607 .34501 m .52596 .34496 L .52604 .34499 L F
.52615 .34494 m .52659 .34502 L .52678 .34509 L F
.52593 .34489 m .52618 .34494 L .52615 .34494 L F
.52618 .34494 m .52659 .34502 L .52615 .34494 L F
.5261 .34495 m .52611 .34495 L .52615 .34491 L F
.52607 .34507 m .52586 .34498 L p .52607 .34507 L F P
0 g
s
.52596 .34496 m .52597 .34496 L .52604 .34499 L .672 .728 .891 r
F
.52629 .34553 m .52633 .34513 L .52618 .34546 L F
.5263 .3451 m .52672 .34507 L .52672 .34507 L F
.5263 .3451 m .5263 .34509 L .52672 .34507 L F
.52622 .34513 m .52672 .34507 L .52663 .34511 L F
.52683 .34526 m .52593 .34489 L .52678 .34509 L F
.52633 .34513 m .52637 .3448 L .52629 .34508 L F
.52633 .34513 m .52629 .34508 L .52618 .34546 L F
.52521 .34513 m .52523 .34512 L .52673 .34498 L F
.52586 .34498 m .52587 .34498 L .52638 .34519 L F
.52618 .34546 m .52627 .34515 L .5262 .34512 L F
.52627 .34515 m .52629 .34508 L .5262 .34512 L F
.5262 .34512 m .52629 .34508 L .52621 .34498 L F
.52586 .34498 m .52638 .34519 L .52638 .34519 L F
.52607 .34507 m .52636 .34518 L .52637 .34519 L F
.52632 .34555 m .52639 .3452 L .52636 .34517 L F
.52639 .3452 m .52658 .34573 L p .52634 .34515 L F P
0 g
s
.52636 .34518 m .52638 .34519 L .52637 .34519 L .672 .728 .891 r
F
.52637 .34519 m .52638 .34519 L .52638 .3452 L F
.52519 .34516 m .52521 .34513 L .5263 .34509 L F
.52587 .34498 m .52632 .34512 L .52638 .34519 L F
.52602 .3453 m .52594 .3451 L .52607 .34496 L F
.52618 .34494 m .52622 .34483 L .52626 .34436 L F
.52625 .34435 m .52626 .34436 L .52627 .34411 L F
.52618 .34494 m .52626 .34436 L .52625 .34435 L F
.52526 .34451 m .52539 .34449 L .52645 .3449 L F
.52607 .3448 m .52618 .34494 L .5262 .34466 L F
.52565 .34483 m .52155 .34312 L .52593 .34489 L F
.52155 .34312 m .51708 .34125 L .52148 .34306 L F
.52155 .34312 m .52148 .34306 L .52593 .34489 L F
.5255 .3448 m .52615 .3449 L .52613 .34488 L F
.52639 .3452 m .52633 .34512 L .52663 .34511 L F
.52565 .34483 m .52683 .34526 L .52684 .34532 L F
.52606 .34479 m .52594 .3451 L .52589 .34497 L F
.52586 .34498 m .52589 .34499 L p .52583 .34487 L F P
0 g
s
.52477 .34506 m .5248 .34505 L .52611 .34492 L .672 .728 .891 r
F
.52583 .34487 m .52589 .34499 L .526 .34497 L F
.52596 .34871 m .52629 .34553 L .52618 .34546 L F
.52613 .34718 m .52621 .34647 L .5262 .34648 L F
.52589 .34969 m .52615 .34716 L .52613 .34718 L F
.52589 .34969 m .52638 .34558 L .52632 .34555 L F
.52596 .34897 m .52627 .34576 L .52596 .34871 L F
.52627 .34576 m .52627 .34576 L .52596 .34871 L F
.52583 .347 m .52606 .34714 L .52615 .34586 L F
.52583 .347 m .52615 .34586 L .52598 .34563 L F
.52608 .35784 m .52627 .34984 L p .52589 .34969 L F P
0 g
s
.52638 .34558 m .52608 .35784 L p .52592 .34585 L .672 .728 .891 r
F P
0 g
s
.52583 .347 m .52589 .34969 L .52606 .34714 L .672 .728 .891 r
F
.52593 .34689 m .52608 .35784 L .52576 .3469 L F
.52589 .34937 m .52634 .34556 L p .5255 .34915 L F P
0 g
s
.52636 .34517 m .5264 .34481 L .52636 .34516 L .672 .728 .891 r
F
.52639 .3452 m .5264 .34481 L p .52636 .34517 L F P
0 g
s
.52546 .34452 m .52546 .34451 L .52692 .34506 L .672 .728 .891 r
F
.52682 .34492 m .52614 .3444 L .52615 .3444 L F
.52664 .34459 m .52636 .34491 L .52636 .34453 L F
.52674 .34427 m .52635 .34463 L .52631 .34462 L F
.52641 .34443 m .52622 .34484 L .52663 .34445 L F
.52637 .3448 m .52641 .3444 L .52622 .34491 L F
.52546 .34452 m .52692 .34506 L .52691 .34506 L F
.52618 .34494 m .52611 .34492 L .52616 .34492 L F
.52611 .34495 m .52673 .34485 L .52662 .34447 L F
.52638 .34479 m .52624 .34487 L .5262 .34479 L F
.52624 .34487 m .52616 .34492 L .5262 .34479 L F
.52617 .34488 m .52617 .34489 L .52622 .34484 L F
.52615 .3449 m .52617 .34489 L .52617 .34488 L F
.52615 .3449 m .52615 .34491 L .52617 .34489 L F
.52606 .34479 m .52615 .3449 L .52622 .34484 L F
.5262 .34479 m .52616 .34492 L .52606 .34479 L F
.52629 .34508 m .52637 .3448 L .52621 .34498 L F
.52565 .34483 m .52657 .34515 L .52655 .34516 L F
.52618 .34494 m .52621 .34498 L .52622 .34491 L F
.52618 .34494 m .52622 .34491 L .52622 .34483 L F
.52618 .34494 m .52616 .34492 L .52621 .34492 L F
.5267 .34487 m .52673 .34485 L .52611 .34495 L F
.52618 .34494 m .52621 .34492 L .52741 .3448 L F
.52606 .34496 m .52604 .34496 L .52611 .34485 L F
.52611 .34485 m .52594 .3451 L .52606 .34479 L F
.52612 .34493 m .52583 .34487 L .526 .34497 L F
.52669 .34496 m .52669 .34496 L .52523 .34512 L F
.52607 .34501 m .52604 .34499 L .52631 .3451 L F
.52632 .34512 m .52607 .34501 L .52631 .3451 L F
.52614 .34494 m .526 .34497 L .52639 .3452 L F
.52618 .34494 m .52607 .34496 L .52613 .34489 L F
.52672 .34487 m .52673 .34485 L p .5267 .34487 L F P
0 g
s
.52741 .3448 m .52616 .34492 L .52638 .34479 L .672 .728 .891 r
F
.52629 .34487 m .52657 .34494 L .5265 .34489 L F
.52622 .34491 m .52635 .34456 L .52622 .34483 L F
.52611 .34485 m .52627 .34488 L .52629 .34487 L F
.52621 .34498 m .52637 .3448 L .52622 .34491 L F
.52634 .34514 m .5264 .34478 L .52637 .3448 L F
.52636 .34516 m .5264 .34481 L .52634 .34514 L F
.52638 .34479 m .52642 .34483 L .52728 .34492 L F
.5264 .34481 m .5264 .34478 L .52639 .3448 L F
.5264 .34481 m .52639 .3448 L .52634 .34514 L F
.52639 .3452 m .5262 .34492 L .52621 .34492 L F
.52637 .34483 m .52637 .3448 L .52637 .34483 L F
.52687 .34551 m .52835 .34644 L p .52722 .34552 L F P
0 g
s
.53853 .35036 m .52639 .3452 L p .53812 .35006 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .52607 .34507 L p .52638 .3452 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .52638 .3452 L .53794 .34998 L .672 .728 .891 r
F
.52637 .34483 m .52637 .34483 L .52633 .34513 L F
.52633 .34513 m .52633 .34513 L .52627 .34576 L F
.52637 .34483 m .52633 .34513 L .52633 .34513 L F
.52627 .34576 m .52637 .34483 L .52627 .34576 L F
.5264 .34481 m .5264 .34489 L p .52629 .34487 L F P
0 g
s
.5264 .34489 m .52639 .3452 L p .52629 .34487 L .672 .728 .891 r
F P
0 g
s
.52629 .34487 m .52639 .3452 L .52625 .34489 L .672 .728 .891 r
F
.52573 .34598 m .52575 .34598 L .52584 .34545 L F
.52589 .34499 m .52639 .3452 L p .526 .34497 L F P
0 g
s
.52606 .34496 m .52594 .3451 L .52604 .34496 L .672 .728 .891 r
F
.52542 .3449 m .5259 .3451 L .52614 .34496 L F
.52508 .34483 m .52436 .34486 L .52498 .34491 L F
.52524 .34478 m .52438 .34508 L .5239 .34477 L F
.52342 .34476 m .52564 .34506 L .52542 .3449 L F
.52524 .34511 m .52669 .34496 L .52523 .34512 L F
.52564 .34506 m .5259 .3451 L .52542 .3449 L F
.52582 .34543 m .52584 .34545 L .52587 .34523 L F
.52501 .34444 m .52645 .3449 L .5264 .34491 L F
.52612 .34493 m .526 .34497 L .52614 .34494 L F
.52613 .34488 m .52606 .34496 L .52611 .34485 L F
.52538 .34478 m .52613 .34488 L .52611 .34485 L F
.5255 .3448 m .52591 .34488 L .52615 .3449 L F
.52546 .34452 m .526 .34472 L .526 .34472 L F
.52606 .34479 m .52574 .34485 L .52538 .34478 L F
.52606 .34479 m .52538 .34478 L .52593 .34483 L F
.52574 .34454 m .52542 .34478 L .52612 .34493 L F
.52573 .34459 m .5254 .34449 L .52568 .34446 L F
.5254 .34449 m .52578 .34444 L .52581 .34445 L F
.52564 .34443 m .52553 .34461 L .52574 .34454 L F
.52575 .34463 m .52546 .34452 L .52574 .34462 L F
.52553 .34461 m .52542 .34478 L .52574 .34454 L F
.52595 .34507 m .52591 .34509 L .5259 .34472 L F
.52547 .34595 m .52526 .34593 L .52594 .3451 L F
.52589 .3451 m .52591 .34533 L .52579 .34516 L F
.52701 .3451 m .52702 .3451 L .52831 .34559 L F
.52625 .34489 m .5262 .34489 L .52622 .34483 L F
.52639 .3452 m .52621 .34492 L .52625 .34489 L F
.52613 .34488 m .52615 .3449 L .52657 .34494 L F
.52621 .34492 m .5262 .34489 L .52625 .34489 L F
.52642 .34491 m .52657 .34494 L .52642 .3449 L F
.52642 .34491 m .52642 .3449 L .52629 .34487 L F
.52627 .34488 m .52642 .34491 L .52629 .34487 L F
.52635 .34456 m .52641 .3444 L .52622 .34483 L F
.52642 .3444 m .52606 .34479 L .52622 .34484 L F
.5264 .34481 m .5264 .34478 L p .5264 .34481 L F P
0 g
s
.5264 .34478 m .5264 .34481 L p .52612 .34461 L .672 .728 .891 r
F P
0 g
s
.52626 .34475 m .52626 .34471 L .52628 .3447 L .672 .728 .891 r
F
.52606 .34479 m .52593 .34483 L .52611 .34485 L F
.52535 .34583 m .51692 .35612 L .52515 .34589 L F
.5246 .34669 m .52572 .34598 L .52582 .34575 L F
.52606 .34479 m .52611 .34485 L .52718 .34495 L F
.5282 .34518 m .52915 .34517 L p .52755 .34479 L F P
0 g
s
.52725 .34492 m .52718 .34495 L .52879 .3451 L .672 .728 .891 r
F
.52606 .34479 m .52718 .34495 L .52725 .34492 L F
.5264 .34481 m .52625 .34489 L .52622 .34483 L F
.52638 .34479 m .52606 .34479 L .52642 .34483 L F
.5264 .34481 m .52622 .34483 L .52627 .34472 L F
.52639 .3452 m .52629 .34523 L .5262 .34492 L F
.52598 .34563 m .52619 .34529 L .52608 .34535 L F
.52638 .34558 m .52625 .34557 L .5262 .34489 L F
.52625 .34557 m .52591 .34554 L .52599 .34537 L F
.52625 .34557 m .52599 .34537 L .5262 .34489 L F
.52509 .34473 m .52506 .34471 L p .52562 .34483 L F P
0 g
s
.52395 .34407 m .525 .34442 L .52501 .34444 L .672 .728 .891 r
F
.525 .34442 m .52645 .3449 L .52501 .34444 L F
.52542 .34479 m .51781 .34156 L p .52565 .34483 L F P
0 g
s
.51781 .34156 m .51708 .34125 L p .51781 .34155 L .672 .728 .891 r
F P
0 g
s
.51781 .34156 m .51781 .34155 L .52565 .34483 L .672 .728 .891 r
F
.52539 .34449 m .52546 .34451 L .52546 .34452 L F
.5251 .34455 m .52395 .34407 L .52503 .34446 L F
.52356 .34382 m .52228 .3432 L p .52355 .34379 L F P
0 g
s
.52228 .3432 m .52154 .34284 L p .52227 .34318 L .672 .728 .891 r
F P
0 g
s
.52546 .34452 m .52539 .34449 L .52546 .34452 L .672 .728 .891 r
F
.52539 .34449 m .5249 .3443 L .5254 .34449 L F
.5254 .34449 m .5249 .3443 L .52578 .34444 L F
.52362 .34383 m .52389 .34395 L .52389 .34395 L F
.52154 .34284 m .52363 .34382 L .52362 .34383 L F
.52154 .34284 m .52161 .34285 L .52588 .34488 L F
.52383 .34358 m .52336 .34332 L .52385 .34358 L F
.52336 .34332 m .52385 .34358 L .52385 .34358 L F
.52331 .34349 m .52421 .34399 L p .52335 .3431 L F P
0 g
s
.52336 .34332 m .51179 .33707 L .52344 .3433 L .672 .728 .891 r
F
.51179 .33707 m .52331 .34349 L p .52335 .3431 L F P
0 g
s
.52154 .34284 m .51951 .34184 L p .52161 .34285 L .672 .728 .891 r
F P
0 g
s
.52335 .3431 m .52453 .34392 L .5243 .34365 L .672 .728 .891 r
F
.52491 .34392 m .51951 .34184 L .5216 .34219 L F
.52395 .34396 m .51951 .34184 L .52491 .34392 L F
.51105 .33772 m .52428 .34417 L p .52445 .34383 L F P
0 g
s
.52395 .34407 m .52411 .34399 L .52539 .34449 L .672 .728 .891 r
F
.52395 .34407 m .52539 .34449 L .52526 .34451 L F
.52395 .34407 m .51708 .34125 L .52411 .34399 L F
.52577 .34443 m .52034 .34252 L .52097 .34224 L F
.52577 .34443 m .52034 .34252 L .52577 .34443 L F
.5249 .3443 m .52034 .34252 L .52581 .34445 L F
.52564 .34443 m .51995 .34218 L .52542 .34479 L F
.52097 .34224 m .51708 .34125 L .51945 .34155 L F
.52034 .34252 m .51708 .34125 L .52097 .34224 L F
.51708 .34125 m .51038 .3384 L p .51945 .34155 L F P
0 g
s
.51038 .3384 m .51781 .34156 L p .51995 .34218 L .672 .728 .891 r
F P
0 g
s
.51781 .34156 m .52542 .34479 L p .51995 .34218 L .672 .728 .891 r
F P
0 g
s
.5282 .34518 m .52747 .34519 L p .5284 .34501 L .672 .728 .891 r
F P
0 g
s
.52783 .34508 m .52775 .3452 L .53097 .3453 L .672 .728 .891 r
F
.52786 .34504 m .52901 .34516 L .52887 .34513 L F
.52639 .3452 m .53794 .34998 L .53794 .34998 L F
.52684 .34532 m .52683 .34526 L .53473 .34851 L F
.52685 .34534 m .52684 .34532 L .53473 .34851 L F
.52838 .34566 m .5277 .34539 L .52831 .34559 L F
.5289 .34611 m .52872 .34604 L .52901 .3459 L F
.52872 .34604 m .52838 .34566 L .52901 .3459 L F
.52901 .3459 m .52838 .34566 L .52831 .34559 L F
.53473 .34851 m .5289 .34611 L .52901 .3459 L F
.53099 .34655 m .52771 .34525 L .52884 .34624 L F
.52655 .34501 m .52652 .345 L .52673 .34498 L F
.52742 .34518 m .52674 .34487 L .52742 .34519 L F
.52693 .34506 m .52675 .345 L .52695 .34496 L F
.52677 .34505 m .52701 .34496 L .5268 .34506 L F
.52704 .34511 m .52675 .345 L .52707 .34511 L F
.52663 .34511 m .52672 .34507 L .52684 .34507 L F
.52696 .34509 m .52684 .34507 L .5284 .34501 L F
.52663 .34511 m .52684 .34507 L .52696 .34509 L F
.52699 .3451 m .52743 .34526 L .52743 .34526 L F
.52601 .34473 m .527 .3451 L .52699 .3451 L F
.527 .3451 m .52743 .34526 L .52699 .3451 L F
.52672 .34507 m .52673 .34498 L .52681 .34504 L F
.52747 .34519 m .52715 .34513 L .5284 .34501 L F
.52639 .3452 m .52663 .34511 L .52696 .34509 L F
.52742 .34518 m .52707 .34511 L .52695 .34496 L F
.52715 .34513 m .52696 .34509 L .5284 .34501 L F
.52639 .3452 m .52696 .34509 L .52715 .34513 L F
.52831 .34559 m .52708 .34512 L .52707 .34511 L F
.52746 .3452 m .52742 .34518 L .52742 .34519 L F
.52831 .34559 m .52707 .34511 L .52742 .34518 L F
.52619 .34496 m .52775 .3452 L .52783 .34508 L F
.52767 .34524 m .52693 .34494 L .52724 .34516 L F
.527 .3451 m .52701 .3451 L .52743 .34526 L F
.52672 .34507 m .52677 .34505 L .5268 .34506 L F
.52708 .34512 m .52704 .34511 L .52707 .34511 L F
.5277 .34539 m .52601 .34473 L .52778 .34539 L F
.5267 .34504 m .52671 .34505 L .52775 .3452 L F
.52632 .34512 m .52631 .3451 L .52684 .34532 L F
.52671 .34505 m .52639 .3452 L .52724 .34516 L F
.52659 .34502 m .52689 .34508 L .52838 .34566 L F
.52671 .34505 m .52688 .34518 L .52742 .34519 L F
.52671 .34505 m .52742 .34519 L .52775 .3452 L F
.52638 .34519 m .52638 .34519 L .53227 .34763 L F
.52638 .3452 m .52638 .34519 L .52866 .34614 L F
.52638 .3452 m .52866 .34614 L .52865 .34614 L F
.52638 .34519 m .52632 .34512 L .53039 .34682 L F
.52655 .34516 m .52657 .34515 L .52683 .34526 L F
.52685 .34534 m .52632 .34512 L .52684 .34532 L F
.52683 .34526 m .52678 .34509 L .52838 .34566 L F
.52639 .3452 m .52884 .34624 L p .52724 .34516 L F P
0 g
s
.52681 .34504 m .52673 .34498 L .52701 .34496 L .672 .728 .891 r
F
.52693 .34494 m .52671 .34505 L .52724 .34516 L F
.52699 .34502 m .52698 .345 L .52767 .34524 L F
.52705 .34499 m .52756 .34506 L .52755 .34503 L F
.52767 .34524 m .52693 .34494 L .52767 .34524 L F
.52767 .34524 m .5271 .34504 L .52715 .34503 L F
.52712 .34523 m .52682 .34503 L .52771 .34501 L F
.52785 .34506 m .52901 .34516 L .52786 .34504 L F
.52755 .34503 m .52756 .34506 L .52901 .34516 L F
.52669 .34496 m .52714 .34491 L .52669 .34496 L F
.5265 .34489 m .52657 .34494 L .53097 .3453 L F
.52701 .34496 m .52714 .34491 L .52862 .34482 L F
.5284 .34501 m .52789 .34503 L .52862 .34482 L F
.52789 .34503 m .52773 .3449 L .52862 .34482 L F
.52741 .3448 m .52749 .34494 L .53097 .3453 L F
.52768 .34517 m .52771 .34501 L .52964 .34497 L F
.52753 .34521 m .52699 .34502 L .52767 .34524 L F
.52712 .34523 m .52771 .34501 L .52768 .34517 L F
.52594 .3451 m .52559 .34553 L .52589 .34497 L F
.52602 .3453 m .52591 .34533 L .52591 .34509 L F
.52595 .3451 m .52521 .34513 L .52602 .34505 L F
.52564 .34506 m .52575 .34514 L .52635 .34516 L F
.52602 .3453 m .52607 .34496 L .52618 .34494 L F
.52618 .34494 m .52602 .3453 L .52591 .34509 L F
.52671 .34505 m .52618 .34494 L .52619 .34496 L F
.52662 .34509 m .52619 .34496 L .52639 .3452 L F
.52619 .34496 m .52688 .34518 L .52671 .34505 L F
.52702 .34516 m .52634 .34515 L .52682 .34503 L F
.52611 .34552 m .52602 .3453 L .52618 .34494 L F
.52613 .34488 m .52657 .34494 L .52611 .34485 L F
.52708 .34498 m .52785 .34506 L .52786 .34504 L F
.52591 .34488 m .52706 .34499 L .52708 .34498 L F
.52706 .34499 m .52785 .34506 L .52708 .34498 L F
.5259 .3451 m .52625 .34515 L .52596 .34506 L F
.52611 .34552 m .52621 .34498 L .52633 .34513 L F
.52625 .34515 m .52631 .34515 L .52618 .34513 L F
.52631 .34515 m .52635 .34516 L .52618 .34513 L F
.52615 .3453 m .52618 .34494 L .52621 .34498 L F
.52611 .34552 m .52613 .34531 L .52615 .3453 L F
.52613 .34531 m .52618 .34494 L .52615 .3453 L F
.52639 .3452 m .52772 .34524 L p .52638 .34519 L F P
0 g
s
.52582 .34514 m .52772 .34524 L .52772 .34524 L .672 .728 .891 r
F
.52721 .34519 m .52582 .34514 L .52715 .34521 L F
.52694 .34522 m .52639 .3452 L p .52702 .34516 L F P
0 g
s
.52559 .34553 m .52551 .34556 L .52589 .34497 L .672 .728 .891 r
F
.52602 .3453 m .52591 .34554 L .52591 .34533 L F
.52586 .34548 m .52591 .34554 L .52601 .34505 L F
.52573 .34555 m .52596 .34543 L .52595 .34534 L F
.52596 .34543 m .52639 .3452 L .52601 .34532 L F
.52591 .34554 m .52595 .34545 L .52601 .34505 L F
.52595 .34545 m .52598 .3453 L .52597 .3453 L F
.52596 .34506 m .52635 .34516 L .52614 .34496 L F
.52588 .34514 m .526 .34506 L .52626 .34504 L F
.52603 .34527 m .5261 .34485 L .52595 .34545 L F
.52613 .34488 m .52611 .34485 L .52638 .34445 L F
.52642 .3444 m .52611 .34485 L .52606 .34479 L F
.52627 .34472 m .52622 .34483 L .52612 .34461 L F
.52621 .34492 m .5262 .34492 L .5262 .34489 L F
.52621 .34498 m .52618 .34494 L .52626 .34475 L F
.52629 .34491 m .52626 .34475 L .52647 .34488 L F
.52618 .34494 m .52613 .34489 L .52626 .34475 L F
.52622 .34483 m .5262 .34489 L .52612 .34461 L F
.52626 .34475 m .52594 .3451 L .52626 .34471 L F
.5262 .34489 m .52618 .34494 L .5259 .34448 L F
.52667 .34484 m .52583 .34451 L .52618 .34494 L F
.5257 .34456 m .52571 .34456 L .52592 .34462 L F
.52593 .34463 m .52592 .34462 L .52693 .34494 L F
.5259 .34447 m .5259 .34448 L .52584 .34443 L F
.52591 .3453 m .52591 .3453 L .52584 .3445 L F
.52885 .34508 m .52879 .3451 L .53097 .3453 L F
.52887 .34513 m .52901 .34516 L .53097 .3453 L F
.53097 .3453 m .52799 .34521 L .53099 .34535 L F
.53074 .34484 m .52924 .34482 L .53097 .3453 L F
.53624 .3449 m .53234 .34486 L .53653 .34509 L F
.53563 .34449 m .53234 .34486 L .53624 .3449 L F
.53563 .34449 m .52941 .3447 L .53234 .34486 L F
.53653 .34509 m .54523 .345 L p .53563 .34449 L F P
0 g
s
.54523 .345 m .53241 .34514 L p .53257 .34486 L .672 .728 .891 r
F P
0 g
s
.53732 .34491 m .53074 .34484 L .53804 .34558 L .672 .728 .891 r
F
.53099 .34535 m .53804 .34558 L p .53074 .34484 L F P
0 g
s
.53804 .34558 m .54521 .34582 L p .53732 .34491 L .672 .728 .891 r
F P
0 g
s
.54521 .34582 m .52931 .3453 L p .52964 .34497 L .672 .728 .891 r
F P
0 g
s
.53058 .34529 m .53158 .34558 L .539 .34617 L .672 .728 .891 r
F
.52772 .34524 m .52805 .34526 L p .52772 .34524 L F P
0 g
s
.52805 .34526 m .53099 .34535 L p .52799 .34521 L .672 .728 .891 r
F P
0 g
s
.52931 .3453 m .52772 .34524 L p .52929 .34502 L .672 .728 .891 r
F P
0 g
s
.52955 .34506 m .52929 .34502 L .52964 .34497 L .672 .728 .891 r
F
.52931 .3453 m .52929 .34502 L .52955 .34506 L F
.52506 .34471 m .52086 .34318 L p .52506 .34463 L F P
0 g
s
.52086 .34318 m .50977 .33911 L p .52078 .34308 L .672 .728 .891 r
F P
0 g
s
.52086 .34318 m .52078 .34308 L .52506 .34463 L .672 .728 .891 r
F
.52799 .34521 m .52721 .34519 L .52805 .34526 L F
.52772 .34524 m .52745 .34519 L .52964 .34497 L F
.52753 .34497 m .52792 .34529 L .52817 .34531 L F
.52841 .34511 m .52817 .34531 L .53158 .34558 L F
.52753 .34497 m .52817 .34531 L .52841 .34511 L F
.52618 .34494 m .52627 .34411 L .52626 .3441 L F
.52613 .34488 m .52638 .34445 L .52638 .34447 L F
.52607 .3448 m .52623 .34427 L .52612 .3443 L F
.5264 .34478 m .52612 .34461 L .52589 .34372 L F
.52612 .34487 m .52618 .34494 L .5263 .34407 L F
.52641 .3444 m .52649 .34097 L p .52626 .34436 L F P
0 g
s
.52627 .34376 m .5263 .34379 L .52649 .34097 L .672 .728 .891 r
F
.52574 .34353 m .52578 .3435 L .52573 .34168 L F
.52574 .34353 m .52573 .34168 L .52548 .3324 L F
.52576 .34353 m .52564 .3435 L .52548 .34268 L F
.5256 .34367 m .52574 .34353 L .52548 .3324 L F
.5257 .34171 m .52577 .34443 L .52649 .34097 L F
.52649 .34097 m .5267 .33239 L p .5257 .34171 L F P
0 g
s
.5267 .33239 m .52642 .344 L p .52589 .34372 L .672 .728 .891 r
F P
0 g
s
.52628 .34404 m .5263 .34407 L .52636 .34362 L .672 .728 .891 r
F
.52618 .34494 m .5263 .34379 L .52627 .34376 L F
.52641 .34443 m .52622 .34441 L .52589 .34372 L F
.52612 .34487 m .5263 .34407 L .52628 .34404 L F
.5264 .34478 m .52641 .3444 L p .52637 .3448 L F P
0 g
s
.52641 .34443 m .5264 .34478 L p .52632 .34461 L .672 .728 .891 r
F P
0 g
s
.52665 .34439 m .52665 .34437 L .52674 .34427 L .672 .728 .891 r
F
.52633 .3446 m .52696 .34428 L .52667 .34432 L F
.53199 .33926 m .52675 .34462 L .52636 .34453 L F
.5265 .34442 m .52629 .34468 L .52642 .3444 L F
.52629 .34468 m .52613 .34488 L .52638 .34447 L F
.52641 .34443 m .52632 .34461 L .52639 .34443 L F
.52629 .34468 m .52638 .34447 L .52642 .3444 L F
.52639 .34443 m .52632 .34461 L .52622 .34441 L F
.52665 .34456 m .52626 .34471 L .5265 .34442 L F
.52637 .34452 m .52623 .34482 L .52678 .34422 L F
.52626 .34475 m .52628 .3447 L .52665 .34456 L F
.52644 .34477 m .52651 .34421 L p .52618 .34494 L F P
0 g
s
.52747 .34504 m .52751 .34494 L .52773 .3449 L .672 .728 .891 r
F
.52606 .34479 m .52879 .3451 L .52885 .34508 L F
.52638 .34447 m .52638 .34445 L .52642 .3444 L F
.52618 .34494 m .52596 .34467 L .52658 .34488 L F
.52594 .34489 m .52615 .34491 L .52591 .34488 L F
.52575 .34463 m .52702 .3451 L .52701 .3451 L F
.52615 .34491 m .52785 .34506 L .52615 .3449 L F
.52615 .34491 m .52615 .3449 L .52591 .34488 L F
.52675 .34494 m .52667 .34484 L .52618 .34494 L F
.52619 .34496 m .52671 .34505 L .52658 .34502 L F
.52619 .34496 m .52635 .34516 L .52688 .34518 L F
.52621 .34492 m .52702 .345 L .52705 .34499 L F
.52699 .34502 m .5267 .34492 L .52698 .345 L F
.52542 .34478 m .52542 .34479 L .52612 .34493 L F
.52538 .34478 m .52591 .34488 L .5255 .3448 L F
.52562 .34483 m .52514 .34466 L .52596 .34467 L F
.52542 .34479 m .52565 .34483 L .52596 .34496 L F
.52542 .34479 m .52586 .34498 L p .52583 .34487 L F P
0 g
s
.52538 .34478 m .52536 .34484 L .52591 .34488 L .672 .728 .891 r
F
.52604 .34477 m .5254 .3449 L .52519 .34473 L F
.5267 .34492 m .52658 .34488 L .52669 .34491 L F
.52536 .34484 m .52866 .34513 L .52536 .34484 L F
.52866 .34513 m .52901 .34516 L .52867 .34513 L F
.52866 .34513 m .52867 .34513 L .52536 .34484 L F
.52668 .34486 m .52639 .3452 L p .52661 .34466 L F P
0 g
s
.52658 .34488 m .52564 .34456 L .5266 .34488 L .672 .728 .891 r
F
.5267 .3448 m .5271 .34427 L .5271 .34427 L F
.5267 .3448 m .5271 .34427 L .5267 .3448 L F
.52669 .34477 m .52667 .3447 L .52714 .34422 L F
.5267 .3448 m .52669 .34477 L .5271 .34427 L F
.52675 .34462 m .52667 .3447 L .52664 .34459 L F
.52673 .34485 m .52718 .34441 L p .52665 .34459 L F P
0 g
s
.5271 .34438 m .52668 .34486 L p .52665 .34456 L .672 .728 .891 r
F P
0 g
s
.52672 .34486 m .52592 .34462 L .52583 .34451 L .672 .728 .891 r
F
.52693 .34494 m .52672 .34486 L .52675 .34494 L F
.52693 .34494 m .52668 .34486 L .52672 .34486 L F
.52647 .34488 m .52626 .34475 L .52658 .34459 L F
.5266 .34464 m .52658 .34459 L .52665 .34456 L F
.52647 .34488 m .52658 .34459 L .5266 .34464 L F
.52672 .34486 m .52667 .34484 L .52675 .34494 L F
.52668 .34486 m .52668 .34486 L .52672 .34486 L F
.52668 .34486 m .52592 .34462 L .52667 .34485 L F
.52668 .34486 m .52667 .34485 L .52672 .34486 L F
.52618 .34513 m .52635 .34516 L .52596 .34506 L F
.52602 .3454 m .52604 .34539 L .52607 .34518 L F
.5259 .34448 m .52591 .3453 L .52584 .3445 L F
.52459 .34477 m .52614 .34496 L .52619 .34493 L F
.52584 .34443 m .52589 .3451 L .52579 .34516 L F
.52583 .34451 m .52578 .3452 L .52597 .34446 L F
.52579 .34516 m .52591 .34533 L .52577 .34537 L F
.52573 .34595 m .52573 .34597 L .52573 .34598 L F
.52578 .3452 m .52573 .34598 L .52586 .34515 L F
.52595 .34507 m .5259 .34472 L .5259 .34448 L F
.52601 .34473 m .52575 .34463 L .52601 .34473 L F
.52578 .3452 m .52586 .34515 L .52597 .34446 L F
.52581 .34518 m .52639 .3452 L p .52579 .34516 L F P
0 g
s
.52579 .34516 m .52639 .3452 L .52638 .34519 L .672 .728 .891 r
F
.52582 .34514 m .52579 .34516 L .52772 .34524 L F
.52639 .3452 m .52581 .34518 L p .52634 .34515 L F P
0 g
s
.52576 .34518 m .52581 .34518 L p .52579 .34516 L .672 .728 .891 r
F P
0 g
s
.52519 .34516 m .52506 .34513 L .52521 .34513 L .672 .728 .891 r
F
.52521 .34513 m .52506 .34513 L .52523 .34512 L F
.52317 .34524 m .52459 .34522 L p .52436 .34486 L F P
0 g
s
.52506 .34513 m .52171 .34525 L .52475 .34506 L .672 .728 .891 r
F
.52458 .34673 m .52572 .34598 L .5246 .34669 L F
.5245 .34689 m .52491 .34691 L .52458 .34673 L F
.52436 .34688 m .5245 .34689 L .52458 .34673 L F
.52547 .34595 m .52505 .34645 L .52526 .34593 L F
.52436 .34688 m .52582 .34575 L .52573 .34555 L F
.52433 .34691 m .52507 .34619 L .52498 .34619 L F
.52441 .34691 m .52491 .34691 L .52436 .34688 L F
.51984 .35276 m .51692 .35612 L p .51965 .35288 L F P
0 g
s
.51692 .35612 m .52491 .34691 L p .52433 .34691 L .672 .728 .891 r
F P
0 g
s
.52523 .34676 m .51798 .35651 L p .5249 .34619 L .672 .728 .891 r
F P
0 g
s
.52497 .3463 m .52415 .3475 L .52502 .34639 L .672 .728 .891 r
F
.52583 .34451 m .52574 .34454 L .52639 .3452 L F
.52583 .3455 m .52601 .34472 L .52596 .34467 L F
.52575 .34598 m .52585 .34549 L .52583 .3455 L F
.52585 .34549 m .52601 .34472 L .52583 .3455 L F
.52691 .34506 m .52692 .34506 L .52831 .34559 L F
.52767 .34524 m .52724 .34516 L .52764 .34543 L F
.52721 .34519 m .52715 .34521 L .52805 .34526 L F
.52767 .34524 m .52712 .34523 L .52745 .34519 L F
.52772 .34524 m .52767 .34524 L p .52767 .34524 L F P
0 g
s
.52767 .34524 m .52712 .34523 L p .52767 .34524 L .672 .728 .891 r
F P
0 g
s
.5277 .34539 m .52778 .34539 L .52831 .34559 L .672 .728 .891 r
F
.52771 .34525 m .52767 .34524 L .52884 .34624 L F
.52743 .34526 m .52743 .34526 L .52831 .34559 L F
.52872 .34604 m .52683 .34526 L .52838 .34566 L F
.52767 .34524 m .52764 .34543 L .52884 .34624 L F
.52771 .34525 m .52767 .34524 L .52767 .34524 L F
.52693 .34494 m .52679 .34494 L .52688 .34497 L F
.52679 .34494 m .52618 .34494 L .52688 .34497 L F
.52658 .34502 m .52671 .34505 L .5267 .34504 L F
.52619 .34493 m .52756 .34506 L .52621 .34492 L F
.52619 .34493 m .52614 .34496 L .52756 .34506 L F
.52688 .34497 m .52618 .34494 L .52671 .34505 L F
.5267 .34492 m .52669 .34491 L .52698 .345 L F
.52639 .3452 m .52633 .34513 L .5266 .34464 L F
.52661 .34466 m .5266 .34464 L .52665 .34456 L F
.52639 .3452 m .5266 .34464 L .52661 .34466 L F
.52614 .34497 m .5262 .34497 L .52607 .34501 L F
.52631 .3451 m .52665 .34487 L .52626 .34504 L F
.52695 .34496 m .52665 .34487 L .52693 .34494 L F
.52665 .34487 m .5257 .34456 L .52668 .34486 L F
.52665 .34487 m .52668 .34486 L .52693 .34494 L F
.52741 .3448 m .52638 .34479 L .52728 .34492 L F
.5264 .34491 m .52671 .34483 L .52664 .34467 L F
.52633 .34513 m .52629 .34491 L .52647 .34488 L F
.52626 .34504 m .52662 .34487 L .5264 .34491 L F
.52662 .34487 m .52671 .34483 L .5264 .34491 L F
.52665 .34487 m .52671 .34483 L .52662 .34487 L F
.52665 .34487 m .52662 .34487 L .52626 .34504 L F
.52616 .34494 m .52753 .34521 L .5277 .34527 L F
.52618 .34494 m .52595 .34507 L .5259 .34448 L F
.52586 .34522 m .52587 .34523 L .526 .34445 L F
.52391 .34483 m .52575 .34514 L .52564 .34506 L F
.52481 .34503 m .52623 .34491 L .52614 .34497 L F
.52477 .34506 m .52438 .34508 L .5248 .34505 L F
.52391 .34483 m .52438 .3451 L .52575 .34514 L F
.52464 .34504 m .52482 .34503 L .52481 .34503 L F
.52482 .34503 m .52623 .34491 L .52481 .34503 L F
.52631 .3451 m .52647 .345 L .52646 .345 L F
.52647 .345 m .52668 .34486 L .52646 .345 L F
.52646 .345 m .52668 .34486 L .52665 .34487 L F
.52639 .3452 m .52668 .34486 L p .52631 .3451 L F P
0 g
s
.52621 .34498 m .52626 .34475 L .52633 .34513 L .672 .728 .891 r
F
.52618 .34494 m .5267 .34492 L .52674 .34505 L F
.52626 .34504 m .52706 .34492 L .5268 .34503 L F
.52614 .34496 m .52635 .34516 L .52619 .34496 L F
.52602 .34505 m .52624 .34502 L .52626 .34504 L F
.52624 .34502 m .52706 .34492 L .52626 .34504 L F
.52634 .34515 m .52588 .34514 L .52626 .34504 L F
.52604 .34524 m .52607 .34518 L .5261 .34499 L F
.52591 .3453 m .52591 .34533 L .52591 .3453 L F
.52586 .34548 m .52601 .34505 L .52595 .34509 L F
.52581 .34518 m .52588 .34514 L .52634 .34515 L F
.52598 .3453 m .52604 .34503 L .52597 .3453 L F
.52586 .34537 m .52624 .34501 L .52568 .34543 L F
.52624 .34501 m .527 .3443 L .52621 .34498 L F
.52582 .34543 m .52587 .34523 L .52586 .34522 L F
.52624 .34501 m .52621 .34498 L .52568 .34543 L F
.52618 .34494 m .52753 .34521 L .52616 .34494 L F
.5262 .34497 m .52706 .34492 L .52622 .345 L F
.52618 .34494 m .52658 .34488 L .5267 .34492 L F
.52674 .34505 m .5267 .34492 L .52753 .34521 L F
.52609 .345 m .5261 .34499 L .52616 .34457 L F
.5266 .34488 m .5266 .34488 L .5266 .34488 L F
.5266 .34488 m .5266 .34488 L .52669 .34491 L F
.52658 .34488 m .5266 .34488 L .52669 .34491 L F
.52595 .34509 m .52601 .34505 L .52609 .34451 L F
.52608 .3445 m .52609 .34451 L .52613 .34426 L F
.52595 .34509 m .52609 .34451 L .52608 .3445 L F
.52601 .34505 m .52605 .34491 L .52603 .34491 L F
.52605 .34491 m .52607 .34481 L .52603 .34491 L F
.52603 .34491 m .52607 .34481 L .52605 .34478 L F
.52586 .34522 m .526 .34445 L .52599 .34446 L F
.52598 .34441 m .52608 .34392 L .52605 .34397 L F
.52614 .34497 m .52607 .34501 L .5256 .34505 L F
.52607 .34501 m .52706 .34492 L .52602 .34505 L F
.5261 .34485 m .52608 .34482 L .52595 .34544 L F
.52464 .34504 m .52495 .34489 L .526 .34491 L F
.52459 .34477 m .52442 .34483 L .52614 .34496 L F
.52509 .34473 m .52594 .345 L .5259 .34501 L F
.5262 .34497 m .52622 .345 L .52607 .34501 L F
.52604 .34524 m .5261 .34499 L .52609 .345 L F
.52597 .3453 m .52604 .34503 L .52601 .34505 L F
.52604 .34524 m .52616 .34457 L .52603 .34527 L F
.52568 .34543 m .52614 .34504 L .52611 .34495 L F
.52614 .34504 m .52626 .34493 L .52618 .34494 L F
.52604 .34525 m .52631 .3451 L .52626 .34504 L F
.52602 .34529 m .52631 .3451 L .52604 .34525 L F
.52604 .34525 m .5264 .34491 L .52607 .34519 L F
.5261 .34485 m .52595 .34544 L .52595 .34544 L F
.5264 .34491 m .52634 .34492 L .52592 .34531 L F
.52592 .34531 m .52592 .34531 L .52586 .34537 L F
.5264 .34491 m .52592 .34531 L .52592 .34531 L F
.52506 .34471 m .52506 .34463 L .52562 .34483 L F
.52642 .3444 m .52641 .34443 L .5284 .34258 L F
.52642 .3444 m .53276 .33853 L .53274 .33853 L F
.52705 .34427 m .52715 .34426 L .52782 .3437 L F
.5271 .34427 m .5271 .34427 L .52714 .34422 L F
.52757 .34378 m .52782 .3437 L .53512 .33756 L F
.53241 .33917 m .52739 .34419 L p .53199 .33926 L F P
0 g
s
.52739 .34419 m .52714 .34422 L .53199 .33926 L .672 .728 .891 r
F
.53699 .33459 m .53241 .33917 L p .53199 .33926 L F P
0 g
s
.52641 .34443 m .52663 .34445 L .53688 .33469 L .672 .728 .891 r
F
.53596 .33415 m .52642 .3444 L .53688 .33469 L F
.52662 .34447 m .52665 .34459 L .53688 .33469 L F
.52701 .34452 m .52801 .34378 L .5271 .3443 L F
.52739 .34419 m .52718 .34441 L p .52714 .34422 L F P
0 g
s
.52718 .34441 m .5271 .34427 L .52714 .34422 L .672 .728 .891 r
F
.52718 .34441 m .53688 .33469 L p .52665 .34459 L F P
0 g
s
.5271 .34438 m .52665 .34456 L .52721 .34356 L .672 .728 .891 r
F
.52601 .34472 m .52613 .34426 L .5261 .34428 L F
.52586 .34547 m .52602 .34474 L .52601 .34472 L F
.5262 .34489 m .5259 .34448 L .52607 .34441 L F
.52602 .34474 m .52613 .34426 L .52601 .34472 L F
.5271 .34504 m .52595 .34466 L .52715 .34503 L F
.52595 .34466 m .52479 .34426 L .52593 .34464 L F
.52595 .34466 m .52593 .34464 L .52715 .34503 L F
.52479 .34426 m .52451 .34417 L .52478 .34426 L F
.52586 .34548 m .52602 .34475 L .52586 .34547 L F
.52602 .34475 m .52613 .34426 L .52602 .34474 L F
.52602 .34475 m .52602 .34474 L .52586 .34547 L F
.52479 .34426 m .52478 .34426 L .52593 .34463 L F
.52593 .34464 m .52593 .34463 L .52715 .34503 L F
.52479 .34426 m .52593 .34463 L .52593 .34464 L F
.5255 .34915 m .52634 .34556 L .52605 .34535 L F
.52634 .34556 m .52619 .34688 L p .52605 .34569 L F P
0 g
s
.52618 .34615 m .52624 .34588 L p .52587 .34597 L .672 .728 .891 r
F P
0 g
s
.5264 .34491 m .5268 .34452 L .52634 .34492 L .672 .728 .891 r
F
.52784 .34351 m .52713 .34418 L .52721 .34356 L F
.52786 .34351 m .52713 .34418 L .52784 .34351 L F
.52786 .34351 m .5271 .34438 L p .52713 .34418 L F P
0 g
s
.5268 .34452 m .52792 .34343 L .52674 .34454 L .672 .728 .891 r
F
.52668 .34486 m .52661 .34466 L .52665 .34456 L F
.5268 .34452 m .52674 .34454 L .52634 .34492 L F
.52862 .34482 m .52714 .34491 L .52741 .3448 L F
.52741 .3448 m .52728 .34492 L .52745 .34486 L F
.52762 .34486 m .52718 .34487 L .52726 .34484 L F
.52964 .34497 m .52772 .34494 L .52762 .34486 L F
.52845 .3449 m .52641 .34479 L .52817 .34499 L F
.52595 .34534 m .52639 .3452 L .52631 .3451 L F
.52605 .34535 m .52639 .3452 L .52618 .34494 L F
.5262 .34496 m .5277 .34527 L .52767 .3453 L F
.52562 .34483 m .52616 .34494 L .52613 .34495 L F
.52573 .34598 m .52595 .34466 L .52594 .34465 L F
.52562 .34483 m .52596 .34467 L .52618 .34494 L F
.526 .34491 m .52568 .34484 L .52604 .34477 L F
.52604 .34477 m .52587 .34499 L .52609 .34482 L F
.52582 .34514 m .52329 .34507 L .52576 .34518 L F
.52459 .34522 m .52506 .34513 L .52528 .34518 L F
.52581 .34518 m .52336 .3451 L p .52588 .34514 L F P
0 g
s
.52535 .34583 m .52515 .34589 L .52589 .34497 L .672 .728 .891 r
F
.52587 .34499 m .52546 .3455 L .52594 .34498 L F
.52536 .34484 m .52594 .34489 L .52591 .34488 L F
.52459 .34477 m .52619 .34493 L .52621 .34492 L F
.526 .34491 m .5254 .3449 L .52568 .34484 L F
.52562 .34483 m .52618 .34494 L .52616 .34494 L F
.52607 .34518 m .52618 .34494 L .52612 .34487 L F
.52614 .34504 m .52618 .34494 L .52611 .34495 L F
.52546 .3455 m .52568 .34543 L .52573 .34537 L F
.52546 .3455 m .52573 .34537 L .52615 .34491 L F
.52559 .34553 m .52535 .34583 L .52551 .34556 L F
.52546 .3455 m .52433 .34691 L .52568 .34543 L F
.52498 .34619 m .52586 .34537 L .52568 .34543 L F
.52639 .3452 m .52651 .34515 L .52702 .34516 L F
.52634 .34515 m .52626 .34504 L .52682 .34503 L F
.52712 .34523 m .52694 .34522 L p .52702 .34516 L F P
0 g
s
.52729 .34543 m .52583 .34491 L .52802 .34539 L .672 .728 .891 r
F
.52713 .34545 m .52752 .34552 L .52748 .34557 L F
.52725 .34544 m .52752 .34552 L .52713 .34545 L F
.52686 .34537 m .52743 .34558 L p .52744 .3452 L F P
0 g
s
.5269 .34524 m .52811 .34533 L p .52687 .34521 L .672 .728 .891 r
F P
0 g
s
.52811 .34533 m .53438 .34581 L p .52792 .34529 L .672 .728 .891 r
F P
0 g
s
.52792 .34529 m .53438 .34581 L .53443 .34581 L .672 .728 .891 r
F
.52808 .3454 m .52753 .34521 L .52767 .34524 L F
.52785 .34528 m .52744 .3452 L .52743 .34558 L F
.52687 .34521 m .52811 .34533 L .52792 .34529 L F
.5429 .35125 m .54344 .35053 L p .5337 .34722 L F P
0 g
s
.5337 .34722 m .52814 .34534 L .53501 .34809 L .672 .728 .891 r
F
.5337 .34722 m .53501 .34809 L .5429 .35125 L F
.52587 .34499 m .52567 .34553 L .52529 .34571 L F
.52554 .34555 m .52568 .34554 L .52582 .34536 L F
.52605 .34535 m .52618 .34494 L .52607 .34518 L F
.50756 .34458 m .50765 .34377 L p .52038 .34446 L F P
0 g
s
.52506 .34472 m .51963 .34468 L .52038 .34446 L .672 .728 .891 r
F
.51963 .34468 m .50756 .34458 L .52038 .34446 L F
.52583 .34491 m .52562 .34483 L .52581 .34487 L F
.52583 .34491 m .52581 .34487 L .52808 .3454 L F
.52464 .34504 m .526 .34491 L .52608 .34492 L F
.52587 .34499 m .52594 .34498 L .52609 .34482 L F
.52594 .3449 m .52616 .34494 L .52616 .34494 L F
.52562 .34483 m .52616 .34494 L .52594 .3449 L F
.52553 .345 m .52614 .34497 L .5256 .34505 L F
.52589 .34499 m .52628 .34507 L .52633 .34513 L F
.5252 .34476 m .52595 .34498 L .52589 .34499 L F
.52604 .34503 m .52621 .34421 L .52601 .34505 L F
.52595 .34498 m .52628 .34507 L .52589 .34499 L F
.52615 .34491 m .526 .34491 L .52604 .34477 L F
.52608 .34492 m .526 .34491 L .52623 .34491 L F
.52594 .34498 m .52615 .34491 L .52609 .34482 L F
.52573 .34598 m .52595 .34466 L .52595 .34466 L F
.5256 .34505 m .52607 .34501 L .52602 .34505 L F
.52546 .3455 m .5261 .34495 L .52594 .34498 L F
.5261 .34495 m .52615 .34491 L .52594 .34498 L F
.52715 .34503 m .52695 .34496 L .52693 .34494 L F
.52649 .34487 m .52684 .34508 L .52729 .34495 L F
.52669 .34485 m .52671 .34483 L p .52669 .34485 L F P
0 g
s
.52665 .34487 m .52669 .34485 L .52669 .34485 L .672 .728 .891 r
F
.52668 .34486 m .52669 .34485 L p .52665 .34487 L F P
0 g
s
.52614 .34497 m .52623 .34491 L .52706 .34492 L .672 .728 .891 r
F
.52564 .34456 m .52563 .34455 L .52698 .345 L F
.52691 .34492 m .52662 .34482 L .52671 .34503 L F
.52618 .34494 m .52664 .34308 L .52648 .34277 L F
.52604 .34477 m .52609 .34482 L .52637 .34452 L F
.52651 .34421 m .52664 .34308 L p .52618 .34494 L F P
0 g
s
.52604 .34477 m .52637 .34452 L .52643 .34438 L .672 .728 .891 r
F
.52609 .34482 m .52615 .34491 L .52623 .34482 L F
.52608 .34501 m .52616 .34457 L .52615 .34456 L F
.52603 .34527 m .52608 .34501 L .52608 .34501 L F
.52608 .34501 m .52616 .34457 L .52608 .34501 L F
.52641 .34479 m .52615 .34491 L .52604 .34477 L F
.52726 .34484 m .52624 .3449 L .52641 .34479 L F
.52626 .34493 m .527 .3443 L .52611 .34495 L F
.52624 .3449 m .52615 .34491 L .52641 .34479 L F
.52609 .34482 m .52623 .34482 L .52637 .34452 L F
.52702 .345 m .52756 .34506 L .52705 .34499 L F
.52684 .34508 m .52785 .34528 L .52729 .34495 L F
.52789 .34525 m .52691 .34492 L .52671 .34503 L F
.52705 .34512 m .52672 .34505 L .52691 .34492 L F
.52671 .34505 m .52665 .34489 L .52691 .34492 L F
.52641 .34431 m .52615 .34491 L .52604 .34477 L F
.52643 .34435 m .52615 .34491 L .52641 .34431 L F
.52645 .34433 m .52615 .34491 L .5265 .34421 L F
.52643 .34482 m .52644 .34477 L p .52641 .34479 L F P
0 g
s
.52618 .34494 m .52643 .34482 L .52641 .34479 L .672 .728 .891 r
F
.5259 .34501 m .52633 .34513 L .52637 .34518 L F
.52613 .34495 m .52619 .34495 L .5262 .34496 L F
.52616 .34494 m .52619 .34495 L .52613 .34495 L F
.52514 .34513 m .52532 .34506 L .52626 .34504 L F
.52594 .345 m .52633 .34513 L .5259 .34501 L F
.52589 .34502 m .52639 .3452 L p .52618 .34494 L F P
0 g
s
.52639 .3452 m .52611 .34552 L p .52633 .34513 L .672 .728 .891 r
F P
0 g
s
.52619 .34495 m .5277 .34527 L .5262 .34496 L .672 .728 .891 r
F
.52639 .3452 m .52643 .34482 L p .52618 .34494 L F P
0 g
s
.52632 .34487 m .52633 .34521 L .52614 .34503 L .672 .728 .891 r
F
.52632 .34555 m .52636 .34517 L .52636 .34516 L F
.52611 .34552 m .52639 .3452 L p .52596 .34543 L F P
0 g
s
.52638 .34558 m .52639 .3452 L p .52632 .34555 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .52638 .34558 L p .52629 .34523 L .672 .728 .891 r
F P
0 g
s
.52634 .34556 m .52639 .3452 L p .52605 .34535 L .672 .728 .891 r
F P
0 g
s
.52633 .34521 m .52634 .34556 L .52622 .34524 L .672 .728 .891 r
F
.52633 .34521 m .52622 .34524 L .52614 .34503 L F
.52747 .3456 m .52639 .3452 L p .52748 .34557 L F P
0 g
s
.52639 .3452 m .52526 .34479 L p .52642 .3452 L .672 .728 .891 r
F P
0 g
s
.52526 .34479 m .52525 .34478 L .52642 .3452 L .672 .728 .891 r
F
.52629 .34469 m .52627 .34472 L .52627 .34469 L F
.52626 .3441 m .52627 .34411 L .5263 .34379 L F
.52612 .34487 m .52636 .34362 L .52631 .34355 L F
.5261 .34485 m .52621 .34421 L .52608 .34482 L F
.5263 .34467 m .52618 .34494 L .52596 .34454 L F
.52616 .34492 m .527 .3443 L .52615 .34491 L F
.52644 .34477 m .52632 .34487 L .5263 .34467 L F
.52632 .34487 m .5262 .34497 L .52618 .34494 L F
.52636 .34485 m .52668 .34504 L .52649 .34487 L F
.52595 .34534 m .52602 .34529 L .52604 .34525 L F
.52595 .34544 m .52595 .34544 L .52595 .34545 L F
.52604 .34525 m .52607 .34519 L .52586 .34537 L F
.52596 .34543 m .52601 .34532 L .52595 .34534 L F
.52591 .34554 m .52611 .34552 L .52596 .34543 L F
.52591 .34554 m .52593 .34556 L .52595 .34545 L F
.52572 .34598 m .52611 .34552 L p .52582 .34575 L F P
0 g
s
.52575 .34598 m .52579 .34582 L .52578 .34583 L .672 .728 .891 r
F
.52579 .34582 m .52586 .34548 L .52578 .34583 L F
.52582 .34575 m .52611 .34552 L .52591 .34554 L F
.52575 .34598 m .52587 .34599 L .52593 .34556 L F
.52575 .34598 m .52593 .34556 L .52586 .34548 L F
.52595 .34534 m .52604 .34525 L .52586 .34537 L F
.526 .34522 m .52589 .34543 L .52587 .34499 L F
.52573 .34598 m .52584 .34545 L .52582 .34543 L F
.52589 .34543 m .52523 .34676 L .52567 .34553 L F
.52589 .34543 m .52567 .34553 L .52587 .34499 L F
.52514 .34511 m .52639 .3452 L p .52513 .3451 L F P
0 g
s
.52588 .34514 m .52514 .34513 L .526 .34506 L .672 .728 .891 r
F
.52602 .34498 m .526 .34522 L .52589 .34502 L F
.52634 .34556 m .52605 .34569 L .52601 .34532 L F
.52615 .345 m .526 .34522 L .52615 .34491 L F
.52603 .34528 m .526 .34522 L .52615 .345 L F
.52608 .34518 m .52601 .34532 L .52598 .34504 L F
.52602 .3454 m .52607 .34518 L .52604 .34524 L F
.52634 .34556 m .52601 .34532 L .52608 .34518 L F
.52634 .34556 m .52598 .34504 L .52612 .34497 L F
.52753 .34497 m .53158 .34558 L .53058 .34529 L F
.52785 .34528 m .52792 .34529 L .52753 .34497 L F
.53242 .34551 m .52658 .34511 L .53152 .34537 L F
.52611 .34495 m .52616 .34492 L .52615 .34491 L F
.52528 .34474 m .52618 .34494 L .52636 .34485 L F
.52615 .34491 m .52613 .34495 L .52604 .34477 L F
.52613 .34495 m .526 .34522 L .52602 .34498 L F
.52613 .34495 m .52602 .34498 L .52604 .34477 L F
.52617 .34493 m .52573 .34469 L .52578 .34485 L F
.52602 .34498 m .52589 .34502 L .52587 .34499 L F
.5259 .34508 m .52601 .34529 L .5259 .34531 L F
.52604 .34477 m .52602 .34498 L .52587 .34499 L F
.52618 .34494 m .52578 .34486 L .52589 .34502 L F
.52597 .34504 m .52601 .34529 L .5259 .34508 L F
.52459 .34477 m .52536 .34484 L .52536 .34484 L F
.52538 .34478 m .52459 .34477 L .52536 .34484 L F
.52506 .34472 m .52503 .34507 L .52579 .34513 L F
.52618 .34494 m .52614 .34503 L .52612 .34497 L F
.5262 .34497 m .52614 .34503 L .52618 .34494 L F
.52643 .34482 m .52634 .34556 L p .52632 .34487 L F P
0 g
s
.52616 .34531 m .52603 .34528 L .52615 .345 L .672 .728 .891 r
F
.52639 .3452 m .52634 .34515 L .52651 .34515 L F
.52633 .34513 m .52752 .34552 L .52637 .34518 L F
.52636 .34517 m .52639 .3452 L .52643 .34518 L F
.52636 .34517 m .52643 .34518 L .5265 .34514 L F
.52618 .34494 m .52636 .34517 L .5265 .34514 L F
.52617 .34494 m .52579 .34513 L .52646 .34518 L F
.52684 .34508 m .52618 .34494 L .52699 .34533 L F
.52617 .34494 m .52646 .34518 L .52683 .34508 L F
.52658 .34511 m .5263 .34509 L .52667 .34507 L F
.52639 .3452 m .52616 .34551 L p .52616 .34531 L F P
0 g
s
.52639 .3452 m .52616 .34531 L .52615 .34491 L .672 .728 .891 r
F
.52594 .34464 m .52601 .34529 L .52588 .34457 L F
.52607 .34481 m .52621 .34421 L .52605 .34478 L F
.52588 .34457 m .526 .34472 L .52634 .3449 L F
.52604 .34477 m .52766 .34312 L .52754 .34318 L F
.52618 .34494 m .52605 .34478 L .52596 .34454 L F
.52605 .34478 m .52621 .34421 L .52613 .34426 L F
.52601 .34472 m .5261 .34428 L .52596 .34467 L F
.5263 .34467 m .52596 .34454 L .52605 .34451 L F
.52595 .34466 m .52607 .34401 L .52607 .34401 L F
.52607 .34441 m .5259 .34448 L .52589 .34372 L F
.526 .34442 m .52608 .34392 L .52598 .34441 L F
.52599 .34446 m .526 .34445 L .52607 .34401 L F
.52595 .3442 m .52639 .34445 L .52591 .34442 L F
.52602 .34433 m .52622 .34365 L .52608 .34392 L F
.5261 .34428 m .52622 .34365 L .52602 .34433 L F
.5261 .34428 m .52613 .34426 L .52622 .34365 L F
.52608 .34392 m .52622 .34365 L .52792 .33243 L F
.52607 .34401 m .52607 .34401 L .52608 .34392 L F
.5259 .34448 m .52584 .3445 L .52584 .34443 L F
.52583 .34451 m .52597 .34446 L .52792 .33243 L F
.52617 .34288 m .52636 .34421 L .52595 .3442 L F
.5265 .34421 m .52604 .34477 L .52657 .34421 L F
.52636 .34421 m .52639 .34445 L .52595 .3442 L F
.53596 .33415 m .53494 .33377 L p .5265 .34421 L F P
0 g
s
.53472 .33397 m .5265 .34421 L .53494 .33377 L .672 .728 .891 r
F
.5265 .34421 m .52657 .34421 L .53596 .33415 L F
.52729 .34543 m .52802 .34539 L .52808 .3454 L F
.52639 .3452 m .52642 .3452 L .52748 .34557 L F
.52639 .3452 m .52686 .34537 L p .5265 .34514 L F P
0 g
s
.52637 .34518 m .52725 .34544 L .52713 .34545 L .672 .728 .891 r
F
.52633 .34513 m .52628 .34507 L .52752 .34552 L F
.52767 .3453 m .5277 .34527 L .52808 .3454 L F
.5278 .34564 m .52639 .3452 L p .52814 .34534 L F P
0 g
s
.5263 .34509 m .52598 .34507 L .52628 .34507 L .672 .728 .891 r
F
.52598 .34507 m .526 .34506 L .52628 .34506 L F
.52618 .34494 m .52668 .34504 L .52636 .34485 L F
.52671 .34503 m .52617 .34493 L .52668 .34504 L F
.52668 .34504 m .52684 .34508 L .52649 .34487 L F
.52662 .34482 m .52634 .3449 L .52671 .34503 L F
.52671 .34503 m .52634 .3449 L .52621 .34493 L F
.52617 .34493 m .52618 .34494 L .52668 .34504 L F
.52618 .34494 m .52633 .34497 L .52633 .34497 L F
.52633 .34497 m .52668 .34505 L .52633 .34497 L F
.52633 .34497 m .52668 .34505 L .52668 .34504 L F
.52618 .34494 m .52668 .34505 L .52618 .34494 L F
.52668 .34481 m .52639 .3452 L p .52632 .3449 L F P
0 g
s
.52639 .3452 m .52668 .34481 L p .5263 .34509 L .672 .728 .891 r
F P
0 g
s
.52699 .34533 m .52618 .34494 L .52686 .34537 L .672 .728 .891 r
F
.52628 .34507 m .52628 .34506 L .52667 .34507 L F
.52598 .34507 m .52628 .34506 L .52628 .34507 L F
.52641 .34479 m .52527 .34473 L .52636 .34485 L F
.52632 .34487 m .52618 .34494 L .5263 .34467 L F
.52639 .3452 m .52615 .34491 L .52627 .34469 L F
.52621 .34493 m .52615 .3449 L .52617 .34493 L F
.52643 .34482 m .52636 .34485 L .52649 .34487 L F
.52641 .34479 m .52636 .34485 L .52643 .34482 L F
.52644 .34477 m .52643 .34482 L p .52632 .34487 L F P
0 g
s
.52661 .34479 m .52632 .3449 L .52627 .34472 L .672 .728 .891 r
F
.52639 .34445 m .52644 .34477 L .5263 .34467 L F
.52669 .34448 m .5265 .34442 L .52721 .34356 L F
.52665 .34456 m .5265 .34442 L .52669 .34448 L F
.52615 .34491 m .527 .3443 L .52684 .34416 L F
.52661 .34479 m .52627 .34472 L .52629 .34469 L F
.52668 .34481 m .52662 .34482 L .52661 .34479 L F
.52718 .34487 m .52615 .34491 L .52726 .34484 L F
.52745 .34486 m .52728 .34492 L .52749 .34494 L F
.52772 .34494 m .52615 .34491 L .52762 .34486 L F
.52559 .34627 m .52523 .34676 L p .52547 .34628 L F P
0 g
s
.52601 .34532 m .52619 .34688 L .52585 .34569 L .672 .728 .891 r
F
.52573 .34598 m .52571 .34627 L .52575 .34598 L F
.52616 .34551 m .52561 .34625 L p .52603 .34528 L F P
0 g
s
.52561 .34625 m .52559 .34627 L p .52603 .34528 L .672 .728 .891 r
F P
0 g
s
.52582 .34575 m .52591 .34554 L .52573 .34555 L .672 .728 .891 r
F
.52573 .34555 m .52591 .34554 L .52596 .34543 L F
.52559 .34627 m .52547 .34628 L .526 .34522 L F
.52571 .34611 m .52589 .34587 L p .52524 .34611 L F P
0 g
s
.52593 .34689 m .52576 .3469 L .52573 .34595 L .672 .728 .891 r
F
.5256 .34779 m .52604 .34524 L .52603 .34527 L F
.52571 .34627 m .52581 .3464 L .52587 .34599 L F
.52571 .34627 m .52587 .34599 L .52575 .34598 L F
.52576 .34534 m .5261 .34655 L .52549 .34691 L F
.52571 .34626 m .52594 .34555 L .52566 .34627 L F
.52592 .34553 m .52616 .34551 L .52598 .3454 L F
.52603 .34528 m .52559 .34627 L .526 .34522 L F
.52589 .34587 m .52616 .34551 L p .52585 .3457 L F P
0 g
s
.52576 .34534 m .52561 .34624 L .52586 .34546 L .672 .728 .891 r
F
.52561 .34624 m .52549 .34691 L .52574 .34594 L F
.52561 .34624 m .52574 .34594 L .52586 .34546 L F
.52543 .34584 m .52595 .34534 L .52539 .34583 L F
.5253 .34602 m .52585 .3457 L .52568 .34554 L F
.52585 .3457 m .52616 .34551 L .52592 .34553 L F
.52601 .34532 m .52585 .34569 L .52576 .34534 L F
.52574 .34594 m .52592 .34553 L .52586 .34546 L F
.52585 .3457 m .52592 .34553 L .52568 .34554 L F
.5253 .34602 m .52576 .3459 L .52585 .3457 L F
.52576 .3459 m .52589 .34587 L .52585 .3457 L F
.52566 .34627 m .52594 .34555 L .52592 .34553 L F
.52566 .34627 m .52592 .34553 L .52574 .34594 L F
.52549 .34691 m .52611 .34537 L .52602 .3453 L F
.52601 .34533 m .52602 .3453 L .52602 .3453 L F
.52549 .34691 m .52602 .3453 L .52601 .34533 L F
.52616 .34551 m .52607 .34535 L .52616 .34531 L F
.52616 .34551 m .52639 .3452 L p .52598 .3454 L F P
0 g
s
.52594 .34555 m .52602 .3453 L .52586 .34546 L .672 .728 .891 r
F
.52568 .34554 m .52592 .34553 L .52598 .3454 L F
.52581 .34514 m .52639 .3452 L .52579 .34513 L F
.52575 .34515 m .52639 .3452 L .52639 .3452 L F
.52575 .34515 m .52639 .3452 L .52575 .34515 L F
.52579 .34513 m .52639 .3452 L .52646 .34518 L F
.52639 .3452 m .52583 .34516 L p .52635 .34515 L F P
0 g
s
.52513 .3451 m .52575 .34515 L .52575 .34515 L .672 .728 .891 r
F
.52513 .3451 m .52639 .3452 L .52513 .3451 L F
.52513 .3451 m .52639 .3452 L .52509 .34507 L F
.52583 .34516 m .52514 .34511 L p .52587 .34513 L F P
0 g
s
.52583 .34516 m .52587 .34513 L .52635 .34515 L .672 .728 .891 r
F
.52134 .34517 m .51642 .34555 L .52177 .34523 L F
.50761 .34621 m .51526 .3458 L p .51642 .34555 L F P
0 g
s
.52136 .34547 m .50761 .34621 L p .52009 .345 L .672 .728 .891 r
F P
0 g
s
.50755 .3454 m .52317 .34524 L p .52436 .34486 L .672 .728 .891 r
F P
0 g
s
.52438 .34508 m .52171 .34525 L .5239 .34477 L .672 .728 .891 r
F
.52342 .34476 m .52336 .34507 L .52438 .3451 L F
.52342 .34476 m .52438 .3451 L .52391 .34483 L F
.52459 .34477 m .52342 .34476 L .52442 .34483 L F
.5239 .34477 m .52171 .34525 L .51971 .34472 L F
.52171 .34525 m .50755 .3454 L p .51971 .34472 L F P
0 g
s
.52342 .34476 m .50756 .34458 L .52336 .34507 L .672 .728 .891 r
F
.5254 .3449 m .50756 .34458 L .52519 .34473 L F
.52526 .34479 m .52509 .34473 L p .52525 .34478 L F P
0 g
s
.52509 .34473 m .5252 .34476 L .5252 .34476 L .672 .728 .891 r
F
.5252 .34476 m .52628 .34507 L .5252 .34476 L F
.52509 .34473 m .52562 .34483 L .52628 .34507 L F
.52506 .34471 m .52583 .345 L p .52578 .34486 L F P
0 g
s
.52583 .345 m .52589 .34502 L p .52578 .34486 L .672 .728 .891 r
F P
0 g
s
.52506 .34472 m .52579 .34513 L .52617 .34494 L .672 .728 .891 r
F
.52615 .3449 m .52573 .34469 L .52617 .34493 L F
.52607 .34481 m .52573 .34469 L .52615 .3449 L F
.52612 .34497 m .52598 .34504 L .52594 .34464 L F
.52595 .34466 m .526 .34442 L .52594 .34465 L F
.52605 .34478 m .52594 .34464 L .52591 .34442 L F
.52612 .34497 m .52594 .34464 L .52605 .34478 L F
.52634 .3449 m .52607 .34481 L .52621 .34493 L F
.52607 .34481 m .52615 .3449 L .52621 .34493 L F
.52601 .34505 m .52609 .34483 L .52598 .34507 L F
.52595 .34466 m .52607 .34401 L .52595 .34466 L F
.52615 .34456 m .52616 .34457 L .52621 .34421 L F
.52596 .34467 m .5261 .34428 L .52602 .34433 L F
.52639 .34445 m .5263 .34467 L .52591 .34442 L F
.52609 .34483 m .52637 .34404 L .52607 .34481 L F
.52532 .34477 m .52618 .34494 L .52528 .34474 L F
.52617 .34493 m .5251 .34472 L .52618 .34494 L F
.52609 .34483 m .52607 .34481 L .52598 .34507 L F
.52634 .3449 m .52632 .3449 L .52634 .3449 L F
.52662 .34482 m .52656 .3448 L .52661 .34479 L F
.52662 .34482 m .52588 .34457 L .52634 .3449 L F
.52607 .34481 m .52604 .34477 L .52662 .34482 L F
.52744 .3452 m .52684 .34508 L .52699 .34533 L F
.52683 .34508 m .52646 .34518 L .52792 .34529 L F
.52578 .34519 m .5259 .34531 L .52576 .34534 L F
.52576 .34534 m .52586 .34546 L .52596 .34508 L F
.52588 .34457 m .52597 .34504 L .5259 .34508 L F
.52662 .34482 m .52604 .34477 L .52588 .34457 L F
.52514 .34466 m .52479 .34427 L .52596 .34467 L F
.52573 .34459 m .52568 .34446 L .52581 .34445 L F
.52583 .34451 m .52564 .34443 L .52574 .34454 L F
.52592 .34462 m .52451 .34417 L .52583 .34451 L F
.52545 .34443 m .52513 .34448 L .52634 .3449 L F
.5257 .34456 m .52592 .34462 L .52593 .34463 L F
.52604 .34477 m .52552 .34472 L .52588 .34457 L F
.52581 .34517 m .52596 .34508 L .52604 .34476 L F
.52597 .34468 m .52604 .34476 L .52638 .3434 L F
.52581 .34517 m .52604 .34476 L .52597 .34468 L F
.52579 .34513 m .5259 .34531 L .52578 .34519 L F
.5259 .34508 m .5259 .34531 L .52579 .34513 L F
.52576 .34534 m .52596 .34508 L .52581 .34517 L F
.52589 .34513 m .52704 .34514 L .52712 .3452 L F
.52519 .34508 m .52592 .34511 L .52589 .34513 L F
.52592 .34511 m .52704 .34514 L .52589 .34513 L F
.52509 .34473 m .50756 .34458 L .52506 .34472 L F
.52329 .34507 m .52215 .34503 L .52332 .34508 L F
.50756 .34458 m .52224 .34507 L p .52215 .34503 L F P
0 g
s
.52335 .3451 m .50756 .34458 L p .52239 .34484 L .672 .728 .891 r
F P
0 g
s
.51045 .34392 m .52513 .3451 L .52509 .34507 L .672 .728 .891 r
F
.52335 .3451 m .52553 .345 L .5256 .34505 L F
.52366 .34499 m .52524 .34506 L .52519 .34508 L F
.52588 .34457 m .5259 .34508 L .52579 .34513 L F
.5265 .34421 m .52643 .34435 L .52641 .34431 L F
.52631 .34355 m .52636 .34362 L .52792 .33243 L F
.52634 .34286 m .52641 .34285 L .52792 .33243 L F
.52613 .34426 m .52641 .34285 L .52634 .34286 L F
.52613 .34426 m .52621 .34421 L .52641 .34285 L F
.52605 .34397 m .52608 .34392 L .52792 .33243 L F
.52667 .34281 m .52644 .34477 L p .52617 .34288 L F P
0 g
s
.52652 .34418 m .52645 .34433 L .5265 .34421 L .672 .728 .891 r
F
.52596 .34508 m .52606 .3448 L .52604 .34476 L F
.52591 .34442 m .52594 .34464 L .52588 .34457 L F
.52594 .34465 m .526 .34442 L .52598 .34441 L F
.52605 .34451 m .52596 .34454 L .52591 .34442 L F
.5263 .34509 m .52668 .34481 L .52619 .34492 L F
.52618 .34494 m .52607 .34481 L .52665 .34489 L F
.52637 .34452 m .52678 .34422 L .5266 .34426 L F
.52698 .3444 m .52627 .34469 L .52652 .34418 L F
.52618 .34494 m .52631 .34466 L .52613 .34497 L F
.52631 .34466 m .52656 .3441 L .52629 .34464 L F
.52631 .34466 m .52629 .34464 L .52613 .34497 L F
.5263 .34509 m .52619 .34492 L .52618 .34494 L F
.52665 .34489 m .52607 .34481 L .52662 .34482 L F
.52616 .34492 m .52668 .34481 L .52649 .3445 L F
.52607 .34535 m .52603 .34528 L .52616 .34531 L F
.52568 .34554 m .52639 .3452 L .5263 .34509 L F
.52602 .3453 m .52605 .34525 L .52602 .3453 L F
.52602 .34505 m .52604 .34503 L .52626 .34504 L F
.52602 .3453 m .52613 .34498 L .52594 .34524 L F
.52601 .34529 m .52601 .34532 L .52576 .34534 L F
.52602 .3453 m .52594 .34524 L .52586 .34546 L F
.52586 .34546 m .52594 .34524 L .52592 .34523 L F
.52568 .34554 m .52603 .34529 L .52616 .34492 L F
.52524 .34506 m .52632 .34511 L .52519 .34508 L F
.52603 .34529 m .5263 .34509 L .52618 .34494 L F
.52564 .34505 m .52626 .34504 L .52628 .34506 L F
.52606 .34519 m .52615 .34496 L .52613 .34497 L F
.52603 .34529 m .52618 .34494 L .52615 .34495 L F
.52671 .34505 m .52607 .34501 L .52618 .34494 L F
.52631 .34486 m .5262 .34493 L .52605 .34525 L F
.52564 .34505 m .52604 .34503 L .52602 .34505 L F
.52611 .34537 m .52631 .34486 L .52605 .34525 L F
.52611 .34537 m .52605 .34525 L .52602 .3453 L F
.52224 .34507 m .52576 .34518 L p .52215 .34503 L F P
0 g
s
.52335 .3451 m .52239 .34484 L .52495 .34489 L .672 .728 .891 r
F
.52335 .3451 m .52495 .34489 L .52464 .34504 L F
.52506 .34472 m .51045 .34392 L .52503 .34507 L F
.52347 .34485 m .51454 .3443 L .5226 .34475 L F
.52605 .34437 m .52625 .34382 L .52624 .34381 L F
.52578 .34519 m .52606 .34438 L .52605 .34437 L F
.52606 .34438 m .52625 .34382 L .52605 .34437 L F
.52578 .34519 m .52581 .34517 L .52606 .34439 L F
.52578 .34519 m .52606 .34439 L .52606 .34438 L F
.52657 .34346 m .52656 .34345 L .52596 .34508 L F
.52607 .34501 m .52607 .34501 L .52671 .34505 L F
.52606 .34502 m .52671 .34505 L .52604 .34503 L F
.52606 .34502 m .52607 .34501 L .52671 .34505 L F
.52628 .34506 m .52626 .34504 L .52667 .34507 L F
.52594 .34509 m .52598 .34507 L .52704 .34514 L F
.52632 .34553 m .52648 .34476 L p .52611 .34537 L F P
0 g
s
.52632 .34489 m .5262 .34576 L .52621 .34493 L .672 .728 .891 r
F
.5262 .34576 m .52609 .34658 L .52615 .3457 L F
.52624 .34588 m .52632 .34553 L p .52601 .34562 L F P
0 g
s
.52601 .34562 m .52632 .34553 L .52611 .34537 L .672 .728 .891 r
F
.5262 .34576 m .52615 .3457 L .52621 .34493 L F
.52598 .34507 m .52618 .34452 L .52596 .34508 L F
.52618 .34494 m .52619 .34492 L .52616 .34492 L F
.52588 .34457 m .52578 .34519 L .52596 .34466 L F
.52618 .34494 m .52612 .34497 L .52605 .34478 L F
.52602 .3453 m .52605 .34525 L .52613 .34497 L F
.52613 .34498 m .52613 .34497 L .52638 .34418 L F
.52602 .3453 m .52613 .34497 L .52613 .34498 L F
.52671 .34505 m .52618 .34494 L .52665 .34489 L F
.52673 .34505 m .52618 .34494 L .52645 .3448 L F
.5251 .34472 m .52618 .34494 L .52618 .34494 L F
.5251 .34472 m .52506 .34472 L .52668 .34505 L F
.5251 .34472 m .5251 .34472 L .52668 .34504 L F
.52519 .34473 m .52509 .34473 L .52506 .34472 L F
.5251 .34472 m .5251 .34472 L .52668 .34504 L F
.52618 .34494 m .52536 .34478 L .52607 .34481 L F
.52527 .34473 m .52528 .34474 L .52649 .34487 L F
.52514 .34466 m .51027 .33929 L .52479 .34427 L F
.51027 .33929 m .50977 .33911 L .51021 .33926 L F
.51027 .33929 m .51021 .33926 L .52479 .34427 L F
.52573 .34469 m .51045 .33935 L .52578 .34485 L F
.51045 .33935 m .50977 .33911 L .51035 .33932 L F
.51045 .33935 m .51035 .33932 L .52578 .34485 L F
.5251 .34472 m .52532 .34477 L .52528 .34474 L F
.52527 .34473 m .5251 .34472 L .52528 .34474 L F
.52578 .34485 m .51035 .33932 L .52506 .34471 L F
.5251 .34472 m .52506 .34471 L .5251 .34472 L F
.52536 .34478 m .52444 .34459 L .52549 .34473 L F
.52588 .34457 m .52545 .34443 L .526 .34472 L F
.52588 .34457 m .52502 .34467 L .52568 .3445 L F
.52571 .34479 m .5257 .34476 L .52607 .34481 L F
.52536 .34478 m .5257 .34476 L .52571 .34479 L F
.52536 .34478 m .52549 .34473 L .5257 .34476 L F
.52631 .34497 m .52663 .34503 L .52662 .34502 L F
.52618 .34494 m .52481 .34487 L .52516 .34474 L F
.52607 .34501 m .52467 .34492 L .52618 .34494 L F
.52467 .34492 m .52347 .34485 L .52474 .34489 L F
.52467 .34492 m .52474 .34489 L .52618 .34494 L F
.52613 .34498 m .52641 .3441 L .52601 .34505 L F
.52616 .34495 m .52598 .34492 L .52618 .34494 L F
.52578 .34519 m .52576 .34534 L .52581 .34517 L F
.52554 .34555 m .5257 .34539 L .52567 .3454 L F
.52601 .34505 m .52598 .34507 L .52592 .34523 L F
.5257 .34539 m .52616 .34492 L .52567 .3454 L F
.52565 .34541 m .52584 .34519 L .52584 .34517 L F
.52554 .34555 m .52567 .3454 L .52565 .34541 L F
.52594 .34524 m .52601 .34505 L .52592 .34523 L F
.52613 .34498 m .52601 .34505 L .52594 .34524 L F
.5257 .34539 m .52582 .34536 L .52616 .34492 L F
.52554 .34555 m .52582 .34536 L .5257 .34539 L F
.52671 .34505 m .52607 .34501 L .52671 .34505 L F
.52604 .34503 m .52671 .34505 L .52667 .34507 L F
.52632 .34511 m .52704 .34514 L .52632 .34512 L F
.5263 .34509 m .52628 .34507 L .52667 .34507 L F
.52639 .3452 m .52639 .3452 L .52639 .3452 L F
.52639 .3452 m .5269 .34524 L p .52639 .3452 L F P
0 g
s
.52646 .34518 m .5269 .34524 L .52687 .34521 L .672 .728 .891 r
F
.52639 .3452 m .5269 .34524 L .52646 .34518 L F
.52639 .3452 m .52635 .34515 L .52648 .34516 L F
.52789 .34532 m .52639 .3452 L p .52795 .34525 L F P
0 g
s
.52639 .3452 m .52648 .34516 L .52795 .34525 L .672 .728 .891 r
F
.52639 .3452 m .52618 .34494 L .52698 .34511 L F
.52846 .34585 m .52729 .34543 L .52808 .3454 L F
.53794 .34998 m .53794 .34998 L .53812 .35006 L F
.53226 .34763 m .53227 .34763 L .53812 .35006 L F
.52638 .34519 m .53227 .34763 L .53226 .34763 L F
.52865 .34614 m .52866 .34614 L .53812 .35006 L F
.5303 .34681 m .53039 .34682 L .53812 .35006 L F
.52638 .34519 m .53039 .34682 L .5303 .34681 L F
.53812 .35006 m .53477 .34865 L .53473 .34851 L F
.54228 .35195 m .53853 .35036 L p .53812 .35006 L F P
0 g
s
.52884 .34624 m .54228 .35195 L p .53099 .34655 L .672 .728 .891 r
F P
0 g
s
.52748 .34557 m .52752 .34552 L .53745 .3491 L .672 .728 .891 r
F
.53747 .34927 m .52747 .3456 L p .53745 .3491 L F P
0 g
s
.52747 .3456 m .52748 .34557 L .53745 .3491 L .672 .728 .891 r
F
.52743 .34558 m .52819 .34586 L p .52789 .34525 L F P
0 g
s
.53745 .3491 m .52846 .34585 L .52808 .3454 L .672 .728 .891 r
F
.5429 .35125 m .53747 .34927 L p .53745 .3491 L F P
0 g
s
.52819 .34586 m .5429 .35125 L p .52811 .34534 L .672 .728 .891 r
F P
0 g
s
.52789 .34525 m .52819 .34586 L .52811 .34534 L .672 .728 .891 r
F
.52789 .34532 m .52795 .34525 L .52809 .34526 L F
.52811 .34533 m .52809 .34526 L .53314 .34556 L F
.52811 .34533 m .52789 .34525 L .52811 .34534 L F
.52789 .34532 m .52809 .34526 L .52811 .34533 L F
.52811 .34533 m .52789 .34532 L p .52811 .34533 L F P
0 g
s
.52639 .3452 m .52698 .34511 L .52814 .34534 L .672 .728 .891 r
F
.52632 .34553 m .52623 .34555 L .52627 .34522 L F
.52618 .34494 m .52642 .34479 L .52645 .3448 L F
.52611 .34537 m .52648 .34476 L .52631 .34486 L F
.52613 .34488 m .52629 .34469 L .52612 .34487 L F
.52618 .34494 m .52516 .34474 L .52642 .34479 L F
.52613 .34488 m .52612 .34487 L .52603 .34497 L F
.52604 .34497 m .52603 .34497 L .52584 .34517 L F
.52586 .345 m .52598 .34492 L .52616 .34495 L F
.52347 .34485 m .5226 .34475 L .52481 .34487 L F
.52474 .34489 m .52481 .34487 L .52618 .34494 L F
.52347 .34485 m .52481 .34487 L .52474 .34489 L F
.52585 .34498 m .52598 .34492 L .52586 .345 L F
.52336 .34486 m .5234 .34485 L .52607 .34501 L F
.52088 .3447 m .52093 .34469 L .52607 .34501 L F
.52603 .34475 m .52583 .34504 L .52605 .34478 L F
.52366 .34499 m .52598 .34507 L .52594 .34509 L F
.52583 .34504 m .52557 .34543 L .52605 .34478 L F
.52098 .34473 m .52606 .34502 L .52604 .34503 L F
.52598 .34507 m .52564 .34505 L .526 .34506 L F
.52605 .34478 m .52557 .34543 L .52608 .34482 L F
.52632 .34511 m .52632 .34512 L .52519 .34508 L F
.52592 .34523 m .52598 .34507 L .52596 .34508 L F
.52567 .3454 m .52616 .34492 L .52613 .34488 L F
.52639 .3452 m .52589 .34505 L p .52618 .34494 L F P
0 g
s
.52589 .34505 m .52639 .3452 L p .52618 .34494 L .672 .728 .891 r
F P
0 g
s
.52618 .34452 m .52617 .34451 L .52596 .34508 L .672 .728 .891 r
F
.52584 .34517 m .52629 .34469 L .52631 .34466 L F
.52613 .34497 m .52649 .34424 L .52638 .34418 L F
.52622 .34469 m .52631 .34466 L .52638 .34449 L F
.52584 .34517 m .52631 .34466 L .52622 .34469 L F
.52643 .34479 m .52603 .34475 L .52659 .34498 L F
.52607 .34481 m .52502 .34467 L .52604 .34477 L F
.51045 .34392 m .52363 .34498 L .52361 .34498 L F
.50963 .34392 m .52514 .34511 L p .51045 .34392 L F P
0 g
s
.51045 .34392 m .52514 .34511 L .52513 .3451 L .672 .728 .891 r
F
.52514 .34474 m .52444 .34459 L .52514 .34473 L F
.52448 .3446 m .52444 .34459 L p .52514 .34474 L F P
0 g
s
.52645 .3448 m .52516 .34474 L .52514 .34474 L .672 .728 .891 r
F
.51028 .3393 m .52506 .34471 L p .51035 .33932 L F P
0 g
s
.52444 .34459 m .52228 .34392 L p .52428 .34423 L .672 .728 .891 r
F P
0 g
s
.52228 .34392 m .52448 .3446 L p .52287 .34375 L .672 .728 .891 r
F P
0 g
s
.52529 .34468 m .52514 .34474 L .52448 .3446 L .672 .728 .891 r
F
.52502 .34467 m .52444 .34459 L .52568 .3445 L F
.52529 .34468 m .52448 .3446 L .52448 .3446 L F
.52516 .34474 m .51454 .3443 L .52444 .3446 L F
.52526 .34485 m .52448 .3446 L p .52514 .34474 L F P
0 g
s
.52448 .3446 m .52579 .34501 L p .52514 .34473 L .672 .728 .891 r
F P
0 g
s
.52571 .34627 m .5256 .34779 L .52581 .3464 L .672 .728 .891 r
F
.5261 .34655 m .52602 .34689 L .52549 .34691 L F
.5256 .34779 m .52569 .34784 L .52604 .34539 L F
.52591 .3474 m .52618 .34615 L p .52549 .34691 L F P
0 g
s
.52549 .34691 m .52618 .34615 L .52587 .34597 L .672 .728 .891 r
F
.52542 .34654 m .52604 .34682 L .52541 .347 L F
.52533 .34687 m .52541 .347 L .52529 .34703 L F
.52542 .34654 m .52541 .347 L .52533 .34687 L F
.52507 .34619 m .52543 .34584 L .52498 .34619 L F
.52543 .34584 m .52539 .34583 L .52498 .34619 L F
.52529 .34571 m .52523 .34676 L .5249 .34619 L F
.52497 .3463 m .52502 .34639 L .5253 .34602 L F
.52513 .34607 m .52497 .3463 L .5253 .34602 L F
.52523 .34676 m .52571 .34611 L p .52475 .34673 L F P
0 g
s
.52475 .34673 m .52571 .34611 L .52524 .34611 L .672 .728 .891 r
F
.52464 .34755 m .52523 .34676 L p .52415 .3475 L F P
0 g
s
.52415 .3475 m .52523 .34676 L .52475 .34673 L .672 .728 .891 r
F
.51798 .35651 m .52464 .34755 L p .52415 .3475 L F P
0 g
s
.52566 .34636 m .51907 .35685 L p .52513 .34607 L .672 .728 .891 r
F P
0 g
s
.52544 .34664 m .52533 .34687 L .52552 .34659 L .672 .728 .891 r
F
.52532 .3469 m .52534 .34688 L p .52533 .34687 L F P
0 g
s
.52534 .34688 m .52552 .34659 L p .52533 .34687 L .672 .728 .891 r
F P
0 g
s
.52609 .34658 m .52604 .34682 L p .52542 .34654 L .672 .728 .891 r
F P
0 g
s
.5256 .34779 m .5255 .34915 L .52569 .34784 L .672 .728 .891 r
F
.52488 .3578 m .52589 .34937 L p .5255 .34915 L F P
0 g
s
.52619 .34688 m .52488 .3578 L p .52549 .34691 L .672 .728 .891 r
F P
0 g
s
.52369 .35771 m .52591 .3474 L p .52549 .34691 L .672 .728 .891 r
F P
0 g
s
.52529 .34703 m .52591 .3474 L .52522 .34732 L .672 .728 .891 r
F
.52604 .34682 m .52591 .3474 L p .52529 .34703 L F P
0 g
s
.52369 .35771 m .52251 .35757 L p .52522 .34732 L .672 .728 .891 r
F P
0 g
s
.52591 .3474 m .52369 .35771 L p .52522 .34732 L .672 .728 .891 r
F P
0 g
s
.52458 .34971 m .52466 .34967 L .5261 .34532 L .672 .728 .891 r
F
.52615 .34495 m .52618 .34494 L .52616 .34492 L F
.52613 .34488 m .52603 .34497 L .52604 .34497 L F
.52567 .3454 m .52629 .34469 L .52565 .34541 L F
.52579 .34501 m .52618 .34494 L .52618 .34494 L F
.52641 .3441 m .52637 .34404 L .52601 .34505 L F
.52618 .34495 m .52599 .34501 L .52603 .34475 L F
.52542 .34479 m .52631 .34497 L .52662 .34502 L F
.52484 .34467 m .52543 .34479 L .52542 .34479 L F
.52543 .34479 m .52631 .34497 L .52542 .34479 L F
.52614 .34538 m .52622 .34499 L .52624 .34501 L F
.52621 .34493 m .52609 .34658 L .52603 .3453 L F
.52612 .34536 m .52612 .34535 L .52614 .34538 L F
.52635 .34521 m .52632 .34489 L .52639 .34487 L F
.52648 .34501 m .52664 .34504 L .52663 .34503 L F
.52789 .34525 m .52671 .34503 L .52785 .34528 L F
.52712 .3452 m .52704 .34514 L .53314 .34556 L F
.52845 .3449 m .52817 .34499 L .539 .34617 L F
.52667 .34507 m .52671 .34505 L .53308 .34545 L F
.52668 .34504 m .52668 .34505 L .52792 .34529 L F
.52671 .34503 m .52668 .34504 L .52785 .34528 L F
.52658 .34511 m .52667 .34507 L .52687 .34508 L F
.52811 .34533 m .52705 .34512 L .52691 .34492 L F
.52718 .34514 m .52687 .34508 L .53308 .34545 L F
.52658 .34511 m .52687 .34508 L .52718 .34514 L F
.52814 .34534 m .52705 .34512 L .52705 .34512 L F
.52814 .34534 m .52811 .34533 L .52813 .34534 L F
.52814 .34534 m .52705 .34512 L .52811 .34533 L F
.53324 .34573 m .52811 .34533 L p .53314 .34556 L F P
0 g
s
.52811 .34533 m .52811 .34533 L .53314 .34556 L .672 .728 .891 r
F
.52663 .34503 m .52664 .34504 L .54483 .34743 L F
.52663 .34503 m .54483 .34743 L .54483 .34743 L F
.5266 .34503 m .5278 .34564 L .52699 .34511 L F
.52645 .345 m .52663 .34503 L .52631 .34497 L F
.52623 .34493 m .5278 .34564 L .52633 .34489 L F
.52633 .34498 m .52715 .34536 L .52713 .34534 L F
.52673 .34505 m .52671 .34505 L .52671 .34505 L F
.52705 .34512 m .52671 .34505 L .52672 .34505 L F
.52705 .34512 m .52672 .34505 L .52705 .34512 L F
.52904 .34552 m .54492 .34744 L p .52664 .34504 L F P
0 g
s
.5268 .34503 m .52706 .34492 L .52964 .34497 L .672 .728 .891 r
F
.52641 .34479 m .52649 .34487 L .52963 .34519 L F
.52973 .34518 m .52963 .34519 L .53214 .34545 L F
.52641 .34479 m .52963 .34519 L .52973 .34518 L F
.52641 .34479 m .53214 .34545 L .53232 .34544 L F
.52691 .34492 m .52665 .34489 L .52662 .34482 L F
.52729 .34495 m .52785 .34528 L .52753 .34497 L F
.52969 .34511 m .52673 .34505 L .52645 .3448 L F
.53308 .34545 m .53015 .34527 L .52969 .34511 L F
.53015 .34527 m .52673 .34505 L .52969 .34511 L F
.52629 .34469 m .52677 .34415 L .52638 .34449 L F
.52648 .34476 m .52663 .34406 L p .52631 .34486 L F P
0 g
s
.52613 .34488 m .52616 .34492 L .52677 .34415 L .672 .728 .891 r
F
.52666 .34387 m .52664 .34416 L .53455 .33419 L F
.52666 .34387 m .53455 .33419 L .5345 .33424 L F
.52656 .3441 m .52664 .34416 L .52666 .34387 L F
.52663 .34406 m .52669 .34379 L p .52656 .3441 L F P
0 g
s
.52669 .34379 m .5267 .34377 L p .52656 .3441 L .672 .728 .891 r
F P
0 g
s
.52638 .34418 m .52656 .3441 L .5267 .34377 L .672 .728 .891 r
F
.5265 .34406 m .52656 .3441 L .52666 .34387 L F
.5267 .34377 m .5269 .34393 L .5265 .34406 L F
.52721 .34356 m .5265 .34442 L .52642 .3444 L F
.52643 .34438 m .52637 .34452 L .52766 .34312 L F
.52839 .34258 m .5284 .34258 L .53276 .33853 L F
.52642 .3444 m .5284 .34258 L .52839 .34258 L F
.53596 .33415 m .52786 .34351 L p .5274 .34354 L F P
0 g
s
.53596 .33415 m .52726 .34355 L p .52721 .34356 L .672 .728 .891 r
F P
0 g
s
.5266 .34426 m .52678 .34422 L .53596 .33415 L .672 .728 .891 r
F
.52754 .34318 m .52766 .34312 L .53596 .33415 L F
.52684 .34416 m .52792 .34343 L .52813 .34274 L F
.527 .3443 m .52792 .34343 L .52684 .34416 L F
.52792 .34343 m .53596 .33415 L p .52813 .34274 L F P
0 g
s
.53489 .33376 m .527 .34438 L p .52652 .34418 L .672 .728 .891 r
F P
0 g
s
.52661 .3442 m .52677 .34415 L .53489 .33376 L .672 .728 .891 r
F
.53489 .33376 m .53379 .33341 L p .52668 .3438 L F P
0 g
s
.52668 .3438 m .5265 .34406 L .52673 .34379 L .672 .728 .891 r
F
.52668 .3438 m .52673 .34379 L .53489 .33376 L F
.52444 .3446 m .51454 .3443 L .51314 .34374 L F
.52595 .34534 m .52586 .34537 L .52498 .34619 L F
.52583 .34552 m .52575 .34557 L .52557 .34543 L F
.52586 .345 m .52583 .34552 L .52557 .34543 L F
.52564 .34505 m .52559 .34501 L .52604 .34503 L F
.52589 .34497 m .52538 .3456 L .52534 .34556 L F
.52589 .34505 m .52579 .34501 L p .52586 .345 L F P
0 g
s
.52579 .34501 m .52585 .34498 L .52586 .345 L .672 .728 .891 r
F
.52579 .34501 m .52526 .34485 L p .52598 .34492 L F P
0 g
s
.52579 .34501 m .52589 .34505 L p .52567 .34467 L .672 .728 .891 r
F P
0 g
s
.52468 .34475 m .52472 .34477 L .52614 .34496 L .672 .728 .891 r
F
.52526 .34485 m .52514 .34473 L .52618 .34494 L F
.52514 .34473 m .52579 .34501 L .52573 .34485 L F
.52467 .34474 m .52614 .34496 L .52615 .34496 L F
.52468 .34475 m .52614 .34496 L .52467 .34474 L F
.52294 .3445 m .52553 .34487 L .52294 .34449 L F
.52553 .34487 m .52614 .34496 L .52553 .34487 L F
.52407 .34483 m .52429 .34471 L .52516 .34474 L F
.52553 .34487 m .52553 .34487 L .52294 .34449 L F
.52603 .34475 m .52579 .34484 L .52625 .34492 L F
.52646 .34484 m .52632 .34553 L .52639 .34487 L F
.52635 .34488 m .52625 .34492 L .52659 .34498 L F
.52603 .34475 m .52625 .34492 L .52635 .34488 L F
.52605 .34525 m .52663 .34406 L .52656 .3441 L F
.52635 .34466 m .52621 .34493 L .52631 .34466 L F
.52621 .34493 m .52603 .3453 L .52618 .34494 L F
.52621 .34493 m .52618 .34494 L .52631 .34466 L F
.52557 .34543 m .52565 .34541 L .52622 .34469 L F
.52618 .3447 m .52622 .34469 L .52664 .34416 L F
.52557 .34543 m .52622 .34469 L .52618 .3447 L F
.52614 .34496 m .52611 .34496 L .52618 .34494 L F
.52589 .34505 m .52611 .34496 L .52614 .34496 L F
.52589 .34505 m .52586 .345 L .52611 .34496 L F
.52621 .34498 m .52622 .34499 L .52614 .34534 L F
.52618 .34495 m .52616 .34499 L .52618 .34494 L F
.52618 .34495 m .52591 .34569 L .52599 .34501 L F
.52618 .34494 m .52603 .3453 L .52601 .34501 L F
.52635 .34521 m .52629 .34508 L .52635 .34515 L F
.52584 .34519 m .52613 .34488 L .52584 .34517 L F
.52603 .34475 m .52594 .34512 L .52586 .345 L F
.52098 .34473 m .52607 .34501 L .52606 .34502 L F
.52633 .34498 m .52618 .34494 L .52715 .34536 L F
.5262 .34496 m .5262 .34497 L .52663 .34503 L F
.52629 .34498 m .52651 .34501 L .52648 .34501 L F
.5262 .34497 m .52651 .34501 L .52629 .34498 L F
.5262 .34497 m .52664 .34504 L .52651 .34501 L F
.52635 .34515 m .52629 .34508 L .52632 .34489 L F
.52617 .34495 m .52645 .345 L .52631 .34497 L F
.52614 .3449 m .52662 .34502 L .52659 .34498 L F
.52448 .3446 m .52448 .3446 L .52514 .34473 L F
.52444 .3446 m .52617 .34493 L .52614 .3449 L F
.52617 .34493 m .52662 .34502 L .52614 .3449 L F
.52662 .34502 m .52663 .34503 L .52752 .34514 L F
.52659 .34498 m .52662 .34502 L .52752 .34514 L F
.52669 .34379 m .52657 .34437 L p .52668 .3438 L F P
0 g
s
.52657 .34437 m .52632 .34553 L p .52656 .34438 L .672 .728 .891 r
F P
0 g
s
.52649 .34424 m .52656 .3441 L .52644 .34416 L .672 .728 .891 r
F
.52649 .34424 m .52644 .34416 L .52638 .34418 L F
.5265 .34406 m .52603 .34475 L .52664 .34416 L F
.52657 .34437 m .52656 .34438 L .52668 .3438 L F
.52634 .34489 m .52633 .34489 L .52647 .34494 L F
.52638 .34449 m .52677 .34415 L .52661 .3442 L F
.52668 .3438 m .52646 .34484 L .52645 .34433 L F
.52698 .3444 m .52668 .34481 L p .52627 .34469 L F P
0 g
s
.527 .34438 m .52698 .3444 L p .52652 .34418 L .672 .728 .891 r
F P
0 g
s
.52668 .34481 m .53489 .33376 L p .52649 .3445 L .672 .728 .891 r
F P
0 g
s
.53379 .33341 m .52726 .34381 L p .5269 .34393 L .672 .728 .891 r
F P
0 g
s
.52666 .34478 m .52646 .3443 L .52654 .34424 L .672 .728 .891 r
F
.52726 .34381 m .52666 .34478 L p .5265 .34406 L F P
0 g
s
.52666 .34478 m .52882 .34133 L p .52641 .34448 L .672 .728 .891 r
F P
0 g
s
.52634 .34489 m .52647 .34494 L .52828 .34553 L .672 .728 .891 r
F
.52634 .34489 m .52828 .34553 L .52826 .34552 L F
.52643 .34479 m .52659 .34498 L .52752 .34514 L F
.52656 .34481 m .52634 .34489 L .52826 .34552 L F
.52629 .34465 m .52618 .34495 L .52603 .34475 L F
.52631 .34466 m .52618 .34494 L .52599 .3446 L F
.52631 .34486 m .52663 .34406 L .5262 .34493 L F
.52635 .34466 m .52632 .34489 L .52621 .34493 L F
.52622 .34499 m .52629 .34465 L .52624 .34501 L F
.52621 .34498 m .52618 .34494 L .52629 .34465 L F
.52607 .3448 m .52623 .34493 L .52633 .34489 L F
.52611 .34486 m .52693 .34501 L .52695 .34505 L F
.52448 .3446 m .52448 .3446 L .52444 .3446 L F
.52645 .3448 m .52514 .34474 L .52529 .34468 L F
.52603 .34475 m .52444 .3446 L .52579 .34484 L F
.52572 .3447 m .52623 .34493 L .52573 .34469 L F
.52544 .3448 m .52551 .34486 L .52631 .34497 L F
.52572 .3447 m .52589 .34505 L .52623 .34493 L F
.52567 .34467 m .52569 .34471 L .52572 .3447 L F
.52569 .34471 m .52589 .34505 L .52572 .3447 L F
.52562 .34489 m .52637 .34518 L .5262 .34497 L F
.52614 .34495 m .52616 .34495 L .52616 .34495 L F
.52616 .34495 m .52616 .34495 L .52616 .34495 L F
.52616 .34495 m .52617 .34495 L .52617 .34495 L F
.52618 .34494 m .52601 .34501 L .526 .34472 L F
.52613 .34488 m .52623 .34493 L .52607 .3448 L F
.52551 .34486 m .52585 .34491 L .52585 .34491 L F
.52585 .34491 m .52614 .34495 L .52585 .34491 L F
.52585 .34491 m .52614 .34495 L .52616 .34495 L F
.52593 .34463 m .52601 .34501 L .5258 .34509 L F
.52594 .34512 m .52583 .34563 L .52586 .345 L F
.52593 .34552 m .52583 .34563 L .52603 .34475 L F
.52587 .34566 m .52583 .34563 L .52593 .34552 L F
.52583 .34552 m .52583 .34563 L .52575 .34557 L F
.52549 .34691 m .52571 .34626 L .52566 .34627 L F
.52587 .34566 m .52577 .34589 L .52583 .34563 L F
.52567 .34556 m .52566 .34557 L .52568 .34554 L F
.52583 .34563 m .52566 .34636 L .52557 .34543 L F
.5258 .34509 m .5259 .34559 L .52542 .34654 L F
.5259 .34559 m .52609 .34658 L .52548 .34655 L F
.52567 .34553 m .52523 .34676 L .52529 .34571 L F
.52513 .34607 m .52566 .34557 L .52567 .34556 L F
.52513 .34607 m .5253 .34602 L .52566 .34557 L F
.52513 .34607 m .52568 .34554 L .52554 .34555 L F
.52557 .34543 m .52513 .34607 L .52565 .34541 L F
.52524 .34611 m .52589 .34587 L .5253 .34602 L F
.52557 .34543 m .52566 .34636 L .52513 .34607 L F
.5259 .34559 m .52548 .34655 L .52542 .34654 L F
.52591 .34569 m .52566 .34636 L .52577 .34589 L F
.52591 .34569 m .52577 .34589 L .52587 .34566 L F
.52591 .34569 m .52587 .34566 L .52593 .34552 L F
.52509 .34507 m .52581 .34514 L .52579 .34513 L F
.52514 .34511 m .52519 .34508 L .52635 .34515 L F
.52601 .34501 m .52603 .3453 L .5258 .34509 L F
.52603 .3453 m .52604 .34555 L .52597 .34542 L F
.52603 .3453 m .52597 .34542 L .5258 .34509 L F
.52587 .34597 m .52624 .34588 L .52601 .34562 L F
.52604 .34555 m .52609 .34658 L .52584 .34529 L F
.52604 .34555 m .52584 .34529 L .5258 .34509 L F
.52558 .34491 m .52637 .34518 L .52562 .34489 L F
.52529 .345 m .52581 .34509 L .52558 .34491 L F
.52581 .34509 m .52637 .34518 L .52558 .34491 L F
.52615 .34496 m .52614 .34496 L .5262 .34497 L F
.52616 .34495 m .52619 .34496 L .52616 .34495 L F
.52656 .34481 m .52639 .3452 L .52627 .34491 L F
.5261 .34484 m .52642 .34491 L .52611 .34486 L F
.52642 .34491 m .52693 .34501 L .5264 .34491 L F
.52646 .34484 m .52639 .34487 L .52645 .34433 L F
.52666 .34478 m .52656 .34481 L .52645 .34426 L F
.52656 .34481 m .52627 .34491 L .5264 .34443 L F
.52656 .34481 m .5264 .34443 L .52645 .34426 L F
.52693 .34501 m .52662 .34493 L .52687 .3449 L F
.52615 .3449 m .52631 .34459 L .52629 .34457 L F
.52639 .3452 m .5278 .34564 L p .52618 .34494 L F P
0 g
s
.52621 .34498 m .52622 .34493 L .52622 .34499 L .672 .728 .891 r
F
.52623 .34493 m .52618 .34494 L .52633 .34498 L F
.52622 .34493 m .52623 .34493 L .52622 .34499 L F
.52619 .34496 m .52645 .345 L .52619 .34495 L F
.52617 .34495 m .52645 .345 L .52617 .34495 L F
.52626 .34504 m .52647 .3449 L .52618 .34495 L F
.52637 .34518 m .52684 .34526 L .5262 .34497 L F
.52639 .3452 m .52624 .34501 L .52627 .34491 L F
.52633 .34489 m .5266 .34503 L .52699 .34511 L F
.52741 .345 m .5272 .34504 L .52752 .34514 L F
.52904 .34552 m .52656 .34481 L .52812 .34534 L F
.52904 .34552 m .52812 .34534 L .52923 .34571 L F
.52904 .34552 m .52812 .34534 L .52904 .34552 L F
.52733 .34488 m .52643 .34479 L .5272 .34504 L F
.52624 .34501 m .52629 .34465 L .52634 .34463 L F
.52599 .3446 m .526 .34472 L .52593 .34463 L F
.52656 .34481 m .52593 .34463 L .52633 .34489 L F
.52564 .34456 m .52451 .34417 L .52563 .34455 L F
.5257 .34456 m .52451 .34417 L .52571 .34456 L F
.52545 .34443 m .50977 .33911 L .52513 .34448 L F
.52568 .3445 m .52444 .34459 L .52539 .34441 L F
.52444 .34459 m .52428 .34423 L .52539 .34441 L F
.52593 .34463 m .52287 .34375 L .52607 .3448 L F
.52603 .34475 m .52608 .34482 L .52664 .34416 L F
.52606 .3448 m .52636 .34401 L .52604 .34476 L F
.52618 .34494 m .526 .34472 L .52599 .3446 L F
.52622 .34493 m .52629 .34465 L .52623 .34493 L F
.52593 .34463 m .52607 .3448 L .52633 .34489 L F
.52573 .34469 m .52613 .34488 L .52607 .3448 L F
.526 .34472 m .52601 .34501 L .52593 .34463 L F
.52687 .3449 m .52602 .34474 L .52593 .34463 L F
.52666 .34478 m .52659 .34488 L p .52656 .34481 L F P
0 g
s
.52659 .34488 m .52639 .3452 L p .52656 .34481 L .672 .728 .891 r
F P
0 g
s
.52635 .34521 m .52627 .34522 L .52629 .34508 L .672 .728 .891 r
F
.52632 .34553 m .52627 .34522 L .52635 .34521 L F
.52639 .3452 m .52603 .34578 L p .52624 .34501 L F P
0 g
s
.52612 .34535 m .52621 .34498 L .52614 .34534 L .672 .728 .891 r
F
.5262 .34497 m .52684 .34526 L .52664 .34504 L F
.52639 .3452 m .52659 .34488 L p .52626 .34504 L F P
0 g
s
.52603 .34578 m .52618 .34494 L .52621 .34498 L .672 .728 .891 r
F
.52615 .34496 m .5262 .34497 L .5262 .34496 L F
.52619 .34496 m .52619 .34495 L .52616 .34495 L F
.52587 .34514 m .52618 .34495 L .52628 .34507 L F
.52626 .34504 m .52618 .34495 L .52608 .34496 L F
.52656 .34481 m .52826 .34552 L .52807 .34539 L F
.52684 .34526 m .52904 .34552 L p .52664 .34504 L F P
0 g
s
.52571 .34512 m .52639 .3452 L p .52577 .3451 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .52587 .34514 L p .52656 .34502 L .672 .728 .891 r
F P
0 g
s
.52666 .34503 m .52663 .34497 L .52695 .34505 L .672 .728 .891 r
F
.52666 .34504 m .52656 .34502 L .52675 .34499 L F
.52639 .3452 m .52656 .34502 L .52666 .34504 L F
.52601 .34525 m .52616 .34492 L .52615 .3449 L F
.52581 .34509 m .52639 .3452 L .52637 .34518 L F
.52444 .3446 m .51314 .34374 L .51544 .34371 L F
.52407 .34483 m .51454 .3443 L .52429 .34471 L F
.52607 .34501 m .51454 .3443 L .52607 .34501 L F
.5203 .34419 m .52583 .34511 L .52581 .34509 L F
.52583 .34511 m .52639 .3452 L .52581 .34509 L F
.52603 .34578 m .52616 .34499 L .52618 .34495 L F
.52585 .34531 m .52639 .3452 L .52626 .34504 L F
.5261 .34532 m .52639 .3452 L .52622 .34499 L F
.52612 .34535 m .52614 .34534 L .52614 .34538 L F
.52603 .34578 m .52612 .34536 L .52614 .34538 L F
.52435 .35057 m .52629 .34547 L .5261 .34532 L F
.52533 .34687 m .52604 .34527 L .52601 .34525 L F
.52533 .34687 m .52601 .34525 L .52593 .34518 L F
.52542 .34654 m .52585 .3454 L .52583 .34539 L F
.52603 .34578 m .52591 .34569 L .52616 .34499 L F
.52603 .34578 m .52639 .3452 L p .52548 .34587 L F P
0 g
s
.52629 .34547 m .52639 .3452 L .5261 .34532 L .672 .728 .891 r
F
.52604 .34527 m .5262 .3449 L .52601 .34525 L F
.52601 .34525 m .52611 .34499 L .52593 .34518 L F
.52611 .34499 m .52599 .34506 L .52593 .34518 L F
.52583 .34539 m .52585 .3454 L .52601 .34495 L F
.52585 .34531 m .52626 .34504 L .52608 .34496 L F
.52583 .34539 m .52601 .34495 L .52601 .34492 L F
.52363 .34498 m .52433 .34504 L .52361 .34498 L F
.52329 .34507 m .52332 .34508 L .52576 .34518 L F
.52514 .34513 m .52335 .3451 L .52532 .34506 L F
.52433 .34504 m .52639 .3452 L .52433 .34504 L F
.52433 .34504 m .52433 .34504 L .52361 .34498 L F
.52593 .34463 m .52564 .34573 L .52605 .34478 L F
.52564 .34573 m .52558 .34592 L .52566 .34574 L F
.52564 .34573 m .52566 .34574 L .52605 .34478 L F
.52558 .34592 m .52547 .34635 L .52565 .34586 L F
.52558 .34592 m .52565 .34586 L .52605 .34478 L F
.52662 .34493 m .52606 .3448 L .52658 .34484 L F
.52659 .34488 m .52666 .34478 L p .52647 .3449 L F P
0 g
s
.52662 .34493 m .52658 .34484 L .52687 .3449 L .672 .728 .891 r
F
.52642 .34491 m .5264 .34491 L .52611 .34486 L F
.52626 .34504 m .52659 .34488 L .52647 .3449 L F
.52666 .34503 m .52563 .34477 L .52663 .34497 L F
.52514 .34473 m .52573 .34485 L .52567 .34467 L F
.52563 .34477 m .52558 .34476 L .52563 .34477 L F
.52612 .34487 m .52635 .34492 L .52635 .34492 L F
.52563 .34477 m .52612 .34487 L .52612 .34487 L F
.52612 .34487 m .52635 .34492 L .52612 .34487 L F
.52611 .34499 m .52615 .3449 L .52599 .34506 L F
.52615 .3449 m .52632 .34449 L .52611 .34486 L F
.52615 .3449 m .52611 .34486 L .52599 .34506 L F
.52593 .3451 m .52594 .3451 L .52605 .34478 L F
.52605 .34478 m .52605 .34478 L .52622 .34432 L F
.52593 .3451 m .52605 .34478 L .52605 .34478 L F
.52639 .3452 m .52684 .34526 L p .52649 .3452 L F P
0 g
s
.52637 .34518 m .52639 .3452 L .52649 .3452 L .672 .728 .891 r
F
.52639 .3452 m .52639 .3452 L p .52637 .34518 L F P
0 g
s
.52716 .3454 m .52639 .3452 L p .52703 .34518 L .672 .728 .891 r
F P
0 g
s
.52587 .34514 m .52571 .34512 L p .52618 .34494 L .672 .728 .891 r
F P
0 g
s
.52591 .34517 m .52591 .34517 L .52594 .3451 L .672 .728 .891 r
F
.52591 .34517 m .52594 .3451 L .52593 .3451 L F
.52565 .34586 m .52605 .34478 L .52565 .34586 L F
.52605 .34478 m .52622 .34432 L .52605 .34478 L F
.52605 .34478 m .52605 .34478 L .52565 .34586 L F
.52565 .34586 m .52605 .34478 L .52605 .34478 L F
.52575 .34518 m .5258 .34539 L .52608 .34496 L F
.52814 .34534 m .52813 .34534 L .5429 .35125 L F
.52811 .34533 m .52811 .34534 L .5429 .35125 L F
.54344 .35053 m .5278 .34564 L p .52814 .34534 L F P
0 g
s
.52656 .34481 m .52941 .3459 L .52923 .34571 L .672 .728 .891 r
F
.52697 .3451 m .52666 .34503 L .52695 .34505 L F
.52699 .34511 m .52695 .34505 L .52774 .34522 L F
.52697 .3451 m .52695 .34505 L .52699 .34511 L F
.52695 .34505 m .52693 .34501 L .52904 .34552 L F
.52733 .34488 m .52752 .34514 L .53217 .34576 L F
.52904 .34552 m .52693 .34501 L .52687 .3449 L F
.52697 .3451 m .52774 .34522 L .52776 .34526 L F
.52639 .3452 m .52675 .34499 L .53101 .34545 L F
.52639 .3452 m .52624 .34501 L .52699 .34517 L F
.52639 .3452 m .52699 .34517 L .52703 .34518 L F
.52547 .34635 m .52565 .34586 L .52565 .34586 L F
.52478 .35034 m .52639 .3452 L p .52435 .35057 L F P
0 g
s
.52542 .34654 m .52544 .34656 L .52585 .3454 L .672 .728 .891 r
F
.52547 .34635 m .52549 .34635 L .52591 .34517 L F
.52547 .34635 m .52591 .34517 L .52591 .34517 L F
.52603 .34578 m .52566 .34636 L .52591 .34569 L F
.52547 .34635 m .52542 .34654 L .52549 .34635 L F
.52552 .34659 m .52603 .34578 L p .52505 .34652 L F P
0 g
s
.52505 .34652 m .52603 .34578 L .52548 .34587 L .672 .728 .891 r
F
.5251 .34725 m .52532 .3469 L p .52462 .34715 L F P
0 g
s
.52462 .34715 m .52532 .3469 L .52544 .34664 L .672 .728 .891 r
F
.52542 .34654 m .52533 .34687 L .52544 .34656 L F
.52462 .34715 m .52552 .34659 L .52505 .34652 L F
.51907 .35685 m .5251 .34725 L p .52462 .34715 L F P
0 g
s
.52593 .34552 m .52019 .35714 L .52575 .3454 L .672 .728 .891 r
F
.52458 .34971 m .5261 .34531 L .52607 .34529 L F
.52458 .34971 m .5261 .34532 L .5261 .34531 L F
.52579 .34584 m .52585 .34692 L .52537 .3468 L F
.52432 .34919 m .52019 .35714 L p .52593 .34552 L F P
0 g
s
.52628 .34521 m .52585 .34692 L .52579 .34584 L .672 .728 .891 r
F
.52602 .34532 m .52575 .3454 L .52591 .34506 L F
.52548 .34587 m .52639 .3452 L .52585 .34531 L F
.52595 .34547 m .52575 .3454 L .52602 .34532 L F
.52606 .34522 m .52579 .34584 L .52576 .34523 L F
.52628 .34521 m .52579 .34584 L .52606 .34522 L F
.5261 .34553 m .52595 .34547 L .52602 .34532 L F
.5252 .34676 m .52256 .35735 L .52432 .34919 L F
.52552 .34472 m .52502 .34467 L .52588 .34457 L F
.52287 .34375 m .52514 .34473 L .52567 .34467 L F
.52256 .34412 m .52615 .3449 L .52617 .34492 L F
.52041 .34364 m .52254 .34411 L .52256 .34412 L F
.52254 .34411 m .52615 .3449 L .52256 .34412 L F
.52479 .3446 m .5247 .34454 L .52615 .3449 L F
.52444 .3446 m .52631 .34497 L .52484 .34467 L F
.52464 .34452 m .52448 .3446 L .52514 .34473 L F
.52041 .34364 m .52567 .34481 L .52574 .34488 L F
.52486 .34865 m .52506 .34829 L .5262 .3449 L F
.52552 .34487 m .52645 .345 L .52551 .34486 L F
.52555 .34491 m .52565 .34487 L .526 .34491 L F
.52599 .34491 m .52617 .34492 L .52614 .34494 L F
.52609 .34493 m .526 .34491 L .52621 .34493 L F
.52555 .34491 m .526 .34491 L .52609 .34493 L F
.52574 .34488 m .52599 .34491 L .52608 .34496 L F
.52617 .34492 m .52623 .34494 L .52618 .34495 L F
.52647 .3449 m .52666 .34478 L .52619 .34493 L F
.52571 .34512 m .52555 .34491 L .52617 .34493 L F
.52617 .34492 m .52615 .3449 L .52697 .3451 L F
.52695 .3451 m .52697 .3451 L .52699 .34511 L F
.52617 .34492 m .52697 .3451 L .52695 .3451 L F
.52656 .34502 m .52621 .34493 L .52675 .34499 L F
.52628 .34507 m .52622 .34495 L .52656 .34502 L F
.52618 .34495 m .52699 .34511 L .52608 .34496 L F
.52623 .34494 m .52695 .3451 L .52618 .34495 L F
.52695 .3451 m .52699 .34511 L .52618 .34495 L F
.52618 .34495 m .52621 .34493 L .52622 .34495 L F
.52618 .34495 m .52622 .34495 L .52628 .34507 L F
.52622 .34495 m .52621 .34493 L .52656 .34502 L F
.52606 .3448 m .52602 .34474 L .52658 .34484 L F
.52601 .34525 m .5262 .3449 L .52631 .34459 L F
.52618 .34495 m .52619 .34493 L .52617 .34493 L F
.52647 .3449 m .52619 .34493 L .52618 .34495 L F
.52618 .34495 m .52619 .34495 L .5262 .3449 L F
.52618 .34494 m .52617 .34493 L .52621 .34493 L F
.5265 .34406 m .52629 .34465 L .52603 .34475 L F
.52635 .34466 m .52599 .3446 L .52616 .34453 L F
.52606 .3448 m .52628 .3445 L .52615 .34455 L F
.52593 .34518 m .5261 .34485 L .52606 .3448 L F
.52565 .34473 m .52571 .34471 L .52693 .34501 L F
.5261 .34485 m .52628 .3445 L .52606 .3448 L F
.52565 .34473 m .52609 .34483 L .52562 .34475 L F
.52609 .34483 m .52693 .34501 L .5261 .34484 L F
.52609 .34483 m .5261 .34484 L .52562 .34475 L F
.52571 .34512 m .52615 .34494 L .52617 .34494 L F
.52614 .34494 m .52618 .34495 L .52608 .34496 L F
.52617 .34492 m .52618 .34495 L .52614 .34494 L F
.52617 .34494 m .52617 .34493 L .52618 .34494 L F
.52615 .34494 m .52617 .34493 L .52617 .34494 L F
.52618 .34495 m .52617 .34493 L .52608 .34496 L F
.52599 .34491 m .52614 .34494 L .52608 .34496 L F
.52481 .34487 m .52513 .34474 L .52516 .34474 L F
.52444 .3446 m .52449 .34471 L .52551 .34486 L F
.52444 .3446 m .52551 .34486 L .52544 .3448 L F
.52041 .34364 m .52215 .34391 L .5247 .34454 L F
.52287 .34375 m .52448 .3446 L .52464 .34452 L F
.52451 .34417 m .50977 .33911 L .52482 .34411 L F
.52228 .34392 m .50923 .33984 L p .52539 .34441 L F P
0 g
s
.50923 .33984 m .52228 .34392 L p .52287 .34375 L .672 .728 .891 r
F P
0 g
s
.52443 .34448 m .50877 .3406 L .52455 .34443 L .672 .728 .891 r
F
.52538 .34463 m .50877 .3406 L .52563 .34454 L F
.52041 .34364 m .52287 .34428 L p .52155 .34362 L F P
0 g
s
.52195 .34435 m .52294 .3445 L .52294 .34449 L .672 .728 .891 r
F
.52444 .3446 m .52195 .34435 L .52449 .34471 L F
.52493 .3447 m .52168 .34437 L .52287 .34428 L F
.52294 .34449 m .52468 .34475 L .52467 .34474 L F
.52195 .34435 m .52201 .34441 L .52472 .34477 L F
.52195 .34435 m .52472 .34477 L .52468 .34475 L F
.52195 .34435 m .52552 .34487 L .52551 .34486 L F
.52465 .34476 m .52122 .3444 L .52493 .3447 L F
.51544 .34371 m .51314 .34374 L .51227 .3434 L F
.50765 .34377 m .50963 .34392 L p .51045 .34392 L F P
0 g
s
.51454 .3443 m .50765 .34377 L p .51227 .3434 L .672 .728 .891 r
F P
0 g
s
.50781 .34296 m .5206 .3445 L p .5203 .34419 L .672 .728 .891 r
F P
0 g
s
.52122 .3444 m .50781 .34296 L .52168 .34437 L .672 .728 .891 r
F
.52122 .3444 m .52168 .34437 L .52493 .3447 L F
.526 .34491 m .52465 .34476 L .52493 .3447 L F
.52575 .34518 m .52462 .34715 L .5258 .34539 L F
.52566 .34535 m .52567 .34558 L .52557 .3455 L F
.52557 .3455 m .52315 .35089 L .5192 .35663 L F
.52567 .34558 m .52315 .35089 L .52557 .3455 L F
.52315 .35089 m .52019 .35714 L .5192 .35663 L F
.52297 .3443 m .52497 .3447 L .52622 .345 L F
.52533 .34687 m .52486 .34865 L .52619 .34495 L F
.52576 .34491 m .52622 .345 L .52624 .34501 L F
.52287 .34428 m .52575 .34489 L .52576 .34491 L F
.52575 .34489 m .52622 .345 L .52576 .34491 L F
.52618 .34452 m .52657 .34346 L .52617 .34451 L F
.52606 .34438 m .52606 .34439 L .52625 .34382 L F
.52624 .34381 m .52625 .34382 L .52638 .3434 L F
.52588 .34457 m .52596 .34466 L .52638 .3434 L F
.52637 .34404 m .52636 .34402 L .52607 .34481 L F
.52604 .34476 m .52636 .34401 L .52627 .34385 L F
.52627 .34385 m .52704 .34218 L .52638 .3434 L F
.52678 .34138 m .52635 .34466 L .52598 .34441 L F
.52632 .34449 m .52628 .3445 L .52627 .34454 L F
.52628 .34456 m .52627 .34454 L .52593 .34518 L F
.52632 .34449 m .52627 .34454 L .52628 .34456 L F
.52574 .34484 m .52547 .3448 L .52584 .3448 L F
.52601 .34492 m .52601 .34495 L .52623 .34432 L F
.52601 .34473 m .52614 .34489 L .52629 .34466 L F
.52617 .34493 m .52619 .34493 L .52615 .3449 L F
.52639 .34447 m .52629 .34465 L .5265 .34406 L F
.52634 .34463 m .52631 .34464 L .52639 .34447 L F
.52631 .34464 m .52629 .34465 L .52639 .34447 L F
.52639 .34487 m .52632 .34489 L .52636 .34453 L F
.52641 .3441 m .52704 .34218 L .52637 .34404 L F
.52644 .34435 m .52636 .34453 L .52658 .34292 L F
.52639 .34487 m .52636 .34453 L .52644 .34435 L F
.52664 .34308 m .52792 .33243 L p .52648 .34277 L F P
0 g
s
.52792 .33243 m .52667 .34281 L p .52617 .34288 L .672 .728 .891 r
F P
0 g
s
.52704 .34218 m .52912 .33252 L p .52638 .3434 L .672 .728 .891 r
F P
0 g
s
.52661 .34289 m .52658 .34292 L .52678 .34138 L .672 .728 .891 r
F
.52636 .34401 m .52704 .34218 L .52627 .34385 L F
.52639 .34487 m .52658 .34292 L .52661 .34289 L F
.52155 .34362 m .5234 .34425 L .52373 .34422 L F
.52287 .34428 m .52041 .34364 L p .52497 .3447 L F P
0 g
s
.52155 .34362 m .52287 .34428 L .5234 .34425 L .672 .728 .891 r
F
.52619 .34493 m .52666 .34478 L .52621 .34489 L F
.52615 .3449 m .52666 .34478 L .52648 .34457 L F
.52635 .34492 m .52635 .34492 L .52663 .34497 L F
.52671 .34483 m .52626 .3449 L .52643 .34479 L F
.52733 .34488 m .5272 .34504 L .52741 .345 L F
.53101 .34545 m .52695 .34498 L .52671 .34483 L F
.52695 .34498 m .52626 .3449 L .52671 .34483 L F
.52631 .34463 m .52648 .34457 L .52641 .34448 L F
.52622 .34499 m .52664 .3444 L .52657 .34415 L F
.52645 .34468 m .52651 .34429 L .52654 .34431 L F
.52621 .34493 m .52622 .34492 L .52681 .34496 L F
.52681 .34496 m .52622 .34492 L .52626 .3449 L F
.52639 .3452 m .52654 .34473 L p .52622 .34499 L F P
0 g
s
.52654 .34473 m .52664 .3444 L p .5263 .34487 L .672 .728 .891 r
F P
0 g
s
.52622 .34499 m .52654 .34473 L .5263 .34487 L .672 .728 .891 r
F
.52619 .34493 m .52621 .34489 L .52615 .3449 L F
.52617 .34493 m .52616 .34492 L .52622 .34492 L F
.52621 .34493 m .5263 .34469 L .52619 .34494 L F
.5263 .34469 m .52647 .34422 L .52622 .34486 L F
.5263 .34469 m .52622 .34486 L .52619 .34494 L F
.52563 .34477 m .52563 .34477 L .52635 .34492 L F
.52558 .34476 m .52562 .34475 L .52663 .34497 L F
.52574 .34484 m .52584 .3448 L .52606 .3448 L F
.52616 .34492 m .52631 .34459 L .52615 .3449 L F
.52608 .34481 m .52606 .3448 L .52643 .34479 L F
.52562 .34475 m .5261 .34484 L .52611 .34486 L F
.52574 .34484 m .52606 .3448 L .52608 .34481 L F
.52614 .34489 m .52625 .3448 L .52631 .34463 L F
.52567 .34481 m .52617 .34492 L .52574 .34488 L F
.52617 .34493 m .526 .34491 L .52616 .34492 L F
.52608 .34496 m .52615 .3449 L .52614 .34489 L F
.52615 .3449 m .52625 .3448 L .52614 .34489 L F
.52625 .3448 m .52648 .34457 L .52632 .34462 L F
.52625 .3448 m .52632 .34462 L .52631 .34463 L F
.52617 .34493 m .52622 .34492 L .52621 .34493 L F
.5264 .3449 m .52643 .34466 L .52645 .34468 L F
.52634 .34515 m .52638 .3449 L .5264 .3449 L F
.52622 .34494 m .52649 .34488 L .52648 .34487 L F
.52643 .34479 m .52601 .34473 L .52648 .34487 L F
.52606 .3448 m .52538 .34463 L .52602 .34474 L F
.52567 .34467 m .52572 .3447 L .52573 .34469 L F
.52643 .34479 m .52547 .3448 L .52535 .34464 L F
.52601 .34473 m .52535 .34464 L .52605 .34478 L F
.52601 .34473 m .52605 .34478 L .52648 .34487 L F
.52628 .34473 m .52612 .34487 L .52608 .3447 L F
.52613 .34488 m .52574 .34484 L .52608 .34481 L F
.52583 .34539 m .52623 .34432 L .52622 .34432 L F
.52601 .34473 m .52594 .34497 L .52614 .34489 L F
.52616 .34492 m .526 .34491 L .52615 .3449 L F
.52585 .345 m .52608 .34496 L .52614 .34489 L F
.52626 .3449 m .526 .34491 L .52547 .3448 L F
.52612 .34487 m .52591 .34506 L .52605 .34478 L F
.52612 .34487 m .52605 .34478 L .52608 .3447 L F
.52638 .3449 m .52643 .34466 L .5264 .3449 L F
.5261 .34531 m .52647 .34422 L .52607 .34529 L F
.52622 .34492 m .52616 .34492 L .52626 .3449 L F
.52616 .34492 m .52615 .3449 L .52626 .3449 L F
.52626 .3449 m .52613 .34488 L .52643 .34479 L F
.52613 .34488 m .52608 .34481 L .52643 .34479 L F
.52585 .345 m .52575 .34518 L .52608 .34496 L F
.52533 .34687 m .52619 .34495 L .52618 .34495 L F
.52555 .34491 m .52551 .34486 L .52565 .34487 L F
.52587 .34514 m .52618 .34494 L .52618 .34495 L F
.52481 .34487 m .52407 .34483 L .52513 .34474 L F
.5203 .34419 m .52529 .345 L .52562 .34489 L F
.52442 .34502 m .52454 .34497 L .52598 .34507 L F
.5206 .3445 m .52571 .34512 L p .5203 .34419 L F P
0 g
s
.5203 .34419 m .52571 .34512 L .52577 .3451 L .672 .728 .891 r
F
.52564 .34505 m .52098 .34473 L .52559 .34501 L F
.52571 .34512 m .50781 .34296 L p .52551 .34486 L F P
0 g
s
.52607 .34529 m .52621 .34493 L .52619 .34494 L .672 .728 .891 r
F
.52639 .3452 m .52526 .34491 L p .52624 .34501 L F P
0 g
s
.52526 .34491 m .52287 .34428 L p .52501 .34475 L .672 .728 .891 r
F P
0 g
s
.52526 .34491 m .52501 .34475 L .52624 .34501 L .672 .728 .891 r
F
.52486 .34865 m .52458 .34971 L .52506 .34829 L F
.52369 .35039 m .52432 .34919 L p .52389 .3492 L F P
0 g
s
.52522 .34732 m .52251 .35757 L .52251 .35755 L .672 .728 .891 r
F
.52458 .34971 m .52435 .35057 L .52466 .34967 L F
.52251 .35757 m .52478 .35034 L p .52435 .35057 L F P
0 g
s
.52585 .34692 m .52253 .3575 L p .52496 .34774 L .672 .728 .891 r
F P
0 g
s
.52253 .3575 m .52256 .35735 L .52496 .34774 L .672 .728 .891 r
F
.52537 .3468 m .52496 .34774 L .5252 .34676 L F
.52585 .34692 m .52496 .34774 L .52537 .3468 L F
.52615 .34565 m .52432 .34919 L p .52593 .34552 L F P
0 g
s
.52614 .346 m .52633 .34513 L .52634 .34515 L .672 .728 .891 r
F
.52615 .34565 m .52605 .34559 L .5261 .34553 L F
.52605 .34559 m .52575 .3454 L .5261 .34553 L F
.52615 .34565 m .52591 .34506 L .52619 .34535 L F
.52614 .346 m .52608 .346 L .52635 .34491 L F
.52637 .3449 m .52635 .34491 L .52651 .34429 L F
.52614 .346 m .52635 .34491 L .52637 .3449 L F
.5261 .34499 m .52591 .34506 L .52612 .34487 L F
.52593 .34508 m .52639 .3452 L p .52607 .34501 L F P
0 g
s
.52606 .34522 m .5261 .34499 L .52618 .34495 L .672 .728 .891 r
F
.52608 .34496 m .52617 .34493 L .52615 .3449 L F
.5261 .34499 m .52612 .34487 L .52618 .34495 L F
.52607 .34501 m .52639 .3452 L .52618 .34495 L F
.52618 .34495 m .52628 .34521 L .52606 .34522 L F
.5261 .34531 m .5261 .34532 L .52647 .34422 L F
.52605 .34478 m .52622 .34494 L .52648 .34487 L F
.5262 .3449 m .52647 .34422 L .52642 .34424 L F
.52619 .34494 m .52622 .34486 L .5262 .3449 L F
.52622 .34486 m .52647 .34422 L .5262 .3449 L F
.52629 .34457 m .52631 .34459 L .52642 .34424 L F
.52632 .34449 m .52642 .34424 L .52628 .3445 L F
.52636 .34412 m .52629 .34466 L .52635 .34456 L F
.5267 .34377 m .52669 .34379 L p .52668 .3438 L F P
0 g
s
.52638 .34418 m .5267 .34377 L .52656 .34366 L .672 .728 .891 r
F
.5267 .34376 m .5267 .34377 L p .5265 .34389 L F P
0 g
s
.52646 .3443 m .52645 .34426 L .52648 .34425 L .672 .728 .891 r
F
.52654 .34424 m .52645 .34426 L .5265 .34406 L F
.5267 .34377 m .52645 .34433 L .5265 .34389 L F
.5267 .34377 m .52704 .34218 L p .52656 .34366 L F P
0 g
s
.52657 .34346 m .52704 .34218 L .52656 .34345 L .672 .728 .891 r
F
.52637 .34404 m .52704 .34218 L .52636 .34402 L F
.52595 .3442 m .52638 .3434 L .52912 .33252 L F
.5267 .34376 m .5265 .34389 L .52678 .34138 L F
.52642 .34424 m .52647 .34422 L .52711 .34229 L F
.5271 .34223 m .52711 .34229 L .53032 .33267 L F
.52642 .34424 m .52711 .34229 L .5271 .34223 L F
.52726 .34115 m .5267 .34376 L p .52678 .34138 L F P
0 g
s
.52717 .34271 m .53032 .33267 L p .52638 .34451 L .672 .728 .891 r
F P
0 g
s
.52636 .34412 m .52657 .34407 L .52687 .34338 L .672 .728 .891 r
F
.52636 .34412 m .52635 .34456 L .52657 .34407 L F
.52737 .3428 m .52682 .34386 L .5267 .34377 L F
.53379 .33341 m .52682 .34386 L .52737 .3428 L F
.53379 .33341 m .5269 .34393 L .52682 .34386 L F
.52646 .3443 m .52648 .34425 L .52654 .34424 L F
.52687 .34338 m .52635 .34456 L .52812 .34192 L F
.52654 .34431 m .52651 .34429 L .52655 .3441 L F
.52716 .34271 m .52657 .34407 L .52636 .34412 L F
.52662 .34395 m .52655 .3441 L .52683 .34299 L F
.53379 .33341 m .53266 .33311 L p .52716 .34271 L F P
0 g
s
.52716 .34271 m .52636 .34412 L .52757 .34237 L .672 .728 .891 r
F
.52716 .34271 m .52757 .34237 L .53379 .33341 L F
.52601 .34473 m .52585 .345 L .52594 .34497 L F
.52535 .34464 m .52518 .34474 L .52592 .34489 L F
.52567 .34477 m .52607 .34501 L .52568 .34476 L F
.52607 .34501 m .52639 .3452 L .52607 .34501 L F
.52591 .34506 m .52589 .34504 L .52601 .34473 L F
.52607 .34501 m .52607 .34501 L .52568 .34476 L F
.52575 .34518 m .52575 .3454 L .52566 .34535 L F
.52601 .34473 m .52586 .34512 L .52575 .34518 L F
.52586 .34512 m .52575 .3454 L .52575 .34518 L F
.52593 .34508 m .52591 .34506 L .5261 .34499 L F
.52567 .34477 m .52593 .34508 L .52607 .34501 L F
.52535 .34464 m .52575 .34482 L .52593 .34476 L F
.52565 .34475 m .52567 .34477 L .52567 .34477 L F
.52567 .34477 m .52593 .34508 L .52567 .34477 L F
.52593 .34476 m .52613 .34488 L .52605 .34478 L F
.52616 .34453 m .52599 .3446 L .52598 .34441 L F
.52593 .34463 m .52605 .34478 L .52621 .34432 L F
.52608 .3447 m .52605 .34478 L .52601 .34473 L F
.52605 .34478 m .52591 .34506 L .52601 .34473 L F
.52536 .34467 m .52568 .34472 L .52565 .34473 L F
.52443 .34448 m .52568 .34472 L .52536 .34467 L F
.52443 .34448 m .52571 .34471 L .52568 .34472 L F
.52443 .34448 m .52455 .34443 L .52571 .34471 L F
.52466 .34436 m .52418 .34435 L .52613 .34489 L F
.52575 .34482 m .52592 .34489 L .52593 .34476 L F
.52588 .34489 m .52607 .34501 L .52618 .34495 L F
.52592 .34489 m .52609 .34497 L .52605 .34492 L F
.52592 .34489 m .52605 .34492 L .52593 .34476 L F
.52609 .34497 m .52616 .34495 L .52593 .34476 L F
.52616 .34495 m .52613 .34488 L .52593 .34476 L F
.5263 .3451 m .52628 .34521 L .52618 .34495 L F
.52618 .34495 m .52619 .34494 L .52621 .34493 L F
.52618 .34495 m .52619 .34494 L .52618 .34495 L F
.52618 .34495 m .52618 .34494 L .52619 .34494 L F
.52618 .34495 m .52613 .34488 L .52616 .34495 L F
.52588 .34489 m .52618 .34495 L .52615 .34491 L F
.52592 .34489 m .52605 .34498 L .52609 .34497 L F
.52606 .3448 m .52618 .34495 L .52591 .34501 L F
.52613 .34488 m .52622 .34494 L .52605 .34478 L F
.52618 .34495 m .52612 .34487 L .52628 .34473 L F
.52628 .34473 m .52608 .3447 L .52629 .34462 L F
.52638 .3445 m .52618 .34495 L .52623 .34456 L F
.52655 .3441 m .52635 .34491 L .52618 .34495 L F
.52635 .34491 m .5263 .3451 L .52618 .34495 L F
.52618 .34495 m .52626 .34496 L .52622 .34494 L F
.52618 .34495 m .52622 .34494 L .52613 .34488 L F
.52618 .34495 m .52639 .3452 L .52626 .34496 L F
.52624 .34501 m .52622 .345 L .52703 .34518 L F
.52608 .34496 m .52666 .34506 L .52671 .34511 L F
.52664 .34438 m .52664 .3444 L p .52654 .34431 L F P
0 g
s
.52675 .34499 m .52617 .34493 L .52681 .34496 L .672 .728 .891 r
F
.52664 .3444 m .52614 .346 L p .52651 .34445 L F P
0 g
s
.52664 .3444 m .52651 .34445 L .52654 .34431 L .672 .728 .891 r
F
.52591 .34506 m .52575 .3454 L .52589 .34504 L F
.52591 .34501 m .52606 .34522 L .52576 .34523 L F
.52583 .34502 m .52591 .34501 L .52576 .34523 L F
.52627 .34543 m .52615 .34565 L .52619 .34535 L F
.52432 .34919 m .52639 .3452 L p .52607 .3452 L F P
0 g
s
.52619 .34535 m .52606 .34522 L .52618 .34495 L .672 .728 .891 r
F
.52607 .3452 m .52639 .3452 L .52608 .34519 L F
.52468 .34751 m .52459 .34792 L .52607 .3452 L F
.52606 .34522 m .52593 .34508 L .5261 .34499 L F
.52618 .34495 m .52606 .34522 L .52591 .34501 L F
.52567 .34484 m .52572 .34503 L .52574 .34486 L F
.52592 .34489 m .52566 .34491 L .52639 .3452 L F
.52486 .34495 m .52599 .34514 L p .52566 .34491 L F P
0 g
s
.52591 .34508 m .52593 .34508 L p .52585 .34498 L .672 .728 .891 r
F P
0 g
s
.52574 .34486 m .52591 .34508 L .52585 .34498 L .672 .728 .891 r
F
.52572 .34503 m .52591 .34508 L p .52574 .34486 L F P
0 g
s
.52599 .34514 m .52639 .3452 L p .52566 .34491 L .672 .728 .891 r
F P
0 g
s
.52609 .34497 m .52627 .34505 L .52616 .34495 L .672 .728 .891 r
F
.52627 .34505 m .52626 .34496 L .52618 .34495 L F
.52622 .34494 m .52626 .34496 L .52649 .34488 L F
.52618 .34495 m .52626 .34496 L .52624 .34492 L F
.52619 .34535 m .52618 .34495 L .52625 .34491 L F
.52605 .34498 m .52639 .3452 L .52609 .34497 L F
.52627 .34505 m .52618 .34495 L .52616 .34495 L F
.52639 .3452 m .52599 .34514 L p .5262 .34497 L F P
0 g
s
.52599 .34513 m .526 .34513 L .52618 .34494 L .672 .728 .891 r
F
.526 .34513 m .52618 .34495 L .52618 .34494 L F
.52588 .34489 m .52588 .34489 L .52604 .3449 L F
.52588 .34489 m .52604 .3449 L .52615 .34491 L F
.52568 .34476 m .52588 .34489 L .52615 .34491 L F
.52596 .34467 m .52591 .34501 L .52583 .34502 L F
.52593 .34463 m .52538 .34463 L .52563 .34454 L F
.52602 .34474 m .52538 .34463 L .52593 .34463 L F
.52596 .34467 m .52466 .34436 L .52613 .34489 L F
.526 .34472 m .52591 .34501 L .52596 .34467 L F
.52568 .34476 m .52615 .34491 L .52613 .34489 L F
.526 .34472 m .52606 .3448 L .52591 .34501 L F
.52596 .34467 m .52576 .34523 L .5261 .34484 L F
.52605 .34478 m .52622 .34432 L .52621 .34432 L F
.52605 .34478 m .52622 .34432 L .52605 .34478 L F
.52615 .34455 m .52642 .34424 L .52623 .34432 L F
.52628 .3445 m .52642 .34424 L .52615 .34455 L F
.52636 .34412 m .52601 .34473 L .52629 .34466 L F
.52629 .34462 m .52608 .3447 L .52636 .34412 L F
.52636 .34412 m .52608 .3447 L .52601 .34473 L F
.52623 .34432 m .52642 .34424 L .53032 .33267 L F
.52622 .34432 m .52623 .34432 L .52661 .34322 L F
.52621 .34432 m .52622 .34432 L .52661 .34322 L F
.52635 .34369 m .52655 .3441 L .52606 .3448 L F
.5263 .34322 m .52598 .34441 L .52661 .34322 L F
.52645 .34331 m .52648 .34354 L .52635 .34369 L F
.52648 .34354 m .52655 .3441 L .52635 .34369 L F
.52659 .3441 m .52717 .34271 L .52662 .34395 L F
.52659 .3441 m .52662 .34395 L .52638 .34451 L F
.52622 .34499 m .52659 .3441 L .52638 .34451 L F
.52654 .34431 m .52655 .3441 L .52662 .34395 L F
.52664 .3444 m .52717 .34271 L p .52657 .34415 L F P
0 g
s
.52717 .34271 m .52673 .34412 L p .52698 .34287 L .672 .728 .891 r
F P
0 g
s
.52718 .34269 m .52703 .34396 L .52657 .34407 L .672 .728 .891 r
F
.52757 .34237 m .52812 .34192 L .53379 .33341 L F
.52687 .34338 m .52812 .34192 L .52757 .34237 L F
.52641 .34448 m .52882 .34133 L .52812 .34192 L F
.53266 .33311 m .5273 .34344 L p .52718 .34269 L F P
0 g
s
.5273 .34344 m .52703 .34396 L p .52718 .34269 L .672 .728 .891 r
F P
0 g
s
.52623 .34456 m .52618 .34495 L .52606 .3448 L .672 .728 .891 r
F
.52596 .34467 m .52613 .34489 L .52624 .34492 L F
.52625 .34491 m .52618 .34495 L .52628 .34473 L F
.52596 .34467 m .52624 .34492 L .52633 .34487 L F
.52611 .34486 m .52607 .34481 L .52649 .34484 L F
.52643 .34479 m .52648 .34487 L .52726 .34503 L F
.52677 .34486 m .52647 .34479 L .5266 .34501 L F
.52647 .34479 m .52596 .34467 L .52633 .34487 L F
.52633 .34513 m .52643 .34466 L .52634 .34515 L F
.52626 .34496 m .52658 .34503 L .52649 .34488 L F
.52647 .34479 m .52633 .34487 L .5266 .34501 L F
.52626 .34496 m .5263 .34503 L .5263 .34497 L F
.5263 .34503 m .52639 .3452 L .5263 .34497 L F
.5263 .34497 m .52639 .3452 L .52658 .34503 L F
.52627 .34505 m .52673 .34526 L .52626 .34496 L F
.52633 .34487 m .52624 .34492 L .5266 .34501 L F
.52624 .34492 m .52626 .34496 L .5266 .34501 L F
.52627 .34505 m .52639 .3452 L .52662 .34521 L F
.52628 .34533 m .52619 .34535 L .52633 .34435 L F
.52628 .34533 m .52633 .34435 L .52634 .34439 L F
.52627 .34543 m .52628 .34533 L .52628 .34533 L F
.52628 .34533 m .52633 .34435 L .52628 .34533 L F
.52666 .34506 m .52699 .34511 L .52671 .34511 L F
.52671 .34511 m .52699 .34511 L .52703 .34518 L F
.52807 .34539 m .52826 .34552 L .52941 .3459 L F
.52923 .34571 m .52941 .3459 L .54344 .35053 L F
.52776 .34526 m .52774 .34522 L .52904 .34552 L F
.52904 .34552 m .52639 .3452 L p .52886 .34533 L F P
0 g
s
.52826 .34552 m .52828 .34553 L .54344 .35053 L .672 .728 .891 r
F
.54344 .35053 m .54392 .34978 L p .52904 .34552 L F P
0 g
s
.52904 .34552 m .52923 .34571 L .54344 .35053 L .672 .728 .891 r
F
.52699 .34511 m .5278 .34564 L .52936 .34589 L F
.52713 .34534 m .52715 .34536 L .5278 .34564 L F
.53078 .34635 m .52716 .3454 L p .53155 .34624 L F P
0 g
s
.52716 .3454 m .52703 .34518 L .53155 .34624 L .672 .728 .891 r
F
.5278 .34564 m .54344 .35053 L p .52936 .34589 L F P
0 g
s
.54389 .34977 m .52904 .34552 L .54392 .34978 L .672 .728 .891 r
F
.54392 .34978 m .53078 .34635 L p .53155 .34624 L F P
0 g
s
.52639 .3452 m .54381 .34975 L p .52682 .34507 L .672 .728 .891 r
F P
0 g
s
.52648 .34487 m .52658 .34503 L .53252 .34622 L .672 .728 .891 r
F
.5266 .34501 m .52658 .34503 L .52682 .34507 L F
.52658 .34503 m .52639 .3452 L .52682 .34507 L F
.5266 .34501 m .54381 .34975 L .54377 .34974 L F
.53248 .34621 m .53252 .34622 L p .52658 .34503 L F P
0 g
s
.53159 .34583 m .52904 .34552 L p .53101 .34545 L .672 .728 .891 r
F P
0 g
s
.52904 .34552 m .52886 .34533 L .53101 .34545 L .672 .728 .891 r
F
.52648 .34487 m .53252 .34622 L .53344 .34631 L F
.52871 .34518 m .52675 .34499 L .52681 .34496 L F
.52873 .3452 m .52675 .34499 L .52871 .34518 L F
.5272 .3449 m .52726 .34503 L .535 .34663 L F
.52755 .34505 m .52732 .34502 L .54371 .34972 L F
.54368 .34971 m .54371 .34972 L .54392 .34978 L F
.52755 .34505 m .54371 .34972 L .54368 .34971 L F
.5272 .3449 m .52643 .34479 L .52726 .34503 L F
.52755 .34505 m .52677 .34486 L .52732 .34502 L F
.54392 .34978 m .54433 .34902 L p .53247 .34621 L F P
0 g
s
.53247 .34621 m .52755 .34505 L .54368 .34971 L .672 .728 .891 r
F
.53247 .34621 m .54368 .34971 L .54392 .34978 L F
.52703 .34518 m .52699 .34511 L .53155 .34624 L F
.53155 .34624 m .52697 .3451 L .52904 .34552 L F
.52677 .34486 m .5266 .34501 L .54392 .34978 L F
.52673 .34526 m .53248 .34621 L p .52658 .34503 L F P
0 g
s
.52626 .34496 m .52673 .34526 L .52658 .34503 L .672 .728 .891 r
F
.53247 .34621 m .52683 .34508 L .52677 .34486 L F
.52639 .3452 m .52673 .34526 L p .52662 .34521 L F P
0 g
s
.52639 .3452 m .53074 .34567 L .53108 .34578 L .672 .728 .891 r
F
.53248 .34621 m .52639 .3452 L p .53108 .34578 L F P
0 g
s
.53437 .34666 m .52685 .34513 L .52683 .34508 L .672 .728 .891 r
F
.53437 .34666 m .52683 .34508 L .53247 .34621 L F
.52639 .3452 m .52655 .34502 L .52656 .34502 L F
.52868 .34545 m .52656 .34502 L .53074 .34567 L F
.52639 .3452 m .52656 .34502 L .52868 .34545 L F
.53101 .34545 m .52873 .3452 L .52871 .34518 L F
.54483 .34743 m .54483 .34743 L .54492 .34744 L F
.53121 .34547 m .53217 .34576 L .54492 .34744 L F
.53438 .34581 m .539 .34617 L p .53443 .34581 L F P
0 g
s
.53859 .34546 m .52845 .3449 L .539 .34617 L .672 .728 .891 r
F
.53651 .34598 m .53324 .34573 L p .53647 .34578 L F P
0 g
s
.53232 .34544 m .53214 .34545 L .539 .34617 L .672 .728 .891 r
F
.53324 .34573 m .53314 .34556 L .53647 .34578 L F
.53012 .34516 m .53121 .34547 L .54492 .34744 L F
.54492 .34744 m .53159 .34583 L p .53101 .34545 L F P
0 g
s
.53101 .34545 m .5272 .3449 L .535 .34663 L .672 .728 .891 r
F
.53108 .34578 m .53074 .34567 L .53272 .34598 L F
.53019 .3455 m .52684 .34507 L .52694 .34488 L F
.53272 .34598 m .53074 .34567 L .53019 .3455 L F
.53074 .34567 m .52684 .34507 L .53019 .3455 L F
.53252 .34622 m .535 .34663 L p .53344 .34631 L F P
0 g
s
.52637 .34518 m .52629 .34508 L .52631 .34488 L .672 .728 .891 r
F
.52679 .34443 m .52652 .34494 L p .52688 .34399 L F P
0 g
s
.52626 .34496 m .52658 .34503 L .5266 .34501 L .672 .728 .891 r
F
.52652 .34494 m .52627 .34543 L p .5265 .34488 L F P
0 g
s
.52652 .34494 m .5265 .34488 L .52688 .34399 L .672 .728 .891 r
F
.5265 .34488 m .52637 .34518 L .52631 .34488 L F
.52613 .34489 m .52615 .34491 L .52624 .34492 L F
.52652 .34494 m .52589 .34489 L .52649 .34486 L F
.52647 .34479 m .52631 .34488 L .52634 .34439 L F
.5265 .34488 m .52631 .34488 L .52647 .34479 L F
.52611 .34486 m .52649 .34484 L .52649 .34486 L F
.52643 .34466 m .52651 .34429 L .52645 .34468 L F
.52673 .34412 m .52664 .34438 L p .5266 .34408 L F P
0 g
s
.52664 .34438 m .52654 .34431 L .5266 .34408 L .672 .728 .891 r
F
.52688 .34399 m .5265 .34488 L .52636 .34412 L F
.52703 .34396 m .52679 .34443 L p .52688 .34399 L F P
0 g
s
.52652 .34494 m .52679 .34443 L p .52621 .34495 L .672 .728 .891 r
F P
0 g
s
.52673 .34412 m .5266 .34408 L .52723 .34145 L .672 .728 .891 r
F
.52673 .34412 m .52723 .34145 L .52727 .34141 L F
.52679 .34443 m .53266 .33311 L p .52642 .34455 L F P
0 g
s
.52621 .34495 m .52679 .34443 L .52642 .34455 L .672 .728 .891 r
F
.52589 .34489 m .52572 .34485 L .52649 .34486 L F
.52296 .3443 m .52497 .3447 L .52297 .3443 L F
.52287 .34428 m .52296 .3443 L .52297 .3443 L F
.52041 .34364 m .5247 .34454 L .52479 .3446 L F
.52287 .34428 m .52572 .34503 L p .5234 .34425 L F P
0 g
s
.52518 .34474 m .52284 .34428 L .52486 .34495 L .672 .728 .891 r
F
.52486 .34468 m .52572 .34503 L .52567 .34484 L F
.5262 .34497 m .52311 .34433 L .52618 .34495 L F
.52596 .34495 m .52589 .34489 L .52618 .34495 L F
.52599 .34514 m .52617 .34496 L .5262 .34497 L F
.52609 .34497 m .52639 .3452 L .52627 .34505 L F
.52608 .34519 m .52639 .3452 L .5262 .34497 L F
.52618 .34495 m .52607 .3452 L .5262 .34497 L F
.526 .34513 m .52632 .34512 L .52618 .34495 L F
.52518 .34474 m .52486 .34495 L .52592 .34489 L F
.5262 .34497 m .52557 .34487 L .52562 .34485 L F
.52565 .34475 m .52567 .34484 L .52574 .34486 L F
.52549 .34485 m .52568 .34478 L .52607 .34481 L F
.52549 .34485 m .52607 .34481 L .52611 .34486 L F
.52565 .34475 m .52567 .34477 L .52568 .34476 L F
.50806 .34216 m .50838 .34137 L p .52297 .3443 L F P
0 g
s
.52558 .34476 m .52443 .34448 L .52562 .34475 L .672 .728 .891 r
F
.52443 .34448 m .52565 .34473 L .52562 .34475 L F
.52535 .34464 m .52547 .3448 L .52284 .34428 L F
.52535 .34464 m .52288 .34428 L .52518 .34474 L F
.5234 .34425 m .52572 .34503 L .52373 .34422 L F
.52287 .34428 m .50781 .34296 L .52284 .34428 L F
.52195 .34435 m .5203 .34419 L .52201 .34441 L F
.52168 .34437 m .50781 .34296 L .52287 .34428 L F
.50781 .34296 m .50806 .34216 L p .52284 .34428 L F P
0 g
s
.52284 .34428 m .51886 .34371 L .52357 .34468 L .672 .728 .891 r
F
.52284 .34428 m .52357 .34468 L .52486 .34495 L F
.50806 .34216 m .51957 .34407 L p .51886 .34371 L F P
0 g
s
.51957 .34407 m .52486 .34495 L p .51886 .34371 L .672 .728 .891 r
F P
0 g
s
.52562 .34485 m .50806 .34216 L .52311 .34433 L .672 .728 .891 r
F
.52288 .34428 m .52284 .34428 L .52518 .34474 L F
.52373 .34422 m .52486 .34468 L .52565 .34475 L F
.52041 .34364 m .50877 .3406 L p .52215 .34391 L F P
0 g
s
.50877 .3406 m .52041 .34364 L p .52155 .34362 L .672 .728 .891 r
F P
0 g
s
.52486 .34468 m .50838 .34137 L .52508 .34446 L .672 .728 .891 r
F
.52311 .34433 m .50806 .34216 L .52297 .3443 L F
.52483 .34472 m .50838 .34137 L .52486 .34468 L F
.52596 .34467 m .5255 .34477 L .52508 .34446 L F
.52677 .34486 m .52607 .34481 L .52596 .34467 L F
.52607 .34481 m .5255 .34477 L .52596 .34467 L F
.52576 .34523 m .52584 .34529 L .52614 .3449 L F
.52576 .34523 m .52614 .3449 L .5261 .34484 L F
.52634 .34439 m .52633 .34435 L .52636 .34412 L F
.5265 .34488 m .52634 .34439 L .52636 .34412 L F
.52655 .3441 m .52638 .3445 L .52623 .34456 L F
.52598 .34441 m .52599 .3446 L .52593 .34463 L F
.52598 .34441 m .52593 .34463 L .52621 .34432 L F
.52605 .34443 m .52596 .34467 L .52655 .34431 L F
.52912 .33252 m .52726 .34115 L p .52678 .34138 L F P
0 g
s
.5263 .34322 m .52661 .34322 L .53032 .33267 L .672 .728 .891 r
F
.52742 .34066 m .52683 .34299 L .52645 .34331 L F
.52683 .34299 m .52655 .3441 L .52645 .34331 L F
.52718 .34269 m .52657 .34407 L .52716 .34271 L F
.52686 .34296 m .52683 .34299 L .52742 .34066 L F
.52654 .34431 m .52683 .34299 L .52686 .34296 L F
.52598 .34441 m .52621 .34432 L .52661 .34322 L F
.52645 .34331 m .526 .34472 L .52596 .34467 L F
.52645 .34331 m .52606 .3448 L .526 .34472 L F
.52622 .34395 m .52605 .34443 L .52655 .3441 L F
.52622 .34395 m .52655 .3441 L .52665 .34389 L F
.52797 .34015 m .52717 .34271 L p .52742 .34066 L F P
0 g
s
.52717 .34271 m .52698 .34287 L .52742 .34066 L .672 .728 .891 r
F
.5265 .34422 m .52634 .34458 L .53266 .33311 L F
.52634 .34458 m .52639 .34457 L .53266 .33311 L F
.52615 .34491 m .52618 .34495 L .52623 .34492 L F
.52615 .34491 m .52623 .34492 L .52624 .34492 L F
.52615 .34491 m .52615 .34491 L .52624 .34492 L F
.52618 .34495 m .52589 .34489 L .52652 .34494 L F
.52618 .34495 m .52621 .34495 L .53266 .33311 L F
.53266 .33311 m .5315 .33287 L p .5265 .34422 L F P
0 g
s
.52695 .34385 m .5315 .33287 L p .52622 .34395 L .672 .728 .891 r
F P
0 g
s
.5315 .33287 m .52599 .3447 L .5265 .34422 L .672 .728 .891 r
F
.52639 .3452 m .52652 .34494 L p .5262 .34497 L F P
0 g
s
.52655 .34502 m .5262 .34497 L .52624 .34496 L .672 .728 .891 r
F
.5262 .34497 m .52652 .34494 L .52621 .34495 L F
.52655 .34502 m .52618 .34495 L .52652 .34494 L F
.52656 .34502 m .52655 .34502 L .52655 .34502 L F
.52656 .34507 m .52649 .34486 L .52677 .34486 L F
.52655 .34502 m .52624 .34496 L .5267 .34485 L F
.52655 .34502 m .52624 .34496 L .52655 .34502 L F
.52618 .34495 m .5262 .34497 L .52621 .34495 L F
.5262 .34497 m .52618 .34495 L .52624 .34496 L F
.52623 .345 m .5262 .34497 L .52628 .34498 L F
.52623 .345 m .52628 .34498 L .52655 .34502 L F
.52639 .3452 m .52623 .345 L .52655 .34502 L F
.52656 .34507 m .52596 .34495 L .52618 .34495 L F
.52656 .34507 m .52618 .34495 L .52655 .34502 L F
.52636 .34517 m .52623 .345 L .52656 .34507 L F
.52661 .34521 m .52656 .34507 L .53192 .34616 L F
.52636 .34517 m .52656 .34507 L .52661 .34521 L F
.53146 .34612 m .53192 .34616 L .53437 .34666 L F
.52636 .34517 m .53192 .34616 L .53146 .34612 L F
.52685 .34513 m .52656 .34507 L .5266 .34503 L F
.52683 .34508 m .5266 .34503 L .52677 .34486 L F
.52685 .34513 m .5266 .34503 L .52683 .34508 L F
.52684 .34507 m .52656 .34502 L .52694 .34488 L F
.52656 .34502 m .52655 .34502 L .52694 .34488 L F
.52655 .34502 m .5267 .34485 L .52694 .34488 L F
.53264 .34653 m .52639 .3452 L p .53437 .34666 L F P
0 g
s
.52627 .34543 m .52623 .34538 L .52628 .34533 L .672 .728 .891 r
F
.52637 .34518 m .52627 .34543 L .52629 .34508 L F
.52431 .34921 m .52639 .3452 L .52635 .34515 L F
.52639 .3452 m .52629 .34515 L .52636 .34517 L F
.52639 .3452 m .52636 .34517 L .53437 .34666 L F
.52536 .34769 m .52639 .3452 L p .52431 .34921 L F P
0 g
s
.54433 .34902 m .53264 .34653 L p .53437 .34666 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .54433 .34902 L p .52636 .34481 L .672 .728 .891 r
F P
0 g
s
.5261 .34484 m .52614 .3449 L .52635 .34463 L .672 .728 .891 r
F
.5261 .34484 m .52635 .34463 L .52634 .34455 L F
.52575 .3454 m .52567 .34558 L .52566 .34535 L F
.52576 .34523 m .52579 .34584 L .5252 .34676 L F
.52432 .34919 m .52432 .34919 L .52607 .3452 L F
.52579 .34584 m .52537 .3468 L .5252 .34676 L F
.52564 .34555 m .52431 .34921 L .52604 .3457 L F
.52468 .34751 m .52607 .3452 L .52618 .34495 L F
.52613 .34489 m .52618 .34495 L .5265 .34422 L F
.52599 .34514 m .50806 .34216 L p .52617 .34496 L F P
0 g
s
.52584 .34529 m .52609 .3452 L .52599 .34513 L .672 .728 .891 r
F
.52584 .34529 m .52599 .34538 L .52607 .34521 L F
.52564 .34555 m .52588 .34564 L .52594 .34551 L F
.52564 .34555 m .52614 .34548 L .52584 .34529 L F
.52468 .34751 m .52618 .34495 L .52613 .34489 L F
.52311 .34433 m .52297 .3443 L .52602 .34474 L F
.52634 .34458 m .52618 .34495 L .52639 .34457 L F
.52584 .34529 m .52666 .34443 L .52644 .3445 L F
.52602 .34474 m .52602 .34474 L .52671 .34484 L F
.52517 .34474 m .52486 .34468 L .52508 .34446 L F
.52311 .34433 m .52602 .34474 L .52602 .34474 L F
.52634 .3448 m .52603 .34475 L .52634 .34479 L F
.52596 .34467 m .5261 .34484 L .52636 .34453 L F
.52599 .3447 m .52613 .34489 L .52629 .3446 L F
.52671 .34484 m .52593 .34473 L .52599 .3447 L F
.52599 .3447 m .52601 .34473 L .52636 .34481 L F
.52635 .34515 m .52639 .3452 L .52638 .34508 L F
.52649 .34486 m .52649 .34484 L .52677 .34486 L F
.52624 .34496 m .5262 .34493 L .5267 .34485 L F
.5262 .34493 m .52603 .34475 L .52634 .3448 L F
.5262 .34493 m .52634 .3448 L .5267 .34485 L F
.5267 .34485 m .52634 .3448 L .52671 .34484 L F
.52671 .34484 m .52636 .34477 L .5267 .34487 L F
.52636 .34477 m .52599 .3447 L .52636 .34479 L F
.52634 .3448 m .52634 .34479 L .52671 .34484 L F
.52636 .34477 m .52636 .34479 L .5267 .34487 L F
.52618 .34494 m .52618 .34495 L .52636 .34476 L F
.52636 .34475 m .52636 .34476 L .52666 .34443 L F
.52618 .34494 m .52636 .34476 L .52636 .34475 L F
.52618 .34495 m .52632 .34512 L .52663 .3445 L F
.52618 .34495 m .52663 .3445 L .52666 .34443 L F
.52618 .34495 m .52603 .34475 L .52624 .34496 L F
.52601 .34473 m .52639 .3452 L .52636 .34481 L F
.52618 .34495 m .52564 .34484 L .52603 .34475 L F
.52486 .34468 m .52567 .34484 L .52565 .34475 L F
.5255 .34477 m .52517 .34474 L .52512 .34458 L F
.52564 .34484 m .52311 .34433 L .52591 .34473 L F
.52564 .34484 m .52591 .34473 L .52603 .34475 L F
.52618 .34495 m .5262 .34511 L .52599 .3447 L F
.52599 .3447 m .52587 .34495 L .52613 .34489 L F
.52576 .34523 m .52564 .34555 L .52584 .34529 L F
.52587 .34495 m .52468 .34751 L .5261 .34495 L F
.52587 .34495 m .5261 .34495 L .52613 .34489 L F
.52609 .3452 m .52632 .34512 L .52599 .34513 L F
.52607 .34521 m .52614 .34548 L .52632 .34512 L F
.5262 .34511 m .52624 .34555 L .52587 .34495 L F
.52524 .34496 m .52623 .345 L .52636 .34517 L F
.52523 .34496 m .52525 .34496 L .52524 .34496 L F
.52525 .34496 m .52623 .345 L .52524 .34496 L F
.52595 .34471 m .52639 .3452 L .52601 .34473 L F
.52639 .3452 m .5262 .34511 L .52618 .34495 L F
.52603 .34475 m .52602 .34474 L .52671 .34484 L F
.52599 .3447 m .52636 .34481 L .52636 .34479 L F
.52639 .3452 m .52618 .34495 L .52613 .3444 L F
.52615 .34464 m .52618 .34495 L .52599 .3447 L F
.52599 .3447 m .5262 .34511 L .52587 .34495 L F
.52599 .3447 m .52595 .34471 L .52601 .34473 L F
.52636 .34479 m .52636 .34481 L .54433 .34902 L F
.52637 .34501 m .52671 .34442 L .52663 .3445 L F
.52623 .34538 m .52619 .34535 L .52628 .34533 L F
.52431 .34921 m .52638 .34508 L .52637 .34501 L F
.52638 .34508 m .52671 .34442 L .52637 .34501 L F
.52639 .3452 m .52671 .34442 L p .52638 .34508 L F P
0 g
s
.52671 .34442 m .52695 .34385 L p .52663 .3445 L .672 .728 .891 r
F P
0 g
s
.52603 .34475 m .52311 .34433 L .52602 .34474 L .672 .728 .891 r
F
.52596 .34467 m .52636 .34453 L .52655 .34431 L F
.52599 .3447 m .52629 .3446 L .5265 .34422 L F
.52596 .34495 m .52549 .34485 L .52589 .34489 L F
.52589 .34489 m .52549 .34485 L .52572 .34485 L F
.52523 .34496 m .52549 .34485 L .52596 .34495 L F
.52525 .34496 m .52596 .34495 L .52623 .345 L F
.52523 .34496 m .52596 .34495 L .52525 .34496 L F
.52639 .3452 m .52523 .34496 L p .52629 .34515 L F P
0 g
s
.52524 .34496 m .52639 .3452 L p .52595 .34471 L .672 .728 .891 r
F P
0 g
s
.52634 .34455 m .52635 .34463 L .52695 .34385 L .672 .728 .891 r
F
.52599 .3447 m .52297 .3443 L .50838 .34137 L F
.5255 .34477 m .52512 .34458 L .52508 .34446 L F
.52593 .34473 m .52297 .3443 L .52599 .3447 L F
.52644 .3445 m .52666 .34443 L .52695 .34385 L F
.52671 .34441 m .52671 .34442 L p .52613 .3444 L F P
0 g
s
.52671 .34442 m .52639 .3452 L p .5262 .34462 L .672 .728 .891 r
F P
0 g
s
.52671 .34442 m .5262 .34462 L .52613 .3444 L .672 .728 .891 r
F
.52639 .3452 m .52624 .34555 L p .5262 .34511 L F P
0 g
s
.52517 .34474 m .52483 .34472 L .52486 .34468 L .672 .728 .891 r
F
.52613 .3444 m .52615 .34464 L .52599 .3447 L F
.52557 .34487 m .50806 .34216 L .52562 .34485 L F
.52523 .34496 m .50838 .34137 L p .52549 .34485 L F P
0 g
s
.52523 .34496 m .52524 .34496 L p .52553 .34462 L .672 .728 .891 r
F P
0 g
s
.52553 .34462 m .52524 .34496 L .52595 .34471 L .672 .728 .891 r
F
.52694 .34488 m .5267 .34485 L .52671 .34484 L F
.53431 .34652 m .53248 .34621 L p .53272 .34598 L F P
0 g
s
.53248 .34621 m .53108 .34578 L .53272 .34598 L .672 .728 .891 r
F
.535 .34663 m .54466 .34823 L p .53101 .34545 L F P
0 g
s
.54466 .34823 m .53431 .34652 L p .53272 .34598 L .672 .728 .891 r
F P
0 g
s
.54433 .34902 m .54466 .34823 L p .52671 .34484 L .672 .728 .891 r
F P
0 g
s
.52671 .34484 m .5267 .34487 L .54433 .34902 L .672 .728 .891 r
F
.52599 .3447 m .52553 .34462 L .52595 .34471 L F
.52549 .34485 m .52483 .34472 L .52568 .34478 L F
.50838 .34137 m .52523 .34496 L p .52553 .34462 L F P
0 g
s
.52599 .34538 m .52614 .34548 L .52607 .34521 L .672 .728 .891 r
F
.52587 .34495 m .52624 .34555 L .52569 .34534 L F
.52665 .34389 m .52655 .3441 L .52695 .34385 L F
.52605 .34443 m .52655 .34431 L .52695 .34385 L F
.5315 .33287 m .52671 .34441 L p .52613 .3444 L F P
0 g
s
.52466 .34436 m .52155 .34362 L .52418 .34435 L .672 .728 .891 r
F
.52594 .34551 m .52604 .3457 L .52614 .34548 L F
.52588 .34564 m .52604 .3457 L .52594 .34551 L F
.52459 .34792 m .52432 .34919 L .52607 .3452 L F
.52389 .3492 m .52432 .34919 L .52459 .34792 L F
.52253 .3575 m .52251 .35757 L p .52256 .35735 L F P
0 g
s
.50838 .34137 m .50877 .3406 L p .52508 .34446 L .672 .728 .891 r
F P
0 g
s
.52468 .34751 m .52389 .3492 L .52459 .34792 L .672 .728 .891 r
F
.52019 .35714 m .52369 .35039 L p .52389 .3492 L F P
0 g
s
.52134 .35738 m .52019 .35714 L p .52569 .34534 L .672 .728 .891 r
F P
0 g
s
.52251 .35757 m .52134 .35738 L p .52432 .34919 L .672 .728 .891 r
F P
0 g
s
.52256 .35735 m .52251 .35757 L .52432 .34919 L .672 .728 .891 r
F
.52134 .35738 m .52536 .34769 L p .52431 .34921 L F P
0 g
s
.52624 .34555 m .52134 .35738 L p .52569 .34534 L .672 .728 .891 r
F P
0 g
s
.54381 .34975 m .54392 .34978 L p .54377 .34974 L .672 .728 .891 r
F P
0 g
s
.52727 .34141 m .52723 .34145 L .52742 .34066 L .672 .728 .891 r
F
.5345 .33424 m .53455 .33419 L .53489 .33376 L F
.52882 .34133 m .53379 .33341 L p .52812 .34192 L F P
0 g
s
.54392 .34978 m .54392 .34978 L p .54389 .34977 L .672 .728 .891 r
F P
0 g
s
.52019 .35714 m .51907 .35685 L p .5192 .35663 L .672 .728 .891 r
F P
0 g
s
.52098 .34473 m .52088 .3447 L .5234 .34485 L .672 .728 .891 r
F
.52098 .34473 m .5234 .34485 L .52336 .34486 L F
.52088 .3447 m .52084 .34469 L .52093 .34469 L F
.53032 .33267 m .52797 .34015 L p .52742 .34066 L F P
0 g
s
.5315 .33287 m .53032 .33267 L p .52622 .34395 L .672 .728 .891 r
F P
0 g
s
.52595 .3442 m .52588 .34457 L .52638 .3434 L .672 .728 .891 r
F
.52366 .34499 m .52359 .34491 L .52454 .34497 L F
.52366 .34499 m .52454 .34497 L .52442 .34502 L F
.52614 .346 m .52585 .34692 L p .52608 .346 L F P
0 g
s
.53494 .33377 m .53489 .33376 L p .53472 .33397 L .672 .728 .891 r
F P
0 g
s
.53314 .34556 m .53242 .34551 L .53308 .34545 L .672 .728 .891 r
F
.53242 .34551 m .53152 .34537 L .53308 .34545 L F
.52361 .34498 m .52513 .3451 L .52513 .3451 L F
.52514 .34511 m .52366 .34499 L p .52519 .34508 L F P
0 g
s
.50877 .3406 m .50923 .33984 L p .52563 .34454 L .672 .728 .891 r
F P
0 g
s
.52632 .34553 m .52609 .34658 L p .52623 .34555 L .672 .728 .891 r
F P
0 g
s
.54466 .34823 m .54492 .34744 L p .53101 .34545 L .672 .728 .891 r
F P
0 g
s
.50977 .33911 m .51028 .3393 L p .51035 .33932 L .672 .728 .891 r
F P
0 g
s
.51907 .35685 m .51798 .35651 L p .52513 .34607 L .672 .728 .891 r
F P
0 g
s
.53274 .33853 m .53276 .33853 L .53688 .33469 L .672 .728 .891 r
F
.50923 .33984 m .50977 .33911 L p .52539 .34441 L F P
0 g
s
.53012 .34516 m .52733 .34488 L .53217 .34576 L .672 .728 .891 r
F
.53647 .34578 m .53314 .34556 L .53308 .34545 L F
.539 .34617 m .5451 .34663 L p .53859 .34546 L F P
0 g
s
.5451 .34663 m .53651 .34598 L p .53647 .34578 L .672 .728 .891 r
F P
0 g
s
.54492 .34744 m .5451 .34663 L p .53012 .34516 L .672 .728 .891 r
F P
0 g
s
.52671 .34483 m .52792 .34343 L p .52664 .34467 L .672 .728 .891 r
F P
0 g
s
.5261 .34655 m .52619 .34688 L .52602 .34689 L .672 .728 .891 r
F
.53032 .33267 m .52912 .33252 L p .5263 .34322 L F P
0 g
s
.52436 .34688 m .52458 .34673 L .5246 .34669 L .672 .728 .891 r
F
.52912 .33252 m .52792 .33243 L p .52595 .3442 L F P
0 g
s
.52589 .34372 m .5259 .34447 L .52584 .34443 L .672 .728 .891 r
F
.52583 .34451 m .52451 .34417 L .52482 .34411 L F
.51692 .35612 m .51591 .35569 L p .52534 .34556 L F P
0 g
s
.52538 .3456 m .51692 .35612 L .52534 .34556 L .672 .728 .891 r
F
.52251 .35757 m .52251 .35757 L p .52251 .35755 L F P
0 g
s
.52098 .34473 m .51454 .3443 L .52084 .34469 L .672 .728 .891 r
F
.52433 .34691 m .52441 .34691 L .52436 .34688 L F
.51798 .35651 m .51692 .35612 L p .5249 .34619 L F P
0 g
s
.52792 .33243 m .5267 .33239 L p .52583 .34451 L .672 .728 .891 r
F P
0 g
s
.52511 .34569 m .52429 .34683 L .52411 .34663 L .672 .728 .891 r
F
.50977 .33911 m .51038 .3384 L p .52482 .34411 L F P
0 g
s
.52459 .34522 m .52449 .34515 L .52506 .34513 L .672 .728 .891 r
F
.52366 .34499 m .51454 .3443 L p .52359 .34491 L F P
0 g
s
.52556 .34329 m .52576 .34419 L .52569 .34439 L .672 .728 .891 r
F
.52548 .34268 m .5256 .34327 L .52556 .34329 L F
.52459 .34522 m .52171 .34525 L p .52449 .34515 L F P
0 g
s
.52646 .34562 m .52646 .34562 L .52646 .34562 L .672 .728 .891 r
F
.5256 .34367 m .52568 .34431 L .52578 .34355 L F
.5256 .34367 m .52578 .34355 L .52575 .34353 L F
.52693 .34473 m .52801 .34378 L p .52699 .34456 L F P
0 g
s
.52699 .34456 m .52801 .34378 L .52701 .34452 L .672 .728 .891 r
F
.5271 .3443 m .52801 .34378 L .52815 .34342 L F
.52527 .34548 m .52523 .34557 L .52517 .34556 L F
.5212 .34551 m .52302 .34541 L .52299 .34538 L F
.5265 .34564 m .52645 .34557 L .52646 .34558 L F
.52907 .34459 m .52756 .34478 L .52784 .34468 L F
.52801 .34378 m .53512 .33756 L p .52815 .34342 L F P
0 g
s
.52888 .3446 m .52754 .3447 L .52959 .34478 L .672 .728 .891 r
F
.5267 .33239 m .52548 .3324 L p .5257 .34171 L F P
0 g
s
.52682 .34547 m .52687 .34551 L p .52682 .34545 L .672 .728 .891 r
F P
0 g
s
.52556 .34452 m .52552 .34389 L .52548 .3439 L .672 .728 .891 r
F
.52538 .34394 m .52548 .3439 L .52541 .34338 L F
.52467 .34537 m .5258 .34526 L p .52464 .34533 L F P
0 g
s
.52656 .34567 m .52652 .34557 L p .52646 .34562 L .672 .728 .891 r
F P
0 g
s
.52649 .34559 m .5265 .34564 L p .52646 .34558 L .672 .728 .891 r
F P
0 g
s
.52557 .34528 m .52301 .34553 L p .52529 .34523 L .672 .728 .891 r
F P
0 g
s
.52453 .34547 m .52465 .34543 L .52465 .34544 L .672 .728 .891 r
F
.5252 .34539 m .5244 .3459 L .52516 .34547 L F
.5256 .34531 m .52453 .34547 L p .52535 .34527 L F P
0 g
s
.5276 .3478 m .52783 .34829 L p .52753 .34778 L .672 .728 .891 r
F P
0 g
s
.52783 .34829 m .53199 .35727 L p .52759 .3483 L .672 .728 .891 r
F P
0 g
s
.52363 .34571 m .5247 .34551 L .5247 .34551 L .672 .728 .891 r
F
.52328 .34578 m .52363 .34571 L .52363 .34571 L F
.52414 .34606 m .52412 .34608 L .52414 .34607 L F
.52387 .34316 m .5225 .34235 L .52397 .34327 L F
.5225 .34235 m .51258 .33645 L .52397 .34327 L F
.51591 .35569 m .51493 .35522 L p .52048 .35003 L F P
0 g
s
.5252 .34249 m .52544 .34364 L .52556 .34194 L .672 .728 .891 r
F
.52515 .34229 m .5252 .34249 L .52551 .34152 L F
.52188 .33276 m .5247 .34054 L p .52436 .34069 L F P
0 g
s
.52526 .34356 m .52539 .34327 L .52307 .33259 L .672 .728 .891 r
F
.52515 .34229 m .52551 .34152 L .52427 .33247 L F
.52548 .3324 m .52427 .33247 L p .5256 .34367 L F P
0 g
s
.52517 .34556 m .52136 .34926 L .52129 .34874 L .672 .728 .891 r
F
.51493 .35522 m .514 .35471 L p .52129 .34874 L F P
0 g
s
.5244 .3459 m .52412 .34608 L .52442 .34591 L .672 .728 .891 r
F
.52771 .34442 m .52786 .34432 L p .52771 .34442 L F P
0 g
s
.52751 .34441 m .5288 .34372 L .5275 .34441 L .672 .728 .891 r
F
.52544 .34364 m .52555 .34416 L .52564 .34374 L F
.52328 .34578 m .52364 .34571 L .52364 .34571 L F
.52364 .34571 m .52583 .34526 L .52364 .34571 L F
.54523 .345 m .54518 .34419 L p .53563 .34449 L F P
0 g
s
.54521 .34582 m .54523 .345 L p .53732 .34491 L .672 .728 .891 r
F P
0 g
s
.5451 .34663 m .54521 .34582 L p .53859 .34546 L .672 .728 .891 r
F P
0 g
s
.52792 .34421 m .52803 .34417 L .5288 .34372 L .672 .728 .891 r
F
.52972 .34454 m .52888 .3446 L .52959 .34478 L F
.52766 .34435 m .52773 .34429 L p .52764 .34435 L F P
0 g
s
.52773 .34429 m .53978 .33616 L p .52777 .34412 L .672 .728 .891 r
F P
0 g
s
.53088 .3427 m .53104 .34266 L .53219 .34207 L .672 .728 .891 r
F
.53183 .34215 m .53219 .34207 L .54138 .3374 L F
.52658 .34573 m .52656 .34577 L .52635 .34522 L F
.52727 .3456 m .52826 .34655 L .52861 .34663 L F
.52125 .34213 m .52044 .34169 L .5216 .34219 L F
.52044 .342 m .52044 .34169 L .52125 .34213 L F
.52044 .342 m .51105 .33772 L .52044 .34169 L F
.52497 .34381 m .52401 .34361 L .52487 .34375 L F
.52821 .34391 m .5288 .34372 L .52879 .34357 L F
.52841 .34392 m .5288 .34372 L .52821 .34391 L F
.52509 .34359 m .525 .34352 L .52501 .34352 L F
.5251 .34359 m .525 .34352 L .52509 .34359 L F
.52658 .34573 m .52704 .34699 L p .52656 .34577 L F P
0 g
s
.52706 .34557 m .52706 .34557 L .52826 .34655 L .672 .728 .891 r
F
.52671 .34542 m .52669 .34545 L .52699 .34577 L F
.52672 .34547 m .52675 .3455 L p .52673 .34545 L F P
0 g
s
.53141 .34441 m .53132 .34442 L .53155 .34445 L .672 .728 .891 r
F
.53132 .34442 m .52972 .34454 L .53155 .34445 L F
.54518 .34419 m .54506 .34337 L p .53141 .34441 L F P
0 g
s
.52526 .34356 m .52527 .3436 L .52539 .34327 L .672 .728 .891 r
F
.52527 .3436 m .52541 .34338 L .52539 .34327 L F
.5229 .34593 m .52395 .34563 L .52395 .34563 L F
.52178 .34625 m .5229 .34593 L .5229 .34593 L F
.51038 .3384 m .51105 .33772 L p .51945 .34155 L F P
0 g
s
.51179 .33707 m .51258 .33645 L p .52487 .34375 L .672 .728 .891 r
F P
0 g
s
.54506 .34337 m .54485 .34257 L p .52881 .3445 L .672 .728 .891 r
F P
0 g
s
.51363 .3476 m .51359 .34761 L .52425 .34555 L .672 .728 .891 r
F
.52425 .34555 m .52425 .34555 L .52573 .34527 L F
.51363 .3476 m .52425 .34555 L .52425 .34555 L F
.52467 .34551 m .52462 .34548 L .524 .34558 L F
.51265 .34779 m .52253 .34588 L .52252 .34589 L F
.52253 .34588 m .52572 .34527 L .52252 .34589 L F
.5239 .34571 m .52178 .34625 L .52395 .34563 L F
.51267 .34778 m .52328 .34578 L .52328 .34578 L F
.52448 .34555 m .52316 .3458 L .52445 .34555 L F
.52328 .34578 m .52413 .3456 L .52411 .34561 L F
.52413 .3456 m .52573 .34527 L .52411 .34561 L F
.52328 .34578 m .52323 .34575 L .52425 .34556 L F
.52413 .3456 m .52425 .34556 L .52573 .34527 L F
.52178 .34625 m .52396 .34561 L .52395 .34563 L F
.52328 .34578 m .52425 .34556 L .52413 .3456 L F
.51312 .35415 m .52018 .34939 L p .51876 .3501 L F P
0 g
s
.51105 .33772 m .51179 .33707 L p .5216 .34219 L .672 .728 .891 r
F P
0 g
s
.54088 .33764 m .53514 .34109 L .54208 .33806 L .672 .728 .891 r
F
.52894 .34387 m .54138 .3374 L p .52807 .34417 L F P
0 g
s
.52879 .34357 m .5288 .34372 L .54061 .33676 L .672 .728 .891 r
F
.52316 .3458 m .52323 .34575 L .52328 .34578 L F
.52427 .33247 m .52307 .33259 L p .52515 .34229 L F P
0 g
s
.52031 .34663 m .51938 .34685 L p .52037 .34661 L .672 .728 .891 r
F P
0 g
s
.52031 .34663 m .52037 .34661 L .52568 .34528 L .672 .728 .891 r
F
.5245 .34556 m .52448 .34555 L .52582 .3453 L F
.52301 .34553 m .50775 .34702 L p .52257 .34539 L F P
0 g
s
.52073 .34822 m .51503 .35183 L .52245 .34746 L .672 .728 .891 r
F
.514 .35471 m .51312 .35415 L p .52525 .34542 L F P
0 g
s
.53512 .33756 m .53797 .33507 L p .53687 .3347 L .672 .728 .891 r
F P
0 g
s
.53688 .33469 m .53699 .33459 L .53694 .33457 L p .672 .728 .891 r
F P
0 g
s
.53694 .33457 m .53596 .33415 L p .53688 .33469 L .672 .728 .891 r
F P
0 g
s
.5245 .34556 m .51267 .34778 L p .52448 .34555 L .672 .728 .891 r
F P
0 g
s
.52044 .34883 m .51273 .35388 L .5205 .3487 L .672 .728 .891 r
F
.52887 .34699 m .52842 .34667 L p .52839 .34648 L F P
0 g
s
.52688 .34607 m .52638 .34519 L .52687 .34607 L .672 .728 .891 r
F
.52652 .34549 m .52676 .34585 L .52648 .34548 L F
.52657 .34551 m .52676 .34585 L p .52654 .34551 L F P
0 g
s
.52179 .34625 m .52183 .34623 L .52565 .34527 L .672 .728 .891 r
F
.52179 .34625 m .52565 .34527 L .52565 .34527 L F
.52316 .3458 m .51363 .3476 L .52301 .34579 L F
.52786 .34432 m .54061 .33676 L p .52789 .34425 L F P
0 g
s
.51503 .35183 m .51676 .35091 L .51611 .3512 L .672 .728 .891 r
F
.52389 .34573 m .52179 .34625 L .52389 .34572 L F
.52179 .34625 m .51938 .34685 L .52183 .34623 L F
.5241 .34598 m .5232 .34629 L .52331 .3462 L F
.52408 .3461 m .52397 .34625 L .52403 .34613 L F
.5252 .34539 m .52397 .34625 L .52408 .3461 L F
.5252 .34539 m .52387 .34646 L .52397 .34625 L F
.52403 .34613 m .5205 .3487 L .52073 .34822 L F
.52387 .34646 m .5205 .3487 L .52403 .34613 L F
.52501 .34352 m .525 .34352 L .52501 .34352 L F
.52307 .33259 m .52188 .33276 L p .52526 .34356 L F P
0 g
s
.52458 .34295 m .52494 .3434 L .52474 .3429 L .672 .728 .891 r
F
.52458 .34295 m .52474 .3429 L .52413 .34141 L F
.52248 .33889 m .52344 .34075 L .52262 .33768 L F
.52344 .34075 m .52413 .34141 L .52262 .33768 L F
.51258 .33645 m .51344 .33587 L p .52335 .34257 L F P
0 g
s
.51344 .33587 m .51435 .33532 L p .52501 .34352 L .672 .728 .891 r
F P
0 g
s
.52826 .34655 m .53164 .34899 L p .52861 .34663 L .672 .728 .891 r
F P
0 g
s
.52178 .34625 m .52033 .34661 L .5217 .34624 L .672 .728 .891 r
F
.51265 .34779 m .51252 .3478 L .52541 .34532 L F
.51265 .34779 m .52541 .34532 L .52542 .34533 L F
.52188 .33276 m .52071 .33298 L p .52506 .3435 L F P
0 g
s
.52033 .34661 m .51938 .34685 L .52021 .34663 L .672 .728 .891 r
F
.52073 .34822 m .51273 .35388 L .51503 .35183 L F
.5205 .3487 m .51273 .35388 L .52073 .34822 L F
.51435 .33532 m .51531 .33482 L p .52458 .34295 L F P
0 g
s
.52461 .34298 m .52328 .34181 L .5245 .34284 L .672 .728 .891 r
F
.53879 .34286 m .54014 .34261 L p .53873 .34287 L F P
0 g
s
.54014 .34261 m .54457 .34177 L p .53999 .34262 L .672 .728 .891 r
F P
0 g
s
.54368 .34194 m .53879 .34286 L p .54395 .34188 L .672 .728 .891 r
F P
0 g
s
.53879 .34286 m .5389 .34283 L .54395 .34188 L .672 .728 .891 r
F
.54395 .34188 m .5389 .34283 L .53976 .34257 L F
.54457 .34177 m .54368 .34194 L p .54395 .34188 L F P
0 g
s
.54485 .34257 m .54457 .34177 L p .53148 .34394 L .672 .728 .891 r
F P
0 g
s
.52303 .3416 m .51531 .33482 L .52309 .34158 L .672 .728 .891 r
F
.51844 .33357 m .52372 .34133 L .52339 .34146 L F
.52071 .33298 m .51956 .33325 L p .52248 .33889 L F P
0 g
s
.52248 .33889 m .52262 .33768 L .52071 .33298 L .672 .728 .891 r
F
.52659 .34542 m .527 .34586 L p .5266 .34541 L F P
0 g
s
.527 .34586 m .53635 .35592 L p .52702 .34584 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .52655 .34544 L p .52652 .34544 L .672 .728 .891 r
F P
0 g
s
.52439 .3427 m .52309 .34158 L .52339 .34146 L .672 .728 .891 r
F
.51844 .33357 m .52374 .34132 L p .52372 .34133 L F P
0 g
s
.5237 .34135 m .52376 .34133 L .51956 .33325 L .672 .728 .891 r
F
.52339 .34146 m .52314 .34125 L .51631 .33436 L F
.52314 .34125 m .51531 .33482 L .51631 .33436 L F
.52309 .34158 m .51531 .33482 L .52339 .34146 L F
.51363 .3476 m .51265 .34779 L .51359 .34761 L F
.51844 .33357 m .51763 .33385 L p .52099 .33848 L F P
0 g
s
.51956 .33325 m .51844 .33357 L p .52339 .34146 L .672 .728 .891 r
F P
0 g
s
.52339 .34146 m .52439 .34271 L .51956 .33325 L .672 .728 .891 r
F
.5171 .33405 m .51736 .33394 L p .51964 .33678 L F P
0 g
s
.52038 .33771 m .52099 .33848 L .51763 .33385 L .672 .728 .891 r
F
.52029 .3376 m .52038 .33771 L .51763 .33385 L F
.51964 .33678 m .52029 .3376 L .51763 .33385 L F
.51631 .33436 m .5171 .33405 L p .52099 .33848 L F P
0 g
s
.51265 .34779 m .50827 .34861 L .51252 .3478 L .672 .728 .891 r
F
.51267 .34778 m .50827 .34861 L p .51265 .34779 L F P
0 g
s
.50827 .34861 m .50811 .34819 L p .51252 .3478 L .672 .728 .891 r
F P
0 g
s
.50811 .34819 m .50797 .34782 L p .51252 .3478 L .672 .728 .891 r
F P
0 g
s
.5177 .34768 m .50908 .35015 L p .51487 .3482 L .672 .728 .891 r
F P
0 g
s
.54422 .34099 m .54379 .34023 L p .53031 .34374 L .672 .728 .891 r
F P
0 g
s
.54457 .34177 m .54422 .34099 L p .53488 .34297 L .672 .728 .891 r
F P
0 g
s
.52672 .34562 m .52704 .34601 L p .52665 .34564 L .672 .728 .891 r
F P
0 g
s
.52704 .34601 m .5274 .34647 L p .52697 .34603 L .672 .728 .891 r
F P
0 g
s
.51229 .35356 m .51571 .35153 L p .51503 .35183 L .672 .728 .891 r
F P
0 g
s
.53531 .35633 m .53504 .35642 L p .53007 .35022 L .672 .728 .891 r
F P
0 g
s
.53504 .35642 m .53424 .35669 L p .53007 .35022 L .672 .728 .891 r
F P
0 g
s
.51152 .35294 m .51081 .35228 L p .52244 .34662 L .672 .728 .891 r
F P
0 g
s
.51229 .35356 m .51152 .35294 L p .519 .34878 L .672 .728 .891 r
F P
0 g
s
.51273 .35388 m .51229 .35356 L p .51503 .35183 L .672 .728 .891 r
F P
0 g
s
.46539 .42267 m .48482 .38353 L .48699 .38526 L p .844 .708 .713 r
F P
0 g
s
.48699 .38526 m .46864 .42521 L .46539 .42267 L p .844 .708 .713 r
F P
0 g
s
.51229 .35356 m .48699 .38526 L .48482 .38353 L p .789 .73 .798 r
F P
0 g
s
.48699 .38526 m .51229 .35356 L .51312 .35415 L p .783 .721 .793 r
F P
0 g
s
.47179 .47414 m .47966 .43202 L .4837 .43396 L p .813 .608 .626 r
F P
0 g
s
.4837 .43396 m .47663 .47656 L .47179 .47414 L p .813 .608 .626 r
F P
0 g
s
.53606 .68615 m .53517 .65696 L .54864 .66245 L p .866 .706 .682 r
F P
0 g
s
.54536 .63142 m .54864 .66245 L .53517 .65696 L p .853 .753 .752 r
F P
0 g
s
.54864 .66245 m .54536 .63142 L .55832 .63402 L p .832 .732 .754 r
F P
0 g
s
.57119 .4326 m .57918 .47406 L .58373 .47202 L p .544 .399 .635 r
F P
0 g
s
.58373 .47202 m .57511 .43073 L .57119 .4326 L p .544 .399 .635 r
F P
0 g
s
.56685 .38447 m .54086 .35327 L .54007 .35387 L p .599 .573 .796 r
F P
0 g
s
.54086 .35327 m .56685 .38447 L .56894 .38273 L p .59 .57 .8 r
F P
0 g
s
.56685 .38447 m .58564 .42428 L .58869 .42187 L p .517 .445 .714 r
F P
0 g
s
.58869 .42187 m .56894 .38273 L .56685 .38447 L p .517 .445 .714 r
F P
0 g
s
.65104 .62091 m .62702 .59207 L .61955 .59596 L p .567 .642 .884 r
F P
0 g
s
.62702 .59207 m .65104 .62091 L .65754 .61489 L p .483 .613 .904 r
F P
0 g
s
.68102 .64821 m .65754 .61489 L .65104 .62091 L p .465 .54 .849 r
F P
0 g
s
.46239 .42002 m .48281 .38171 L .48482 .38353 L p .855 .724 .718 r
F P
0 g
s
.48482 .38353 m .46539 .42267 L .46239 .42002 L p .855 .724 .718 r
F P
0 g
s
.51152 .35294 m .48482 .38353 L .48281 .38171 L p .794 .74 .802 r
F P
0 g
s
.48482 .38353 m .51152 .35294 L .51229 .35356 L p .789 .73 .798 r
F P
0 g
s
.46712 .47152 m .47579 .4299 L .47966 .43202 L p .825 .622 .628 r
F P
0 g
s
.47966 .43202 m .47179 .47414 L .46712 .47152 L p .825 .622 .628 r
F P
0 g
s
.55243 .60596 m .55832 .63402 L .54536 .63142 L p .832 .774 .797 r
F P
0 g
s
.55832 .63402 m .55243 .60596 L .56383 .60613 L p .808 .754 .803 r
F P
0 g
s
.65754 .61489 m .68102 .64821 L .68529 .63943 L p .346 .491 .862 r
F P
0 g
s
.68102 .64821 m .69722 .68372 L .70194 .67274 L p .255 .338 .757 r
F P
0 g
s
.70194 .67274 m .68529 .63943 L .68102 .64821 L p .255 .338 .757 r
F P
0 g
s
.57511 .43073 m .58373 .47202 L .58802 .46987 L p .521 .383 .634 r
F P
0 g
s
.58802 .46987 m .57884 .42872 L .57511 .43073 L p .521 .383 .634 r
F P
0 g
s
.56894 .38273 m .54161 .35263 L .54086 .35327 L p .59 .57 .8 r
F P
0 g
s
.54161 .35263 m .56894 .38273 L .57086 .38089 L p .581 .568 .804 r
F P
0 g
s
.56894 .38273 m .58869 .42187 L .59149 .41932 L p .497 .435 .717 r
F P
0 g
s
.59149 .41932 m .57086 .38089 L .56894 .38273 L p .497 .435 .717 r
F P
0 g
s
.45965 .41727 m .48097 .37982 L .48281 .38171 L p .867 .742 .722 r
F P
0 g
s
.48281 .38171 m .46239 .42002 L .45965 .41727 L p .867 .742 .722 r
F P
0 g
s
.51081 .35228 m .48281 .38171 L .48097 .37982 L p .8 .75 .807 r
F P
0 g
s
.48281 .38171 m .51081 .35228 L .51152 .35294 L p .794 .74 .802 r
F P
0 g
s
.46266 .46871 m .47211 .42763 L .47579 .4299 L p .839 .637 .63 r
F P
0 g
s
.47579 .4299 m .46712 .47152 L .46266 .46871 L p .839 .637 .63 r
F P
0 g
s
.69722 .68372 m .702 .71521 L .70681 .70261 L p 0 0 .501 r
F P
0 g
s
.70681 .70261 m .70194 .67274 L .69722 .68372 L p 0 0 .501 r
F P
0 g
s
.57086 .38089 m .54228 .35195 L .54161 .35263 L p .581 .568 .804 r
F P
0 g
s
.54228 .35195 m .57086 .38089 L .57261 .37898 L p .571 .566 .809 r
F P
0 g
s
.57086 .38089 m .59149 .41932 L .59405 .41665 L p .476 .425 .721 r
F P
0 g
s
.59405 .41665 m .57261 .37898 L .57086 .38089 L p .476 .425 .721 r
F P
0 g
s
.57884 .42872 m .58802 .46987 L .59203 .4676 L p .497 .366 .632 r
F P
0 g
s
.59203 .4676 m .58235 .42657 L .57884 .42872 L p .497 .366 .632 r
F P
0 g
s
.5845 .57837 m .59953 .60221 L .58787 .6043 L p .724 .73 .855 r
F P
0 g
s
.59953 .60221 m .5845 .57837 L .59294 .57597 L p .684 .714 .872 r
F P
0 g
s
.59294 .57597 m .61025 .5994 L .59953 .60221 L p .684 .714 .872 r
F P
0 g
s
.6933 .72621 m .68576 .74816 L .69397 .73666 L p 0 0 0 r
F P
0 g
s
.69397 .73666 m .702 .71521 L .6933 .72621 L p 0 0 0 r
F P
0 g
s
.48097 .37982 m .51017 .3516 L .51081 .35228 L p .8 .75 .807 r
F P
0 g
s
.57538 .58045 m .58787 .6043 L .5758 .6056 L p .759 .746 .841 r
F P
0 g
s
.58787 .6043 m .57538 .58045 L .5845 .57837 L p .724 .73 .855 r
F P
0 g
s
.45719 .41443 m .47931 .37785 L .48097 .37982 L p .879 .76 .727 r
F P
0 g
s
.48097 .37982 m .45965 .41727 L .45719 .41443 L p .879 .76 .727 r
F P
0 g
s
.51017 .3516 m .48097 .37982 L .47931 .37785 L p .805 .76 .812 r
F P
0 g
s
.57261 .37898 m .5429 .35125 L .54228 .35195 L p .571 .566 .809 r
F P
0 g
s
.47931 .37785 m .50959 .35088 L .51017 .3516 L p .805 .76 .812 r
F P
0 g
s
.53077 .5222 m .53061 .48587 L .5363 .48531 L p .716 .485 .574 r
F P
0 g
s
.5363 .48531 m .53675 .52137 L .53077 .5222 L p .716 .485 .574 r
F P
0 g
s
.53675 .52137 m .5363 .48531 L .54199 .48452 L p .702 .477 .579 r
F P
0 g
s
.45844 .46576 m .46864 .42521 L .47211 .42763 L p .853 .654 .633 r
F P
0 g
s
.47211 .42763 m .46266 .46871 L .45844 .46576 L p .853 .654 .633 r
F P
0 g
s
.54199 .48452 m .5428 .5203 L .53675 .52137 L p .702 .477 .579 r
F P
0 g
s
.5428 .5203 m .54199 .48452 L .54765 .48351 L p .686 .467 .583 r
F P
0 g
s
.5429 .35125 m .57261 .37898 L .57417 .37699 L p .561 .564 .814 r
F P
0 g
s
.57417 .37699 m .54344 .35053 L .5429 .35125 L p .561 .564 .814 r
F P
0 g
s
.52488 .52277 m .52493 .4862 L .53061 .48587 L p .728 .491 .569 r
F P
0 g
s
.53061 .48587 m .53077 .5222 L .52488 .52277 L p .728 .491 .569 r
F P
0 g
s
.54765 .48351 m .54888 .51903 L .5428 .5203 L p .686 .467 .583 r
F P
0 g
s
.54888 .51903 m .54765 .48351 L .55325 .48232 L p .667 .454 .587 r
F P
0 g
s
.57261 .37898 m .59405 .41665 L .59634 .41385 L p .454 .414 .724 r
F P
0 g
s
.59634 .41385 m .57417 .37699 L .57261 .37898 L p .454 .414 .724 r
F P
0 g
s
.47785 .37582 m .50908 .35015 L .50959 .35088 L p .809 .771 .818 r
F P
0 g
s
.50959 .35088 m .47931 .37785 L .47785 .37582 L p .809 .771 .818 r
F P
0 g
s
.51909 .52304 m .51929 .48626 L .52493 .4862 L p .737 .496 .564 r
F P
0 g
s
.52493 .4862 m .52488 .52277 L .51909 .52304 L p .737 .496 .564 r
F P
0 g
s
.54344 .35053 m .57417 .37699 L .57554 .37493 L p .55 .562 .819 r
F P
0 g
s
.57554 .37493 m .54392 .34978 L .54344 .35053 L p .55 .562 .819 r
F P
0 g
s
.59294 .57597 m .61025 .5994 L .61955 .59596 L p .634 .696 .89 r
F P
0 g
s
.55325 .48232 m .55494 .51759 L .54888 .51903 L p .667 .454 .587 r
F P
0 g
s
.55494 .51759 m .55325 .48232 L .55875 .48096 L p .645 .439 .59 r
F P
0 g
s
.51339 .523 m .5137 .48604 L .51929 .48626 L p .745 .5 .56 r
F P
0 g
s
.51929 .48626 m .51909 .52304 L .51339 .523 L p .745 .5 .56 r
F P
0 g
s
.58235 .42657 m .59203 .4676 L .59574 .4652 L p .47 .347 .63 r
F P
0 g
s
.59574 .4652 m .58564 .42428 L .58235 .42657 L p .47 .347 .63 r
F P
0 g
s
.47658 .37373 m .50864 .34939 L .50908 .35015 L p .813 .782 .824 r
F P
0 g
s
.50908 .35015 m .47785 .37582 L .47658 .37373 L p .813 .782 .824 r
F P
0 g
s
.45501 .41153 m .47785 .37582 L .47931 .37785 L p .891 .78 .732 r
F P
0 g
s
.47931 .37785 m .45719 .41443 L .45501 .41153 L p .891 .78 .732 r
F P
0 g
s
.54392 .34978 m .57554 .37493 L .57671 .37281 L p .539 .561 .825 r
F P
0 g
s
.57671 .37281 m .54433 .34902 L .54392 .34978 L p .539 .561 .825 r
F P
0 g
s
.50777 .52262 m .50816 .48555 L .5137 .48604 L p .751 .503 .557 r
F P
0 g
s
.5137 .48604 m .51339 .523 L .50777 .52262 L p .751 .503 .557 r
F P
0 g
s
.47551 .37159 m .50827 .34861 L .50864 .34939 L p .817 .793 .83 r
F P
0 g
s
.50864 .34939 m .47658 .37373 L .47551 .37159 L p .817 .793 .83 r
F P
0 g
s
.55875 .48096 m .56091 .51601 L .55494 .51759 L p .645 .439 .59 r
F P
0 g
s
.56091 .51601 m .55875 .48096 L .56413 .47943 L p .62 .422 .592 r
F P
0 g
s
.56595 .58214 m .5758 .6056 L .56383 .60613 L p .79 .762 .827 r
F P
0 g
s
.5758 .6056 m .56595 .58214 L .57538 .58045 L p .759 .746 .841 r
F P
0 g
s
.45449 .46267 m .46539 .42267 L .46864 .42521 L p .869 .674 .635 r
F P
0 g
s
.46864 .42521 m .45844 .46576 L .45449 .46267 L p .869 .674 .635 r
F P
0 g
s
.54433 .34902 m .57671 .37281 L .57769 .37064 L p .528 .56 .832 r
F P
0 g
s
.57769 .37064 m .54466 .34823 L .54433 .34902 L p .528 .56 .832 r
F P
0 g
s
.57417 .37699 m .59634 .41385 L .59836 .41094 L p .429 .403 .729 r
F P
0 g
s
.59836 .41094 m .57554 .37493 L .57417 .37699 L p .429 .403 .729 r
F P
0 g
s
.50221 .52188 m .50269 .48476 L .50816 .48555 L p .757 .506 .554 r
F P
0 g
s
.50816 .48555 m .50777 .52262 L .50221 .52188 L p .757 .506 .554 r
F P
0 g
s
.47465 .36941 m .50797 .34782 L .50827 .34861 L p .82 .805 .837 r
F P
0 g
s
.50827 .34861 m .47551 .37159 L .47465 .36941 L p .82 .805 .837 r
F P
0 g
s
.60401 .762 m .62333 .76564 L p .59736 .76694 L .556 0 0 r
F P
0 g
s
.59611 .76661 m .60401 .762 L p .59736 .76694 L .556 0 0 r
F P
0 g
s
.62333 .76564 m .61254 .77127 L .59537 .76704 L p .556 0 0 r
F P
0 g
s
.58493 .75551 m .60401 .762 L p .58081 .76019 L .661 .119 0 r
F P
0 g
s
.5784 .76 m .57919 .75946 L p .58081 .76019 L .661 .119 0 r
F P
0 g
s
.57919 .75946 m .58493 .75551 L p .58081 .76019 L .661 .119 0 r
F P
0 g
s
.60401 .762 m .59537 .76704 L .5784 .76 L p .661 .119 0 r
F P
0 g
s
.56685 .74672 m .58493 .75551 L p .56488 .75124 L .724 .195 0 r
F P
0 g
s
.56233 .7507 m .56303 .75009 L p .56488 .75124 L .724 .195 0 r
F P
0 g
s
.56303 .75009 m .56685 .74672 L p .56488 .75124 L .724 .195 0 r
F P
0 g
s
.58493 .75551 m .5784 .76 L .56233 .7507 L p .724 .195 0 r
F P
0 g
s
.56685 .74672 m .56233 .7507 L .54768 .73986 L p .755 .238 0 r
F P
0 g
s
.56985 .7522 m .55647 .74338 L p .57606 .75823 L 0 .27 .708 r
F P
0 g
s
.5784 .76 m .57731 .75901 L p .57606 .75823 L 0 .27 .708 r
F P
0 g
s
.57731 .75901 m .56985 .7522 L p .57606 .75823 L 0 .27 .708 r
F P
0 g
s
.58395 .759 m .56985 .7522 L p .59318 .76577 L 0 .388 .77 r
F P
0 g
s
.59537 .76704 m .59424 .76625 L p .59318 .76577 L 0 .388 .77 r
F P
0 g
s
.59424 .76625 m .58395 .759 L p .59318 .76577 L 0 .388 .77 r
F P
0 g
s
.59821 .76324 m .58395 .759 L p .61074 .77049 L .017 .543 .856 r
F P
0 g
s
.61254 .77127 m .61154 .77071 L p .61074 .77049 L .017 .543 .856 r
F P
0 g
s
.61154 .77071 m .59821 .76324 L p .61074 .77049 L .017 .543 .856 r
F P
0 g
s
.59537 .76704 m .59611 .76661 L p .59736 .76694 L .556 0 0 r
F P
0 g
s
.61254 .77127 m .62333 .76564 L .64203 .7661 L p .387 0 0 r
F P
0 g
s
.54466 .34823 m .57769 .37064 L .57845 .36842 L p .517 .56 .838 r
F P
0 g
s
.57845 .36842 m .54492 .34744 L .54466 .34823 L p .517 .56 .838 r
F P
0 g
s
.56413 .47943 m .56674 .51431 L .56091 .51601 L p .62 .422 .592 r
F P
0 g
s
.56674 .51431 m .56413 .47943 L .56935 .47777 L p .591 .401 .592 r
F P
0 g
s
.53584 .7251 m .53631 .71043 L .55154 .7203 L p .9 .536 .341 r
F P
0 g
s
.55154 .7203 m .55036 .73631 L .53584 .7251 L p .9 .536 .341 r
F P
0 g
s
.45312 .40856 m .47658 .37373 L .47785 .37582 L p .902 .8 .737 r
F P
0 g
s
.47785 .37582 m .45501 .41153 L .45312 .40856 L p .902 .8 .737 r
F P
0 g
s
.474 .3672 m .50775 .34702 L .50797 .34782 L p .823 .817 .844 r
F P
0 g
s
.50797 .34782 m .47465 .36941 L .474 .3672 L p .823 .817 .844 r
F P
0 g
s
.49669 .52079 m .49729 .48368 L .50269 .48476 L p .762 .51 .553 r
F P
0 g
s
.50269 .48476 m .50221 .52188 L .49669 .52079 L p .762 .51 .553 r
F P
0 g
s
.58564 .42428 m .59574 .4652 L .59917 .46266 L p .44 .326 .627 r
F P
0 g
s
.59917 .46266 m .58869 .42187 L .58564 .42428 L p .44 .326 .627 r
F P
0 g
s
.54492 .34744 m .57845 .36842 L .579 .36617 L p .505 .56 .845 r
F P
0 g
s
.579 .36617 m .5451 .34663 L .54492 .34744 L p .505 .56 .845 r
F P
0 g
s
.64203 .7661 m .62915 .77231 L .61254 .77127 L p .387 0 0 r
F P
0 g
s
.62915 .77231 m .64203 .7661 L .65919 .76326 L p .114 0 0 r
F P
0 g
s
.47356 .36497 m .50761 .34621 L .50775 .34702 L p .825 .828 .851 r
F P
0 g
s
.50775 .34702 m .474 .3672 L .47356 .36497 L p .825 .828 .851 r
F P
0 g
s
.52322 .70051 m .5233 .67817 L .53606 .68615 L p .909 .666 .56 r
F P
0 g
s
.53606 .68615 m .53631 .71043 L .52322 .70051 L p .909 .666 .56 r
F P
0 g
s
.53517 .65696 m .53606 .68615 L .5233 .67817 L p .883 .726 .682 r
F P
0 g
s
.57554 .37493 m .59836 .41094 L .60011 .40791 L p .402 .392 .733 r
F P
0 g
s
.60011 .40791 m .57671 .37281 L .57554 .37493 L p .402 .392 .733 r
F P
0 g
s
.5451 .34663 m .579 .36617 L .57934 .3639 L p .493 .561 .853 r
F P
0 g
s
.57934 .3639 m .54521 .34582 L .5451 .34663 L p .493 .561 .853 r
F P
0 g
s
.45085 .4595 m .46239 .42002 L .46539 .42267 L p .887 .695 .637 r
F P
0 g
s
.46539 .42267 m .45449 .46267 L .45085 .4595 L p .887 .695 .637 r
F P
0 g
s
.4912 .51933 m .49197 .48231 L .49729 .48368 L p .767 .515 .553 r
F P
0 g
s
.49729 .48368 m .49669 .52079 L .4912 .51933 L p .767 .515 .553 r
F P
0 g
s
.56935 .47777 m .57236 .51253 L .56674 .51431 L p .591 .401 .592 r
F P
0 g
s
.56935 .47777 m .57236 .51253 L .5777 .51069 L p .563 .379 .59 r
F P
0 g
s
.5777 .51069 m .57438 .47598 L .56935 .47777 L p .563 .379 .59 r
F P
0 g
s
.47334 .36271 m .50755 .3454 L .50761 .34621 L p .826 .84 .858 r
F P
0 g
s
.50761 .34621 m .47356 .36497 L .47334 .36271 L p .826 .84 .858 r
F P
0 g
s
.54521 .34582 m .57934 .3639 L .57947 .36161 L p .481 .562 .861 r
F P
0 g
s
.57947 .36161 m .54523 .345 L .54521 .34582 L p .481 .562 .861 r
F P
0 g
s
.45154 .40554 m .47551 .37159 L .47658 .37373 L p .913 .822 .743 r
F P
0 g
s
.47658 .37373 m .45312 .40856 L .45154 .40554 L p .913 .822 .743 r
F P
0 g
s
.61955 .59596 m .60035 .57334 L .59294 .57597 L p .634 .696 .89 r
F P
0 g
s
.60035 .57334 m .61955 .59596 L .62702 .59207 L p .569 .674 .91 r
F P
0 g
s
.47333 .36045 m .50756 .34458 L .50755 .3454 L p .826 .852 .866 r
F P
0 g
s
.50755 .3454 m .47334 .36271 L .47333 .36045 L p .826 .852 .866 r
F P
0 g
s
.48571 .51751 m .48675 .48066 L .49197 .48231 L p .774 .521 .554 r
F P
0 g
s
.49197 .48231 m .4912 .51933 L .48571 .51751 L p .774 .521 .554 r
F P
0 g
s
.5233 .67817 m .52358 .65127 L .53517 .65696 L p .883 .726 .682 r
F P
0 g
s
.53389 .62826 m .53517 .65696 L .52358 .65127 L p .867 .771 .753 r
F P
0 g
s
.53517 .65696 m .53389 .62826 L .54536 .63142 L p .853 .753 .752 r
F P
0 g
s
.54193 .60519 m .54536 .63142 L .53389 .62826 L p .851 .792 .793 r
F P
0 g
s
.54536 .63142 m .54193 .60519 L .55243 .60596 L p .832 .774 .797 r
F P
0 g
s
.65754 .61489 m .63241 .58789 L .62702 .59207 L p .483 .613 .904 r
F P
0 g
s
.63241 .58789 m .65754 .61489 L .66119 .60848 L p .372 .574 .918 r
F P
0 g
s
.68529 .63943 m .66119 .60848 L .65754 .61489 L p .346 .491 .862 r
F P
0 g
s
.54523 .345 m .57947 .36161 L .57937 .35931 L p .468 .563 .869 r
F P
0 g
s
.57937 .35931 m .54518 .34419 L .54523 .345 L p .468 .563 .869 r
F P
0 g
s
.58869 .42187 m .59917 .46266 L .6023 .45998 L p .408 .304 .624 r
F P
0 g
s
.6023 .45998 m .59149 .41932 L .58869 .42187 L p .408 .304 .624 r
F P
0 g
s
.57671 .37281 m .60011 .40791 L .60158 .40478 L p .373 .38 .738 r
F P
0 g
s
.60158 .40478 m .57769 .37064 L .57671 .37281 L p .373 .38 .738 r
F P
0 g
s
.47355 .35819 m .50765 .34377 L .50756 .34458 L p .826 .864 .874 r
F P
0 g
s
.50756 .34458 m .47333 .36045 L .47355 .35819 L p .826 .864 .874 r
F P
0 g
s
.57438 .47598 m .5777 .51069 L .58271 .50879 L p .536 .358 .587 r
F P
0 g
s
.58271 .50879 m .57918 .47406 L .57438 .47598 L p .536 .358 .587 r
F P
0 g
s
.54518 .34419 m .57937 .35931 L .57906 .35702 L p .455 .565 .877 r
F P
0 g
s
.57906 .35702 m .54506 .34337 L .54518 .34419 L p .455 .565 .877 r
F P
0 g
s
.48024 .51535 m .48163 .47874 L .48675 .48066 L p .781 .53 .556 r
F P
0 g
s
.48675 .48066 m .48571 .51751 L .48024 .51535 L p .781 .53 .556 r
F P
0 g
s
.44755 .45626 m .45965 .41727 L .46239 .42002 L p .905 .718 .639 r
F P
0 g
s
.46239 .42002 m .45085 .4595 L .44755 .45626 L p .905 .718 .639 r
F P
0 g
s
.55657 .58342 m .56383 .60613 L .55243 .60596 L p .818 .778 .815 r
F P
0 g
s
.56383 .60613 m .55657 .58342 L .56595 .58214 L p .79 .762 .827 r
F P
0 g
s
.47398 .35593 m .50781 .34296 L .50765 .34377 L p .824 .875 .882 r
F P
0 g
s
.50765 .34377 m .47355 .35819 L .47398 .35593 L p .824 .875 .882 r
F P
0 g
s
.45027 .40248 m .47465 .36941 L .47551 .37159 L p .924 .844 .747 r
F P
0 g
s
.47551 .37159 m .45154 .40554 L .45027 .40248 L p .924 .844 .747 r
F P
0 g
s
.54506 .34337 m .57906 .35702 L .57853 .35474 L p .442 .568 .886 r
F P
0 g
s
.57853 .35474 m .54485 .34257 L .54506 .34337 L p .442 .568 .886 r
F P
0 g
s
.65919 .76326 m .64437 .77001 L .65748 .76442 L p 0 0 0 r
F P
0 g
s
.65748 .76442 m .674 .75719 L .65919 .76326 L p 0 0 0 r
F P
0 g
s
.65919 .76326 m .64437 .77001 L .62915 .77231 L p .114 0 0 r
F P
0 g
s
.47463 .35369 m .50806 .34216 L .50781 .34296 L p .821 .886 .891 r
F P
0 g
s
.50781 .34296 m .47398 .35593 L .47463 .35369 L p .821 .886 .891 r
F P
0 g
s
.54485 .34257 m .57853 .35474 L .57778 .35249 L p .428 .571 .895 r
F P
0 g
s
.57778 .35249 m .54457 .34177 L .54485 .34257 L p .428 .571 .895 r
F P
0 g
s
.4748 .51286 m .47663 .47656 L .48163 .47874 L p .79 .54 .559 r
F P
0 g
s
.48163 .47874 m .48024 .51535 L .4748 .51286 L p .79 .54 .559 r
F P
0 g
s
.57769 .37064 m .60158 .40478 L .60276 .40156 L p .342 .367 .742 r
F P
0 g
s
.60276 .40156 m .57845 .36842 L .57769 .37064 L p .342 .367 .742 r
F P
0 g
s
.47549 .35148 m .50838 .34137 L .50806 .34216 L p .816 .897 .899 r
F P
0 g
s
.50806 .34216 m .47463 .35369 L .47549 .35148 L p .816 .897 .899 r
F P
0 g
s
.59149 .41932 m .6023 .45998 L .60515 .45713 L p .373 .28 .621 r
F P
0 g
s
.60515 .45713 m .59405 .41665 L .59149 .41932 L p .373 .28 .621 r
F P
0 g
s
.57918 .47406 m .58271 .50879 L .58736 .50686 L p .506 .334 .581 r
F P
0 g
s
.58736 .50686 m .58373 .47202 L .57918 .47406 L p .506 .334 .581 r
F P
0 g
s
.54457 .34177 m .57778 .35249 L .57682 .35028 L p .414 .575 .904 r
F P
0 g
s
.57682 .35028 m .54422 .34099 L .54457 .34177 L p .414 .575 .904 r
F P
0 g
s
.44932 .39938 m .474 .3672 L .47465 .36941 L p .932 .867 .752 r
F P
0 g
s
.47465 .36941 m .45027 .40248 L .44932 .39938 L p .932 .867 .752 r
F P
0 g
s
.47656 .3493 m .50877 .3406 L .50838 .34137 L p .81 .906 .907 r
F P
0 g
s
.50838 .34137 m .47549 .35148 L .47656 .3493 L p .81 .906 .907 r
F P
0 g
s
.44461 .45298 m .45719 .41443 L .45965 .41727 L p .924 .743 .639 r
F P
0 g
s
.45965 .41727 m .44755 .45626 L .44461 .45298 L p .924 .743 .639 r
F P
0 g
s
.54422 .34099 m .57682 .35028 L .57565 .34812 L p .4 .58 .912 r
F P
0 g
s
.57565 .34812 m .54379 .34023 L .54422 .34099 L p .4 .58 .912 r
F P
0 g
s
.46944 .51009 m .47179 .47414 L .47663 .47656 L p .801 .553 .562 r
F P
0 g
s
.47663 .47656 m .4748 .51286 L .46944 .51009 L p .801 .553 .562 r
F P
0 g
s
.47784 .34717 m .50923 .33984 L .50877 .3406 L p .802 .916 .916 r
F P
0 g
s
.50877 .3406 m .47656 .3493 L .47784 .34717 L p .802 .916 .916 r
F P
0 g
s
.66119 .60848 m .68529 .63943 L .68624 .6303 L p .187 .422 .856 r
F P
0 g
s
.68529 .63943 m .70194 .67274 L .70299 .66111 L p .04 .221 .723 r
F P
0 g
s
.70299 .66111 m .68624 .6303 L .68529 .63943 L p .04 .221 .723 r
F P
0 g
s
.54379 .34023 m .57565 .34812 L .57426 .34601 L p .386 .585 .921 r
F P
0 g
s
.57426 .34601 m .54329 .33948 L .54379 .34023 L p .386 .585 .921 r
F P
0 g
s
.57845 .36842 m .60276 .40156 L .60364 .39826 L p .307 .354 .747 r
F P
0 g
s
.60364 .39826 m .579 .36617 L .57845 .36842 L p .307 .354 .747 r
F P
0 g
s
.47933 .34508 m .50977 .33911 L .50923 .33984 L p .792 .924 .924 r
F P
0 g
s
.50923 .33984 m .47784 .34717 L .47933 .34508 L p .792 .924 .924 r
F P
0 g
s
.54329 .33948 m .57426 .34601 L .57268 .34397 L p .371 .59 .929 r
F P
0 g
s
.57268 .34397 m .54272 .33876 L .54329 .33948 L p .371 .59 .929 r
F P
0 g
s
.58373 .47202 m .58736 .50686 L .59162 .50488 L p .473 .306 .574 r
F P
0 g
s
.59162 .50488 m .58802 .46987 L .58373 .47202 L p .473 .306 .574 r
F P
0 g
s
.702 .71521 m .69397 .73666 L .69843 .72329 L p .678 .765 .279 r
F P
0 g
s
.69843 .72329 m .70681 .70261 L .702 .71521 L p .678 .765 .279 r
F P
0 g
s
.44868 .39625 m .47356 .36497 L .474 .3672 L p .939 .89 .755 r
F P
0 g
s
.474 .3672 m .44932 .39938 L .44868 .39625 L p .939 .89 .755 r
F P
0 g
s
.48101 .34306 m .51038 .3384 L .50977 .33911 L p .78 .931 .932 r
F P
0 g
s
.50977 .33911 m .47933 .34508 L .48101 .34306 L p .78 .931 .932 r
F P
0 g
s
.59405 .41665 m .60515 .45713 L .60771 .45411 L p .334 .255 .616 r
F P
0 g
s
.60771 .45411 m .59634 .41385 L .59405 .41665 L p .334 .255 .616 r
F P
0 g
s
.46418 .50707 m .46712 .47152 L .47179 .47414 L p .814 .568 .566 r
F P
0 g
s
.47179 .47414 m .46944 .51009 L .46418 .50707 L p .814 .568 .566 r
F P
0 g
s
.54272 .33876 m .57268 .34397 L .5709 .34201 L p .357 .596 .937 r
F P
0 g
s
.5709 .34201 m .54208 .33806 L .54272 .33876 L p .357 .596 .937 r
F P
0 g
s
.48289 .34112 m .51105 .33772 L .51038 .3384 L p .766 .937 .939 r
F P
0 g
s
.51038 .3384 m .48101 .34306 L .48289 .34112 L p .766 .937 .939 r
F P
0 g
s
.70194 .67274 m .70681 .70261 L .70782 .68906 L p 0 0 .344 r
F P
0 g
s
.70782 .68906 m .70299 .66111 L .70194 .67274 L p 0 0 .344 r
F P
0 g
s
.44206 .44968 m .45501 .41153 L .45719 .41443 L p .943 .77 .637 r
F P
0 g
s
.45719 .41443 m .44461 .45298 L .44206 .44968 L p .943 .77 .637 r
F P
0 g
s
.62702 .59207 m .60646 .57057 L .60035 .57334 L p .569 .674 .91 r
F P
0 g
s
.60646 .57057 m .62702 .59207 L .63241 .58789 L p .484 .645 .928 r
F P
0 g
s
.54208 .33806 m .5709 .34201 L .56892 .34013 L p .342 .603 .944 r
F P
0 g
s
.56892 .34013 m .54138 .3374 L .54208 .33806 L p .342 .603 .944 r
F P
0 g
s
.579 .36617 m .60364 .39826 L .60422 .3949 L p .268 .339 .752 r
F P
0 g
s
.60422 .3949 m .57934 .3639 L .579 .36617 L p .268 .339 .752 r
F P
0 g
s
.48495 .33925 m .51179 .33707 L .51105 .33772 L p .749 .941 .946 r
F P
0 g
s
.51105 .33772 m .48289 .34112 L .48495 .33925 L p .749 .941 .946 r
F P
0 g
s
.54138 .3374 m .56892 .34013 L .56677 .33834 L p .329 .61 .951 r
F P
0 g
s
.56677 .33834 m .54061 .33676 L .54138 .3374 L p .329 .61 .951 r
F P
0 g
s
.48718 .33748 m .51258 .33645 L .51179 .33707 L p .729 .944 .953 r
F P
0 g
s
.51179 .33707 m .48495 .33925 L .48718 .33748 L p .729 .944 .953 r
F P
0 g
s
.45911 .50384 m .46266 .46871 L .46712 .47152 L p .83 .586 .57 r
F P
0 g
s
.46712 .47152 m .46418 .50707 L .45911 .50384 L p .83 .586 .57 r
F P
0 g
s
.44836 .39309 m .47334 .36271 L .47356 .36497 L p .943 .913 .757 r
F P
0 g
s
.47356 .36497 m .44868 .39625 L .44836 .39309 L p .943 .913 .757 r
F P
0 g
s
.54061 .33676 m .56677 .33834 L .56445 .33665 L p .315 .618 .957 r
F P
0 g
s
.56445 .33665 m .53978 .33616 L .54061 .33676 L p .315 .618 .957 r
F P
0 g
s
.54755 .5843 m .55243 .60596 L .54193 .60519 L p .843 .794 .804 r
F P
0 g
s
.55243 .60596 m .54755 .5843 L .55657 .58342 L p .818 .778 .815 r
F P
0 g
s
.52337 .71395 m .52322 .70051 L .53631 .71043 L p .918 .549 .31 r
F P
0 g
s
.53631 .71043 m .53584 .7251 L .52337 .71395 L p .918 .549 .31 r
F P
0 g
s
.48959 .33581 m .51344 .33587 L .51258 .33645 L p .706 .944 .958 r
F P
0 g
s
.51258 .33645 m .48718 .33748 L .48959 .33581 L p .706 .944 .958 r
F P
0 g
s
.58802 .46987 m .59162 .50488 L .59549 .50286 L p .436 .275 .564 r
F P
0 g
s
.59549 .50286 m .59203 .4676 L .58802 .46987 L p .436 .275 .564 r
F P
0 g
s
.53978 .33616 m .56445 .33665 L .56196 .33507 L p .303 .627 .961 r
F P
0 g
s
.56196 .33507 m .5389 .3356 L .53978 .33616 L p .303 .627 .961 r
F P
0 g
s
.59634 .41385 m .60771 .45411 L .61 .45091 L p .291 .227 .611 r
F P
0 g
s
.61 .45091 m .59836 .41094 L .59634 .41385 L p .291 .227 .611 r
F P
0 g
s
.49215 .33424 m .51435 .33532 L .51344 .33587 L p .681 .942 .963 r
F P
0 g
s
.51344 .33587 m .48959 .33581 L .49215 .33424 L p .681 .942 .963 r
F P
0 g
s
.674 .75719 m .65748 .76442 L .66784 .75582 L p .589 .939 .78 r
F P
0 g
s
.66784 .75582 m .68576 .74816 L .674 .75719 L p .589 .939 .78 r
F P
0 g
s
.57934 .3639 m .60422 .3949 L .60449 .39149 L p .225 .324 .756 r
F P
0 g
s
.60449 .39149 m .57947 .36161 L .57934 .3639 L p .225 .324 .756 r
F P
0 g
s
.5389 .3356 m .56196 .33507 L .55932 .3336 L p .292 .636 .965 r
F P
0 g
s
.55932 .3336 m .53797 .33507 L .5389 .3356 L p .292 .636 .965 r
F P
0 g
s
.49486 .3328 m .51531 .33482 L .51435 .33532 L p .654 .937 .966 r
F P
0 g
s
.51435 .33532 m .49215 .33424 L .49486 .3328 L p .654 .937 .966 r
F P
0 g
s
.43991 .44638 m .45312 .40856 L .45501 .41153 L p .962 .798 .633 r
F P
0 g
s
.45501 .41153 m .44206 .44968 L .43991 .44638 L p .962 .798 .633 r
F P
0 g
s
.53797 .33507 m .55932 .3336 L .55654 .33224 L p .283 .646 .967 r
F P
0 g
s
.55654 .33224 m .53699 .33459 L .53797 .33507 L p .283 .646 .967 r
F P
0 g
s
.4977 .33148 m .51631 .33436 L .51531 .33482 L p .624 .93 .969 r
F P
0 g
s
.51531 .33482 m .49486 .3328 L .4977 .33148 L p .624 .93 .969 r
F P
0 g
s
.45428 .50046 m .45844 .46576 L .46266 .46871 L p .848 .607 .574 r
F P
0 g
s
.46266 .46871 m .45911 .50384 L .45428 .50046 L p .848 .607 .574 r
F P
0 g
s
.51207 .69134 m .51241 .67071 L .5233 .67817 L p .92 .678 .557 r
F P
0 g
s
.5233 .67817 m .52322 .70051 L .51207 .69134 L p .92 .678 .557 r
F P
0 g
s
.52358 .65127 m .5233 .67817 L .51241 .67071 L p .89 .738 .686 r
F P
0 g
s
.53699 .33459 m .55654 .33224 L .55363 .33101 L p .275 .656 .968 r
F P
0 g
s
.55363 .33101 m .53596 .33415 L .53699 .33459 L p .275 .656 .968 r
F P
0 g
s
.44835 .38991 m .47333 .36045 L .47334 .36271 L p .944 .934 .757 r
F P
0 g
s
.47334 .36271 m .44836 .39309 L .44835 .38991 L p .944 .934 .757 r
F P
0 g
s
.55036 .73631 m .56685 .74672 L p .55011 .74073 L .755 .238 0 r
F P
0 g
s
.54817 .73921 m .55036 .73631 L p .55011 .74073 L .755 .238 0 r
F P
0 g
s
.55036 .73631 m .54768 .73986 L .53478 .7283 L p .756 .251 0 r
F P
0 g
s
.55647 .74338 m .54425 .73319 L p .56007 .74852 L 0 .197 .676 r
F P
0 g
s
.56233 .7507 m .56143 .74958 L p .56007 .74852 L 0 .197 .676 r
F P
0 g
s
.56143 .74958 m .55647 .74338 L p .56007 .74852 L 0 .197 .676 r
F P
0 g
s
.54768 .73986 m .54817 .73921 L p .55011 .74073 L .755 .238 0 r
F P
0 g
s
.50067 .33029 m .51736 .33394 L .51631 .33436 L p .592 .92 .97 r
F P
0 g
s
.51631 .33436 m .4977 .33148 L .50067 .33029 L p .592 .92 .97 r
F P
0 g
s
.52358 .65127 m .52398 .62484 L .53389 .62826 L p .867 .771 .753 r
F P
0 g
s
.53257 .60398 m .53389 .62826 L .52398 .62484 L p .864 .808 .792 r
F P
0 g
s
.53389 .62826 m .53257 .60398 L .54193 .60519 L p .851 .792 .793 r
F P
0 g
s
.53596 .33415 m .55363 .33101 L .5506 .3299 L p .271 .668 .969 r
F P
0 g
s
.5506 .3299 m .53489 .33376 L .53596 .33415 L p .271 .668 .969 r
F P
0 g
s
.50067 .33029 m .51736 .33394 L .51844 .33357 L p .56 .908 .97 r
F P
0 g
s
.53489 .33376 m .5506 .3299 L .54747 .32893 L p .269 .68 .968 r
F P
0 g
s
.54747 .32893 m .53379 .33341 L .53489 .33376 L p .269 .68 .968 r
F P
0 g
s
.50376 .32923 m .51844 .33357 L .51956 .33325 L p .528 .895 .97 r
F P
0 g
s
.51844 .33357 m .50376 .32923 L .50067 .33029 L p .56 .908 .97 r
F P
0 g
s
.53379 .33341 m .54747 .32893 L .54425 .32808 L p .27 .693 .967 r
F P
0 g
s
.54425 .32808 m .53266 .33311 L .53379 .33341 L p .27 .693 .967 r
F P
0 g
s
.57947 .36161 m .60449 .39149 L .60444 .38805 L p .177 .307 .759 r
F P
0 g
s
.60444 .38805 m .57937 .35931 L .57947 .36161 L p .177 .307 .759 r
F P
0 g
s
.51241 .67071 m .51368 .64587 L .52358 .65127 L p .89 .738 .686 r
F P
0 g
s
.52398 .62484 m .52358 .65127 L .51368 .64587 L p .872 .782 .76 r
F P
0 g
s
.50694 .32832 m .51956 .33325 L .52071 .33298 L p .496 .879 .969 r
F P
0 g
s
.51956 .33325 m .50694 .32832 L .50376 .32923 L p .528 .895 .97 r
F P
0 g
s
.59203 .4676 m .59549 .50286 L .59897 .50076 L p .395 .241 .551 r
F P
0 g
s
.59897 .50076 m .59574 .4652 L .59203 .4676 L p .395 .241 .551 r
F P
0 g
s
.53266 .33311 m .54425 .32808 L .54095 .32737 L p .275 .707 .966 r
F P
0 g
s
.54095 .32737 m .5315 .33287 L .53266 .33311 L p .275 .707 .966 r
F P
0 g
s
.3058 .6608 m .32704 .62646 L .34607 .63142 L p .74 .601 .702 r
F P
0 g
s
.34607 .63142 m .32701 .66485 L .3058 .6608 L p .74 .601 .702 r
F P
0 g
s
.37362 .60093 m .34607 .63142 L .32704 .62646 L p .713 .632 .765 r
F P
0 g
s
.32701 .66485 m .34607 .63142 L .36646 .63479 L p .71 .567 .691 r
F P
0 g
s
.34607 .63142 m .37362 .60093 L .39068 .60516 L p .69 .601 .751 r
F P
0 g
s
.39068 .60516 m .36646 .63479 L .34607 .63142 L p .69 .601 .751 r
F P
0 g
s
.54322 .5468 m .5428 .5203 L .54888 .51903 L p .725 .495 .577 r
F P
0 g
s
.54888 .51903 m .5497 .54534 L .54322 .5468 L p .725 .495 .577 r
F P
0 g
s
.5497 .54534 m .54888 .51903 L .55494 .51759 L p .703 .484 .588 r
F P
0 g
s
.5102 .32756 m .52071 .33298 L .52188 .33276 L p .464 .863 .968 r
F P
0 g
s
.52071 .33298 m .5102 .32756 L .50694 .32832 L p .496 .879 .969 r
F P
0 g
s
.55494 .51759 m .55624 .54372 L .5497 .54534 L p .703 .484 .588 r
F P
0 g
s
.55624 .54372 m .55494 .51759 L .56091 .51601 L p .676 .468 .596 r
F P
0 g
s
.5315 .33287 m .54095 .32737 L .53759 .32681 L p .283 .722 .965 r
F P
0 g
s
.53759 .32681 m .53032 .33267 L .5315 .33287 L p .283 .722 .965 r
F P
0 g
s
.59836 .41094 m .61 .45091 L .61202 .44752 L p .243 .198 .605 r
F P
0 g
s
.61202 .44752 m .60011 .40791 L .59836 .41094 L p .243 .198 .605 r
F P
0 g
s
.51354 .32694 m .52188 .33276 L .52307 .33259 L p .433 .845 .966 r
F P
0 g
s
.52188 .33276 m .51354 .32694 L .5102 .32756 L p .464 .863 .968 r
F P
0 g
s
.53689 .54805 m .53675 .52137 L .5428 .5203 L p .743 .502 .565 r
F P
0 g
s
.5428 .5203 m .54322 .5468 L .53689 .54805 L p .743 .502 .565 r
F P
0 g
s
.53032 .33267 m .53759 .32681 L .53419 .32638 L p .295 .738 .963 r
F P
0 g
s
.53419 .32638 m .52912 .33252 L .53032 .33267 L p .295 .738 .963 r
F P
0 g
s
.51693 .32647 m .52307 .33259 L .52427 .33247 L p .403 .827 .965 r
F P
0 g
s
.52307 .33259 m .51693 .32647 L .51354 .32694 L p .433 .845 .966 r
F P
0 g
s
.52912 .33252 m .53419 .32638 L .53074 .3261 L p .31 .755 .963 r
F P
0 g
s
.53074 .3261 m .52792 .33243 L .52912 .33252 L p .31 .755 .963 r
F P
0 g
s
.52036 .32615 m .52427 .33247 L .52548 .3324 L p .376 .809 .963 r
F P
0 g
s
.52427 .33247 m .52036 .32615 L .51693 .32647 L p .403 .827 .965 r
F P
0 g
s
.52792 .33243 m .53074 .3261 L .52728 .32597 L p .329 .772 .962 r
F P
0 g
s
.52728 .32597 m .5267 .33239 L .52792 .33243 L p .329 .772 .962 r
F P
0 g
s
.36646 .63479 m .34969 .66688 L .32701 .66485 L p .71 .567 .691 r
F P
0 g
s
.34969 .66688 m .36646 .63479 L .3872 .63666 L p .683 .538 .682 r
F P
0 g
s
.36646 .63479 m .39068 .60516 L .40806 .60826 L p .668 .574 .741 r
F P
0 g
s
.40806 .60826 m .3872 .63666 L .36646 .63479 L p .668 .574 .741 r
F P
0 g
s
.52381 .32599 m .52548 .3324 L .5267 .33239 L p .351 .79 .963 r
F P
0 g
s
.52548 .3324 m .52381 .32599 L .52036 .32615 L p .376 .809 .963 r
F P
0 g
s
.5267 .33239 m .52728 .32597 L .52381 .32599 L p .351 .79 .963 r
F P
0 g
s
.56091 .51601 m .56274 .54197 L .55624 .54372 L p .676 .468 .596 r
F P
0 g
s
.56274 .54197 m .56091 .51601 L .56674 .51431 L p .643 .446 .602 r
F P
0 g
s
.44977 .49698 m .45449 .46267 L .45844 .46576 L p .869 .631 .576 r
F P
0 g
s
.45844 .46576 m .45428 .50046 L .44977 .49698 L p .869 .631 .576 r
F P
0 g
s
.44866 .38671 m .47355 .35819 L .47333 .36045 L p .94 .953 .755 r
F P
0 g
s
.47333 .36045 m .44835 .38991 L .44866 .38671 L p .94 .953 .755 r
F P
0 g
s
.53077 .54905 m .53077 .5222 L .53675 .52137 L p .756 .504 .552 r
F P
0 g
s
.53675 .52137 m .53689 .54805 L .53077 .54905 L p .756 .504 .552 r
F P
0 g
s
.66119 .60848 m .63559 .58364 L .63241 .58789 L p .372 .574 .918 r
F P
0 g
s
.63559 .58364 m .66119 .60848 L .66209 .60201 L p .228 .516 .912 r
F P
0 g
s
.68624 .6303 m .66209 .60201 L .66119 .60848 L p .187 .422 .856 r
F P
0 g
s
.43816 .44308 m .45154 .40554 L .45312 .40856 L p .978 .826 .624 r
F P
0 g
s
.45312 .40856 m .43991 .44638 L .43816 .44308 L p .978 .826 .624 r
F P
0 g
s
.57428 .55957 m .5845 .57837 L .57538 .58045 L p .729 .701 .825 r
F P
0 g
s
.5845 .57837 m .57428 .55957 L .58114 .5575 L p .684 .683 .843 r
F P
0 g
s
.58114 .5575 m .59294 .57597 L .5845 .57837 L p .684 .683 .843 r
F P
0 g
s
.56697 .56155 m .57538 .58045 L .56595 .58214 L p .767 .717 .806 r
F P
0 g
s
.57538 .58045 m .56697 .56155 L .57428 .55957 L p .729 .701 .825 r
F P
0 g
s
.56674 .51431 m .56905 .54013 L .56274 .54197 L p .643 .446 .602 r
F P
0 g
s
.56905 .54013 m .56674 .51431 L .57236 .51253 L p .603 .418 .604 r
F P
0 g
s
.57937 .35931 m .60444 .38805 L .60407 .38461 L p .123 .287 .76 r
F P
0 g
s
.60407 .38461 m .57906 .35702 L .57937 .35931 L p .123 .287 .76 r
F P
0 g
s
.28717 .65473 m .31036 .61999 L .32704 .62646 L p .773 .643 .717 r
F P
0 g
s
.32704 .62646 m .3058 .6608 L .28717 .65473 L p .773 .643 .717 r
F P
0 g
s
.35773 .5956 m .32704 .62646 L .31036 .61999 L p .738 .669 .783 r
F P
0 g
s
.32704 .62646 m .35773 .5956 L .37362 .60093 L p .713 .632 .765 r
F P
0 g
s
.5249 .54979 m .52488 .52277 L .53077 .5222 L p .765 .503 .538 r
F P
0 g
s
.53077 .5222 m .53077 .54905 L .5249 .54979 L p .765 .503 .538 r
F P
0 g
s
.58114 .5575 m .59294 .57597 L .60035 .57334 L p .632 .661 .861 r
F P
0 g
s
.3214 .69546 m .32701 .66485 L .34969 .66688 L p .713 .495 .593 r
F P
0 g
s
.34969 .66688 m .34483 .69582 L .3214 .69546 L p .713 .495 .593 r
F P
0 g
s
.34483 .69582 m .34969 .66688 L .37273 .66706 L p .678 .464 .588 r
F P
0 g
s
.3872 .63666 m .37273 .66706 L .34969 .66688 L p .683 .538 .682 r
F P
0 g
s
.51926 .55021 m .51909 .52304 L .52488 .52277 L p .769 .499 .526 r
F P
0 g
s
.52488 .52277 m .5249 .54979 L .51926 .55021 L p .769 .499 .526 r
F P
0 g
s
.44927 .3835 m .47398 .35593 L .47355 .35819 L p .93 .969 .75 r
F P
0 g
s
.47355 .35819 m .44866 .38671 L .44927 .3835 L p .93 .969 .75 r
F P
0 g
s
.59574 .4652 m .59897 .50076 L .60209 .49855 L p .349 .203 .537 r
F P
0 g
s
.60209 .49855 m .59917 .46266 L .59574 .4652 L p .349 .203 .537 r
F P
0 g
s
.29948 .69275 m .3058 .6608 L .32701 .66485 L p .752 .532 .598 r
F P
0 g
s
.32701 .66485 m .3214 .69546 L .29948 .69275 L p .752 .532 .598 r
F P
0 g
s
.60011 .40791 m .61202 .44752 L .61376 .44395 L p .19 .165 .598 r
F P
0 g
s
.61376 .44395 m .60158 .40478 L .60011 .40791 L p .19 .165 .598 r
F P
0 g
s
.55942 .56337 m .56595 .58214 L .55657 .58342 L p .8 .73 .787 r
F P
0 g
s
.56595 .58214 m .55942 .56337 L .56697 .56155 L p .767 .717 .806 r
F P
0 g
s
.44565 .49347 m .45085 .4595 L .45449 .46267 L p .892 .658 .577 r
F P
0 g
s
.45449 .46267 m .44977 .49698 L .44565 .49347 L p .892 .658 .577 r
F P
0 g
s
.57236 .51253 m .57506 .53825 L .56905 .54013 L p .603 .418 .604 r
F P
0 g
s
.57236 .51253 m .57506 .53825 L .58064 .53635 L p .563 .388 .601 r
F P
0 g
s
.58064 .53635 m .5777 .51069 L .57236 .51253 L p .563 .388 .601 r
F P
0 g
s
.37273 .66706 m .3872 .63666 L .40736 .63721 L p .66 .515 .677 r
F P
0 g
s
.3872 .63666 m .40806 .60826 L .425 .61032 L p .648 .553 .734 r
F P
0 g
s
.425 .61032 m .40736 .63721 L .3872 .63666 L p .648 .553 .734 r
F P
0 g
s
.57906 .35702 m .60407 .38461 L .60338 .3812 L p .063 .266 .757 r
F P
0 g
s
.60338 .3812 m .57853 .35474 L .57906 .35702 L p .063 .266 .757 r
F P
0 g
s
.63241 .58789 m .61109 .56779 L .60646 .57057 L p .484 .645 .928 r
F P
0 g
s
.61109 .56779 m .63241 .58789 L .63559 .58364 L p .372 .602 .937 r
F P
0 g
s
.5138 .55031 m .51339 .523 L .51909 .52304 L p .769 .492 .514 r
F P
0 g
s
.51909 .52304 m .51926 .55021 L .5138 .55031 L p .769 .492 .514 r
F P
0 g
s
.43681 .43978 m .45027 .40248 L .45154 .40554 L p .99 .853 .61 r
F P
0 g
s
.45154 .40554 m .43816 .44308 L .43681 .43978 L p .99 .853 .61 r
F P
0 g
s
.53915 .58479 m .54193 .60519 L .53257 .60398 L p .864 .808 .793 r
F P
0 g
s
.54193 .60519 m .53915 .58479 L .54755 .5843 L p .843 .794 .804 r
F P
0 g
s
.37273 .66706 m .3686 .6941 L .34483 .69582 L p .678 .464 .588 r
F P
0 g
s
.3686 .6941 m .37273 .66706 L .3951 .66573 L p .649 .439 .585 r
F P
0 g
s
.40736 .63721 m .3951 .66573 L .37273 .66706 L p .66 .515 .677 r
F P
0 g
s
.4502 .38029 m .47463 .35369 L .47398 .35593 L p .912 .981 .74 r
F P
0 g
s
.47398 .35593 m .44927 .3835 L .4502 .38029 L p .912 .981 .74 r
F P
0 g
s
.50847 .55004 m .50777 .52262 L .51339 .523 L p .766 .483 .506 r
F P
0 g
s
.51339 .523 m .5138 .55031 L .50847 .55004 L p .766 .483 .506 r
F P
0 g
s
.5777 .51069 m .58064 .53635 L .5857 .53449 L p .525 .356 .594 r
F P
0 g
s
.5857 .53449 m .58271 .50879 L .5777 .51069 L p .525 .356 .594 r
F P
0 g
s
.28022 .6876 m .28717 .65473 L .3058 .6608 L p .798 .578 .603 r
F P
0 g
s
.3058 .6608 m .29948 .69275 L .28022 .6876 L p .798 .578 .603 r
F P
0 g
s
.57853 .35474 m .60338 .3812 L .60236 .37782 L p 0 .241 .75 r
F P
0 g
s
.60236 .37782 m .57778 .35249 L .57853 .35474 L p 0 .241 .75 r
F P
0 g
s
.44198 .48997 m .44755 .45626 L .45085 .4595 L p .918 .688 .575 r
F P
0 g
s
.45085 .4595 m .44565 .49347 L .44198 .48997 L p .918 .688 .575 r
F P
0 g
s
.60158 .40478 m .61376 .44395 L .61522 .44019 L p .13 .13 .59 r
F P
0 g
s
.61522 .44019 m .60276 .40156 L .60158 .40478 L p .13 .13 .59 r
F P
0 g
s
.59917 .46266 m .60209 .49855 L .60489 .49622 L p .299 .162 .52 r
F P
0 g
s
.60489 .49622 m .6023 .45998 L .59917 .46266 L p .299 .162 .52 r
F P
0 g
s
.40293 .57691 m .37362 .60093 L .35773 .5956 L p .682 .64 .802 r
F P
0 g
s
.37362 .60093 m .40293 .57691 L .4163 .58148 L p .663 .611 .786 r
F P
0 g
s
.4163 .58148 m .39068 .60516 L .37362 .60093 L p .663 .611 .786 r
F P
0 g
s
.27216 .64679 m .29696 .61223 L .31036 .61999 L p .811 .694 .737 r
F P
0 g
s
.31036 .61999 m .28717 .65473 L .27216 .64679 L p .811 .694 .737 r
F P
0 g
s
.34384 .58929 m .31036 .61999 L .29696 .61223 L p .763 .713 .805 r
F P
0 g
s
.31036 .61999 m .34384 .58929 L .35773 .5956 L p .738 .669 .783 r
F P
0 g
s
.60035 .57334 m .58731 .55538 L .58114 .5575 L p .632 .661 .861 r
F P
0 g
s
.58731 .55538 m .60035 .57334 L .60646 .57057 L p .569 .634 .875 r
F P
0 g
s
.50318 .54939 m .50221 .52188 L .50777 .52262 L p .761 .475 .5 r
F P
0 g
s
.50777 .52262 m .50847 .55004 L .50318 .54939 L p .761 .475 .5 r
F P
0 g
s
.68576 .74816 m .66784 .75582 L .67503 .74465 L p .803 1 .828 r
F P
0 g
s
.67503 .74465 m .69397 .73666 L .68576 .74816 L p .803 1 .828 r
F P
0 g
s
.55186 .56498 m .55657 .58342 L .54755 .5843 L p .829 .741 .767 r
F P
0 g
s
.55657 .58342 m .55186 .56498 L .55942 .56337 L p .8 .73 .787 r
F P
0 g
s
.53584 .7251 m .55036 .73631 L p .53688 .72938 L .756 .251 0 r
F P
0 g
s
.535 .72766 m .53584 .7251 L p .53688 .72938 L .756 .251 0 r
F P
0 g
s
.52337 .71395 m .53584 .7251 L p .52605 .71849 L .727 .232 0 r
F P
0 g
s
.52371 .71691 m .52362 .71616 L p .52605 .71849 L .727 .232 0 r
F P
0 g
s
.52362 .71616 m .52337 .71395 L p .52605 .71849 L .727 .232 0 r
F P
0 g
s
.53584 .7251 m .53478 .7283 L .52371 .71691 L p .727 .232 0 r
F P
0 g
s
.54425 .73319 m .53345 .72242 L p .54545 .73712 L 0 .166 .673 r
F P
0 g
s
.54571 .73744 m .54568 .73734 L .54545 .73712 L 0 .166 .673 r
F
.54568 .73734 m .54425 .73319 L .54545 .73712 L F
.54768 .73986 m .54709 .7387 L p .54571 .73744 L F P
0 g
s
.54709 .7387 m .54425 .73319 L p .54571 .73744 L 0 .166 .673 r
F P
0 g
s
.53478 .7283 m .535 .72766 L p .53688 .72938 L .756 .251 0 r
F P
0 g
s
.45143 .37709 m .47549 .35148 L .47463 .35369 L p .886 .987 .726 r
F P
0 g
s
.47463 .35369 m .4502 .38029 L .45143 .37709 L p .886 .987 .726 r
F P
0 g
s
.43586 .43648 m .44932 .39938 L .45027 .40248 L p .993 .875 .588 r
F P
0 g
s
.45027 .40248 m .43681 .43978 L .43586 .43648 L p .993 .875 .588 r
F P
0 g
s
.51276 .70373 m .51207 .69134 L .52322 .70051 L p .924 .548 .278 r
F P
0 g
s
.52322 .70051 m .52337 .71395 L .51276 .70373 L p .924 .548 .278 r
F P
0 g
s
.3905 .57167 m .35773 .5956 L .34384 .58929 L p .701 .675 .821 r
F P
0 g
s
.35773 .5956 m .3905 .57167 L .40293 .57691 L p .682 .64 .802 r
F P
0 g
s
.39068 .60516 m .4163 .58148 L .42996 .5853 L p .644 .585 .773 r
F P
0 g
s
.42996 .5853 m .40806 .60826 L .39068 .60516 L p .644 .585 .773 r
F P
0 g
s
.49786 .54834 m .49669 .52079 L .50221 .52188 L p .755 .469 .498 r
F P
0 g
s
.50221 .52188 m .50318 .54939 L .49786 .54834 L p .755 .469 .498 r
F P
0 g
s
.66209 .60201 m .68624 .6303 L .6843 .62126 L p 0 .329 .814 r
F P
0 g
s
.68624 .6303 m .70299 .66111 L .70082 .6494 L p 0 .071 .633 r
F P
0 g
s
.70082 .6494 m .6843 .62126 L .68624 .6303 L p 0 .071 .633 r
F P
0 g
s
.3951 .66573 m .40736 .63721 L .42616 .63678 L p .64 .498 .674 r
F P
0 g
s
.40736 .63721 m .425 .61032 L .44082 .61151 L p .631 .538 .73 r
F P
0 g
s
.44082 .61151 m .42616 .63678 L .40736 .63721 L p .631 .538 .73 r
F P
0 g
s
.58271 .50879 m .5857 .53449 L .59017 .53266 L p .481 .317 .582 r
F P
0 g
s
.59017 .53266 m .58736 .50686 L .58271 .50879 L p .481 .317 .582 r
F P
0 g
s
.57778 .35249 m .60236 .37782 L .60101 .37451 L p 0 .213 .737 r
F P
0 g
s
.60101 .37451 m .57682 .35028 L .57778 .35249 L p 0 .213 .737 r
F P
0 g
s
.70681 .70261 m .69843 .72329 L .69926 .70878 L p .918 .881 .458 r
F P
0 g
s
.69926 .70878 m .70782 .68906 L .70681 .70261 L p .918 .881 .458 r
F P
0 g
s
.49243 .54687 m .4912 .51933 L .49669 .52079 L p .751 .466 .5 r
F P
0 g
s
.49669 .52079 m .49786 .54834 L .49243 .54687 L p .751 .466 .5 r
F P
0 g
s
.50238 .68362 m .50295 .66436 L .51241 .67071 L p .915 .676 .563 r
F P
0 g
s
.51241 .67071 m .51207 .69134 L .50238 .68362 L p .915 .676 .563 r
F P
0 g
s
.51368 .64587 m .51241 .67071 L .50295 .66436 L p .883 .738 .697 r
F P
0 g
s
.3951 .66573 m .39164 .69078 L .3686 .6941 L p .649 .439 .585 r
F P
0 g
s
.39164 .69078 m .3951 .66573 L .41592 .66337 L p .625 .418 .582 r
F P
0 g
s
.42616 .63678 m .41592 .66337 L .3951 .66573 L p .64 .498 .674 r
F P
0 g
s
.51368 .64587 m .51549 .62151 L .52398 .62484 L p .872 .782 .76 r
F P
0 g
s
.5244 .6025 m .52398 .62484 L .51549 .62151 L p .868 .817 .797 r
F P
0 g
s
.52398 .62484 m .5244 .6025 L .53257 .60398 L p .864 .808 .792 r
F P
0 g
s
.43883 .48652 m .44461 .45298 L .44755 .45626 L p .945 .721 .568 r
F P
0 g
s
.44755 .45626 m .44198 .48997 L .43883 .48652 L p .945 .721 .568 r
F P
0 g
s
.60276 .40156 m .61522 .44019 L .61638 .43627 L p .063 .092 .579 r
F P
0 g
s
.61638 .43627 m .60364 .39826 L .60276 .40156 L p .063 .092 .579 r
F P
0 g
s
.45296 .3739 m .47656 .3493 L .47549 .35148 L p .849 .985 .706 r
F P
0 g
s
.47549 .35148 m .45143 .37709 L .45296 .3739 L p .849 .985 .706 r
F P
0 g
s
.48683 .54499 m .48571 .51751 L .4912 .51933 L p .748 .466 .505 r
F P
0 g
s
.4912 .51933 m .49243 .54687 L .48683 .54499 L p .748 .466 .505 r
F P
0 g
s
.6023 .45998 m .60489 .49622 L .60741 .4937 L p .245 .118 .501 r
F P
0 g
s
.60741 .4937 m .60515 .45713 L .6023 .45998 L p .245 .118 .501 r
F P
0 g
s
.50295 .66436 m .50508 .64119 L .51368 .64587 L p .883 .738 .697 r
F P
0 g
s
.51549 .62151 m .51368 .64587 L .50508 .64119 L p .861 .781 .771 r
F P
0 g
s
.57682 .35028 m .60101 .37451 L .59933 .37129 L p 0 .181 .715 r
F P
0 g
s
.59933 .37129 m .57565 .34812 L .57682 .35028 L p 0 .181 .715 r
F P
0 g
s
.48106 .5427 m .48024 .51535 L .48571 .51751 L p .749 .472 .512 r
F P
0 g
s
.48571 .51751 m .48683 .54499 L .48106 .5427 L p .749 .472 .512 r
F P
0 g
s
.43529 .43318 m .44868 .39625 L .44932 .39938 L p .986 .89 .557 r
F P
0 g
s
.44932 .39938 m .43586 .43648 L .43529 .43318 L p .986 .89 .557 r
F P
0 g
s
.70299 .66111 m .70782 .68906 L .70551 .67528 L p .701 .468 0 r
F P
0 g
s
.70551 .67528 m .70082 .6494 L .70299 .66111 L p .701 .468 0 r
F P
0 g
s
.40806 .60826 m .42996 .5853 L .44331 .58834 L p .626 .563 .764 r
F P
0 g
s
.44331 .58834 m .425 .61032 L .40806 .60826 L p .626 .563 .764 r
F P
0 g
s
.29696 .61223 m .33272 .58223 L .34384 .58929 L p .763 .713 .805 r
F P
0 g
s
.37966 .56591 m .34384 .58929 L .33272 .58223 L p .718 .714 .845 r
F P
0 g
s
.34384 .58929 m .37966 .56591 L .3905 .57167 L p .701 .675 .821 r
F P
0 g
s
.58736 .50686 m .59017 .53266 L .59402 .5309 L p .429 .27 .563 r
F P
0 g
s
.59402 .5309 m .59162 .50488 L .58736 .50686 L p .429 .27 .563 r
F P
0 g
s
.47512 .54001 m .4748 .51286 L .48024 .51535 L p .754 .482 .521 r
F P
0 g
s
.48024 .51535 m .48106 .5427 L .47512 .54001 L p .754 .482 .521 r
F P
0 g
s
.45479 .37073 m .47784 .34717 L .47656 .3493 L p .801 .974 .679 r
F P
0 g
s
.47656 .3493 m .45296 .3739 L .45479 .37073 L p .801 .974 .679 r
F P
0 g
s
.26469 .6801 m .27216 .64679 L .28717 .65473 L p .855 .636 .606 r
F P
0 g
s
.28717 .65473 m .28022 .6876 L .26469 .6801 L p .855 .636 .606 r
F P
0 g
s
.55942 .56337 m .55624 .54372 L .56274 .54197 L p .737 .59 .692 r
F P
0 g
s
.56274 .54197 m .56697 .56155 L .55942 .56337 L p .737 .59 .692 r
F P
0 g
s
.56697 .56155 m .56274 .54197 L .56905 .54013 L p .699 .571 .707 r
F P
0 g
s
.60646 .57057 m .59264 .55329 L .58731 .55538 L p .569 .634 .875 r
F P
0 g
s
.59264 .55329 m .60646 .57057 L .61109 .56779 L p .489 .595 .886 r
F P
0 g
s
.55186 .56498 m .5497 .54534 L .55624 .54372 L p .769 .603 .673 r
F P
0 g
s
.55624 .54372 m .55942 .56337 L .55186 .56498 L p .769 .603 .673 r
F P
0 g
s
.5445 .56637 m .54755 .5843 L .53915 .58479 L p .855 .749 .746 r
F P
0 g
s
.54755 .5843 m .5445 .56637 L .55186 .56498 L p .829 .741 .767 r
F P
0 g
s
.57565 .34812 m .59933 .37129 L .59733 .36817 L p 0 .144 .682 r
F P
0 g
s
.59733 .36817 m .57426 .34601 L .57565 .34812 L p 0 .144 .682 r
F P
0 g
s
.60364 .39826 m .61638 .43627 L .61724 .4322 L p 0 .049 .564 r
F P
0 g
s
.61724 .4322 m .60422 .3949 L .60364 .39826 L p 0 .049 .564 r
F P
0 g
s
.46906 .53696 m .46944 .51009 L .4748 .51286 L p .762 .497 .532 r
F P
0 g
s
.4748 .51286 m .47512 .54001 L .46906 .53696 L p .762 .497 .532 r
F P
0 g
s
.56905 .54013 m .57428 .55957 L .56697 .56155 L p .699 .571 .707 r
F P
0 g
s
.43622 .48317 m .44206 .44968 L .44461 .45298 L p .972 .756 .553 r
F P
0 g
s
.44461 .45298 m .43883 .48652 L .43622 .48317 L p .972 .756 .553 r
F P
0 g
s
.57428 .55957 m .56905 .54013 L .57506 .53825 L p .653 .545 .719 r
F P
0 g
s
.57506 .53825 m .58114 .5575 L .57428 .55957 L p .653 .545 .719 r
F P
0 g
s
.5445 .56637 m .54322 .5468 L .5497 .54534 L p .794 .61 .653 r
F P
0 g
s
.5497 .54534 m .55186 .56498 L .5445 .56637 L p .794 .61 .653 r
F P
0 g
s
.53152 .58495 m .53257 .60398 L .5244 .6025 L p .879 .819 .785 r
F P
0 g
s
.53257 .60398 m .53152 .58495 L .53915 .58479 L p .864 .808 .793 r
F P
0 g
s
.60515 .45713 m .60741 .4937 L .60971 .49097 L p .185 .071 .48 r
F P
0 g
s
.60971 .49097 m .60771 .45411 L .60515 .45713 L p .185 .071 .48 r
F P
0 g
s
.45692 .36762 m .47933 .34508 L .47784 .34717 L p .739 .951 .644 r
F P
0 g
s
.47784 .34717 m .45479 .37073 L .45692 .36762 L p .739 .951 .644 r
F P
0 g
s
.46298 .5336 m .46418 .50707 L .46944 .51009 L p .774 .516 .544 r
F P
0 g
s
.46944 .51009 m .46906 .53696 L .46298 .5336 L p .774 .516 .544 r
F P
0 g
s
.41592 .66337 m .42616 .63678 L .44302 .63578 L p .627 .489 .675 r
F P
0 g
s
.42616 .63678 m .44082 .61151 L .45505 .61209 L p .62 .53 .731 r
F P
0 g
s
.45505 .61209 m .44302 .63578 L .42616 .63678 L p .62 .53 .731 r
F P
0 g
s
.26162 .6373 m .28758 .60349 L .29696 .61223 L p .852 .76 .761 r
F P
0 g
s
.29696 .61223 m .27216 .64679 L .26162 .6373 L p .852 .76 .761 r
F P
0 g
s
.33272 .58223 m .29696 .61223 L .28758 .60349 L p .787 .766 .834 r
F P
0 g
s
.43509 .42985 m .44836 .39309 L .44868 .39625 L p .964 .893 .515 r
F P
0 g
s
.44868 .39625 m .43529 .43318 L .43509 .42985 L p .964 .893 .515 r
F P
0 g
s
.57506 .53825 m .58114 .5575 L .58731 .55538 L p .603 .513 .726 r
F P
0 g
s
.58731 .55538 m .58064 .53635 L .57506 .53825 L p .603 .513 .726 r
F P
0 g
s
.41592 .66337 m .41308 .68646 L .39164 .69078 L p .625 .418 .582 r
F P
0 g
s
.41308 .68646 m .41592 .66337 L .43458 .66055 L p .608 .405 .581 r
F P
0 g
s
.44302 .63578 m .43458 .66055 L .41592 .66337 L p .627 .489 .675 r
F P
0 g
s
.63559 .58364 m .61416 .56509 L .61109 .56779 L p .372 .602 .937 r
F P
0 g
s
.61416 .56509 m .63559 .58364 L .63665 .57949 L p .228 .538 .925 r
F P
0 g
s
.66209 .60201 m .63665 .57949 L .63559 .58364 L p .228 .516 .912 r
F P
0 g
s
.63665 .57949 m .66209 .60201 L .66056 .59574 L p .058 .437 .874 r
F P
0 g
s
.6843 .62126 m .66056 .59574 L .66209 .60201 L p 0 .329 .814 r
F P
0 g
s
.53749 .5675 m .53689 .54805 L .54322 .5468 L p .815 .613 .629 r
F P
0 g
s
.54322 .5468 m .5445 .56637 L .53749 .5675 L p .815 .613 .629 r
F P
0 g
s
.57426 .34601 m .59733 .36817 L .59502 .36519 L p 0 .105 .638 r
F P
0 g
s
.59502 .36519 m .57268 .34397 L .57426 .34601 L p 0 .105 .638 r
F P
0 g
s
.59162 .50488 m .59402 .5309 L .59725 .52918 L p .371 .216 .537 r
F P
0 g
s
.59725 .52918 m .59549 .50286 L .59162 .50488 L p .371 .216 .537 r
F P
0 g
s
.457 .53 m .45911 .50384 L .46418 .50707 L p .791 .539 .556 r
F P
0 g
s
.46418 .50707 m .46298 .5336 L .457 .53 L p .791 .539 .556 r
F P
0 g
s
.425 .61032 m .44331 .58834 L .45584 .59068 L p .611 .547 .758 r
F P
0 g
s
.45584 .59068 m .44082 .61151 L .425 .61032 L p .611 .547 .758 r
F P
0 g
s
.45933 .36457 m .48101 .34306 L .47933 .34508 L p .663 .915 .601 r
F P
0 g
s
.47933 .34508 m .45692 .36762 L .45933 .36457 L p .663 .915 .601 r
F P
0 g
s
.60422 .3949 m .61724 .4322 L .61777 .42802 L p 0 .002 .544 r
F P
0 g
s
.61777 .42802 m .60449 .39149 L .60422 .3949 L p 0 .002 .544 r
F P
0 g
s
.33093 .71737 m .3214 .69546 L .34483 .69582 L p .669 .344 .414 r
F P
0 g
s
.34483 .69582 m .35333 .71605 L .33093 .71737 L p .669 .344 .414 r
F P
0 g
s
.35333 .71605 m .34483 .69582 L .3686 .6941 L p .627 .316 .424 r
F P
0 g
s
.43417 .47994 m .43991 .44638 L .44206 .44968 L p .993 .788 .524 r
F P
0 g
s
.44206 .44968 m .43622 .48317 L .43417 .47994 L p .993 .788 .524 r
F P
0 g
s
.5924 .36234 m .5709 .34201 L .57268 .34397 L p 0 .064 .581 r
F P
0 g
s
.5709 .34201 m .5924 .36234 L .58949 .35964 L p 0 .023 .515 r
F P
0 g
s
.58949 .35964 m .56892 .34013 L .57066 .34178 L p 0 .023 .515 r
F P
0 g
s
.57066 .34178 m .5709 .34201 L p .57204 .34309 L 0 .023 .515 r
F P
0 g
s
.58949 .35964 m .57066 .34178 L .57204 .34309 L 0 .023 .515 r
F
.57268 .34397 m .59502 .36519 L .59301 .363 L p 0 .064 .581 r
F P
0 g
s
.59301 .363 m .5924 .36234 L p .58776 .35802 L 0 .064 .581 r
F P
0 g
s
.58776 .35802 m .57268 .34397 L .59301 .363 L 0 .064 .581 r
F
.53094 .56836 m .53077 .54905 L .53689 .54805 L p .829 .609 .605 r
F P
0 g
s
.53689 .54805 m .53749 .5675 L .53094 .56836 L p .829 .609 .605 r
F P
0 g
s
.58064 .53635 m .58731 .55538 L .59264 .55329 L p .551 .476 .724 r
F P
0 g
s
.59264 .55329 m .5857 .53449 L .58064 .53635 L p .551 .476 .724 r
F P
0 g
s
.45127 .52621 m .45428 .50046 L .45911 .50384 L p .811 .566 .568 r
F P
0 g
s
.45911 .50384 m .457 .53 L .45127 .52621 L p .811 .566 .568 r
F P
0 g
s
.60771 .45411 m .60971 .49097 L .61181 .48797 L p .121 .022 .458 r
F P
0 g
s
.61181 .48797 m .61 .45091 L .60771 .45411 L p .121 .022 .458 r
F P
0 g
s
.30997 .71618 m .29948 .69275 L .3214 .69546 L p .717 .373 .394 r
F P
0 g
s
.3214 .69546 m .33093 .71737 L .30997 .71618 L p .717 .373 .394 r
F P
0 g
s
.3686 .6941 m .37605 .71258 L .35333 .71605 L p .627 .316 .424 r
F P
0 g
s
.37605 .71258 m .3686 .6941 L .39164 .69078 L p .59 .289 .426 r
F P
0 g
s
.28758 .60349 m .32497 .57472 L .33272 .58223 L p .787 .766 .834 r
F P
0 g
s
.37096 .55986 m .33272 .58223 L .32497 .57472 L p .733 .76 .874 r
F P
0 g
s
.33272 .58223 m .37096 .55986 L .37966 .56591 L p .718 .714 .845 r
F P
0 g
s
.43525 .42649 m .44835 .38991 L .44836 .39309 L p .924 .883 .463 r
F P
0 g
s
.44836 .39309 m .43509 .42985 L .43525 .42649 L p .924 .883 .463 r
F P
0 g
s
.46204 .3616 m .48289 .34112 L .48101 .34306 L p .575 .866 .55 r
F P
0 g
s
.48101 .34306 m .45933 .36457 L .46204 .3616 L p .575 .866 .55 r
F P
0 g
s
.50355 .6952 m .50238 .68362 L .51207 .69134 L p .916 .529 .255 r
F P
0 g
s
.51207 .69134 m .51276 .70373 L .50355 .6952 L p .916 .529 .255 r
F P
0 g
s
.69397 .73666 m .67503 .74465 L .67888 .73153 L p .896 .974 .817 r
F P
0 g
s
.67888 .73153 m .69843 .72329 L .69397 .73666 L p .896 .974 .817 r
F P
0 g
s
.49346 .67789 m .49424 .65956 L .50295 .66436 L p .886 .651 .578 r
F P
0 g
s
.50295 .66436 m .50238 .68362 L .49346 .67789 L p .886 .651 .578 r
F P
0 g
s
.50508 .64119 m .50295 .66436 L .49424 .65956 L p .854 .717 .711 r
F P
0 g
s
.53749 .5675 m .53915 .58479 L .53152 .58495 L p .876 .753 .723 r
F P
0 g
s
.53915 .58479 m .53749 .5675 L .5445 .56637 L p .855 .749 .746 r
F P
0 g
s
.59549 .50286 m .59725 .52918 L .59991 .52749 L p .305 .154 .505 r
F P
0 g
s
.59991 .52749 m .59897 .50076 L .59549 .50286 L p .305 .154 .505 r
F P
0 g
s
.44592 .52235 m .44977 .49698 L .45428 .50046 L p .836 .598 .578 r
F P
0 g
s
.45428 .50046 m .45127 .52621 L .44592 .52235 L p .836 .598 .578 r
F P
0 g
s
.52487 .56894 m .5249 .54979 L .53077 .54905 L p .836 .598 .579 r
F P
0 g
s
.53077 .54905 m .53094 .56836 L .52487 .56894 L p .836 .598 .579 r
F P
0 g
s
.50508 .64119 m .50808 .61852 L .51549 .62151 L p .861 .781 .771 r
F P
0 g
s
.51731 .60093 m .51549 .62151 L .50808 .61852 L p .857 .813 .806 r
F P
0 g
s
.51549 .62151 m .51731 .60093 L .5244 .6025 L p .868 .817 .797 r
F P
0 g
s
.42759 .55926 m .40293 .57691 L .3905 .57167 L p .662 .633 .81 r
F P
0 g
s
.40293 .57691 m .42759 .55926 L .43757 .56376 L p .645 .602 .79 r
F P
0 g
s
.43757 .56376 m .4163 .58148 L .40293 .57691 L p .645 .602 .79 r
F P
0 g
s
.58395 .759 m .59537 .76704 L .61254 .77127 L p .017 .543 .856 r
F P
0 g
s
.59821 .76324 m .61254 .77127 L .62915 .77231 L p .235 .709 .94 r
F P
0 g
s
.60449 .39149 m .61777 .42802 L .61796 .42376 L p 0 0 .517 r
F P
0 g
s
.61796 .42376 m .60444 .38805 L .60449 .39149 L p 0 0 .517 r
F P
0 g
s
.61109 .56779 m .597 .55127 L .59264 .55329 L p .489 .595 .886 r
F P
0 g
s
.597 .55127 m .61109 .56779 L .61416 .56509 L p .385 .54 .886 r
F P
0 g
s
.49424 .65956 m .49714 .63756 L .50508 .64119 L p .854 .717 .711 r
F P
0 g
s
.50808 .61852 m .50508 .64119 L .49714 .63756 L p .831 .76 .784 r
F P
0 g
s
.46501 .35874 m .48495 .33925 L .48289 .34112 L p 0 0 0 r
F P
0 g
s
.48289 .34112 m .46204 .3616 L .46501 .35874 L p 0 0 0 r
F P
0 g
s
.41832 .55441 m .3905 .57167 L .37966 .56591 L p .678 .668 .834 r
F P
0 g
s
.3905 .57167 m .41832 .55441 L .42759 .55926 L p .662 .633 .81 r
F P
0 g
s
.43458 .66055 m .44302 .63578 L .45764 .63469 L p .625 .491 .68 r
F P
0 g
s
.44302 .63578 m .45505 .61209 L .46742 .61236 L p .618 .534 .737 r
F P
0 g
s
.46742 .61236 m .45764 .63469 L .44302 .63578 L p .618 .534 .737 r
F P
0 g
s
.43458 .66055 m .43227 .68185 L .41308 .68646 L p .608 .405 .581 r
F P
0 g
s
.43227 .68185 m .43458 .66055 L .45073 .65791 L p .604 .403 .582 r
F P
0 g
s
.45764 .63469 m .45073 .65791 L .43458 .66055 L p .625 .491 .68 r
F P
0 g
s
.56985 .7522 m .5784 .76 L .59537 .76704 L p 0 .388 .77 r
F P
0 g
s
.43268 .47684 m .43816 .44308 L .43991 .44638 L p .999 .811 .477 r
F P
0 g
s
.43991 .44638 m .43417 .47994 L .43268 .47684 L p .999 .811 .477 r
F P
0 g
s
.5857 .53449 m .59264 .55329 L .597 .55127 L p .486 .425 .714 r
F P
0 g
s
.597 .55127 m .59017 .53266 L .5857 .53449 L p .486 .425 .714 r
F P
0 g
s
.4163 .58148 m .43757 .56376 L .44781 .5678 L p .629 .573 .773 r
F P
0 g
s
.44781 .5678 m .42996 .5853 L .4163 .58148 L p .629 .573 .773 r
F P
0 g
s
.62915 .77231 m .61199 .76455 L .59821 .76324 L p .235 .709 .94 r
F P
0 g
s
.61199 .76455 m .62915 .77231 L .64437 .77001 L p .461 .84 .987 r
F P
0 g
s
.39164 .69078 m .39807 .70752 L .37605 .71258 L p .59 .289 .426 r
F P
0 g
s
.39807 .70752 m .39164 .69078 L .41308 .68646 L p .558 .263 .424 r
F P
0 g
s
.56892 .34013 m .58949 .35964 L .58629 .35711 L p .548 .016 0 r
F P
0 g
s
.58629 .35711 m .56677 .33834 L .56892 .34013 L p .548 .016 0 r
F P
0 g
s
.25379 .67053 m .26162 .6373 L .27216 .64679 L p .924 .715 .602 r
F P
0 g
s
.27216 .64679 m .26469 .6801 L .25379 .67053 L p .924 .715 .602 r
F P
0 g
s
.61 .45091 m .61181 .48797 L .61377 .48468 L p .053 0 .434 r
F P
0 g
s
.61377 .48468 m .61202 .44752 L .61 .45091 L p .053 0 .434 r
F P
0 g
s
.43574 .42308 m .44866 .38671 L .44835 .38991 L p .867 .857 .403 r
F P
0 g
s
.44835 .38991 m .43525 .42649 L .43574 .42308 L p .867 .857 .403 r
F P
0 g
s
.29159 .7123 m .28022 .6876 L .29948 .69275 L p .774 .403 .354 r
F P
0 g
s
.29948 .69275 m .30997 .71618 L .29159 .7123 L p .774 .403 .354 r
F P
0 g
s
.44082 .61151 m .45584 .59068 L .46718 .59242 L p .601 .539 .757 r
F P
0 g
s
.46718 .59242 m .45505 .61209 L .44082 .61151 L p .601 .539 .757 r
F P
0 g
s
.44111 .51848 m .44565 .49347 L .44977 .49698 L p .866 .635 .587 r
F P
0 g
s
.44977 .49698 m .44592 .52235 L .44111 .51848 L p .866 .635 .587 r
F P
0 g
s
.46826 .35601 m .48718 .33748 L .48495 .33925 L p 0 0 0 r
F P
0 g
s
.48495 .33925 m .46501 .35874 L .46826 .35601 L p 0 0 0 r
F P
0 g
s
.51925 .56924 m .51926 .55021 L .5249 .54979 L p .836 .58 .553 r
F P
0 g
s
.5249 .54979 m .52487 .56894 L .51925 .56924 L p .836 .58 .553 r
F P
0 g
s
.52471 .58483 m .5244 .6025 L .51731 .60093 L p .884 .822 .781 r
F P
0 g
s
.5244 .6025 m .52471 .58483 L .53152 .58495 L p .879 .819 .785 r
F P
0 g
s
.56677 .33834 m .58629 .35711 L .58284 .35474 L p .597 .05 0 r
F P
0 g
s
.58284 .35474 m .56445 .33665 L .56677 .33834 L p .597 .05 0 r
F P
0 g
s
.60444 .38805 m .61796 .42376 L .61777 .41947 L p 0 0 .48 r
F P
0 g
s
.61777 .41947 m .60407 .38461 L .60444 .38805 L p 0 0 .48 r
F P
0 g
s
.4102 .54938 m .37966 .56591 L .37096 .55986 L p .691 .708 .861 r
F P
0 g
s
.37966 .56591 m .4102 .54938 L .41832 .55441 L p .678 .668 .834 r
F P
0 g
s
.59897 .50076 m .59991 .52749 L .6021 .52577 L p .233 .085 .466 r
F P
0 g
s
.6021 .52577 m .60209 .49855 L .59897 .50076 L p .233 .085 .466 r
F P
0 g
s
.47177 .35343 m .48959 .33581 L .48718 .33748 L p 0 0 0 r
F P
0 g
s
.48718 .33748 m .46826 .35601 L .47177 .35343 L p 0 0 0 r
F P
0 g
s
.42996 .5853 m .44781 .5678 L .45789 .57132 L p .613 .549 .758 r
F P
0 g
s
.45789 .57132 m .44331 .58834 L .42996 .5853 L p .613 .549 .758 r
F P
0 g
s
.53152 .58495 m .53094 .56836 L .53749 .5675 L p .876 .753 .723 r
F P
0 g
s
.55647 .74338 m .56233 .7507 L .5784 .76 L p 0 .27 .708 r
F P
0 g
s
.51398 .56924 m .5138 .55031 L .51926 .55021 L p .825 .555 .53 r
F P
0 g
s
.51926 .55021 m .51925 .56924 L .51398 .56924 L p .825 .555 .53 r
F P
0 g
s
.66056 .59574 m .6843 .62126 L .68015 .61268 L p 0 .229 .736 r
F P
0 g
s
.6843 .62126 m .70082 .6494 L .69619 .63814 L p 0 0 .498 r
F P
0 g
s
.69619 .63814 m .68015 .61268 L .6843 .62126 L p 0 0 .498 r
F P
0 g
s
.70782 .68906 m .69926 .70878 L .69692 .6939 L p .99 .877 .54 r
F P
0 g
s
.69692 .6939 m .70551 .67528 L .70782 .68906 L p .99 .877 .54 r
F P
0 g
s
.56445 .33665 m .58284 .35474 L .57914 .35254 L p .633 .079 0 r
F P
0 g
s
.57914 .35254 m .56196 .33507 L .56445 .33665 L p .633 .079 0 r
F P
0 g
s
.25613 .62669 m .28274 .59417 L .28758 .60349 L p .895 .845 .788 r
F P
0 g
s
.28758 .60349 m .26162 .6373 L .25613 .62669 L p .895 .845 .788 r
F P
0 g
s
.32497 .57472 m .28758 .60349 L .28274 .59417 L p .808 .83 .867 r
F P
0 g
s
.43173 .47387 m .43681 .43978 L .43816 .44308 L p .977 .814 .403 r
F P
0 g
s
.43816 .44308 m .43268 .47684 L .43173 .47387 L p .977 .814 .403 r
F P
0 g
s
.64437 .77001 m .62462 .76278 L .6355 .75795 L p .63 .904 .984 r
F P
0 g
s
.6355 .75795 m .65748 .76442 L .64437 .77001 L p .63 .904 .984 r
F P
0 g
s
.64437 .77001 m .62462 .76278 L .61199 .76455 L p .461 .84 .987 r
F P
0 g
s
.43698 .5147 m .44198 .48997 L .44565 .49347 L p .901 .678 .591 r
F P
0 g
s
.44565 .49347 m .44111 .51848 L .43698 .5147 L p .901 .678 .591 r
F P
0 g
s
.59017 .53266 m .597 .55127 L .60035 .54937 L p .407 .358 .692 r
F P
0 g
s
.60035 .54937 m .59402 .5309 L .59017 .53266 L p .407 .358 .692 r
F P
0 g
s
.43655 .41959 m .44927 .3835 L .44866 .38671 L p .794 .816 .336 r
F P
0 g
s
.44866 .38671 m .43574 .42308 L .43655 .41959 L p .794 .816 .336 r
F P
0 g
s
.61202 .44752 m .61377 .48468 L .61558 .48107 L p 0 0 .408 r
F P
0 g
s
.61558 .48107 m .61376 .44395 L .61202 .44752 L p 0 0 .408 r
F P
0 g
s
.47553 .35103 m .49215 .33424 L .48959 .33581 L p 0 0 0 r
F P
0 g
s
.48959 .33581 m .47177 .35343 L .47553 .35103 L p 0 0 0 r
F P
0 g
s
.41308 .68646 m .41854 .70157 L .39807 .70752 L p .558 .263 .424 r
F P
0 g
s
.41854 .70157 m .41308 .68646 L .43227 .68185 L p .533 .241 .416 r
F P
0 g
s
.53094 .56836 m .53152 .58495 L .52471 .58483 L p .89 .75 .7 r
F P
0 g
s
.48446 .67449 m .48545 .65658 L .49424 .65956 L p .823 .596 .595 r
F P
0 g
s
.49424 .65956 m .49346 .67789 L .48446 .67449 L p .823 .596 .595 r
F P
0 g
s
.49714 .63756 m .49424 .65956 L .48545 .65658 L p .8 .671 .721 r
F P
0 g
s
.45073 .65791 m .44887 .67769 L .43227 .68185 L p .604 .403 .582 r
F P
0 g
s
.44887 .67769 m .45073 .65791 L .46435 .65603 L p .62 .418 .587 r
F P
0 g
s
.45073 .65791 m .45764 .63469 L .46998 .63396 L p .639 .51 .69 r
F P
0 g
s
.46998 .63396 m .46435 .65603 L .45073 .65791 L p .639 .51 .69 r
F P
0 g
s
.45764 .63469 m .46742 .61236 L .47791 .61265 L p .631 .554 .749 r
F P
0 g
s
.47791 .61265 m .46998 .63396 L .45764 .63469 L p .631 .554 .749 r
F P
0 g
s
.56196 .33507 m .57914 .35254 L .57521 .35051 L p .656 .101 0 r
F P
0 g
s
.57521 .35051 m .55932 .3336 L .56196 .33507 L p .656 .101 0 r
F P
0 g
s
.60407 .38461 m .61777 .41947 L .61718 .41519 L p 0 0 .431 r
F P
0 g
s
.61718 .41519 m .60338 .3812 L .60407 .38461 L p 0 0 .431 r
F P
0 g
s
.28274 .59417 m .32101 .56711 L .32497 .57472 L p .808 .83 .867 r
F P
0 g
s
.36489 .55375 m .32497 .57472 L .32101 .56711 L p .742 .813 .908 r
F P
0 g
s
.32497 .57472 m .36489 .55375 L .37096 .55986 L p .733 .76 .874 r
F P
0 g
s
.48545 .65658 m .48914 .63516 L .49714 .63756 L p .8 .671 .721 r
F P
0 g
s
.50123 .6161 m .49714 .63756 L .48914 .63516 L p .78 .714 .79 r
F P
0 g
s
.49714 .63756 m .50123 .6161 L .50808 .61852 L p .831 .76 .784 r
F P
0 g
s
.5089 .56893 m .50847 .55004 L .5138 .55031 L p .806 .525 .512 r
F P
0 g
s
.5138 .55031 m .51398 .56924 L .5089 .56893 L p .806 .525 .512 r
F P
0 g
s
.63665 .57949 m .61573 .56257 L .61416 .56509 L p .228 .538 .925 r
F P
0 g
s
.61573 .56257 m .63665 .57949 L .63586 .5756 L p .059 .45 .879 r
F P
0 g
s
.66056 .59574 m .63586 .5756 L .63665 .57949 L p .058 .437 .874 r
F P
0 g
s
.51276 .70373 m .52337 .71395 L p .51545 .70748 L .67 .181 0 r
F P
0 g
s
.52337 .71395 m .52371 .71691 L .51428 .70653 L p .67 .181 0 r
F P
0 g
s
.52413 .71186 m .51614 .7023 L p .52262 .71481 L 0 .219 .736 r
F P
0 g
s
.52371 .71691 m .52378 .71599 L p .52262 .71481 L 0 .219 .736 r
F P
0 g
s
.52378 .71599 m .52413 .71186 L p .52262 .71481 L 0 .219 .736 r
F P
0 g
s
.51428 .70653 m .51399 .706 L p .51545 .70748 L .67 .181 0 r
F P
0 g
s
.51399 .706 m .51276 .70373 L p .51545 .70748 L .67 .181 0 r
F P
0 g
s
.47952 .34882 m .49486 .3328 L .49215 .33424 L p 0 0 0 r
F P
0 g
s
.49215 .33424 m .47553 .35103 L .47952 .34882 L p 0 0 0 r
F P
0 g
s
.49508 .68897 m .49346 .67789 L .50238 .68362 L p .886 .485 .256 r
F P
0 g
s
.50238 .68362 m .50355 .6952 L .49508 .68897 L p .886 .485 .256 r
F P
0 g
s
.55932 .3336 m .57521 .35051 L .57108 .34865 L p .668 .117 0 r
F P
0 g
s
.57108 .34865 m .55654 .33224 L .55932 .3336 L p .668 .117 0 r
F P
0 g
s
.45505 .61209 m .46718 .59242 L .47714 .59374 L p .6 .542 .761 r
F P
0 g
s
.47714 .59374 m .46742 .61236 L .45505 .61209 L p .6 .542 .761 r
F P
0 g
s
.51104 .59941 m .50808 .61852 L .50123 .6161 L p .825 .788 .817 r
F P
0 g
s
.50808 .61852 m .51104 .59941 L .51731 .60093 L p .857 .813 .806 r
F P
0 g
s
.70082 .6494 m .70551 .67528 L .70068 .66191 L p .877 .585 .066 r
F P
0 g
s
.70068 .66191 m .69619 .63814 L .70082 .6494 L p .877 .585 .066 r
F P
0 g
s
.60209 .49855 m .6021 .52577 L .60393 .52397 L p .156 .013 .422 r
F P
0 g
s
.60393 .52397 m .60489 .49622 L .60209 .49855 L p .156 .013 .422 r
F P
0 g
s
.61416 .56509 m .60035 .54937 L .597 .55127 L p .385 .54 .886 r
F P
0 g
s
.40363 .54433 m .37096 .55986 L .36489 .55375 L p .702 .753 .892 r
F P
0 g
s
.37096 .55986 m .40363 .54433 L .4102 .54938 L p .691 .708 .861 r
F P
0 g
s
.44331 .58834 m .45789 .57132 L .46745 .57429 L p .6 .529 .746 r
F P
0 g
s
.46745 .57429 m .45584 .59068 L .44331 .58834 L p .6 .529 .746 r
F P
0 g
s
.43362 .5111 m .43883 .48652 L .44198 .48997 L p .94 .728 .588 r
F P
0 g
s
.44198 .48997 m .43698 .5147 L .43362 .5111 L p .94 .728 .588 r
F P
0 g
s
.60035 .54937 m .61416 .56509 L .61573 .56257 L p .25 .459 .868 r
F P
0 g
s
.52471 .58483 m .52487 .56894 L .53094 .56836 L p .89 .75 .7 r
F P
0 g
s
.48373 .34682 m .4977 .33148 L .49486 .3328 L p .036 0 0 r
F P
0 g
s
.49486 .3328 m .47952 .34882 L .48373 .34682 L p .036 0 0 r
F P
0 g
s
.43767 .41603 m .4502 .38029 L .44927 .3835 L p .71 .764 .267 r
F P
0 g
s
.44927 .3835 m .43655 .41959 L .43757 .41633 L p .71 .764 .267 r
F P
0 g
s
.44927 .3835 m .43757 .41633 L .43842 .41391 L .71 .764 .267 r
F
.43909 .41239 m .45143 .37709 L .45071 .37895 L p 0 0 0 r
F P
0 g
s
.45071 .37895 m .4502 .38029 L p .44744 .38826 L 0 0 0 r
F P
0 g
s
.44744 .38826 m .43909 .41239 L .45071 .37895 L 0 0 0 r
F
.43757 .41633 m .43767 .41603 L p .43842 .41391 L .71 .764 .267 r
F P
0 g
s
.50385 .56828 m .50318 .54939 L .50847 .55004 L p .779 .493 .502 r
F P
0 g
s
.50847 .55004 m .5089 .56893 L .50385 .56828 L p .779 .493 .502 r
F P
0 g
s
.2768 .70576 m .26469 .6801 L .28022 .6876 L p .839 .431 .269 r
F P
0 g
s
.28022 .6876 m .29159 .7123 L .2768 .70576 L p .839 .431 .269 r
F P
0 g
s
.61376 .44395 m .61558 .48107 L .61727 .47714 L p 0 0 .381 r
F P
0 g
s
.61727 .47714 m .61522 .44019 L .61376 .44395 L p 0 0 .381 r
F P
0 g
s
.43128 .471 m .43586 .43648 L .43681 .43978 L p .915 .784 .303 r
F P
0 g
s
.43681 .43978 m .43173 .47387 L .43128 .471 L p .915 .784 .303 r
F P
0 g
s
.55654 .33224 m .57108 .34865 L .56676 .34696 L p .672 .127 0 r
F P
0 g
s
.56676 .34696 m .55363 .33101 L .55654 .33224 L p .672 .127 0 r
F P
0 g
s
.54425 .73319 m .54768 .73986 L .56233 .7507 L p 0 .197 .676 r
F P
0 g
s
.63586 .5756 m .66056 .59574 L .65722 .5899 L p 0 .35 .805 r
F P
0 g
s
.68015 .61268 m .65722 .5899 L .66056 .59574 L p 0 .229 .736 r
F P
0 g
s
.46435 .65603 m .46285 .6747 L .44887 .67769 L p .62 .418 .587 r
F P
0 g
s
.46285 .6747 m .46435 .65603 L .47574 .65547 L p .664 .457 .594 r
F P
0 g
s
.46435 .65603 m .46998 .63396 L .48031 .63402 L p .675 .549 .704 r
F P
0 g
s
.48031 .63402 m .47574 .65547 L .46435 .65603 L p .675 .549 .704 r
F P
0 g
s
.60338 .3812 m .61718 .41519 L .61619 .41098 L p 0 0 .368 r
F P
0 g
s
.61619 .41098 m .60236 .37782 L .60338 .3812 L p 0 0 .368 r
F P
0 g
s
.59402 .5309 m .60035 .54937 L .60271 .54761 L p .31 .272 .653 r
F P
0 g
s
.60271 .54761 m .59725 .52918 L .59402 .5309 L p .31 .272 .653 r
F P
0 g
s
.48813 .34505 m .50067 .33029 L .4977 .33148 L p .12 0 0 r
F P
0 g
s
.4977 .33148 m .48373 .34682 L .48813 .34505 L p .12 0 0 r
F P
0 g
s
.46998 .63396 m .47791 .61265 L .48674 .61323 L p .665 .594 .766 r
F P
0 g
s
.48674 .61323 m .48031 .63402 L .46998 .63396 L p .665 .594 .766 r
F P
0 g
s
.47452 .67349 m .47574 .65547 L .48545 .65658 L p .739 .522 .6 r
F P
0 g
s
.48545 .65658 m .48446 .67449 L .47452 .67349 L p .739 .522 .6 r
F P
0 g
s
.48914 .63516 m .48545 .65658 L .47574 .65547 L p .733 .608 .718 r
F P
0 g
s
.49863 .56728 m .49786 .54834 L .50318 .54939 L p .75 .464 .499 r
F P
0 g
s
.50318 .54939 m .50385 .56828 L .49863 .56728 L p .75 .464 .499 r
F P
0 g
s
.43227 .68185 m .43684 .69552 L .41854 .70157 L p .533 .241 .416 r
F P
0 g
s
.43684 .69552 m .43227 .68185 L .44887 .67769 L p .522 .225 .405 r
F P
0 g
s
.55363 .33101 m .56676 .34696 L .56226 .34544 L p .669 .131 0 r
F P
0 g
s
.56226 .34544 m .5506 .3299 L .55363 .33101 L p .669 .131 0 r
F P
0 g
s
.47574 .65547 m .48031 .63402 L .48914 .63516 L p .733 .608 .718 r
F P
0 g
s
.49432 .61434 m .48914 .63516 L .48031 .63402 L p .718 .652 .783 r
F P
0 g
s
.48914 .63516 m .49432 .61434 L .50123 .6161 L p .78 .714 .79 r
F P
0 g
s
.48813 .34505 m .50067 .33029 L .50376 .32923 L p .192 0 0 r
F P
0 g
s
.49309 .56588 m .49243 .54687 L .49786 .54834 L p .723 .445 .504 r
F P
0 g
s
.49786 .54834 m .49863 .56728 L .49309 .56588 L p .723 .445 .504 r
F P
0 g
s
.51864 .5845 m .51731 .60093 L .51104 .59941 L p .876 .811 .782 r
F P
0 g
s
.51731 .60093 m .51864 .5845 L .52471 .58483 L p .884 .822 .781 r
F P
0 g
s
.47574 .65547 m .47452 .67349 L .46285 .6747 L p .664 .457 .594 r
F P
0 g
s
.65748 .76442 m .6355 .75795 L .6441 .75031 L p .737 .918 .954 r
F P
0 g
s
.6441 .75031 m .66784 .75582 L .65748 .76442 L p .737 .918 .954 r
F P
0 g
s
.45868 .55235 m .46298 .5336 L .46906 .53696 L p .706 .494 .598 r
F P
0 g
s
.46906 .53696 m .46629 .55592 L .45868 .55235 L p .706 .494 .598 r
F P
0 g
s
.46629 .55592 m .46906 .53696 L .47512 .54001 L p .696 .469 .574 r
F P
0 g
s
.48711 .56406 m .48683 .54499 L .49243 .54687 L p .704 .436 .516 r
F P
0 g
s
.49243 .54687 m .49309 .56588 L .48711 .56406 L p .704 .436 .516 r
F P
0 g
s
.47512 .54001 m .47366 .55908 L .46629 .55592 L p .696 .469 .574 r
F P
0 g
s
.47366 .55908 m .47512 .54001 L .48106 .5427 L p .691 .45 .553 r
F P
0 g
s
.5506 .3299 m .56226 .34544 L .55762 .34408 L p .661 .131 0 r
F P
0 g
s
.55762 .34408 m .54747 .32893 L .5506 .3299 L p .661 .131 0 r
F P
0 g
s
.48031 .63402 m .48674 .61323 L .49432 .61434 L p .718 .652 .783 r
F P
0 g
s
.48106 .5427 m .48063 .56179 L .47366 .55908 L p .691 .45 .553 r
F P
0 g
s
.48063 .56179 m .48106 .5427 L .48683 .54499 L p .693 .438 .533 r
F P
0 g
s
.48683 .54499 m .48711 .56406 L .48063 .56179 L p .693 .438 .533 r
F P
0 g
s
.45106 .54843 m .457 .53 L .46298 .5336 L p .722 .523 .622 r
F P
0 g
s
.46298 .5336 m .45868 .55235 L .45106 .54843 L p .722 .523 .622 r
F P
0 g
s
.4502 .38029 m .43767 .41603 L .43909 .41239 L p 0 0 0 r
F P
0 g
s
.49271 .34351 m .50376 .32923 L .50694 .32832 L p .253 0 0 r
F P
0 g
s
.50376 .32923 m .49271 .34351 L .48813 .34505 L p .192 0 0 r
F P
0 g
s
.43112 .50775 m .43622 .48317 L .43883 .48652 L p .979 .782 .567 r
F P
0 g
s
.43883 .48652 m .43362 .5111 L .43112 .50775 L p .979 .782 .567 r
F P
0 g
s
.44367 .54424 m .42759 .55926 L .41832 .55441 L p .684 .616 .773 r
F P
0 g
s
.42759 .55926 m .44367 .54424 L .45106 .54843 L p .668 .579 .746 r
F P
0 g
s
.45106 .54843 m .43757 .56376 L .42759 .55926 L p .668 .579 .746 r
F P
0 g
s
.69843 .72329 m .67888 .73153 L .67953 .71718 L p .925 .925 .79 r
F P
0 g
s
.67953 .71718 m .69926 .70878 L .69843 .72329 L p .925 .925 .79 r
F P
0 g
s
.60489 .49622 m .60393 .52397 L .60553 .52201 L p .078 0 .375 r
F P
0 g
s
.60553 .52201 m .60741 .4937 L .60489 .49622 L p .078 0 .375 r
F P
0 g
s
.44367 .54424 m .45127 .52621 L .457 .53 L p .74 .558 .646 r
F P
0 g
s
.457 .53 m .45106 .54843 L .44367 .54424 L p .74 .558 .646 r
F P
0 g
s
.52487 .56894 m .52471 .58483 L .51864 .5845 L p .895 .737 .678 r
F P
0 g
s
.24813 .65933 m .25613 .62669 L .26162 .6373 L p .992 .814 .564 r
F P
0 g
s
.26162 .6373 m .25379 .67053 L .24813 .65933 L p .992 .814 .564 r
F P
0 g
s
.54747 .32893 m .55762 .34408 L .55285 .34288 L p .648 .127 0 r
F P
0 g
s
.55285 .34288 m .54425 .32808 L .54747 .32893 L p .648 .127 0 r
F P
0 g
s
.61522 .44019 m .61727 .47714 L .61879 .47288 L p 0 0 .352 r
F P
0 g
s
.61879 .47288 m .61638 .43627 L .61522 .44019 L p 0 0 .352 r
F P
0 g
s
.51864 .5845 m .51925 .56924 L .52487 .56894 L p .895 .737 .678 r
F P
0 g
s
.4368 .5399 m .41832 .55441 L .4102 .54938 L p .702 .657 .803 r
F P
0 g
s
.41832 .55441 m .4368 .5399 L .44367 .54424 L p .684 .616 .773 r
F P
0 g
s
.43757 .56376 m .45106 .54843 L .45868 .55235 L p .652 .546 .721 r
F P
0 g
s
.45868 .55235 m .44781 .5678 L .43757 .56376 L p .652 .546 .721 r
F P
0 g
s
.49744 .34222 m .50694 .32832 L .5102 .32756 L p .309 0 0 r
F P
0 g
s
.50694 .32832 m .49744 .34222 L .49271 .34351 L p .253 0 0 r
F P
0 g
s
.46742 .61236 m .47714 .59374 L .48568 .5948 L p .615 .563 .773 r
F P
0 g
s
.48568 .5948 m .47791 .61265 L .46742 .61236 L p .615 .563 .773 r
F P
0 g
s
.60236 .37782 m .61619 .41098 L .61476 .40689 L p 0 0 .291 r
F P
0 g
s
.61476 .40689 m .60101 .37451 L .60236 .37782 L p 0 0 .291 r
F P
0 g
s
.45584 .59068 m .46745 .57429 L .47624 .57673 L p .592 .516 .738 r
F P
0 g
s
.47624 .57673 m .46718 .59242 L .45584 .59068 L p .592 .516 .738 r
F P
0 g
s
.43128 .46819 m .43529 .43318 L .43586 .43648 L p .812 .718 .185 r
F P
0 g
s
.43128 .46819 m .43165 .46539 L p .43393 .44522 L 0 0 0 r
F P
0 g
s
.43529 .43318 m .43413 .44332 L p .43393 .44522 L 0 0 0 r
F P
0 g
s
.43413 .44332 m .43128 .46819 L p .43393 .44522 L 0 0 0 r
F P
0 g
s
.43509 .42985 m .43529 .43318 L p .43393 .44522 L 0 0 0 r
F P
0 g
s
.43165 .46539 m .43509 .42985 L p .43393 .44522 L 0 0 0 r
F P
0 g
s
.43128 .471 m .43128 .46819 L p .43332 .45407 L .812 .718 .185 r
F P
0 g
s
.43316 .4568 m .43128 .471 L p .43332 .45407 L .812 .718 .185 r
F P
0 g
s
.43165 .46539 m .43234 .46255 L p .43398 .44313 L 0 0 .035 r
F P
0 g
s
.43509 .42985 m .434 .44109 L p .43398 .44313 L 0 0 .035 r
F P
0 g
s
.434 .44109 m .43165 .46539 L p .43398 .44313 L 0 0 .035 r
F P
0 g
s
.43525 .42649 m .43509 .42985 L p .43382 .44502 L 0 0 .035 r
F P
0 g
s
.43574 .42308 m .43525 .42649 L p .43389 .44948 L 0 0 .116 r
F P
0 g
s
.43586 .43648 m .43316 .4568 L p .43332 .45407 L .812 .718 .185 r
F P
0 g
s
.43329 .4596 m .43387 .45097 L p .43389 .44948 L 0 0 .116 r
F P
0 g
s
.43387 .45097 m .43574 .42308 L p .43389 .44948 L 0 0 .116 r
F P
0 g
s
.43382 .44502 m .43326 .45168 L .43396 .44254 L 0 0 .035 r
F
.43234 .46255 m .43309 .45333 L p .43326 .45168 L F P
0 g
s
.43309 .45333 m .43396 .44254 L p .43326 .45168 L 0 0 .035 r
F P
0 g
s
.43396 .44254 m .43525 .42649 L p .43382 .44502 L 0 0 .035 r
F P
0 g
s
.54425 .32808 m .55285 .34288 L .54797 .34185 L p .633 .119 .006 r
F P
0 g
s
.54797 .34185 m .54095 .32737 L .54425 .32808 L p .633 .119 .006 r
F P
0 g
s
.4368 .5399 m .44592 .52235 L .45127 .52621 L p .763 .597 .672 r
F P
0 g
s
.45127 .52621 m .44367 .54424 L .4368 .5399 L p .763 .597 .672 r
F P
0 g
s
.50231 .34117 m .5102 .32756 L .51354 .32694 L p .358 0 0 r
F P
0 g
s
.5102 .32756 m .50231 .34117 L .49744 .34222 L p .309 0 0 r
F P
0 g
s
.48652 .68539 m .48446 .67449 L .49346 .67789 L p .811 .408 .287 r
F P
0 g
s
.49346 .67789 m .49508 .68897 L .48652 .68539 L p .811 .408 .287 r
F P
0 g
s
.50521 .59803 m .50123 .6161 L .49432 .61434 L p .772 .738 .821 r
F P
0 g
s
.50123 .6161 m .50521 .59803 L .51104 .59941 L p .825 .788 .817 r
F P
0 g
s
.54095 .32737 m .54797 .34185 L .543 .34099 L p .614 .107 .021 r
F P
0 g
s
.543 .34099 m .53759 .32681 L .54095 .32737 L p .614 .107 .021 r
F P
0 g
s
.50727 .34037 m .51354 .32694 L .51693 .32647 L p .403 0 0 r
F P
0 g
s
.51354 .32694 m .50727 .34037 L .50231 .34117 L p .358 0 0 r
F P
0 g
s
.61573 .56257 m .60271 .54761 L .60035 .54937 L p .25 .459 .868 r
F P
0 g
s
.53759 .32681 m .543 .34099 L .53795 .3403 L p .593 .091 .032 r
F P
0 g
s
.53795 .3403 m .53419 .32638 L .53759 .32681 L p .593 .091 .032 r
F P
0 g
s
.44887 .67769 m .45266 .69018 L .43684 .69552 L p .522 .225 .405 r
F P
0 g
s
.45266 .69018 m .44887 .67769 L .46285 .6747 L p .534 .224 .388 r
F P
0 g
s
.51232 .33981 m .51693 .32647 L .52036 .32615 L p .443 0 .015 r
F P
0 g
s
.51693 .32647 m .51232 .33981 L .50727 .34037 L p .403 0 0 r
F P
0 g
s
.59725 .52918 m .60271 .54761 L .60421 .54598 L p .198 .166 .594 r
F P
0 g
s
.60421 .54598 m .59991 .52749 L .59725 .52918 L p .198 .166 .594 r
F P
0 g
s
.44781 .5678 m .45868 .55235 L .46629 .55592 L p .638 .516 .698 r
F P
0 g
s
.46629 .55592 m .45789 .57132 L .44781 .5678 L p .638 .516 .698 r
F P
0 g
s
.32101 .56711 m .36173 .54789 L .36489 .55375 L p .742 .813 .908 r
F P
0 g
s
.39893 .53947 m .36489 .55375 L .36173 .54789 L p .704 .805 .928 r
F P
0 g
s
.36489 .55375 m .39893 .53947 L .40363 .54433 L p .702 .753 .892 r
F P
0 g
s
.53419 .32638 m .53795 .3403 L .53285 .3398 L p .569 .072 .037 r
F P
0 g
s
.53285 .3398 m .53074 .3261 L .53419 .32638 L p .569 .072 .037 r
F P
0 g
s
.44081 .40867 m .45296 .3739 L .45143 .37709 L p 0 0 0 r
F P
0 g
s
.45143 .37709 m .43909 .41239 L .44081 .40867 L p 0 0 0 r
F P
0 g
s
.43073 .53554 m .4102 .54938 L .40363 .54433 L p .719 .705 .836 r
F P
0 g
s
.4102 .54938 m .43073 .53554 L .4368 .5399 L p .702 .657 .803 r
F P
0 g
s
.51743 .33948 m .52036 .32615 L .52381 .32599 L p .479 0 .026 r
F P
0 g
s
.52036 .32615 m .51743 .33948 L .51232 .33981 L p .443 0 .015 r
F P
0 g
s
.53074 .3261 m .53285 .3398 L .52771 .33948 L p .542 .05 .038 r
F P
0 g
s
.52771 .33948 m .52728 .32597 L .53074 .3261 L p .542 .05 .038 r
F P
0 g
s
.52256 .33937 m .52381 .32599 L .52728 .32597 L p .512 .024 .034 r
F P
0 g
s
.52381 .32599 m .52256 .33937 L .51743 .33948 L p .479 0 .026 r
F P
0 g
s
.43073 .53554 m .44111 .51848 L .44592 .52235 L p .791 .643 .699 r
F P
0 g
s
.44592 .52235 m .4368 .5399 L .43073 .53554 L p .791 .643 .699 r
F P
0 g
s
.52728 .32597 m .52771 .33948 L .52256 .33937 L p .512 .024 .034 r
F P
0 g
s
.50609 .69794 m .50355 .6952 L .51276 .70373 L p .591 .094 0 r
F P
0 g
s
.51276 .70373 m .51428 .70653 L .50609 .69794 L p .591 .094 0 r
F P
0 g
s
.60101 .37451 m .61476 .40689 L .6129 .40295 L p .729 .351 0 r
F P
0 g
s
.6129 .40295 m .59933 .37129 L .60101 .37451 L p .729 .351 0 r
F P
0 g
s
.42949 .5047 m .43417 .47994 L .43622 .48317 L p 1 .826 .511 r
F P
0 g
s
.43622 .48317 m .43112 .50775 L .42949 .5047 L p 1 .826 .511 r
F P
0 g
s
.53345 .72242 m .53478 .7283 L .54768 .73986 L p 0 .166 .673 r
F P
0 g
s
.61638 .43627 m .61879 .47288 L .62013 .46832 L p 0 0 .321 r
F P
0 g
s
.62013 .46832 m .61724 .4322 L .61638 .43627 L p 0 0 .321 r
F P
0 g
s
.60741 .4937 m .60553 .52201 L .60703 .5198 L p .001 0 .329 r
F P
0 g
s
.60703 .5198 m .60971 .49097 L .60741 .4937 L p .001 0 .329 r
F P
0 g
s
.47791 .61265 m .48568 .5948 L .49298 .59578 L p .65 .606 .792 r
F P
0 g
s
.49298 .59578 m .48674 .61323 L .47791 .61265 L p .65 .606 .792 r
F P
0 g
s
.51314 .58399 m .51398 .56924 L .51925 .56924 L p .886 .711 .659 r
F P
0 g
s
.51925 .56924 m .51864 .5845 L .51314 .58399 L p .886 .711 .659 r
F P
0 g
s
.25596 .61549 m .28267 .58474 L .28274 .59417 L p .917 .944 .803 r
F P
0 g
s
.28274 .59417 m .25613 .62669 L .25596 .61549 L p .917 .944 .803 r
F P
0 g
s
.32101 .56711 m .28274 .59417 L .28267 .58474 L p .816 .904 .902 r
F P
0 g
s
.28267 .58474 m .321 .55978 L .32101 .56711 L p .816 .904 .902 r
F P
0 g
s
.36173 .54789 m .32101 .56711 L .321 .55978 L p .736 .871 .943 r
F P
0 g
s
.49935 .59683 m .49432 .61434 L .48674 .61323 L p .707 .669 .811 r
F P
0 g
s
.49432 .61434 m .49935 .59683 L .50521 .59803 L p .772 .738 .821 r
F P
0 g
s
.60271 .54761 m .61573 .56257 L .61599 .56027 L p .086 .348 .819 r
F P
0 g
s
.63586 .5756 m .61599 .56027 L .61573 .56257 L p .059 .45 .879 r
F P
0 g
s
.47707 .68457 m .47452 .67349 L .48446 .67449 L p .691 .315 .33 r
F P
0 g
s
.48446 .67449 m .48652 .68539 L .47707 .68457 L p .691 .315 .33 r
F P
0 g
s
.46718 .59242 m .47624 .57673 L .48412 .5787 L p .594 .516 .736 r
F P
0 g
s
.48412 .5787 m .47714 .59374 L .46718 .59242 L p .594 .516 .736 r
F P
0 g
s
.46285 .6747 m .46596 .68631 L .45266 .69018 L p .534 .224 .388 r
F P
0 g
s
.46596 .68631 m .46285 .6747 L .47452 .67349 L p .587 .249 .364 r
F P
0 g
s
.45789 .57132 m .46629 .55592 L .47366 .55908 L p .628 .49 .676 r
F P
0 g
s
.47366 .55908 m .46745 .57429 L .45789 .57132 L p .628 .49 .676 r
F P
0 g
s
.51314 .58399 m .51104 .59941 L .50521 .59803 L p .846 .779 .786 r
F P
0 g
s
.51104 .59941 m .51314 .58399 L .51864 .5845 L p .876 .811 .782 r
F P
0 g
s
.42569 .53128 m .43698 .5147 L .44111 .51848 L p .824 .699 .727 r
F P
0 g
s
.44111 .51848 m .43073 .53554 L .42569 .53128 L p .824 .699 .727 r
F P
0 g
s
.26648 .69679 m .25379 .67053 L .26469 .6801 L p .871 .428 .072 r
F P
0 g
s
.26469 .6801 m .2768 .70576 L .26648 .69679 L p .871 .428 .072 r
F P
0 g
s
.48674 .61323 m .49298 .59578 L .49935 .59683 L p .707 .669 .811 r
F P
0 g
s
.44284 .40489 m .45479 .37073 L .45296 .3739 L p 0 0 0 r
F P
0 g
s
.45296 .3739 m .44081 .40867 L .44284 .40489 L p 0 0 0 r
F P
0 g
s
.61599 .56027 m .63586 .5756 L .63367 .57205 L p 0 .35 .804 r
F P
0 g
s
.65722 .5899 m .63367 .57205 L .63586 .5756 L p 0 .35 .805 r
F P
0 g
s
.42569 .53128 m .40363 .54433 L .39893 .53947 L p .735 .761 .873 r
F P
0 g
s
.40363 .54433 m .42569 .53128 L .43073 .53554 L p .719 .705 .836 r
F P
0 g
s
.47452 .67349 m .47707 .68457 L .46596 .68631 L p .587 .249 .364 r
F P
0 g
s
.59933 .37129 m .6129 .40295 L .61061 .39922 L p .803 .397 0 r
F P
0 g
s
.61061 .39922 m .59733 .36817 L .59933 .37129 L p .803 .397 0 r
F P
0 g
s
.35324 .72701 m .33093 .71737 L .35333 .71605 L p .484 .007 .046 r
F P
0 g
s
.35333 .71605 m .37304 .72438 L .35324 .72701 L p .484 .007 .046 r
F P
0 g
s
.37304 .72438 m .35333 .71605 L .37605 .71258 L p .453 .01 .106 r
F P
0 g
s
.37605 .71258 m .39313 .7197 L .37304 .72438 L p .453 .01 .106 r
F P
0 g
s
.39313 .7197 m .37605 .71258 L .39807 .70752 L p .415 0 .132 r
F P
0 g
s
.66784 .75582 m .6441 .75031 L .65011 .74026 L p .801 .903 .913 r
F P
0 g
s
.65011 .74026 m .67503 .74465 L .66784 .75582 L p .801 .903 .913 r
F P
0 g
s
.61724 .4322 m .62013 .46832 L .62123 .46352 L p 0 0 .285 r
F P
0 g
s
.62123 .46352 m .61777 .42802 L .61724 .4322 L p 0 0 .285 r
F P
0 g
s
.65722 .5899 m .68015 .61268 L .67475 .60483 L p 0 .159 .661 r
F P
0 g
s
.68015 .61268 m .69619 .63814 L .69016 .62777 L p .601 .168 0 r
F P
0 g
s
.69016 .62777 m .67475 .60483 L .68015 .61268 L p .601 .168 0 r
F P
0 g
s
.59991 .52749 m .60421 .54598 L .60503 .54445 L p .077 .045 .515 r
F P
0 g
s
.60503 .54445 m .6021 .52577 L .59991 .52749 L p .077 .045 .515 r
F P
0 g
s
.50794 .58333 m .5089 .56893 L .51398 .56924 L p .857 .667 .644 r
F P
0 g
s
.51398 .56924 m .51314 .58399 L .50794 .58333 L p .857 .667 .644 r
F P
0 g
s
.70551 .67528 m .69692 .6939 L .69218 .67939 L p .996 .844 .574 r
F P
0 g
s
.69218 .67939 m .70068 .66191 L .70551 .67528 L p .996 .844 .574 r
F P
0 g
s
.42872 .50196 m .43268 .47684 L .43417 .47994 L p .958 .824 .391 r
F P
0 g
s
.42872 .49954 m .43173 .47387 L .43268 .47684 L p .802 .726 .196 r
F P
0 g
s
.41869 .51778 m .42872 .50196 L .42949 .5047 L p .857 .972 .659 r
F P
0 g
s
.41839 .52043 m .41869 .51778 L p .42452 .51072 L .857 .972 .659 r
F P
0 g
s
.42949 .5047 m .42379 .51278 L p .42452 .51072 L .857 .972 .659 r
F P
0 g
s
.42379 .51278 m .41839 .52043 L p .42452 .51072 L .857 .972 .659 r
F P
0 g
s
.42635 .50576 m .41972 .51615 L .42019 .51566 L 0 0 0 r
F
.42659 .50532 m .41869 .51778 L p .42635 .50576 L F P
0 g
s
.42872 .50196 m .42659 .50532 L p .42635 .50576 L 0 0 0 r
F P
0 g
s
.42019 .51566 m .42872 .49954 L .42872 .50196 L p 0 0 0 r
F P
0 g
s
.37726 .53127 m .39844 .52552 L p .40074 .52534 L .326 .811 .807 r
F P
0 g
s
.41046 .52125 m .40261 .52519 L .40074 .52534 L .479 .894 .805 r
F
.41869 .51778 m .42019 .51566 L p .41972 .51615 L 0 0 0 r
F P
0 g
s
.40074 .52534 m .42019 .51566 L .41869 .51778 L p .479 .894 .805 r
F P
0 g
s
.42019 .51566 m .40476 .52334 L p .40559 .52358 L 0 0 0 r
F P
0 g
s
.40476 .52334 m .40074 .52534 L .40559 .52358 L p 0 0 0 r
F P
0 g
s
.39844 .52552 m .40559 .52358 L .40074 .52534 L p .326 .811 .807 r
F P
0 g
s
.40737 .52311 m .39736 .52783 L p .41046 .52125 L .479 .894 .805 r
F P
0 g
s
.39736 .52783 m .41869 .51778 L .41839 .52043 L p .672 .956 .947 r
F P
0 g
s
.40074 .52534 m .3698 .53411 L .37726 .53127 L p .326 .811 .807 r
F P
0 g
s
.38609 .52931 m .40639 .52381 L p .40559 .52358 L 0 0 0 r
F P
0 g
s
.40639 .52381 m .41143 .52245 L .40559 .52358 L p 0 0 0 r
F P
0 g
s
.39736 .52783 m .40074 .52534 L p .40261 .52519 L .479 .894 .805 r
F P
0 g
s
.41869 .51778 m .40737 .52311 L p .41046 .52125 L .479 .894 .805 r
F P
0 g
s
.40559 .52358 m .41842 .51642 L p .4185 .51638 L 0 0 0 r
F P
0 g
s
.42019 .51566 m .41539 .51827 L .4185 .51638 L 0 0 0 r
F
.41539 .51827 m .40559 .52358 L .4185 .51638 L F
.42872 .49954 m .42019 .51566 L .42269 .51404 L p F P
0 g
s
.41842 .51642 m .42066 .51517 L p .42019 .51566 L 0 0 0 r
F P
0 g
s
.42066 .51517 m .42269 .51404 L .42019 .51566 L p 0 0 0 r
F P
0 g
s
.42706 .50354 m .42534 .50766 L .42799 .50089 L 0 0 0 r
F
.42269 .51404 m .425 .5083 L p .42534 .50766 L F P
0 g
s
.425 .5083 m .42799 .50089 L p .42534 .50766 L 0 0 0 r
F P
0 g
s
.42872 .49954 m .42706 .50354 L .42824 .50028 L 0 0 0 r
F
.42799 .50089 m .42824 .50028 L p .42706 .50354 L F P
0 g
s
.43104 .48624 m .42918 .49884 L .42872 .49954 L .802 .726 .196 r
F
.43105 .48662 m .42872 .50196 L .43104 .48624 L F
.4288 .49889 m .42941 .49738 L p .43113 .48003 L 0 0 .018 r
F P
0 g
s
.43118 .47861 m .4288 .49889 L .43113 .48003 L 0 0 .018 r
F
.43173 .47387 m .43118 .47861 L .43113 .48003 L F
.43128 .471 m .43173 .47387 L p .43034 .48797 L F P
0 g
s
.42941 .49738 m .42998 .48933 L p .43034 .48797 L 0 0 .018 r
F P
0 g
s
.42998 .48933 m .43128 .471 L p .43034 .48797 L 0 0 .018 r
F P
0 g
s
.4318 .48245 m .42872 .50196 L p .43153 .48348 L .802 .726 .196 r
F P
0 g
s
.42949 .5047 m .42872 .50196 L p .43095 .49294 L .958 .824 .391 r
F P
0 g
s
.43128 .471 m .42941 .49738 L .43063 .49543 L p 0 0 .187 r
F P
0 g
s
.43099 .48199 m .43084 .48753 L .43098 .48087 L 0 0 .187 r
F
.43063 .49543 m .43078 .48923 L p .43084 .48753 L F P
0 g
s
.43078 .48923 m .43098 .48087 L p .43084 .48753 L 0 0 .187 r
F P
0 g
s
.42824 .50028 m .42941 .49738 L .42872 .49954 L p 0 0 0 r
F P
0 g
s
.42872 .50196 m .42872 .49954 L p .42918 .49884 L .802 .726 .196 r
F P
0 g
s
.43153 .48348 m .43105 .48662 L .43104 .48624 L .802 .726 .196 r
F
.43117 .47535 m .43099 .48199 L .43123 .46997 L 0 0 .187 r
F
.43098 .48087 m .43123 .46997 L p .43099 .48199 L F P
0 g
s
.43268 .47684 m .4318 .48245 L p .43153 .48348 L .802 .726 .196 r
F P
0 g
s
.43128 .46819 m .43128 .471 L p .43117 .47535 L 0 0 .187 r
F P
0 g
s
.43123 .46997 m .43128 .46819 L p .43117 .47535 L 0 0 .187 r
F P
0 g
s
.43417 .47994 m .4309 .49726 L p .43095 .49294 L .958 .824 .391 r
F P
0 g
s
.4309 .49726 m .42949 .5047 L p .43095 .49294 L .958 .824 .391 r
F P
0 g
s
.60971 .49097 m .60703 .5198 L .60855 .51725 L p 0 0 .287 r
F P
0 g
s
.60855 .51725 m .61181 .48797 L .60971 .49097 L p 0 0 .287 r
F P
0 g
s
.42189 .52726 m .43362 .5111 L .43698 .5147 L p .863 .768 .756 r
F P
0 g
s
.43698 .5147 m .42569 .53128 L .42189 .52726 L p .863 .768 .756 r
F P
0 g
s
.61599 .56027 m .60421 .54598 L .60271 .54761 L p .086 .348 .819 r
F P
0 g
s
.39807 .70752 m .41261 .71356 L .39313 .7197 L p .415 0 .132 r
F P
0 g
s
.41261 .71356 m .39807 .70752 L .41854 .70157 L p .374 0 .133 r
F P
0 g
s
.46745 .57429 m .47366 .55908 L .48063 .56179 L p .623 .472 .656 r
F P
0 g
s
.48063 .56179 m .47624 .57673 L .46745 .57429 L p .623 .472 .656 r
F P
0 g
s
.44517 .40107 m .45692 .36762 L .45479 .37073 L p 0 0 0 r
F P
0 g
s
.45479 .37073 m .44284 .40489 L .44517 .40107 L p 0 0 0 r
F P
0 g
s
.33475 .72717 m .30997 .71618 L .33093 .71737 L p .501 0 0 r
F P
0 g
s
.33093 .71737 m .35324 .72701 L .33475 .72717 L p .501 0 0 r
F P
0 g
s
.47714 .59374 m .48412 .5787 L .49108 .58027 L p .612 .533 .741 r
F P
0 g
s
.49108 .58027 m .48568 .5948 L .47714 .59374 L p .612 .533 .741 r
F P
0 g
s
.59733 .36817 m .61061 .39922 L .60788 .39573 L p .853 .431 0 r
F P
0 g
s
.60788 .39573 m .59502 .36519 L .59733 .36817 L p .853 .431 0 r
F P
0 g
s
.50794 .58333 m .50521 .59803 L .49935 .59683 L p .79 .719 .785 r
F P
0 g
s
.50521 .59803 m .50794 .58333 L .51314 .58399 L p .846 .779 .786 r
F P
0 g
s
.50274 .58251 m .50385 .56828 L .5089 .56893 L p .807 .608 .632 r
F P
0 g
s
.5089 .56893 m .50794 .58333 L .50274 .58251 L p .807 .608 .632 r
F P
0 g
s
.47624 .57673 m .48063 .56179 L .48711 .56406 L p .629 .463 .639 r
F P
0 g
s
.63367 .57205 m .65722 .5899 L .65283 .5846 L p 0 .288 .74 r
F P
0 g
s
.67475 .60483 m .65283 .5846 L .65722 .5899 L p 0 .159 .661 r
F P
0 g
s
.321 .55978 m .36161 .54252 L .36173 .54789 L p .736 .871 .943 r
F P
0 g
s
.39629 .53499 m .36173 .54789 L .36161 .54252 L p .691 .86 .963 r
F P
0 g
s
.36173 .54789 m .39629 .53499 L .39893 .53947 L p .704 .805 .928 r
F P
0 g
s
.49855 .69173 m .49508 .68897 L .50355 .6952 L p .501 0 0 r
F P
0 g
s
.50355 .6952 m .50609 .69794 L .49855 .69173 L p .501 0 0 r
F P
0 g
s
.52413 .71186 m .52371 .71691 L .53478 .7283 L p 0 .174 .695 r
F P
0 g
s
.53478 .7283 m .53345 .72242 L .52413 .71186 L p 0 .174 .695 r
F P
0 g
s
.61777 .42802 m .62123 .46352 L .62202 .45854 L p 0 0 .243 r
F P
0 g
s
.62202 .45854 m .61796 .42376 L .61777 .42802 L p 0 0 .243 r
F P
0 g
s
.69619 .63814 m .70068 .66191 L .69441 .64953 L p .939 .624 .175 r
F P
0 g
s
.69441 .64953 m .69016 .62777 L .69619 .63814 L p .939 .624 .175 r
F P
0 g
s
.41854 .70157 m .43072 .70669 L .41261 .71356 L p .374 0 .133 r
F P
0 g
s
.43072 .70669 m .41854 .70157 L .43684 .69552 L p .331 0 .111 r
F P
0 g
s
.44782 .39724 m .45933 .36457 L .45692 .36762 L p 0 0 .038 r
F P
0 g
s
.45692 .36762 m .44517 .40107 L .44782 .39724 L p 0 0 .038 r
F P
0 g
s
.42189 .52726 m .39893 .53947 L .39629 .53499 L p .745 .827 .915 r
F P
0 g
s
.39893 .53947 m .42189 .52726 L .42569 .53128 L p .735 .761 .873 r
F P
0 g
s
.48711 .56406 m .48412 .5787 L .47624 .57673 L p .629 .463 .639 r
F P
0 g
s
.48412 .5787 m .48711 .56406 L .49309 .56588 L p .649 .469 .627 r
F P
0 g
s
.49721 .58151 m .49863 .56728 L .50385 .56828 L p .745 .546 .625 r
F P
0 g
s
.50385 .56828 m .50274 .58251 L .49721 .58151 L p .745 .546 .625 r
F P
0 g
s
.61181 .48797 m .60855 .51725 L .61019 .51428 L p 0 0 .251 r
F P
0 g
s
.61019 .51428 m .61377 .48468 L .61181 .48797 L p 0 0 .251 r
F P
0 g
s
.48568 .5948 m .49108 .58027 L .49721 .58151 L p .654 .576 .755 r
F P
0 g
s
.49721 .58151 m .49298 .59578 L .48568 .5948 L p .654 .576 .755 r
F P
0 g
s
.41944 .52362 m .43112 .50775 L .43362 .5111 L p .906 .854 .78 r
F P
0 g
s
.43362 .5111 m .42189 .52726 L .41944 .52362 L p .906 .854 .78 r
F P
0 g
s
.59502 .36519 m .60788 .39573 L .60475 .39251 L p .88 .453 .057 r
F P
0 g
s
.60475 .39251 m .5924 .36234 L .59502 .36519 L p .88 .453 .057 r
F P
0 g
s
.49309 .56588 m .49108 .58027 L .48412 .5787 L p .649 .469 .627 r
F P
0 g
s
.49108 .58027 m .49309 .56588 L .49863 .56728 L p .688 .497 .622 r
F P
0 g
s
.6021 .52577 m .60503 .54445 L .6054 .54293 L p 0 0 .423 r
F P
0 g
s
.6054 .54293 m .60393 .52397 L .6021 .52577 L p 0 0 .423 r
F P
0 g
s
.24799 .64705 m .25596 .61549 L .25613 .62669 L p .924 .841 .391 r
F P
0 g
s
.25613 .62669 m .24813 .65933 L .24799 .64705 L p .924 .841 .391 r
F P
0 g
s
.49863 .56728 m .49721 .58151 L .49108 .58027 L p .688 .497 .622 r
F P
0 g
s
.50274 .58251 m .49935 .59683 L .49298 .59578 L p .718 .643 .773 r
F P
0 g
s
.49935 .59683 m .50274 .58251 L .50794 .58333 L p .79 .719 .785 r
F P
0 g
s
.31856 .72461 m .29159 .7123 L .30997 .71618 L p .476 0 0 r
F P
0 g
s
.30997 .71618 m .33475 .72717 L .31856 .72461 L p .476 0 0 r
F P
0 g
s
.43525 .42649 m .43234 .46255 L .43329 .4596 L p 0 0 .116 r
F P
0 g
s
.69926 .70878 m .67953 .71718 L .67738 .70239 L p .928 .877 .766 r
F P
0 g
s
.67738 .70239 m .69692 .6939 L .69926 .70878 L p .928 .877 .766 r
F P
0 g
s
.49298 .59578 m .49721 .58151 L .50274 .58251 L p .718 .643 .773 r
F P
0 g
s
.60421 .54598 m .61599 .56027 L .61525 .5582 L p 0 .211 .736 r
F P
0 g
s
.63367 .57205 m .61525 .5582 L .61599 .56027 L p 0 .35 .804 r
F P
0 g
s
.45079 .39345 m .46204 .3616 L .45933 .36457 L p 0 0 .087 r
F P
0 g
s
.45933 .36457 m .44782 .39724 L .45079 .39345 L p 0 0 .087 r
F P
0 g
s
.61796 .42376 m .62202 .45854 L .62243 .45345 L p 0 0 .193 r
F P
0 g
s
.62243 .45345 m .61777 .41947 L .61796 .42376 L p 0 0 .193 r
F P
0 g
s
.43684 .69552 m .44691 .69989 L .43072 .70669 L p .331 0 .111 r
F P
0 g
s
.44691 .69989 m .43684 .69552 L .45266 .69018 L p .291 0 .059 r
F P
0 g
s
.61525 .5582 m .60503 .54445 L .60421 .54598 L p 0 .211 .736 r
F P
0 g
s
.5924 .36234 m .60475 .39251 L .60123 .38955 L p .891 .466 .127 r
F P
0 g
s
.60123 .38955 m .58949 .35964 L .5924 .36234 L p .891 .466 .127 r
F P
0 g
s
.61377 .48468 m .61019 .51428 L .612 .51083 L p 0 0 .225 r
F P
0 g
s
.612 .51083 m .61558 .48107 L .61377 .48468 L p 0 0 .225 r
F P
0 g
s
.28723 .57565 m .32483 .55305 L .321 .55978 L p .783 .97 .918 r
F P
0 g
s
.321 .55978 m .28267 .58474 L .28723 .57565 L p .783 .97 .918 r
F P
0 g
s
.36161 .54252 m .321 .55978 L .32483 .55305 L p .7 .923 .967 r
F P
0 g
s
.39629 .53499 m .41944 .52362 L .42189 .52726 L p .745 .827 .915 r
F P
0 g
s
.49094 .68825 m .48652 .68539 L .49508 .68897 L p .407 0 0 r
F P
0 g
s
.49508 .68897 m .49855 .69173 L .49094 .68825 L p .407 0 0 r
F P
0 g
s
.67503 .74465 m .65011 .74026 L .6534 .72836 L p .837 .877 .872 r
F P
0 g
s
.6534 .72836 m .67888 .73153 L .67503 .74465 L p .837 .877 .872 r
F P
0 g
s
.25379 .67053 m .26648 .69679 L .2612 .68578 L p 0 0 .31 r
F P
0 g
s
.2612 .68578 m .24813 .65933 L .25379 .67053 L p 0 0 .31 r
F P
0 g
s
.41839 .52043 m .42949 .5047 L .43112 .50775 L p .933 .948 .775 r
F P
0 g
s
.43112 .50775 m .41944 .52362 L .41839 .52043 L p .933 .948 .775 r
F P
0 g
s
.4541 .38974 m .46501 .35874 L .46204 .3616 L p 0 0 .132 r
F P
0 g
s
.46204 .3616 m .45079 .39345 L .4541 .38974 L p 0 0 .132 r
F P
0 g
s
.43445 .45649 m .43655 .41959 L .43574 .42308 L p 0 0 .176 r
F P
0 g
s
.43574 .42308 m .43329 .4596 L .43445 .45649 L p 0 0 .176 r
F P
0 g
s
.26099 .60424 m .28723 .57565 L .28267 .58474 L p .839 .992 .738 r
F P
0 g
s
.28267 .58474 m .25596 .61549 L .26099 .60424 L p .839 .992 .738 r
F P
0 g
s
.61525 .5582 m .63367 .57205 L .63068 .56886 L p 0 .267 .731 r
F P
0 g
s
.65283 .5846 m .63068 .56886 L .63367 .57205 L p 0 .288 .74 r
F P
0 g
s
.60393 .52397 m .6054 .54293 L .60559 .54132 L p 0 0 .333 r
F P
0 g
s
.60559 .54132 m .60553 .52201 L .60393 .52397 L p 0 0 .333 r
F P
0 g
s
.45266 .69018 m .4609 .69396 L .44691 .69989 L p .291 0 .059 r
F P
0 g
s
.4609 .69396 m .45266 .69018 L .46596 .68631 L p .261 0 0 r
F P
0 g
s
.61777 .41947 m .62243 .45345 L .6224 .44836 L p 0 0 .132 r
F P
0 g
s
.6224 .44836 m .61735 .41625 L p .61777 .41947 L 0 0 .132 r
F P
0 g
s
.61718 .41519 m .62066 .4373 L p .62186 .44336 L .768 .514 0 r
F P
0 g
s
.62066 .4373 m .6224 .44836 L .62186 .44336 L p .768 .514 0 r
F P
0 g
s
.62186 .44336 m .62571 .46593 L p .62567 .46176 L .714 .459 0 r
F P
0 g
s
.62571 .46593 m .62598 .46752 L .62567 .46176 L p .714 .459 0 r
F P
0 g
s
.63688 .46638 m .62562 .45741 L p .62567 .46176 L .196 .346 .789 r
F P
0 g
s
.62567 .46176 m .62314 .4498 L p .62186 .44336 L .714 .459 0 r
F P
0 g
s
.62598 .46752 m .62186 .44336 L .6224 .44836 L p 0 0 .187 r
F P
0 g
s
.62076 .43855 m .62531 .46009 L p .62446 .45649 L .822 .508 0 r
F P
0 g
s
.62531 .46009 m .62567 .46176 L .62446 .45649 L p .822 .508 0 r
F P
0 g
s
.62446 .45649 m .61906 .43404 L .62076 .43855 L p .822 .508 0 r
F P
0 g
s
.63491 .46085 m .62357 .45275 L p .62446 .45649 L .084 .338 .812 r
F P
0 g
s
.6255 .47358 m .6224 .44836 L .62243 .45345 L p 0 0 .217 r
F P
0 g
s
.6224 .44836 m .6255 .47358 L .62598 .46752 L p 0 0 .187 r
F P
0 g
s
.61906 .43404 m .62403 .45473 L p .62231 .45185 L .902 .548 .079 r
F P
0 g
s
.62403 .45473 m .62446 .45649 L .62231 .45185 L p .902 .548 .079 r
F P
0 g
s
.62231 .45185 m .61676 .42991 L .61906 .43404 L p .902 .548 .079 r
F P
0 g
s
.61676 .42991 m .62184 .44999 L p .61923 .44799 L .937 .568 .192 r
F P
0 g
s
.62184 .44999 m .62231 .45185 L .61923 .44799 L p .937 .568 .192 r
F P
0 g
s
.63146 .4565 m .62054 .4489 L p .62231 .45185 L 0 .277 .774 r
F P
0 g
s
.62054 .4489 m .61923 .44799 L .62231 .45185 L p 0 .277 .774 r
F P
0 g
s
.61923 .44799 m .61385 .42623 L .61676 .42991 L p .937 .568 .192 r
F P
0 g
s
.61385 .42623 m .61923 .44799 L .61528 .44498 L p .937 .573 .289 r
F P
0 g
s
.61923 .44799 m .6301 .45555 L p .62662 .45348 L 0 .12 .574 r
F P
0 g
s
.6301 .45555 m .63146 .4565 L .62662 .45348 L p 0 .12 .574 r
F P
0 g
s
.62662 .45348 m .61658 .44595 L p .61923 .44799 L 0 .12 .574 r
F P
0 g
s
.61658 .44595 m .61528 .44498 L .61923 .44799 L p 0 .12 .574 r
F P
0 g
s
.62357 .45275 m .62231 .45185 L .62446 .45649 L p .084 .338 .812 r
F P
0 g
s
.62231 .45185 m .63491 .46085 L .63146 .4565 L p 0 .277 .774 r
F P
0 g
s
.61528 .44498 m .62535 .45252 L p .62058 .45184 L .647 .088 0 r
F P
0 g
s
.62535 .45252 m .62662 .45348 L .62058 .45184 L p .647 .088 0 r
F P
0 g
s
.62058 .45184 m .61056 .44285 L .61528 .44498 L p .647 .088 0 r
F P
0 g
s
.61056 .44285 m .61949 .45086 L p .6136 .45156 L .734 .241 .067 r
F P
0 g
s
.61949 .45086 m .62058 .45184 L .6136 .45156 L p .734 .241 .067 r
F P
0 g
s
.63166 .44836 m .61583 .45117 L p .62058 .45184 L .322 .789 .934 r
F P
0 g
s
.61583 .45117 m .6136 .45156 L .62058 .45184 L p .322 .789 .934 r
F P
0 g
s
.6136 .45156 m .6052 .44158 L .61056 .44285 L p .734 .241 .067 r
F P
0 g
s
.6052 .44158 m .6136 .45156 L .60596 .45249 L p .753 .332 .251 r
F P
0 g
s
.6136 .45156 m .62684 .44921 L p .62117 .45052 L .098 .653 .713 r
F P
0 g
s
.62684 .44921 m .63166 .44836 L .62117 .45052 L p .098 .653 .713 r
F P
0 g
s
.62117 .45052 m .60783 .45225 L p .6136 .45156 L .098 .653 .713 r
F P
0 g
s
.62314 .4498 m .62076 .43855 L .62186 .44336 L p .714 .459 0 r
F P
0 g
s
.60783 .45225 m .60596 .45249 L .6136 .45156 L p .098 .653 .713 r
F P
0 g
s
.60596 .45249 m .61801 .45093 L p .61028 .4541 L .134 0 0 r
F P
0 g
s
.61801 .45093 m .62117 .45052 L .61028 .4541 L p .134 0 0 r
F P
0 g
s
.61028 .4541 m .598 .4544 L .60596 .45249 L p .134 0 0 r
F P
0 g
s
.598 .4544 m .61028 .4541 L .59948 .45864 L p .307 0 0 r
F P
0 g
s
.61633 .45111 m .60281 .45715 L p .61028 .4541 L .314 .787 .688 r
F P
0 g
s
.60281 .45715 m .59948 .45864 L .61028 .4541 L p .314 .787 .688 r
F P
0 g
s
.63094 .44506 m .61545 .45183 L p .62117 .45052 L .399 .854 .818 r
F P
0 g
s
.61545 .45183 m .61028 .4541 L .62117 .45052 L p .399 .854 .818 r
F P
0 g
s
.64124 .44795 m .62309 .45137 L p .62662 .45348 L .462 .8 .999 r
F P
0 g
s
.62309 .45137 m .62058 .45184 L .62662 .45348 L p .462 .8 .999 r
F P
0 g
s
.62562 .45741 m .62446 .45649 L .62567 .46176 L p .196 .346 .789 r
F P
0 g
s
.61619 .41098 m .62036 .43482 L p .62076 .43855 L .85 .555 .02 r
F P
0 g
s
.62036 .43482 m .62186 .44336 L .62148 .4417 L p .85 .555 .02 r
F P
0 g
s
.62148 .4417 m .62076 .43855 L p .62036 .43482 L .85 .555 .02 r
F P
0 g
s
.61735 .41625 m .61718 .41519 L .61721 .4154 L p 0 0 .132 r
F P
0 g
s
.61721 .4154 m .61777 .41947 L p .61735 .41625 L 0 0 .132 r
F P
0 g
s
.36161 .54252 m .3958 .53107 L .39629 .53499 L p .691 .86 .963 r
F P
0 g
s
.41944 .52362 m .39629 .53499 L .3958 .53107 L p .737 .902 .952 r
F P
0 g
s
.58949 .35964 m .60123 .38955 L .59734 .38688 L p .89 .471 .186 r
F P
0 g
s
.59734 .38688 m .58629 .35711 L .58949 .35964 L p .89 .471 .186 r
F P
0 g
s
.51614 .7023 m .51428 .70653 L .52371 .71691 L p 0 .219 .736 r
F P
0 g
s
.61558 .48107 m .612 .51083 L .61401 .50684 L p 0 0 .209 r
F P
0 g
s
.61401 .50684 m .61727 .47714 L .61558 .48107 L p 0 0 .209 r
F P
0 g
s
.45775 .38616 m .46826 .35601 L .46501 .35874 L p .049 0 .172 r
F P
0 g
s
.46501 .35874 m .4541 .38974 L .45775 .38616 L p .049 0 .172 r
F P
0 g
s
.48254 .68763 m .47707 .68457 L .48652 .68539 L p .313 0 0 r
F P
0 g
s
.48652 .68539 m .49094 .68825 L .48254 .68763 L p .313 0 0 r
F P
0 g
s
.3056 .71932 m .2768 .70576 L .29159 .7123 L p .332 0 0 r
F P
0 g
s
.29159 .7123 m .31856 .72461 L .3056 .71932 L p .332 0 0 r
F P
0 g
s
.32483 .55305 m .36441 .53787 L .36161 .54252 L p .7 .923 .967 r
F P
0 g
s
.3958 .53107 m .36161 .54252 L .36441 .53787 L p .642 .907 .982 r
F P
0 g
s
.46596 .68631 m .47269 .68967 L .4609 .69396 L p .261 0 0 r
F P
0 g
s
.47269 .68967 m .46596 .68631 L .47707 .68457 L p .26 0 0 r
F P
0 g
s
.58629 .35711 m .59734 .38688 L .59313 .38448 L p .882 .472 .235 r
F P
0 g
s
.59313 .38448 m .58284 .35474 L .58629 .35711 L p .882 .472 .235 r
F P
0 g
s
.47707 .68457 m .48254 .68763 L .47269 .68967 L p .26 0 0 r
F P
0 g
s
.43578 .45315 m .43767 .41603 L .43655 .41959 L p 0 0 .221 r
F P
0 g
s
.43655 .41959 m .43445 .45649 L .43578 .45315 L p 0 0 .221 r
F P
0 g
s
.67347 .60365 m .67475 .60483 L .66919 .59784 L p 0 .158 .648 r
F P
0 g
s
.68396 .61854 m .67764 .60913 L .68956 .62687 L .638 .185 0 r
F
.67793 .60956 m .69016 .62777 L p .67764 .60913 L F P
0 g
s
.67475 .60483 m .67793 .60956 L p .67764 .60913 L .638 .185 0 r
F P
0 g
s
.65283 .5846 m .67347 .60365 L p .66919 .59784 L 0 .158 .648 r
F P
0 g
s
.68396 .61854 m .66919 .59784 L .67475 .60483 L p .638 .185 0 r
F P
0 g
s
.66919 .59784 m .68118 .61464 L p .67887 .61054 L 0 0 .438 r
F P
0 g
s
.68118 .61464 m .68396 .61854 L .67887 .61054 L p 0 0 .438 r
F P
0 g
s
.67887 .61054 m .67625 .60705 L p .67644 .60734 L 0 0 .438 r
F P
0 g
s
.66464 .59168 m .67444 .60466 L p .6761 .60366 L 0 .119 .667 r
F P
0 g
s
.67444 .60466 m .67887 .61054 L .6761 .60366 L p 0 .119 .667 r
F P
0 g
s
.67984 .62125 m .67677 .60678 L p .67887 .61054 L .851 .552 .019 r
F P
0 g
s
.67677 .60678 m .6761 .60366 L .67887 .61054 L p .851 .552 .019 r
F P
0 g
s
.68272 .62911 m .679 .61116 L p .68396 .61854 L .945 .62 .189 r
F P
0 g
s
.679 .61116 m .67887 .61054 L .68396 .61854 L p .945 .62 .189 r
F P
0 g
s
.67887 .61054 m .68272 .62911 L .6799 .62141 L p .851 .552 .019 r
F P
0 g
s
.6799 .62141 m .67984 .62125 L p .67982 .62105 L .851 .552 .019 r
F P
0 g
s
.67982 .62105 m .67887 .61054 L .6799 .62141 L .851 .552 .019 r
F
.68036 .61473 m .67772 .60268 L p .67617 .60361 L 0 0 .388 r
F P
0 g
s
.67628 .60411 m .67617 .60361 L .6761 .60366 L 0 0 .388 r
F
.68036 .61473 m .67617 .60361 L .67628 .60411 L F
.67772 .60268 m .67661 .59761 L .6761 .60366 L p F P
0 g
s
.69016 .62777 m .68396 .61854 L p .68956 .62687 L .638 .185 0 r
F P
0 g
s
.67644 .60734 m .66542 .59271 L .66919 .59784 L 0 0 .438 r
F
.67625 .60705 m .66542 .59271 L p .67644 .60734 L F P
0 g
s
.66542 .59271 m .66464 .59168 L .66919 .59784 L p 0 0 .438 r
F P
0 g
s
.3958 .53107 m .41839 .52043 L .41944 .52362 L p .737 .902 .952 r
F P
0 g
s
.62186 .44336 m .61619 .41098 L .61718 .41519 L p .768 .514 0 r
F P
0 g
s
.57268 .74471 m .58395 .759 L .59821 .76324 L p .315 .659 .972 r
F P
0 g
s
.59821 .76324 m .58397 .74836 L .57268 .74471 L p .315 .659 .972 r
F P
0 g
s
.58397 .74836 m .59821 .76324 L .61199 .76455 L p .454 .745 .991 r
F P
0 g
s
.46174 .38277 m .47177 .35343 L .46826 .35601 L p .133 0 .208 r
F P
0 g
s
.46826 .35601 m .45775 .38616 L .46174 .38277 L p .133 0 .208 r
F P
0 g
s
.61392 .55629 m .6054 .54293 L .60503 .54445 L p 0 .072 .634 r
F P
0 g
s
.61392 .55629 m .60529 .5448 L .61513 .55804 L 0 .072 .634 r
F
.61525 .5582 m .61392 .55629 L p .61513 .55804 L F P
0 g
s
.6054 .54293 m .61392 .55629 L .61246 .55444 L p 0 0 .548 r
F P
0 g
s
.613 .55484 m .61283 .55472 L p .61392 .55629 L 0 .24 .709 r
F P
0 g
s
.62758 .56594 m .613 .55484 L p .61392 .55629 L 0 .24 .709 r
F P
0 g
s
.61283 .55472 m .61246 .55444 L .61392 .55629 L p 0 .24 .709 r
F P
0 g
s
.60559 .54132 m .6054 .54293 L p .61175 .55328 L 0 0 .548 r
F P
0 g
s
.61246 .55444 m .61209 .55372 L p .61175 .55328 L 0 0 .548 r
F P
0 g
s
.61209 .55372 m .60559 .54132 L p .61175 .55328 L 0 0 .548 r
F P
0 g
s
.60503 .54445 m .60518 .54466 L p .60529 .5448 L 0 .072 .634 r
F P
0 g
s
.60518 .54466 m .61525 .5582 L p .60529 .5448 L 0 .072 .634 r
F P
0 g
s
.56149 .73893 m .56985 .7522 L .58395 .759 L p .183 .558 .933 r
F P
0 g
s
.58395 .759 m .57268 .74471 L .56149 .73893 L p .183 .558 .933 r
F P
0 g
s
.70068 .66191 m .69218 .67939 L .68611 .6659 L p .985 .816 .592 r
F P
0 g
s
.68611 .6659 m .69441 .64953 L .70068 .66191 L p .985 .816 .592 r
F P
0 g
s
.60553 .52201 m .60559 .54132 L .60589 .53949 L p 0 0 .261 r
F P
0 g
s
.60589 .53949 m .60703 .5198 L .60553 .52201 L p 0 0 .261 r
F P
0 g
s
.63068 .56886 m .61392 .55629 L .61525 .5582 L p 0 .267 .731 r
F P
0 g
s
.61727 .47714 m .61401 .50684 L .61618 .50231 L p 0 0 .203 r
F P
0 g
s
.61618 .50231 m .61879 .47288 L .61727 .47714 L p 0 0 .203 r
F P
0 g
s
.63068 .56886 m .65283 .5846 L .64833 .57987 L p 0 .288 .732 r
F P
0 g
s
.66919 .59784 m .64833 .57987 L .65283 .5846 L p 0 .158 .648 r
F P
0 g
s
.58284 .35474 m .59313 .38448 L .58863 .38233 L p .869 .469 .274 r
F P
0 g
s
.58863 .38233 m .57914 .35254 L .58284 .35474 L p .869 .469 .274 r
F P
0 g
s
.61199 .76455 m .59487 .74957 L .58397 .74836 L p .454 .745 .991 r
F P
0 g
s
.59487 .74957 m .61199 .76455 L .62462 .76278 L p .579 .804 .985 r
F P
0 g
s
.55082 .73149 m .55647 .74338 L .56985 .7522 L p .076 .462 .886 r
F P
0 g
s
.56985 .7522 m .56149 .73893 L .55082 .73149 L p .076 .462 .886 r
F P
0 g
s
.46606 .37963 m .47553 .35103 L .47177 .35343 L p .211 0 .24 r
F P
0 g
s
.47177 .35343 m .46174 .38277 L .46606 .37963 L p .211 0 .24 r
F P
0 g
s
.43727 .44956 m .43909 .41239 L .43767 .41603 L p 0 0 .253 r
F P
0 g
s
.43767 .41603 m .43578 .45315 L .43727 .44956 L p 0 0 .253 r
F P
0 g
s
.50916 .69442 m .50609 .69794 L .51428 .70653 L p 0 .301 .794 r
F P
0 g
s
.51428 .70653 m .51614 .7023 L .50916 .69442 L p 0 .301 .794 r
F P
0 g
s
.62076 .43855 m .61476 .40689 L .61619 .41098 L p .85 .555 .02 r
F P
0 g
s
.69016 .62777 m .69441 .64953 L .68798 .63853 L p .954 .63 .217 r
F P
0 g
s
.68798 .63853 m .68396 .61854 L .69016 .62777 L p .954 .63 .217 r
F P
0 g
s
.36441 .53787 m .39736 .52783 L .3958 .53107 L p .642 .907 .982 r
F P
0 g
s
.41839 .52043 m .3958 .53107 L .39736 .52783 L p .672 .956 .947 r
F P
0 g
s
.57914 .35254 m .58863 .38233 L .58387 .38041 L p .854 .464 .306 r
F P
0 g
s
.58387 .38041 m .57521 .35051 L .57914 .35254 L p .854 .464 .306 r
F P
0 g
s
.61879 .47288 m .61618 .50231 L .61843 .49725 L p 0 0 .205 r
F P
0 g
s
.61843 .49725 m .62013 .46832 L .61879 .47288 L p 0 0 .205 r
F P
0 g
s
.43224 .49357 m .43165 .46539 L .43128 .46819 L p 0 0 .298 r
F P
0 g
s
.43128 .46819 m .43063 .49543 L .43224 .49357 L p 0 0 .298 r
F P
0 g
s
.47071 .37679 m .47952 .34882 L .47553 .35103 L p .282 0 .268 r
F P
0 g
s
.47553 .35103 m .46606 .37963 L .47071 .37679 L p .282 0 .268 r
F P
0 g
s
.25323 .63429 m .26099 .60424 L .25596 .61549 L p 0 0 0 r
F P
0 g
s
.25596 .61549 m .24799 .64705 L .25323 .63429 L p 0 0 0 r
F P
0 g
s
.69692 .6939 m .67738 .70239 L .67315 .68792 L p .92 .839 .748 r
F P
0 g
s
.67315 .68792 m .69218 .67939 L .69692 .6939 L p .92 .839 .748 r
F P
0 g
s
.62462 .76278 m .6049 .74819 L .6136 .74424 L p .671 .831 .961 r
F P
0 g
s
.6136 .74424 m .6355 .75795 L .62462 .76278 L p .671 .831 .961 r
F P
0 g
s
.62462 .76278 m .6049 .74819 L .59487 .74957 L p .579 .804 .985 r
F P
0 g
s
.67888 .73153 m .6534 .72836 L .65407 .71529 L p .853 .847 .837 r
F P
0 g
s
.65407 .71529 m .67953 .71718 L .67888 .73153 L p .853 .847 .837 r
F P
0 g
s
.60703 .5198 m .60589 .53949 L .60654 .53729 L p 0 0 .22 r
F P
0 g
s
.60654 .53729 m .60855 .51725 L .60703 .5198 L p 0 0 .22 r
F P
0 g
s
.541 .72294 m .54425 .73319 L .55647 .74338 L p .005 .385 .845 r
F P
0 g
s
.55647 .74338 m .55082 .73149 L .541 .72294 L p .005 .385 .845 r
F P
0 g
s
.57521 .35051 m .58387 .38041 L .57889 .37869 L p .837 .457 .332 r
F P
0 g
s
.57889 .37869 m .57108 .34865 L .57521 .35051 L p .837 .457 .332 r
F P
0 g
s
.61392 .55629 m .63068 .56886 L .62758 .56594 L p 0 .24 .709 r
F P
0 g
s
.64833 .57987 m .62758 .56594 L .63068 .56886 L p 0 .288 .732 r
F P
0 g
s
.29595 .5673 m .33207 .5472 L .32483 .55305 L p .657 .972 .861 r
F P
0 g
s
.32483 .55305 m .28723 .57565 L .29595 .5673 L p .657 .972 .861 r
F P
0 g
s
.36441 .53787 m .32483 .55305 L .33207 .5472 L p .603 .938 .947 r
F P
0 g
s
.47565 .37428 m .48373 .34682 L .47952 .34882 L p .346 .038 .291 r
F P
0 g
s
.47952 .34882 m .47071 .37679 L .47565 .37428 L p .346 .038 .291 r
F P
0 g
s
.43891 .44569 m .44081 .40867 L .43909 .41239 L p 0 0 .276 r
F P
0 g
s
.43909 .41239 m .43727 .44956 L .43891 .44569 L p 0 0 .276 r
F P
0 g
s
.61476 .40689 m .62076 .43855 L .61906 .43404 L p .909 .583 .103 r
F P
0 g
s
.61906 .43404 m .6129 .40295 L .61476 .40689 L p .909 .583 .103 r
F P
0 g
s
.29662 .71145 m .26648 .69679 L .2768 .70576 L p 0 .403 .842 r
F P
0 g
s
.2768 .70576 m .3056 .71932 L .29662 .71145 L p 0 .403 .842 r
F P
0 g
s
.26123 .6733 m .24799 .64705 L .24813 .65933 L p 0 .015 .568 r
F P
0 g
s
.24813 .65933 m .2612 .68578 L .26123 .6733 L p 0 .015 .568 r
F P
0 g
s
.62013 .46832 m .61843 .49725 L .62064 .49174 L p 0 0 .213 r
F P
0 g
s
.62064 .49174 m .62123 .46352 L .62013 .46832 L p 0 0 .213 r
F P
0 g
s
.57108 .34865 m .57889 .37869 L .57372 .37713 L p .821 .449 .352 r
F P
0 g
s
.57372 .37713 m .56676 .34696 L .57108 .34865 L p .821 .449 .352 r
F P
0 g
s
.33207 .5472 m .3698 .53411 L .36441 .53787 L p .603 .938 .947 r
F P
0 g
s
.39736 .52783 m .36441 .53787 L .3698 .53411 L p .526 .907 .946 r
F P
0 g
s
.48087 .37214 m .48813 .34505 L .48373 .34682 L p .404 .088 .312 r
F P
0 g
s
.48373 .34682 m .47565 .37428 L .48087 .37214 L p .404 .088 .312 r
F P
0 g
s
.50271 .68875 m .49855 .69173 L .50609 .69794 L p .046 .425 .867 r
F P
0 g
s
.50609 .69794 m .50916 .69442 L .50271 .68875 L p .046 .425 .867 r
F P
0 g
s
.28723 .57565 m .26099 .60424 L .27067 .59346 L p .539 .829 .494 r
F P
0 g
s
.27067 .59346 m .29595 .5673 L .28723 .57565 L p .539 .829 .494 r
F P
0 g
s
.43406 .49168 m .43234 .46255 L .43165 .46539 L p 0 0 .368 r
F P
0 g
s
.43165 .46539 m .43224 .49357 L .43406 .49168 L p 0 0 .368 r
F P
0 g
s
.60855 .51725 m .60654 .53729 L .60775 .53457 L p 0 0 .214 r
F P
0 g
s
.60775 .53457 m .61019 .51428 L .60855 .51725 L p 0 0 .214 r
F P
0 g
s
.39861 .72187 m .37304 .72438 L .39313 .7197 L p .076 0 0 r
F P
0 g
s
.39313 .7197 m .41508 .71682 L .39861 .72187 L p .076 0 0 r
F P
0 g
s
.41508 .71682 m .39313 .7197 L .41261 .71356 L p .071 0 0 r
F P
0 g
s
.56676 .34696 m .57372 .37713 L .56838 .37571 L p .804 .44 .368 r
F P
0 g
s
.56838 .37571 m .56226 .34544 L .56676 .34696 L p .804 .44 .368 r
F P
0 g
s
.6355 .75795 m .6136 .74424 L .62059 .73791 L p .733 .837 .929 r
F P
0 g
s
.62059 .73791 m .6441 .75031 L .6355 .75795 L p .733 .837 .929 r
F P
0 g
s
.53221 .71394 m .53345 .72242 L .54425 .73319 L p 0 .335 .816 r
F P
0 g
s
.54425 .73319 m .541 .72294 L .53221 .71394 L p 0 .335 .816 r
F P
0 g
s
.41261 .71356 m .43107 .71054 L .41508 .71682 L p .071 0 0 r
F P
0 g
s
.43107 .71054 m .41261 .71356 L .43072 .70669 L p .04 0 0 r
F P
0 g
s
.48087 .37214 m .48813 .34505 L .49271 .34351 L p .451 .129 .328 r
F P
0 g
s
.44073 .44154 m .44284 .40489 L .44081 .40867 L p 0 0 .295 r
F P
0 g
s
.44081 .40867 m .43891 .44569 L .44073 .44154 L p 0 0 .295 r
F P
0 g
s
.6129 .40295 m .61906 .43404 L .61676 .42991 L p .942 .598 .181 r
F P
0 g
s
.61676 .42991 m .61061 .39922 L .6129 .40295 L p .942 .598 .181 r
F P
0 g
s
.38241 .7251 m .35324 .72701 L .37304 .72438 L p .042 0 0 r
F P
0 g
s
.37304 .72438 m .39861 .72187 L .38241 .7251 L p .042 0 0 r
F P
0 g
s
.62123 .46352 m .62064 .49174 L .62266 .48586 L p 0 0 .222 r
F P
0 g
s
.62266 .48586 m .62202 .45854 L .62123 .46352 L p 0 0 .222 r
F P
0 g
s
.56226 .34544 m .56838 .37571 L .5629 .37439 L p .787 .43 .38 r
F P
0 g
s
.5629 .37439 m .55762 .34408 L .56226 .34544 L p .787 .43 .38 r
F P
0 g
s
.64833 .57987 m .66919 .59784 L .66464 .59168 L p 0 .255 .736 r
F P
0 g
s
.43072 .70669 m .44597 .70371 L .43107 .71054 L p .04 0 0 r
F P
0 g
s
.44597 .70371 m .43072 .70669 L .44691 .69989 L p 0 0 0 r
F P
0 g
s
.3698 .53411 m .40074 .52534 L .39736 .52783 L p .526 .907 .946 r
F P
0 g
s
.48632 .3704 m .49271 .34351 L .49744 .34222 L p .489 .163 .341 r
F P
0 g
s
.49271 .34351 m .48632 .3704 L .48087 .37214 L p .451 .129 .328 r
F P
0 g
s
.62758 .56594 m .64833 .57987 L .64465 .57558 L p 0 .378 .812 r
F P
0 g
s
.66464 .59168 m .64465 .57558 L .64833 .57987 L p 0 .255 .736 r
F P
0 g
s
.60559 .54132 m .61246 .55444 L .61135 .55248 L p 0 0 .511 r
F P
0 g
s
.61135 .55248 m .60589 .53949 L .60559 .54132 L p 0 0 .511 r
F P
0 g
s
.55762 .34408 m .5629 .37439 L .55731 .37316 L p .77 .418 .389 r
F P
0 g
s
.55731 .37316 m .55285 .34288 L .55762 .34408 L p .77 .418 .389 r
F P
0 g
s
.49198 .36905 m .49744 .34222 L .50231 .34117 L p .523 .195 .353 r
F P
0 g
s
.49744 .34222 m .49198 .36905 L .48632 .3704 L p .489 .163 .341 r
F P
0 g
s
.4962 .68563 m .49094 .68825 L .49855 .69173 L p .17 .587 .937 r
F P
0 g
s
.49855 .69173 m .50271 .68875 L .4962 .68563 L p .17 .587 .937 r
F P
0 g
s
.61019 .51428 m .60775 .53457 L .60964 .53121 L p 0 0 .243 r
F P
0 g
s
.60964 .53121 m .612 .51083 L .61019 .51428 L p 0 0 .243 r
F P
0 g
s
.35324 .72701 m .38241 .7251 L .36731 .72611 L p 0 0 0 r
F P
0 g
s
.36731 .72611 m .33475 .72717 L .35324 .72701 L p 0 0 0 r
F P
0 g
s
.44691 .69989 m .45934 .69705 L .44597 .70371 L p 0 0 0 r
F P
0 g
s
.45934 .69705 m .44691 .69989 L .4609 .69396 L p 0 0 0 r
F P
0 g
s
.44276 .43716 m .44517 .40107 L .44284 .40489 L p 0 0 .311 r
F P
0 g
s
.44284 .40489 m .44073 .44154 L .44276 .43716 L p 0 0 .311 r
F P
0 g
s
.43595 .48963 m .43329 .4596 L .43234 .46255 L p 0 0 .411 r
F P
0 g
s
.43234 .46255 m .43406 .49168 L .43595 .48963 L p 0 0 .411 r
F P
0 g
s
.61061 .39922 m .61676 .42991 L .61385 .42623 L p .952 .601 .251 r
F P
0 g
s
.61385 .42623 m .60788 .39573 L .61061 .39922 L p .952 .601 .251 r
F P
0 g
s
.55285 .34288 m .55731 .37316 L .5516 .372 L p .753 .406 .395 r
F P
0 g
s
.5516 .372 m .54797 .34185 L .55285 .34288 L p .753 .406 .395 r
F P
0 g
s
.69441 .64953 m .68611 .6659 L .67991 .65395 L p .976 .802 .604 r
F P
0 g
s
.67991 .65395 m .68798 .63853 L .69441 .64953 L p .976 .802 .604 r
F P
0 g
s
.49779 .3681 m .50231 .34117 L .50727 .34037 L p .555 .225 .363 r
F P
0 g
s
.50231 .34117 m .49779 .3681 L .49198 .36905 L p .523 .195 .353 r
F P
0 g
s
.62202 .45854 m .62266 .48586 L .62434 .47975 L p 0 0 .225 r
F P
0 g
s
.62434 .47975 m .62243 .45345 L .62202 .45854 L p 0 0 .225 r
F P
0 g
s
.52451 .70514 m .52413 .71186 L .53345 .72242 L p 0 .315 .805 r
F P
0 g
s
.53345 .72242 m .53221 .71394 L .52451 .70514 L p 0 .315 .805 r
F P
0 g
s
.54797 .34185 m .5516 .372 L .5458 .37092 L p .735 .392 .399 r
F P
0 g
s
.5458 .37092 m .543 .34099 L .54797 .34185 L p .735 .392 .399 r
F P
0 g
s
.50373 .36752 m .50727 .34037 L .51232 .33981 L p .584 .252 .373 r
F P
0 g
s
.50727 .34037 m .50373 .36752 L .49779 .3681 L p .555 .225 .363 r
F P
0 g
s
.61246 .55444 m .62758 .56594 L .62508 .56314 L p 0 .299 .772 r
F P
0 g
s
.64465 .57558 m .62508 .56314 L .62758 .56594 L p 0 .378 .812 r
F P
0 g
s
.4609 .69396 m .47094 .69131 L .45934 .69705 L p 0 0 0 r
F P
0 g
s
.47094 .69131 m .4609 .69396 L .47269 .68967 L p 0 0 0 r
F P
0 g
s
.543 .34099 m .5458 .37092 L .53992 .36993 L p .717 .377 .401 r
F P
0 g
s
.53992 .36993 m .53795 .3403 L .543 .34099 L p .717 .377 .401 r
F P
0 g
s
.42589 .51281 m .43063 .49543 L .42941 .49738 L p .03 0 .203 r
F P
0 g
s
.42941 .49738 m .42269 .51404 L .42589 .51281 L p .03 0 .203 r
F P
0 g
s
.50975 .3673 m .51232 .33981 L .51743 .33948 L p .611 .278 .381 r
F P
0 g
s
.51232 .33981 m .50975 .3673 L .50373 .36752 L p .584 .252 .373 r
F P
0 g
s
.68396 .61854 m .68798 .63853 L .68272 .62911 L p .945 .62 .189 r
F P
0 g
s
.67953 .71718 m .65407 .71529 L .6525 .70176 L p .858 .819 .809 r
F P
0 g
s
.6525 .70176 m .67738 .70239 L .67953 .71718 L p .858 .819 .809 r
F P
0 g
s
.48907 .68515 m .48254 .68763 L .49094 .68825 L p .263 .74 .935 r
F P
0 g
s
.49094 .68825 m .4962 .68563 L .48907 .68515 L p .263 .74 .935 r
F P
0 g
s
.6441 .75031 m .62059 .73791 L .62564 .72953 L p .776 .831 .895 r
F P
0 g
s
.62564 .72953 m .65011 .74026 L .6441 .75031 L p .776 .831 .895 r
F P
0 g
s
.53795 .3403 m .53992 .36993 L .53396 .36904 L p .699 .36 .4 r
F P
0 g
s
.53396 .36904 m .53285 .3398 L .53795 .3403 L p .699 .36 .4 r
F P
0 g
s
.51581 .36738 m .51743 .33948 L .52256 .33937 L p .635 .301 .388 r
F P
0 g
s
.51743 .33948 m .51581 .36738 L .50975 .3673 L p .611 .278 .381 r
F P
0 g
s
.53285 .3398 m .53396 .36904 L .52794 .36829 L p .679 .342 .398 r
F P
0 g
s
.52794 .36829 m .52771 .33948 L .53285 .3398 L p .679 .342 .398 r
F P
0 g
s
.52189 .36772 m .52256 .33937 L .52771 .33948 L p .658 .323 .394 r
F P
0 g
s
.52256 .33937 m .52189 .36772 L .51581 .36738 L p .635 .301 .388 r
F P
0 g
s
.612 .51083 m .60964 .53121 L .61225 .52709 L p 0 0 .299 r
F P
0 g
s
.61225 .52709 m .61401 .50684 L .612 .51083 L p 0 0 .299 r
F P
0 g
s
.52771 .33948 m .52794 .36829 L .52189 .36772 L p .658 .323 .394 r
F P
0 g
s
.62508 .56314 m .61135 .55248 L .61246 .55444 L p 0 .299 .772 r
F P
0 g
s
.48078 .68717 m .47269 .68967 L .47553 .68908 L p .261 .769 .776 r
F P
0 g
s
.47553 .68908 m .48254 .68763 L p .48078 .68717 L .261 .769 .776 r
F P
0 g
s
.4876 .68452 m .48078 .68717 L .48907 .68515 L p .29 .789 .8 r
F P
0 g
s
.48078 .68717 m .4876 .68452 L .48516 .68557 L p 0 0 0 r
F P
0 g
s
.48254 .68763 m .48907 .68515 L .48078 .68717 L p .261 .769 .776 r
F P
0 g
s
.48516 .68557 m .47961 .68796 L p .48078 .68717 L 0 0 0 r
F P
0 g
s
.47269 .68967 m .48078 .68717 L .47094 .69131 L p 0 0 0 r
F P
0 g
s
.44504 .43258 m .44782 .39724 L .44517 .40107 L p 0 0 .325 r
F P
0 g
s
.44517 .40107 m .44276 .43716 L .44504 .43258 L p 0 0 .325 r
F P
0 g
s
.60788 .39573 m .61385 .42623 L .61037 .42303 L p .947 .598 .31 r
F P
0 g
s
.61037 .42303 m .60475 .39251 L .60788 .39573 L p .947 .598 .31 r
F P
0 g
s
.29214 .70138 m .2612 .68578 L .26648 .69679 L p .216 .451 .871 r
F P
0 g
s
.26648 .69679 m .29662 .71145 L .29214 .70138 L p .216 .451 .871 r
F P
0 g
s
.69218 .67939 m .67315 .68792 L .66777 .67446 L p .91 .813 .739 r
F P
0 g
s
.66777 .67446 m .68611 .6659 L .69218 .67939 L p .91 .813 .739 r
F P
0 g
s
.62243 .45345 m .62434 .47975 L .6255 .47358 L p 0 0 .217 r
F P
0 g
s
.35412 .72462 m .31856 .72461 L .33475 .72717 L p .184 .697 .893 r
F P
0 g
s
.33475 .72717 m .36731 .72611 L .35412 .72462 L p .184 .697 .893 r
F P
0 g
s
.60589 .53949 m .61135 .55248 L .61103 .55021 L p 0 0 .531 r
F P
0 g
s
.61103 .55021 m .60654 .53729 L .60589 .53949 L p 0 0 .531 r
F P
0 g
s
.43778 .48727 m .43445 .45649 L .43329 .4596 L p .001 0 .436 r
F P
0 g
s
.43329 .4596 m .43595 .48963 L .43778 .48727 L p .001 0 .436 r
F P
0 g
s
.33207 .5472 m .29595 .5673 L .30799 .55998 L p .418 .842 .687 r
F P
0 g
s
.3698 .53411 m .33207 .5472 L .34204 .5424 L p .427 .871 .845 r
F P
0 g
s
.30799 .55998 m .34204 .5424 L .33207 .5472 L p .418 .842 .687 r
F P
0 g
s
.34204 .5424 m .37726 .53127 L .3698 .53411 L p .427 .871 .845 r
F P
0 g
s
.26329 .62167 m .27067 .59346 L .26099 .60424 L p 0 0 .247 r
F P
0 g
s
.26099 .60424 m .25323 .63429 L .26329 .62167 L p 0 0 .247 r
F P
0 g
s
.51778 .69719 m .51614 .7023 L .52413 .71186 L p 0 .327 .813 r
F P
0 g
s
.52413 .71186 m .52451 .70514 L .51778 .69719 L p 0 .327 .813 r
F P
0 g
s
.61401 .50684 m .61225 .52709 L .61553 .52216 L p 0 0 .369 r
F P
0 g
s
.61553 .52216 m .61618 .50231 L .61401 .50684 L p 0 0 .369 r
F P
0 g
s
.44764 .4279 m .45079 .39345 L .44782 .39724 L p .01 0 .339 r
F P
0 g
s
.44782 .39724 m .44504 .43258 L .44764 .4279 L p .01 0 .339 r
F P
0 g
s
.60475 .39251 m .61037 .42303 L .60636 .42035 L p .933 .59 .358 r
F P
0 g
s
.60636 .42035 m .60123 .38955 L .60475 .39251 L p .933 .59 .358 r
F P
0 g
s
.2664 .65996 m .25323 .63429 L .24799 .64705 L p .179 .178 .62 r
F P
0 g
s
.24799 .64705 m .26123 .6733 L .2664 .65996 L p .179 .178 .62 r
F P
0 g
s
.42949 .51181 m .43224 .49357 L .43063 .49543 L p .156 0 .326 r
F P
0 g
s
.43063 .49543 m .42589 .51281 L .42949 .51181 L p .156 0 .326 r
F P
0 g
s
.62508 .56314 m .64465 .57558 L .64267 .5715 L p .174 .526 .921 r
F P
0 g
s
.64465 .57558 m .66464 .59168 L .66216 .58616 L p .081 .431 .873 r
F P
0 g
s
.66216 .58616 m .64267 .5715 L .64465 .57558 L p .081 .431 .873 r
F P
0 g
s
.6761 .60366 m .66216 .58616 L .66464 .59168 L p 0 .119 .667 r
F P
0 g
s
.43948 .48449 m .43578 .45315 L .43445 .45649 L p 0 0 .448 r
F P
0 g
s
.43445 .45649 m .43778 .48727 L .43948 .48449 L p 0 0 .448 r
F P
0 g
s
.60654 .53729 m .61103 .55021 L .61183 .54741 L p .05 .087 .579 r
F P
0 g
s
.61183 .54741 m .60775 .53457 L .60654 .53729 L p .05 .087 .579 r
F P
0 g
s
.28409 .58359 m .30799 .55998 L .29595 .5673 L p 0 0 0 r
F P
0 g
s
.29595 .5673 m .27067 .59346 L .28409 .58359 L p 0 0 0 r
F P
0 g
s
.61618 .50231 m .61553 .52216 L .61932 .51643 L p .087 0 .442 r
F P
0 g
s
.61932 .51643 m .61843 .49725 L .61618 .50231 L p .087 0 .442 r
F P
0 g
s
.45059 .4232 m .4541 .38974 L .45079 .39345 L p .072 0 .354 r
F P
0 g
s
.45079 .39345 m .44764 .4279 L .45059 .4232 L p .072 0 .354 r
F P
0 g
s
.61135 .55248 m .62508 .56314 L .62384 .56023 L p .101 .43 .872 r
F P
0 g
s
.64267 .5715 m .62384 .56023 L .62508 .56314 L p .174 .526 .921 r
F P
0 g
s
.62384 .56023 m .61103 .55021 L .61135 .55248 L p .101 .43 .872 r
F P
0 g
s
.65011 .74026 m .62564 .72953 L .62866 .71956 L p .804 .817 .861 r
F P
0 g
s
.62866 .71956 m .6534 .72836 L .65011 .74026 L p .804 .817 .861 r
F P
0 g
s
.60123 .38955 m .60636 .42035 L .60189 .41816 L p .914 .58 .396 r
F P
0 g
s
.60189 .41816 m .59734 .38688 L .60123 .38955 L p .914 .58 .396 r
F P
0 g
s
.51179 .69064 m .50916 .69442 L .51614 .7023 L p .049 .375 .841 r
F P
0 g
s
.51614 .7023 m .51778 .69719 L .51179 .69064 L p .049 .375 .841 r
F P
0 g
s
.34359 .72057 m .3056 .71932 L .31856 .72461 L p .327 .714 .982 r
F P
0 g
s
.31856 .72461 m .35412 .72462 L .34359 .72057 L p .327 .714 .982 r
F P
0 g
s
.41143 .52245 m .42589 .51281 L .42269 .51404 L p .083 0 0 r
F P
0 g
s
.42269 .51404 m .40559 .52358 L .41143 .52245 L p .083 0 0 r
F P
0 g
s
.61843 .49725 m .61932 .51643 L .62339 .50995 L p .163 .082 .51 r
F P
0 g
s
.62339 .50995 m .62064 .49174 L .61843 .49725 L p .163 .082 .51 r
F P
0 g
s
.68798 .63853 m .67991 .65395 L .67484 .64382 L p .975 .811 .616 r
F P
0 g
s
.67484 .64382 m .68272 .62911 L .68798 .63853 L p .975 .811 .616 r
F P
0 g
s
.45396 .41861 m .45775 .38616 L .4541 .38974 L p .139 0 .369 r
F P
0 g
s
.4541 .38974 m .45059 .4232 L .45396 .41861 L p .139 0 .369 r
F P
0 g
s
.44099 .48119 m .43727 .44956 L .43578 .45315 L p 0 0 .447 r
F P
0 g
s
.43578 .45315 m .43948 .48449 L .44099 .48119 L p 0 0 .447 r
F P
0 g
s
.43316 .51086 m .43406 .49168 L .43224 .49357 L p .216 .03 .4 r
F P
0 g
s
.43224 .49357 m .42949 .51181 L .43316 .51086 L p .216 .03 .4 r
F P
0 g
s
.60775 .53457 m .61183 .54741 L .61399 .54388 L p .252 .214 .62 r
F P
0 g
s
.61399 .54388 m .60964 .53121 L .60775 .53457 L p .252 .214 .62 r
F P
0 g
s
.67738 .70239 m .6525 .70176 L .64926 .68849 L p .857 .794 .789 r
F P
0 g
s
.64926 .68849 m .67315 .68792 L .67738 .70239 L p .857 .794 .789 r
F P
0 g
s
.59734 .38688 m .60189 .41816 L .59703 .41644 L p .894 .57 .427 r
F P
0 g
s
.59703 .41644 m .59313 .38448 L .59734 .38688 L p .894 .57 .427 r
F P
0 g
s
.40559 .52358 m .37726 .53127 L .38609 .52931 L p 0 0 0 r
F P
0 g
s
.62064 .49174 m .62339 .50995 L .62746 .50286 L p .22 .157 .57 r
F P
0 g
s
.62746 .50286 m .62266 .48586 L .62064 .49174 L p .22 .157 .57 r
F P
0 g
s
.50618 .68592 m .50271 .68875 L .50916 .69442 L p .12 .466 .892 r
F P
0 g
s
.50916 .69442 m .51179 .69064 L .50618 .68592 L p .12 .466 .892 r
F P
0 g
s
.37726 .53127 m .34204 .5424 L .35382 .53867 L p .215 .726 .676 r
F P
0 g
s
.35382 .53867 m .38609 .52931 L .37726 .53127 L p .215 .726 .676 r
F P
0 g
s
.61103 .55021 m .62384 .56023 L .62438 .55692 L p .378 .528 .88 r
F P
0 g
s
.62438 .55692 m .61183 .54741 L .61103 .55021 L p .378 .528 .88 r
F P
0 g
s
.55524 .72971 m .56149 .73893 L .57268 .74471 L p .187 .564 .935 r
F P
0 g
s
.57298 .73655 m .56409 .73393 L p .56675 .73586 L .334 .664 .974 r
F P
0 g
s
.58397 .74836 m .57298 .73655 L p .56675 .73586 L .334 .664 .974 r
F P
0 g
s
.58158 .73733 m .57298 .73655 L p .57603 .73837 L .471 .743 .988 r
F P
0 g
s
.59487 .74957 m .58158 .73733 L p .57603 .73837 L .471 .743 .988 r
F P
0 g
s
.58158 .73733 m .58956 .73614 L p .58717 .73628 L .28 .781 .857 r
F P
0 g
s
.57298 .73655 m .58158 .73733 L p .5794 .73726 L 0 .574 .72 r
F P
0 g
s
.56409 .73393 m .57268 .74471 L .58397 .74836 L p .334 .664 .974 r
F P
0 g
s
.57298 .73655 m .58397 .74836 L .59487 .74957 L p .471 .743 .988 r
F P
0 g
s
.56668 .73688 m .57298 .73655 L p .5794 .73726 L 0 .574 .72 r
F P
0 g
s
.57385 .73703 m .58158 .73733 L p .58717 .73628 L .28 .781 .857 r
F P
0 g
s
.56409 .73393 m .57298 .73655 L p .57112 .7364 L .281 0 0 r
F P
0 g
s
.57268 .74471 m .56409 .73393 L p .55742 .73158 L .187 .564 .935 r
F P
0 g
s
.5593 .73546 m .56409 .73393 L p .57112 .7364 L .281 0 0 r
F P
0 g
s
.56409 .73393 m .55524 .72971 L p .55742 .73158 L .187 .564 .935 r
F P
0 g
s
.45777 .41425 m .46174 .38277 L .45775 .38616 L p .209 .015 .384 r
F P
0 g
s
.45775 .38616 m .45396 .41861 L .45777 .41425 L p .209 .015 .384 r
F P
0 g
s
.62384 .56023 m .64267 .5715 L .6431 .56731 L p .442 .61 .919 r
F P
0 g
s
.64267 .5715 m .66216 .58616 L .66261 .58097 L p .388 .548 .893 r
F P
0 g
s
.66261 .58097 m .6431 .56731 L .64267 .5715 L p .388 .548 .893 r
F P
0 g
s
.68611 .6659 m .66777 .67446 L .66231 .66254 L p .9 .8 .74 r
F P
0 g
s
.66231 .66254 m .67991 .65395 L .68611 .6659 L p .9 .8 .74 r
F P
0 g
s
.29233 .68959 m .26123 .6733 L .2612 .68578 L p .361 .456 .822 r
F P
0 g
s
.2612 .68578 m .29214 .70138 L .29233 .68959 L p .361 .456 .822 r
F P
0 g
s
.55082 .73149 m .56149 .73893 L p .54853 .72604 L .044 .453 .878 r
F P
0 g
s
.54736 .72538 m .55082 .73149 L p .54853 .72604 L .044 .453 .878 r
F P
0 g
s
.55524 .72971 m .54671 .72423 L p .54838 .72589 L .044 .453 .878 r
F P
0 g
s
.56149 .73893 m .55524 .72971 L p .54838 .72589 L .044 .453 .878 r
F P
0 g
s
.55524 .72971 m .56409 .73393 L p .56262 .73381 L .504 0 0 r
F P
0 g
s
.5519 .73294 m .55524 .72971 L p .56262 .73381 L .504 0 0 r
F P
0 g
s
.541 .72294 m .55082 .73149 L p .54277 .72248 L 0 .343 .809 r
F P
0 g
s
.53871 .71793 m .53988 .72049 L p .54277 .72248 L 0 .343 .809 r
F P
0 g
s
.53988 .72049 m .541 .72294 L p .54277 .72248 L 0 .343 .809 r
F P
0 g
s
.54671 .72423 m .53871 .71793 L p .53989 .71924 L 0 .343 .809 r
F P
0 g
s
.55082 .73149 m .54671 .72423 L p .53989 .71924 L 0 .343 .809 r
F P
0 g
s
.54671 .72423 m .55524 .72971 L p .55418 .72969 L .657 .116 0 r
F P
0 g
s
.54671 .72423 m .54736 .72538 L p .54853 .72604 L .044 .453 .878 r
F P
0 g
s
.54465 .72955 m .54671 .72423 L p .55418 .72969 L .657 .116 0 r
F P
0 g
s
.5519 .73294 m .54465 .72955 L p .55326 .72968 L .657 .116 0 r
F P
0 g
s
.55498 .72971 m .55432 .73041 L .55326 .72968 L .657 .116 0 r
F
.55432 .73041 m .5519 .73294 L .55326 .72968 L F
.55524 .72971 m .55515 .7298 L p .55498 .72971 L F P
0 g
s
.55515 .7298 m .5519 .73294 L p .55498 .72971 L .657 .116 0 r
F P
0 g
s
.6431 .56731 m .62438 .55692 L .62384 .56023 L p .442 .61 .919 r
F P
0 g
s
.60964 .53121 m .61399 .54388 L .61758 .53942 L p .394 .313 .646 r
F P
0 g
s
.61758 .53942 m .61225 .52709 L .60964 .53121 L p .394 .313 .646 r
F P
0 g
s
.44233 .47729 m .43891 .44569 L .43727 .44956 L p 0 0 .437 r
F P
0 g
s
.43727 .44956 m .44099 .48119 L .44233 .47729 L p 0 0 .437 r
F P
0 g
s
.32225 .55384 m .35382 .53867 L .34204 .5424 L p 0 0 0 r
F P
0 g
s
.34204 .5424 m .30799 .55998 L .32225 .55384 L p 0 0 0 r
F P
0 g
s
.59313 .38448 m .59703 .41644 L .59187 .4151 L p .874 .56 .452 r
F P
0 g
s
.59187 .4151 m .58863 .38233 L .59313 .38448 L p .874 .56 .452 r
F P
0 g
s
.66216 .58616 m .6761 .60366 L .67661 .59761 L p .211 .361 .797 r
F P
0 g
s
.67661 .59761 m .66261 .58097 L .66216 .58616 L p .211 .361 .797 r
F P
0 g
s
.58158 .73733 m .59487 .74957 L .6049 .74819 L p .587 .796 .979 r
F P
0 g
s
.62266 .48586 m .62746 .50286 L .63121 .49535 L p .258 .218 .621 r
F P
0 g
s
.63121 .49535 m .62434 .47975 L .62266 .48586 L p .258 .218 .621 r
F P
0 g
s
.6534 .72836 m .62866 .71956 L .62975 .70857 L p .821 .799 .831 r
F P
0 g
s
.62975 .70857 m .65407 .71529 L .6534 .72836 L p .821 .799 .831 r
F P
0 g
s
.41772 .52176 m .42949 .51181 L .42589 .51281 L p .233 0 .026 r
F P
0 g
s
.42589 .51281 m .41143 .52245 L .41772 .52176 L p .233 0 .026 r
F P
0 g
s
.43661 .50971 m .43595 .48963 L .43406 .49168 L p .232 .071 .446 r
F P
0 g
s
.43406 .49168 m .43316 .51086 L .43661 .50971 L p .232 .071 .446 r
F P
0 g
s
.46203 .41023 m .46606 .37963 L .46174 .38277 L p .279 .065 .399 r
F P
0 g
s
.46174 .38277 m .45777 .41425 L .46203 .41023 L p .279 .065 .399 r
F P
0 g
s
.50056 .68331 m .4962 .68563 L .50271 .68875 L p .207 .605 .948 r
F P
0 g
s
.50271 .68875 m .50618 .68592 L .50056 .68331 L p .207 .605 .948 r
F P
0 g
s
.61225 .52709 m .61758 .53942 L .62249 .53392 L p .481 .382 .666 r
F P
0 g
s
.62249 .53392 m .61553 .52216 L .61225 .52709 L p .481 .382 .666 r
F P
0 g
s
.33633 .71407 m .29662 .71145 L .3056 .71932 L p .428 .676 .966 r
F P
0 g
s
.3056 .71932 m .34359 .72057 L .33633 .71407 L p .428 .676 .966 r
F P
0 g
s
.4359 .70964 m .41508 .71682 L .43107 .71054 L p 0 0 0 r
F P
0 g
s
.43107 .71054 m .44826 .7042 L .4359 .70964 L p 0 0 0 r
F P
0 g
s
.44826 .7042 m .43107 .71054 L .44597 .70371 L p 0 0 0 r
F P
0 g
s
.61183 .54741 m .62438 .55692 L .62703 .55291 L p .536 .556 .822 r
F P
0 g
s
.62703 .55291 m .61399 .54388 L .61183 .54741 L p .536 .556 .822 r
F P
0 g
s
.58863 .38233 m .59187 .4151 L .58648 .41408 L p .855 .551 .472 r
F P
0 g
s
.58648 .41408 m .58387 .38041 L .58863 .38233 L p .855 .551 .472 r
F P
0 g
s
.44597 .70371 m .45985 .69837 L .44826 .7042 L p 0 0 0 r
F P
0 g
s
.45985 .69837 m .44597 .70371 L .45934 .69705 L p 0 0 0 r
F P
0 g
s
.27722 .60973 m .28409 .58359 L .27067 .59346 L p .207 0 .363 r
F P
0 g
s
.27067 .59346 m .26329 .62167 L .27722 .60973 L p .207 0 .363 r
F P
0 g
s
.53871 .71793 m .54671 .72423 L p .54488 .7245 L .751 .265 .084 r
F P
0 g
s
.53221 .71394 m .541 .72294 L p .53211 .71216 L 0 .241 .736 r
F P
0 g
s
.541 .72294 m .53871 .71793 L .53138 .71127 L p 0 .241 .736 r
F P
0 g
s
.53767 .72557 m .53864 .71847 L p .54488 .7245 L .751 .265 .084 r
F P
0 g
s
.53864 .71847 m .53871 .71793 L p .54488 .7245 L .751 .265 .084 r
F P
0 g
s
.53138 .71127 m .53146 .71153 L p .53211 .71216 L 0 .241 .736 r
F P
0 g
s
.53146 .71153 m .53221 .71394 L p .53211 .71216 L 0 .241 .736 r
F P
0 g
s
.41508 .71682 m .4183 .71571 L p .42324 .71411 L 0 0 0 r
F P
0 g
s
.4183 .71571 m .4359 .70964 L .42324 .71411 L p 0 0 0 r
F P
0 g
s
.44133 .70946 m .42324 .71411 L .4359 .70964 L p 0 0 0 r
F P
0 g
s
.43214 .71152 m .42722 .71281 L p .42324 .71411 L .211 .733 .737 r
F P
0 g
s
.42722 .71281 m .41083 .71712 L .42324 .71411 L p .211 .733 .737 r
F P
0 g
s
.42324 .71411 m .39861 .72187 L .41508 .71682 L p 0 0 0 r
F P
0 g
s
.44356 .47279 m .44073 .44154 L .43891 .44569 L p 0 0 .42 r
F P
0 g
s
.43891 .44569 m .44233 .47729 L .44356 .47279 L p 0 0 .42 r
F P
0 g
s
.6049 .74819 m .58956 .73614 L .59662 .733 L p .676 .823 .954 r
F P
0 g
s
.59662 .733 m .6136 .74424 L .6049 .74819 L p .676 .823 .954 r
F P
0 g
s
.6049 .74819 m .58956 .73614 L .58158 .73733 L p .587 .796 .979 r
F P
0 g
s
.45934 .69705 m .47036 .69275 L .45985 .69837 L p 0 0 0 r
F P
0 g
s
.47036 .69275 m .45934 .69705 L .47094 .69131 L p 0 0 0 r
F P
0 g
s
.49449 .68288 m .48907 .68515 L .4962 .68563 L p .281 .749 .944 r
F P
0 g
s
.4962 .68563 m .50056 .68331 L .49449 .68288 L p .281 .749 .944 r
F P
0 g
s
.46676 .40666 m .47071 .37679 L .46606 .37963 L p .347 .115 .413 r
F P
0 g
s
.46606 .37963 m .46203 .41023 L .46676 .40666 L p .347 .115 .413 r
F P
0 g
s
.62434 .47975 m .63121 .49535 L .6343 .48766 L p .278 .267 .667 r
F P
0 g
s
.6343 .48766 m .6255 .47358 L .62434 .47975 L p .278 .267 .667 r
F P
0 g
s
.47094 .69131 m .47961 .68796 L .47036 .69275 L p 0 0 0 r
F P
0 g
s
.47961 .68796 m .47094 .69131 L .48078 .68717 L p 0 0 0 r
F P
0 g
s
.62438 .55692 m .6431 .56731 L .6464 .56265 L p .582 .613 .849 r
F P
0 g
s
.6464 .56265 m .62703 .55291 L .62438 .55692 L p .582 .613 .849 r
F P
0 g
s
.48907 .68515 m .49449 .68288 L .4876 .68452 L p .29 .789 .8 r
F P
0 g
s
.61553 .52216 m .62249 .53392 L .62849 .52733 L p .533 .429 .682 r
F P
0 g
s
.62849 .52733 m .61932 .51643 L .61553 .52216 L p .533 .429 .682 r
F P
0 g
s
.6431 .56731 m .66261 .58097 L .66657 .57569 L p .549 .57 .828 r
F P
0 g
s
.66657 .57569 m .6464 .56265 L .6431 .56731 L p .549 .57 .828 r
F P
0 g
s
.27617 .64644 m .26329 .62167 L .25323 .63429 L p .335 .26 .622 r
F P
0 g
s
.25323 .63429 m .2664 .65996 L .27617 .64644 L p .335 .26 .622 r
F P
0 g
s
.67856 .61523 m .67984 .62125 L .68036 .61473 L p 0 0 .388 r
F P
0 g
s
.67252 .62907 m .68036 .61473 L .67984 .62125 L p .945 .932 .584 r
F P
0 g
s
.67682 .62393 m .68212 .61424 L p .68036 .61473 L 0 0 0 r
F P
0 g
s
.68212 .61424 m .68492 .60914 L .68036 .61473 L p 0 0 0 r
F P
0 g
s
.6761 .60366 m .67856 .61523 L p .68036 .61473 L 0 0 .388 r
F P
0 g
s
.41083 .71712 m .38241 .7251 L .39861 .72187 L p .299 .794 .797 r
F P
0 g
s
.39861 .72187 m .42324 .71411 L .41083 .71712 L p .299 .794 .797 r
F P
0 g
s
.58387 .38041 m .58648 .41408 L .58093 .41328 L p .838 .541 .487 r
F P
0 g
s
.58093 .41328 m .57889 .37869 L .58387 .38041 L p .838 .541 .487 r
F P
0 g
s
.30001 .57491 m .32225 .55384 L .30799 .55998 L p .084 0 .008 r
F P
0 g
s
.30799 .55998 m .28409 .58359 L .30001 .57491 L p .084 0 .008 r
F P
0 g
s
.68272 .62911 m .67484 .64382 L .67206 .63558 L p .986 .857 .627 r
F P
0 g
s
.67206 .63558 m .67984 .62125 L .68272 .62911 L p .986 .857 .627 r
F P
0 g
s
.3955 .52803 m .41772 .52176 L .41143 .52245 L p .076 0 0 r
F P
0 g
s
.41143 .52245 m .38609 .52931 L .3955 .52803 L p .076 0 0 r
F P
0 g
s
.43958 .50814 m .43778 .48727 L .43595 .48963 L p .207 .076 .472 r
F P
0 g
s
.43595 .48963 m .43661 .50971 L .43958 .50814 L p .207 .076 .472 r
F P
0 g
s
.53138 .71127 m .53871 .71793 L p .53711 .71863 L .801 .37 .224 r
F P
0 g
s
.52451 .70514 m .53221 .71394 L p .52592 .7062 L 0 .148 .657 r
F P
0 g
s
.52592 .7062 m .52512 .7052 L .52501 .70519 L 0 .148 .657 r
F
.52592 .7062 m .52501 .70519 L .52451 .70514 L F
.53221 .71394 m .53138 .71127 L .52475 .70475 L p F P
0 g
s
.53105 .7213 m .52482 .71706 L p .5309 .71169 L .821 .441 .333 r
F P
0 g
s
.53138 .71127 m .53135 .71218 L p .5309 .71169 L .821 .441 .333 r
F P
0 g
s
.53135 .71218 m .53105 .7213 L p .5309 .71169 L .821 .441 .333 r
F P
0 g
s
.53105 .7213 m .53135 .71218 L p .53711 .71863 L .801 .37 .224 r
F P
0 g
s
.53135 .71218 m .53138 .71127 L p .53711 .71863 L .801 .37 .224 r
F P
0 g
s
.52475 .70475 m .52473 .70477 L p .52512 .7052 L 0 .148 .657 r
F P
0 g
s
.52473 .70477 m .52451 .70514 L p .52512 .7052 L 0 .148 .657 r
F P
0 g
s
.47192 .40366 m .47565 .37428 L .47071 .37679 L p .41 .163 .426 r
F P
0 g
s
.47071 .37679 m .46676 .40666 L .47192 .40366 L p .41 .163 .426 r
F P
0 g
s
.61399 .54388 m .62703 .55291 L .63191 .54794 L p .607 .559 .774 r
F P
0 g
s
.63191 .54794 m .61758 .53942 L .61399 .54388 L p .607 .559 .774 r
F P
0 g
s
.66261 .58097 m .67661 .59761 L .68104 .59197 L p .463 .453 .762 r
F P
0 g
s
.68104 .59197 m .66657 .57569 L .66261 .58097 L p .463 .453 .762 r
F P
0 g
s
.67315 .68792 m .64926 .68849 L .6451 .67611 L p .852 .777 .777 r
F P
0 g
s
.6451 .67611 m .66777 .67446 L .67315 .68792 L p .852 .777 .777 r
F P
0 g
s
.44476 .4677 m .44276 .43716 L .44073 .44154 L p 0 0 .398 r
F P
0 g
s
.44073 .44154 m .44356 .47279 L .44476 .4677 L p 0 0 .398 r
F P
0 g
s
.61932 .51643 m .62849 .52733 L .63518 .51968 L p .564 .463 .699 r
F P
0 g
s
.63518 .51968 m .62339 .50995 L .61932 .51643 L p .564 .463 .699 r
F P
0 g
s
.6255 .47358 m .6343 .48766 L .63643 .48007 L p .277 .304 .71 r
F P
0 g
s
.63643 .48007 m .62598 .46752 L .6255 .47358 L p .277 .304 .71 r
F P
0 g
s
.6136 .74424 m .59662 .733 L .60251 .72804 L p .742 .832 .92 r
F P
0 g
s
.60251 .72804 m .62059 .73791 L .6136 .74424 L p .742 .832 .92 r
F P
0 g
s
.42393 .52124 m .43316 .51086 L .42949 .51181 L p .304 0 .148 r
F P
0 g
s
.42949 .51181 m .41772 .52176 L .42393 .52124 L p .304 0 .148 r
F P
0 g
s
.57889 .37869 m .58093 .41328 L .57527 .41258 L p .822 .533 .499 r
F P
0 g
s
.57527 .41258 m .57372 .37713 L .57889 .37869 L p .822 .533 .499 r
F P
0 g
s
.36635 .53586 m .3955 .52803 L .38609 .52931 L p 0 0 0 r
F P
0 g
s
.38609 .52931 m .35382 .53867 L .36635 .53586 L p 0 0 0 r
F P
0 g
s
.47748 .40127 m .48087 .37214 L .47565 .37428 L p .468 .209 .438 r
F P
0 g
s
.47565 .37428 m .47192 .40366 L .47748 .40127 L p .468 .209 .438 r
F P
0 g
s
.62703 .55291 m .6464 .56265 L .65273 .55715 L p .637 .594 .789 r
F P
0 g
s
.65273 .55715 m .63191 .54794 L .62703 .55291 L p .637 .594 .789 r
F P
0 g
s
.39928 .71829 m .36731 .72611 L .38241 .7251 L p .393 .841 .926 r
F P
0 g
s
.38241 .7251 m .41083 .71712 L .39928 .71829 L p .393 .841 .926 r
F P
0 g
s
.61758 .53942 m .63191 .54794 L .63888 .54179 L p .638 .556 .746 r
F P
0 g
s
.63888 .54179 m .62249 .53392 L .61758 .53942 L p .638 .556 .746 r
F P
0 g
s
.52482 .71706 m .51896 .71315 L p .52428 .70543 L .822 .484 .416 r
F P
0 g
s
.52475 .70475 m .52475 .70601 L p .52428 .70543 L .822 .484 .416 r
F P
0 g
s
.52475 .70601 m .52482 .71706 L p .52428 .70543 L .822 .484 .416 r
F P
0 g
s
.51778 .69719 m .52451 .70514 L p .51963 .6998 L 0 .059 .564 r
F P
0 g
s
.51875 .69883 m .51853 .69846 L p .51963 .6998 L 0 .059 .564 r
F P
0 g
s
.51853 .69846 m .51778 .69719 L p .51963 .6998 L 0 .059 .564 r
F P
0 g
s
.52451 .70514 m .52475 .70475 L .51875 .69883 L p 0 .059 .564 r
F P
0 g
s
.65407 .71529 m .62975 .70857 L .62917 .69715 L p .83 .781 .806 r
F P
0 g
s
.62917 .69715 m .6525 .70176 L .65407 .71529 L p .83 .781 .806 r
F P
0 g
s
.62339 .50995 m .63518 .51968 L .6421 .51113 L p .581 .49 .716 r
F P
0 g
s
.6421 .51113 m .62746 .50286 L .62339 .50995 L p .581 .49 .716 r
F P
0 g
s
.61528 .44498 m .61037 .42303 L .61385 .42623 L p .937 .573 .289 r
F P
0 g
s
.6464 .56265 m .66657 .57569 L .67423 .56987 L p .612 .558 .77 r
F P
0 g
s
.67423 .56987 m .65273 .55715 L .6464 .56265 L p .612 .558 .77 r
F P
0 g
s
.67991 .65395 m .66231 .66254 L .65786 .65252 L p .894 .805 .753 r
F P
0 g
s
.65786 .65252 m .67484 .64382 L .67991 .65395 L p .894 .805 .753 r
F P
0 g
s
.44607 .46213 m .44504 .43258 L .44276 .43716 L p 0 0 .376 r
F P
0 g
s
.44276 .43716 m .44476 .4677 L .44607 .46213 L p 0 0 .376 r
F P
0 g
s
.57372 .37713 m .57527 .41258 L .56954 .4119 L p .807 .524 .508 r
F P
0 g
s
.56954 .4119 m .56838 .37571 L .57372 .37713 L p .807 .524 .508 r
F P
0 g
s
.44191 .50591 m .43948 .48449 L .43778 .48727 L p .136 .045 .478 r
F P
0 g
s
.43778 .48727 m .43958 .50814 L .44191 .50591 L p .136 .045 .478 r
F P
0 g
s
.47748 .40127 m .48087 .37214 L .48632 .3704 L p .513 .246 .447 r
F P
0 g
s
.62598 .46752 m .63643 .48007 L .63735 .47288 L p .254 .331 .751 r
F P
0 g
s
.63735 .47288 m .62567 .46176 L .62598 .46752 L p .254 .331 .751 r
F P
0 g
s
.33744 .54885 m .36635 .53586 L .35382 .53867 L p .012 0 0 r
F P
0 g
s
.35382 .53867 m .32225 .55384 L .33744 .54885 L p .012 0 0 r
F P
0 g
s
.62249 .53392 m .63888 .54179 L .64758 .53433 L p .65 .555 .734 r
F P
0 g
s
.64758 .53433 m .62849 .52733 L .62249 .53392 L p .65 .555 .734 r
F P
0 g
s
.63191 .54794 m .65273 .55715 L .66191 .55048 L p .656 .577 .754 r
F P
0 g
s
.66191 .55048 m .63888 .54179 L .63191 .54794 L p .656 .577 .754 r
F P
0 g
s
.62746 .50286 m .6421 .51113 L .6487 .5019 L p .59 .512 .735 r
F P
0 g
s
.6487 .5019 m .63121 .49535 L .62746 .50286 L p .59 .512 .735 r
F P
0 g
s
.29706 .67669 m .2664 .65996 L .26123 .6733 L p .444 .454 .775 r
F P
0 g
s
.26123 .6733 m .29233 .68959 L .29706 .67669 L p .444 .454 .775 r
F P
0 g
s
.33272 .70541 m .29214 .70138 L .29662 .71145 L p .49 .628 .912 r
F P
0 g
s
.29662 .71145 m .33633 .71407 L .33272 .70541 L p .49 .628 .912 r
F P
0 g
s
.62059 .73791 m .60251 .72804 L .60708 .7215 L p .789 .83 .884 r
F P
0 g
s
.60708 .7215 m .62564 .72953 L .62059 .73791 L p .789 .83 .884 r
F P
0 g
s
.51323 .69391 m .51179 .69064 L .51778 .69719 L p .554 .028 0 r
F P
0 g
s
.51778 .69719 m .51875 .69883 L .51323 .69391 L p .554 .028 0 r
F P
0 g
s
.56838 .37571 m .56954 .4119 L .56378 .41114 L p .793 .514 .515 r
F P
0 g
s
.56378 .41114 m .5629 .37439 L .56838 .37571 L p .793 .514 .515 r
F P
0 g
s
.48337 .39955 m .48632 .3704 L .49198 .36905 L p .548 .276 .456 r
F P
0 g
s
.48632 .3704 m .48337 .39955 L .47748 .40127 L p .513 .246 .447 r
F P
0 g
s
.66657 .57569 m .68104 .59197 L .68961 .58623 L p .557 .472 .714 r
F P
0 g
s
.68961 .58623 m .67423 .56987 L .66657 .57569 L p .557 .472 .714 r
F P
0 g
s
.67661 .59761 m .68036 .61473 L .68492 .60914 L p .258 .178 .571 r
F P
0 g
s
.68492 .60914 m .68104 .59197 L .67661 .59761 L p .258 .178 .571 r
F P
0 g
s
.42954 .52058 m .43661 .50971 L .43316 .51086 L p .316 0 .213 r
F P
0 g
s
.43316 .51086 m .42393 .52124 L .42954 .52058 L p .316 0 .213 r
F P
0 g
s
.38919 .71737 m .35412 .72462 L .36731 .72611 L p .477 .838 .994 r
F P
0 g
s
.36731 .72611 m .39928 .71829 L .38919 .71737 L p .477 .838 .994 r
F P
0 g
s
.61037 .42303 m .61528 .44498 L .61056 .44285 L p .917 .57 .364 r
F P
0 g
s
.61056 .44285 m .60636 .42035 L .61037 .42303 L p .917 .57 .364 r
F P
0 g
s
.40469 .52713 m .42393 .52124 L .41772 .52176 L p .166 0 0 r
F P
0 g
s
.41772 .52176 m .3955 .52803 L .40469 .52713 L p .166 0 0 r
F P
0 g
s
.62849 .52733 m .64758 .53433 L .65746 .52553 L p .653 .556 .732 r
F P
0 g
s
.65746 .52553 m .63518 .51968 L .62849 .52733 L p .653 .556 .732 r
F P
0 g
s
.65273 .55715 m .67423 .56987 L .6854 .56308 L p .634 .543 .735 r
F P
0 g
s
.6854 .56308 m .66191 .55048 L .65273 .55715 L p .634 .543 .735 r
F P
0 g
s
.44762 .45619 m .44764 .4279 L .44504 .43258 L p 0 0 .358 r
F P
0 g
s
.44504 .43258 m .44603 .46119 L p .44762 .45619 L 0 0 .358 r
F P
0 g
s
.44764 .4279 m .44762 .45503 L p .44956 .45008 L 0 0 .347 r
F P
0 g
s
.44762 .45503 m .44762 .45619 L .44956 .45008 L p 0 0 .347 r
F P
0 g
s
.44956 .45008 m .45059 .4232 L .44764 .4279 L p 0 0 .347 r
F P
0 g
s
.45059 .4232 m .44961 .44876 L p .45202 .44399 L 0 0 .343 r
F P
0 g
s
.44961 .44876 m .44956 .45008 L .45202 .44399 L p 0 0 .343 r
F P
0 g
s
.45202 .44399 m .45396 .41861 L .45059 .4232 L p 0 0 .343 r
F P
0 g
s
.45396 .41861 m .45213 .44256 L p .45511 .43816 L .038 0 .348 r
F P
0 g
s
.45213 .44256 m .45202 .44399 L .45511 .43816 L p .038 0 .348 r
F P
0 g
s
.45511 .43816 m .45777 .41425 L .45396 .41861 L p .038 0 .348 r
F P
0 g
s
.45777 .41425 m .45528 .43666 L p .4589 .43282 L .136 0 .358 r
F P
0 g
s
.45528 .43666 m .45511 .43816 L .4589 .43282 L p .136 0 .358 r
F P
0 g
s
.4589 .43282 m .46203 .41023 L .45777 .41425 L p .136 0 .358 r
F P
0 g
s
.46203 .41023 m .45911 .43126 L p .4634 .42819 L .241 .026 .373 r
F P
0 g
s
.45911 .43126 m .4589 .43282 L .4634 .42819 L p .241 .026 .373 r
F P
0 g
s
.46269 .42881 m .4634 .42819 L .4589 .43282 L p .705 .912 .563 r
F P
0 g
s
.4634 .42819 m .45631 .43432 L p .46096 .43011 L .49 .831 .548 r
F P
0 g
s
.45631 .43432 m .45552 .435 L .46096 .43011 L p .49 .831 .548 r
F P
0 g
s
.4634 .42819 m .46676 .40666 L .46203 .41023 L p .241 .026 .373 r
F P
0 g
s
.46676 .40666 m .4634 .42819 L .46859 .42445 L p .345 .099 .39 r
F P
0 g
s
.45349 .4162 m .46589 .42565 L p .46096 .43011 L .699 .835 .948 r
F P
0 g
s
.46096 .43011 m .46785 .425 L p .4634 .42819 L .49 .831 .548 r
F P
0 g
s
.46785 .425 m .46859 .42445 L .4634 .42819 L p .49 .831 .548 r
F P
0 g
s
.45552 .435 m .46269 .42881 L p .4589 .43282 L .705 .912 .563 r
F P
0 g
s
.46859 .42445 m .46177 .42951 L p .46741 .42681 L 0 0 0 r
F P
0 g
s
.46177 .42951 m .46096 .43011 L .46741 .42681 L p 0 0 0 r
F P
0 g
s
.47469 .42525 m .46741 .42681 L p .46871 .42616 L .114 0 0 r
F P
0 g
s
.48073 .42015 m .47469 .42525 L p .46871 .42616 L .114 0 0 r
F P
0 g
s
.48254 .42545 m .47469 .42525 L p .4759 .42472 L .333 0 0 r
F P
0 g
s
.48744 .41967 m .48254 .42545 L p .4759 .42472 L .333 0 0 r
F P
0 g
s
.4907 .42733 m .48254 .42545 L p .4836 .42499 L .504 .001 0 r
F P
0 g
s
.49437 .42028 m .4907 .42733 L p .4836 .42499 L .504 .001 0 r
F P
0 g
s
.49889 .43067 m .4907 .42733 L p .49156 .42688 L .623 .159 .131 r
F P
0 g
s
.50139 .42183 m .49889 .43067 L p .49156 .42688 L .623 .159 .131 r
F P
0 g
s
.50686 .43517 m .49889 .43067 L p .50127 .42903 L .699 .278 .244 r
F P
0 g
s
.50835 .42417 m .50702 .43402 L p .50127 .42903 L .699 .278 .244 r
F P
0 g
s
.50702 .43402 m .50686 .43517 L p .50127 .42903 L .699 .278 .244 r
F P
0 g
s
.50686 .43517 m .50835 .42417 L .51514 .42706 L p .744 .365 .334 r
F P
0 g
s
.52169 .43028 m .5215 .44613 L .51444 .44047 L p .769 .426 .406 r
F P
0 g
s
.51444 .44047 m .5215 .44613 L p .52094 .44567 L 0 .108 .574 r
F P
0 g
s
.50729 .43475 m .50922 .43287 L .51444 .44047 L .744 .365 .334 r
F
.51454 .43868 m .51444 .44047 L p .50922 .43287 L F P
0 g
s
.51444 .44047 m .51514 .42706 L .52169 .43028 L p .769 .426 .406 r
F P
0 g
s
.52798 .43356 m .52801 .45173 L .5215 .44613 L p .78 .469 .462 r
F P
0 g
s
.52801 .45173 m .52819 .45546 L .52083 .44716 L p .61 .074 0 r
F P
0 g
s
.5215 .44613 m .52801 .45173 L p .52095 .44724 L .61 .074 0 r
F P
0 g
s
.52083 .44716 m .52084 .44714 L p .52095 .44724 L .61 .074 0 r
F P
0 g
s
.52084 .44714 m .5215 .44613 L p .52095 .44724 L .61 .074 0 r
F P
0 g
s
.52801 .45173 m .52798 .43356 L .534 .43667 L p .782 .497 .504 r
F P
0 g
s
.5215 .44613 m .52169 .43028 L .52798 .43356 L p .78 .469 .462 r
F P
0 g
s
.52857 .44825 m .51958 .43727 L p .52682 .45256 L .064 .368 .836 r
F P
0 g
s
.52801 .45173 m .534 .45687 L p .52839 .45551 L .752 .236 0 r
F P
0 g
s
.52819 .45546 m .52819 .45531 L p .52839 .45551 L .752 .236 0 r
F P
0 g
s
.52819 .45531 m .52801 .45173 L p .52839 .45551 L .752 .236 0 r
F P
0 g
s
.5398 .4394 m .5396 .46119 L .534 .45687 L p .78 .515 .535 r
F P
0 g
s
.534 .45687 m .534 .43667 L .5398 .4394 L p .78 .515 .535 r
F P
0 g
s
.534 .43667 m .534 .45687 L .52801 .45173 L p .782 .497 .504 r
F P
0 g
s
.534 .45687 m .5396 .46119 L p .5349 .4629 L .819 .348 .09 r
F P
0 g
s
.5347 .46297 m .53467 .46268 L p .5349 .4629 L .819 .348 .09 r
F P
0 g
s
.53467 .46268 m .534 .45687 L p .5349 .4629 L .819 .348 .09 r
F P
0 g
s
.5396 .46119 m .54496 .46443 L p .54071 .469 L .819 .401 .251 r
F P
0 g
s
.54055 .46916 m .54051 .46885 L p .54071 .469 L .819 .401 .251 r
F P
0 g
s
.54051 .46885 m .5396 .46119 L p .54071 .469 L .819 .401 .251 r
F P
0 g
s
.55029 .46643 m .55155 .47624 L .54605 .47366 L p .782 .408 .348 r
F P
0 g
s
.54605 .47366 m .54496 .46443 L .55029 .46643 L p .782 .408 .348 r
F P
0 g
s
.54496 .46443 m .54605 .47366 L .54055 .46916 L p .819 .401 .251 r
F P
0 g
s
.54918 .47202 m .54297 .46621 L p .54574 .47292 L .068 .439 .876 r
F P
0 g
s
.54605 .47366 m .54644 .47346 L p .54574 .47292 L .068 .439 .876 r
F P
0 g
s
.54644 .47346 m .54918 .47202 L p .54574 .47292 L .068 .439 .876 r
F P
0 g
s
.5396 .46119 m .54055 .46916 L .5347 .46297 L p .819 .348 .09 r
F P
0 g
s
.54297 .46621 m .53625 .45812 L p .53998 .46768 L .051 .378 .843 r
F P
0 g
s
.54055 .46916 m .54098 .46864 L p .53998 .46768 L .051 .378 .843 r
F P
0 g
s
.54098 .46864 m .54297 .46621 L p .53998 .46768 L .051 .378 .843 r
F P
0 g
s
.534 .45687 m .5347 .46297 L .52819 .45546 L p .752 .236 0 r
F P
0 g
s
.53625 .45812 m .52857 .44825 L p .53376 .46072 L .049 .357 .83 r
F P
0 g
s
.5347 .46297 m .53503 .46195 L p .53376 .46072 L .049 .357 .83 r
F P
0 g
s
.53503 .46195 m .53625 .45812 L p .53376 .46072 L .049 .357 .83 r
F P
0 g
s
.52819 .45546 m .52828 .45388 L p .52682 .45256 L .064 .368 .836 r
F P
0 g
s
.52828 .45388 m .52857 .44825 L p .52682 .45256 L .064 .368 .836 r
F P
0 g
s
.52083 .44716 m .52819 .45546 L p .52492 .44855 L .064 .368 .836 r
F P
0 g
s
.51958 .43727 m .52057 .4451 L p .52492 .44855 L .064 .368 .836 r
F P
0 g
s
.5132 .43925 m .51444 .44047 L .52094 .44567 L 0 .108 .574 r
F
.51251 .43867 m .51269 .43885 L p .5132 .43925 L F P
0 g
s
.51269 .43885 m .51444 .44047 L p .5132 .43925 L 0 .108 .574 r
F P
0 g
s
.51444 .44047 m .50686 .43517 L p .50729 .43475 L .744 .365 .334 r
F P
0 g
s
.51251 .43867 m .50328 .43064 L p .50481 .43199 L 0 .286 .741 r
F P
0 g
s
.50481 .43199 m .5136 .43973 L .51251 .43867 L 0 .286 .741 r
F
.51444 .44047 m .51425 .44029 L p .5136 .43973 L F P
0 g
s
.51425 .44029 m .51251 .43867 L p .5136 .43973 L 0 .286 .741 r
F P
0 g
s
.50328 .43064 m .50686 .43517 L .51444 .44047 L p 0 .286 .741 r
F P
0 g
s
.52083 .44716 m .51251 .43867 L p .52094 .44567 L 0 .108 .574 r
F P
0 g
s
.51949 .44475 m .51251 .43867 L .52083 .44716 L .1 .404 .857 r
F
.51514 .42706 m .51454 .43868 L p .50922 .43287 L .744 .365 .334 r
F P
0 g
s
.50915 .426 m .51251 .43867 L p .51949 .44475 L .1 .404 .857 r
F P
0 g
s
.5215 .44613 m .52145 .44622 L p .52094 .44567 L 0 .108 .574 r
F P
0 g
s
.52145 .44622 m .52083 .44716 L p .52094 .44567 L 0 .108 .574 r
F P
0 g
s
.52057 .4451 m .52083 .44716 L p .52492 .44855 L .064 .368 .836 r
F P
0 g
s
.49889 .43067 m .50686 .43517 L p .50571 .4342 L 0 .447 .862 r
F P
0 g
s
.4907 .42733 m .49437 .42028 L .50139 .42183 L p .623 .159 .131 r
F P
0 g
s
.49889 .43067 m .50139 .42183 L .50835 .42417 L p .699 .278 .244 r
F P
0 g
s
.49332 .42369 m .49889 .43067 L p .50571 .4342 L 0 .447 .862 r
F P
0 g
s
.4907 .42733 m .49889 .43067 L p .49742 .42954 L .187 .583 .941 r
F P
0 g
s
.48953 .39851 m .48744 .41967 L .48073 .42015 L p .557 .272 .438 r
F P
0 g
s
.47469 .42525 m .48073 .42015 L .48744 .41967 L p .333 0 0 r
F P
0 g
s
.48254 .42545 m .48744 .41967 L .49437 .42028 L p .504 .001 0 r
F P
0 g
s
.48294 .41839 m .4907 .42733 L p .49742 .42954 L .187 .583 .941 r
F P
0 g
s
.48254 .42545 m .4907 .42733 L p .48895 .42616 L .357 .688 .981 r
F P
0 g
s
.4744 .42174 m .47748 .40127 L .47192 .40366 L p .439 .171 .408 r
F P
0 g
s
.47192 .40366 m .46859 .42445 L .4744 .42174 L p .439 .171 .408 r
F P
0 g
s
.4744 .42174 m .47748 .40127 L .48337 .39955 L p .508 .227 .423 r
F P
0 g
s
.48337 .39955 m .48073 .42015 L .4744 .42174 L p .508 .227 .423 r
F P
0 g
s
.46741 .42681 m .4744 .42174 L .48073 .42015 L p .114 0 0 r
F P
0 g
s
.47255 .4152 m .48254 .42545 L p .48895 .42616 L .357 .688 .981 r
F P
0 g
s
.47469 .42525 m .48254 .42545 L p .48056 .42436 L .499 .762 .99 r
F P
0 g
s
.46859 .42445 m .47192 .40366 L .46676 .40666 L p .345 .099 .39 r
F P
0 g
s
.46741 .42681 m .4744 .42174 L .46859 .42445 L p 0 0 0 r
F P
0 g
s
.46258 .41443 m .47469 .42525 L p .48056 .42436 L .499 .762 .99 r
F P
0 g
s
.46741 .42681 m .47469 .42525 L p .47257 .42435 L .61 .809 .976 r
F P
0 g
s
.45349 .4162 m .46741 .42681 L p .47257 .42435 L .61 .809 .976 r
F P
0 g
s
.46589 .42565 m .46741 .42681 L .46096 .43011 L p .699 .835 .948 r
F P
0 g
s
.45121 .44125 m .45825 .43353 L p .45511 .43816 L .826 .919 .526 r
F P
0 g
s
.45825 .43353 m .4589 .43282 L .45511 .43816 L p .826 .919 .526 r
F P
0 g
s
.44805 .44853 m .45457 .43896 L p .45202 .44399 L .885 .889 .463 r
F P
0 g
s
.45457 .43896 m .45511 .43816 L .45202 .44399 L p .885 .889 .463 r
F P
0 g
s
.44598 .45648 m .45161 .44485 L p .44956 .45008 L .904 .842 .385 r
F P
0 g
s
.45161 .44485 m .45202 .44399 L .44956 .45008 L p .904 .842 .385 r
F P
0 g
s
.44485 .46471 m .44928 .45093 L p .44762 .45619 L .893 .783 .293 r
F P
0 g
s
.44928 .45093 m .44956 .45008 L .44762 .45619 L p .893 .783 .293 r
F P
0 g
s
.44603 .46119 m .44607 .46213 L .44762 .45619 L p 0 0 .358 r
F P
0 g
s
.48953 .39851 m .49198 .36905 L .49779 .3681 L p .58 .305 .465 r
F P
0 g
s
.49198 .36905 m .48953 .39851 L .48337 .39955 L p .548 .276 .456 r
F P
0 g
s
.5629 .37439 m .56378 .41114 L .55798 .41023 L p .78 .504 .519 r
F P
0 g
s
.55798 .41023 m .55731 .37316 L .5629 .37439 L p .78 .504 .519 r
F P
0 g
s
.63888 .54179 m .66191 .55048 L .67348 .54241 L p .66 .565 .737 r
F P
0 g
s
.67348 .54241 m .64758 .53433 L .63888 .54179 L p .66 .565 .737 r
F P
0 g
s
.62567 .46176 m .63735 .47288 L .63688 .46638 L p .196 .346 .789 r
F P
0 g
s
.44352 .50284 m .44099 .48119 L .43948 .48449 L p .009 0 .456 r
F P
0 g
s
.43948 .48449 m .44191 .50591 L .44352 .50284 L p .009 0 .456 r
F P
0 g
s
.67984 .62125 m .67206 .63558 L .67252 .62907 L p .945 .932 .584 r
F P
0 g
s
.63121 .49535 m .6487 .5019 L .65444 .4923 L p .595 .534 .757 r
F P
0 g
s
.65444 .4923 m .6343 .48766 L .63121 .49535 L p .595 .534 .757 r
F P
0 g
s
.50799 .69032 m .50618 .68592 L .51179 .69064 L p .655 .103 0 r
F P
0 g
s
.51179 .69064 m .51323 .69391 L .50799 .69032 L p .655 .103 0 r
F P
0 g
s
.49587 .39812 m .49779 .3681 L .50373 .36752 L p .608 .333 .474 r
F P
0 g
s
.49779 .3681 m .49587 .39812 L .48953 .39851 L p .58 .305 .465 r
F P
0 g
s
.55731 .37316 m .55798 .41023 L .55214 .40914 L p .767 .494 .521 r
F P
0 g
s
.55214 .40914 m .5516 .372 L .55731 .37316 L p .767 .494 .521 r
F P
0 g
s
.63518 .51968 m .65746 .52553 L .66781 .51553 L p .652 .559 .737 r
F P
0 g
s
.66781 .51553 m .6421 .51113 L .63518 .51968 L p .652 .559 .737 r
F P
0 g
s
.66777 .67446 m .6451 .67611 L .64088 .66515 L p .846 .768 .775 r
F P
0 g
s
.64088 .66515 m .66231 .66254 L .66777 .67446 L p .846 .768 .775 r
F P
0 g
s
.50233 .39832 m .50373 .36752 L .50975 .3673 L p .634 .358 .483 r
F P
0 g
s
.50373 .36752 m .50233 .39832 L .49587 .39812 L p .608 .333 .474 r
F P
0 g
s
.29371 .59891 m .30001 .57491 L .28409 .58359 L p .334 .11 .417 r
F P
0 g
s
.28409 .58359 m .27722 .60973 L .29371 .59891 L p .334 .11 .417 r
F P
0 g
s
.64758 .53433 m .67348 .54241 L .68671 .53283 L p .656 .557 .731 r
F P
0 g
s
.68671 .53283 m .65746 .52553 L .64758 .53433 L p .656 .557 .731 r
F P
0 g
s
.5516 .372 m .55214 .40914 L .54624 .40786 L p .754 .482 .521 r
F P
0 g
s
.54624 .40786 m .5458 .37092 L .5516 .372 L p .754 .482 .521 r
F P
0 g
s
.66191 .55048 m .6854 .56308 L .69952 .55496 L p .637 .53 .717 r
F P
0 g
s
.69952 .55496 m .67348 .54241 L .66191 .55048 L p .637 .53 .717 r
F P
0 g
s
.37855 .53371 m .40469 .52713 L .3955 .52803 L p .033 0 0 r
F P
0 g
s
.3955 .52803 m .36635 .53586 L .37855 .53371 L p .033 0 0 r
F P
0 g
s
.50274 .68824 m .50056 .68331 L .50618 .68592 L p .673 .139 0 r
F P
0 g
s
.50618 .68592 m .50799 .69032 L .50274 .68824 L p .673 .139 0 r
F P
0 g
s
.60636 .42035 m .61056 .44285 L .6052 .44158 L p .893 .565 .42 r
F P
0 g
s
.6052 .44158 m .60189 .41816 L .60636 .42035 L p .893 .565 .42 r
F P
0 g
s
.67423 .56987 m .68961 .58623 L .70214 .57989 L p .589 .47 .685 r
F P
0 g
s
.70214 .57989 m .6854 .56308 L .67423 .56987 L p .589 .47 .685 r
F P
0 g
s
.62564 .72953 m .60708 .7215 L .61027 .71373 L p .821 .82 .847 r
F P
0 g
s
.61027 .71373 m .62866 .71956 L .62564 .72953 L p .821 .82 .847 r
F P
0 g
s
.50882 .39904 m .50975 .3673 L .51581 .36738 L p .656 .381 .492 r
F P
0 g
s
.50975 .3673 m .50882 .39904 L .50233 .39832 L p .634 .358 .483 r
F P
0 g
s
.6525 .70176 m .62917 .69715 L .62735 .6859 L p .834 .765 .786 r
F P
0 g
s
.62735 .6859 m .64926 .68849 L .6525 .70176 L p .834 .765 .786 r
F P
0 g
s
.5458 .37092 m .54624 .40786 L .54026 .40639 L p .74 .469 .52 r
F P
0 g
s
.54026 .40639 m .53992 .36993 L .5458 .37092 L p .74 .469 .52 r
F P
0 g
s
.6343 .48766 m .65444 .4923 L .6588 .48272 L p .595 .558 .782 r
F P
0 g
s
.6588 .48272 m .63643 .48007 L .6343 .48766 L p .595 .558 .782 r
F P
0 g
s
.31697 .56752 m .33744 .54885 L .32225 .55384 L p .22 0 .11 r
F P
0 g
s
.32225 .55384 m .30001 .57491 L .31697 .56752 L p .22 0 .11 r
F P
0 g
s
.44443 .49878 m .44233 .47729 L .44099 .48119 L p 0 0 .388 r
F P
0 g
s
.44099 .48119 m .44352 .50284 L .44443 .49878 L p 0 0 .388 r
F P
0 g
s
.62446 .45649 m .63688 .46638 L .63491 .46085 L p .084 .338 .812 r
F P
0 g
s
.6421 .51113 m .66781 .51553 L .67784 .50454 L p .648 .566 .748 r
F P
0 g
s
.67784 .50454 m .6487 .5019 L .6421 .51113 L p .648 .566 .748 r
F P
0 g
s
.51529 .40016 m .51581 .36738 L .52189 .36772 L p .677 .403 .5 r
F P
0 g
s
.51581 .36738 m .51529 .40016 L .50882 .39904 L p .656 .381 .492 r
F P
0 g
s
.43413 .51943 m .43958 .50814 L .43661 .50971 L p .257 0 .226 r
F P
0 g
s
.43661 .50971 m .42954 .52058 L .43413 .51943 L p .257 0 .226 r
F P
0 g
s
.53992 .36993 m .54026 .40639 L .53419 .4048 L p .726 .455 .517 r
F P
0 g
s
.53419 .4048 m .53396 .36904 L .53992 .36993 L p .726 .455 .517 r
F P
0 g
s
.49724 .68775 m .49449 .68288 L .50056 .68331 L p .61 .124 .075 r
F P
0 g
s
.50056 .68331 m .50274 .68824 L .49724 .68775 L p .61 .124 .075 r
F P
0 g
s
.5217 .40158 m .52189 .36772 L .52794 .36829 L p .695 .422 .507 r
F P
0 g
s
.52189 .36772 m .5217 .40158 L .51529 .40016 L p .677 .403 .5 r
F P
0 g
s
.53396 .36904 m .53419 .4048 L .528 .40316 L p .711 .439 .512 r
F P
0 g
s
.528 .40316 m .52794 .36829 L .53396 .36904 L p .711 .439 .512 r
F P
0 g
s
.67484 .64382 m .65786 .65252 L .65542 .64452 L p .892 .838 .786 r
F P
0 g
s
.65542 .64452 m .67206 .63558 L .67484 .64382 L p .892 .838 .786 r
F P
0 g
s
.68104 .59197 m .68492 .60914 L .69376 .60397 L p .457 .303 .584 r
F P
0 g
s
.69376 .60397 m .68961 .58623 L .68104 .59197 L p .457 .303 .584 r
F P
0 g
s
.2896 .63335 m .27722 .60973 L .26329 .62167 L p .424 .309 .618 r
F P
0 g
s
.26329 .62167 m .27617 .64644 L .2896 .63335 L p .424 .309 .618 r
F P
0 g
s
.52794 .36829 m .528 .40316 L .5217 .40158 L p .695 .422 .507 r
F P
0 g
s
.3811 .7143 m .34359 .72057 L .35412 .72462 L p .534 .792 .992 r
F P
0 g
s
.35412 .72462 m .38919 .71737 L .3811 .7143 L p .534 .792 .992 r
F P
0 g
s
.49124 .68876 m .4876 .68452 L .49449 .68288 L p .519 .074 .131 r
F P
0 g
s
.49449 .68288 m .49724 .68775 L .49124 .68876 L p .519 .074 .131 r
F P
0 g
s
.65746 .52553 m .68671 .53283 L .70066 .52178 L p .649 .554 .733 r
F P
0 g
s
.70066 .52178 m .66781 .51553 L .65746 .52553 L p .649 .554 .733 r
F P
0 g
s
.41287 .52623 m .42954 .52058 L .42393 .52124 L p .163 0 0 r
F P
0 g
s
.42393 .52124 m .40469 .52713 L .41287 .52623 L p .163 0 0 r
F P
0 g
s
.48457 .69109 m .47961 .68796 L .4876 .68452 L p .432 .005 .126 r
F P
0 g
s
.4876 .68452 m .49124 .68876 L .48457 .69109 L p .432 .005 .126 r
F P
0 g
s
.47712 .69442 m .47036 .69275 L .47961 .68796 L p .351 0 .077 r
F P
0 g
s
.47961 .68796 m .48457 .69109 L .47712 .69442 L p .351 0 .077 r
F P
0 g
s
.67348 .54241 m .69952 .55496 L .71574 .54529 L p .631 .521 .71 r
F P
0 g
s
.71574 .54529 m .68671 .53283 L .67348 .54241 L p .631 .521 .71 r
F P
0 g
s
.60189 .41816 m .6052 .44158 L .59936 .44107 L p .868 .559 .463 r
F P
0 g
s
.59936 .44107 m .59703 .41644 L .60189 .41816 L p .868 .559 .463 r
F P
0 g
s
.56409 .73393 m .5593 .73546 L .5519 .73294 L p .504 0 0 r
F P
0 g
s
.54671 .72423 m .54465 .72955 L .53767 .72557 L p .751 .265 .084 r
F P
0 g
s
.46891 .69836 m .45985 .69837 L .47036 .69275 L p .271 0 0 r
F P
0 g
s
.47036 .69275 m .47712 .69442 L .46891 .69836 L p .271 0 0 r
F P
0 g
s
.46005 .70248 m .44826 .7042 L .45985 .69837 L p .184 0 0 r
F P
0 g
s
.45985 .69837 m .46891 .69836 L .46005 .70248 L p .184 0 0 r
F P
0 g
s
.35221 .54479 m .37855 .53371 L .36635 .53586 L p .091 0 0 r
F P
0 g
s
.36635 .53586 m .33744 .54885 L .35221 .54479 L p .091 0 0 r
F P
0 g
s
.6487 .5019 m .67784 .50454 L .68673 .49294 L p .643 .576 .764 r
F P
0 g
s
.68673 .49294 m .65444 .4923 L .6487 .5019 L p .643 .576 .764 r
F P
0 g
s
.63643 .48007 m .6588 .48272 L .66134 .47359 L p .593 .584 .812 r
F P
0 g
s
.66134 .47359 m .63735 .47288 L .63643 .48007 L p .593 .584 .812 r
F P
0 g
s
.53871 .71793 m .53767 .72557 L .53105 .7213 L p .801 .37 .224 r
F P
0 g
s
.57298 .73655 m .56668 .73688 L .5593 .73546 L p .281 0 0 r
F P
0 g
s
.44476 .49369 m .44356 .47279 L .44233 .47729 L p 0 0 .266 r
F P
0 g
s
.44233 .47729 m .44443 .49878 L .44476 .49369 L p 0 0 .266 r
F P
0 g
s
.6854 .56308 m .70214 .57989 L .71802 .57247 L p .596 .463 .67 r
F P
0 g
s
.71802 .57247 m .69952 .55496 L .6854 .56308 L p .596 .463 .67 r
F P
0 g
s
.67529 .62399 m .67252 .62907 L .67682 .62393 L p 0 0 0 r
F P
0 g
s
.65956 .63405 m .67682 .62393 L .67252 .62907 L p .749 .994 .858 r
F P
0 g
s
.66685 .63087 m .67833 .62388 L p .67682 .62393 L 0 0 0 r
F P
0 g
s
.67833 .62388 m .68519 .61969 L .67682 .62393 L p 0 0 0 r
F P
0 g
s
.68036 .61473 m .67529 .62399 L p .67682 .62393 L 0 0 0 r
F P
0 g
s
.45075 .70632 m .4359 .70964 L .44826 .7042 L p .081 0 0 r
F P
0 g
s
.44826 .7042 m .46005 .70248 L .45075 .70632 L p .081 0 0 r
F P
0 g
s
.33291 .69502 m .29233 .68959 L .29214 .70138 L p .53 .589 .858 r
F P
0 g
s
.29214 .70138 m .33272 .70541 L .33291 .69502 L p .53 .589 .858 r
F P
0 g
s
.52482 .71706 m .52475 .70475 L .53138 .71127 L p .821 .441 .333 r
F P
0 g
s
.43742 .51743 m .44191 .50591 L .43958 .50814 L p .061 0 .157 r
F P
0 g
s
.43958 .50814 m .43413 .51943 L .43742 .51743 L p .061 0 .157 r
F P
0 g
s
.66781 .51553 m .70066 .52178 L .71429 .50945 L p .64 .555 .743 r
F P
0 g
s
.71429 .50945 m .67784 .50454 L .66781 .51553 L p .64 .555 .743 r
F P
0 g
s
.62866 .71956 m .61027 .71373 L .61214 .70513 L p .844 .806 .813 r
F P
0 g
s
.61214 .70513 m .62975 .70857 L .62866 .71956 L p .844 .806 .813 r
F P
0 g
s
.5806 .73585 m .57385 .73703 L p .57527 .73695 L .28 .781 .857 r
F P
0 g
s
.58956 .73614 m .5806 .73585 L p .57527 .73695 L .28 .781 .857 r
F P
0 g
s
.58158 .73733 m .57385 .73703 L p .56803 .73692 L 0 .574 .72 r
F P
0 g
s
.58956 .73614 m .58147 .73587 L p .58676 .73331 L .542 .923 .918 r
F P
0 g
s
.58147 .73587 m .5806 .73585 L .58676 .73331 L p .542 .923 .918 r
F P
0 g
s
.58676 .73331 m .59662 .733 L .58956 .73614 L p .542 .923 .918 r
F P
0 g
s
.59662 .733 m .58766 .73329 L p .59218 .72952 L .738 .985 .903 r
F P
0 g
s
.58766 .73329 m .58676 .73331 L .59218 .72952 L p .738 .985 .903 r
F P
0 g
s
.59218 .72952 m .60251 .72804 L .59662 .733 L p .738 .985 .903 r
F P
0 g
s
.60251 .72804 m .59305 .7294 L p .59676 .72463 L .855 .987 .849 r
F P
0 g
s
.59305 .7294 m .59218 .72952 L .59676 .72463 L p .855 .987 .849 r
F P
0 g
s
.59676 .72463 m .60708 .7215 L .60251 .72804 L p .855 .987 .849 r
F P
0 g
s
.60708 .7215 m .59755 .72439 L p .60047 .71886 L .922 .965 .782 r
F P
0 g
s
.59755 .72439 m .59676 .72463 L .60047 .71886 L p .922 .965 .782 r
F P
0 g
s
.60047 .71886 m .61027 .71373 L .60708 .7215 L p .922 .965 .782 r
F P
0 g
s
.61027 .71373 m .60113 .71851 L p .60333 .71247 L .961 .934 .713 r
F P
0 g
s
.60113 .71851 m .60047 .71886 L .60333 .71247 L p .961 .934 .713 r
F P
0 g
s
.60333 .71247 m .61214 .70513 L .61027 .71373 L p .961 .934 .713 r
F P
0 g
s
.61214 .70513 m .60382 .71207 L p .60544 .70577 L .983 .901 .643 r
F P
0 g
s
.60382 .71207 m .60333 .71247 L .60544 .70577 L p .983 .901 .643 r
F P
0 g
s
.60544 .70577 m .61287 .69616 L .61214 .70513 L p .983 .901 .643 r
F P
0 g
s
.61287 .69616 m .60574 .70537 L p .60694 .69904 L .995 .868 .57 r
F P
0 g
s
.60574 .70537 m .60544 .70577 L .60694 .69904 L p .995 .868 .57 r
F P
0 g
s
.60694 .69904 m .61272 .68725 L .61287 .69616 L p .995 .868 .57 r
F P
0 g
s
.61272 .68725 m .60707 .69877 L p .60803 .69255 L .996 .836 .486 r
F P
0 g
s
.60707 .69877 m .60694 .69904 L .60803 .69255 L p .996 .836 .486 r
F P
0 g
s
.60803 .69255 m .61205 .67883 L .61272 .68725 L p .996 .836 .486 r
F P
0 g
s
.61205 .67883 m .60803 .69255 L .60891 .68656 L p .976 .795 .376 r
F P
0 g
s
.61205 .7147 m .60893 .68669 L p .60803 .69255 L 0 0 .387 r
F P
0 g
s
.60893 .68669 m .60891 .68656 L .60803 .69255 L p 0 0 .387 r
F P
0 g
s
.60984 .71944 m .60806 .69309 L p .60694 .69904 L 0 0 .342 r
F P
0 g
s
.60806 .69309 m .60803 .69255 L .60694 .69904 L p 0 0 .342 r
F P
0 g
s
.60736 .72439 m .60695 .69987 L p .60544 .70577 L 0 0 .307 r
F P
0 g
s
.60695 .69987 m .60694 .69904 L .60544 .70577 L p 0 0 .307 r
F P
0 g
s
.60451 .72941 m .6054 .70681 L p .60333 .71247 L 0 0 .285 r
F P
0 g
s
.6054 .70681 m .60544 .70577 L .60333 .71247 L p 0 0 .285 r
F P
0 g
s
.60122 .73433 m .60322 .71365 L p .60047 .71886 L 0 0 .278 r
F P
0 g
s
.60322 .71365 m .60333 .71247 L .60047 .71886 L p 0 0 .278 r
F P
0 g
s
.59743 .73898 m .60028 .72011 L p .59676 .72463 L .025 0 .285 r
F P
0 g
s
.60028 .72011 m .60047 .71886 L .59676 .72463 L p .025 0 .285 r
F P
0 g
s
.5931 .74321 m .59651 .72592 L p .59218 .72952 L .161 0 .303 r
F P
0 g
s
.59651 .72592 m .59676 .72463 L .59218 .72952 L p .161 0 .303 r
F P
0 g
s
.58822 .74685 m .59188 .73084 L p .58676 .73331 L .299 .03 .327 r
F P
0 g
s
.59188 .73084 m .59218 .72952 L .58676 .73331 L p .299 .03 .327 r
F P
0 g
s
.58283 .74978 m .58644 .73463 L p .5806 .73585 L .423 .126 .354 r
F P
0 g
s
.58644 .73463 m .58676 .73331 L .5806 .73585 L p .423 .126 .354 r
F P
0 g
s
.57385 .73703 m .5806 .73585 L p .57986 .73715 L .511 .2 .376 r
F P
0 g
s
.57077 .75322 m .57385 .73703 L p .57986 .73715 L .511 .2 .376 r
F P
0 g
s
.57385 .73703 m .56668 .73688 L p .56803 .73692 L 0 .574 .72 r
F P
0 g
s
.4359 .70964 m .45075 .70632 L .44133 .70946 L p 0 0 0 r
F P
0 g
s
.59703 .41644 m .59936 .44107 L .5932 .4412 L p .847 .555 .495 r
F P
0 g
s
.5932 .4412 m .59187 .4151 L .59703 .41644 L p .847 .555 .495 r
F P
0 g
s
.51896 .71315 m .51875 .69883 L .52475 .70475 L p .822 .484 .416 r
F P
0 g
s
.68961 .58623 m .69376 .60397 L .7067 .59864 L p .52 .341 .579 r
F P
0 g
s
.7067 .59864 m .70214 .57989 L .68961 .58623 L p .52 .341 .579 r
F P
0 g
s
.68671 .53283 m .71574 .54529 L .73292 .534 L p .62 .515 .712 r
F P
0 g
s
.73292 .534 m .70066 .52178 L .68671 .53283 L p .62 .515 .712 r
F P
0 g
s
.38938 .5318 m .41287 .52623 L .40469 .52713 L p .002 0 0 r
F P
0 g
s
.40469 .52713 m .37855 .53371 L .38938 .5318 L p .002 0 0 r
F P
0 g
s
.30581 .66336 m .27617 .64644 L .2664 .65996 L p .498 .455 .74 r
F P
0 g
s
.2664 .65996 m .29706 .67669 L .30581 .66336 L p .498 .455 .74 r
F P
0 g
s
.44476 .4677 m .44356 .47279 L p .44445 .48444 L 0 0 .108 r
F P
0 g
s
.44445 .48444 m .44464 .48684 L .44466 .48247 L 0 0 .108 r
F
.44445 .48444 m .44466 .48247 L .44476 .4677 L F
.4447 .48573 m .44476 .4677 L p .44464 .48684 L F P
0 g
s
.44469 .48758 m .4447 .48573 L p .44464 .48684 L 0 0 .108 r
F P
0 g
s
.44476 .4677 m .44469 .48758 L .44449 .48057 L p .764 .615 .049 r
F P
0 g
s
.44607 .46213 m .44476 .4677 L p .44453 .47866 L .764 .615 .049 r
F P
0 g
s
.44449 .48057 m .44488 .47609 L p .44453 .47866 L .764 .615 .049 r
F P
0 g
s
.44488 .47609 m .44607 .46213 L p .44453 .47866 L .764 .615 .049 r
F P
0 g
s
.44604 .46233 m .44487 .47607 L .44445 .47285 L .851 .711 .183 r
F
.44449 .48057 m .44445 .47285 L p .44487 .47607 L F P
0 g
s
.44601 .46279 m .44449 .48057 L p .44604 .46233 L .851 .711 .183 r
F P
0 g
s
.44607 .46213 m .44601 .46279 L p .44604 .46233 L .851 .711 .183 r
F P
0 g
s
.44445 .47285 m .44762 .45619 L .44607 .46213 L p .851 .711 .183 r
F P
0 g
s
.44734 .45754 m .44445 .47285 L .44742 .45679 L .893 .783 .293 r
F
.44732 .45775 m .4473 .45785 L p .44734 .45754 L F P
0 g
s
.4473 .45785 m .44445 .47285 L p .44734 .45754 L .893 .783 .293 r
F P
0 g
s
.44445 .47285 m .44485 .46471 L p .44742 .45679 L .893 .783 .293 r
F P
0 g
s
.44762 .45619 m .44732 .45775 L p .44742 .45679 L .893 .783 .293 r
F P
0 g
s
.44356 .47279 m .44476 .49369 L .44469 .48758 L p 0 0 .108 r
F P
0 g
s
.66231 .66254 m .64088 .66515 L .63747 .65596 L p .839 .771 .786 r
F P
0 g
s
.63747 .65596 m .65786 .65252 L .66231 .66254 L p .839 .771 .786 r
F P
0 g
s
.65444 .4923 m .68673 .49294 L .69373 .48119 L p .638 .591 .785 r
F P
0 g
s
.69373 .48119 m .6588 .48272 L .65444 .4923 L p .638 .591 .785 r
F P
0 g
s
.64926 .68849 m .62735 .6859 L .62484 .67536 L p .835 .753 .773 r
F P
0 g
s
.62484 .67536 m .6451 .67611 L .64926 .68849 L p .835 .753 .773 r
F P
0 g
s
.63735 .47288 m .66134 .47359 L .66176 .46533 L p .589 .616 .847 r
F P
0 g
s
.66176 .46533 m .63688 .46638 L .63735 .47288 L p .589 .616 .847 r
F P
0 g
s
.51337 .70983 m .51323 .69391 L .51875 .69883 L p .811 .507 .476 r
F P
0 g
s
.51875 .69883 m .51896 .71315 L .51337 .70983 L p .811 .507 .476 r
F P
0 g
s
.41944 .52488 m .43413 .51943 L .42954 .52058 L p .01 0 0 r
F P
0 g
s
.42954 .52058 m .41287 .52623 L .41944 .52488 L p .01 0 0 r
F P
0 g
s
.42324 .71411 m .43836 .71023 L p .43214 .71152 L .211 .733 .737 r
F P
0 g
s
.41083 .71712 m .42848 .71249 L p .42359 .71221 L .368 .828 .917 r
F P
0 g
s
.42848 .71249 m .43214 .71152 L .42359 .71221 L p .368 .828 .917 r
F P
0 g
s
.42359 .71221 m .39928 .71829 L .41083 .71712 L p .368 .828 .917 r
F P
0 g
s
.39928 .71829 m .42359 .71221 L .41608 .71132 L p .483 .839 .994 r
F P
0 g
s
.43152 .71488 m .41873 .71193 L p .42359 .71221 L .246 0 0 r
F P
0 g
s
.41873 .71193 m .41608 .71132 L .42359 .71221 L p .246 0 0 r
F P
0 g
s
.43729 .71618 m .4258 .71285 L p .43214 .71152 L .466 0 0 r
F P
0 g
s
.4258 .71285 m .42359 .71221 L .43214 .71152 L p .466 0 0 r
F P
0 g
s
.43836 .71023 m .44133 .70946 L .43214 .71152 L p .211 .733 .737 r
F P
0 g
s
.37546 .70911 m .33633 .71407 L .34359 .72057 L p .567 .734 .954 r
F P
0 g
s
.34359 .72057 m .3811 .7143 L .37546 .70911 L p .567 .734 .954 r
F P
0 g
s
.67206 .63558 m .65542 .64452 L .65581 .63846 L p .882 .917 .844 r
F P
0 g
s
.65581 .63846 m .67252 .62907 L .67206 .63558 L p .882 .917 .844 r
F P
0 g
s
.69952 .55496 m .71802 .57247 L .73629 .56362 L p .589 .454 .664 r
F P
0 g
s
.73629 .56362 m .71574 .54529 L .69952 .55496 L p .589 .454 .664 r
F P
0 g
s
.59187 .4151 m .5932 .4412 L .5869 .44178 L p .829 .552 .52 r
F P
0 g
s
.5869 .44178 m .58648 .41408 L .59187 .4151 L p .829 .552 .52 r
F P
0 g
s
.43928 .5143 m .44352 .50284 L .44191 .50591 L p 0 0 0 r
F P
0 g
s
.44191 .50591 m .43742 .51743 L .43928 .5143 L p 0 0 0 r
F P
0 g
s
.50796 .7073 m .50799 .69032 L .51323 .69391 L p .794 .515 .515 r
F P
0 g
s
.51323 .69391 m .51337 .70983 L .50796 .7073 L p .794 .515 .515 r
F P
0 g
s
.67784 .50454 m .71429 .50945 L .72652 .49622 L p .63 .561 .758 r
F P
0 g
s
.72652 .49622 m .68673 .49294 L .67784 .50454 L p .63 .561 .758 r
F P
0 g
s
.68492 .60914 m .67682 .62393 L .68519 .61969 L p .23 0 .237 r
F P
0 g
s
.68519 .61969 m .69376 .60397 L .68492 .60914 L p .23 0 .237 r
F P
0 g
s
.50258 .7057 m .50274 .68824 L .50799 .69032 L p .775 .513 .539 r
F P
0 g
s
.50799 .69032 m .50796 .7073 L .50258 .7057 L p .775 .513 .539 r
F P
0 g
s
.33348 .56132 m .35221 .54479 L .33744 .54885 L p .282 0 .145 r
F P
0 g
s
.33744 .54885 m .31697 .56752 L .33348 .56132 L p .282 0 .145 r
F P
0 g
s
.31126 .58943 m .31697 .56752 L .30001 .57491 L p .405 .172 .444 r
F P
0 g
s
.30001 .57491 m .29371 .59891 L .31126 .58943 L p .405 .172 .444 r
F P
0 g
s
.62975 .70857 m .61214 .70513 L .61287 .69616 L p .861 .792 .782 r
F P
0 g
s
.61287 .69616 m .62917 .69715 L .62975 .70857 L p .861 .792 .782 r
F P
0 g
s
.6588 .48272 m .69373 .48119 L .69818 .46983 L p .633 .612 .812 r
F P
0 g
s
.69818 .46983 m .66134 .47359 L .6588 .48272 L p .633 .612 .812 r
F P
0 g
s
.70066 .52178 m .73292 .534 L .74979 .52121 L p .606 .512 .721 r
F P
0 g
s
.74979 .52121 m .71429 .50945 L .70066 .52178 L p .606 .512 .721 r
F P
0 g
s
.4971 .70505 m .49724 .68775 L .50274 .68824 L p .756 .502 .549 r
F P
0 g
s
.50274 .68824 m .50258 .7057 L .4971 .70505 L p .756 .502 .549 r
F P
0 g
s
.63688 .46638 m .66176 .46533 L .65989 .45835 L p .58 .655 .888 r
F P
0 g
s
.65989 .45835 m .63491 .46085 L .63688 .46638 L p .58 .655 .888 r
F P
0 g
s
.58648 .41408 m .5869 .44178 L .58058 .4426 L p .815 .55 .538 r
F P
0 g
s
.58058 .4426 m .58093 .41328 L .58648 .41408 L p .815 .55 .538 r
F P
0 g
s
.36533 .54128 m .38938 .5318 L .37855 .53371 L p .062 0 0 r
F P
0 g
s
.37855 .53371 m .35221 .54479 L .36533 .54128 L p .062 0 0 r
F P
0 g
s
.70214 .57989 m .7067 .59864 L .72311 .59263 L p .535 .349 .576 r
F P
0 g
s
.72311 .59263 m .71802 .57247 L .70214 .57989 L p .535 .349 .576 r
F P
0 g
s
.43974 .5098 m .44443 .49878 L .44352 .50284 L p .927 .879 .457 r
F P
0 g
s
.44352 .50284 m .43928 .5143 L .43974 .5098 L p .927 .879 .457 r
F P
0 g
s
.49138 .70533 m .49124 .68876 L .49724 .68775 L p .738 .485 .548 r
F P
0 g
s
.49724 .68775 m .4971 .70505 L .49138 .70533 L p .738 .485 .548 r
F P
0 g
s
.42395 .52263 m .43742 .51743 L .43413 .51943 L p .415 .861 .794 r
F P
0 g
s
.43413 .51943 m .41944 .52488 L .42395 .52263 L p .415 .861 .794 r
F P
0 g
s
.41287 .52623 m .40528 .52803 L p .39799 .52962 L .198 .722 .719 r
F P
0 g
s
.40528 .52803 m .38938 .5318 L .39799 .52962 L p .198 .722 .719 r
F P
0 g
s
.37573 .5378 m .39799 .52962 L .38938 .5318 L p 0 0 0 r
F P
0 g
s
.38938 .5318 m .36533 .54128 L .3723 .53895 L p 0 0 0 r
F P
0 g
s
.36746 .54606 m .3781 .53748 L p .37573 .5378 L 0 0 0 r
F P
0 g
s
.37841 .53662 m .37509 .53788 L .37573 .5378 L 0 0 0 r
F
.38938 .5318 m .3723 .53895 L .37841 .53662 L F
.39799 .52962 m .37573 .5378 L .3827 .53377 L p .532 .923 .871 r
F P
0 g
s
.3781 .53748 m .3827 .53377 L .37573 .5378 L p 0 0 0 r
F P
0 g
s
.3723 .53895 m .37573 .5378 L p .37509 .53788 L 0 0 0 r
F P
0 g
s
.3827 .53377 m .38957 .53145 L p .39527 .53021 L .532 .923 .871 r
F P
0 g
s
.39799 .52962 m .3939 .53073 L .39527 .53021 L .532 .923 .871 r
F
.3939 .53073 m .3827 .53377 L .39527 .53021 L F
.38957 .53145 m .40381 .52662 L .39799 .52962 L p F P
0 g
s
.39799 .52962 m .41944 .52488 L .41287 .52623 L p .198 .722 .719 r
F P
0 g
s
.48534 .70641 m .48457 .69109 L .49124 .68876 L p .72 .462 .535 r
F P
0 g
s
.49124 .68876 m .49138 .70533 L .48534 .70641 L p .72 .462 .535 r
F P
0 g
s
.30543 .62121 m .29371 .59891 L .27722 .60973 L p .48 .341 .614 r
F P
0 g
s
.27722 .60973 m .2896 .63335 L .30543 .62121 L p .48 .341 .614 r
F P
0 g
s
.65786 .65252 m .63747 .65596 L .63565 .6487 L p .831 .795 .817 r
F P
0 g
s
.63565 .6487 m .65542 .64452 L .65786 .65252 L p .831 .795 .817 r
F P
0 g
s
.6451 .67611 m .62484 .67536 L .62225 .66598 L p .834 .748 .769 r
F P
0 g
s
.62225 .66598 m .64088 .66515 L .6451 .67611 L p .834 .748 .769 r
F P
0 g
s
.58093 .41328 m .58058 .4426 L .57435 .44344 L p .802 .547 .553 r
F P
0 g
s
.57435 .44344 m .57527 .41258 L .58093 .41328 L p .802 .547 .553 r
F P
0 g
s
.47893 .7081 m .47712 .69442 L .48457 .69109 L p .703 .432 .511 r
F P
0 g
s
.48457 .69109 m .48534 .70641 L .47893 .7081 L p .703 .432 .511 r
F P
0 g
s
.68673 .49294 m .72652 .49622 L .73631 .48258 L p .619 .572 .78 r
F P
0 g
s
.73631 .48258 m .69373 .48119 L .68673 .49294 L p .619 .572 .78 r
F P
0 g
s
.71574 .54529 m .73629 .56362 L .75571 .55316 L p .574 .444 .666 r
F P
0 g
s
.75571 .55316 m .73292 .534 L .71574 .54529 L p .574 .444 .666 r
F P
0 g
s
.33675 .68344 m .29706 .67669 L .29233 .68959 L p .559 .562 .813 r
F P
0 g
s
.29233 .68959 m .33291 .69502 L .33675 .68344 L p .559 .562 .813 r
F P
0 g
s
.67252 .62907 m .65581 .63846 L .65956 .63405 L p .749 .994 .858 r
F P
0 g
s
.47216 .71016 m .46891 .69836 L .47712 .69442 L p .686 .394 .473 r
F P
0 g
s
.47712 .69442 m .47893 .7081 L .47216 .71016 L p .686 .394 .473 r
F P
0 g
s
.43899 .50381 m .44476 .49369 L .44443 .49878 L p .995 .854 .582 r
F P
0 g
s
.44443 .49878 m .43974 .5098 L .43899 .50381 L p .995 .854 .582 r
F P
0 g
s
.41608 .71132 m .38919 .71737 L .39928 .71829 L p .483 .839 .994 r
F P
0 g
s
.63491 .46085 m .65989 .45835 L .65572 .45299 L p .564 .702 .934 r
F P
0 g
s
.65572 .45299 m .63146 .4565 L .63491 .46085 L p .564 .702 .934 r
F P
0 g
s
.37253 .70204 m .33272 .70541 L .33633 .71407 L p .587 .68 .905 r
F P
0 g
s
.33633 .71407 m .37546 .70911 L .37253 .70204 L p .587 .68 .905 r
F P
0 g
s
.66134 .47359 m .69818 .46983 L .69959 .45943 L p .628 .641 .844 r
F P
0 g
s
.69959 .45943 m .66176 .46533 L .66134 .47359 L p .628 .641 .844 r
F P
0 g
s
.69376 .60397 m .68519 .61969 L .69746 .61577 L p .396 .106 .351 r
F P
0 g
s
.69746 .61577 m .7067 .59864 L .69376 .60397 L p .396 .106 .351 r
F P
0 g
s
.62917 .69715 m .61287 .69616 L .61272 .68725 L p .873 .779 .755 r
F P
0 g
s
.61272 .68725 m .62735 .6859 L .62917 .69715 L p .873 .779 .755 r
F P
0 g
s
.57527 .41258 m .57435 .44344 L .56828 .44409 L p .792 .544 .563 r
F P
0 g
s
.56828 .44409 m .56954 .4119 L .57527 .41258 L p .792 .544 .563 r
F P
0 g
s
.4651 .7123 m .46005 .70248 L .46891 .69836 L p .668 .346 .419 r
F P
0 g
s
.46891 .69836 m .47216 .71016 L .4651 .7123 L p .668 .346 .419 r
F P
0 g
s
.42621 .51905 m .43928 .5143 L .43742 .51743 L p .782 .955 .927 r
F P
0 g
s
.43742 .51743 m .42395 .52263 L .42621 .51905 L p .782 .955 .927 r
F P
0 g
s
.71429 .50945 m .74979 .52121 L .76505 .50721 L p .59 .513 .737 r
F P
0 g
s
.76505 .50721 m .72652 .49622 L .71429 .50945 L p .59 .513 .737 r
F P
0 g
s
.53107 .7464 m .53105 .7213 L .53767 .72557 L p .732 .466 .526 r
F P
0 g
s
.53767 .72557 m .53754 .74868 L .53107 .7464 L p .732 .466 .526 r
F P
0 g
s
.53754 .74868 m .53767 .72557 L .54465 .72955 L p .716 .437 .503 r
F P
0 g
s
.54465 .72955 m .54415 .75071 L .53754 .74868 L p .716 .437 .503 r
F P
0 g
s
.54415 .75071 m .54465 .72955 L .5519 .73294 L p .693 .402 .478 r
F P
0 g
s
.52479 .74405 m .52482 .71706 L .53105 .7213 L p .742 .488 .546 r
F P
0 g
s
.53105 .7213 m .53107 .7464 L .52479 .74405 L p .742 .488 .546 r
F P
0 g
s
.51868 .74179 m .51896 .71315 L .52482 .71706 L p .75 .506 .562 r
F P
0 g
s
.52482 .71706 m .52479 .74405 L .51868 .74179 L p .75 .506 .562 r
F P
0 g
s
.5519 .73294 m .55086 .75232 L .54415 .75071 L p .693 .402 .478 r
F P
0 g
s
.55086 .75232 m .5519 .73294 L .5593 .73546 L p .663 .361 .451 r
F P
0 g
s
.71802 .57247 m .72311 .59263 L .74203 .58547 L p .529 .343 .573 r
F P
0 g
s
.74203 .58547 m .73629 .56362 L .71802 .57247 L p .529 .343 .573 r
F P
0 g
s
.31772 .65021 m .2896 .63335 L .27617 .64644 L p .537 .459 .715 r
F P
0 g
s
.27617 .64644 m .30581 .66336 L .31772 .65021 L p .537 .459 .715 r
F P
0 g
s
.45789 .71424 m .45075 .70632 L .46005 .70248 L p .648 .285 .342 r
F P
0 g
s
.46005 .70248 m .4651 .7123 L .45789 .71424 L p .648 .285 .342 r
F P
0 g
s
.40381 .52662 m .42395 .52263 L .41944 .52488 L p .543 .914 .95 r
F P
0 g
s
.41944 .52488 m .39799 .52962 L .40381 .52662 L p .543 .914 .95 r
F P
0 g
s
.48073 .42015 m .48337 .39955 L .48953 .39851 L p .557 .272 .438 r
F P
0 g
s
.44956 .45008 m .44485 .46471 L .44598 .45648 L p .904 .842 .385 r
F P
0 g
s
.56954 .4119 m .56828 .44409 L .56239 .44436 L p .783 .541 .57 r
F P
0 g
s
.56239 .44436 m .56378 .41114 L .56954 .4119 L p .783 .541 .57 r
F P
0 g
s
.51272 .73977 m .51337 .70983 L .51896 .71315 L p .754 .519 .575 r
F P
0 g
s
.51896 .71315 m .51868 .74179 L .51272 .73977 L p .754 .519 .575 r
F P
0 g
s
.43736 .49632 m .44469 .48758 L .44476 .49369 L p .972 .812 .625 r
F P
0 g
s
.44476 .49369 m .43899 .50381 L .43736 .49632 L p .972 .812 .625 r
F P
0 g
s
.5593 .73546 m .5576 .75335 L .55086 .75232 L p .663 .361 .451 r
F P
0 g
s
.5576 .75335 m .5593 .73546 L .56668 .73688 L p .622 .312 .424 r
F P
0 g
s
.60596 .45249 m .59936 .44107 L .6052 .44158 L p .753 .332 .251 r
F P
0 g
s
.50687 .73809 m .50796 .7073 L .51337 .70983 L p .758 .528 .585 r
F P
0 g
s
.51337 .70983 m .51272 .73977 L .50687 .73809 L p .758 .528 .585 r
F P
0 g
s
.34812 .556 m .36533 .54128 L .35221 .54479 L p .277 0 .12 r
F P
0 g
s
.35221 .54479 m .33348 .56132 L .34812 .556 L p .277 0 .12 r
F P
0 g
s
.64088 .66515 m .62225 .66598 L .6202 .65807 L p .832 .754 .778 r
F P
0 g
s
.6202 .65807 m .63747 .65596 L .64088 .66515 L p .832 .754 .778 r
F P
0 g
s
.65542 .64452 m .63565 .6487 L .63608 .64336 L p .814 .852 .877 r
F P
0 g
s
.63608 .64336 m .65581 .63846 L .65542 .64452 L p .814 .852 .877 r
F P
0 g
s
.56668 .73688 m .56427 .75368 L .5576 .75335 L p .622 .312 .424 r
F P
0 g
s
.56427 .75368 m .56668 .73688 L .57385 .73703 L p .572 .258 .398 r
F P
0 g
s
.48744 .41967 m .48953 .39851 L .49587 .39812 L p .6 .315 .455 r
F P
0 g
s
.69373 .48119 m .73631 .48258 L .74278 .46915 L p .608 .59 .808 r
F P
0 g
s
.74278 .46915 m .69818 .46983 L .69373 .48119 L p .608 .59 .808 r
F P
0 g
s
.50107 .73683 m .50258 .7057 L .50796 .7073 L p .76 .534 .591 r
F P
0 g
s
.50796 .7073 m .50687 .73809 L .50107 .73683 L p .76 .534 .591 r
F P
0 g
s
.56378 .41114 m .56239 .44436 L .55666 .44408 L p .775 .536 .574 r
F P
0 g
s
.55666 .44408 m .55798 .41023 L .56378 .41114 L p .775 .536 .574 r
F P
0 g
s
.63146 .4565 m .65572 .45299 L .6494 .44948 L p .532 .756 .979 r
F P
0 g
s
.6494 .44948 m .62662 .45348 L .63146 .4565 L p .532 .756 .979 r
F P
0 g
s
.42626 .51381 m .43974 .5098 L .43928 .5143 L p .848 .847 .842 r
F P
0 g
s
.43928 .5143 m .42621 .51905 L .42626 .51381 L p .848 .847 .842 r
F P
0 g
s
.4507 .71569 m .44133 .70946 L .45075 .70632 L p .62 .202 .228 r
F P
0 g
s
.45075 .70632 m .45789 .71424 L .4507 .71569 L p .62 .202 .228 r
F P
0 g
s
.40996 .70878 m .3811 .7143 L .38919 .71737 L p .548 .796 .99 r
F P
0 g
s
.38919 .71737 m .41608 .71132 L .40996 .70878 L p .548 .796 .99 r
F P
0 g
s
.66631 .6301 m .65956 .63405 L .66685 .63087 L p 0 0 0 r
F P
0 g
s
.63915 .63971 m .65956 .63405 L .65581 .63846 L p .737 .937 .952 r
F P
0 g
s
.65956 .63405 m .63915 .63971 L .6421 .63856 L p .426 .87 .847 r
F P
0 g
s
.6421 .63856 m .64501 .63743 L p .64863 .63659 L .426 .87 .847 r
F P
0 g
s
.64863 .63659 m .65956 .63405 L .6421 .63856 L .426 .87 .847 r
F
.64501 .63743 m .66685 .63087 L .65956 .63405 L p F P
0 g
s
.65353 .63606 m .66738 .63163 L p .66697 .63104 L 0 0 0 r
F P
0 g
s
.66446 .6318 m .66697 .63104 L .66685 .63087 L 0 0 0 r
F
.65353 .63606 m .66697 .63104 L .66446 .6318 L F
.66738 .63163 m .67752 .62839 L .66685 .63087 L p F P
0 g
s
.67682 .62393 m .66631 .6301 L p .66685 .63087 L 0 0 0 r
F P
0 g
s
.49528 .73602 m .4971 .70505 L .50258 .7057 L p .763 .538 .593 r
F P
0 g
s
.50258 .7057 m .50107 .73683 L .49528 .73602 L p .763 .538 .593 r
F P
0 g
s
.73292 .534 m .75571 .55316 L .77486 .54107 L p .553 .435 .673 r
F P
0 g
s
.77486 .54107 m .74979 .52121 L .73292 .534 L p .553 .435 .673 r
F P
0 g
s
.32832 .58132 m .33348 .56132 L .31697 .56752 L p .443 .204 .455 r
F P
0 g
s
.31697 .56752 m .31126 .58943 L .32832 .58132 L p .443 .204 .455 r
F P
0 g
s
.45202 .44399 m .44598 .45648 L .44805 .44853 L p .885 .889 .463 r
F P
0 g
s
.66176 .46533 m .69959 .45943 L .69771 .45052 L p .624 .678 .881 r
F P
0 g
s
.69771 .45052 m .65989 .45835 L .66176 .46533 L p .624 .678 .881 r
F P
0 g
s
.62735 .6859 m .61272 .68725 L .61205 .67883 L p .883 .771 .733 r
F P
0 g
s
.61205 .67883 m .62484 .67536 L .62735 .6859 L p .883 .771 .733 r
F P
0 g
s
.4353 .48747 m .44449 .48057 L .44469 .48758 L p .949 .794 .655 r
F P
0 g
s
.44469 .48758 m .43736 .49632 L .4353 .48747 L p .949 .794 .655 r
F P
0 g
s
.49437 .42028 m .49587 .39812 L .50233 .39832 L p .636 .354 .474 r
F P
0 g
s
.49587 .39812 m .49437 .42028 L .48744 .41967 L p .6 .315 .455 r
F P
0 g
s
.55798 .41023 m .55666 .44408 L .55104 .44318 L p .767 .53 .575 r
F P
0 g
s
.55104 .44318 m .55214 .40914 L .55798 .41023 L p .767 .53 .575 r
F P
0 g
s
.57385 .73703 m .57077 .75322 L .56427 .75368 L p .572 .258 .398 r
F P
0 g
s
.48944 .73564 m .49138 .70533 L .4971 .70505 L p .765 .54 .592 r
F P
0 g
s
.4971 .70505 m .49528 .73602 L .48944 .73564 L p .765 .54 .592 r
F P
0 g
s
.7067 .59864 m .69746 .61577 L .71304 .61161 L p .441 .159 .388 r
F P
0 g
s
.71304 .61161 m .72311 .59263 L .7067 .59864 L p .441 .159 .388 r
F P
0 g
s
.59936 .44107 m .60596 .45249 L .598 .4544 L p .753 .389 .365 r
F P
0 g
s
.598 .4544 m .5932 .4412 L .59936 .44107 L p .753 .389 .365 r
F P
0 g
s
.50139 .42183 m .50233 .39832 L .50882 .39904 L p .666 .389 .492 r
F P
0 g
s
.50233 .39832 m .50139 .42183 L .49437 .42028 L p .636 .354 .474 r
F P
0 g
s
.55214 .40914 m .55104 .44318 L .54545 .44161 L p .76 .522 .573 r
F P
0 g
s
.54545 .44161 m .54624 .40786 L .55214 .40914 L p .76 .522 .573 r
F P
0 g
s
.40655 .52229 m .42621 .51905 L .42395 .52263 L p .745 .894 .946 r
F P
0 g
s
.42395 .52263 m .40381 .52662 L .40655 .52229 L p .745 .894 .946 r
F P
0 g
s
.44376 .7164 m .43214 .71152 L .44133 .70946 L p .571 .08 .051 r
F P
0 g
s
.44133 .70946 m .4507 .71569 L .44376 .7164 L p .571 .08 .051 r
F P
0 g
s
.48351 .73563 m .48534 .70641 L .49138 .70533 L p .769 .54 .588 r
F P
0 g
s
.49138 .70533 m .48944 .73564 L .48351 .73563 L p .769 .54 .588 r
F P
0 g
s
.50835 .42417 m .50882 .39904 L .51529 .40016 L p .689 .42 .51 r
F P
0 g
s
.50882 .39904 m .50835 .42417 L .50139 .42183 L p .666 .389 .492 r
F P
0 g
s
.54624 .40786 m .54545 .44161 L .5398 .4394 L p .752 .512 .569 r
F P
0 g
s
.5398 .4394 m .54026 .40639 L .54624 .40786 L p .752 .512 .569 r
F P
0 g
s
.42439 .50671 m .43899 .50381 L .43974 .5098 L p .849 .778 .782 r
F P
0 g
s
.43974 .5098 m .42626 .51381 L .42439 .50671 L p .849 .778 .782 r
F P
0 g
s
.5806 .73585 m .57699 .75192 L .58283 .74978 L p .423 .126 .354 r
F P
0 g
s
.5806 .73585 m .57699 .75192 L .57077 .75322 L p .511 .2 .376 r
F P
0 g
s
.37242 .69342 m .33291 .69502 L .33272 .70541 L p .602 .638 .859 r
F P
0 g
s
.33272 .70541 m .37253 .70204 L .37242 .69342 L p .602 .638 .859 r
F P
0 g
s
.45511 .43816 m .44805 .44853 L .45121 .44125 L p .826 .919 .526 r
F P
0 g
s
.51514 .42706 m .51529 .40016 L .5217 .40158 L p .708 .446 .526 r
F P
0 g
s
.51529 .40016 m .51514 .42706 L .50835 .42417 L p .689 .42 .51 r
F P
0 g
s
.54026 .40639 m .5398 .4394 L .534 .43667 L p .744 .5 .562 r
F P
0 g
s
.534 .43667 m .53419 .4048 L .54026 .40639 L p .744 .5 .562 r
F P
0 g
s
.32223 .61038 m .31126 .58943 L .29371 .59891 L p .518 .364 .612 r
F P
0 g
s
.29371 .59891 m .30543 .62121 L .32223 .61038 L p .518 .364 .612 r
F P
0 g
s
.72652 .49622 m .76505 .50721 L .77741 .49251 L p .57 .519 .759 r
F P
0 g
s
.77741 .49251 m .73631 .48258 L .72652 .49622 L p .57 .519 .759 r
F P
0 g
s
.62662 .45348 m .6494 .44948 L .64124 .44795 L p .462 .8 .999 r
F P
0 g
s
.43329 .47751 m .44445 .47285 L .44449 .48057 L p .93 .792 .686 r
F P
0 g
s
.44449 .48057 m .4353 .48747 L .43329 .47751 L p .93 .792 .686 r
F P
0 g
s
.4775 .73588 m .47893 .7081 L .48534 .70641 L p .773 .538 .58 r
F P
0 g
s
.48534 .70641 m .48351 .73563 L .4775 .73588 L p .773 .538 .58 r
F P
0 g
s
.52169 .43028 m .5217 .40158 L .528 .40316 L p .722 .468 .541 r
F P
0 g
s
.5217 .40158 m .52169 .43028 L .51514 .42706 L p .708 .446 .526 r
F P
0 g
s
.53419 .4048 m .534 .43667 L .52798 .43356 L p .734 .486 .553 r
F P
0 g
s
.52798 .43356 m .528 .40316 L .53419 .4048 L p .734 .486 .553 r
F P
0 g
s
.528 .40316 m .52798 .43356 L .52169 .43028 L p .722 .468 .541 r
F P
0 g
s
.3438 .67127 m .30581 .66336 L .29706 .67669 L p .582 .545 .779 r
F P
0 g
s
.29706 .67669 m .33675 .68344 L .3438 .67127 L p .582 .545 .779 r
F P
0 g
s
.63747 .65596 m .6202 .65807 L .61927 .65181 L p .828 .781 .808 r
F P
0 g
s
.61927 .65181 m .63565 .6487 L .63747 .65596 L p .828 .781 .808 r
F P
0 g
s
.73629 .56362 m .74203 .58547 L .76217 .57686 L p .508 .328 .572 r
F P
0 g
s
.76217 .57686 m .75571 .55316 L .73629 .56362 L p .508 .328 .572 r
F P
0 g
s
.65581 .63846 m .63608 .64336 L .63915 .63971 L p .737 .937 .952 r
F P
0 g
s
.5932 .4412 m .598 .4544 L .58999 .45697 L p .751 .429 .439 r
F P
0 g
s
.58999 .45697 m .5869 .44178 L .5932 .4412 L p .751 .429 .439 r
F P
0 g
s
.62484 .67536 m .61205 .67883 L .61125 .67123 L p .894 .772 .719 r
F P
0 g
s
.61125 .67123 m .62225 .66598 L .62484 .67536 L p .894 .772 .719 r
F P
0 g
s
.58676 .73331 m .58283 .74978 L .58822 .74685 L p .299 .03 .327 r
F P
0 g
s
.40552 .70462 m .37546 .70911 L .3811 .7143 L p .581 .738 .951 r
F P
0 g
s
.3811 .7143 m .40996 .70878 L .40552 .70462 L p .581 .738 .951 r
F P
0 g
s
.47142 .73626 m .47216 .71016 L .47893 .7081 L p .779 .535 .568 r
F P
0 g
s
.47893 .7081 m .4775 .73588 L .47142 .73626 L p .779 .535 .568 r
F P
0 g
s
.69818 .46983 m .74278 .46915 L .74524 .4566 L p .597 .617 .843 r
F P
0 g
s
.74524 .4566 m .69959 .45943 L .69818 .46983 L p .597 .617 .843 r
F P
0 g
s
.43214 .71152 m .44376 .7164 L .43729 .71618 L p .466 0 0 r
F P
0 g
s
.65989 .45835 m .69771 .45052 L .69249 .4436 L p .618 .725 .923 r
F P
0 g
s
.69249 .4436 m .65572 .45299 L .65989 .45835 L p .618 .725 .923 r
F P
0 g
s
.4589 .43282 m .45121 .44125 L .45552 .435 L p .705 .912 .563 r
F P
0 g
s
.68519 .61969 m .66685 .63087 L .67752 .62839 L p .175 0 0 r
F P
0 g
s
.67752 .62839 m .69746 .61577 L .68519 .61969 L p .175 0 0 r
F P
0 g
s
.35972 .5511 m .37573 .5378 L .36533 .54128 L p .163 0 0 r
F P
0 g
s
.36533 .54128 m .34812 .556 L .35972 .5511 L p .163 0 0 r
F P
0 g
s
.42109 .49768 m .43736 .49632 L .43899 .50381 L p .845 .748 .756 r
F P
0 g
s
.43899 .50381 m .42439 .50671 L .42109 .49768 L p .845 .748 .756 r
F P
0 g
s
.40628 .51619 m .42626 .51381 L .42621 .51905 L p .799 .814 .864 r
F P
0 g
s
.42621 .51905 m .40655 .52229 L .40628 .51619 L p .799 .814 .864 r
F P
0 g
s
.43183 .46682 m .44485 .46471 L .44445 .47285 L p .914 .798 .719 r
F P
0 g
s
.44445 .47285 m .43329 .47751 L .43183 .46682 L p .914 .798 .719 r
F P
0 g
s
.46531 .73663 m .4651 .7123 L .47216 .71016 L p .786 .531 .552 r
F P
0 g
s
.47216 .71016 m .47142 .73626 L .46531 .73663 L p .786 .531 .552 r
F P
0 g
s
.5869 .44178 m .58999 .45697 L .58221 .45986 L p .75 .459 .489 r
F P
0 g
s
.58221 .45986 m .58058 .4426 L .5869 .44178 L p .75 .459 .489 r
F P
0 g
s
.62058 .45184 m .64124 .44795 L .63166 .44836 L p .322 .789 .934 r
F P
0 g
s
.59218 .72952 m .58822 .74685 L .5931 .74321 L p .161 0 .303 r
F P
0 g
s
.3317 .63782 m .30543 .62121 L .2896 .63335 L p .565 .465 .7 r
F P
0 g
s
.2896 .63335 m .31772 .65021 L .3317 .63782 L p .565 .465 .7 r
F P
0 g
s
.74979 .52121 m .77486 .54107 L .79227 .52757 L p .525 .427 .686 r
F P
0 g
s
.79227 .52757 m .76505 .50721 L .74979 .52121 L p .525 .427 .686 r
F P
0 g
s
.72311 .59263 m .71304 .61161 L .731 .60667 L p .439 .164 .398 r
F P
0 g
s
.731 .60667 m .74203 .58547 L .72311 .59263 L p .439 .164 .398 r
F P
0 g
s
.34343 .5744 m .34812 .556 L .33348 .56132 L p .45 .208 .455 r
F P
0 g
s
.33348 .56132 m .32832 .58132 L .34343 .5744 L p .45 .208 .455 r
F P
0 g
s
.63565 .6487 m .61927 .65181 L .6199 .64721 L p .814 .842 .871 r
F P
0 g
s
.6199 .64721 m .63608 .64336 L .63565 .6487 L p .814 .842 .871 r
F P
0 g
s
.38589 .52861 m .40655 .52229 L .40381 .52662 L p .78 .938 .932 r
F P
0 g
s
.40381 .52662 m .3827 .53377 L .38589 .52861 L p .78 .938 .932 r
F P
0 g
s
.62225 .66598 m .61125 .67123 L .61072 .6647 L p .909 .789 .715 r
F P
0 g
s
.61072 .6647 m .6202 .65807 L .62225 .66598 L p .909 .789 .715 r
F P
0 g
s
.45924 .73681 m .45789 .71424 L .4651 .7123 L p .796 .527 .53 r
F P
0 g
s
.4651 .7123 m .46531 .73663 L .45924 .73681 L p .796 .527 .53 r
F P
0 g
s
.41701 .48684 m .4353 .48747 L .43736 .49632 L p .841 .739 .75 r
F P
0 g
s
.43736 .49632 m .42109 .49768 L .41701 .48684 L p .841 .739 .75 r
F P
0 g
s
.43337 .73038 m .42727 .71402 L p .43152 .71488 L .9 .505 .258 r
F P
0 g
s
.42359 .71221 m .43577 .71574 L p .43152 .71488 L .246 0 0 r
F P
0 g
s
.41608 .71132 m .42989 .71451 L p .42668 .71245 L .049 .542 .885 r
F P
0 g
s
.42989 .71451 m .43152 .71488 L .42668 .71245 L p .049 .542 .885 r
F P
0 g
s
.42668 .71245 m .40996 .70878 L .41608 .71132 L p .049 .542 .885 r
F P
0 g
s
.40996 .70878 m .42501 .71208 L p .42291 .70889 L .261 .586 .946 r
F P
0 g
s
.42501 .71208 m .42668 .71245 L .42291 .70889 L p .261 .586 .946 r
F P
0 g
s
.42291 .70889 m .40552 .70462 L .40996 .70878 L p .261 .586 .946 r
F P
0 g
s
.40552 .70462 m .42128 .70849 L p .42034 .7043 L .371 .566 .912 r
F P
0 g
s
.42128 .70849 m .42291 .70889 L .42034 .7043 L p .371 .566 .912 r
F P
0 g
s
.42713 .72317 m .42087 .70578 L p .42291 .70889 L .854 .452 0 r
F P
0 g
s
.42087 .70578 m .42034 .7043 L .42291 .70889 L p .854 .452 0 r
F P
0 g
s
.42034 .7043 m .42621 .72063 L p .42515 .71866 L .739 .392 0 r
F P
0 g
s
.42621 .72063 m .42713 .72317 L .42515 .71866 L p .739 .392 0 r
F P
0 g
s
.42596 .74773 m .42412 .71674 L p .42515 .71866 L .958 .676 .238 r
F P
0 g
s
.42515 .71866 m .41943 .70025 L p .42034 .7043 L .739 .392 0 r
F P
0 g
s
.41898 .69881 m .42435 .71609 L p .42394 .7137 L 0 0 .272 r
F P
0 g
s
.42435 .71609 m .42515 .71866 L .42394 .7137 L p 0 0 .272 r
F P
0 g
s
.42394 .7137 m .4188 .69263 L .41898 .69881 L p 0 0 .272 r
F P
0 g
s
.42987 .7271 m .4235 .71042 L p .42668 .71245 L .903 .489 .131 r
F P
0 g
s
.4235 .71042 m .42291 .70889 L .42668 .71245 L p .903 .489 .131 r
F P
0 g
s
.42291 .70889 m .42987 .7271 L .42713 .72317 L p .854 .452 0 r
F P
0 g
s
.4188 .69263 m .42328 .71101 L p .42343 .70841 L 0 0 .313 r
F P
0 g
s
.42328 .71101 m .42394 .7137 L .42343 .70841 L p 0 0 .313 r
F P
0 g
s
.42394 .7137 m .42396 .71482 L .42353 .71137 L .921 .67 .179 r
F
.42396 .71482 m .42386 .71855 L .42353 .71137 L F
.42407 .72676 m .42353 .71137 L p .42426 .72714 L F P
0 g
s
.42383 .73902 m .42347 .73456 L p .42349 .7256 L .795 .628 .069 r
F P
0 g
s
.42353 .71137 m .42343 .70841 L .42394 .7137 L p .921 .67 .179 r
F P
0 g
s
.42343 .70841 m .42465 .74344 L .42383 .73902 L p .865 .654 .121 r
F P
0 g
s
.42343 .70841 m .42367 .72679 L .42358 .70588 L .865 .654 .121 r
F
.42383 .73902 m .42371 .72387 L p .42367 .72679 L F P
0 g
s
.42371 .72387 m .42358 .70588 L p .42367 .72679 L .865 .654 .121 r
F P
0 g
s
.42355 .70295 m .42371 .72387 L p .42349 .7256 L .795 .628 .069 r
F P
0 g
s
.42371 .72387 m .42373 .72608 L p .42367 .72595 L .795 .628 .069 r
F P
0 g
s
.42371 .72387 m .42367 .72595 L .42349 .7256 L .795 .628 .069 r
F
.42373 .72608 m .42383 .73902 L p .42349 .7256 L F P
0 g
s
.42358 .70588 m .42355 .70295 L .42343 .70841 L p .865 .654 .121 r
F P
0 g
s
.4242 .69746 m .42355 .70295 L p .4235 .7239 L .795 .628 .069 r
F P
0 g
s
.42347 .73456 m .42376 .71991 L p .4235 .7239 L .795 .628 .069 r
F P
0 g
s
.42376 .71991 m .4242 .69746 L p .4235 .7239 L .795 .628 .069 r
F P
0 g
s
.42387 .71328 m .42356 .73 L .42352 .73012 L .717 .595 .022 r
F
.42382 .71671 m .42356 .73 L p .42387 .71328 L F P
0 g
s
.42396 .71482 m .42426 .72714 L .42386 .71855 L .921 .67 .179 r
F
.42412 .71674 m .42394 .7137 L .42515 .71866 L p .958 .676 .238 r
F P
0 g
s
.42394 .7137 m .42596 .74773 L .42465 .74344 L p .921 .67 .179 r
F P
0 g
s
.42352 .73012 m .42394 .72578 L p .42478 .70417 L 0 0 .02 r
F P
0 g
s
.42525 .6921 m .42451 .70831 L p .42478 .70417 L 0 0 .02 r
F P
0 g
s
.42451 .70831 m .42352 .73012 L p .42478 .70417 L 0 0 .02 r
F P
0 g
s
.4242 .69746 m .42382 .71671 L p .42387 .71328 L .717 .595 .022 r
F P
0 g
s
.42356 .73 m .42347 .73456 L .42349 .73241 L p .717 .595 .022 r
F P
0 g
s
.42349 .73241 m .42352 .73012 L p .42356 .73 L .717 .595 .022 r
F P
0 g
s
.42465 .74344 m .42407 .72676 L p .42426 .72714 L .921 .67 .179 r
F P
0 g
s
.41943 .70025 m .41898 .69881 L .42034 .7043 L p .739 .392 0 r
F P
0 g
s
.42727 .71402 m .42668 .71245 L .43152 .71488 L p .9 .505 .258 r
F P
0 g
s
.43577 .71574 m .43729 .71618 L .43152 .71488 L p .246 0 0 r
F P
0 g
s
.4314 .45586 m .44598 .45648 L .44485 .46471 L p .897 .809 .754 r
F P
0 g
s
.44485 .46471 m .43183 .46682 L .4314 .45586 L p .897 .809 .754 r
F P
0 g
s
.58058 .4426 m .58221 .45986 L .57483 .46267 L p .75 .481 .525 r
F P
0 g
s
.57483 .46267 m .57435 .44344 L .58058 .4426 L p .75 .481 .525 r
F P
0 g
s
.40336 .508 m .42439 .50671 L .42626 .51381 L p .813 .766 .809 r
F P
0 g
s
.42626 .51381 m .40628 .51619 L .40336 .508 L p .813 .766 .809 r
F P
0 g
s
.51845 .78114 m .51868 .74179 L .52479 .74405 L p .722 .478 .557 r
F P
0 g
s
.52479 .74405 m .52475 .78227 L .51845 .78114 L p .722 .478 .557 r
F P
0 g
s
.52475 .78227 m .52479 .74405 L .53107 .7464 L p .709 .463 .55 r
F P
0 g
s
.59676 .72463 m .5931 .74321 L .59743 .73898 L p .025 0 .285 r
F P
0 g
s
.53107 .7464 m .53113 .78332 L .52475 .78227 L p .709 .463 .55 r
F P
0 g
s
.53113 .78332 m .53107 .7464 L .53754 .74868 L p .695 .446 .543 r
F P
0 g
s
.51222 .78001 m .51272 .73977 L .51868 .74179 L p .733 .491 .562 r
F P
0 g
s
.51868 .74179 m .51845 .78114 L .51222 .78001 L p .733 .491 .562 r
F P
0 g
s
.53754 .74868 m .53756 .78423 L .53113 .78332 L p .695 .446 .543 r
F P
0 g
s
.53756 .78423 m .53754 .74868 L .54415 .75071 L p .678 .427 .535 r
F P
0 g
s
.375 .68368 m .33675 .68344 L .33291 .69502 L p .614 .608 .821 r
F P
0 g
s
.33291 .69502 m .37242 .69342 L .375 .68368 L p .614 .608 .821 r
F P
0 g
s
.65572 .45299 m .69249 .4436 L .68417 .43903 L p .608 .782 .964 r
F P
0 g
s
.68417 .43903 m .6494 .44948 L .65572 .45299 L p .608 .782 .964 r
F P
0 g
s
.50607 .77892 m .50687 .73809 L .51272 .73977 L p .744 .503 .566 r
F P
0 g
s
.51272 .73977 m .51222 .78001 L .50607 .77892 L p .744 .503 .566 r
F P
0 g
s
.40293 .69897 m .37253 .70204 L .37546 .70911 L p .598 .686 .904 r
F P
0 g
s
.37546 .70911 m .40552 .70462 L .40293 .69897 L p .598 .686 .904 r
F P
0 g
s
.54415 .75071 m .54402 .78491 L .53756 .78423 L p .678 .427 .535 r
F P
0 g
s
.54402 .78491 m .54415 .75071 L .55086 .75232 L p .659 .406 .527 r
F P
0 g
s
.73631 .48258 m .77741 .49251 L .78576 .47772 L p .548 .532 .79 r
F P
0 g
s
.78576 .47772 m .74278 .46915 L .73631 .48258 L p .548 .532 .79 r
F P
0 g
s
.57435 .44344 m .57483 .46267 L .56797 .46503 L p .752 .499 .549 r
F P
0 g
s
.56797 .46503 m .56828 .44409 L .57435 .44344 L p .752 .499 .549 r
F P
0 g
s
.49998 .77792 m .50107 .73683 L .50687 .73809 L p .754 .513 .568 r
F P
0 g
s
.50687 .73809 m .50607 .77892 L .49998 .77792 L p .754 .513 .568 r
F P
0 g
s
.45331 .73666 m .4507 .71569 L .45789 .71424 L p .81 .522 .502 r
F P
0 g
s
.45789 .71424 m .45924 .73681 L .45331 .73666 L p .81 .522 .502 r
F P
0 g
s
.69746 .61577 m .67752 .62839 L .69105 .62607 L p .293 0 .06 r
F P
0 g
s
.69105 .62607 m .71304 .61161 L .69746 .61577 L p .293 0 .06 r
F P
0 g
s
.55086 .75232 m .55048 .78529 L .54402 .78491 L p .659 .406 .527 r
F P
0 g
s
.55048 .78529 m .55086 .75232 L .5576 .75335 L p .636 .383 .518 r
F P
0 g
s
.36694 .55651 m .36962 .54566 L p .36746 .54606 L 0 0 .096 r
F P
0 g
s
.37573 .5378 m .3653 .54646 L p .36746 .54606 L 0 0 0 r
F P
0 g
s
.3827 .53377 m .37289 .54168 L p .37095 .54026 L .808 .998 .789 r
F P
0 g
s
.37289 .54168 m .36746 .54606 L .37095 .54026 L p .808 .998 .789 r
F P
0 g
s
.36962 .54566 m .37095 .54026 L .36746 .54606 L p 0 0 .096 r
F P
0 g
s
.3653 .54646 m .35972 .5511 L .36746 .54606 L p 0 0 0 r
F P
0 g
s
.36336 .56253 m .36746 .54606 L .35972 .5511 L p .266 .039 .371 r
F P
0 g
s
.36746 .54606 m .36477 .55685 L p .36694 .55651 L 0 0 .096 r
F P
0 g
s
.36477 .55685 m .36336 .56253 L .36694 .55651 L p 0 0 .096 r
F P
0 g
s
.37465 .56837 m .36913 .55617 L p .36694 .55651 L 0 0 .553 r
F P
0 g
s
.37095 .54026 m .36809 .55184 L p .36619 .54967 L .954 .836 .405 r
F P
0 g
s
.36809 .55184 m .36694 .55651 L .36619 .54967 L p .954 .836 .405 r
F P
0 g
s
.36913 .55617 m .36619 .54967 L .36694 .55651 L p 0 0 .553 r
F P
0 g
s
.37034 .5616 m .36415 .54733 L p .36619 .54967 L .786 .393 0 r
F P
0 g
s
.36415 .54733 m .36161 .5415 L .36619 .54967 L p .786 .393 0 r
F P
0 g
s
.36619 .54967 m .36888 .53875 L p .37095 .54026 L .954 .836 .405 r
F P
0 g
s
.36888 .53875 m .37026 .53314 L .37095 .54026 L p .954 .836 .405 r
F P
0 g
s
.69959 .45943 m .74524 .4566 L .74332 .44562 L p .584 .654 .885 r
F P
0 g
s
.74332 .44562 m .69771 .45052 L .69959 .45943 L p .584 .654 .885 r
F P
0 g
s
.33853 .601 m .32832 .58132 L .31126 .58943 L p .541 .381 .614 r
F P
0 g
s
.31126 .58943 m .32223 .61038 L .33853 .601 L p .541 .381 .614 r
F P
0 g
s
.49396 .77701 m .49528 .73602 L .50107 .73683 L p .764 .522 .568 r
F P
0 g
s
.50107 .73683 m .49998 .77792 L .49396 .77701 L p .764 .522 .568 r
F P
0 g
s
.75571 .55316 m .76217 .57686 L .7821 .56666 L p .474 .305 .572 r
F P
0 g
s
.7821 .56666 m .77486 .54107 L .75571 .55316 L p .474 .305 .572 r
F P
0 g
s
.43237 .4452 m .44805 .44853 L .44598 .45648 L p .876 .822 .791 r
F P
0 g
s
.44598 .45648 m .4314 .45586 L .43237 .4452 L p .876 .822 .791 r
F P
0 g
s
.41287 .47448 m .43329 .47751 L .4353 .48747 L p .838 .741 .757 r
F P
0 g
s
.4353 .48747 m .41701 .48684 L .41287 .47448 L p .838 .741 .757 r
F P
0 g
s
.35338 .6591 m .31772 .65021 L .30581 .66336 L p .601 .536 .754 r
F P
0 g
s
.30581 .66336 m .3438 .67127 L .35338 .6591 L p .601 .536 .754 r
F P
0 g
s
.6202 .65807 m .61072 .6647 L .61081 .65941 L p .932 .839 .729 r
F P
0 g
s
.61081 .65941 m .61927 .65181 L .6202 .65807 L p .932 .839 .729 r
F P
0 g
s
.63608 .64336 m .6199 .64721 L .62237 .64414 L p .73 .934 .955 r
F P
0 g
s
.62237 .64414 m .63915 .63971 L .63608 .64336 L p .73 .934 .955 r
F P
0 g
s
.5576 .75335 m .5569 .78529 L .55048 .78529 L p .636 .383 .518 r
F P
0 g
s
.5569 .78529 m .5576 .75335 L .56427 .75368 L p .611 .359 .51 r
F P
0 g
s
.60047 .71886 m .59743 .73898 L .60122 .73433 L p 0 0 .278 r
F P
0 g
s
.56828 .44409 m .56797 .46503 L .56164 .46661 L p .755 .512 .565 r
F P
0 g
s
.56164 .46661 m .56239 .44436 L .56828 .44409 L p .755 .512 .565 r
F P
0 g
s
.48799 .77619 m .48944 .73564 L .49528 .73602 L p .774 .531 .568 r
F P
0 g
s
.49528 .73602 m .49396 .77701 L .48799 .77619 L p .774 .531 .568 r
F P
0 g
s
.38537 .52179 m .40628 .51619 L .40655 .52229 L p .833 .848 .858 r
F P
0 g
s
.40655 .52229 m .38589 .52861 L .38537 .52179 L p .833 .848 .858 r
F P
0 g
s
.39844 .4976 m .42109 .49768 L .42439 .50671 L p .82 .746 .782 r
F P
0 g
s
.42439 .50671 m .40336 .508 L .39844 .4976 L p .82 .746 .782 r
F P
0 g
s
.56427 .75368 m .56322 .78487 L .5569 .78529 L p .611 .359 .51 r
F P
0 g
s
.56322 .78487 m .56427 .75368 L .57077 .75322 L p .583 .333 .503 r
F P
0 g
s
.60891 .68656 m .61125 .67123 L .61205 .67883 L p .976 .795 .376 r
F P
0 g
s
.44764 .73604 m .44376 .7164 L .4507 .71569 L p .827 .517 .465 r
F P
0 g
s
.4507 .71569 m .45331 .73666 L .44764 .73604 L p .827 .517 .465 r
F P
0 g
s
.56239 .44436 m .56164 .46661 L .5558 .46713 L p .759 .522 .573 r
F P
0 g
s
.5558 .46713 m .55666 .44408 L .56239 .44436 L p .759 .522 .573 r
F P
0 g
s
.48209 .77543 m .48351 .73563 L .48944 .73564 L p .784 .538 .565 r
F P
0 g
s
.48944 .73564 m .48799 .77619 L .48209 .77543 L p .784 .538 .565 r
F P
0 g
s
.66685 .63087 m .64501 .63743 L .65353 .63606 L p 0 0 0 r
F P
0 g
s
.6494 .44948 m .68417 .43903 L .67317 .437 L p .588 .84 .992 r
F P
0 g
s
.67317 .437 m .64124 .44795 L .6494 .44948 L p .588 .84 .992 r
F P
0 g
s
.43502 .43539 m .45121 .44125 L .44805 .44853 L p .85 .834 .83 r
F P
0 g
s
.44805 .44853 m .43237 .4452 L .43502 .43539 L p .85 .834 .83 r
F P
0 g
s
.35539 .56831 m .35972 .5511 L .34812 .556 L p .413 .172 .436 r
F P
0 g
s
.34812 .556 m .34343 .5744 L .35539 .56831 L p .413 .172 .436 r
F P
0 g
s
.55666 .44408 m .5558 .46713 L .55029 .46643 L p .764 .527 .575 r
F P
0 g
s
.55029 .46643 m .55104 .44318 L .55666 .44408 L p .764 .527 .575 r
F P
0 g
s
.60333 .71247 m .60122 .73433 L .60451 .72941 L p 0 0 .285 r
F P
0 g
s
.57077 .75322 m .56939 .78397 L .56322 .78487 L p .583 .333 .503 r
F P
0 g
s
.56939 .78397 m .57077 .75322 L .57699 .75192 L p .551 .306 .497 r
F P
0 g
s
.61927 .65181 m .61081 .65941 L .61181 .65538 L p .941 .946 .758 r
F P
0 g
s
.61181 .65538 m .6199 .64721 L .61927 .65181 L p .941 .946 .758 r
F P
0 g
s
.47625 .77469 m .4775 .73588 L .48351 .73563 L p .795 .545 .56 r
F P
0 g
s
.48351 .73563 m .48209 .77543 L .47625 .77469 L p .795 .545 .56 r
F P
0 g
s
.74203 .58547 m .731 .60667 L .75014 .60058 L p .408 .138 .39 r
F P
0 g
s
.75014 .60058 m .76217 .57686 L .74203 .58547 L p .408 .138 .39 r
F P
0 g
s
.40943 .46105 m .43183 .46682 L .43329 .47751 L p .833 .75 .771 r
F P
0 g
s
.43329 .47751 m .41287 .47448 L .40943 .46105 L p .833 .75 .771 r
F P
0 g
s
.34648 .6266 m .32223 .61038 L .30543 .62121 L p .587 .473 .691 r
F P
0 g
s
.30543 .62121 m .3317 .63782 L .34648 .6266 L p .587 .473 .691 r
F P
0 g
s
.40226 .69208 m .37242 .69342 L .37253 .70204 L p .608 .643 .86 r
F P
0 g
s
.37253 .70204 m .40293 .69897 L .40226 .69208 L p .608 .643 .86 r
F P
0 g
s
.59948 .45864 m .58999 .45697 L .598 .4544 L p .307 0 0 r
F P
0 g
s
.55104 .44318 m .55029 .46643 L .54496 .46443 L p .769 .528 .569 r
F P
0 g
s
.54496 .46443 m .54545 .44161 L .55104 .44318 L p .769 .528 .569 r
F P
0 g
s
.76505 .50721 m .79227 .52757 L .80648 .51305 L p .489 .42 .705 r
F P
0 g
s
.80648 .51305 m .77741 .49251 L .76505 .50721 L p .489 .42 .705 r
F P
0 g
s
.63915 .63971 m .62237 .64414 L .6268 .64235 L p .374 .841 .831 r
F P
0 g
s
.6268 .64235 m .64501 .63743 L .63915 .63971 L p .374 .841 .831 r
F P
0 g
s
.61125 .67123 m .61065 .67515 L p .6107 .67504 L .896 .72 .212 r
F P
0 g
s
.60891 .68656 m .60981 .68123 L p .6107 .67504 L .896 .72 .212 r
F P
0 g
s
.61065 .67515 m .60891 .68656 L p .6107 .67504 L .896 .72 .212 r
F P
0 g
s
.60981 .68123 m .61072 .6647 L .61125 .67123 L p .896 .72 .212 r
F P
0 g
s
.61081 .65941 m .61072 .6647 L p .61089 .67464 L 0 0 .034 r
F P
0 g
s
.61092 .67669 m .61091 .67459 L p .61089 .67464 L 0 0 .034 r
F P
0 g
s
.61091 .67459 m .61081 .65941 L p .61089 .67464 L 0 0 .034 r
F P
0 g
s
.37095 .54026 m .38589 .52861 L .3827 .53377 L p .808 .998 .789 r
F P
0 g
s
.44235 .73483 m .43729 .71618 L .44376 .7164 L p .85 .514 .416 r
F P
0 g
s
.44376 .7164 m .44764 .73604 L .44235 .73483 L p .85 .514 .416 r
F P
0 g
s
.54545 .44161 m .54496 .46443 L .5396 .46119 L p .775 .524 .557 r
F P
0 g
s
.5396 .46119 m .5398 .4394 L .54545 .44161 L p .775 .524 .557 r
F P
0 g
s
.57699 .75192 m .57536 .78258 L .58108 .78071 L p .509 .273 .491 r
F P
0 g
s
.58108 .78071 m .58283 .74978 L .57699 .75192 L p .509 .273 .491 r
F P
0 g
s
.57699 .75192 m .57536 .78258 L .56939 .78397 L p .551 .306 .497 r
F P
0 g
s
.37994 .67332 m .3438 .67127 L .33675 .68344 L p .624 .586 .791 r
F P
0 g
s
.33675 .68344 m .375 .68368 L .37994 .67332 L p .624 .586 .791 r
F P
0 g
s
.39239 .48506 m .41701 .48684 L .42109 .49768 L p .825 .742 .772 r
F P
0 g
s
.42109 .49768 m .39844 .4976 L .39239 .48506 L p .825 .742 .772 r
F P
0 g
s
.47051 .77392 m .47142 .73626 L .4775 .73588 L p .806 .552 .554 r
F P
0 g
s
.4775 .73588 m .47625 .77469 L .47051 .77392 L p .806 .552 .554 r
F P
0 g
s
.38157 .5129 m .40336 .508 L .40628 .51619 L p .844 .793 .802 r
F P
0 g
s
.40628 .51619 m .38537 .52179 L .38157 .5129 L p .844 .793 .802 r
F P
0 g
s
.60544 .70577 m .60451 .72941 L .60736 .72439 L p 0 0 .307 r
F P
0 g
s
.69771 .45052 m .74332 .44562 L .73693 .43682 L p .569 .704 .933 r
F P
0 g
s
.73693 .43682 m .69249 .4436 L .69771 .45052 L p .569 .704 .933 r
F P
0 g
s
.43947 .42698 m .45552 .435 L .45121 .44125 L p .815 .842 .87 r
F P
0 g
s
.45121 .44125 m .43502 .43539 L .43947 .42698 L p .815 .842 .87 r
F P
0 g
s
.71304 .61161 m .69105 .62607 L .70665 .62337 L p .307 0 .099 r
F P
0 g
s
.70665 .62337 m .731 .60667 L .71304 .61161 L p .307 0 .099 r
F P
0 g
s
.58999 .45697 m .59948 .45864 L .58921 .46362 L p .423 0 .089 r
F P
0 g
s
.58921 .46362 m .58221 .45986 L .58999 .45697 L p .423 0 .089 r
F P
0 g
s
.74278 .46915 m .78576 .47772 L .78924 .46358 L p .52 .553 .83 r
F P
0 g
s
.78924 .46358 m .74524 .4566 L .74278 .46915 L p .52 .553 .83 r
F P
0 g
s
.6199 .64721 m .61181 .65538 L .6139 .65255 L p .639 .908 .603 r
F P
0 g
s
.6139 .65255 m .62237 .64414 L .6199 .64721 L p .639 .908 .603 r
F P
0 g
s
.35293 .59303 m .34343 .5744 L .32832 .58132 L p .549 .391 .619 r
F P
0 g
s
.32832 .58132 m .33853 .601 L .35293 .59303 L p .549 .391 .619 r
F P
0 g
s
.58283 .74978 m .58108 .78071 L .5865 .77836 L p .454 .231 .485 r
F P
0 g
s
.5865 .77836 m .58822 .74685 L .58283 .74978 L p .454 .231 .485 r
F P
0 g
s
.64124 .44795 m .67317 .437 L .66013 .4375 L p .549 .884 .988 r
F P
0 g
s
.66013 .4375 m .63166 .44836 L .64124 .44795 L p .549 .884 .988 r
F P
0 g
s
.46488 .77305 m .46531 .73663 L .47142 .73626 L p .819 .559 .545 r
F P
0 g
s
.47142 .73626 m .47051 .77392 L .46488 .77305 L p .819 .559 .545 r
F P
0 g
s
.61072 .6647 m .60981 .68123 L .61092 .67669 L p 0 0 .034 r
F P
0 g
s
.4074 .44716 m .4314 .45586 L .43183 .46682 L p .826 .761 .791 r
F P
0 g
s
.43183 .46682 m .40943 .46105 L .4074 .44716 L p .826 .761 .791 r
F P
0 g
s
.36458 .64746 m .3317 .63782 L .31772 .65021 L p .617 .533 .737 r
F P
0 g
s
.31772 .65021 m .35338 .6591 L .36458 .64746 L p .617 .533 .737 r
F P
0 g
s
.67752 .62839 m .65353 .63606 L .66428 .63512 L p .16 0 0 r
F P
0 g
s
.66428 .63512 m .69105 .62607 L .67752 .62839 L p .16 0 0 r
F P
0 g
s
.58221 .45986 m .58921 .46362 L .57977 .46846 L p .505 .11 .225 r
F P
0 g
s
.57977 .46846 m .57483 .46267 L .58221 .45986 L p .505 .11 .225 r
F P
0 g
s
.43756 .73296 m .43152 .71488 L .43729 .71618 L p .876 .511 .35 r
F P
0 g
s
.43729 .71618 m .44235 .73483 L .43756 .73296 L p .876 .511 .35 r
F P
0 g
s
.60694 .69904 m .60736 .72439 L .60984 .71944 L p 0 0 .342 r
F P
0 g
s
.44569 .42046 m .46096 .43011 L .45552 .435 L p .766 .844 .91 r
F P
0 g
s
.45552 .435 m .43947 .42698 L .44569 .42046 L p .766 .844 .91 r
F P
0 g
s
.35972 .5511 m .35539 .56831 L .36336 .56253 L p .266 .039 .371 r
F P
0 g
s
.64501 .63743 m .6268 .64235 L .63307 .6415 L p .038 0 0 r
F P
0 g
s
.63307 .6415 m .65353 .63606 L .64501 .63743 L p .038 0 0 r
F P
0 g
s
.58822 .74685 m .5865 .77836 L .59159 .77559 L p .395 .189 .478 r
F P
0 g
s
.59159 .77559 m .5931 .74321 L .58822 .74685 L p .395 .189 .478 r
F P
0 g
s
.77486 .54107 m .7821 .56666 L .80025 .55495 L p .423 .273 .572 r
F P
0 g
s
.80025 .55495 m .79227 .52757 L .77486 .54107 L p .423 .273 .572 r
F P
0 g
s
.42034 .7043 m .40293 .69897 L .40552 .70462 L p .371 .566 .912 r
F P
0 g
s
.40341 .68427 m .375 .68368 L .37242 .69342 L p .615 .61 .823 r
F P
0 g
s
.37242 .69342 m .40226 .69208 L .40341 .68427 L p .615 .61 .823 r
F P
0 g
s
.57483 .46267 m .57977 .46846 L .57133 .47259 L p .57 .209 .316 r
F P
0 g
s
.57133 .47259 m .56797 .46503 L .57483 .46267 L p .57 .209 .316 r
F P
0 g
s
.45942 .77201 m .45924 .73681 L .46531 .73663 L p .834 .566 .534 r
F P
0 g
s
.46531 .73663 m .46488 .77305 L .45942 .77201 L p .834 .566 .534 r
F P
0 g
s
.38616 .47064 m .41287 .47448 L .41701 .48684 L p .829 .748 .775 r
F P
0 g
s
.41701 .48684 m .39239 .48506 L .38616 .47064 L p .829 .748 .775 r
F P
0 g
s
.37026 .53314 m .38537 .52179 L .38589 .52861 L p .921 .909 .793 r
F P
0 g
s
.38589 .52861 m .37095 .54026 L .37026 .53314 L p .921 .909 .793 r
F P
0 g
s
.61081 .65941 m .61092 .67669 L .6124 .67297 L p 0 0 .285 r
F P
0 g
s
.6124 .67297 m .61181 .65538 L .61081 .65941 L p 0 0 .285 r
F P
0 g
s
.62237 .64414 m .6139 .65255 L .61714 .65075 L p .025 0 0 r
F P
0 g
s
.61714 .65075 m .6268 .64235 L .62237 .64414 L p .025 0 0 r
F P
0 g
s
.37528 .50172 m .39844 .4976 L .40336 .508 L p .849 .769 .773 r
F P
0 g
s
.40336 .508 m .38157 .5129 L .37528 .50172 L p .849 .769 .773 r
F P
0 g
s
.63166 .44836 m .66013 .4375 L .64579 .44033 L p .483 .892 .928 r
F P
0 g
s
.64579 .44033 m .62117 .45052 L .63166 .44836 L p .483 .892 .928 r
F P
0 g
s
.36078 .6168 m .33853 .601 L .32223 .61038 L p .602 .483 .689 r
F P
0 g
s
.32223 .61038 m .34648 .6266 L .36078 .6168 L p .602 .483 .689 r
F P
0 g
s
.56797 .46503 m .57133 .47259 L .56391 .47551 L p .627 .285 .372 r
F P
0 g
s
.56391 .47551 m .56164 .46661 L .56797 .46503 L p .627 .285 .372 r
F P
0 g
s
.60803 .69255 m .60984 .71944 L .61205 .7147 L p 0 0 .387 r
F P
0 g
s
.38673 .66282 m .35338 .6591 L .3438 .67127 L p .634 .572 .767 r
F P
0 g
s
.3438 .67127 m .37994 .67332 L .38673 .66282 L p .634 .572 .767 r
F P
0 g
s
.5931 .74321 m .59159 .77559 L .59632 .77245 L p .332 .146 .472 r
F P
0 g
s
.59632 .77245 m .59743 .73898 L .5931 .74321 L p .332 .146 .472 r
F P
0 g
s
.46096 .43011 m .44569 .42046 L .45349 .4162 L p .699 .835 .948 r
F P
0 g
s
.40735 .43351 m .43237 .4452 L .4314 .45586 L p .815 .773 .814 r
F P
0 g
s
.4314 .45586 m .4074 .44716 L .40735 .43351 L p .815 .773 .814 r
F P
0 g
s
.43152 .71488 m .43756 .73296 L .43337 .73038 L p .9 .505 .258 r
F P
0 g
s
.56164 .46661 m .56391 .47551 L .55739 .47681 L p .68 .343 .398 r
F P
0 g
s
.55739 .47681 m .5558 .46713 L .56164 .46661 L p .68 .343 .398 r
F P
0 g
s
.69249 .4436 m .73693 .43682 L .72635 .43071 L p .546 .763 .978 r
F P
0 g
s
.72635 .43071 m .68417 .43903 L .69249 .4436 L p .546 .763 .978 r
F P
0 g
s
.45416 .77073 m .45331 .73666 L .45924 .73681 L p .85 .574 .52 r
F P
0 g
s
.45924 .73681 m .45942 .77201 L .45416 .77073 L p .85 .574 .52 r
F P
0 g
s
.76217 .57686 m .75014 .60058 L .76908 .59306 L p .347 .084 .364 r
F P
0 g
s
.76908 .59306 m .7821 .56666 L .76217 .57686 L p .347 .084 .364 r
F P
0 g
s
.5558 .46713 m .55739 .47681 L .55155 .47624 L p .732 .385 .392 r
F P
0 g
s
.55155 .47624 m .55029 .46643 L .5558 .46713 L p .732 .385 .392 r
F P
0 g
s
.36432 .58622 m .35539 .56831 L .34343 .5744 L p .537 .392 .631 r
F P
0 g
s
.34343 .5744 m .35293 .59303 L .36432 .58622 L p .537 .392 .631 r
F P
0 g
s
.61181 .65538 m .6124 .67297 L .61434 .67006 L p .046 0 .418 r
F P
0 g
s
.61434 .67006 m .6139 .65255 L .61181 .65538 L p .046 0 .418 r
F P
0 g
s
.41898 .69881 m .40226 .69208 L .40293 .69897 L p .426 .533 .862 r
F P
0 g
s
.40293 .69897 m .42034 .7043 L .41898 .69881 L p .426 .533 .862 r
F P
0 g
s
.59743 .73898 m .59632 .77245 L .60068 .76902 L p .27 .106 .466 r
F P
0 g
s
.60068 .76902 m .60122 .73433 L .59743 .73898 L p .27 .106 .466 r
F P
0 g
s
.62117 .45052 m .64579 .44033 L .63094 .44506 L p .399 .854 .818 r
F P
0 g
s
.60891 .68656 m .61205 .7147 L .6141 .71028 L p 0 0 .435 r
F P
0 g
s
.6141 .71028 m .60981 .68123 L .60891 .68656 L p 0 0 .435 r
F P
0 g
s
.77741 .49251 m .80648 .51305 L .81622 .4981 L p .439 .414 .734 r
F P
0 g
s
.81622 .4981 m .78576 .47772 L .77741 .49251 L p .439 .414 .734 r
F P
0 g
s
.37641 .6368 m .34648 .6266 L .3317 .63782 L p .631 .534 .727 r
F P
0 g
s
.3317 .63782 m .36458 .64746 L .37641 .6368 L p .631 .534 .727 r
F P
0 g
s
.65353 .63606 m .63307 .6415 L .64087 .6412 L p .198 0 0 r
F P
0 g
s
.64087 .6412 m .66428 .63512 L .65353 .63606 L p .198 0 0 r
F P
0 g
s
.6268 .64235 m .61714 .65075 L .62146 .64977 L p .285 0 .059 r
F P
0 g
s
.62146 .64977 m .63307 .6415 L .6268 .64235 L p .285 0 .059 r
F P
0 g
s
.731 .60667 m .70665 .62337 L .72324 .61984 L p .262 0 .076 r
F P
0 g
s
.72324 .61984 m .75014 .60058 L .731 .60667 L p .262 0 .076 r
F P
0 g
s
.40618 .67588 m .37994 .67332 L .375 .68368 L p .62 .585 .793 r
F P
0 g
s
.375 .68368 m .40341 .68427 L .40618 .67588 L p .62 .585 .793 r
F P
0 g
s
.69105 .62607 m .66428 .63512 L .67662 .63413 L p .19 0 0 r
F P
0 g
s
.67662 .63413 m .70665 .62337 L .69105 .62607 L p .19 0 0 r
F P
0 g
s
.44917 .76915 m .44764 .73604 L .45331 .73666 L p .869 .584 .503 r
F P
0 g
s
.45331 .73666 m .45416 .77073 L .44917 .76915 L p .869 .584 .503 r
F P
0 g
s
.38079 .45485 m .40943 .46105 L .41287 .47448 L p .83 .76 .785 r
F P
0 g
s
.41287 .47448 m .38616 .47064 L .38079 .45485 L p .83 .76 .785 r
F P
0 g
s
.74524 .4566 m .78924 .46358 L .78732 .45087 L p .483 .586 .882 r
F P
0 g
s
.78732 .45087 m .74332 .44562 L .74524 .4566 L p .483 .586 .882 r
F P
0 g
s
.42668 .71245 m .43337 .73038 L .42987 .7271 L p .903 .489 .131 r
F P
0 g
s
.36588 .52421 m .38157 .5129 L .38537 .52179 L p .916 .826 .743 r
F P
0 g
s
.38537 .52179 m .37026 .53314 L .36588 .52421 L p .916 .826 .743 r
F P
0 g
s
.51886 .82314 m .51845 .78114 L .52475 .78227 L p .703 .426 .502 r
F P
0 g
s
.52475 .78227 m .52484 .82362 L .51886 .82314 L p .703 .426 .502 r
F P
0 g
s
.52484 .82362 m .52475 .78227 L .53113 .78332 L p .687 .411 .499 r
F P
0 g
s
.47469 .42525 m .46258 .41443 L .45349 .4162 L p .61 .809 .976 r
F P
0 g
s
.51292 .82253 m .51222 .78001 L .51845 .78114 L p .718 .44 .505 r
F P
0 g
s
.51845 .78114 m .51886 .82314 L .51292 .82253 L p .718 .44 .505 r
F P
0 g
s
.40972 .42084 m .43502 .43539 L .43237 .4452 L p .797 .784 .841 r
F P
0 g
s
.43237 .4452 m .40735 .43351 L .40972 .42084 L p .797 .784 .841 r
F P
0 g
s
.53113 .78332 m .53085 .82395 L .52484 .82362 L p .687 .411 .499 r
F P
0 g
s
.53085 .82395 m .53113 .78332 L .53756 .78423 L p .67 .394 .495 r
F P
0 g
s
.36752 .48824 m .39239 .48506 L .39844 .4976 L p .856 .766 .762 r
F P
0 g
s
.39844 .4976 m .37528 .50172 L .36752 .48824 L p .856 .766 .762 r
F P
0 g
s
.61028 .4541 m .63094 .44506 L .61633 .45111 L p .314 .787 .688 r
F P
0 g
s
.60122 .73433 m .60068 .76902 L .60468 .76537 L p .21 .07 .462 r
F P
0 g
s
.60468 .76537 m .60451 .72941 L .60122 .73433 L p .21 .07 .462 r
F P
0 g
s
.50703 .82182 m .50607 .77892 L .51222 .78001 L p .732 .454 .506 r
F P
0 g
s
.51222 .78001 m .51292 .82253 L .50703 .82182 L p .732 .454 .506 r
F P
0 g
s
.53756 .78423 m .53686 .82411 L .53085 .82395 L p .67 .394 .495 r
F P
0 g
s
.53686 .82411 m .53756 .78423 L .54402 .78491 L p .652 .377 .49 r
F P
0 g
s
.60981 .68123 m .6141 .71028 L .61605 .70626 L p 0 0 .479 r
F P
0 g
s
.61605 .70626 m .61092 .67669 L .60981 .68123 L p 0 0 .479 r
F P
0 g
s
.6139 .65255 m .61434 .67006 L .61677 .66788 L p .234 .079 .456 r
F P
0 g
s
.61677 .66788 m .61714 .65075 L .6139 .65255 L p .234 .079 .456 r
F P
0 g
s
.3734 .60849 m .35293 .59303 L .33853 .601 L p .609 .493 .696 r
F P
0 g
s
.33853 .601 m .36078 .6168 L .3734 .60849 L p .609 .493 .696 r
F P
0 g
s
.50122 .82102 m .49998 .77792 L .50607 .77892 L p .746 .466 .506 r
F P
0 g
s
.50607 .77892 m .50703 .82182 L .50122 .82102 L p .746 .466 .506 r
F P
0 g
s
.39473 .65266 m .36458 .64746 L .35338 .6591 L p .643 .564 .75 r
F P
0 g
s
.35338 .6591 m .38673 .66282 L .39473 .65266 L p .643 .564 .75 r
F P
0 g
s
.54402 .78491 m .54285 .82408 L .53686 .82411 L p .652 .377 .49 r
F P
0 g
s
.54285 .82408 m .54402 .78491 L .55048 .78529 L p .632 .358 .485 r
F P
0 g
s
.48254 .42545 m .47255 .4152 L .46258 .41443 L p .499 .762 .99 r
F P
0 g
s
.49549 .82014 m .49396 .77701 L .49998 .77792 L p .76 .478 .505 r
F P
0 g
s
.49998 .77792 m .50122 .82102 L .49549 .82014 L p .76 .478 .505 r
F P
0 g
s
.55048 .78529 m .5488 .82382 L .54285 .82408 L p .632 .358 .485 r
F P
0 g
s
.5488 .82382 m .55048 .78529 L .5569 .78529 L p .61 .338 .48 r
F P
0 g
s
.4188 .69263 m .40341 .68427 L .40226 .69208 L p .454 .499 .815 r
F P
0 g
s
.40226 .69208 m .41898 .69881 L .4188 .69263 L p .454 .499 .815 r
F P
0 g
s
.59948 .45864 m .61633 .45111 L .60258 .45777 L p 0 0 0 r
F P
0 g
s
.60258 .45777 m .58921 .46362 L .59948 .45864 L p 0 0 0 r
F P
0 g
s
.68417 .43903 m .72635 .43071 L .71217 .42757 L p .508 .82 1 r
F P
0 g
s
.71217 .42757 m .67317 .437 L .68417 .43903 L p .508 .82 1 r
F P
0 g
s
.44451 .76722 m .44235 .73483 L .44764 .73604 L p .89 .596 .483 r
F P
0 g
s
.44764 .73604 m .44917 .76915 L .44451 .76722 L p .89 .596 .483 r
F P
0 g
s
.4907 .42733 m .48294 .41839 L .47255 .4152 L p .357 .688 .981 r
F P
0 g
s
.37191 .58017 m .36336 .56253 L .35539 .56831 L p .48 .371 .652 r
F P
0 g
s
.35539 .56831 m .36432 .58622 L .37191 .58017 L p .48 .371 .652 r
F P
0 g
s
.60451 .72941 m .60468 .76537 L .60832 .76159 L p .158 .041 .459 r
F P
0 g
s
.60832 .76159 m .60736 .72439 L .60451 .72941 L p .158 .041 .459 r
F P
0 g
s
.48985 .81917 m .48799 .77619 L .49396 .77701 L p .774 .488 .503 r
F P
0 g
s
.49396 .77701 m .49549 .82014 L .48985 .81917 L p .774 .488 .503 r
F P
0 g
s
.5569 .78529 m .55467 .82331 L .5488 .82382 L p .61 .338 .48 r
F P
0 g
s
.55467 .82331 m .5569 .78529 L .56322 .78487 L p .587 .317 .474 r
F P
0 g
s
.49889 .43067 m .49332 .42369 L .48294 .41839 L p .187 .583 .941 r
F P
0 g
s
.41023 .6673 m .38673 .66282 L .37994 .67332 L p .624 .565 .768 r
F P
0 g
s
.37994 .67332 m .40618 .67588 L .41023 .6673 L p .624 .565 .768 r
F P
0 g
s
.50686 .43517 m .50328 .43064 L .49332 .42369 L p 0 .447 .862 r
F P
0 g
s
.63307 .6415 m .62146 .64977 L .62665 .64931 L p .355 0 .093 r
F P
0 g
s
.62665 .64931 m .64087 .6412 L .63307 .6415 L p .355 0 .093 r
F P
0 g
s
.58921 .46362 m .60258 .45777 L .59017 .46429 L p 0 0 0 r
F P
0 g
s
.59017 .46429 m .57977 .46846 L .58921 .46362 L p 0 0 0 r
F P
0 g
s
.61092 .67669 m .61605 .70626 L .61798 .70269 L p .047 .028 .51 r
F P
0 g
s
.61798 .70269 m .6124 .67297 L .61092 .67669 L p .047 .028 .51 r
F P
0 g
s
.38784 .62741 m .36078 .6168 L .34648 .6266 L p .641 .54 .724 r
F P
0 g
s
.34648 .6266 m .37641 .6368 L .38784 .62741 L p .641 .54 .724 r
F P
0 g
s
.79227 .52757 m .80025 .55495 L .81514 .54199 L p .346 .225 .569 r
F P
0 g
s
.81514 .54199 m .80648 .51305 L .79227 .52757 L p .346 .225 .569 r
F P
0 g
s
.57977 .46846 m .59017 .46429 L .57932 .4699 L p 0 0 0 r
F P
0 g
s
.57932 .4699 m .57133 .47259 L .57977 .46846 L p 0 0 0 r
F P
0 g
s
.48433 .81811 m .48209 .77543 L .48799 .77619 L p .787 .499 .499 r
F P
0 g
s
.48799 .77619 m .48985 .81917 L .48433 .81811 L p .787 .499 .499 r
F P
0 g
s
.4147 .40991 m .43947 .42698 L .43502 .43539 L p .773 .792 .869 r
F P
0 g
s
.43502 .43539 m .40972 .42084 L .4147 .40991 L p .773 .792 .869 r
F P
0 g
s
.61714 .65075 m .61677 .66788 L .61966 .66627 L p .325 .127 .451 r
F P
0 g
s
.61966 .66627 m .62146 .64977 L .61714 .65075 L p .325 .127 .451 r
F P
0 g
s
.56322 .78487 m .56044 .82254 L .55467 .82331 L p .587 .317 .474 r
F P
0 g
s
.56044 .82254 m .56322 .78487 L .56939 .78397 L p .562 .294 .468 r
F P
0 g
s
.66428 .63512 m .64087 .6412 L .64973 .64104 L p .215 0 0 r
F P
0 g
s
.64973 .64104 m .67662 .63413 L .66428 .63512 L p .215 0 0 r
F P
0 g
s
.57133 .47259 m .57932 .4699 L .57006 .47393 L p 0 0 0 r
F P
0 g
s
.57006 .47393 m .56391 .47551 L .57133 .47259 L p 0 0 0 r
F P
0 g
s
.37722 .43835 m .4074 .44716 L .40943 .46105 L p .828 .776 .803 r
F P
0 g
s
.40943 .46105 m .38079 .45485 L .37722 .43835 L p .828 .776 .803 r
F P
0 g
s
.56391 .47551 m .57006 .47393 L .56222 .47583 L p .141 .681 .695 r
F P
0 g
s
.56222 .47583 m .55739 .47681 L .56391 .47551 L p .141 .681 .695 r
F P
0 g
s
.44022 .76491 m .43756 .73296 L .44235 .73483 L p .913 .609 .458 r
F P
0 g
s
.44235 .73483 m .44451 .76722 L .44022 .76491 L p .913 .609 .458 r
F P
0 g
s
.60736 .72439 m .60832 .76159 L .61163 .75777 L p .115 .018 .457 r
F P
0 g
s
.61163 .75777 m .60984 .71944 L .60736 .72439 L p .115 .018 .457 r
F P
0 g
s
.40321 .64323 m .37641 .6368 L .36458 .64746 L p .651 .56 .739 r
F P
0 g
s
.36458 .64746 m .39473 .65266 L .40321 .64323 L p .651 .56 .739 r
F P
0 g
s
.47894 .81694 m .47625 .77469 L .48209 .77543 L p .802 .509 .494 r
F P
0 g
s
.48209 .77543 m .48433 .81811 L .47894 .81694 L p .802 .509 .494 r
F P
0 g
s
.35865 .51317 m .37528 .50172 L .38157 .5129 L p .912 .792 .714 r
F P
0 g
s
.38157 .5129 m .36588 .52421 L .35865 .51317 L p .912 .792 .714 r
F P
0 g
s
.41968 .686 m .40618 .67588 L .40341 .68427 L p .465 .465 .774 r
F P
0 g
s
.40341 .68427 m .4188 .69263 L .41968 .686 L p .465 .465 .774 r
F P
0 g
s
.38338 .60154 m .36432 .58622 L .35293 .59303 L p .604 .505 .715 r
F P
0 g
s
.35293 .59303 m .3734 .60849 L .38338 .60154 L p .604 .505 .715 r
F P
0 g
s
.56939 .78397 m .56609 .82149 L .56044 .82254 L p .562 .294 .468 r
F P
0 g
s
.56609 .82149 m .56939 .78397 L .57536 .78258 L p .534 .271 .462 r
F P
0 g
s
.55739 .47681 m .56222 .47583 L .55542 .47525 L p .127 .66 .863 r
F P
0 g
s
.55542 .47525 m .55155 .47624 L .55739 .47681 L p .127 .66 .863 r
F P
0 g
s
.6124 .67297 m .61798 .70269 L .61994 .69955 L p .12 .075 .528 r
F P
0 g
s
.61994 .69955 m .61434 .67006 L .6124 .67297 L p .12 .075 .528 r
F P
0 g
s
.35948 .47268 m .38616 .47064 L .39239 .48506 L p .863 .775 .763 r
F P
0 g
s
.39239 .48506 m .36752 .48824 L .35948 .47268 L p .863 .775 .763 r
F P
0 g
s
.70665 .62337 m .67662 .63413 L .68969 .63264 L p .133 0 0 r
F P
0 g
s
.68969 .63264 m .72324 .61984 L .70665 .62337 L p .133 0 0 r
F P
0 g
s
.55155 .47624 m .55542 .47525 L .54918 .47202 L p .097 .549 .91 r
F P
0 g
s
.54918 .47202 m .54605 .47366 L .55155 .47624 L p .097 .549 .91 r
F P
0 g
s
.67317 .437 m .71217 .42757 L .69522 .42747 L p .449 .851 .971 r
F P
0 g
s
.69522 .42747 m .66013 .4375 L .67317 .437 L p .449 .851 .971 r
F P
0 g
s
.41515 .65889 m .39473 .65266 L .38673 .66282 L p .626 .55 .748 r
F P
0 g
s
.38673 .66282 m .41023 .6673 L .41515 .65889 L p .626 .55 .748 r
F P
0 g
s
.7821 .56666 m .76908 .59306 L .78633 .58408 L p .245 0 .313 r
F P
0 g
s
.78633 .58408 m .80025 .55495 L .7821 .56666 L p .245 0 .313 r
F P
0 g
s
.74332 .44562 m .78732 .45087 L .77989 .44031 L p .429 .632 .94 r
F P
0 g
s
.77989 .44031 m .73693 .43682 L .74332 .44562 L p .429 .632 .94 r
F P
0 g
s
.57536 .78258 m .57157 .82016 L .57687 .81856 L p .5 .243 .456 r
F P
0 g
s
.57687 .81856 m .58108 .78071 L .57536 .78258 L p .5 .243 .456 r
F P
0 g
s
.57536 .78258 m .57157 .82016 L .56609 .82149 L p .534 .271 .462 r
F P
0 g
s
.47371 .81566 m .47051 .77392 L .47625 .77469 L p .816 .519 .487 r
F P
0 g
s
.47625 .77469 m .47894 .81694 L .47371 .81566 L p .816 .519 .487 r
F P
0 g
s
.37533 .5744 m .36694 .55651 L .36336 .56253 L p .296 .284 .675 r
F P
0 g
s
.36336 .56253 m .37191 .58017 L .37533 .5744 L p .296 .284 .675 r
F P
0 g
s
.39794 .61943 m .3734 .60849 L .36078 .6168 L p .647 .55 .731 r
F P
0 g
s
.36078 .6168 m .38784 .62741 L .39794 .61943 L p .647 .55 .731 r
F P
0 g
s
.54297 .46621 m .54055 .46916 L .54605 .47366 L p .068 .439 .876 r
F P
0 g
s
.60984 .71944 m .61163 .75777 L .61463 .75396 L p .084 .004 .457 r
F P
0 g
s
.61463 .75396 m .61205 .7147 L .60984 .71944 L p .084 .004 .457 r
F P
0 g
s
.75014 .60058 m .72324 .61984 L .73962 .61518 L p .159 0 0 r
F P
0 g
s
.73962 .61518 m .76908 .59306 L .75014 .60058 L p .159 0 0 r
F P
0 g
s
.42228 .4014 m .44569 .42046 L .43947 .42698 L p .738 .795 .898 r
F P
0 g
s
.43947 .42698 m .4147 .40991 L .42228 .4014 L p .738 .795 .898 r
F P
0 g
s
.78576 .47772 m .81622 .4981 L .82048 .48345 L p .365 .409 .773 r
F P
0 g
s
.82048 .48345 m .78924 .46358 L .78576 .47772 L p .365 .409 .773 r
F P
0 g
s
.62146 .64977 m .61966 .66627 L .62287 .66508 L p .359 .129 .423 r
F P
0 g
s
.62287 .66508 m .62665 .64931 L .62146 .64977 L p .359 .129 .423 r
F P
0 g
s
.43637 .7622 m .43337 .73038 L .43756 .73296 L p .936 .625 .427 r
F P
0 g
s
.43756 .73296 m .44022 .76491 L .43637 .7622 L p .936 .625 .427 r
F P
0 g
s
.64087 .6412 m .62665 .64931 L .63241 .64909 L p .348 0 .053 r
F P
0 g
s
.63241 .64909 m .64973 .64104 L .64087 .6412 L p .348 0 .053 r
F P
0 g
s
.41145 .63482 m .38784 .62741 L .37641 .6368 L p .657 .561 .736 r
F P
0 g
s
.37641 .6368 m .40321 .64323 L .41145 .63482 L p .657 .561 .736 r
F P
0 g
s
.42144 .67916 m .41023 .6673 L .40618 .67588 L p .463 .431 .737 r
F P
0 g
s
.40618 .67588 m .41968 .686 L .42144 .67916 L p .463 .431 .737 r
F P
0 g
s
.58108 .78071 m .57687 .81856 L .58195 .81668 L p .458 .208 .447 r
F P
0 g
s
.58195 .81668 m .5865 .77836 L .58108 .78071 L p .458 .208 .447 r
F P
0 g
s
.61434 .67006 m .61994 .69955 L .62193 .69683 L p .174 .104 .532 r
F P
0 g
s
.62193 .69683 m .61677 .66788 L .61434 .67006 L p .174 .104 .532 r
F P
0 g
s
.53625 .45812 m .5347 .46297 L .54055 .46916 L p .051 .378 .843 r
F P
0 g
s
.46865 .81424 m .46488 .77305 L .47051 .77392 L p .831 .529 .477 r
F P
0 g
s
.47051 .77392 m .47371 .81566 L .46865 .81424 L p .831 .529 .477 r
F P
0 g
s
.42049 .65096 m .40321 .64323 L .39473 .65266 L p .626 .537 .733 r
F P
0 g
s
.39473 .65266 m .41515 .65889 L .42049 .65096 L p .626 .537 .733 r
F P
0 g
s
.39006 .59567 m .37191 .58017 L .36432 .58622 L p .574 .515 .751 r
F P
0 g
s
.36432 .58622 m .38338 .60154 L .39006 .59567 L p .574 .515 .751 r
F P
0 g
s
.36161 .5415 m .36588 .52421 L .37026 .53314 L p .995 .792 .518 r
F P
0 g
s
.37026 .53314 m .36619 .54967 L .36161 .5415 L p .995 .792 .518 r
F P
0 g
s
.61205 .7147 m .61463 .75396 L .61735 .75024 L p .063 0 .459 r
F P
0 g
s
.61735 .75024 m .6141 .71028 L .61205 .7147 L p .063 0 .459 r
F P
0 g
s
.37627 .42197 m .40735 .43351 L .4074 .44716 L p .821 .793 .826 r
F P
0 g
s
.4074 .44716 m .37722 .43835 L .37627 .42197 L p .821 .793 .826 r
F P
0 g
s
.66013 .4375 m .69522 .42747 L .67653 .43018 L p .376 .84 .88 r
F P
0 g
s
.67653 .43018 m .64579 .44033 L .66013 .4375 L p .376 .84 .88 r
F P
0 g
s
.52857 .44825 m .52819 .45546 L .5347 .46297 L p .049 .357 .83 r
F P
0 g
s
.5865 .77836 m .58195 .81668 L .58679 .81455 L p .412 .172 .438 r
F P
0 g
s
.58679 .81455 m .59159 .77559 L .5865 .77836 L p .412 .172 .438 r
F P
0 g
s
.40595 .61282 m .38338 .60154 L .3734 .60849 L p .643 .564 .75 r
F P
0 g
s
.3734 .60849 m .39794 .61943 L .40595 .61282 L p .643 .564 .75 r
F P
0 g
s
.43219 .39583 m .45349 .4162 L .44569 .42046 L p .691 .789 .925 r
F P
0 g
s
.44569 .42046 m .42228 .4014 L .43219 .39583 L p .691 .789 .925 r
F P
0 g
s
.67662 .63413 m .64973 .64104 L .65904 .64066 L p .149 0 0 r
F P
0 g
s
.65904 .64066 m .68969 .63264 L .67662 .63413 L p .149 0 0 r
F P
0 g
s
.46378 .81267 m .45942 .77201 L .46488 .77305 L p .848 .539 .466 r
F P
0 g
s
.46488 .77305 m .46865 .81424 L .46378 .81267 L p .848 .539 .466 r
F P
0 g
s
.433 .7591 m .42987 .7271 L .43337 .73038 L p .957 .642 .39 r
F P
0 g
s
.43337 .73038 m .43637 .7622 L .433 .7591 L p .957 .642 .39 r
F P
0 g
s
.41879 .62761 m .39794 .61943 L .38784 .62741 L p .658 .567 .74 r
F P
0 g
s
.38784 .62741 m .41145 .63482 L .41879 .62761 L p .658 .567 .74 r
F P
0 g
s
.42385 .67237 m .41515 .65889 L .41023 .6673 L p .45 .392 .701 r
F P
0 g
s
.41023 .6673 m .42144 .67916 L .42385 .67237 L p .45 .392 .701 r
F P
0 g
s
.42578 .64376 m .41145 .63482 L .40321 .64323 L p .62 .524 .724 r
F P
0 g
s
.40321 .64323 m .42049 .65096 L .42578 .64376 L p .62 .524 .724 r
F P
0 g
s
.34972 .49992 m .36752 .48824 L .37528 .50172 L p .916 .786 .702 r
F P
0 g
s
.37528 .50172 m .35865 .51317 L .34972 .49992 L p .916 .786 .702 r
F P
0 g
s
.61677 .66788 m .62193 .69683 L .62392 .69445 L p .205 .114 .524 r
F P
0 g
s
.62392 .69445 m .61966 .66627 L .61677 .66788 L p .205 .114 .524 r
F P
0 g
s
.62665 .64931 m .62287 .66508 L .62624 .66411 L p .355 .096 .376 r
F P
0 g
s
.62624 .66411 m .63241 .64909 L .62665 .64931 L p .355 .096 .376 r
F P
0 g
s
.36694 .55651 m .37533 .5744 L .37465 .56837 L p 0 0 .553 r
F P
0 g
s
.59159 .77559 m .58679 .81455 L .59138 .8122 L p .363 .134 .427 r
F P
0 g
s
.59138 .8122 m .59632 .77245 L .59159 .77559 L p .363 .134 .427 r
F P
0 g
s
.6141 .71028 m .61735 .75024 L .6198 .74666 L p .051 0 .46 r
F P
0 g
s
.6198 .74666 m .61605 .70626 L .6141 .71028 L p .051 0 .46 r
F P
0 g
s
.42343 .70841 m .41968 .686 L .4188 .69263 L p 0 0 .313 r
F P
0 g
s
.35242 .4555 m .38079 .45485 L .38616 .47064 L p .868 .792 .774 r
F P
0 g
s
.38616 .47064 m .35948 .47268 L .35242 .4555 L p .868 .792 .774 r
F P
0 g
s
.64579 .44033 m .67653 .43018 L .65718 .43525 L p .311 .798 .76 r
F P
0 g
s
.65718 .43525 m .63094 .44506 L .64579 .44033 L p .311 .798 .76 r
F P
0 g
s
.45915 .81092 m .45416 .77073 L .45942 .77201 L p .865 .549 .452 r
F P
0 g
s
.45942 .77201 m .46378 .81267 L .45915 .81092 L p .865 .549 .452 r
F P
0 g
s
.42665 .66585 m .42049 .65096 L .41515 .65889 L p .422 .344 .664 r
F P
0 g
s
.41515 .65889 m .42385 .67237 L .42665 .66585 L p .422 .344 .664 r
F P
0 g
s
.43219 .39583 m .45349 .4162 L .46258 .41443 L p .626 .77 .949 r
F P
0 g
s
.42468 .62163 m .40595 .61282 L .39794 .61943 L p .651 .576 .758 r
F P
0 g
s
.39794 .61943 m .41879 .62761 L .42468 .62163 L p .651 .576 .758 r
F P
0 g
s
.43059 .63747 m .41879 .62761 L .41145 .63482 L p .607 .511 .72 r
F P
0 g
s
.41145 .63482 m .42578 .64376 L .43059 .63747 L p .607 .511 .72 r
F P
0 g
s
.64973 .64104 m .63241 .64909 L .63833 .6488 L p .286 0 0 r
F P
0 g
s
.63833 .6488 m .65904 .64066 L .64973 .64104 L p .286 0 0 r
F P
0 g
s
.39311 .5905 m .37533 .5744 L .37191 .58017 L p .479 .51 .811 r
F P
0 g
s
.37191 .58017 m .39006 .59567 L .39311 .5905 L p .479 .51 .811 r
F P
0 g
s
.52083 .44716 m .51958 .43727 L .50915 .426 L p .1 .404 .857 r
F P
0 g
s
.41137 .60744 m .39006 .59567 L .38338 .60154 L p .621 .582 .789 r
F P
0 g
s
.38338 .60154 m .40595 .61282 L .41137 .60744 L p .621 .582 .789 r
F P
0 g
s
.73693 .43682 m .77989 .44031 L .76725 .43252 L p .341 .679 .978 r
F P
0 g
s
.76725 .43252 m .72635 .43071 L .73693 .43682 L p .341 .679 .978 r
F P
0 g
s
.80648 .51305 m .81514 .54199 L .8254 .52828 L p .218 .148 .559 r
F P
0 g
s
.8254 .52828 m .81622 .4981 L .80648 .51305 L p .218 .148 .559 r
F P
0 g
s
.43013 .75562 m .42713 .72317 L .42987 .7271 L p .971 .658 .346 r
F P
0 g
s
.42987 .7271 m .433 .7591 L .43013 .75562 L p .971 .658 .346 r
F P
0 g
s
.63094 .44506 m .65718 .43525 L .63818 .44199 L p .275 .758 .658 r
F P
0 g
s
.63818 .44199 m .61633 .45111 L .63094 .44506 L p .275 .758 .658 r
F P
0 g
s
.59632 .77245 m .59138 .8122 L .59568 .80965 L p .31 .094 .415 r
F P
0 g
s
.59568 .80965 m .60068 .76902 L .59632 .77245 L p .31 .094 .415 r
F P
0 g
s
.72324 .61984 m .68969 .63264 L .70253 .63032 L p 0 0 0 r
F P
0 g
s
.70253 .63032 m .73962 .61518 L .72324 .61984 L p 0 0 0 r
F P
0 g
s
.61605 .70626 m .6198 .74666 L .62202 .74323 L p .043 0 .46 r
F P
0 g
s
.62202 .74323 m .61798 .70269 L .61605 .70626 L p .043 0 .46 r
F P
0 g
s
.42355 .70295 m .42144 .67916 L .41968 .686 L p 0 0 .313 r
F P
0 g
s
.41968 .686 m .42343 .70841 L .42355 .70295 L p 0 0 .313 r
F P
0 g
s
.51251 .43867 m .50915 .426 L .49733 .41529 L p .159 .461 .887 r
F P
0 g
s
.49733 .41529 m .50328 .43064 L .51251 .43867 L p .159 .461 .887 r
F P
0 g
s
.61633 .45111 m .63818 .44199 L .62041 .44957 L p 0 0 0 r
F P
0 g
s
.62041 .44957 m .60258 .45777 L .61633 .45111 L p 0 0 0 r
F P
0 g
s
.57914 .46825 m .57006 .47393 L .57932 .4699 L p .44 .874 .796 r
F P
0 g
s
.57006 .47393 m .57914 .46825 L .56949 .47045 L p .486 .89 .937 r
F P
0 g
s
.56949 .47045 m .56222 .47583 L .57006 .47393 L p .486 .89 .937 r
F P
0 g
s
.42958 .65979 m .42578 .64376 L .42049 .65096 L p .375 .283 .622 r
F P
0 g
s
.42049 .65096 m .42665 .66585 L .42958 .65979 L p .375 .283 .622 r
F P
0 g
s
.43458 .63215 m .42468 .62163 L .41879 .62761 L p .577 .493 .723 r
F P
0 g
s
.41879 .62761 m .43059 .63747 L .43458 .63215 L p .577 .493 .723 r
F P
0 g
s
.57932 .4699 m .59071 .46356 L .57914 .46825 L p .44 .874 .796 r
F P
0 g
s
.59071 .46356 m .58261 .46807 L p .59017 .46429 L .365 .81 .668 r
F P
0 g
s
.58238 .46831 m .59017 .46429 L p .58261 .46807 L .365 .81 .668 r
F P
0 g
s
.58867 .46569 m .57914 .46825 L .59071 .46356 L p 0 0 0 r
F P
0 g
s
.57914 .46825 m .58353 .46707 L p .5772 .46784 L .234 .751 .763 r
F P
0 g
s
.58353 .46707 m .58867 .46569 L .584 .46656 L p .234 .751 .763 r
F P
0 g
s
.584 .46656 m .5772 .46784 L p .58353 .46707 L .234 .751 .763 r
F P
0 g
s
.58261 .46807 m .57932 .4699 L .58238 .46831 L p .365 .81 .668 r
F P
0 g
s
.44399 .39353 m .46258 .41443 L .47255 .4152 L p .541 .733 .963 r
F P
0 g
s
.46258 .41443 m .44399 .39353 L .43219 .39583 L p .626 .77 .949 r
F P
0 g
s
.61966 .66627 m .62392 .69445 L .62585 .69233 L p .212 .103 .505 r
F P
0 g
s
.62585 .69233 m .62287 .66508 L .61966 .66627 L p .212 .103 .505 r
F P
0 g
s
.37854 .40663 m .40972 .42084 L .40735 .43351 L p .807 .81 .853 r
F P
0 g
s
.40735 .43351 m .37627 .42197 L .37854 .40663 L p .807 .81 .853 r
F P
0 g
s
.45476 .80897 m .44917 .76915 L .45416 .77073 L p .882 .56 .435 r
F P
0 g
s
.45416 .77073 m .45915 .81092 L .45476 .80897 L p .882 .56 .435 r
F P
0 g
s
.60253 .46094 m .58867 .46569 L p .58885 .4655 L 0 0 0 r
F P
0 g
s
.59751 .46058 m .59017 .46429 L .60087 .45867 L p 0 0 0 r
F P
0 g
s
.60448 .45706 m .59751 .46058 L p .60258 .45777 L 0 0 0 r
F P
0 g
s
.60087 .45867 m .60258 .45777 L p .59751 .46058 L 0 0 0 r
F P
0 g
s
.59017 .46429 m .60448 .45706 L .59071 .46356 L p .365 .81 .668 r
F P
0 g
s
.59071 .46356 m .59325 .463 L p .58885 .4655 L 0 0 0 r
F P
0 g
s
.59325 .463 m .60253 .46094 L p .58885 .4655 L 0 0 0 r
F P
0 g
s
.56222 .47583 m .56949 .47045 L .56128 .46973 L p .45 .8 .998 r
F P
0 g
s
.56128 .46973 m .55542 .47525 L .56222 .47583 L p .45 .8 .998 r
F P
0 g
s
.60258 .45777 m .62041 .44957 L .60448 .45706 L p 0 0 0 r
F P
0 g
s
.42877 .61683 m .41137 .60744 L .40595 .61282 L p .626 .59 .794 r
F P
0 g
s
.40595 .61282 m .42468 .62163 L .42877 .61683 L p .626 .59 .794 r
F P
0 g
s
.35408 .53162 m .35865 .51317 L .36588 .52421 L p .979 .756 .53 r
F P
0 g
s
.36588 .52421 m .36161 .5415 L .35408 .53162 L p .979 .756 .53 r
F P
0 g
s
.55542 .47525 m .56128 .46973 L .55386 .46588 L p .351 .65 .967 r
F P
0 g
s
.55386 .46588 m .54918 .47202 L .55542 .47525 L p .351 .65 .967 r
F P
0 g
s
.50328 .43064 m .49733 .41529 L .48438 .406 L p .24 .532 .92 r
F P
0 g
s
.48438 .406 m .49332 .42369 L .50328 .43064 L p .24 .532 .92 r
F P
0 g
s
.60068 .76902 m .59568 .80965 L .59971 .80693 L p .255 .054 .402 r
F P
0 g
s
.59971 .80693 m .60468 .76537 L .60068 .76902 L p .255 .054 .402 r
F P
0 g
s
.45708 .39461 m .47255 .4152 L .48294 .41839 L p .442 .677 .963 r
F P
0 g
s
.47255 .4152 m .45708 .39461 L .44399 .39353 L p .541 .733 .963 r
F P
0 g
s
.78924 .46358 m .82048 .48345 L .81863 .46987 L p .242 .4 .821 r
F P
0 g
s
.81863 .46987 m .78732 .45087 L .78924 .46358 L p .242 .4 .821 r
F P
0 g
s
.63241 .64909 m .62624 .66411 L .62953 .66316 L p .315 .025 .304 r
F P
0 g
s
.62953 .66316 m .63833 .6488 L .63241 .64909 L p .315 .025 .304 r
F P
0 g
s
.43242 .65433 m .43059 .63747 L .42578 .64376 L p .3 .2 .57 r
F P
0 g
s
.42578 .64376 m .42958 .65979 L .43242 .65433 L p .3 .2 .57 r
F P
0 g
s
.42778 .75181 m .42515 .71866 L .42713 .72317 L p .973 .671 .295 r
F P
0 g
s
.42713 .72317 m .43013 .75562 L .42778 .75181 L p .973 .671 .295 r
F P
0 g
s
.41394 .60302 m .39311 .5905 L .39006 .59567 L p .552 .599 .855 r
F P
0 g
s
.39006 .59567 m .41137 .60744 L .41394 .60302 L p .552 .599 .855 r
F P
0 g
s
.49332 .42369 m .48438 .406 L .47077 .3989 L p .338 .607 .948 r
F P
0 g
s
.47077 .3989 m .48294 .41839 L .49332 .42369 L p .338 .607 .948 r
F P
0 g
s
.43752 .62781 m .42877 .61683 L .42468 .62163 L p .517 .464 .737 r
F P
0 g
s
.42468 .62163 m .43458 .63215 L .43752 .62781 L p .517 .464 .737 r
F P
0 g
s
.76908 .59306 m .73962 .61518 L .75449 .60921 L p 0 0 0 r
F P
0 g
s
.75449 .60921 m .78633 .58408 L .76908 .59306 L p 0 0 0 r
F P
0 g
s
.48294 .41839 m .47077 .3989 L .45708 .39461 L p .442 .677 .963 r
F P
0 g
s
.80025 .55495 m .78633 .58408 L .80046 .57375 L p .064 0 .21 r
F P
0 g
s
.80046 .57375 m .81514 .54199 L .80025 .55495 L p .064 0 .21 r
F P
0 g
s
.4242 .69746 m .42385 .67237 L .42144 .67916 L p 0 0 .285 r
F P
0 g
s
.42144 .67916 m .42355 .70295 L .4242 .69746 L p 0 0 .285 r
F P
0 g
s
.61798 .70269 m .62202 .74323 L .62401 .73998 L p .035 0 .457 r
F P
0 g
s
.62401 .73998 m .61994 .69955 L .61798 .70269 L p .035 0 .457 r
F P
0 g
s
.54918 .47202 m .55386 .46588 L .54649 .45895 L p .245 .517 .91 r
F P
0 g
s
.54649 .45895 m .54297 .46621 L .54918 .47202 L p .245 .517 .91 r
F P
0 g
s
.45067 .80682 m .44451 .76722 L .44917 .76915 L p .9 .571 .414 r
F P
0 g
s
.44917 .76915 m .45476 .80897 L .45067 .80682 L p .9 .571 .414 r
F P
0 g
s
.36619 .54967 m .37299 .56469 L p .37034 .5616 L .786 .393 0 r
F P
0 g
s
.37299 .56469 m .37465 .56837 L .37034 .5616 L p .786 .393 0 r
F P
0 g
s
.38899 .58052 m .37034 .5616 L .37465 .56837 L p 0 .185 .699 r
F P
0 g
s
.36161 .5415 m .37034 .5616 L .36323 .55369 L p .899 .502 .079 r
F P
0 g
s
.37034 .5616 m .38751 .57902 L p .38296 .57488 L .556 .048 0 r
F P
0 g
s
.38751 .57902 m .38899 .58052 L .38296 .57488 L p .556 .048 0 r
F P
0 g
s
.38296 .57488 m .36743 .5582 L p .37034 .5616 L .556 .048 0 r
F P
0 g
s
.40662 .59207 m .38296 .57488 L .38899 .58052 L p 0 .224 .67 r
F P
0 g
s
.38296 .57488 m .40662 .59207 L .40104 .5881 L p .428 0 0 r
F P
0 g
s
.36743 .5582 m .36323 .55369 L .37034 .5616 L p .556 .048 0 r
F P
0 g
s
.36323 .55369 m .38296 .57488 L .37549 .5684 L p .648 .142 0 r
F P
0 g
s
.40104 .5881 m .37774 .57014 L p .38296 .57488 L .428 0 0 r
F P
0 g
s
.37774 .57014 m .37549 .5684 L .38296 .57488 L p .428 0 0 r
F P
0 g
s
.68969 .63264 m .65904 .64066 L .66808 .63973 L p .009 0 0 r
F P
0 g
s
.66808 .63973 m .70253 .63032 L .68969 .63264 L p .009 0 0 r
F P
0 g
s
.39262 .5856 m .37465 .56837 L .37533 .5744 L p .216 .432 .856 r
F P
0 g
s
.37533 .5744 m .39311 .5905 L .39262 .5856 L p .216 .432 .856 r
F P
0 g
s
.43089 .61304 m .41394 .60302 L .41137 .60744 L p .555 .604 .857 r
F P
0 g
s
.41137 .60744 m .42877 .61683 L .43089 .61304 L p .555 .604 .857 r
F P
0 g
s
.43496 .64955 m .43458 .63215 L .43059 .63747 L p .189 .088 .501 r
F P
0 g
s
.43059 .63747 m .43242 .65433 L .43496 .64955 L p .189 .088 .501 r
F P
0 g
s
.60468 .76537 m .59971 .80693 L .60343 .80409 L p .199 .012 .388 r
F P
0 g
s
.60343 .80409 m .60832 .76159 L .60468 .76537 L p .199 .012 .388 r
F P
0 g
s
.62287 .66508 m .62585 .69233 L .62764 .69035 L p .192 .071 .476 r
F P
0 g
s
.62764 .69035 m .62624 .66411 L .62287 .66508 L p .192 .071 .476 r
F P
0 g
s
.34042 .48458 m .35948 .47268 L .36752 .48824 L p .925 .798 .701 r
F P
0 g
s
.36752 .48824 m .34972 .49992 L .34042 .48458 L p .925 .798 .701 r
F P
0 g
s
.4393 .62437 m .43089 .61304 L .42877 .61683 L p .391 .41 .76 r
F P
0 g
s
.42877 .61683 m .43752 .62781 L .4393 .62437 L p .391 .41 .76 r
F P
0 g
s
.34751 .4374 m .37722 .43835 L .38079 .45485 L p .871 .816 .792 r
F P
0 g
s
.38079 .45485 m .35242 .4555 L .34751 .4374 L p .871 .816 .792 r
F P
0 g
s
.72635 .43071 m .76725 .43252 L .7501 .42789 L p .206 .688 .932 r
F P
0 g
s
.7501 .42789 m .71217 .42757 L .72635 .43071 L p .206 .688 .932 r
F P
0 g
s
.42525 .6921 m .42665 .66585 L .42385 .67237 L p 0 0 .242 r
F P
0 g
s
.42385 .67237 m .4242 .69746 L .42525 .6921 L p 0 0 .242 r
F P
0 g
s
.65904 .64066 m .63833 .6488 L .64395 .64819 L p .161 0 0 r
F P
0 g
s
.64395 .64819 m .66808 .63973 L .65904 .64066 L p .161 0 0 r
F P
0 g
s
.54297 .46621 m .54649 .45895 L .53843 .4493 L p .154 .424 .864 r
F P
0 g
s
.53843 .4493 m .53625 .45812 L .54297 .46621 L p .154 .424 .864 r
F P
0 g
s
.42515 .71866 m .42778 .75181 L .42596 .74773 L p .958 .676 .238 r
F P
0 g
s
.43707 .64548 m .43752 .62781 L .43458 .63215 L p .036 0 .413 r
F P
0 g
s
.43458 .63215 m .43496 .64955 L .43707 .64548 L p .036 0 .413 r
F P
0 g
s
.44687 .80446 m .44022 .76491 L .44451 .76722 L p .919 .583 .388 r
F P
0 g
s
.44451 .76722 m .45067 .80682 L .44687 .80446 L p .919 .583 .388 r
F P
0 g
s
.38433 .39325 m .4147 .40991 L .40972 .42084 L p .783 .824 .884 r
F P
0 g
s
.40972 .42084 m .37854 .40663 L .38433 .39325 L p .783 .824 .884 r
F P
0 g
s
.61994 .69955 m .62401 .73998 L .62576 .7369 L p .022 0 .448 r
F P
0 g
s
.62576 .7369 m .62193 .69683 L .61994 .69955 L p .022 0 .448 r
F P
0 g
s
.60832 .76159 m .60343 .80409 L .60685 .80114 L p .143 0 .372 r
F P
0 g
s
.60685 .80114 m .61163 .75777 L .60832 .76159 L p .143 0 .372 r
F P
0 g
s
.41375 .59922 m .39262 .5856 L .39311 .5905 L p .366 .578 .923 r
F P
0 g
s
.39311 .5905 m .41394 .60302 L .41375 .59922 L p .366 .578 .923 r
F P
0 g
s
.43108 .61002 m .41375 .59922 L .41394 .60302 L p .372 .583 .924 r
F P
0 g
s
.41394 .60302 m .43089 .61304 L .43108 .61002 L p .372 .583 .924 r
F P
0 g
s
.42658 .68697 m .42958 .65979 L .42665 .66585 L p 0 0 .192 r
F P
0 g
s
.42665 .66585 m .42525 .6921 L .42658 .68697 L p 0 0 .192 r
F P
0 g
s
.43996 .62169 m .43108 .61002 L .43089 .61304 L p .137 .297 .764 r
F P
0 g
s
.43089 .61304 m .4393 .62437 L .43996 .62169 L p .137 .297 .764 r
F P
0 g
s
.63833 .6488 m .62953 .66316 L .63248 .66205 L p .228 0 .189 r
F P
0 g
s
.63248 .66205 m .64395 .64819 L .63833 .6488 L p .228 0 .189 r
F P
0 g
s
.53625 .45812 m .53843 .4493 L .52907 .4375 L p .087 .371 .836 r
F P
0 g
s
.52907 .4375 m .52857 .44825 L .53625 .45812 L p .087 .371 .836 r
F P
0 g
s
.4387 .64209 m .4393 .62437 L .43752 .62781 L p 0 0 .31 r
F P
0 g
s
.43752 .62781 m .43707 .64548 L .4387 .64209 L p 0 0 .31 r
F P
0 g
s
.52034 .85723 m .51886 .82314 L .52484 .82362 L p .67 .325 .381 r
F P
0 g
s
.52484 .82362 m .52515 .85741 L .52034 .85723 L p .67 .325 .381 r
F P
0 g
s
.52515 .85741 m .52484 .82362 L .53085 .82395 L p .651 .308 .379 r
F P
0 g
s
.51555 .8569 m .51292 .82253 L .51886 .82314 L p .688 .341 .381 r
F P
0 g
s
.51886 .82314 m .52034 .85723 L .51555 .8569 L p .688 .341 .381 r
F P
0 g
s
.53085 .82395 m .52997 .85745 L .52515 .85741 L p .651 .308 .379 r
F P
0 g
s
.52997 .85745 m .53085 .82395 L .53686 .82411 L p .631 .29 .375 r
F P
0 g
s
.51081 .85645 m .50703 .82182 L .51292 .82253 L p .705 .355 .381 r
F P
0 g
s
.51292 .82253 m .51555 .8569 L .51081 .85645 L p .705 .355 .381 r
F P
0 g
s
.53686 .82411 m .53477 .85735 L .52997 .85745 L p .631 .29 .375 r
F P
0 g
s
.53477 .85735 m .53686 .82411 L .54285 .82408 L p .609 .27 .371 r
F P
0 g
s
.62624 .66411 m .62764 .69035 L .62917 .68843 L p .141 .012 .431 r
F P
0 g
s
.62917 .68843 m .62953 .66316 L .62624 .66411 L p .141 .012 .431 r
F P
0 g
s
.44342 .80188 m .43637 .7622 L .44022 .76491 L p .935 .594 .358 r
F P
0 g
s
.44022 .76491 m .44687 .80446 L .44342 .80188 L p .935 .594 .358 r
F P
0 g
s
.61163 .75777 m .60685 .80114 L .60997 .79813 L p .086 0 .355 r
F P
0 g
s
.60997 .79813 m .61463 .75396 L .61163 .75777 L p .086 0 .355 r
F P
0 g
s
.34476 .51986 m .34972 .49992 L .35865 .51317 L p .977 .75 .527 r
F P
0 g
s
.35865 .51317 m .35408 .53162 L .34476 .51986 L p .977 .75 .527 r
F P
0 g
s
.50612 .85586 m .50122 .82102 L .50703 .82182 L p .722 .369 .378 r
F P
0 g
s
.50703 .82182 m .51081 .85645 L .50612 .85586 L p .722 .369 .378 r
F P
0 g
s
.54285 .82408 m .53955 .85709 L .53477 .85735 L p .609 .27 .371 r
F P
0 g
s
.53955 .85709 m .54285 .82408 L .5488 .82382 L p .586 .249 .365 r
F P
0 g
s
.73962 .61518 m .70253 .63032 L .7141 .62693 L p 0 0 0 r
F P
0 g
s
.7141 .62693 m .75449 .60921 L .73962 .61518 L p 0 0 0 r
F P
0 g
s
.37465 .56837 m .39262 .5856 L .38899 .58052 L p 0 .185 .699 r
F P
0 g
s
.42809 .68218 m .43242 .65433 L .42958 .65979 L p 0 0 .142 r
F P
0 g
s
.42958 .65979 m .42658 .68697 L .42809 .68218 L p 0 0 .142 r
F P
0 g
s
.62193 .69683 m .62576 .7369 L .62725 .73396 L p 0 0 .433 r
F P
0 g
s
.62725 .73396 m .62392 .69445 L .62193 .69683 L p 0 0 .433 r
F P
0 g
s
.5488 .82382 m .54428 .85668 L .53955 .85709 L p .586 .249 .365 r
F P
0 g
s
.54428 .85668 m .5488 .82382 L .55467 .82331 L p .562 .227 .358 r
F P
0 g
s
.50151 .85515 m .49549 .82014 L .50122 .82102 L p .739 .381 .374 r
F P
0 g
s
.50122 .82102 m .50612 .85586 L .50151 .85515 L p .739 .381 .374 r
F P
0 g
s
.81622 .4981 m .8254 .52828 L .82998 .51443 L p 0 .003 .516 r
F P
0 g
s
.82998 .51443 m .82048 .48345 L .81622 .4981 L p 0 .003 .516 r
F P
0 g
s
.71217 .42757 m .7501 .42789 L .72951 .42657 L p .055 .621 .759 r
F P
0 g
s
.72951 .42657 m .69522 .42747 L .71217 .42757 L p .055 .621 .759 r
F P
0 g
s
.36323 .55369 m .35408 .53162 L .36161 .5415 L p .899 .502 .079 r
F P
0 g
s
.43996 .62169 m .4393 .62437 L p .43967 .63448 L 0 0 .219 r
F P
0 g
s
.43988 .63475 m .43996 .62169 L p .43967 .63448 L 0 0 .219 r
F P
0 g
s
.43108 .61002 m .43996 .62169 L .43966 .6196 L p 0 .119 .669 r
F P
0 g
s
.43996 .62169 m .43985 .63933 L .44062 .63709 L p 0 0 .17 r
F P
0 g
s
.43966 .6196 m .43996 .62169 L p .44059 .63632 L 0 0 .17 r
F P
0 g
s
.44062 .63709 m .44055 .63584 L p .44059 .63632 L 0 0 .17 r
F P
0 g
s
.44055 .63584 m .43966 .6196 L p .44059 .63632 L 0 0 .17 r
F P
0 g
s
.43966 .6196 m .44054 .63562 L p .44116 .63526 L 0 0 .182 r
F P
0 g
s
.43966 .6196 m .42959 .60753 L .43108 .61002 L p 0 .119 .669 r
F P
0 g
s
.42959 .60753 m .43966 .6196 L .43866 .6179 L p 0 0 .535 r
F P
0 g
s
.44116 .63526 m .43875 .61855 L p .43966 .6196 L 0 0 .182 r
F P
0 g
s
.43875 .61855 m .43866 .6179 L .43932 .61903 L p 0 0 .182 r
F P
0 g
s
.43932 .61903 m .43966 .6196 L p .43875 .61855 L 0 0 .182 r
F P
0 g
s
.41375 .59922 m .43108 .61002 L .42959 .60753 L p .027 .448 .872 r
F P
0 g
s
.42959 .60753 m .41111 .59568 L .41375 .59922 L p .027 .448 .872 r
F P
0 g
s
.41111 .59568 m .42959 .60753 L .42685 .60528 L p 0 .26 .693 r
F P
0 g
s
.43866 .6179 m .42685 .60528 L .42959 .60753 L p 0 0 .535 r
F P
0 g
s
.42685 .60528 m .40662 .59207 L .41111 .59568 L p 0 .26 .693 r
F P
0 g
s
.42685 .60528 m .43843 .61766 L p .43732 .6164 L 0 0 .495 r
F P
0 g
s
.43843 .61766 m .43866 .6179 L .43732 .6164 L p 0 0 .495 r
F P
0 g
s
.40662 .59207 m .4259 .60465 L p .42342 .60303 L 0 .168 .593 r
F P
0 g
s
.4259 .60465 m .42685 .60528 L .42342 .60303 L p 0 .168 .593 r
F P
0 g
s
.43732 .6164 m .42342 .60303 L .42685 .60528 L p 0 0 .495 r
F P
0 g
s
.42342 .60303 m .40104 .5881 L .40662 .59207 L p 0 .168 .593 r
F P
0 g
s
.42342 .60303 m .43632 .61544 L p .43606 .61494 L 0 .052 .552 r
F P
0 g
s
.43632 .61544 m .43732 .6164 L .43606 .61494 L p 0 .052 .552 r
F P
0 g
s
.43606 .61494 m .42059 .60118 L p .42342 .60303 L 0 .052 .552 r
F P
0 g
s
.44116 .63526 m .44167 .63369 L p .43956 .62262 L 0 0 .257 r
F P
0 g
s
.43866 .6179 m .43979 .62579 L p .43956 .62262 L 0 0 .257 r
F P
0 g
s
.43979 .62579 m .44116 .63526 L p .43956 .62262 L 0 0 .257 r
F P
0 g
s
.44167 .63369 m .43732 .6164 L .43866 .6179 L p 0 0 .257 r
F P
0 g
s
.44167 .63369 m .44237 .63228 L p .43851 .62013 L 0 0 .381 r
F P
0 g
s
.43732 .6164 m .43796 .61896 L p .43851 .62013 L 0 0 .381 r
F P
0 g
s
.43796 .61896 m .44167 .63369 L p .43851 .62013 L 0 0 .381 r
F P
0 g
s
.44237 .63228 m .43677 .61687 L p .43711 .61716 L 0 0 .381 r
F P
0 g
s
.43773 .61769 m .43851 .62013 L .43711 .61716 L 0 0 .381 r
F
.43851 .62013 m .44237 .63228 L .43711 .61716 L F
.43677 .61687 m .43606 .61494 L p .43773 .61769 L F P
0 g
s
.43606 .61494 m .44237 .63228 L .44351 .63089 L p 0 0 .528 r
F P
0 g
s
.40104 .5881 m .41893 .60004 L p .41992 .60059 L 0 .176 .607 r
F P
0 g
s
.41893 .60004 m .42342 .60303 L .41992 .60059 L p 0 .176 .607 r
F P
0 g
s
.41992 .60059 m .42342 .60303 L p .42068 .60124 L 0 .052 .552 r
F P
0 g
s
.42059 .60118 m .41992 .60059 L p .42068 .60124 L 0 .052 .552 r
F P
0 g
s
.4353 .61336 m .42098 .60118 L p .41992 .60059 L 0 .175 .668 r
F P
0 g
s
.42098 .60118 m .41703 .59782 L .41992 .60059 L p 0 .175 .668 r
F P
0 g
s
.41992 .60059 m .43606 .61494 L .4353 .61336 L p 0 .175 .668 r
F P
0 g
s
.43606 .61494 m .44241 .62855 L .43578 .61438 L 0 0 .528 r
F
.44351 .63089 m .44279 .62937 L p .44241 .62855 L F P
0 g
s
.44279 .62937 m .43578 .61438 L p .44241 .62855 L 0 0 .528 r
F P
0 g
s
.43578 .61438 m .4353 .61336 L .43606 .61494 L p 0 0 .528 r
F P
0 g
s
.43732 .6164 m .43773 .61769 L .43709 .61663 L 0 0 .381 r
F
.43732 .6164 m .43709 .61663 L .43614 .61506 L F
.43606 .61494 m .43732 .6164 L p .43614 .61506 L F P
0 g
s
.44054 .63562 m .44062 .63709 L .44091 .6361 L p 0 0 .182 r
F P
0 g
s
.44091 .6361 m .44116 .63526 L p .44054 .63562 L 0 0 .182 r
F P
0 g
s
.43985 .63933 m .43988 .63475 L p .43967 .63448 L 0 0 .219 r
F P
0 g
s
.4393 .62437 m .4387 .64209 L .43985 .63933 L p 0 0 .219 r
F P
0 g
s
.55467 .82331 m .54895 .8561 L .54428 .85668 L p .562 .227 .358 r
F P
0 g
s
.54895 .8561 m .55467 .82331 L .56044 .82254 L p .535 .202 .351 r
F P
0 g
s
.49699 .85432 m .48985 .81917 L .49549 .82014 L p .755 .393 .368 r
F P
0 g
s
.49549 .82014 m .50151 .85515 L .49699 .85432 L p .755 .393 .368 r
F P
0 g
s
.52857 .44825 m .52907 .4375 L .51794 .42436 L p .047 .354 .828 r
F P
0 g
s
.51794 .42436 m .51958 .43727 L .52857 .44825 L p .047 .354 .828 r
F P
0 g
s
.78732 .45087 m .81863 .46987 L .81051 .45817 L p .017 .365 .835 r
F P
0 g
s
.81051 .45817 m .77989 .44031 L .78732 .45087 L p .017 .365 .835 r
F P
0 g
s
.39364 .38269 m .42228 .4014 L .4147 .40991 L p .746 .832 .917 r
F P
0 g
s
.4147 .40991 m .38433 .39325 L .39364 .38269 L p .746 .832 .917 r
F P
0 g
s
.42968 .6778 m .43496 .64955 L .43242 .65433 L p 0 0 .099 r
F P
0 g
s
.43242 .65433 m .42809 .68218 L .42968 .6778 L p 0 0 .099 r
F P
0 g
s
.61463 .75396 m .60997 .79813 L .61278 .79508 L p .029 0 .336 r
F P
0 g
s
.61278 .79508 m .61735 .75024 L .61463 .75396 L p .029 0 .336 r
F P
0 g
s
.39262 .5856 m .41375 .59922 L .41111 .59568 L p .007 .431 .863 r
F P
0 g
s
.41111 .59568 m .38899 .58052 L .39262 .5856 L p .007 .431 .863 r
F P
0 g
s
.56044 .82254 m .55353 .85536 L .54895 .8561 L p .535 .202 .351 r
F P
0 g
s
.55353 .85536 m .56044 .82254 L .56609 .82149 L p .507 .176 .341 r
F P
0 g
s
.44032 .79909 m .433 .7591 L .43637 .7622 L p .949 .604 .32 r
F P
0 g
s
.43637 .7622 m .44342 .80188 L .44032 .79909 L p .949 .604 .32 r
F P
0 g
s
.49258 .85336 m .48433 .81811 L .48985 .81917 L p .771 .403 .36 r
F P
0 g
s
.48985 .81917 m .49699 .85432 L .49258 .85336 L p .771 .403 .36 r
F P
0 g
s
.66808 .63973 m .64756 .64693 L p .6488 .64705 L 0 0 0 r
F P
0 g
s
.64756 .64693 m .64395 .64819 L .6488 .64705 L p 0 0 0 r
F P
0 g
s
.63483 .66062 m .6488 .64705 L .64395 .64819 L p .063 0 0 r
F P
0 g
s
.63483 .66062 m .63631 .65876 L p .63646 .65896 L 0 0 0 r
F P
0 g
s
.63976 .65583 m .63483 .66062 L p .64104 .65433 L 0 0 0 r
F P
0 g
s
.64395 .64819 m .63248 .66205 L .63483 .66062 L p .063 0 0 r
F P
0 g
s
.63032 .68644 m .63248 .66205 L .62953 .66316 L p .044 0 .361 r
F P
0 g
s
.62937 .72839 m .62764 .69035 L .62585 .69233 L p 0 0 .369 r
F P
0 g
s
.62937 .72839 m .62991 .72567 L p .62933 .7166 L 0 0 .31 r
F P
0 g
s
.62764 .69035 m .62909 .72219 L p .62933 .7166 L 0 0 .31 r
F P
0 g
s
.62909 .72219 m .62937 .72839 L p .62933 .7166 L 0 0 .31 r
F P
0 g
s
.62991 .72567 m .62917 .68843 L .62764 .69035 L p 0 0 .31 r
F P
0 g
s
.62991 .72567 m .63003 .72294 L p .62968 .7088 L 0 0 .222 r
F P
0 g
s
.62917 .68843 m .62962 .71112 L p .62968 .7088 L 0 0 .222 r
F P
0 g
s
.62962 .71112 m .62991 .72567 L p .62968 .7088 L 0 0 .222 r
F P
0 g
s
.63003 .72294 m .63032 .68644 L .62917 .68843 L p 0 0 .222 r
F P
0 g
s
.62885 .71727 m .62962 .70433 L p .62991 .70001 L .743 .634 .072 r
F P
0 g
s
.63003 .72294 m .6297 .72015 L p .63006 .70066 L 0 0 .094 r
F P
0 g
s
.63032 .68644 m .63022 .69883 L p .63006 .70066 L 0 0 .094 r
F P
0 g
s
.63022 .69883 m .63003 .72294 L p .63006 .70066 L 0 0 .094 r
F P
0 g
s
.6297 .72015 m .63095 .68429 L .63032 .68644 L p 0 0 .094 r
F P
0 g
s
.62957 .70608 m .63024 .695 L .63018 .69637 L .743 .634 .072 r
F
.62885 .71727 m .62952 .7066 L .62957 .70608 L F
.62952 .7066 m .63024 .695 L .62957 .70608 L F
.6299 .70057 m .62991 .70001 L .63024 .695 L F
.62885 .71727 m .62991 .70001 L .6299 .70057 L F
.63018 .69637 m .63024 .695 L .63095 .68429 L F
.63032 .68644 m .63095 .68429 L p .63142 .67719 L 0 0 .245 r
F P
0 g
s
.62962 .70433 m .63096 .68191 L .63095 .68429 L p .743 .634 .072 r
F P
0 g
s
.63095 .68429 m .63146 .67688 L .63142 .67719 L 0 0 .245 r
F
.63248 .66205 m .63096 .67916 L p .63146 .67688 L F P
0 g
s
.63096 .67916 m .63032 .68644 L p .63146 .67688 L 0 0 .245 r
F P
0 g
s
.63095 .68429 m .63483 .66062 L .63248 .66205 L p 0 0 .245 r
F P
0 g
s
.63095 .68429 m .63096 .68191 L p .63167 .678 L 0 0 .046 r
F P
0 g
s
.63483 .66062 m .63103 .6838 L p .63167 .678 L 0 0 .046 r
F P
0 g
s
.63103 .6838 m .63095 .68429 L p .63167 .678 L 0 0 .046 r
F P
0 g
s
.63096 .68191 m .63631 .65876 L .63483 .66062 L p 0 0 .046 r
F P
0 g
s
.63592 .65349 m .63673 .65639 L p .63302 .66557 L .961 .886 .498 r
F P
0 g
s
.62953 .66316 m .62917 .68843 L .63032 .68644 L p .044 0 .361 r
F P
0 g
s
.6287 .67629 m .63351 .66109 L p .63302 .66557 L .961 .886 .498 r
F P
0 g
s
.63351 .66109 m .63592 .65349 L p .63302 .66557 L .961 .886 .498 r
F P
0 g
s
.63294 .6701 m .63613 .65851 L .63631 .65876 L .743 .755 .245 r
F
.63023 .67926 m .63333 .66836 L p .63294 .6701 L F P
0 g
s
.63333 .66836 m .63613 .65851 L p .63294 .6701 L .743 .755 .245 r
F P
0 g
s
.63613 .65851 m .63673 .65639 L .63631 .65876 L p .743 .755 .245 r
F P
0 g
s
.63631 .65876 m .64104 .65433 L .63646 .65896 L 0 0 0 r
F
.6488 .64705 m .63976 .65583 L p .64104 .65433 L F P
0 g
s
.63631 .65876 m .6501 .64718 L p .6488 .64705 L 0 0 0 r
F P
0 g
s
.6488 .64705 m .67612 .638 L .66808 .63973 L p 0 0 0 r
F P
0 g
s
.67612 .638 m .65326 .64557 L p .65243 .64523 L .323 .807 .772 r
F P
0 g
s
.65326 .64557 m .6488 .64705 L .65243 .64523 L p .323 .807 .772 r
F P
0 g
s
.65243 .64523 m .6488 .64705 L p .65 .64717 L 0 0 0 r
F P
0 g
s
.6501 .64718 m .65243 .64523 L p .65 .64717 L 0 0 0 r
F P
0 g
s
.64321 .65178 m .65167 .64491 L .65243 .64523 L .603 .931 .716 r
F
.65445 .64264 m .65243 .64523 L p .65167 .64491 L F P
0 g
s
.63673 .65639 m .64426 .65055 L p .64321 .65178 L .603 .931 .716 r
F P
0 g
s
.64426 .65055 m .65445 .64264 L p .64321 .65178 L .603 .931 .716 r
F P
0 g
s
.65243 .64523 m .65931 .64296 L p .67612 .638 L .323 .807 .772 r
F P
0 g
s
.69714 .63179 m .66808 .63973 L .67612 .638 L p .201 .718 .682 r
F P
0 g
s
.65931 .64296 m .68245 .63533 L .67612 .638 L p .323 .807 .772 r
F P
0 g
s
.70253 .63032 m .69714 .63179 L p .67612 .638 L .201 .718 .682 r
F P
0 g
s
.67612 .638 m .7141 .62693 L .70253 .63032 L p .201 .718 .682 r
F P
0 g
s
.34578 .41926 m .37627 .42197 L .37722 .43835 L p .868 .844 .819 r
F P
0 g
s
.37722 .43835 m .34751 .4374 L .34578 .41926 L p .868 .844 .819 r
F P
0 g
s
.62392 .69445 m .62725 .73396 L .62847 .73114 L p 0 0 .408 r
F P
0 g
s
.62847 .73114 m .62585 .69233 L .62392 .69445 L p 0 0 .408 r
F P
0 g
s
.56609 .82149 m .55801 .85446 L .55353 .85536 L p .507 .176 .341 r
F P
0 g
s
.55801 .85446 m .56609 .82149 L .57157 .82016 L p .475 .148 .331 r
F P
0 g
s
.4883 .85228 m .47894 .81694 L .48433 .81811 L p .787 .413 .349 r
F P
0 g
s
.48433 .81811 m .49258 .85336 L .4883 .85228 L p .787 .413 .349 r
F P
0 g
s
.33215 .46753 m .35242 .4555 L .35948 .47268 L p .936 .822 .708 r
F P
0 g
s
.35948 .47268 m .34042 .48458 L .33215 .46753 L p .936 .822 .708 r
F P
0 g
s
.78633 .58408 m .75449 .60921 L .7666 .60193 L p 0 0 0 r
F P
0 g
s
.7666 .60193 m .80046 .57375 L .78633 .58408 L p 0 0 0 r
F P
0 g
s
.43129 .67386 m .43707 .64548 L .43496 .64955 L p 0 0 .069 r
F P
0 g
s
.43496 .64955 m .42968 .6778 L .43129 .67386 L p 0 0 .069 r
F P
0 g
s
.81514 .54199 m .80046 .57375 L .81019 .56242 L p 0 0 0 r
F P
0 g
s
.81019 .56242 m .8254 .52828 L .81514 .54199 L p 0 0 0 r
F P
0 g
s
.69522 .42747 m .72951 .42657 L .70674 .42838 L p .05 0 0 r
F P
0 g
s
.70674 .42838 m .67653 .43018 L .69522 .42747 L p .05 0 0 r
F P
0 g
s
.5772 .46784 m .56949 .47045 L .57914 .46825 L p .234 .751 .763 r
F P
0 g
s
.56949 .47045 m .5772 .46784 L .56752 .4669 L p .237 .723 .927 r
F P
0 g
s
.56752 .4669 m .56128 .46973 L .56949 .47045 L p .237 .723 .927 r
F P
0 g
s
.51958 .43727 m .51794 .42436 L .50483 .41085 L p .039 .37 .838 r
F P
0 g
s
.50483 .41085 m .50915 .426 L .51958 .43727 L p .039 .37 .838 r
F P
0 g
s
.57157 .82016 m .56236 .8534 L .56658 .85218 L p .439 .115 .318 r
F P
0 g
s
.56658 .85218 m .57687 .81856 L .57157 .82016 L p .439 .115 .318 r
F P
0 g
s
.57157 .82016 m .56236 .8534 L .55801 .85446 L p .475 .148 .331 r
F P
0 g
s
.61735 .75024 m .61278 .79508 L .61527 .79202 L p 0 0 .314 r
F P
0 g
s
.61527 .79202 m .6198 .74666 L .61735 .75024 L p 0 0 .314 r
F P
0 g
s
.48416 .85108 m .47371 .81566 L .47894 .81694 L p .802 .422 .336 r
F P
0 g
s
.47894 .81694 m .4883 .85228 L .48416 .85108 L p .802 .422 .336 r
F P
0 g
s
.4376 .79611 m .43013 .75562 L .433 .7591 L p .956 .611 .276 r
F P
0 g
s
.433 .7591 m .44032 .79909 L .4376 .79611 L p .956 .611 .276 r
F P
0 g
s
.60253 .46094 m .59071 .46356 L .60448 .45706 L p 0 0 0 r
F P
0 g
s
.56128 .46973 m .56752 .4669 L .55881 .46261 L p .142 .565 .927 r
F P
0 g
s
.55881 .46261 m .55386 .46588 L .56128 .46973 L p .142 .565 .927 r
F P
0 g
s
.40613 .37564 m .43219 .39583 L .42228 .4014 L p .691 .828 .949 r
F P
0 g
s
.42228 .4014 m .39364 .38269 L .40613 .37564 L p .691 .828 .949 r
F P
0 g
s
.57687 .81856 m .56658 .85218 L .57063 .85081 L p .395 .076 .302 r
F P
0 g
s
.57063 .85081 m .58195 .81668 L .57687 .81856 L p .395 .076 .302 r
F P
0 g
s
.43288 .67038 m .4387 .64209 L .43707 .64548 L p 0 0 .058 r
F P
0 g
s
.43707 .64548 m .43129 .67386 L .43288 .67038 L p 0 0 .058 r
F P
0 g
s
.61912 .45434 m .60448 .45706 L .62041 .44957 L p .016 0 0 r
F P
0 g
s
.60448 .45706 m .61912 .45434 L .60253 .46094 L p 0 0 0 r
F P
0 g
s
.48017 .84975 m .46865 .81424 L .47371 .81566 L p .818 .43 .319 r
F P
0 g
s
.47371 .81566 m .48416 .85108 L .48017 .84975 L p .818 .43 .319 r
F P
0 g
s
.42352 .73012 m .42525 .6921 L .4242 .69746 L p .717 .595 .022 r
F P
0 g
s
.67653 .43018 m .70674 .42838 L .68315 .43287 L p .096 0 0 r
F P
0 g
s
.68315 .43287 m .65718 .43525 L .67653 .43018 L p .096 0 0 r
F P
0 g
s
.62585 .69233 m .62847 .73114 L .62937 .72839 L p 0 0 .369 r
F P
0 g
s
.55386 .46588 m .55881 .46261 L .55016 .45504 L p .015 .398 .852 r
F P
0 g
s
.55016 .45504 m .54649 .45895 L .55386 .46588 L p .015 .398 .852 r
F P
0 g
s
.63841 .4468 m .62041 .44957 L .63818 .44199 L p .068 0 0 r
F P
0 g
s
.62041 .44957 m .63841 .4468 L .61912 .45434 L p .016 0 0 r
F P
0 g
s
.6198 .74666 m .61527 .79202 L .61745 .78896 L p 0 0 .288 r
F P
0 g
s
.61745 .78896 m .62202 .74323 L .6198 .74666 L p 0 0 .288 r
F P
0 g
s
.38899 .58052 m .41111 .59568 L .40662 .59207 L p 0 .224 .67 r
F P
0 g
s
.50915 .426 m .50483 .41085 L .4898 .39802 L p .068 .417 .865 r
F P
0 g
s
.4898 .39802 m .49733 .41529 L .50915 .426 L p .068 .417 .865 r
F P
0 g
s
.58195 .81668 m .57063 .85081 L .57451 .84928 L p .346 .032 .283 r
F P
0 g
s
.57451 .84928 m .58679 .81455 L .58195 .81668 L p .346 .032 .283 r
F P
0 g
s
.65718 .43525 m .68315 .43287 L .66001 .43931 L p .097 0 0 r
F P
0 g
s
.66001 .43931 m .63818 .44199 L .65718 .43525 L p .097 0 0 r
F P
0 g
s
.43526 .79296 m .42778 .75181 L .43013 .75562 L p .953 .613 .222 r
F P
0 g
s
.43013 .75562 m .4376 .79611 L .43526 .79296 L p .953 .613 .222 r
F P
0 g
s
.63818 .44199 m .66001 .43931 L .63841 .4468 L p .068 0 0 r
F P
0 g
s
.47636 .8483 m .46378 .81267 L .46865 .81424 L p .833 .437 .298 r
F P
0 g
s
.46865 .81424 m .48017 .84975 L .47636 .8483 L p .833 .437 .298 r
F P
0 g
s
.33502 .50622 m .34042 .48458 L .34972 .49992 L p .985 .761 .517 r
F P
0 g
s
.34972 .49992 m .34476 .51986 L .33502 .50622 L p .985 .761 .517 r
F P
0 g
s
.43447 .66733 m .43985 .63933 L .4387 .64209 L p 0 0 .069 r
F P
0 g
s
.4387 .64209 m .43288 .67038 L .43447 .66733 L p 0 0 .069 r
F P
0 g
s
.42394 .72578 m .42658 .68697 L .42525 .6921 L p 0 0 .02 r
F P
0 g
s
.35442 .54439 m .34476 .51986 L .35408 .53162 L p .918 .53 .132 r
F P
0 g
s
.35408 .53162 m .36323 .55369 L .35442 .54439 L p .918 .53 .132 r
F P
0 g
s
.40613 .37564 m .43219 .39583 L .44399 .39353 L p .61 .806 .975 r
F P
0 g
s
.58679 .81455 m .57451 .84928 L .57821 .84763 L p .292 0 .261 r
F P
0 g
s
.57821 .84763 m .59138 .8122 L .58679 .81455 L p .292 0 .261 r
F P
0 g
s
.75449 .60921 m .7141 .62693 L .72341 .62238 L p .471 .89 .797 r
F P
0 g
s
.72341 .62238 m .7666 .60193 L .75449 .60921 L p .471 .89 .797 r
F P
0 g
s
.77989 .44031 m .81051 .45817 L .79643 .44901 L p 0 .24 .655 r
F P
0 g
s
.79643 .44901 m .76725 .43252 L .77989 .44031 L p 0 .24 .655 r
F P
0 g
s
.7141 .62693 m .67612 .638 L .68245 .63533 L p .43 .872 .874 r
F P
0 g
s
.49733 .41529 m .4898 .39802 L .47321 .38693 L p .136 .492 .904 r
F P
0 g
s
.47321 .38693 m .48438 .406 L .49733 .41529 L p .136 .492 .904 r
F P
0 g
s
.54649 .45895 m .55016 .45504 L .54068 .44452 L p 0 .272 .775 r
F P
0 g
s
.53843 .4493 m .54649 .45895 L p .54121 .44583 L 0 .272 .775 r
F P
0 g
s
.55284 .46027 m .54232 .44987 L p .54936 .45451 L .702 .219 0 r
F P
0 g
s
.55016 .45504 m .55053 .45575 L p .54936 .45451 L .702 .219 0 r
F P
0 g
s
.55053 .45575 m .55284 .46027 L p .54936 .45451 L .702 .219 0 r
F P
0 g
s
.54068 .44452 m .54045 .44502 L p .54121 .44583 L 0 .272 .775 r
F P
0 g
s
.54045 .44502 m .53843 .4493 L p .54121 .44583 L 0 .272 .775 r
F P
0 g
s
.62202 .74323 m .61745 .78896 L .6193 .78593 L p 0 0 .257 r
F P
0 g
s
.6193 .78593 m .62401 .73998 L .62202 .74323 L p 0 0 .257 r
F P
0 g
s
.47275 .84673 m .45915 .81092 L .46378 .81267 L p .847 .442 .274 r
F P
0 g
s
.46378 .81267 m .47636 .8483 L .47275 .84673 L p .847 .442 .274 r
F P
0 g
s
.34801 .40207 m .37854 .40663 L .37627 .42197 L p .855 .874 .853 r
F P
0 g
s
.37627 .42197 m .34578 .41926 L .34801 .40207 L p .855 .874 .853 r
F P
0 g
s
.43333 .78965 m .42596 .74773 L .42778 .75181 L p .934 .607 .16 r
F P
0 g
s
.42778 .75181 m .43526 .79296 L .43333 .78965 L p .934 .607 .16 r
F P
0 g
s
.68245 .63533 m .72341 .62238 L .7141 .62693 L p .43 .872 .874 r
F P
0 g
s
.82048 .48345 m .82998 .51443 L .82819 .50119 L p 0 0 .33 r
F P
0 g
s
.82819 .50119 m .81863 .46987 L .82048 .48345 L p 0 0 .33 r
F P
0 g
s
.59138 .8122 m .57821 .84763 L .5817 .84584 L p .232 0 .235 r
F P
0 g
s
.5817 .84584 m .59568 .80965 L .59138 .8122 L p .232 0 .235 r
F P
0 g
s
.4247 .72159 m .42809 .68218 L .42658 .68697 L p 0 0 .059 r
F P
0 g
s
.42658 .68697 m .42394 .72578 L .4247 .72159 L p 0 0 .059 r
F P
0 g
s
.4212 .37255 m .44399 .39353 L .45708 .39461 L p .497 .755 .988 r
F P
0 g
s
.44399 .39353 m .4212 .37255 L .40613 .37564 L p .61 .806 .975 r
F P
0 g
s
.43608 .66467 m .44062 .63709 L .43985 .63933 L p 0 0 .101 r
F P
0 g
s
.43985 .63933 m .43447 .66733 L .43608 .66467 L p 0 0 .101 r
F P
0 g
s
.48438 .406 m .47321 .38693 L .45568 .37853 L p .24 .584 .945 r
F P
0 g
s
.45568 .37853 m .47077 .3989 L .48438 .406 L p .24 .584 .945 r
F P
0 g
s
.46934 .84503 m .45476 .80897 L .45915 .81092 L p .86 .447 .243 r
F P
0 g
s
.45915 .81092 m .47275 .84673 L .46934 .84503 L p .86 .447 .243 r
F P
0 g
s
.32627 .44941 m .34751 .4374 L .35242 .4555 L p .946 .858 .722 r
F P
0 g
s
.35242 .4555 m .33215 .46753 L .32627 .44941 L p .946 .858 .722 r
F P
0 g
s
.43803 .37357 m .45708 .39461 L .47077 .3989 L p .367 .678 .977 r
F P
0 g
s
.45708 .39461 m .43803 .37357 L .4212 .37255 L p .497 .755 .988 r
F P
0 g
s
.47077 .3989 m .45568 .37853 L .43803 .37357 L p .367 .678 .977 r
F P
0 g
s
.62401 .73998 m .6193 .78593 L .62082 .78291 L p 0 0 .219 r
F P
0 g
s
.62082 .78291 m .62576 .7369 L .62401 .73998 L p 0 0 .219 r
F P
0 g
s
.59568 .80965 m .5817 .84584 L .58497 .84394 L p .166 0 .204 r
F P
0 g
s
.58497 .84394 m .59971 .80693 L .59568 .80965 L p .166 0 .204 r
F P
0 g
s
.43179 .78623 m .42465 .74344 L .42596 .74773 L p .895 .59 .089 r
F P
0 g
s
.42596 .74773 m .43333 .78965 L .43179 .78623 L p .895 .59 .089 r
F P
0 g
s
.42575 .7176 m .42968 .6778 L .42809 .68218 L p 0 0 .098 r
F P
0 g
s
.42809 .68218 m .4247 .72159 L .42575 .7176 L p 0 0 .098 r
F P
0 g
s
.53843 .4493 m .54068 .44452 L .52958 .43167 L p 0 .189 .714 r
F P
0 g
s
.52907 .4375 m .53843 .4493 L p .53051 .43352 L 0 .189 .714 r
F P
0 g
s
.54232 .44987 m .52995 .43721 L p .53942 .44366 L .754 .283 0 r
F P
0 g
s
.54068 .44452 m .54095 .4454 L p .53942 .44366 L .754 .283 0 r
F P
0 g
s
.54095 .4454 m .54232 .44987 L p .53942 .44366 L .754 .283 0 r
F P
0 g
s
.52958 .43167 m .52952 .43239 L p .53051 .43352 L 0 .189 .714 r
F P
0 g
s
.52952 .43239 m .52907 .4375 L p .53051 .43352 L 0 .189 .714 r
F P
0 g
s
.46615 .84321 m .45067 .80682 L .45476 .80897 L p .871 .449 .207 r
F P
0 g
s
.45476 .80897 m .46934 .84503 L .46615 .84321 L p .871 .449 .207 r
F P
0 g
s
.80046 .57375 m .7666 .60193 L .77484 .59352 L p .667 .952 .714 r
F P
0 g
s
.77484 .59352 m .81019 .56242 L .80046 .57375 L p .667 .952 .714 r
F P
0 g
s
.37549 .5684 m .35442 .54439 L .36323 .55369 L p .648 .142 0 r
F P
0 g
s
.4378 .66234 m .44116 .63526 L .44062 .63709 L p 0 0 .154 r
F P
0 g
s
.44062 .63709 m .43608 .66467 L .4378 .66234 L p 0 0 .154 r
F P
0 g
s
.59971 .80693 m .58497 .84394 L .58801 .84194 L p .094 0 .17 r
F P
0 g
s
.58801 .84194 m .60343 .80409 L .59971 .80693 L p .094 0 .17 r
F P
0 g
s
.68245 .63533 m .65243 .64523 L .65445 .64264 L p .548 .917 .946 r
F P
0 g
s
.65243 .64523 m .63631 .65876 L .63673 .65639 L p .603 .931 .716 r
F P
0 g
s
.8254 .52828 m .81019 .56242 L .81448 .55056 L p .76 .833 .373 r
F P
0 g
s
.81448 .55056 m .82998 .51443 L .8254 .52828 L p .76 .833 .373 r
F P
0 g
s
.62576 .7369 m .62082 .78291 L .62201 .77993 L p 0 0 .17 r
F P
0 g
s
.62201 .77993 m .62725 .73396 L .62576 .7369 L p 0 0 .17 r
F P
0 g
s
.76725 .43252 m .79643 .44901 L .7772 .44289 L p .515 0 0 r
F P
0 g
s
.7772 .44289 m .7501 .42789 L .76725 .43252 L p .515 0 0 r
F P
0 g
s
.42708 .71385 m .43129 .67386 L .42968 .6778 L p 0 0 .139 r
F P
0 g
s
.42968 .6778 m .42575 .7176 L .42708 .71385 L p 0 0 .139 r
F P
0 g
s
.43066 .78272 m .42521 .74786 L p .42465 .74344 L .834 .559 .012 r
F P
0 g
s
.42465 .74344 m .43179 .78623 L .43066 .78272 L p .834 .559 .012 r
F P
0 g
s
.42383 .73902 m .43066 .78272 L .42992 .77917 L p .749 .513 0 r
F P
0 g
s
.42347 .73456 m .42917 .77395 L p .42958 .7756 L 0 0 .142 r
F P
0 g
s
.42917 .77395 m .42992 .77917 L .42986 .77851 L p 0 0 .142 r
F P
0 g
s
.42986 .77851 m .42958 .7756 L p .42917 .77395 L 0 0 .142 r
F P
0 g
s
.42521 .74786 m .42383 .73902 L .42406 .74024 L p .834 .559 .012 r
F P
0 g
s
.42406 .74024 m .42465 .74344 L p .42521 .74786 L .834 .559 .012 r
F P
0 g
s
.4632 .84127 m .44687 .80446 L .45067 .80682 L p .878 .448 .163 r
F P
0 g
s
.45067 .80682 m .46615 .84321 L .4632 .84127 L p .878 .448 .163 r
F P
0 g
s
.72341 .62238 m .68245 .63533 L .68646 .63168 L p .597 .923 .968 r
F P
0 g
s
.65445 .64264 m .68646 .63168 L .68245 .63533 L p .548 .917 .946 r
F P
0 g
s
.60343 .80409 m .58801 .84194 L .59081 .83984 L p .015 0 .13 r
F P
0 g
s
.59081 .83984 m .60685 .80114 L .60343 .80409 L p .015 0 .13 r
F P
0 g
s
.3546 .38688 m .38433 .39325 L .37854 .40663 L p .826 .902 .893 r
F P
0 g
s
.37854 .40663 m .34801 .40207 L .3546 .38688 L p .826 .902 .893 r
F P
0 g
s
.63631 .65876 m .63096 .68191 L .63023 .67926 L p .743 .755 .245 r
F P
0 g
s
.32631 .49098 m .33215 .46753 L .34042 .48458 L p .996 .784 .498 r
F P
0 g
s
.34042 .48458 m .33502 .50622 L .32631 .49098 L p .996 .784 .498 r
F P
0 g
s
.52907 .4375 m .52958 .43167 L .51628 .41738 L p 0 .146 .672 r
F P
0 g
s
.51794 .42436 m .52907 .4375 L p .51766 .41956 L 0 .146 .672 r
F P
0 g
s
.52995 .43721 m .51509 .42316 L p .52779 .43062 L .79 .317 0 r
F P
0 g
s
.52958 .43167 m .52965 .43265 L p .52779 .43062 L .79 .317 0 r
F P
0 g
s
.52965 .43265 m .52995 .43721 L p .52779 .43062 L .79 .317 0 r
F P
0 g
s
.51628 .41738 m .51649 .41828 L p .51766 .41956 L 0 .146 .672 r
F P
0 g
s
.51649 .41828 m .51794 .42436 L p .51766 .41956 L 0 .146 .672 r
F P
0 g
s
.34521 .5336 m .33502 .50622 L .34476 .51986 L p .913 .532 .107 r
F P
0 g
s
.34476 .51986 m .35442 .54439 L .34521 .5336 L p .913 .532 .107 r
F P
0 g
s
.58282 .47336 m .5772 .46784 L .58867 .46569 L p .376 0 0 r
F P
0 g
s
.5772 .46784 m .58282 .47336 L .57206 .47219 L p .465 0 0 r
F P
0 g
s
.57206 .47219 m .56752 .4669 L .5772 .46784 L p .465 0 0 r
F P
0 g
s
.42867 .71036 m .43288 .67038 L .43129 .67386 L p 0 0 .181 r
F P
0 g
s
.43129 .67386 m .42708 .71385 L .42867 .71036 L p 0 0 .181 r
F P
0 g
s
.43971 .66026 m .44167 .63369 L .44116 .63526 L p 0 0 .225 r
F P
0 g
s
.44116 .63526 m .4378 .66234 L .43971 .66026 L p 0 0 .225 r
F P
0 g
s
.4605 .83922 m .44342 .80188 L .44687 .80446 L p .879 .442 .111 r
F P
0 g
s
.44687 .80446 m .4632 .84127 L .4605 .83922 L p .879 .442 .111 r
F P
0 g
s
.42992 .77917 m .42347 .73456 L .42383 .73902 L p .749 .513 0 r
F P
0 g
s
.5956 .47159 m .58867 .46569 L .60253 .46094 L p .348 0 .088 r
F P
0 g
s
.58867 .46569 m .5956 .47159 L .58282 .47336 L p .376 0 0 r
F P
0 g
s
.6233 .77402 m .62937 .72839 L .62847 .73114 L p 0 0 .028 r
F P
0 g
s
.62201 .77993 m .62284 .77697 L p .62442 .76157 L 0 0 .107 r
F P
0 g
s
.62284 .77697 m .62847 .73114 L .62725 .73396 L p 0 0 .107 r
F P
0 g
s
.62284 .77697 m .6233 .77402 L p .62625 .74959 L 0 0 .028 r
F P
0 g
s
.62847 .73114 m .6263 .74882 L p .62625 .74959 L 0 0 .028 r
F P
0 g
s
.6263 .74882 m .62284 .77697 L p .62625 .74959 L 0 0 .028 r
F P
0 g
s
.62937 .72839 m .62832 .73633 L p .62769 .74038 L 0 0 0 r
F P
0 g
s
.62832 .73633 m .6233 .77402 L p .62769 .74038 L 0 0 0 r
F P
0 g
s
.6233 .77402 m .62338 .77109 L p .62769 .74038 L 0 0 0 r
F P
0 g
s
.62611 .75163 m .62922 .73046 L .62769 .74038 L 0 0 0 r
F
.62338 .77109 m .62606 .75249 L p .62611 .75163 L F P
0 g
s
.62606 .75249 m .62922 .73046 L p .62611 .75163 L 0 0 0 r
F P
0 g
s
.62991 .72567 m .62937 .72839 L p .62769 .74038 L 0 0 0 r
F P
0 g
s
.62922 .73046 m .62991 .72567 L p .62769 .74038 L 0 0 0 r
F P
0 g
s
.62725 .73396 m .62321 .76942 L p .62442 .76157 L 0 0 .107 r
F P
0 g
s
.62321 .76942 m .62201 .77993 L p .62442 .76157 L 0 0 .107 r
F P
0 g
s
.7666 .60193 m .72341 .62238 L .7296 .61672 L p .666 .966 .925 r
F P
0 g
s
.7296 .61672 m .77484 .59352 L .7666 .60193 L p .666 .966 .925 r
F P
0 g
s
.68646 .63168 m .7296 .61672 L .72341 .62238 L p .597 .923 .968 r
F P
0 g
s
.56752 .4669 m .57206 .47219 L .56241 .46782 L p .572 0 0 r
F P
0 g
s
.56241 .46782 m .55881 .46261 L .56752 .4669 L p .572 0 0 r
F P
0 g
s
.60685 .80114 m .59081 .83984 L .59335 .83767 L p 0 0 .084 r
F P
0 g
s
.59335 .83767 m .60997 .79813 L .60685 .80114 L p 0 0 .084 r
F P
0 g
s
.81863 .46987 m .82819 .50119 L .81987 .48931 L p .897 .518 .067 r
F P
0 g
s
.81987 .48931 m .81051 .45817 L .81863 .46987 L p .897 .518 .067 r
F P
0 g
s
.61109 .4674 m .60253 .46094 L .61912 .45434 L p .359 0 .155 r
F P
0 g
s
.60253 .46094 m .61109 .4674 L .5956 .47159 L p .348 0 .088 r
F P
0 g
s
.68646 .63168 m .65445 .64264 L .65459 .63931 L p .658 .902 .981 r
F P
0 g
s
.65445 .64264 m .63673 .65639 L .63592 .65349 L p .798 .986 .892 r
F P
0 g
s
.63592 .65349 m .65459 .63931 L .65445 .64264 L p .798 .986 .892 r
F P
0 g
s
.7501 .42789 m .7772 .44289 L .75402 .44002 L p .55 .024 0 r
F P
0 g
s
.75402 .44002 m .72951 .42657 L .7501 .42789 L p .55 .024 0 r
F P
0 g
s
.45807 .83707 m .44032 .79909 L .44342 .80188 L p .871 .432 .05 r
F P
0 g
s
.44342 .80188 m .4605 .83922 L .45807 .83707 L p .871 .432 .05 r
F P
0 g
s
.43052 .70711 m .43447 .66733 L .43288 .67038 L p 0 0 .226 r
F P
0 g
s
.43288 .67038 m .42867 .71036 L .43052 .70711 L p 0 0 .226 r
F P
0 g
s
.42958 .7756 m .42352 .73012 L .42347 .73456 L p 0 0 .142 r
F P
0 g
s
.60997 .79813 m .59335 .83767 L .59564 .83543 L p 0 0 .033 r
F P
0 g
s
.59564 .83543 m .61278 .79508 L .60997 .79813 L p 0 0 .033 r
F P
0 g
s
.55881 .46261 m .56241 .46782 L .55284 .46027 L p .644 .121 0 r
F P
0 g
s
.55284 .46027 m .55016 .45504 L .55881 .46261 L p .644 .121 0 r
F P
0 g
s
.41992 .60059 m .39527 .58359 L .40104 .5881 L p 0 .176 .607 r
F P
0 g
s
.37549 .5684 m .40104 .5881 L .39527 .58359 L p 0 .111 .568 r
F P
0 g
s
.32395 .43106 m .34578 .41926 L .34751 .4374 L p .949 .903 .744 r
F P
0 g
s
.34751 .4374 m .32627 .44941 L .32395 .43106 L p .949 .903 .744 r
F P
0 g
s
.63095 .68429 m .6297 .72015 L .62885 .71727 L p .743 .634 .072 r
F P
0 g
s
.63673 .65639 m .63023 .67926 L .6287 .67629 L p .961 .886 .498 r
F P
0 g
s
.62968 .46155 m .61912 .45434 L .63841 .4468 L p .387 .007 .19 r
F P
0 g
s
.61912 .45434 m .62968 .46155 L .61109 .4674 L p .359 0 .155 r
F P
0 g
s
.44192 .65837 m .44237 .63228 L .44167 .63369 L p 0 0 .306 r
F P
0 g
s
.44167 .63369 m .43971 .66026 L .44192 .65837 L p 0 0 .306 r
F P
0 g
s
.51794 .42436 m .51628 .41738 L .5005 .4027 L p 0 .142 .654 r
F P
0 g
s
.50483 .41085 m .51794 .42436 L p .50232 .40496 L 0 .142 .654 r
F P
0 g
s
.51509 .42316 m .49739 .40877 L p .51398 .41633 L .805 .321 0 r
F P
0 g
s
.51628 .41738 m .51607 .41838 L p .51398 .41633 L .805 .321 0 r
F P
0 g
s
.51607 .41838 m .51509 .42316 L p .51398 .41633 L .805 .321 0 r
F P
0 g
s
.5005 .4027 m .50104 .4037 L p .50232 .40496 L 0 .142 .654 r
F P
0 g
s
.50104 .4037 m .50483 .41085 L p .50232 .40496 L 0 .142 .654 r
F P
0 g
s
.45591 .83482 m .4376 .79611 L .44032 .79909 L p .85 .413 0 r
F P
0 g
s
.44032 .79909 m .45807 .83707 L .45591 .83482 L p .85 .413 0 r
F P
0 g
s
.7296 .61672 m .68646 .63168 L .68768 .62712 L p .678 .895 .975 r
F P
0 g
s
.65459 .63931 m .68768 .62712 L .68646 .63168 L p .658 .902 .981 r
F P
0 g
s
.36559 .37469 m .39364 .38269 L .38433 .39325 L p .77 .921 .937 r
F P
0 g
s
.38433 .39325 m .3546 .38688 L .36559 .37469 L p .77 .921 .937 r
F P
0 g
s
.3677 .56092 m .34521 .5336 L .35442 .54439 L p .637 .144 0 r
F P
0 g
s
.35442 .54439 m .37549 .5684 L .3677 .56092 L p .637 .144 0 r
F P
0 g
s
.42962 .77206 m .42394 .72578 L .42352 .73012 L p 0 0 .212 r
F P
0 g
s
.42352 .73012 m .42958 .7756 L .42962 .77206 L p 0 0 .212 r
F P
0 g
s
.61278 .79508 m .59564 .83543 L .59765 .83313 L p 0 0 0 r
F P
0 g
s
.59765 .83313 m .61527 .79202 L .61278 .79508 L p 0 0 0 r
F P
0 g
s
.43263 .70412 m .43608 .66467 L .43447 .66733 L p 0 0 .272 r
F P
0 g
s
.43447 .66733 m .43052 .70711 L .43263 .70412 L p 0 0 .272 r
F P
0 g
s
.65136 .45494 m .63841 .4468 L .66001 .43931 L p .422 .037 .201 r
F P
0 g
s
.63841 .4468 m .65136 .45494 L .62968 .46155 L p .387 .007 .19 r
F P
0 g
s
.72951 .42657 m .75402 .44002 L .72835 .44032 L p .53 .061 .087 r
F P
0 g
s
.72835 .44032 m .70674 .42838 L .72951 .42657 L p .53 .061 .087 r
F P
0 g
s
.39527 .58359 m .3677 .56092 L .37549 .5684 L p 0 .111 .568 r
F P
0 g
s
.81019 .56242 m .77484 .59352 L .77834 .5843 L p .847 .991 .849 r
F P
0 g
s
.77834 .5843 m .81448 .55056 L .81019 .56242 L p .847 .991 .849 r
F P
0 g
s
.52296 .87314 m .52034 .85723 L .52515 .85741 L p .525 .026 .013 r
F P
0 g
s
.52515 .85741 m .52569 .87321 L .52296 .87314 L p .525 .026 .013 r
F P
0 g
s
.52569 .87321 m .52515 .85741 L .52997 .85745 L p .501 .006 .012 r
F P
0 g
s
.52997 .85745 m .52841 .87319 L .52569 .87321 L p .501 .006 .012 r
F P
0 g
s
.52841 .87319 m .52997 .85745 L .53477 .85735 L p .475 0 .008 r
F P
0 g
s
.52025 .87299 m .51555 .8569 L .52034 .85723 L p .547 .044 .011 r
F P
0 g
s
.52034 .85723 m .52296 .87314 L .52025 .87299 L p .547 .044 .011 r
F P
0 g
s
.39527 .58359 m .41992 .60059 L .41703 .59782 L p 0 .252 .696 r
F P
0 g
s
.53477 .85735 m .53113 .87309 L .52841 .87319 L p .475 0 .008 r
F P
0 g
s
.53113 .87309 m .53477 .85735 L .53955 .85709 L p .446 0 0 r
F P
0 g
s
.54232 .44987 m .54068 .44452 L .55016 .45504 L p .702 .219 0 r
F P
0 g
s
.68768 .62712 m .65459 .63931 L .65267 .63529 L p .695 .841 .953 r
F P
0 g
s
.65459 .63931 m .63592 .65349 L .63381 .65008 L p .825 .898 .893 r
F P
0 g
s
.63381 .65008 m .65267 .63529 L .65459 .63931 L p .825 .898 .893 r
F P
0 g
s
.51756 .87275 m .51081 .85645 L .51555 .8569 L p .567 .058 .005 r
F P
0 g
s
.51555 .8569 m .52025 .87299 L .51756 .87275 L p .567 .058 .005 r
F P
0 g
s
.63096 .68191 m .62885 .71727 L .62747 .71428 L p .906 .742 .244 r
F P
0 g
s
.62747 .71428 m .63023 .67926 L .63096 .68191 L p .906 .742 .244 r
F P
0 g
s
.53955 .85709 m .53384 .87291 L .53113 .87309 L p .446 0 0 r
F P
0 g
s
.53384 .87291 m .53955 .85709 L .54428 .85668 L p .414 0 0 r
F P
0 g
s
.82998 .51443 m .81448 .55056 L .81272 .53879 L p .982 .911 .622 r
F P
0 g
s
.81272 .53879 m .82819 .50119 L .82998 .51443 L p .982 .911 .622 r
F P
0 g
s
.63592 .65349 m .6287 .67629 L .62633 .67303 L p .99 .853 .61 r
F P
0 g
s
.62633 .67303 m .63381 .65008 L .63592 .65349 L p .99 .853 .61 r
F P
0 g
s
.67567 .44856 m .66001 .43931 L .68315 .43287 L p .459 .058 .191 r
F P
0 g
s
.66001 .43931 m .67567 .44856 L .65136 .45494 L p .422 .037 .201 r
F P
0 g
s
.51491 .87243 m .50612 .85586 L .51081 .85645 L p .584 .071 0 r
F P
0 g
s
.51081 .85645 m .51756 .87275 L .51491 .87243 L p .584 .071 0 r
F P
0 g
s
.45404 .83248 m .43526 .79296 L .4376 .79611 L p .811 .385 0 r
F P
0 g
s
.4376 .79611 m .45591 .83482 L .45404 .83248 L p .811 .385 0 r
F P
0 g
s
.54428 .85668 m .53651 .87264 L .53384 .87291 L p .414 0 0 r
F P
0 g
s
.53651 .87264 m .54428 .85668 L .54895 .8561 L p .379 0 0 r
F P
0 g
s
.70674 .42838 m .72835 .44032 L .70174 .44339 L p .496 .068 .157 r
F P
0 g
s
.70174 .44339 m .68315 .43287 L .70674 .42838 L p .496 .068 .157 r
F P
0 g
s
.5123 .87203 m .50151 .85515 L .50612 .85586 L p .6 .08 0 r
F P
0 g
s
.50612 .85586 m .51491 .87243 L .5123 .87203 L p .6 .08 0 r
F P
0 g
s
.61527 .79202 m .59765 .83313 L .59939 .83079 L p 0 0 0 r
F P
0 g
s
.59939 .83079 m .61745 .78896 L .61527 .79202 L p 0 0 0 r
F P
0 g
s
.43003 .76856 m .4247 .72159 L .42394 .72578 L p 0 0 .274 r
F P
0 g
s
.42394 .72578 m .42962 .77206 L .43003 .76856 L p 0 0 .274 r
F P
0 g
s
.68315 .43287 m .70174 .44339 L .67567 .44856 L p .459 .058 .191 r
F P
0 g
s
.54895 .8561 m .53914 .87228 L .53651 .87264 L p .379 0 0 r
F P
0 g
s
.53914 .87228 m .54895 .8561 L .55353 .85536 L p .341 0 0 r
F P
0 g
s
.44452 .65659 m .44351 .63089 L .44237 .63228 L p .037 0 .39 r
F P
0 g
s
.44237 .63228 m .44192 .65837 L .44452 .65659 L p .037 0 .39 r
F P
0 g
s
.50975 .87155 m .49699 .85432 L .50151 .85515 L p .613 .086 0 r
F P
0 g
s
.50151 .85515 m .5123 .87203 L .50975 .87155 L p .613 .086 0 r
F P
0 g
s
.43505 .70135 m .4378 .66234 L .43608 .66467 L p 0 0 .318 r
F P
0 g
s
.43608 .66467 m .43263 .70412 L .43505 .70135 L p 0 0 .318 r
F P
0 g
s
.50483 .41085 m .5005 .4027 L .48231 .3888 L p 0 .181 .663 r
F P
0 g
s
.4898 .39802 m .50483 .41085 L p .48445 .39089 L 0 .181 .663 r
F P
0 g
s
.49739 .40877 m .47692 .39523 L p .49781 .40185 L .794 .298 0 r
F P
0 g
s
.5005 .4027 m .50001 .40365 L p .49781 .40185 L .794 .298 0 r
F P
0 g
s
.50001 .40365 m .49739 .40877 L p .49781 .40185 L .794 .298 0 r
F P
0 g
s
.48231 .3888 m .48314 .38982 L p .48445 .39089 L 0 .181 .663 r
F P
0 g
s
.48314 .38982 m .4898 .39802 L p .48445 .39089 L 0 .181 .663 r
F P
0 g
s
.55353 .85536 m .54172 .87185 L .53914 .87228 L p .341 0 0 r
F P
0 g
s
.54172 .87185 m .55353 .85536 L .55801 .85446 L p .298 0 0 r
F P
0 g
s
.77484 .59352 m .7296 .61672 L .732 .61011 L p .753 .935 .946 r
F P
0 g
s
.68768 .62712 m .732 .61011 L .7296 .61672 L p .678 .895 .975 r
F P
0 g
s
.50726 .87099 m .49258 .85336 L .49699 .85432 L p .624 .089 0 r
F P
0 g
s
.49699 .85432 m .50975 .87155 L .50726 .87099 L p .624 .089 0 r
F P
0 g
s
.55801 .85446 m .54425 .87133 L .54172 .87185 L p .298 0 0 r
F P
0 g
s
.54425 .87133 m .55801 .85446 L .56236 .8534 L p .251 0 0 r
F P
0 g
s
.32004 .47462 m .32627 .44941 L .33215 .46753 L p .998 .811 .463 r
F P
0 g
s
.33215 .46753 m .32631 .49098 L .32004 .47462 L p .998 .811 .463 r
F P
0 g
s
.81051 .45817 m .81987 .48931 L .80533 .47948 L p .897 .52 .311 r
F P
0 g
s
.80533 .47948 m .79643 .44901 L .81051 .45817 L p .897 .52 .311 r
F P
0 g
s
.45246 .83006 m .43333 .78965 L .43526 .79296 L p .751 .345 0 r
F P
0 g
s
.43526 .79296 m .45404 .83248 L .45246 .83006 L p .751 .345 0 r
F P
0 g
s
.56786 .57596 m .56373 .5913 L .55736 .58982 L p .665 .536 .697 r
F P
0 g
s
.55736 .58982 m .56049 .57472 L .56786 .57596 L p .665 .536 .697 r
F P
0 g
s
.55752 .60771 m .55736 .58982 L .56373 .5913 L p .705 .449 .534 r
F P
0 g
s
.56049 .57472 m .55736 .58982 L .55154 .58873 L p .736 .605 .71 r
F P
0 g
s
.55736 .58982 m .55752 .60771 L .55172 .60659 L p .751 .484 .528 r
F P
0 g
s
.55172 .60659 m .55154 .58873 L .55736 .58982 L p .751 .484 .528 r
F P
0 g
s
.57576 .55816 m .56786 .57596 L .56049 .57472 L p .642 .598 .79 r
F P
0 g
s
.56049 .57472 m .56675 .55731 L .57576 .55816 L p .642 .598 .79 r
F P
0 g
s
.56675 .55731 m .56049 .57472 L .55403 .57359 L p .708 .672 .813 r
F P
0 g
s
.55154 .58873 m .55403 .57359 L .56049 .57472 L p .736 .605 .71 r
F P
0 g
s
.50485 .87036 m .4883 .85228 L .49258 .85336 L p .632 .089 0 r
F P
0 g
s
.49258 .85336 m .50726 .87099 L .50485 .87036 L p .632 .089 0 r
F P
0 g
s
.62991 .72567 m .62338 .77109 L .62307 .76815 L p .78 .711 .174 r
F P
0 g
s
.62307 .76815 m .63003 .72294 L .62991 .72567 L p .78 .711 .174 r
F P
0 g
s
.33698 .52148 m .32631 .49098 L .33502 .50622 L p .875 .506 .02 r
F P
0 g
s
.33502 .50622 m .34521 .5336 L .33698 .52148 L p .875 .506 .02 r
F P
0 g
s
.57647 .57743 m .57083 .59321 L .56373 .5913 L p .619 .496 .691 r
F P
0 g
s
.56373 .5913 m .56786 .57596 L .57647 .57743 L p .619 .496 .691 r
F P
0 g
s
.56357 .60931 m .56373 .5913 L .57083 .59321 L p .673 .431 .547 r
F P
0 g
s
.56373 .5913 m .56357 .60931 L .55752 .60771 L p .705 .449 .534 r
F P
0 g
s
.732 .61011 m .77834 .5843 L .77484 .59352 L p .753 .935 .946 r
F P
0 g
s
.61745 .78896 m .59939 .83079 L .60083 .82841 L p 0 0 0 r
F P
0 g
s
.60083 .82841 m .6193 .78593 L .61745 .78896 L p 0 0 0 r
F P
0 g
s
.44529 .62946 m .43544 .61159 L .4353 .61336 L p 0 .133 .66 r
F P
0 g
s
.4353 .61336 m .44351 .63089 L .44529 .62946 L p 0 .133 .66 r
F P
0 g
s
.41703 .59782 m .4353 .61336 L .43544 .61159 L p 0 .322 .794 r
F P
0 g
s
.38059 .36633 m .40613 .37564 L .39364 .38269 L p .673 .916 .975 r
F P
0 g
s
.39364 .38269 m .36559 .37469 L .38059 .36633 L p .673 .916 .975 r
F P
0 g
s
.63023 .67926 m .62747 .71428 L .62551 .71117 L p .985 .78 .38 r
F P
0 g
s
.62551 .71117 m .6287 .67629 L .63023 .67926 L p .985 .78 .38 r
F P
0 g
s
.55403 .57359 m .55907 .5561 L .56675 .55731 L p .708 .672 .813 r
F P
0 g
s
.55907 .5561 m .55403 .57359 L .54806 .57249 L p .783 .752 .825 r
F P
0 g
s
.55403 .57359 m .55154 .58873 L .546 .58797 L p .815 .686 .722 r
F P
0 g
s
.546 .58797 m .54806 .57249 L .55403 .57359 L p .815 .686 .722 r
F P
0 g
s
.55154 .58873 m .55172 .60659 L .54602 .60593 L p .802 .533 .531 r
F P
0 g
s
.54602 .60593 m .546 .58797 L .55154 .58873 L p .802 .533 .531 r
F P
0 g
s
.56236 .8534 m .5467 .87073 L .54907 .87006 L p .197 0 0 r
F P
0 g
s
.54907 .87006 m .56658 .85218 L .56236 .8534 L p .197 0 0 r
F P
0 g
s
.56236 .8534 m .5467 .87073 L .54425 .87133 L p .251 0 0 r
F P
0 g
s
.43081 .76515 m .42575 .7176 L .4247 .72159 L p 0 0 .328 r
F P
0 g
s
.4247 .72159 m .43003 .76856 L .43081 .76515 L p 0 0 .328 r
F P
0 g
s
.65267 .63529 m .63381 .65008 L .63039 .64623 L p .803 .802 .851 r
F P
0 g
s
.63381 .65008 m .62633 .67303 L .62313 .6695 L p .947 .775 .637 r
F P
0 g
s
.62313 .6695 m .63039 .64623 L .63381 .65008 L p .947 .775 .637 r
F P
0 g
s
.58654 .55886 m .57647 .57743 L .56786 .57596 L p .601 .551 .77 r
F P
0 g
s
.56786 .57596 m .57576 .55816 L .58654 .55886 L p .601 .551 .77 r
F P
0 g
s
.50252 .86965 m .48416 .85108 L .4883 .85228 L p .636 .086 0 r
F P
0 g
s
.4883 .85228 m .50485 .87036 L .50252 .86965 L p .636 .086 0 r
F P
0 g
s
.65267 .63529 m .68587 .62181 L .68768 .62712 L p .695 .841 .953 r
F P
0 g
s
.68587 .62181 m .65267 .63529 L .64871 .63071 L p .699 .778 .912 r
F P
0 g
s
.63039 .64623 m .64871 .63071 L .65267 .63529 L p .803 .802 .851 r
F P
0 g
s
.732 .61011 m .68768 .62712 L .68587 .62181 L p .705 .838 .946 r
F P
0 g
s
.5865 .57929 m .57878 .59563 L .57083 .59321 L p .597 .482 .694 r
F P
0 g
s
.57083 .59321 m .57647 .57743 L .5865 .57929 L p .597 .482 .694 r
F P
0 g
s
.56996 .6114 m .57083 .59321 L .57878 .59563 L p .655 .43 .566 r
F P
0 g
s
.57083 .59321 m .56996 .6114 L .56357 .60931 L p .673 .431 .547 r
F P
0 g
s
.43778 .69878 m .43971 .66026 L .4378 .66234 L p .053 0 .363 r
F P
0 g
s
.4378 .66234 m .43505 .70135 L .43778 .69878 L p .053 0 .363 r
F P
0 g
s
.41703 .59782 m .39024 .57845 L .39527 .58359 L p 0 .252 .696 r
F P
0 g
s
.3677 .56092 m .39527 .58359 L .39024 .57845 L p 0 .178 .656 r
F P
0 g
s
.56658 .85218 m .54907 .87006 L .55135 .86931 L p .134 0 0 r
F P
0 g
s
.55135 .86931 m .57063 .85081 L .56658 .85218 L p .134 0 0 r
F P
0 g
s
.52995 .43721 m .52958 .43167 L .54068 .44452 L p .754 .283 0 r
F P
0 g
s
.54806 .57249 m .546 .58797 L .54044 .5875 L p .874 .754 .727 r
F P
0 g
s
.546 .58797 m .54602 .60593 L .54028 .6057 L p .845 .584 .544 r
F P
0 g
s
.54028 .6057 m .54044 .5875 L .546 .58797 L p .845 .584 .544 r
F P
0 g
s
.50029 .86887 m .48017 .84975 L .48416 .85108 L p .635 .078 0 r
F P
0 g
s
.48416 .85108 m .50252 .86965 L .50029 .86887 L p .635 .078 0 r
F P
0 g
s
.3261 .41347 m .34801 .40207 L .34578 .41926 L p .933 .954 .77 r
F P
0 g
s
.34578 .41926 m .32395 .43106 L .3261 .41347 L p .933 .954 .77 r
F P
0 g
s
.54806 .57249 m .55211 .55438 L .55907 .5561 L p .783 .752 .825 r
F P
0 g
s
.55211 .55438 m .54806 .57249 L .54211 .57136 L p .842 .811 .82 r
F P
0 g
s
.54044 .5875 m .54211 .57136 L .54806 .57249 L p .874 .754 .727 r
F P
0 g
s
.43333 .78965 m .45246 .83006 L .45118 .82759 L p .67 .294 0 r
F P
0 g
s
.45118 .82759 m .43179 .78623 L .43333 .78965 L p .67 .294 0 r
F P
0 g
s
.58434 .4886 m .58282 .47336 L .5956 .47159 L p .623 .337 .462 r
F P
0 g
s
.58282 .47336 m .58434 .4886 L .57329 .48727 L p .726 .413 .448 r
F P
0 g
s
.57329 .48727 m .57206 .47219 L .58282 .47336 L p .726 .413 .448 r
F P
0 g
s
.59936 .55969 m .5865 .57929 L .57647 .57743 L p .584 .529 .76 r
F P
0 g
s
.57647 .57743 m .58654 .55886 L .59936 .55969 L p .584 .529 .76 r
F P
0 g
s
.4898 .39802 m .48231 .3888 L .46216 .37687 L p 0 .266 .704 r
F P
0 g
s
.47321 .38693 m .4898 .39802 L p .46441 .3786 L 0 .266 .704 r
F P
0 g
s
.47692 .39523 m .45419 .38372 L p .47947 .38829 L .757 .245 0 r
F P
0 g
s
.48231 .3888 m .4816 .38966 L p .47947 .38829 L .757 .245 0 r
F P
0 g
s
.4816 .38966 m .47692 .39523 L p .47947 .38829 L .757 .245 0 r
F P
0 g
s
.46216 .37687 m .46319 .3778 L p .46441 .3786 L 0 .266 .704 r
F P
0 g
s
.46319 .3778 m .47321 .38693 L p .46441 .3786 L 0 .266 .704 r
F P
0 g
s
.44763 .65485 m .44529 .62946 L .44351 .63089 L p .151 .042 .466 r
F P
0 g
s
.44351 .63089 m .44452 .65659 L .44763 .65485 L p .151 .042 .466 r
F P
0 g
s
.57063 .85081 m .55135 .86931 L .55353 .86848 L p .065 0 0 r
F P
0 g
s
.55353 .86848 m .57451 .84928 L .57063 .85081 L p .065 0 0 r
F P
0 g
s
.59792 .58168 m .58756 .59858 L .57878 .59563 L p .592 .488 .704 r
F P
0 g
s
.57878 .59563 m .5865 .57929 L .59792 .58168 L p .592 .488 .704 r
F P
0 g
s
.57674 .61399 m .57878 .59563 L .58756 .59858 L p .65 .443 .589 r
F P
0 g
s
.57878 .59563 m .57674 .61399 L .56996 .6114 L p .655 .43 .566 r
F P
0 g
s
.6193 .78593 m .60083 .82841 L .60138 .82729 L p 0 0 0 r
F P
0 g
s
.60624 .81616 m .6193 .78593 L .60138 .82729 L 0 0 0 r
F
.60199 .82601 m .62082 .78291 L .6193 .78593 L p F P
0 g
s
.60284 .82359 m .62201 .77993 L .62118 .78201 L p .686 .786 .313 r
F P
0 g
s
.62118 .78201 m .62082 .78291 L p .61724 .79102 L .686 .786 .313 r
F P
0 g
s
.60284 .82359 m .62118 .78201 L .61724 .79102 L .686 .786 .313 r
F
.60138 .82729 m .60199 .82601 L p .60624 .81616 L 0 0 0 r
F P
0 g
s
.59748 .48746 m .5956 .47159 L .61109 .4674 L p .567 .298 .468 r
F P
0 g
s
.5956 .47159 m .59748 .48746 L .58434 .4886 L p .623 .337 .462 r
F P
0 g
s
.43195 .76184 m .42708 .71385 L .42575 .7176 L p 0 0 .374 r
F P
0 g
s
.42575 .7176 m .43081 .76515 L .43195 .76184 L p 0 0 .374 r
F P
0 g
s
.57206 .47219 m .57329 .48727 L .56339 .48322 L p .843 .508 .418 r
F P
0 g
s
.56339 .48322 m .56241 .46782 L .57206 .47219 L p .843 .508 .418 r
F P
0 g
s
.63003 .72294 m .62307 .76815 L .62234 .76521 L p .887 .777 .282 r
F P
0 g
s
.62234 .76521 m .6297 .72015 L .63003 .72294 L p .887 .777 .282 r
F P
0 g
s
.49816 .86802 m .47636 .8483 L .48017 .84975 L p .63 .067 0 r
F P
0 g
s
.48017 .84975 m .50029 .86887 L .49816 .86802 L p .63 .067 0 r
F P
0 g
s
.64871 .63071 m .63039 .64623 L .62575 .64204 L p .773 .724 .807 r
F P
0 g
s
.63039 .64623 m .62313 .6695 L .61915 .66576 L p .896 .703 .633 r
F P
0 g
s
.61915 .66576 m .62575 .64204 L .63039 .64623 L p .896 .703 .633 r
F P
0 g
s
.6287 .67629 m .62551 .71117 L .62298 .70793 L p .995 .765 .464 r
F P
0 g
s
.62298 .70793 m .62633 .67303 L .6287 .67629 L p .995 .765 .464 r
F P
0 g
s
.57451 .84928 m .55353 .86848 L .55561 .86759 L p 0 0 0 r
F P
0 g
s
.55561 .86759 m .57821 .84763 L .57451 .84928 L p 0 0 0 r
F P
0 g
s
.43544 .61159 m .41539 .59466 L .41703 .59782 L p 0 .322 .794 r
F P
0 g
s
.39024 .57845 m .41703 .59782 L .41539 .59466 L p 0 .366 .809 r
F P
0 g
s
.54211 .57136 m .54044 .5875 L .53458 .58731 L p .903 .795 .73 r
F P
0 g
s
.54044 .5875 m .54028 .6057 L .53434 .60587 L p .874 .629 .565 r
F P
0 g
s
.53434 .60587 m .53458 .58731 L .54044 .5875 L p .874 .629 .565 r
F P
0 g
s
.38059 .36633 m .40613 .37564 L .4212 .37255 L p .512 .864 .99 r
F P
0 g
s
.64871 .63071 m .68097 .61599 L .68587 .62181 L p .699 .778 .912 r
F P
0 g
s
.68097 .61599 m .64871 .63071 L .64282 .62577 L p .69 .721 .873 r
F P
0 g
s
.62575 .64204 m .64282 .62577 L .64871 .63071 L p .773 .724 .807 r
F P
0 g
s
.61055 .58472 m .59703 .60209 L .58756 .59858 L p .599 .505 .719 r
F P
0 g
s
.58756 .59858 m .59792 .58168 L .61055 .58472 L p .599 .505 .719 r
F P
0 g
s
.5839 .61707 m .58756 .59858 L .59703 .60209 L p .654 .464 .615 r
F P
0 g
s
.58756 .59858 m .5839 .61707 L .57674 .61399 L p .65 .443 .589 r
F P
0 g
s
.49614 .86711 m .47275 .84673 L .47636 .8483 L p .618 .05 0 r
F P
0 g
s
.47636 .8483 m .49816 .86802 L .49614 .86711 L p .618 .05 0 r
F P
0 g
s
.58538 .53577 m .57576 .55816 L .56675 .55731 L p .652 .606 .791 r
F P
0 g
s
.56675 .55731 m .5745 .53548 L .58538 .53577 L p .652 .606 .791 r
F P
0 g
s
.5745 .53548 m .56675 .55731 L .55907 .5561 L p .71 .672 .811 r
F P
0 g
s
.45021 .82506 m .43066 .78272 L .43179 .78623 L p 0 0 .357 r
F P
0 g
s
.43179 .78623 m .45118 .82759 L .45021 .82506 L p 0 0 .357 r
F P
0 g
s
.44087 .69638 m .44192 .65837 L .43971 .66026 L p .135 0 .405 r
F P
0 g
s
.43971 .66026 m .43778 .69878 L .44087 .69638 L p .135 0 .405 r
F P
0 g
s
.61344 .48434 m .61109 .4674 L .62968 .46155 L p .55 .289 .473 r
F P
0 g
s
.61109 .4674 m .61344 .48434 L .59748 .48746 L p .567 .298 .468 r
F P
0 g
s
.61422 .56093 m .59792 .58168 L .5865 .57929 L p .584 .527 .757 r
F P
0 g
s
.5865 .57929 m .59936 .55969 L .61422 .56093 L p .584 .527 .757 r
F P
0 g
s
.55907 .5561 m .56533 .53417 L .5745 .53548 L p .71 .672 .811 r
F P
0 g
s
.56533 .53417 m .55907 .5561 L .55211 .55438 L p .779 .743 .82 r
F P
0 g
s
.54211 .57136 m .54519 .55211 L .55211 .55438 L p .842 .811 .82 r
F P
0 g
s
.54519 .55211 m .54211 .57136 L .5357 .57022 L p .874 .84 .809 r
F P
0 g
s
.53458 .58731 m .5357 .57022 L .54211 .57136 L p .903 .795 .73 r
F P
0 g
s
.57821 .84763 m .55561 .86759 L .55757 .86664 L p 0 0 0 r
F P
0 g
s
.55757 .86664 m .5817 .84584 L .57821 .84763 L p 0 0 0 r
F P
0 g
s
.62082 .78291 m .60199 .82601 L .60284 .82359 L p .686 .786 .313 r
F P
0 g
s
.47321 .38693 m .46216 .37687 L .4408 .36796 L p 0 .398 .778 r
F P
0 g
s
.45568 .37853 m .47321 .38693 L p .44294 .36921 L 0 .398 .778 r
F P
0 g
s
.44189 .36874 m .45568 .37853 L p .44294 .36921 L 0 .398 .778 r
F P
0 g
s
.45568 .37853 m .4408 .36796 L .4193 .36294 L p .05 .568 .873 r
F P
0 g
s
.43803 .37357 m .45568 .37853 L p .42106 .36369 L .05 .568 .873 r
F P
0 g
s
.4193 .36294 m .42028 .3635 L p .42106 .36369 L .05 .568 .873 r
F P
0 g
s
.42028 .3635 m .43803 .37357 L p .42106 .36369 L .05 .568 .873 r
F P
0 g
s
.39883 .36234 m .4212 .37255 L .43803 .37357 L p .286 .74 .956 r
F P
0 g
s
.4212 .37255 m .39883 .36234 L .38059 .36633 L p .512 .864 .99 r
F P
0 g
s
.43803 .37357 m .4193 .36294 L .39883 .36234 L p .286 .74 .956 r
F P
0 g
s
.43008 .37532 m .40579 .37091 L p .43858 .36815 L .57 .021 0 r
F P
0 g
s
.4408 .36796 m .44 .36851 L p .43858 .36815 L .57 .021 0 r
F P
0 g
s
.44 .36851 m .43008 .37532 L p .43858 .36815 L .57 .021 0 r
F P
0 g
s
.45419 .38372 m .43008 .37532 L p .45946 .37674 L .687 .157 0 r
F P
0 g
s
.46216 .37687 m .46132 .37758 L p .45946 .37674 L .687 .157 0 r
F P
0 g
s
.46132 .37758 m .45419 .38372 L p .45946 .37674 L .687 .157 0 r
F P
0 g
s
.4408 .36796 m .44189 .36874 L p .44294 .36921 L 0 .398 .778 r
F P
0 g
s
.39024 .57845 m .36077 .55246 L .3677 .56092 L p 0 .178 .656 r
F P
0 g
s
.34521 .5336 m .3677 .56092 L .36077 .55246 L p 0 0 .453 r
F P
0 g
s
.36077 .55246 m .33698 .52148 L .34521 .5336 L p 0 0 .453 r
F P
0 g
s
.59854 .53536 m .58654 .55886 L .57576 .55816 L p .615 .561 .771 r
F P
0 g
s
.57576 .55816 m .58538 .53577 L .59854 .53536 L p .615 .561 .771 r
F P
0 g
s
.43344 .75864 m .42867 .71036 L .42708 .71385 L p 0 0 .412 r
F P
0 g
s
.42708 .71385 m .43195 .76184 L .43344 .75864 L p 0 0 .412 r
F P
0 g
s
.64282 .62577 m .62575 .64204 L .62005 .63764 L p .746 .661 .767 r
F P
0 g
s
.62575 .64204 m .61915 .66576 L .61447 .66187 L p .852 .643 .619 r
F P
0 g
s
.61447 .66187 m .62005 .63764 L .62575 .64204 L p .852 .643 .619 r
F P
0 g
s
.56241 .46782 m .56339 .48322 L .55357 .47645 L p .917 .577 .382 r
F P
0 g
s
.55357 .47645 m .55284 .46027 L .56241 .46782 L p .917 .577 .382 r
F P
0 g
s
.44791 .6279 m .43682 .60957 L .43544 .61159 L p .154 .292 .753 r
F P
0 g
s
.43544 .61159 m .44529 .62946 L .44791 .6279 L p .154 .292 .753 r
F P
0 g
s
.41539 .59466 m .43544 .61159 L .43682 .60957 L p .094 .458 .886 r
F P
0 g
s
.49425 .86613 m .46934 .84503 L .47275 .84673 L p .597 .029 0 r
F P
0 g
s
.47275 .84673 m .49614 .86711 L .49425 .86613 L p .597 .029 0 r
F P
0 g
s
.79643 .44901 m .80533 .47948 L .78541 .47224 L p .816 .471 .405 r
F P
0 g
s
.78541 .47224 m .7772 .44289 L .79643 .44901 L p .816 .471 .405 r
F P
0 g
s
.81448 .55056 m .77834 .5843 L .77656 .57472 L p .871 .907 .853 r
F P
0 g
s
.77656 .57472 m .81272 .53879 L .81448 .55056 L p .871 .907 .853 r
F P
0 g
s
.62399 .5885 m .60693 .60614 L .59703 .60209 L p .611 .529 .738 r
F P
0 g
s
.59703 .60209 m .61055 .58472 L .62399 .5885 L p .611 .529 .738 r
F P
0 g
s
.59133 .6206 m .59703 .60209 L .60693 .60614 L p .665 .493 .642 r
F P
0 g
s
.59703 .60209 m .59133 .6206 L .5839 .61707 L p .654 .464 .615 r
F P
0 g
s
.82819 .50119 m .81272 .53879 L .80472 .52777 L p .945 .803 .672 r
F P
0 g
s
.80472 .52777 m .81987 .48931 L .82819 .50119 L p .945 .803 .672 r
F P
0 g
s
.68587 .62181 m .7302 .60286 L .732 .61011 L p .705 .838 .946 r
F P
0 g
s
.7302 .60286 m .68587 .62181 L .68097 .61599 L p .707 .78 .909 r
F P
0 g
s
.6297 .72015 m .62234 .76521 L .62119 .76226 L p .958 .814 .377 r
F P
0 g
s
.62119 .76226 m .62885 .71727 L .6297 .72015 L p .958 .814 .377 r
F P
0 g
s
.77834 .5843 m .732 .61011 L .7302 .60286 L p .772 .866 .918 r
F P
0 g
s
.56577 .63592 m .56357 .60931 L .56996 .6114 L p .727 .431 .478 r
F P
0 g
s
.56357 .60931 m .56577 .63592 L .55959 .6343 L p .738 .435 .468 r
F P
0 g
s
.55959 .6343 m .55752 .60771 L .56357 .60931 L p .738 .435 .468 r
F P
0 g
s
.62633 .67303 m .62298 .70793 L .61989 .7046 L p .972 .727 .509 r
F P
0 g
s
.61989 .7046 m .62313 .6695 L .62633 .67303 L p .972 .727 .509 r
F P
0 g
s
.5817 .84584 m .55757 .86664 L .5594 .86562 L p 0 0 0 r
F P
0 g
s
.5594 .86562 m .58497 .84394 L .5817 .84584 L p 0 0 0 r
F P
0 g
s
.55752 .60771 m .55959 .6343 L .55344 .63313 L p .753 .445 .464 r
F P
0 g
s
.55344 .63313 m .55172 .60659 L .55752 .60771 L p .753 .445 .464 r
F P
0 g
s
.57202 .638 m .56996 .6114 L .57674 .61399 L p .723 .436 .491 r
F P
0 g
s
.56996 .6114 m .57202 .638 L .56577 .63592 L p .727 .431 .478 r
F P
0 g
s
.45131 .65311 m .44791 .6279 L .44529 .62946 L p .258 .145 .528 r
F P
0 g
s
.44529 .62946 m .44763 .65485 L .45131 .65311 L p .258 .145 .528 r
F P
0 g
s
.64282 .62577 m .6732 .60992 L .68097 .61599 L p .69 .721 .873 r
F P
0 g
s
.6732 .60992 m .64282 .62577 L .6353 .62064 L p .676 .672 .839 r
F P
0 g
s
.62005 .63764 m .6353 .62064 L .64282 .62577 L p .746 .661 .767 r
F P
0 g
s
.5357 .57022 m .53458 .58731 L .52815 .58741 L p .91 .813 .739 r
F P
0 g
s
.53458 .58731 m .53434 .60587 L .52807 .60642 L p .887 .663 .593 r
F P
0 g
s
.52807 .60642 m .52815 .58741 L .53458 .58731 L p .887 .663 .593 r
F P
0 g
s
.44956 .82251 m .42992 .77917 L .43066 .78272 L p 0 0 .43 r
F P
0 g
s
.43066 .78272 m .45021 .82506 L .44956 .82251 L p 0 0 .43 r
F P
0 g
s
.51509 .42316 m .51628 .41738 L .52958 .43167 L p .79 .317 0 r
F P
0 g
s
.57835 .64051 m .57674 .61399 L .5839 .61707 L p .725 .448 .507 r
F P
0 g
s
.57674 .61399 m .57835 .64051 L .57202 .638 L p .723 .436 .491 r
F P
0 g
s
.55172 .60659 m .55344 .63313 L .54727 .63242 L p .77 .462 .465 r
F P
0 g
s
.54727 .63242 m .54602 .60593 L .55172 .60659 L p .77 .462 .465 r
F P
0 g
s
.55211 .55438 m .55709 .53163 L .56533 .53417 L p .779 .743 .82 r
F P
0 g
s
.55709 .53163 m .55211 .55438 L .54519 .55211 L p .835 .795 .813 r
F P
0 g
s
.6353 .62064 m .62005 .63764 L .6135 .63316 L p .721 .61 .732 r
F P
0 g
s
.62005 .63764 m .61447 .66187 L .60919 .65793 L p .816 .594 .601 r
F P
0 g
s
.60919 .65793 m .6135 .63316 L .62005 .63764 L p .816 .594 .601 r
F P
0 g
s
.49248 .8651 m .46615 .84321 L .46934 .84503 L p .568 .003 0 r
F P
0 g
s
.46934 .84503 m .49425 .86613 L .49248 .8651 L p .568 .003 0 r
F P
0 g
s
.63261 .47994 m .62968 .46155 L .65136 .45494 L p .557 .296 .476 r
F P
0 g
s
.62968 .46155 m .63261 .47994 L .61344 .48434 L p .55 .289 .473 r
F P
0 g
s
.63766 .59301 m .6169 .61066 L .60693 .60614 L p .626 .559 .759 r
F P
0 g
s
.60693 .60614 m .62399 .5885 L .63766 .59301 L p .626 .559 .759 r
F P
0 g
s
.59889 .62452 m .60693 .60614 L .6169 .61066 L p .68 .527 .67 r
F P
0 g
s
.60693 .60614 m .59889 .62452 L .59133 .6206 L p .665 .493 .642 r
F P
0 g
s
.63084 .56288 m .61055 .58472 L .59792 .58168 L p .594 .538 .762 r
F P
0 g
s
.59792 .58168 m .61422 .56093 L .63084 .56288 L p .594 .538 .762 r
F P
0 g
s
.58473 .64343 m .5839 .61707 L .59133 .6206 L p .732 .466 .525 r
F P
0 g
s
.5839 .61707 m .58473 .64343 L .57835 .64051 L p .725 .448 .507 r
F P
0 g
s
.61433 .53465 m .59936 .55969 L .58654 .55886 L p .601 .539 .757 r
F P
0 g
s
.58654 .55886 m .59854 .53536 L .61433 .53465 L p .601 .539 .757 r
F P
0 g
s
.44434 .69411 m .44452 .65659 L .44192 .65837 L p .212 .058 .443 r
F P
0 g
s
.44192 .65837 m .44087 .69638 L .44434 .69411 L p .212 .058 .443 r
F P
0 g
s
.62201 .77993 m .60284 .82359 L .60339 .82115 L p .781 .845 .389 r
F P
0 g
s
.60339 .82115 m .62284 .77697 L .62201 .77993 L p .781 .845 .389 r
F P
0 g
s
.58497 .84394 m .5594 .86562 L .56111 .86455 L p 0 0 0 r
F P
0 g
s
.56111 .86455 m .58801 .84194 L .58497 .84394 L p 0 0 0 r
F P
0 g
s
.43529 .75558 m .43052 .70711 L .42867 .71036 L p 0 0 .445 r
F P
0 g
s
.42867 .71036 m .43344 .75864 L .43529 .75558 L p 0 0 .445 r
F P
0 g
s
.6135 .63316 m .62651 .61555 L .6353 .62064 L p .721 .61 .732 r
F P
0 g
s
.62651 .61555 m .6135 .63316 L .60636 .62874 L p .699 .565 .7 r
F P
0 g
s
.6135 .63316 m .60919 .65793 L .60345 .65403 L p .787 .553 .582 r
F P
0 g
s
.60345 .65403 m .60636 .62874 L .6135 .63316 L p .787 .553 .582 r
F P
0 g
s
.6353 .62064 m .66298 .6039 L .6732 .60992 L p .676 .672 .839 r
F P
0 g
s
.66298 .6039 m .6353 .62064 L .62651 .61555 L p .66 .63 .809 r
F P
0 g
s
.54602 .60593 m .54727 .63242 L .54103 .63215 L p .786 .482 .473 r
F P
0 g
s
.54103 .63215 m .54028 .6057 L .54602 .60593 L p .786 .482 .473 r
F P
0 g
s
.5911 .6467 m .59133 .6206 L .59889 .62452 L p .745 .489 .544 r
F P
0 g
s
.59133 .6206 m .5911 .6467 L .58473 .64343 L p .732 .466 .525 r
F P
0 g
s
.6509 .59819 m .62651 .61555 L .6169 .61066 L p .643 .592 .782 r
F P
0 g
s
.6169 .61066 m .63766 .59301 L .6509 .59819 L p .643 .592 .782 r
F P
0 g
s
.60636 .62874 m .6169 .61066 L .62651 .61555 L p .699 .565 .7 r
F P
0 g
s
.6169 .61066 m .60636 .62874 L .59889 .62452 L p .68 .527 .67 r
F P
0 g
s
.59738 .65025 m .59889 .62452 L .60636 .62874 L p .763 .518 .563 r
F P
0 g
s
.59889 .62452 m .59738 .65025 L .5911 .6467 L p .745 .489 .544 r
F P
0 g
s
.60636 .62874 m .60345 .65403 L .59738 .65025 L p .763 .518 .563 r
F P
0 g
s
.62651 .61555 m .6509 .59819 L .66298 .6039 L p .66 .63 .809 r
F P
0 g
s
.49084 .86401 m .4632 .84127 L .46615 .84321 L p .527 0 0 r
F P
0 g
s
.46615 .84321 m .49248 .8651 L .49084 .86401 L p .527 0 0 r
F P
0 g
s
.7302 .60286 m .77656 .57472 L .77834 .5843 L p .772 .866 .918 r
F P
0 g
s
.62313 .6695 m .61989 .7046 L .61625 .70118 L p .938 .686 .53 r
F P
0 g
s
.61625 .70118 m .61915 .66576 L .62313 .6695 L p .938 .686 .53 r
F P
0 g
s
.5357 .57022 m .53764 .54936 L .54519 .55211 L p .874 .84 .809 r
F P
0 g
s
.53764 .54936 m .5357 .57022 L .52843 .56914 L p .885 .846 .801 r
F P
0 g
s
.52815 .58741 m .52843 .56914 L .5357 .57022 L p .91 .813 .739 r
F P
0 g
s
.62885 .71727 m .62119 .76226 L .61962 .75929 L p .993 .82 .451 r
F P
0 g
s
.61962 .75929 m .62747 .71428 L .62885 .71727 L p .993 .82 .451 r
F P
0 g
s
.44921 .81993 m .42958 .7756 L .42992 .77917 L p 0 0 .49 r
F P
0 g
s
.42992 .77917 m .44956 .82251 L .44921 .81993 L p 0 0 .49 r
F P
0 g
s
.58801 .84194 m .56111 .86455 L .56267 .86343 L p 0 0 0 r
F P
0 g
s
.56267 .86343 m .59081 .83984 L .58801 .84194 L p 0 0 0 r
F P
0 g
s
.54028 .6057 m .54103 .63215 L .53466 .63229 L p .798 .501 .487 r
F P
0 g
s
.53466 .63229 m .53434 .60587 L .54028 .6057 L p .798 .501 .487 r
F P
0 g
s
.31745 .45788 m .32395 .43106 L .32627 .44941 L p .959 .823 .391 r
F P
0 g
s
.32627 .44941 m .32004 .47462 L .31745 .45788 L p .959 .823 .391 r
F P
0 g
s
.55284 .46027 m .55357 .47645 L .54277 .46722 L p .943 .609 .364 r
F P
0 g
s
.54277 .46722 m .54232 .44987 L .55284 .46027 L p .943 .609 .364 r
F P
0 g
s
.5936 .5106 m .58538 .53577 L .5745 .53548 L p .667 .576 .743 r
F P
0 g
s
.5745 .53548 m .58117 .511 L .5936 .5106 L p .667 .576 .743 r
F P
0 g
s
.58117 .511 m .5745 .53548 L .56533 .53417 L p .728 .64 .76 r
F P
0 g
s
.655 .47507 m .65136 .45494 L .67567 .44856 L p .579 .313 .478 r
F P
0 g
s
.65136 .45494 m .655 .47507 L .63261 .47994 L p .557 .296 .476 r
F P
0 g
s
.58117 .511 m .58434 .4886 L .59748 .48746 L p .669 .503 .651 r
F P
0 g
s
.58434 .4886 m .58117 .511 L .57073 .50963 L p .743 .572 .662 r
F P
0 g
s
.57073 .50963 m .57329 .48727 L .58434 .4886 L p .743 .572 .662 r
F P
0 g
s
.41539 .59466 m .38685 .57271 L .39024 .57845 L p 0 .366 .809 r
F P
0 g
s
.36077 .55246 m .39024 .57845 L .38685 .57271 L p 0 .29 .771 r
F P
0 g
s
.52843 .56914 m .52815 .58741 L .521 .58779 L p .903 .818 .753 r
F P
0 g
s
.52815 .58741 m .52807 .60642 L .52138 .60732 L p .886 .684 .624 r
F P
0 g
s
.52138 .60732 m .521 .58779 L .52815 .58741 L p .886 .684 .624 r
F P
0 g
s
.33323 .39771 m .3546 .38688 L .34801 .40207 L p .868 .995 .791 r
F P
0 g
s
.34801 .40207 m .3261 .41347 L .33323 .39771 L p .868 .995 .791 r
F P
0 g
s
.68097 .61599 m .72414 .59532 L .7302 .60286 L p .707 .78 .909 r
F P
0 g
s
.72414 .59532 m .68097 .61599 L .6732 .60992 L p .696 .728 .875 r
F P
0 g
s
.62284 .77697 m .60339 .82115 L .60363 .81871 L p .86 .887 .458 r
F P
0 g
s
.60363 .81871 m .6233 .77402 L .62284 .77697 L p .86 .887 .458 r
F P
0 g
s
.64866 .56576 m .62399 .5885 L .61055 .58472 L p .609 .557 .771 r
F P
0 g
s
.61055 .58472 m .63084 .56288 L .64866 .56576 L p .609 .557 .771 r
F P
0 g
s
.48935 .86286 m .4605 .83922 L .4632 .84127 L p .476 0 0 r
F P
0 g
s
.4632 .84127 m .49084 .86401 L .48935 .86286 L p .476 0 0 r
F P
0 g
s
.56533 .53417 m .57073 .50963 L .58117 .511 L p .728 .64 .76 r
F P
0 g
s
.57073 .50963 m .56533 .53417 L .55709 .53163 L p .798 .708 .765 r
F P
0 g
s
.45561 .65133 m .45148 .62619 L .44791 .6279 L p .353 .234 .576 r
F P
0 g
s
.44791 .6279 m .45131 .65311 L .45561 .65133 L p .353 .234 .576 r
F P
0 g
s
.43682 .60957 m .44791 .6279 L .45148 .62619 L p .313 .413 .804 r
F P
0 g
s
.43748 .75265 m .43263 .70412 L .43052 .70711 L p .08 .013 .473 r
F P
0 g
s
.43052 .70711 m .43529 .75558 L .43748 .75265 L p .08 .013 .473 r
F P
0 g
s
.7772 .44289 m .78541 .47224 L .76136 .46786 L p .746 .428 .445 r
F P
0 g
s
.76136 .46786 m .75402 .44002 L .7772 .44289 L p .746 .428 .445 r
F P
0 g
s
.33105 .50834 m .32004 .47462 L .32631 .49098 L p .759 .423 0 r
F P
0 g
s
.32631 .49098 m .33698 .52148 L .33105 .50834 L p .759 .423 0 r
F P
0 g
s
.54519 .55211 m .54891 .52785 L .55709 .53163 L p .835 .795 .813 r
F P
0 g
s
.54891 .52785 m .54519 .55211 L .53764 .54936 L p .868 .819 .798 r
F P
0 g
s
.63274 .53414 m .61422 .56093 L .59936 .55969 L p .602 .535 .751 r
F P
0 g
s
.59936 .55969 m .61433 .53465 L .63274 .53414 L p .602 .535 .751 r
F P
0 g
s
.57329 .48727 m .57073 .50963 L .56136 .50625 L p .827 .648 .661 r
F P
0 g
s
.56136 .50625 m .56339 .48322 L .57329 .48727 L p .827 .648 .661 r
F P
0 g
s
.44823 .69195 m .44763 .65485 L .44452 .65659 L p .282 .12 .476 r
F P
0 g
s
.44452 .65659 m .44434 .69411 L .44823 .69195 L p .282 .12 .476 r
F P
0 g
s
.43682 .60957 m .41554 .59115 L .41539 .59466 L p .094 .458 .886 r
F P
0 g
s
.38685 .57271 m .41539 .59466 L .41554 .59115 L p .095 .48 .896 r
F P
0 g
s
.5936 .5106 m .59748 .48746 L .61344 .48434 L p .624 .459 .637 r
F P
0 g
s
.59748 .48746 m .5936 .5106 L .58117 .511 L p .669 .503 .651 r
F P
0 g
s
.60869 .50883 m .59854 .53536 L .58538 .53577 L p .63 .532 .725 r
F P
0 g
s
.58538 .53577 m .5936 .5106 L .60869 .50883 L p .63 .532 .725 r
F P
0 g
s
.59081 .83984 m .56267 .86343 L .56409 .86226 L p .466 .821 .549 r
F P
0 g
s
.56409 .86226 m .59335 .83767 L .59081 .83984 L p .466 .821 .549 r
F P
0 g
s
.45148 .62619 m .43967 .60731 L .43682 .60957 L p .313 .413 .804 r
F P
0 g
s
.41554 .59115 m .43682 .60957 L .43967 .60731 L p .28 .56 .931 r
F P
0 g
s
.61915 .66576 m .61625 .70118 L .6121 .69774 L p .904 .646 .539 r
F P
0 g
s
.6121 .69774 m .61447 .66187 L .61915 .66576 L p .904 .646 .539 r
F P
0 g
s
.53434 .60587 m .53466 .63229 L .52811 .63281 L p .804 .519 .506 r
F P
0 g
s
.52811 .63281 m .52807 .60642 L .53434 .60587 L p .804 .519 .506 r
F P
0 g
s
.44918 .81735 m .42962 .77206 L .42958 .7756 L p 0 0 .536 r
F P
0 g
s
.42958 .7756 m .44921 .81993 L .44918 .81735 L p 0 0 .536 r
F P
0 g
s
.62747 .71428 m .61962 .75929 L .61761 .75631 L p .999 .805 .503 r
F P
0 g
s
.61761 .75631 m .62551 .71117 L .62747 .71428 L p .999 .805 .503 r
F P
0 g
s
.48801 .86167 m .45807 .83707 L .4605 .83922 L p 0 .1 .58 r
F P
0 g
s
.4605 .83922 m .48935 .86286 L .48801 .86167 L p 0 .1 .58 r
F P
0 g
s
.68014 .47063 m .67567 .44856 L .70174 .44339 L p .609 .336 .478 r
F P
0 g
s
.67567 .44856 m .68014 .47063 L .655 .47507 L p .579 .313 .478 r
F P
0 g
s
.77656 .57472 m .7302 .60286 L .72414 .59532 L p .762 .796 .881 r
F P
0 g
s
.66688 .56974 m .63766 .59301 L .62399 .5885 L p .626 .581 .784 r
F P
0 g
s
.62399 .5885 m .64866 .56576 L .66688 .56974 L p .626 .581 .784 r
F P
0 g
s
.49739 .40877 m .5005 .4027 L .51628 .41738 L p .805 .321 0 r
F P
0 g
s
.59335 .83767 m .56409 .86226 L .56536 .86104 L p .555 .879 .605 r
F P
0 g
s
.56536 .86104 m .59564 .83543 L .59335 .83767 L p .555 .879 .605 r
F P
0 g
s
.6233 .77402 m .60363 .81871 L .60356 .81627 L p .92 .912 .518 r
F P
0 g
s
.60356 .81627 m .62338 .77109 L .6233 .77402 L p .92 .912 .518 r
F P
0 g
s
.55709 .53163 m .56136 .50625 L .57073 .50963 L p .798 .708 .765 r
F P
0 g
s
.56136 .50625 m .55709 .53163 L .54891 .52785 L p .855 .758 .755 r
F P
0 g
s
.61447 .66187 m .6121 .69774 L .6075 .69431 L p .873 .611 .54 r
F P
0 g
s
.6075 .69431 m .60919 .65793 L .61447 .66187 L p .873 .611 .54 r
F P
0 g
s
.6732 .60992 m .71408 .58789 L .72414 .59532 L p .696 .728 .875 r
F P
0 g
s
.71408 .58789 m .6732 .60992 L .66298 .6039 L p .681 .683 .846 r
F P
0 g
s
.44003 .74985 m .43505 .70135 L .43263 .70412 L p .153 .067 .496 r
F P
0 g
s
.43263 .70412 m .43748 .75265 L .44003 .74985 L p .153 .067 .496 r
F P
0 g
s
.60869 .50883 m .61344 .48434 L .63261 .47994 L p .608 .439 .628 r
F P
0 g
s
.61344 .48434 m .60869 .50883 L .5936 .5106 L p .624 .459 .637 r
F P
0 g
s
.75402 .44002 m .76136 .46786 L .73474 .46637 L p .691 .392 .464 r
F P
0 g
s
.73474 .46637 m .72835 .44032 L .75402 .44002 L p .691 .392 .464 r
F P
0 g
s
.62683 .50627 m .61433 .53465 L .59854 .53536 L p .615 .511 .712 r
F P
0 g
s
.59854 .53536 m .60869 .50883 L .62683 .50627 L p .615 .511 .712 r
F P
0 g
s
.52807 .60642 m .52811 .63281 L .52135 .63368 L p .804 .532 .527 r
F P
0 g
s
.52135 .63368 m .52138 .60732 L .52807 .60642 L p .804 .532 .527 r
F P
0 g
s
.56339 .48322 m .56136 .50625 L .55207 .50085 L p .89 .703 .643 r
F P
0 g
s
.55207 .50085 m .55357 .47645 L .56339 .48322 L p .89 .703 .643 r
F P
0 g
s
.52843 .56914 m .52889 .54628 L .53764 .54936 L p .885 .846 .801 r
F P
0 g
s
.52889 .54628 m .52843 .56914 L .52001 .56822 L p .881 .84 .8 r
F P
0 g
s
.521 .58779 m .52001 .56822 L .52843 .56914 L p .903 .818 .753 r
F P
0 g
s
.48682 .86044 m .45591 .83482 L .45807 .83707 L p 0 .139 .639 r
F P
0 g
s
.45807 .83707 m .48801 .86167 L .48682 .86044 L p 0 .139 .639 r
F P
0 g
s
.52001 .56822 m .521 .58779 L .51302 .5885 L p .886 .813 .771 r
F P
0 g
s
.521 .58779 m .52138 .60732 L .51424 .60854 L p .876 .695 .655 r
F P
0 g
s
.51424 .60854 m .51302 .5885 L .521 .58779 L p .876 .695 .655 r
F P
0 g
s
.81987 .48931 m .80472 .52777 L .79082 .51812 L p .872 .702 .668 r
F P
0 g
s
.79082 .51812 m .80533 .47948 L .81987 .48931 L p .872 .702 .668 r
F P
0 g
s
.45255 .68987 m .45131 .65311 L .44763 .65485 L p .345 .177 .504 r
F P
0 g
s
.44763 .65485 m .44823 .69195 L .45255 .68987 L p .345 .177 .504 r
F P
0 g
s
.44946 .81478 m .43003 .76856 L .42962 .77206 L p 0 .02 .571 r
F P
0 g
s
.42962 .77206 m .44918 .81735 L .44946 .81478 L p 0 .02 .571 r
F P
0 g
s
.46055 .64949 m .45605 .62431 L .45148 .62619 L p .434 .307 .608 r
F P
0 g
s
.45148 .62619 m .45561 .65133 L .46055 .64949 L p .434 .307 .608 r
F P
0 g
s
.43967 .60731 m .45148 .62619 L .45605 .62431 L p .438 .499 .825 r
F P
0 g
s
.70715 .46748 m .70174 .44339 L .72835 .44032 L p .646 .362 .474 r
F P
0 g
s
.70174 .44339 m .70715 .46748 L .68014 .47063 L p .609 .336 .478 r
F P
0 g
s
.60919 .65793 m .6075 .69431 L .60251 .69094 L p .846 .581 .537 r
F P
0 g
s
.60251 .69094 m .60345 .65403 L .60919 .65793 L p .846 .581 .537 r
F P
0 g
s
.68454 .57484 m .6509 .59819 L .63766 .59301 L p .645 .611 .801 r
F P
0 g
s
.63766 .59301 m .66688 .56974 L .68454 .57484 L p .645 .611 .801 r
F P
0 g
s
.65343 .53432 m .63084 .56288 L .61422 .56093 L p .613 .543 .751 r
F P
0 g
s
.61422 .56093 m .63274 .53414 L .65343 .53432 L p .613 .543 .751 r
F P
0 g
s
.59564 .83543 m .56536 .86104 L .56647 .85979 L p .636 .925 .656 r
F P
0 g
s
.56647 .85979 m .59765 .83313 L .59564 .83543 L p .636 .925 .656 r
F P
0 g
s
.81272 .53879 m .77656 .57472 L .76937 .5653 L p .842 .812 .821 r
F P
0 g
s
.76937 .5653 m .80472 .52777 L .81272 .53879 L p .842 .812 .821 r
F P
0 g
s
.72835 .44032 m .73474 .46637 L .70715 .46748 L p .646 .362 .474 r
F P
0 g
s
.66298 .6039 m .70061 .58096 L .71408 .58789 L p .681 .683 .846 r
F P
0 g
s
.70061 .58096 m .66298 .6039 L .6509 .59819 L p .663 .644 .821 r
F P
0 g
s
.62551 .71117 m .61761 .75631 L .61517 .75333 L p .987 .779 .536 r
F P
0 g
s
.61517 .75333 m .62298 .70793 L .62551 .71117 L p .987 .779 .536 r
F P
0 g
s
.6509 .59819 m .68454 .57484 L .70061 .58096 L p .663 .644 .821 r
F P
0 g
s
.54232 .44987 m .54277 .46722 L .53006 .45606 L p .947 .617 .368 r
F P
0 g
s
.53006 .45606 m .52995 .43721 L .54232 .44987 L p .947 .617 .368 r
F P
0 g
s
.38685 .57271 m .35587 .54317 L .36077 .55246 L p 0 .29 .771 r
F P
0 g
s
.33698 .52148 m .36077 .55246 L .35587 .54317 L p 0 .053 .604 r
F P
0 g
s
.62338 .77109 m .60356 .81627 L .60316 .81383 L p .959 .919 .567 r
F P
0 g
s
.60316 .81383 m .62307 .76815 L .62338 .77109 L p .959 .919 .567 r
F P
0 g
s
.60345 .65403 m .60251 .69094 L .59718 .6877 L p .824 .555 .532 r
F P
0 g
s
.59718 .6877 m .59738 .65025 L .60345 .65403 L p .824 .555 .532 r
F P
0 g
s
.48579 .85917 m .45404 .83248 L .45591 .83482 L p 0 .178 .689 r
F P
0 g
s
.45591 .83482 m .48682 .86044 L .48579 .85917 L p 0 .178 .689 r
F P
0 g
s
.53764 .54936 m .53993 .52295 L .54891 .52785 L p .868 .819 .798 r
F P
0 g
s
.53993 .52295 m .53764 .54936 L .52889 .54628 L p .88 .822 .786 r
F P
0 g
s
.52138 .60732 m .52135 .63368 L .51439 .63486 L p .797 .539 .549 r
F P
0 g
s
.51439 .63486 m .51424 .60854 L .52138 .60732 L p .797 .539 .549 r
F P
0 g
s
.44293 .74719 m .43778 .69878 L .43505 .70135 L p .219 .115 .516 r
F P
0 g
s
.43505 .70135 m .44003 .74985 L .44293 .74719 L p .219 .115 .516 r
F P
0 g
s
.54891 .52785 m .55207 .50085 L .56136 .50625 L p .855 .758 .755 r
F P
0 g
s
.45605 .62431 m .4441 .60484 L .43967 .60731 L p .438 .499 .825 r
F P
0 g
s
.41786 .58737 m .43967 .60731 L .4441 .60484 L p .426 .629 .939 r
F P
0 g
s
.43967 .60731 m .41786 .58737 L .41554 .59115 L p .28 .56 .931 r
F P
0 g
s
.35587 .54317 m .33105 .50834 L .33698 .52148 L p 0 .053 .604 r
F P
0 g
s
.63261 .47994 m .62683 .50627 L .60869 .50883 L p .608 .439 .628 r
F P
0 g
s
.59765 .83313 m .56647 .85979 L .56742 .85851 L p .707 .96 .7 r
F P
0 g
s
.56742 .85851 m .59939 .83079 L .59765 .83313 L p .707 .96 .7 r
F P
0 g
s
.59738 .65025 m .59718 .6877 L .59157 .68464 L p .806 .533 .526 r
F P
0 g
s
.59157 .68464 m .5911 .6467 L .59738 .65025 L p .806 .533 .526 r
F P
0 g
s
.72414 .59532 m .76937 .5653 L .77656 .57472 L p .762 .796 .881 r
F P
0 g
s
.45006 .81224 m .43081 .76515 L .43003 .76856 L p 0 .073 .597 r
F P
0 g
s
.43003 .76856 m .44946 .81478 L .45006 .81224 L p 0 .073 .597 r
F P
0 g
s
.62683 .50627 m .63261 .47994 L .655 .47507 L p .611 .438 .624 r
F P
0 g
s
.5911 .6467 m .59157 .68464 L .58575 .6818 L p .791 .515 .52 r
F P
0 g
s
.58575 .6818 m .58473 .64343 L .5911 .6467 L p .791 .515 .52 r
F P
0 g
s
.45731 .68785 m .45561 .65133 L .45131 .65311 L p .402 .227 .527 r
F P
0 g
s
.45131 .65311 m .45255 .68987 L .45731 .68785 L p .402 .227 .527 r
F P
0 g
s
.64801 .5036 m .63274 .53414 L .61433 .53465 L p .617 .507 .706 r
F P
0 g
s
.61433 .53465 m .62683 .50627 L .64801 .5036 L p .617 .507 .706 r
F P
0 g
s
.55207 .50085 m .54891 .52785 L .53993 .52295 L p .886 .78 .738 r
F P
0 g
s
.4661 .64759 m .4616 .62229 L .45605 .62431 L p .501 .366 .628 r
F P
0 g
s
.45605 .62431 m .46055 .64949 L .4661 .64759 L p .501 .366 .628 r
F P
0 g
s
.4441 .60484 m .45605 .62431 L .4616 .62229 L p .533 .559 .828 r
F P
0 g
s
.48493 .85787 m .45246 .83006 L .45404 .83248 L p 0 .215 .73 r
F P
0 g
s
.45404 .83248 m .48579 .85917 L .48493 .85787 L p 0 .215 .73 r
F P
0 g
s
.58473 .64343 m .58575 .6818 L .57976 .67924 L p .78 .501 .513 r
F P
0 g
s
.57976 .67924 m .57835 .64051 L .58473 .64343 L p .78 .501 .513 r
F P
0 g
s
.62298 .70793 m .61517 .75333 L .61231 .75035 L p .966 .747 .557 r
F P
0 g
s
.61231 .75035 m .61989 .7046 L .62298 .70793 L p .966 .747 .557 r
F P
0 g
s
.34539 .38484 m .36559 .37469 L .3546 .38688 L p .695 .974 .771 r
F P
0 g
s
.3546 .38688 m .33323 .39771 L .34539 .38484 L p .695 .974 .771 r
F P
0 g
s
.51302 .5885 m .51029 .56759 L .52001 .56822 L p .886 .813 .771 r
F P
0 g
s
.51029 .56759 m .51302 .5885 L .50427 .58955 L p .864 .803 .789 r
F P
0 g
s
.51302 .5885 m .51424 .60854 L .5067 .61004 L p .857 .699 .685 r
F P
0 g
s
.5067 .61004 m .50427 .58955 L .51302 .5885 L p .857 .699 .685 r
F P
0 g
s
.76937 .5653 m .72414 .59532 L .71408 .58789 L p .742 .737 .847 r
F P
0 g
s
.57835 .64051 m .57976 .67924 L .57364 .67699 L p .772 .49 .508 r
F P
0 g
s
.57364 .67699 m .57202 .638 L .57835 .64051 L p .772 .49 .508 r
F P
0 g
s
.38588 .56653 m .41554 .59115 L .41786 .58737 L p .279 .57 .936 r
F P
0 g
s
.41554 .59115 m .38588 .56653 L .38685 .57271 L p .095 .48 .896 r
F P
0 g
s
.51424 .60854 m .51439 .63486 L .50727 .6363 L p .783 .541 .57 r
F P
0 g
s
.50727 .6363 m .5067 .61004 L .51424 .60854 L p .783 .541 .57 r
F P
0 g
s
.67566 .53563 m .64866 .56576 L .63084 .56288 L p .63 .559 .756 r
F P
0 g
s
.63084 .56288 m .65343 .53432 L .67566 .53563 L p .63 .559 .756 r
F P
0 g
s
.57202 .638 m .57364 .67699 L .56741 .67508 L p .766 .483 .504 r
F P
0 g
s
.56741 .67508 m .56577 .63592 L .57202 .638 L p .766 .483 .504 r
F P
0 g
s
.62307 .76815 m .60316 .81383 L .60245 .8114 L p .98 .911 .603 r
F P
0 g
s
.60245 .8114 m .62234 .76521 L .62307 .76815 L p .98 .911 .603 r
F P
0 g
s
.59939 .83079 m .56742 .85851 L .5682 .8572 L p .767 .983 .735 r
F P
0 g
s
.5682 .8572 m .60083 .82841 L .59939 .83079 L p .767 .983 .735 r
F P
0 g
s
.55357 .47645 m .55207 .50085 L .54186 .49361 L p .921 .726 .623 r
F P
0 g
s
.54186 .49361 m .54277 .46722 L .55357 .47645 L p .921 .726 .623 r
F P
0 g
s
.56577 .63592 m .56741 .67508 L .56109 .67354 L p .763 .478 .502 r
F P
0 g
s
.56109 .67354 m .55959 .6343 L .56577 .63592 L p .763 .478 .502 r
F P
0 g
s
.47692 .39523 m .48231 .3888 L .5005 .4027 L p .794 .298 0 r
F P
0 g
s
.44618 .74467 m .44087 .69638 L .43778 .69878 L p .278 .16 .533 r
F P
0 g
s
.43778 .69878 m .44293 .74719 L .44618 .74467 L p .278 .16 .533 r
F P
0 g
s
.45096 .80973 m .43195 .76184 L .43081 .76515 L p .056 .121 .615 r
F P
0 g
s
.43081 .76515 m .45006 .81224 L .45096 .80973 L p .056 .121 .615 r
F P
0 g
s
.35587 .54317 m .38685 .57271 L .38588 .56653 L p .061 .408 .86 r
F P
0 g
s
.52001 .56822 m .5185 .54313 L .52889 .54628 L p .881 .84 .8 r
F P
0 g
s
.5185 .54313 m .52001 .56822 L .51029 .56759 L p .867 .826 .805 r
F P
0 g
s
.55959 .6343 m .56109 .67354 L .55469 .67237 L p .762 .477 .501 r
F P
0 g
s
.55469 .67237 m .55344 .63313 L .55959 .6343 L p .762 .477 .501 r
F P
0 g
s
.48424 .85654 m .45118 .82759 L .45246 .83006 L p 0 .249 .761 r
F P
0 g
s
.45246 .83006 m .48493 .85787 L .48424 .85654 L p 0 .249 .761 r
F P
0 g
s
.31949 .44164 m .3261 .41347 L .32395 .43106 L p .795 .757 .241 r
F P
0 g
s
.32395 .43106 m .31745 .45788 L .31949 .44164 L p .795 .757 .241 r
F P
0 g
s
.55344 .63313 m .55469 .67237 L .54819 .67159 L p .761 .477 .503 r
F P
0 g
s
.54819 .67159 m .54727 .63242 L .55344 .63313 L p .761 .477 .503 r
F P
0 g
s
.655 .47507 m .64801 .5036 L .62683 .50627 L p .611 .438 .624 r
F P
0 g
s
.4625 .68587 m .46055 .64949 L .45561 .65133 L p .452 .271 .544 r
F P
0 g
s
.45561 .65133 m .45731 .68785 L .4625 .68587 L p .452 .271 .544 r
F P
0 g
s
.4722 .64563 m .46804 .62016 L .4616 .62229 L p .557 .41 .638 r
F P
0 g
s
.4616 .62229 m .4661 .64759 L .4722 .64563 L p .557 .41 .638 r
F P
0 g
s
.45011 .60226 m .4616 .62229 L .46804 .62016 L p .605 .6 .82 r
F P
0 g
s
.4616 .62229 m .45011 .60226 L .4441 .60484 L p .533 .559 .828 r
F P
0 g
s
.61989 .7046 m .61231 .75035 L .60904 .7474 L p .942 .716 .568 r
F P
0 g
s
.60904 .7474 m .61625 .70118 L .61989 .7046 L p .942 .716 .568 r
F P
0 g
s
.80533 .47948 m .79082 .51812 L .77182 .51037 L p .809 .627 .656 r
F P
0 g
s
.77182 .51037 m .78541 .47224 L .80533 .47948 L p .809 .627 .656 r
F P
0 g
s
.60083 .82841 m .5682 .8572 L .56881 .85586 L p .816 .995 .762 r
F P
0 g
s
.56881 .85586 m .60199 .82601 L .60083 .82841 L p .816 .995 .762 r
F P
0 g
s
.50427 .58955 m .5067 .61004 L .49884 .61179 L p .833 .696 .712 r
F P
0 g
s
.5067 .61004 m .50727 .6363 L .50004 .63795 L p .763 .537 .59 r
F P
0 g
s
.50004 .63795 m .49884 .61179 L .5067 .61004 L p .763 .537 .59 r
F P
0 g
s
.64801 .5036 m .655 .47507 L .68014 .47063 L p .626 .449 .623 r
F P
0 g
s
.42257 .58347 m .4441 .60484 L .45011 .60226 L p .534 .674 .927 r
F P
0 g
s
.4441 .60484 m .42257 .58347 L .41786 .58737 L p .426 .629 .939 r
F P
0 g
s
.53993 .52295 m .54186 .49361 L .55207 .50085 L p .886 .78 .738 r
F P
0 g
s
.54727 .63242 m .54819 .67159 L .5416 .67117 L p .759 .478 .507 r
F P
0 g
s
.5416 .67117 m .54103 .63215 L .54727 .63242 L p .759 .478 .507 r
F P
0 g
s
.62234 .76521 m .60245 .8114 L .60141 .80899 L p .987 .893 .628 r
F P
0 g
s
.60141 .80899 m .62119 .76226 L .62234 .76521 L p .987 .893 .628 r
F P
0 g
s
.50427 .58955 m .49932 .5674 L .51029 .56759 L p .864 .803 .789 r
F P
0 g
s
.49932 .5674 m .50427 .58955 L .4949 .59095 L p .836 .791 .808 r
F P
0 g
s
.49884 .61179 m .4949 .59095 L .50427 .58955 L p .833 .696 .712 r
F P
0 g
s
.48371 .85519 m .45021 .82506 L .45118 .82759 L p 0 .279 .782 r
F P
0 g
s
.45118 .82759 m .48424 .85654 L .48371 .85519 L p 0 .279 .782 r
F P
0 g
s
.69842 .53841 m .66688 .56974 L .64866 .56576 L p .65 .583 .766 r
F P
0 g
s
.64866 .56576 m .67566 .53563 L .69842 .53841 L p .65 .583 .766 r
F P
0 g
s
.67183 .50151 m .65343 .53432 L .63274 .53414 L p .63 .516 .705 r
F P
0 g
s
.63274 .53414 m .64801 .5036 L .67183 .50151 L p .63 .516 .705 r
F P
0 g
s
.44979 .74227 m .44434 .69411 L .44087 .69638 L p .33 .2 .548 r
F P
0 g
s
.44087 .69638 m .44618 .74467 L .44979 .74227 L p .33 .2 .548 r
F P
0 g
s
.45218 .80727 m .43344 .75864 L .43195 .76184 L p .13 .162 .627 r
F P
0 g
s
.43195 .76184 m .45096 .80973 L .45218 .80727 L p .13 .162 .627 r
F P
0 g
s
.52569 .87321 m .52639 .86422 L .52296 .87314 L closepath p .379 .791 .979 r
F P
0 g
s
.52841 .87319 m .52639 .86422 L .52569 .87321 L closepath p .391 .801 .979 r
F P
0 g
s
.53113 .87309 m .52639 .86422 L .52841 .87319 L closepath p .404 .811 .98 r
F P
0 g
s
.52296 .87314 m .52639 .86422 L .52025 .87299 L closepath p .369 .782 .98 r
F P
0 g
s
.53384 .87291 m .52639 .86422 L .53113 .87309 L closepath p .418 .821 .98 r
F P
0 g
s
.71408 .58789 m .75709 .55656 L .76937 .5653 L p .742 .737 .847 r
F P
0 g
s
.75709 .55656 m .71408 .58789 L .70061 .58096 L p .719 .687 .819 r
F P
0 g
s
.52025 .87299 m .52639 .86422 L .51756 .87275 L closepath p .361 .773 .98 r
F P
0 g
s
.53651 .87264 m .52639 .86422 L .53384 .87291 L closepath p .435 .832 .981 r
F P
0 g
s
.54103 .63215 m .5416 .67117 L .53492 .67111 L p .756 .48 .513 r
F P
0 g
s
.53492 .67111 m .53466 .63229 L .54103 .63215 L p .756 .48 .513 r
F P
0 g
s
.51756 .87275 m .52639 .86422 L .51491 .87243 L closepath p .354 .764 .981 r
F P
0 g
s
.4949 .59095 m .49884 .61179 L .49083 .61374 L p .802 .688 .738 r
F P
0 g
s
.49884 .61179 m .50004 .63795 L .49281 .63976 L p .738 .527 .608 r
F P
0 g
s
.49281 .63976 m .49083 .61374 L .49884 .61179 L p .738 .527 .608 r
F P
0 g
s
.3286 .49473 m .31745 .45788 L .32004 .47462 L p 0 0 .353 r
F P
0 g
s
.32004 .47462 m .33105 .50834 L .3286 .49473 L p 0 0 .353 r
F P
0 g
s
.46804 .62016 m .45753 .59965 L .45011 .60226 L p .605 .6 .82 r
F P
0 g
s
.46609 .59713 m .4752 .61798 L .46804 .62016 L p .668 .632 .805 r
F P
0 g
s
.46804 .62016 m .45753 .59965 L .46609 .59713 L p .668 .632 .805 r
F P
0 g
s
.4722 .64563 m .46804 .62016 L .4752 .61798 L p .612 .451 .639 r
F P
0 g
s
.53914 .87228 m .52639 .86422 L .53651 .87264 L closepath p .452 .842 .982 r
F P
0 g
s
.80472 .52777 m .76937 .5653 L .75709 .55656 L p .803 .735 .789 r
F P
0 g
s
.75709 .55656 m .79082 .51812 L .80472 .52777 L p .803 .735 .789 r
F P
0 g
s
.52995 .43721 m .53006 .45606 L .51475 .44373 L p .938 .609 .385 r
F P
0 g
s
.51475 .44373 m .51509 .42316 L .52995 .43721 L p .938 .609 .385 r
F P
0 g
s
.51491 .87243 m .52639 .86422 L .5123 .87203 L closepath p .35 .756 .982 r
F P
0 g
s
.52889 .54628 m .52942 .5172 L .53993 .52295 L p .88 .822 .786 r
F P
0 g
s
.52942 .5172 m .52889 .54628 L .5185 .54313 L p .877 .811 .781 r
F P
0 g
s
.60199 .82601 m .56881 .85586 L .56925 .85451 L p .853 .997 .782 r
F P
0 g
s
.56925 .85451 m .60284 .82359 L .60199 .82601 L p .853 .997 .782 r
F P
0 g
s
.54172 .87185 m .52639 .86422 L .53914 .87228 L closepath p .47 .852 .983 r
F P
0 g
s
.61625 .70118 m .60904 .7474 L .60538 .74449 L p .917 .687 .574 r
F P
0 g
s
.60538 .74449 m .6121 .69774 L .61625 .70118 L p .917 .687 .574 r
F P
0 g
s
.46809 .68393 m .4661 .64759 L .46055 .64949 L p .496 .309 .556 r
F P
0 g
s
.46055 .64949 m .4625 .68587 L .46809 .68393 L p .496 .309 .556 r
F P
0 g
s
.5123 .87203 m .52639 .86422 L .50975 .87155 L closepath p .347 .749 .983 r
F P
0 g
s
.54425 .87133 m .52639 .86422 L .54172 .87185 L closepath p .489 .861 .984 r
F P
0 g
s
.50975 .87155 m .52639 .86422 L .50726 .87099 L closepath p .345 .741 .984 r
F P
0 g
s
.49083 .61374 m .48517 .59271 L .4949 .59095 L p .802 .688 .738 r
F P
0 g
s
.48517 .59271 m .49083 .61374 L .48287 .61582 L p .766 .675 .762 r
F P
0 g
s
.49083 .61374 m .49281 .63976 L .48567 .64167 L p .705 .51 .622 r
F P
0 g
s
.48567 .64167 m .48287 .61582 L .49083 .61374 L p .705 .51 .622 r
F P
0 g
s
.53466 .63229 m .53492 .67111 L .52814 .67139 L p .751 .48 .521 r
F P
0 g
s
.52814 .67139 m .52811 .63281 L .53466 .63229 L p .751 .48 .521 r
F P
0 g
s
.47544 .59478 m .48287 .61582 L .4752 .61798 L p .722 .657 .784 r
F P
0 g
s
.4752 .61798 m .46609 .59713 L .47544 .59478 L p .722 .657 .784 r
F P
0 g
s
.47876 .64364 m .4752 .61798 L .48287 .61582 L p .664 .485 .633 r
F P
0 g
s
.4752 .61798 m .47876 .64364 L .4722 .64563 L p .612 .451 .639 r
F P
0 g
s
.5467 .87073 m .52639 .86422 L .54425 .87133 L closepath p .509 .871 .985 r
F P
0 g
s
.48336 .85382 m .44956 .82251 L .45021 .82506 L p .032 .306 .796 r
F P
0 g
s
.45021 .82506 m .48371 .85519 L .48336 .85382 L p .032 .306 .796 r
F P
0 g
s
.50726 .87099 m .52639 .86422 L .50485 .87036 L closepath p .346 .734 .985 r
F P
0 g
s
.48287 .61582 m .47544 .59478 L .48517 .59271 L p .766 .675 .762 r
F P
0 g
s
.48287 .61582 m .48567 .64167 L .47876 .64364 L p .664 .485 .633 r
F P
0 g
s
.54186 .49361 m .53993 .52295 L .52942 .5172 L p .897 .781 .725 r
F P
0 g
s
.62119 .76226 m .60141 .80899 L .60006 .8066 L p .983 .869 .645 r
F P
0 g
s
.60006 .8066 m .61962 .75929 L .62119 .76226 L p .983 .869 .645 r
F P
0 g
s
.72045 .54285 m .68454 .57484 L .66688 .56974 L p .672 .611 .779 r
F P
0 g
s
.66688 .56974 m .69842 .53841 L .72045 .54285 L p .672 .611 .779 r
F P
0 g
s
.52639 .86422 m .54907 .87006 L .5467 .87073 L closepath p .529 .879 .986 r
F P
0 g
s
.67183 .50151 m .68014 .47063 L .70715 .46748 L p .65 .469 .625 r
F P
0 g
s
.68014 .47063 m .67183 .50151 L .64801 .5036 L p .626 .449 .623 r
F P
0 g
s
.42965 .57966 m .45011 .60226 L .45753 .59965 L p .615 .704 .908 r
F P
0 g
s
.45011 .60226 m .42965 .57966 L .42257 .58347 L p .534 .674 .927 r
F P
0 g
s
.50485 .87036 m .52639 .86422 L .50252 .86965 L closepath p .347 .728 .986 r
F P
0 g
s
.36216 .37573 m .38059 .36633 L .36559 .37469 L p .361 .804 .652 r
F P
0 g
s
.36559 .37469 m .34539 .38484 L .36216 .37573 L p .361 .804 .652 r
F P
0 g
s
.4537 .80487 m .43529 .75558 L .43344 .75864 L p .195 .2 .637 r
F P
0 g
s
.43344 .75864 m .45218 .80727 L .4537 .80487 L p .195 .2 .637 r
F P
0 g
s
.70061 .58096 m .74044 .54896 L .75709 .55656 L p .719 .687 .819 r
F P
0 g
s
.74044 .54896 m .70061 .58096 L .68454 .57484 L p .696 .646 .796 r
F P
0 g
s
.45419 .38372 m .46216 .37687 L .48231 .3888 L p .757 .245 0 r
F P
0 g
s
.45374 .73998 m .44823 .69195 L .44434 .69411 L p .377 .237 .56 r
F P
0 g
s
.44434 .69411 m .44979 .74227 L .45374 .73998 L p .377 .237 .56 r
F P
0 g
s
.4949 .59095 m .48731 .56778 L .49932 .5674 L p .836 .791 .808 r
F P
0 g
s
.48731 .56778 m .4949 .59095 L .48517 .59271 L p .804 .777 .827 r
F P
0 g
s
.52639 .86422 m .55135 .86931 L .54907 .87006 L closepath p .549 .886 .986 r
F P
0 g
s
.60284 .82359 m .56925 .85451 L .56952 .85315 L p .88 .992 .796 r
F P
0 g
s
.56952 .85315 m .60339 .82115 L .60284 .82359 L p .88 .992 .796 r
F P
0 g
s
.52811 .63281 m .52814 .67139 L .52129 .67198 L p .744 .479 .53 r
F P
0 g
s
.52129 .67198 m .52135 .63368 L .52811 .63281 L p .744 .479 .53 r
F P
0 g
s
.6121 .69774 m .60538 .74449 L .60135 .74166 L p .894 .66 .577 r
F P
0 g
s
.60135 .74166 m .6075 .69431 L .6121 .69774 L p .894 .66 .577 r
F P
0 g
s
.50252 .86965 m .52639 .86422 L .50029 .86887 L closepath p .351 .721 .986 r
F P
0 g
s
.68454 .57484 m .72045 .54285 L .74044 .54896 L p .696 .646 .796 r
F P
0 g
s
.78541 .47224 m .77182 .51037 L .74893 .50485 L p .758 .572 .645 r
F P
0 g
s
.74893 .50485 m .76136 .46786 L .78541 .47224 L p .758 .572 .645 r
F P
0 g
s
.47406 .68204 m .4722 .64563 L .4661 .64759 L p .534 .34 .564 r
F P
0 g
s
.4661 .64759 m .46809 .68393 L .47406 .68204 L p .534 .34 .564 r
F P
0 g
s
.54277 .46722 m .54186 .49361 L .52985 .48495 L p .927 .726 .611 r
F P
0 g
s
.52985 .48495 m .53006 .45606 L .54277 .46722 L p .927 .726 .611 r
F P
0 g
s
.51029 .56759 m .50626 .5402 L .5185 .54313 L p .867 .826 .805 r
F P
0 g
s
.50626 .5402 m .51029 .56759 L .49932 .5674 L p .847 .809 .813 r
F P
0 g
s
.38791 .56015 m .41786 .58737 L .42257 .58347 L p .424 .63 .94 r
F P
0 g
s
.41786 .58737 m .38791 .56015 L .38588 .56653 L p .279 .57 .936 r
F P
0 g
s
.52639 .86422 m .55353 .86848 L .55135 .86931 L closepath p .569 .893 .986 r
F P
0 g
s
.50029 .86887 m .52639 .86422 L .49816 .86802 L closepath p .355 .716 .986 r
F P
0 g
s
.48319 .85245 m .44921 .81993 L .44956 .82251 L p .096 .33 .804 r
F P
0 g
s
.44956 .82251 m .48336 .85382 L .48319 .85245 L p .096 .33 .804 r
F P
0 g
s
.52135 .63368 m .52129 .67198 L .51437 .67285 L p .733 .475 .539 r
F P
0 g
s
.51437 .67285 m .51439 .63486 L .52135 .63368 L p .733 .475 .539 r
F P
0 g
s
.69743 .50068 m .67566 .53563 L .65343 .53432 L p .649 .533 .709 r
F P
0 g
s
.65343 .53432 m .67183 .50151 L .69743 .50068 L p .649 .533 .709 r
F P
0 g
s
.52639 .86422 m .55561 .86759 L .55353 .86848 L closepath p .588 .898 .986 r
F P
0 g
s
.49816 .86802 m .52639 .86422 L .49614 .86711 L closepath p .361 .71 .986 r
F P
0 g
s
.38588 .56653 m .35401 .53339 L .35587 .54317 L p .061 .408 .86 r
F P
0 g
s
.33105 .50834 m .35587 .54317 L .35401 .53339 L p 0 .21 .736 r
F P
0 g
s
.61962 .75929 m .60006 .8066 L .59839 .80424 L p .972 .841 .655 r
F P
0 g
s
.59839 .80424 m .61761 .75631 L .61962 .75929 L p .972 .841 .655 r
F P
0 g
s
.45753 .59965 m .43889 .57613 L .42965 .57966 L p .615 .704 .908 r
F P
0 g
s
.44985 .57306 m .46609 .59713 L .45753 .59965 L p .677 .727 .887 r
F P
0 g
s
.45753 .59965 m .43889 .57613 L .44985 .57306 L p .677 .727 .887 r
F P
0 g
s
.60339 .82115 m .56952 .85315 L .56961 .85178 L p .898 .98 .804 r
F P
0 g
s
.56961 .85178 m .60363 .81871 L .60339 .82115 L p .898 .98 .804 r
F P
0 g
s
.52639 .86422 m .55757 .86664 L .55561 .86759 L closepath p .606 .903 .985 r
F P
0 g
s
.6075 .69431 m .60135 .74166 L .59699 .73892 L p .872 .636 .577 r
F P
0 g
s
.59699 .73892 m .60251 .69094 L .6075 .69431 L p .872 .636 .577 r
F P
0 g
s
.47406 .68204 m .4722 .64563 L .47876 .64364 L p .575 .372 .568 r
F P
0 g
s
.48517 .59271 m .47469 .56883 L .48731 .56778 L p .804 .777 .827 r
F P
0 g
s
.47469 .56883 m .48517 .59271 L .47544 .59478 L p .768 .762 .847 r
F P
0 g
s
.69743 .50068 m .70715 .46748 L .73474 .46637 L p .68 .495 .63 r
F P
0 g
s
.70715 .46748 m .69743 .50068 L .67183 .50151 L p .65 .469 .625 r
F P
0 g
s
.45553 .80254 m .43748 .75265 L .43529 .75558 L p .252 .233 .643 r
F P
0 g
s
.43529 .75558 m .4537 .80487 L .45553 .80254 L p .252 .233 .643 r
F P
0 g
s
.51439 .63486 m .51437 .67285 L .50742 .67397 L p .718 .468 .547 r
F P
0 g
s
.50742 .67397 m .50727 .6363 L .51439 .63486 L p .718 .468 .547 r
F P
0 g
s
.49614 .86711 m .52639 .86422 L .49425 .86613 L closepath p .368 .705 .985 r
F P
0 g
s
.45804 .73781 m .45255 .68987 L .44823 .69195 L p .419 .27 .57 r
F P
0 g
s
.44823 .69195 m .45374 .73998 L .45804 .73781 L p .419 .27 .57 r
F P
0 g
s
.52639 .86422 m .5594 .86562 L .55757 .86664 L closepath p .624 .906 .984 r
F P
0 g
s
.76136 .46786 m .74893 .50485 L .72362 .50167 L p .716 .529 .636 r
F P
0 g
s
.72362 .50167 m .73474 .46637 L .76136 .46786 L p .716 .529 .636 r
F P
0 g
s
.52942 .5172 m .52985 .48495 L .54186 .49361 L p .897 .781 .725 r
F P
0 g
s
.48319 .85107 m .44918 .81735 L .44921 .81993 L p .155 .351 .807 r
F P
0 g
s
.44921 .81993 m .48319 .85245 L .48319 .85107 L p .155 .351 .807 r
F P
0 g
s
.462 .5706 m .47544 .59478 L .46609 .59713 L p .727 .745 .867 r
F P
0 g
s
.46609 .59713 m .44985 .57306 L .462 .5706 L p .727 .745 .867 r
F P
0 g
s
.47544 .59478 m .462 .5706 L .47469 .56883 L p .768 .762 .847 r
F P
0 g
s
.48034 .6802 m .47876 .64364 L .48567 .64167 L p .615 .402 .569 r
F P
0 g
s
.47876 .64364 m .48034 .6802 L .47406 .68204 L p .575 .372 .568 r
F P
0 g
s
.50727 .6363 m .50742 .67397 L .50048 .6753 L p .699 .458 .555 r
F P
0 g
s
.50048 .6753 m .50004 .63795 L .50727 .6363 L p .699 .458 .555 r
F P
0 g
s
.49425 .86613 m .52639 .86422 L .49248 .8651 L closepath p .376 .699 .984 r
F P
0 g
s
.73474 .46637 m .72362 .50167 L .69743 .50068 L p .68 .495 .63 r
F P
0 g
s
.35401 .53339 m .3286 .49473 L .33105 .50834 L p 0 .21 .736 r
F P
0 g
s
.79082 .51812 m .75709 .55656 L .74044 .54896 L p .765 .675 .763 r
F P
0 g
s
.74044 .54896 m .77182 .51037 L .79082 .51812 L p .765 .675 .763 r
F P
0 g
s
.52639 .86422 m .56111 .86455 L .5594 .86562 L closepath p .641 .908 .982 r
F P
0 g
s
.60251 .69094 m .59699 .73892 L .59232 .73631 L p .853 .614 .576 r
F P
0 g
s
.59232 .73631 m .59718 .6877 L .60251 .69094 L p .853 .614 .576 r
F P
0 g
s
.50004 .63795 m .50048 .6753 L .49362 .67681 L p .676 .444 .562 r
F P
0 g
s
.49362 .67681 m .49281 .63976 L .50004 .63795 L p .676 .444 .562 r
F P
0 g
s
.35401 .53339 m .38588 .56653 L .38791 .56015 L p .256 .502 .898 r
F P
0 g
s
.48688 .67845 m .48567 .64167 L .49281 .63976 L p .648 .425 .567 r
F P
0 g
s
.48567 .64167 m .48688 .67845 L .48034 .6802 L p .615 .402 .569 r
F P
0 g
s
.60363 .81871 m .56961 .85178 L .56952 .85041 L p .909 .964 .807 r
F P
0 g
s
.56952 .85041 m .60356 .81627 L .60363 .81871 L p .909 .964 .807 r
F P
0 g
s
.49281 .63976 m .49362 .67681 L .48688 .67845 L p .648 .425 .567 r
F P
0 g
s
.49248 .8651 m .52639 .86422 L .49084 .86401 L closepath p .385 .695 .981 r
F P
0 g
s
.43008 .37532 m .4408 .36796 L .46216 .37687 L p .687 .157 0 r
F P
0 g
s
.61761 .75631 m .59839 .80424 L .59641 .80192 L p .957 .813 .66 r
F P
0 g
s
.59641 .80192 m .61517 .75333 L .61761 .75631 L p .957 .813 .66 r
F P
0 g
s
.36216 .37573 m .38059 .36633 L .39883 .36234 L p .051 0 0 r
F P
0 g
s
.52639 .86422 m .56267 .86343 L .56111 .86455 L closepath p .656 .909 .98 r
F P
0 g
s
.45765 .80029 m .44003 .74985 L .43748 .75265 L p .302 .263 .648 r
F P
0 g
s
.43748 .75265 m .45553 .80254 L .45765 .80029 L p .302 .263 .648 r
F P
0 g
s
.72362 .50167 m .69842 .53841 L .67566 .53563 L p .673 .558 .716 r
F P
0 g
s
.67566 .53563 m .69743 .50068 L .72362 .50167 L p .673 .558 .716 r
F P
0 g
s
.5185 .54313 m .51679 .51103 L .52942 .5172 L p .877 .811 .781 r
F P
0 g
s
.51679 .51103 m .5185 .54313 L .50626 .5402 L p .864 .794 .781 r
F P
0 g
s
.46267 .73576 m .45731 .68785 L .45255 .68987 L p .457 .299 .578 r
F P
0 g
s
.45255 .68987 m .45804 .73781 L .46267 .73576 L p .457 .299 .578 r
F P
0 g
s
.49084 .86401 m .52639 .86422 L .48935 .86286 L closepath p .394 .69 .979 r
F P
0 g
s
.48338 .8497 m .44946 .81478 L .44918 .81735 L p .207 .37 .806 r
F P
0 g
s
.44918 .81735 m .48319 .85107 L .48338 .8497 L p .207 .37 .806 r
F P
0 g
s
.59718 .6877 m .59232 .73631 L .58736 .73385 L p .836 .596 .575 r
F P
0 g
s
.58736 .73385 m .59157 .68464 L .59718 .6877 L p .836 .596 .575 r
F P
0 g
s
.51509 .42316 m .51475 .44373 L .49649 .43119 L p .919 .59 .404 r
F P
0 g
s
.49649 .43119 m .49739 .40877 L .51509 .42316 L p .919 .59 .404 r
F P
0 g
s
.52639 .86422 m .56409 .86226 L .56267 .86343 L closepath p .67 .908 .977 r
F P
0 g
s
.32671 .42688 m .33323 .39771 L .3261 .41347 L p 0 0 0 r
F P
0 g
s
.3261 .41347 m .31949 .44164 L .32671 .42688 L p 0 0 0 r
F P
0 g
s
.49932 .5674 m .49221 .53783 L .50626 .5402 L p .847 .809 .813 r
F P
0 g
s
.49221 .53783 m .49932 .5674 L .48731 .56778 L p .821 .791 .824 r
F P
0 g
s
.48935 .86286 m .52639 .86422 L .48801 .86167 L closepath p .404 .686 .976 r
F P
0 g
s
.60356 .81627 m .56952 .85041 L .56925 .84905 L p .914 .944 .808 r
F P
0 g
s
.56925 .84905 m .60316 .81383 L .60356 .81627 L p .914 .944 .808 r
F P
0 g
s
.39326 .55391 m .42257 .58347 L .42965 .57966 L p .533 .67 .925 r
F P
0 g
s
.42257 .58347 m .39326 .55391 L .38791 .56015 L p .424 .63 .94 r
F P
0 g
s
.59157 .68464 m .58736 .73385 L .58215 .73157 L p .822 .58 .573 r
F P
0 g
s
.58215 .73157 m .58575 .6818 L .59157 .68464 L p .822 .58 .573 r
F P
0 g
s
.52639 .86422 m .56536 .86104 L .56409 .86226 L closepath p .683 .907 .974 r
F P
0 g
s
.52985 .48495 m .52942 .5172 L .51679 .51103 L p .891 .768 .719 r
F P
0 g
s
.77182 .51037 m .74044 .54896 L .72045 .54285 L p .731 .627 .742 r
F P
0 g
s
.61517 .75333 m .59641 .80192 L .59412 .79965 L p .94 .785 .663 r
F P
0 g
s
.59412 .79965 m .61231 .75035 L .61517 .75333 L p .94 .785 .663 r
F P
0 g
s
.48801 .86167 m .52639 .86422 L .48682 .86044 L closepath p .415 .682 .972 r
F P
0 g
s
.46006 .79812 m .44293 .74719 L .44003 .74985 L p .346 .29 .651 r
F P
0 g
s
.44003 .74985 m .45765 .80029 L .46006 .79812 L p .346 .29 .651 r
F P
0 g
s
.74893 .50485 m .72045 .54285 L .69842 .53841 L p .701 .589 .727 r
F P
0 g
s
.69842 .53841 m .72362 .50167 L .74893 .50485 L p .701 .589 .727 r
F P
0 g
s
.40579 .37091 m .4193 .36294 L .4408 .36796 L p .57 .021 0 r
F P
0 g
s
.48373 .84833 m .45006 .81224 L .44946 .81478 L p .255 .386 .804 r
F P
0 g
s
.44946 .81478 m .48338 .8497 L .48373 .84833 L p .255 .386 .804 r
F P
0 g
s
.46762 .73381 m .4625 .68587 L .45731 .68785 L p .491 .326 .584 r
F P
0 g
s
.45731 .68785 m .46267 .73576 L .46762 .73381 L p .491 .326 .584 r
F P
0 g
s
.38269 .37099 m .39883 .36234 L .4193 .36294 L p .373 0 0 r
F P
0 g
s
.39883 .36234 m .38269 .37099 L .36216 .37573 L p .051 0 0 r
F P
0 g
s
.72045 .54285 m .74893 .50485 L .77182 .51037 L p .731 .627 .742 r
F P
0 g
s
.52639 .86422 m .56647 .85979 L .56536 .86104 L closepath p .695 .905 .97 r
F P
0 g
s
.58575 .6818 m .58215 .73157 L .57672 .7295 L p .808 .566 .572 r
F P
0 g
s
.57672 .7295 m .57976 .67924 L .58575 .6818 L p .808 .566 .572 r
F P
0 g
s
.48682 .86044 m .52639 .86422 L .48579 .85917 L closepath p .425 .678 .968 r
F P
0 g
s
.53006 .45606 m .52985 .48495 L .51539 .47548 L p .918 .713 .609 r
F P
0 g
s
.51539 .47548 m .51475 .44373 L .53006 .45606 L p .918 .713 .609 r
F P
0 g
s
.4193 .36294 m .40579 .37091 L .38269 .37099 L p .373 0 0 r
F P
0 g
s
.60316 .81383 m .56925 .84905 L .56881 .84769 L p .915 .923 .805 r
F P
0 g
s
.56881 .84769 m .60245 .8114 L .60316 .81383 L p .915 .923 .805 r
F P
0 g
s
.52639 .86422 m .56742 .85851 L .56647 .85979 L closepath p .706 .902 .966 r
F P
0 g
s
.57976 .67924 m .57672 .7295 L .5711 .72766 L p .797 .554 .57 r
F P
0 g
s
.5711 .72766 m .57364 .67699 L .57976 .67924 L p .797 .554 .57 r
F P
0 g
s
.33055 .48134 m .31949 .44164 L .31745 .45788 L p 0 0 .539 r
F P
0 g
s
.31745 .45788 m .3286 .49473 L .33055 .48134 L p 0 0 .539 r
F P
0 g
s
.48579 .85917 m .52639 .86422 L .48493 .85787 L closepath p .436 .674 .964 r
F P
0 g
s
.61231 .75035 m .59412 .79965 L .59154 .79744 L p .922 .759 .663 r
F P
0 g
s
.59154 .79744 m .60904 .7474 L .61231 .75035 L p .922 .759 .663 r
F P
0 g
s
.48427 .84697 m .45096 .80973 L .45006 .81224 L p .297 .401 .8 r
F P
0 g
s
.45006 .81224 m .48373 .84833 L .48427 .84697 L p .297 .401 .8 r
F P
0 g
s
.47286 .73197 m .46809 .68393 L .4625 .68587 L p .522 .35 .589 r
F P
0 g
s
.4625 .68587 m .46762 .73381 L .47286 .73197 L p .522 .35 .589 r
F P
0 g
s
.46276 .79604 m .44618 .74467 L .44293 .74719 L p .386 .314 .654 r
F P
0 g
s
.44293 .74719 m .46006 .79812 L .46276 .79604 L p .386 .314 .654 r
F P
0 g
s
.57364 .67699 m .5711 .72766 L .5653 .72607 L p .787 .544 .569 r
F P
0 g
s
.5653 .72607 m .56741 .67508 L .57364 .67699 L p .787 .544 .569 r
F P
0 g
s
.52639 .86422 m .5682 .8572 L .56742 .85851 L closepath p .715 .897 .962 r
F P
0 g
s
.48731 .56778 m .47667 .53636 L .49221 .53783 L p .821 .791 .824 r
F P
0 g
s
.47667 .53636 m .48731 .56778 L .47469 .56883 L p .791 .772 .836 r
F P
0 g
s
.48493 .85787 m .52639 .86422 L .48424 .85654 L closepath p .447 .671 .959 r
F P
0 g
s
.60245 .8114 m .56881 .84769 L .56819 .84636 L p .912 .901 .802 r
F P
0 g
s
.56819 .84636 m .60141 .80899 L .60245 .8114 L p .912 .901 .802 r
F P
0 g
s
.56741 .67508 m .5653 .72607 L .55935 .72474 L p .777 .535 .569 r
F P
0 g
s
.55935 .72474 m .56109 .67354 L .56741 .67508 L p .777 .535 .569 r
F P
0 g
s
.52639 .86422 m .56881 .85586 L .5682 .8572 L closepath p .723 .893 .957 r
F P
0 g
s
.40195 .54816 m .42965 .57966 L .43889 .57613 L p .615 .698 .903 r
F P
0 g
s
.42965 .57966 m .40195 .54816 L .39326 .55391 L p .533 .67 .925 r
F P
0 g
s
.51679 .51103 m .51539 .47548 L .52985 .48495 L p .891 .768 .719 r
F P
0 g
s
.47836 .73025 m .47406 .68204 L .46809 .68393 L p .549 .371 .592 r
F P
0 g
s
.46809 .68393 m .47286 .73197 L .47836 .73025 L p .549 .371 .592 r
F P
0 g
s
.48498 .84564 m .45218 .80727 L .45096 .80973 L p .335 .414 .795 r
F P
0 g
s
.45096 .80973 m .48427 .84697 L .48498 .84564 L p .335 .414 .795 r
F P
0 g
s
.56109 .67354 m .55935 .72474 L .55327 .72369 L p .768 .527 .569 r
F P
0 g
s
.55327 .72369 m .55469 .67237 L .56109 .67354 L p .768 .527 .569 r
F P
0 g
s
.48424 .85654 m .52639 .86422 L .48371 .85519 L closepath p .458 .668 .954 r
F P
0 g
s
.60904 .7474 m .59154 .79744 L .58868 .7953 L p .904 .735 .662 r
F P
0 g
s
.58868 .7953 m .60538 .74449 L .60904 .7474 L p .904 .735 .662 r
F P
0 g
s
.46573 .79405 m .44979 .74227 L .44618 .74467 L p .421 .337 .655 r
F P
0 g
s
.44618 .74467 m .46276 .79604 L .46573 .79405 L p .421 .337 .655 r
F P
0 g
s
.52639 .86422 m .56925 .85451 L .56881 .85586 L closepath p .73 .887 .952 r
F P
0 g
s
.55469 .67237 m .55327 .72369 L .54708 .72291 L p .76 .52 .57 r
F P
0 g
s
.54708 .72291 m .54819 .67159 L .55469 .67237 L p .76 .52 .57 r
F P
0 g
s
.50626 .5402 m .50178 .50497 L .51679 .51103 L p .864 .794 .781 r
F P
0 g
s
.50178 .50497 m .50626 .5402 L .49221 .53783 L p .844 .774 .785 r
F P
0 g
s
.60141 .80899 m .56819 .84636 L .56739 .84504 L p .906 .878 .797 r
F P
0 g
s
.56739 .84504 m .60006 .8066 L .60141 .80899 L p .906 .878 .797 r
F P
0 g
s
.38791 .56015 m .35593 .52359 L .35401 .53339 L p .256 .502 .898 r
F P
0 g
s
.3286 .49473 m .35401 .53339 L .35593 .52359 L p .155 .347 .803 r
F P
0 g
s
.35593 .52359 m .38791 .56015 L .39326 .55391 L p .41 .567 .899 r
F P
0 g
s
.48371 .85519 m .52639 .86422 L .48336 .85382 L closepath p .469 .666 .948 r
F P
0 g
s
.47836 .73025 m .47406 .68204 L .48034 .6802 L p .578 .392 .593 r
F P
0 g
s
.54819 .67159 m .54708 .72291 L .5408 .72241 L p .751 .513 .572 r
F P
0 g
s
.5408 .72241 m .5416 .67117 L .54819 .67159 L p .751 .513 .572 r
F P
0 g
s
.49739 .40877 m .49649 .43119 L .47534 .41948 L p .89 .562 .422 r
F P
0 g
s
.47534 .41948 m .47692 .39523 L .49739 .40877 L p .89 .562 .422 r
F P
0 g
s
.52639 .86422 m .56952 .85315 L .56925 .85451 L closepath p .737 .881 .947 r
F P
0 g
s
.48586 .84433 m .4537 .80487 L .45218 .80727 L p .37 .427 .79 r
F P
0 g
s
.45218 .80727 m .48498 .84564 L .48586 .84433 L p .37 .427 .79 r
F P
0 g
s
.60538 .74449 m .58868 .7953 L .58554 .79324 L p .887 .712 .66 r
F P
0 g
s
.58554 .79324 m .60135 .74166 L .60538 .74449 L p .887 .712 .66 r
F P
0 g
s
.47469 .56883 m .46022 .53604 L .47667 .53636 L p .791 .772 .836 r
F P
0 g
s
.46022 .53604 m .47469 .56883 L .462 .5706 L p .758 .755 .85 r
F P
0 g
s
.5416 .67117 m .5408 .72241 L .53445 .72219 L p .742 .507 .574 r
F P
0 g
s
.53445 .72219 m .53492 .67111 L .5416 .67117 L p .742 .507 .574 r
F P
0 g
s
.48336 .85382 m .52639 .86422 L .48319 .85245 L closepath p .479 .664 .943 r
F P
0 g
s
.48411 .72866 m .48034 .6802 L .48688 .67845 L p .606 .413 .594 r
F P
0 g
s
.48034 .6802 m .48411 .72866 L .47836 .73025 L p .578 .392 .593 r
F P
0 g
s
.46897 .79216 m .45374 .73998 L .44979 .74227 L p .453 .357 .657 r
F P
0 g
s
.44979 .74227 m .46573 .79405 L .46897 .79216 L p .453 .357 .657 r
F P
0 g
s
.43889 .57613 m .41366 .54326 L .40195 .54816 L p .615 .698 .903 r
F P
0 g
s
.42782 .5395 m .44985 .57306 L .43889 .57613 L p .674 .719 .883 r
F P
0 g
s
.43889 .57613 m .41366 .54326 L .42782 .5395 L p .674 .719 .883 r
F P
0 g
s
.52639 .86422 m .56961 .85178 L .56952 .85315 L closepath p .742 .875 .942 r
F P
0 g
s
.53492 .67111 m .53445 .72219 L .52804 .72222 L p .731 .5 .577 r
F P
0 g
s
.52804 .72222 m .52814 .67139 L .53492 .67111 L p .731 .5 .577 r
F P
0 g
s
.60006 .8066 m .56739 .84504 L .56643 .84374 L p .899 .856 .791 r
F P
0 g
s
.56643 .84374 m .59839 .80424 L .60006 .8066 L p .899 .856 .791 r
F P
0 g
s
.33919 .41458 m .34539 .38484 L .33323 .39771 L p .026 0 .219 r
F P
0 g
s
.33323 .39771 m .32671 .42688 L .33919 .41458 L p .026 0 .219 r
F P
0 g
s
.48319 .85245 m .52639 .86422 L .48319 .85107 L closepath p .49 .662 .938 r
F P
0 g
s
.52814 .67139 m .52804 .72222 L .52161 .72252 L p .719 .492 .58 r
F P
0 g
s
.52161 .72252 m .52129 .67198 L .52814 .67139 L p .719 .492 .58 r
F P
0 g
s
.51539 .47548 m .51679 .51103 L .50178 .50497 L p .876 .749 .719 r
F P
0 g
s
.49006 .7272 m .48688 .67845 L .49362 .67681 L p .631 .431 .593 r
F P
0 g
s
.48688 .67845 m .49006 .7272 L .48411 .72866 L p .606 .413 .594 r
F P
0 g
s
.35593 .52359 m .33055 .48134 L .3286 .49473 L p .155 .347 .803 r
F P
0 g
s
.48691 .84305 m .45553 .80254 L .4537 .80487 L p .401 .439 .784 r
F P
0 g
s
.4537 .80487 m .48586 .84433 L .48691 .84305 L p .401 .439 .784 r
F P
0 g
s
.52639 .86422 m .56952 .85041 L .56961 .85178 L closepath p .746 .868 .936 r
F P
0 g
s
.462 .5706 m .44364 .53707 L .46022 .53604 L p .758 .755 .85 r
F P
0 g
s
.44364 .53707 m .462 .5706 L .44985 .57306 L p .719 .737 .865 r
F P
0 g
s
.52129 .67198 m .52161 .72252 L .51517 .72305 L p .706 .483 .583 r
F P
0 g
s
.51517 .72305 m .51437 .67285 L .52129 .67198 L p .706 .483 .583 r
F P
0 g
s
.60135 .74166 m .58554 .79324 L .58215 .79128 L p .87 .692 .658 r
F P
0 g
s
.58215 .79128 m .59699 .73892 L .60135 .74166 L p .87 .692 .658 r
F P
0 g
s
.49618 .72589 m .49362 .67681 L .50048 .6753 L p .654 .447 .591 r
F P
0 g
s
.49362 .67681 m .49618 .72589 L .49006 .7272 L p .631 .431 .593 r
F P
0 g
s
.44985 .57306 m .42782 .5395 L .44364 .53707 L p .719 .737 .865 r
F P
0 g
s
.51437 .67285 m .51517 .72305 L .50877 .7238 L p .691 .473 .586 r
F P
0 g
s
.50877 .7238 m .50742 .67397 L .51437 .67285 L p .691 .473 .586 r
F P
0 g
s
.50242 .72475 m .50048 .6753 L .50742 .67397 L p .673 .461 .589 r
F P
0 g
s
.50048 .6753 m .50242 .72475 L .49618 .72589 L p .654 .447 .591 r
F P
0 g
s
.50742 .67397 m .50877 .7238 L .50242 .72475 L p .673 .461 .589 r
F P
0 g
s
.48319 .85107 m .52639 .86422 L .48338 .8497 L closepath p .5 .66 .933 r
F P
0 g
s
.47245 .79037 m .45804 .73781 L .45374 .73998 L p .482 .376 .657 r
F P
0 g
s
.45374 .73998 m .46897 .79216 L .47245 .79037 L p .482 .376 .657 r
F P
0 g
s
.59839 .80424 m .56643 .84374 L .5653 .84248 L p .89 .834 .785 r
F P
0 g
s
.5653 .84248 m .59641 .80192 L .59839 .80424 L p .89 .834 .785 r
F P
0 g
s
.52639 .86422 m .56925 .84905 L .56952 .85041 L closepath p .749 .86 .931 r
F P
0 g
s
.51475 .44373 m .51539 .47548 L .49813 .46596 L p .899 .691 .613 r
F P
0 g
s
.49813 .46596 m .49649 .43119 L .51475 .44373 L p .899 .691 .613 r
F P
0 g
s
.48338 .8497 m .52639 .86422 L .48373 .84833 L closepath p .51 .659 .927 r
F P
0 g
s
.48813 .84181 m .45765 .80029 L .45553 .80254 L p .429 .449 .779 r
F P
0 g
s
.45553 .80254 m .48691 .84305 L .48813 .84181 L p .429 .449 .779 r
F P
0 g
s
.59699 .73892 m .58215 .79128 L .57851 .78942 L p .855 .673 .656 r
F P
0 g
s
.57851 .78942 m .59232 .73631 L .59699 .73892 L p .855 .673 .656 r
F P
0 g
s
.52639 .86422 m .56881 .84769 L .56925 .84905 L closepath p .751 .853 .926 r
F P
0 g
s
.48373 .84833 m .52639 .86422 L .48427 .84697 L closepath p .52 .658 .922 r
F P
0 g
s
.47618 .7887 m .46267 .73576 L .45804 .73781 L p .509 .394 .658 r
F P
0 g
s
.45804 .73781 m .47245 .79037 L .47618 .7887 L p .509 .394 .658 r
F P
0 g
s
.59641 .80192 m .5653 .84248 L .564 .84126 L p .88 .814 .779 r
F P
0 g
s
.564 .84126 m .59412 .79965 L .59641 .80192 L p .88 .814 .779 r
F P
0 g
s
.52639 .86422 m .56819 .84636 L .56881 .84769 L closepath p .753 .845 .92 r
F P
0 g
s
.59232 .73631 m .57851 .78942 L .57465 .78769 L p .84 .656 .653 r
F P
0 g
s
.57465 .78769 m .58736 .73385 L .59232 .73631 L p .84 .656 .653 r
F P
0 g
s
.49221 .53783 m .48443 .4996 L .50178 .50497 L p .844 .774 .785 r
F P
0 g
s
.48443 .4996 m .49221 .53783 L .47667 .53636 L p .818 .753 .791 r
F P
0 g
s
.48951 .84061 m .46006 .79812 L .45765 .80029 L p .455 .46 .774 r
F P
0 g
s
.45765 .80029 m .48813 .84181 L .48951 .84061 L p .455 .46 .774 r
F P
0 g
s
.52639 .86422 m .56739 .84504 L .56819 .84636 L closepath p .753 .837 .915 r
F P
0 g
s
.52639 .86422 m .56643 .84374 L .56739 .84504 L closepath p .754 .829 .91 r
F P
0 g
s
.52639 .86422 m .5653 .84248 L .56643 .84374 L closepath p .753 .821 .905 r
F P
0 g
s
.52639 .86422 m .564 .84126 L .5653 .84248 L closepath p .752 .813 .9 r
F P
0 g
s
.52639 .86422 m .56255 .84007 L .564 .84126 L closepath p .75 .804 .896 r
F P
0 g
s
.52639 .86422 m .56094 .83894 L .56255 .84007 L closepath p .748 .797 .892 r
F P
0 g
s
.52639 .86422 m .55919 .83785 L .56094 .83894 L closepath p .746 .789 .888 r
F P
0 g
s
.52639 .86422 m .55729 .83682 L .55919 .83785 L closepath p .743 .781 .884 r
F P
0 g
s
.52639 .86422 m .55527 .83586 L .55729 .83682 L closepath p .74 .774 .88 r
F P
0 g
s
.52639 .86422 m .55313 .83496 L .55527 .83586 L closepath p .736 .767 .877 r
F P
0 g
s
.52639 .86422 m .55087 .83413 L .55313 .83496 L closepath p .733 .76 .874 r
F P
0 g
s
.52639 .86422 m .5485 .83337 L .55087 .83413 L closepath p .729 .753 .872 r
F P
0 g
s
.52639 .86422 m .54605 .8327 L .5485 .83337 L closepath p .724 .747 .87 r
F P
0 g
s
.52639 .86422 m .5435 .8321 L .54605 .8327 L closepath p .72 .74 .868 r
F P
0 g
s
.52639 .86422 m .54089 .83159 L .5435 .8321 L closepath p .715 .734 .866 r
F P
0 g
s
.52639 .86422 m .53821 .83117 L .54089 .83159 L closepath p .711 .728 .864 r
F P
0 g
s
.52639 .86422 m .53548 .83083 L .53821 .83117 L closepath p .706 .723 .863 r
F P
0 g
s
.52639 .86422 m .53272 .83058 L .53548 .83083 L closepath p .7 .718 .862 r
F P
0 g
s
.52639 .86422 m .52992 .83043 L .53272 .83058 L closepath p .695 .712 .862 r
F P
0 g
s
.52639 .86422 m .52711 .83036 L .52992 .83043 L closepath p .69 .707 .861 r
F P
0 g
s
.52639 .86422 m .5243 .83039 L .52711 .83036 L closepath p .684 .703 .861 r
F P
0 g
s
.52639 .86422 m .52149 .8305 L .5243 .83039 L closepath p .678 .698 .862 r
F P
0 g
s
.52639 .86422 m .51871 .83071 L .52149 .8305 L closepath p .672 .694 .862 r
F P
0 g
s
.52639 .86422 m .51596 .83101 L .51871 .83071 L closepath p .665 .69 .863 r
F P
0 g
s
.52639 .86422 m .51326 .83139 L .51596 .83101 L closepath p .659 .686 .864 r
F P
0 g
s
.52639 .86422 m .51061 .83186 L .51326 .83139 L closepath p .652 .682 .865 r
F P
0 g
s
.52639 .86422 m .50803 .83241 L .51061 .83186 L closepath p .645 .678 .867 r
F P
0 g
s
.52639 .86422 m .50552 .83305 L .50803 .83241 L closepath p .638 .675 .869 r
F P
0 g
s
.49455 .83731 m .52639 .86422 L .49651 .83632 L closepath p .6 .663 .883 r
F P
0 g
s
.49272 .83836 m .52639 .86422 L .49455 .83731 L closepath p .592 .661 .886 r
F P
0 g
s
.49104 .83946 m .52639 .86422 L .49272 .83836 L closepath p .583 .66 .89 r
F P
0 g
s
.48951 .84061 m .52639 .86422 L .49104 .83946 L closepath p .575 .658 .894 r
F P
0 g
s
.48813 .84181 m .52639 .86422 L .48951 .84061 L closepath p .566 .658 .898 r
F P
0 g
s
.48691 .84305 m .52639 .86422 L .48813 .84181 L closepath p .557 .657 .903 r
F P
0 g
s
.48586 .84433 m .52639 .86422 L .48691 .84305 L closepath p .548 .657 .907 r
F P
0 g
s
.48498 .84564 m .52639 .86422 L .48586 .84433 L closepath p .539 .657 .912 r
F P
0 g
s
.48427 .84697 m .52639 .86422 L .48498 .84564 L closepath p .53 .657 .917 r
F P
0 g
s
.50311 .83376 m .52639 .86422 L .50552 .83305 L closepath p .631 .672 .871 r
F P
0 g
s
.5008 .83454 m .52639 .86422 L .50311 .83376 L closepath p .623 .669 .874 r
F P
0 g
s
.49859 .8354 m .52639 .86422 L .5008 .83454 L closepath p .616 .667 .876 r
F P
0 g
s
.49651 .83632 m .52639 .86422 L .49859 .8354 L closepath p .608 .665 .879 r
F P
0 g
s
.50178 .50497 m .49813 .46596 L .51539 .47548 L p .876 .749 .719 r
F P
0 g
s
.47692 .39523 m .47534 .41948 L .45181 .4097 L p .851 .525 .435 r
F P
0 g
s
.45181 .4097 m .45419 .38372 L .47692 .39523 L p .851 .525 .435 r
F P
0 g
s
.36209 .51431 m .39326 .55391 L .40195 .54816 L p .523 .611 .882 r
F P
0 g
s
.39326 .55391 m .36209 .51431 L .35593 .52359 L p .41 .567 .899 r
F P
0 g
s
.59412 .79965 m .564 .84126 L .56255 .84007 L p .87 .794 .773 r
F P
0 g
s
.56255 .84007 m .59154 .79744 L .59412 .79965 L p .87 .794 .773 r
F P
0 g
s
.48013 .78713 m .46762 .73381 L .46267 .73576 L p .533 .41 .658 r
F P
0 g
s
.46267 .73576 m .47618 .7887 L .48013 .78713 L p .533 .41 .658 r
F P
0 g
s
.33741 .46896 m .32671 .42688 L .31949 .44164 L p .165 .184 .635 r
F P
0 g
s
.31949 .44164 m .33055 .48134 L .33741 .46896 L p .165 .184 .635 r
F P
0 g
s
.58736 .73385 m .57465 .78769 L .57058 .78609 L p .827 .641 .651 r
F P
0 g
s
.57058 .78609 m .58215 .73157 L .58736 .73385 L p .827 .641 .651 r
F P
0 g
s
.49104 .83946 m .46276 .79604 L .46006 .79812 L p .479 .47 .769 r
F P
0 g
s
.46006 .79812 m .48951 .84061 L .49104 .83946 L p .479 .47 .769 r
F P
0 g
s
.58215 .73157 m .57058 .78609 L .56632 .78463 L p .814 .627 .65 r
F P
0 g
s
.56632 .78463 m .57672 .7295 L .58215 .73157 L p .814 .627 .65 r
F P
0 g
s
.59154 .79744 m .56255 .84007 L .56094 .83894 L p .859 .775 .768 r
F P
0 g
s
.56094 .83894 m .58868 .7953 L .59154 .79744 L p .859 .775 .768 r
F P
0 g
s
.48429 .78569 m .47286 .73197 L .46762 .73381 L p .555 .425 .658 r
F P
0 g
s
.46762 .73381 m .48013 .78713 L .48429 .78569 L p .555 .425 .658 r
F P
0 g
s
.35649 .40557 m .36216 .37573 L .34539 .38484 L p .339 .066 .344 r
F P
0 g
s
.34539 .38484 m .33919 .41458 L .35649 .40557 L p .339 .066 .344 r
F P
0 g
s
.49272 .83836 m .46573 .79405 L .46276 .79604 L p .501 .479 .765 r
F P
0 g
s
.46276 .79604 m .49104 .83946 L .49272 .83836 L p .501 .479 .765 r
F P
0 g
s
.33055 .48134 m .35593 .52359 L .36209 .51431 L p .349 .445 .818 r
F P
0 g
s
.57672 .7295 m .56632 .78463 L .56189 .78332 L p .802 .614 .648 r
F P
0 g
s
.56189 .78332 m .5711 .72766 L .57672 .7295 L p .802 .614 .648 r
F P
0 g
s
.49813 .46596 m .50178 .50497 L .48443 .4996 L p .853 .726 .723 r
F P
0 g
s
.48864 .78436 m .47836 .73025 L .47286 .73197 L p .576 .439 .657 r
F P
0 g
s
.47286 .73197 m .48429 .78569 L .48864 .78436 L p .576 .439 .657 r
F P
0 g
s
.58868 .7953 m .56094 .83894 L .55919 .83785 L p .849 .758 .763 r
F P
0 g
s
.55919 .83785 m .58554 .79324 L .58868 .7953 L p .849 .758 .763 r
F P
0 g
s
.5711 .72766 m .56189 .78332 L .5573 .78218 L p .79 .603 .647 r
F P
0 g
s
.5573 .78218 m .5653 .72607 L .5711 .72766 L p .79 .603 .647 r
F P
0 g
s
.49455 .83731 m .46897 .79216 L .46573 .79405 L p .521 .488 .761 r
F P
0 g
s
.46573 .79405 m .49272 .83836 L .49455 .83731 L p .521 .488 .761 r
F P
0 g
s
.47667 .53636 m .46515 .49549 L .48443 .4996 L p .818 .753 .791 r
F P
0 g
s
.46515 .49549 m .47667 .53636 L .46022 .53604 L p .788 .732 .801 r
F P
0 g
s
.48864 .78436 m .47836 .73025 L .48411 .72866 L p .597 .453 .656 r
F P
0 g
s
.58554 .79324 m .55919 .83785 L .55729 .83682 L p .838 .742 .758 r
F P
0 g
s
.55729 .83682 m .58215 .79128 L .58554 .79324 L p .838 .742 .758 r
F P
0 g
s
.5653 .72607 m .5573 .78218 L .55258 .7812 L p .779 .592 .646 r
F P
0 g
s
.55258 .7812 m .55935 .72474 L .5653 .72607 L p .779 .592 .646 r
F P
0 g
s
.49649 .43119 m .49813 .46596 L .47814 .45722 L p .872 .665 .62 r
F P
0 g
s
.47814 .45722 m .47534 .41948 L .49649 .43119 L p .872 .665 .62 r
F P
0 g
s
.45419 .38372 m .45181 .4097 L .42683 .40282 L p .802 .478 .442 r
F P
0 g
s
.42683 .40282 m .43008 .37532 L .45419 .38372 L p .802 .478 .442 r
F P
0 g
s
.49651 .83632 m .47245 .79037 L .46897 .79216 L p .54 .497 .757 r
F P
0 g
s
.46897 .79216 m .49455 .83731 L .49651 .83632 L p .54 .497 .757 r
F P
0 g
s
.37252 .50615 m .40195 .54816 L .41366 .54326 L p .607 .644 .861 r
F P
0 g
s
.40195 .54816 m .37252 .50615 L .36209 .51431 L p .523 .611 .882 r
F P
0 g
s
.49315 .78317 m .48411 .72866 L .49006 .7272 L p .617 .467 .655 r
F P
0 g
s
.48411 .72866 m .49315 .78317 L .48864 .78436 L p .597 .453 .656 r
F P
0 g
s
.36209 .51431 m .33741 .46896 L .33055 .48134 L p .349 .445 .818 r
F P
0 g
s
.55935 .72474 m .55258 .7812 L .54775 .7804 L p .769 .582 .646 r
F P
0 g
s
.54775 .7804 m .55327 .72369 L .55935 .72474 L p .769 .582 .646 r
F P
0 g
s
.58215 .79128 m .55729 .83682 L .55527 .83586 L p .827 .727 .754 r
F P
0 g
s
.55527 .83586 m .57851 .78942 L .58215 .79128 L p .827 .727 .754 r
F P
0 g
s
.55327 .72369 m .54775 .7804 L .54282 .77978 L p .758 .572 .646 r
F P
0 g
s
.54282 .77978 m .54708 .72291 L .55327 .72369 L p .758 .572 .646 r
F P
0 g
s
.49782 .78212 m .49006 .7272 L .49618 .72589 L p .636 .48 .654 r
F P
0 g
s
.49006 .7272 m .49782 .78212 L .49315 .78317 L p .617 .467 .655 r
F P
0 g
s
.49859 .8354 m .47618 .7887 L .47245 .79037 L p .558 .506 .753 r
F P
0 g
s
.47245 .79037 m .49651 .83632 L .49859 .8354 L p .558 .506 .753 r
F P
0 g
s
.54708 .72291 m .54282 .77978 L .53783 .77935 L p .747 .563 .646 r
F P
0 g
s
.53783 .77935 m .5408 .72241 L .54708 .72291 L p .747 .563 .646 r
F P
0 g
s
.35649 .40557 m .36216 .37573 L .38269 .37099 L p .531 .231 .404 r
F P
0 g
s
.50261 .7812 m .49618 .72589 L .50242 .72475 L p .653 .492 .653 r
F P
0 g
s
.49618 .72589 m .50261 .7812 L .49782 .78212 L p .636 .48 .654 r
F P
0 g
s
.57851 .78942 m .55527 .83586 L .55313 .83496 L p .817 .712 .75 r
F P
0 g
s
.55313 .83496 m .57465 .78769 L .57851 .78942 L p .817 .712 .75 r
F P
0 g
s
.5408 .72241 m .53783 .77935 L .53278 .77909 L p .736 .553 .646 r
F P
0 g
s
.53278 .77909 m .53445 .72219 L .5408 .72241 L p .736 .553 .646 r
F P
0 g
s
.50751 .78044 m .50242 .72475 L .50877 .7238 L p .67 .504 .651 r
F P
0 g
s
.50242 .72475 m .50751 .78044 L .50261 .7812 L p .653 .492 .653 r
F P
0 g
s
.53445 .72219 m .53278 .77909 L .5277 .77901 L p .724 .544 .647 r
F P
0 g
s
.5277 .77901 m .52804 .72222 L .53445 .72219 L p .724 .544 .647 r
F P
0 g
s
.51249 .77983 m .50877 .7238 L .51517 .72305 L p .685 .514 .65 r
F P
0 g
s
.50877 .7238 m .51249 .77983 L .50751 .78044 L p .67 .504 .651 r
F P
0 g
s
.52804 .72222 m .5277 .77901 L .52261 .77912 L p .712 .535 .648 r
F P
0 g
s
.52261 .77912 m .52161 .72252 L .52804 .72222 L p .712 .535 .648 r
F P
0 g
s
.5008 .83454 m .48013 .78713 L .47618 .7887 L p .575 .514 .75 r
F P
0 g
s
.47618 .7887 m .49859 .8354 L .5008 .83454 L p .575 .514 .75 r
F P
0 g
s
.48443 .4996 m .47814 .45722 L .49813 .46596 L p .853 .726 .723 r
F P
0 g
s
.51753 .77939 m .51517 .72305 L .52161 .72252 L p .699 .525 .649 r
F P
0 g
s
.51517 .72305 m .51753 .77939 L .51249 .77983 L p .685 .514 .65 r
F P
0 g
s
.52161 .72252 m .52261 .77912 L .51753 .77939 L p .699 .525 .649 r
F P
0 g
s
.46022 .53604 m .44467 .49317 L .46515 .49549 L p .788 .732 .801 r
F P
0 g
s
.44467 .49317 m .46022 .53604 L .44364 .53707 L p .753 .711 .812 r
F P
0 g
s
.57465 .78769 m .55313 .83496 L .55087 .83413 L p .807 .699 .746 r
F P
0 g
s
.55087 .83413 m .57058 .78609 L .57465 .78769 L p .807 .699 .746 r
F P
0 g
s
.43008 .37532 m .42683 .40282 L .40165 .39959 L p .738 .419 .441 r
F P
0 g
s
.40165 .39959 m .40579 .37091 L .43008 .37532 L p .738 .419 .441 r
F P
0 g
s
.48013 .78713 m .5008 .83454 L .50311 .83376 L p .59 .523 .747 r
F P
0 g
s
.41366 .54326 m .38686 .49962 L .37252 .50615 L p .607 .644 .861 r
F P
0 g
s
.40437 .49516 m .42782 .5395 L .41366 .54326 L p .668 .669 .841 r
F P
0 g
s
.41366 .54326 m .38686 .49962 L .40437 .49516 L p .668 .669 .841 r
F P
0 g
s
.34924 .45839 m .33919 .41458 L .32671 .42688 L p .384 .323 .665 r
F P
0 g
s
.32671 .42688 m .33741 .46896 L .34924 .45839 L p .384 .323 .665 r
F P
0 g
s
.57058 .78609 m .55087 .83413 L .5485 .83337 L p .797 .687 .743 r
F P
0 g
s
.50311 .83376 m .48429 .78569 L .48013 .78713 L p .59 .523 .747 r
F P
0 g
s
.48429 .78569 m .50311 .83376 L .50552 .83305 L p .605 .531 .745 r
F P
0 g
s
.5485 .83337 m .56632 .78463 L .57058 .78609 L p .797 .687 .743 r
F P
0 g
s
.56632 .78463 m .5485 .83337 L .54605 .8327 L p .787 .675 .741 r
F P
0 g
s
.37773 .40048 m .38269 .37099 L .40579 .37091 L p .654 .341 .431 r
F P
0 g
s
.38269 .37099 m .37773 .40048 L .35649 .40557 L p .531 .231 .404 r
F P
0 g
s
.50552 .83305 m .48864 .78436 L .48429 .78569 L p .605 .531 .745 r
F P
0 g
s
.49315 .78317 m .50803 .83241 L .50552 .83305 L p .62 .539 .742 r
F P
0 g
s
.50552 .83305 m .48864 .78436 L .49315 .78317 L p .62 .539 .742 r
F P
0 g
s
.54605 .8327 m .56189 .78332 L .56632 .78463 L p .787 .675 .741 r
F P
0 g
s
.56189 .78332 m .54605 .8327 L .5435 .8321 L p .777 .664 .738 r
F P
0 g
s
.47814 .45722 m .48443 .4996 L .46515 .49549 L p .825 .702 .729 r
F P
0 g
s
.49782 .78212 m .51061 .83186 L .50803 .83241 L p .634 .548 .74 r
F P
0 g
s
.50803 .83241 m .49315 .78317 L .49782 .78212 L p .634 .548 .74 r
F P
0 g
s
.40579 .37091 m .40165 .39959 L .37773 .40048 L p .654 .341 .431 r
F P
0 g
s
.33741 .46896 m .36209 .51431 L .37252 .50615 L p .486 .511 .808 r
F P
0 g
s
.44364 .53707 m .42403 .49299 L .44467 .49317 L p .753 .711 .812 r
F P
0 g
s
.42403 .49299 m .44364 .53707 L .42782 .5395 L p .714 .69 .826 r
F P
0 g
s
.5435 .8321 m .5573 .78218 L .56189 .78332 L p .777 .664 .738 r
F P
0 g
s
.5573 .78218 m .5435 .8321 L .54089 .83159 L p .767 .654 .737 r
F P
0 g
s
.42782 .5395 m .40437 .49516 L .42403 .49299 L p .714 .69 .826 r
F P
0 g
s
.50261 .7812 m .51326 .83139 L .51061 .83186 L p .648 .556 .738 r
F P
0 g
s
.51061 .83186 m .49782 .78212 L .50261 .7812 L p .648 .556 .738 r
F P
0 g
s
.54089 .83159 m .55258 .7812 L .5573 .78218 L p .767 .654 .737 r
F P
0 g
s
.55258 .7812 m .54089 .83159 L .53821 .83117 L p .758 .644 .735 r
F P
0 g
s
.50751 .78044 m .51596 .83101 L .51326 .83139 L p .661 .565 .736 r
F P
0 g
s
.51326 .83139 m .50261 .7812 L .50751 .78044 L p .661 .565 .736 r
F P
0 g
s
.53821 .83117 m .54775 .7804 L .55258 .7812 L p .758 .644 .735 r
F P
0 g
s
.54775 .7804 m .53821 .83117 L .53548 .83083 L p .748 .634 .734 r
F P
0 g
s
.51249 .77983 m .51871 .83071 L .51596 .83101 L p .673 .573 .735 r
F P
0 g
s
.51596 .83101 m .50751 .78044 L .51249 .77983 L p .673 .573 .735 r
F P
0 g
s
.53548 .83083 m .54282 .77978 L .54775 .7804 L p .748 .634 .734 r
F P
0 g
s
.54282 .77978 m .53548 .83083 L .53272 .83058 L p .738 .625 .733 r
F P
0 g
s
.51753 .77939 m .52149 .8305 L .51871 .83071 L p .685 .582 .734 r
F P
0 g
s
.51871 .83071 m .51249 .77983 L .51753 .77939 L p .685 .582 .734 r
F P
0 g
s
.53272 .83058 m .53783 .77935 L .54282 .77978 L p .738 .625 .733 r
F P
0 g
s
.53783 .77935 m .53272 .83058 L .52992 .83043 L p .728 .616 .733 r
F P
0 g
s
.52261 .77912 m .5243 .83039 L .52149 .8305 L p .696 .59 .733 r
F P
0 g
s
.52149 .8305 m .51753 .77939 L .52261 .77912 L p .696 .59 .733 r
F P
0 g
s
.52992 .83043 m .53278 .77909 L .53783 .77935 L p .728 .616 .733 r
F P
0 g
s
.53278 .77909 m .52992 .83043 L .52711 .83036 L p .718 .607 .733 r
F P
0 g
s
.5277 .77901 m .52711 .83036 L .5243 .83039 L p .707 .599 .733 r
F P
0 g
s
.5243 .83039 m .52261 .77912 L .5277 .77901 L p .707 .599 .733 r
F P
0 g
s
.52711 .83036 m .5277 .77901 L .53278 .77909 L p .718 .607 .733 r
F P
0 g
s
.47534 .41948 m .47814 .45722 L .45589 .45013 L p .839 .636 .628 r
F P
0 g
s
.45589 .45013 m .45181 .4097 L .47534 .41948 L p .839 .636 .628 r
F P
0 g
s
.37252 .50615 m .34924 .45839 L .33741 .46896 L p .486 .511 .808 r
F P
0 g
s
.46515 .49549 m .45589 .45013 L .47814 .45722 L p .825 .702 .729 r
F P
0 g
s
.45589 .45013 m .46515 .49549 L .44467 .49317 L p .791 .677 .738 r
F P
0 g
s
.36565 .45034 m .35649 .40557 L .33919 .41458 L p .528 .415 .668 r
F P
0 g
s
.33919 .41458 m .34924 .45839 L .36565 .45034 L p .528 .415 .668 r
F P
0 g
s
.34924 .45839 m .37252 .50615 L .38686 .49962 L p .585 .559 .791 r
F P
0 g
s
.45181 .4097 m .45589 .45013 L .43226 .44544 L p .799 .604 .637 r
F P
0 g
s
.43226 .44544 m .42683 .40282 L .45181 .4097 L p .799 .604 .637 r
F P
0 g
s
.44467 .49317 m .43226 .44544 L .45589 .45013 L p .791 .677 .738 r
F P
0 g
s
.43226 .44544 m .44467 .49317 L .42403 .49299 L p .753 .651 .748 r
F P
0 g
s
.38686 .49962 m .36565 .45034 L .34924 .45839 L p .585 .559 .791 r
F P
0 g
s
.38577 .44537 m .40437 .49516 L .38686 .49962 L p .655 .594 .774 r
F P
0 g
s
.38686 .49962 m .36565 .45034 L .38577 .44537 L p .655 .594 .774 r
F P
0 g
s
.36565 .45034 m .35649 .40557 L .37773 .40048 L p .626 .479 .663 r
F P
0 g
s
.42683 .40282 m .43226 .44544 L .40843 .44375 L p .753 .568 .646 r
F P
0 g
s
.40843 .44375 m .40165 .39959 L .42683 .40282 L p .753 .568 .646 r
F P
0 g
s
.42403 .49299 m .40843 .44375 L .43226 .44544 L p .753 .651 .748 r
F P
0 g
s
.40843 .44375 m .42403 .49299 L .40437 .49516 L p .708 .623 .76 r
F P
0 g
s
.40437 .49516 m .38577 .44537 L .40843 .44375 L p .708 .623 .76 r
F P
0 g
s
.38577 .44537 m .37773 .40048 L .40165 .39959 L p .697 .527 .654 r
F P
0 g
s
.37773 .40048 m .38577 .44537 L .36565 .45034 L p .626 .479 .663 r
F P
0 g
s
.40165 .39959 m .40843 .44375 L .38577 .44537 L p .697 .527 .654 r
F P
0 g
s
.25 Mabswid
.67201 0 m
.92731 .41559 L
s
.92731 .41559 m
1 .94836 L
s
1 .94836 m
.70577 .58502 L
s
.70577 .58502 m
.67201 0 L
s
.08828 .24537 m
0 .80321 L
s
0 .80321 m
.70577 .58502 L
s
.70577 .58502 m
.67201 0 L
s
.67201 0 m
.08828 .24537 L
s
.08828 .24537 m
.67201 0 L
s
.18312 .20551 m
.18804 .21088 L
s
[(-0.01)] .17327 .19475 .91505 1 Mshowa
.36332 .12976 m
.36786 .13546 L
s
[(0)] .35423 .11836 .79742 1 Mshowa
.55738 .04818 m
.56148 .05421 L
s
[(0.01)] .54918 .03613 .6798 1 Mshowa
.125 Mabswid
.21812 .19079 m
.22103 .19406 L
s
.25363 .17587 m
.2565 .17917 L
s
.28966 .16072 m
.29248 .16406 L
s
.32622 .14535 m
.32899 .14873 L
s
.40097 .11393 m
.40365 .11739 L
s
.43919 .09786 m
.44182 .10136 L
s
.47799 .08156 m
.48056 .08509 L
s
.51738 .065 m
.5199 .06857 L
s
.14861 .22001 m
.1516 .2232 L
s
.11459 .23431 m
.11762 .23746 L
s
.598 .03111 m
.60039 .03477 L
s
.63925 .01377 m
.64159 .01747 L
s
.25 Mabswid
0 .80321 m
.40091 1.08568 L
s
.08573 .86361 m
.08667 .85638 L
s
[(-0.01)] .08385 .87807 .13011 -1 Mshowa
.22213 .95971 m
.22276 .95245 L
s
[(0)] .22086 .97424 .08736 -1 Mshowa
.34085 1.04337 m
.34123 1.03609 L
s
[(0.01)] .3401 1.05793 .05202 -1 Mshowa
.125 Mabswid
.11461 .88396 m
.11513 .87962 L
s
.14265 .90372 m
.14314 .89937 L
s
.1699 .92292 m
.17035 .91857 L
s
.19638 .94157 m
.19679 .93722 L
s
.24717 .97736 m
.24752 .973 L
s
.27154 .99453 m
.27185 .99017 L
s
.29526 1.01124 m
.29554 1.00688 L
s
.31835 1.02751 m
.31861 1.02315 L
s
.05597 .84265 m
.05658 .83832 L
s
.02531 .82104 m
.02596 .81672 L
s
.36278 1.05881 m
.36298 1.05444 L
s
.38415 1.07387 m
.38432 1.0695 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{265.25, 287.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 264.25}, {286.938, 0}} -> {-0.0325185, -0.0405773, \
0.00355188, 0.00355188}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics3D", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"],

Cell[BoxData["\<\"austenite.pdf\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"epsnn", " ", "normal"}], ")"}], "/.", " ", "copper"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot3D", "[", " ", 
  RowBox[{
   RowBox[{"Evaluate", "[", "%", "]"}], "  ", ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "0", ",", "  ", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"p", ",", " ", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], " ", ",", " ", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", " ", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "50"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<copper.pdf\>\"", ",", "%"}], "]"}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.08568 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567931 1.16636 0 1.16636 [
[.17327 .19475 -28.7258 -9 ]
[.17327 .19475 1.27425 0 ]
[.35423 .11836 -5.39227 -9 ]
[.35423 .11836 .60773 0 ]
[.54918 .03613 -20.1576 -9 ]
[.54918 .03613 3.84245 0 ]
[.08385 .87807 -16.9517 0 ]
[.08385 .87807 13.0483 9 ]
[.22086 .97424 -3.26208 0 ]
[.22086 .97424 2.73792 9 ]
[.3401 1.05793 -12.6243 0 ]
[.3401 1.05793 11.3757 9 ]
[.0614 .33523 -30 -2.68293 ]
[.0614 .33523 0 6.31707 ]
[.03472 .5025 -6 -2.8322 ]
[.03472 .5025 0 6.1678 ]
[.00471 .69065 -24 -3.00214 ]
[.00471 .69065 0 5.99786 ]
[ 0 0 0 0 ]
[ 1 1.08568 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08828 .24537 m
.67201 0 L
s
.18312 .20551 m
.18804 .21088 L
s
[(-0.01)] .17327 .19475 .91505 1 Mshowa
.36332 .12976 m
.36786 .13546 L
s
[(0)] .35423 .11836 .79742 1 Mshowa
.55738 .04818 m
.56148 .05421 L
s
[(0.01)] .54918 .03613 .6798 1 Mshowa
.125 Mabswid
.21812 .19079 m
.22103 .19406 L
s
.25363 .17587 m
.2565 .17917 L
s
.28966 .16072 m
.29248 .16406 L
s
.32622 .14535 m
.32899 .14873 L
s
.40097 .11393 m
.40365 .11739 L
s
.43919 .09786 m
.44182 .10136 L
s
.47799 .08156 m
.48056 .08509 L
s
.51738 .065 m
.5199 .06857 L
s
.14861 .22001 m
.1516 .2232 L
s
.11459 .23431 m
.11762 .23746 L
s
.598 .03111 m
.60039 .03477 L
s
.63925 .01377 m
.64159 .01747 L
s
.25 Mabswid
0 .80321 m
.40091 1.08568 L
s
.08573 .86361 m
.08667 .85638 L
s
[(-0.01)] .08385 .87807 .13011 -1 Mshowa
.22213 .95971 m
.22276 .95245 L
s
[(0)] .22086 .97424 .08736 -1 Mshowa
.34085 1.04337 m
.34123 1.03609 L
s
[(0.01)] .3401 1.05793 .05202 -1 Mshowa
.125 Mabswid
.11461 .88396 m
.11513 .87962 L
s
.14265 .90372 m
.14314 .89937 L
s
.1699 .92292 m
.17035 .91857 L
s
.19638 .94157 m
.19679 .93722 L
s
.24717 .97736 m
.24752 .973 L
s
.27154 .99453 m
.27185 .99017 L
s
.29526 1.01124 m
.29554 1.00688 L
s
.31835 1.02751 m
.31861 1.02315 L
s
.05597 .84265 m
.05658 .83832 L
s
.02531 .82104 m
.02596 .81672 L
s
.36278 1.05881 m
.36298 1.05444 L
s
.38415 1.07387 m
.38432 1.0695 L
s
.25 Mabswid
.08828 .24537 m
0 .80321 L
s
.07492 .32977 m
.08168 .32704 L
s
[(-0.01)] .0614 .33523 1 -0.40379 Mshowa
.04839 .49744 m
.05522 .4949 L
s
[(0)] .03472 .5025 1 -0.37062 Mshowa
.01854 .68604 m
.02546 .68374 L
s
[(0.01)] .00471 .69065 1 -0.33286 Mshowa
.125 Mabswid
.06985 .3618 m
.07392 .36018 L
s
.06467 .39455 m
.06874 .39296 L
s
.05937 .42806 m
.06345 .42649 L
s
.05394 .46234 m
.05803 .4608 L
s
.0427 .53336 m
.04681 .53187 L
s
.03688 .57015 m
.041 .56869 L
s
.03092 .60784 m
.03505 .6064 L
s
.02481 .64646 m
.02895 .64505 L
s
.07988 .29845 m
.08393 .29679 L
s
.08473 .2678 m
.08877 .26612 L
s
.01212 .72663 m
.01628 .72528 L
s
.00553 .76825 m
.0097 .76693 L
s
.25 Mabswid
.08828 .24537 m
0 .80321 L
s
0 .80321 m
.40091 1.08568 L
s
.40091 1.08568 m
.41842 .58207 L
s
.41842 .58207 m
.08828 .24537 L
s
.67201 0 m
.92731 .41559 L
s
.92731 .41559 m
1 .94836 L
s
1 .94836 m
.70577 .58502 L
s
.70577 .58502 m
.67201 0 L
s
.08828 .24537 m
0 .80321 L
s
0 .80321 m
.70577 .58502 L
s
.70577 .58502 m
.67201 0 L
s
.67201 0 m
.08828 .24537 L
s
.41842 .58207 m
.92731 .41559 L
s
.92731 .41559 m
1 .94836 L
s
1 .94836 m
.40091 1.08568 L
s
.40091 1.08568 m
.41842 .58207 L
s
0 0 m
1 0 L
1 1.08568 L
0 1.08568 L
closepath
clip
newpath
.5 Mabswid
.60767 .74211 m .60549 .71044 L .62511 .71192 L p .743 .525 .599 r
F P
0 g
s
.62511 .71192 m .62787 .74477 L .60767 .74211 L p .743 .525 .599 r
F P
0 g
s
.61587 .67333 m .62511 .71192 L .60549 .71044 L p .745 .607 .704 r
F P
0 g
s
.62787 .74477 m .62511 .71192 L .6441 .71093 L p .691 .486 .605 r
F P
0 g
s
.62511 .71192 m .61587 .67333 L .63304 .67176 L p .705 .58 .713 r
F P
0 g
s
.63304 .67176 m .6441 .71093 L .62511 .71192 L p .705 .58 .713 r
F P
0 g
s
.6441 .71093 m .64741 .7445 L .62787 .74477 L p .691 .486 .605 r
F P
0 g
s
.64741 .7445 m .6441 .71093 L .66156 .70742 L p .628 .44 .608 r
F P
0 g
s
.6441 .71093 m .63304 .67176 L .64883 .66828 L p .657 .551 .723 r
F P
0 g
s
.64883 .66828 m .66156 .70742 L .6441 .71093 L p .657 .551 .723 r
F P
0 g
s
.61694 .63384 m .63304 .67176 L .61587 .67333 L p .712 .647 .783 r
F P
0 g
s
.63304 .67176 m .61694 .63384 L .63029 .63062 L p .672 .626 .795 r
F P
0 g
s
.63029 .63062 m .64883 .66828 L .63304 .67176 L p .672 .626 .795 r
F P
0 g
s
.60549 .71044 m .59811 .67299 L .61587 .67333 L p .745 .607 .704 r
F P
0 g
s
.6024 .63577 m .61587 .67333 L .59811 .67299 L p .747 .668 .773 r
F P
0 g
s
.61587 .67333 m .6024 .63577 L .61694 .63384 L p .712 .647 .783 r
F P
0 g
s
.58772 .73682 m .5861 .70669 L .60549 .71044 L p .787 .56 .593 r
F P
0 g
s
.60549 .71044 m .60767 .74211 L .58772 .73682 L p .787 .56 .593 r
F P
0 g
s
.59811 .67299 m .60549 .71044 L .5861 .70669 L p .781 .633 .697 r
F P
0 g
s
.66156 .70742 m .66538 .74122 L .64741 .7445 L p .628 .44 .608 r
F P
0 g
s
.64883 .66828 m .66156 .70742 L .67667 .70152 L p .598 .518 .735 r
F P
0 g
s
.66156 .70742 m .66538 .74122 L .68092 .73503 L p .546 .38 .608 r
F P
0 g
s
.68092 .73503 m .67667 .70152 L .66156 .70742 L p .546 .38 .608 r
F P
0 g
s
.63029 .63062 m .64883 .66828 L .66248 .66302 L p .621 .603 .811 r
F P
0 g
s
.67667 .70152 m .66248 .66302 L .64883 .66828 L p .598 .518 .735 r
F P
0 g
s
.5861 .70669 m .58054 .67087 L .59811 .67299 L p .781 .633 .697 r
F P
0 g
s
.58736 .63639 m .59811 .67299 L .58054 .67087 L p .779 .689 .765 r
F P
0 g
s
.59811 .67299 m .58736 .63639 L .6024 .63577 L p .747 .668 .773 r
F P
0 g
s
.5688 .72934 m .5677 .70104 L .5861 .70669 L p .826 .592 .585 r
F P
0 g
s
.5861 .70669 m .58772 .73682 L .5688 .72934 L p .826 .592 .585 r
F P
0 g
s
.58054 .67087 m .5861 .70669 L .5677 .70104 L p .813 .658 .69 r
F P
0 g
s
.66248 .66302 m .64183 .62624 L .63029 .63062 L p .621 .603 .811 r
F P
0 g
s
.64183 .62624 m .66248 .66302 L .67335 .65621 L p .554 .575 .83 r
F P
0 g
s
.66248 .66302 m .67667 .70152 L .68872 .69348 L p .518 .475 .748 r
F P
0 g
s
.68872 .69348 m .67335 .65621 L .66248 .66302 L p .518 .475 .748 r
F P
0 g
s
.5677 .70104 m .56387 .66723 L .58054 .67087 L p .813 .658 .69 r
F P
0 g
s
.57247 .63575 m .58054 .67087 L .56387 .66723 L p .807 .711 .758 r
F P
0 g
s
.58054 .67087 m .57247 .63575 L .58736 .63639 L p .779 .689 .765 r
F P
0 g
s
.67667 .70152 m .68092 .73503 L .6933 .72621 L p .43 .299 .6 r
F P
0 g
s
.6933 .72621 m .68872 .69348 L .67667 .70152 L p .43 .299 .6 r
F P
0 g
s
.60401 .762 m .60767 .74211 L .62787 .74477 L p .725 .379 .393 r
F P
0 g
s
.62787 .74477 m .62333 .76564 L .60401 .762 L p .725 .379 .393 r
F P
0 g
s
.62333 .76564 m .62787 .74477 L .64741 .7445 L p .647 .306 .381 r
F P
0 g
s
.64741 .7445 m .64203 .7661 L .62333 .76564 L p .647 .306 .381 r
F P
0 g
s
.64203 .7661 m .64741 .7445 L .66538 .74122 L p .54 .206 .351 r
F P
0 g
s
.59953 .60221 m .61694 .63384 L .6024 .63577 L p .717 .7 .832 r
F P
0 g
s
.61694 .63384 m .59953 .60221 L .61025 .5994 L p .68 .683 .846 r
F P
0 g
s
.61025 .5994 m .63029 .63062 L .61694 .63384 L p .68 .683 .846 r
F P
0 g
s
.58787 .6043 m .6024 .63577 L .58736 .63639 L p .751 .717 .82 r
F P
0 g
s
.6024 .63577 m .58787 .6043 L .59953 .60221 L p .717 .7 .832 r
F P
0 g
s
.58493 .75551 m .58772 .73682 L .60767 .74211 L p .784 .434 .393 r
F P
0 g
s
.60767 .74211 m .60401 .762 L .58493 .75551 L p .784 .434 .393 r
F P
0 g
s
.61025 .5994 m .63029 .63062 L .64183 .62624 L p .631 .664 .864 r
F P
0 g
s
.66538 .74122 m .65919 .76326 L .64203 .7661 L p .54 .206 .351 r
F P
0 g
s
.66538 .74122 m .65919 .76326 L .674 .75719 L p .381 .061 .292 r
F P
0 g
s
.674 .75719 m .68092 .73503 L .66538 .74122 L p .381 .061 .292 r
F P
0 g
s
.5758 .6056 m .58736 .63639 L .57247 .63575 L p .781 .735 .811 r
F P
0 g
s
.58736 .63639 m .5758 .6056 L .58787 .6043 L p .751 .717 .82 r
F P
0 g
s
.55154 .7203 m .5509 .694 L .5677 .70104 L p .859 .621 .576 r
F P
0 g
s
.5677 .70104 m .5688 .72934 L .55154 .7203 L p .859 .621 .576 r
F P
0 g
s
.56387 .66723 m .5677 .70104 L .5509 .694 L p .842 .683 .685 r
F P
0 g
s
.52028 .44229 m .52219 .39694 L .52553 .39703 L p .719 .574 .69 r
F P
0 g
s
.52553 .39703 m .52514 .44237 L .52028 .44229 L p .719 .574 .69 r
F P
0 g
s
.52608 .35784 m .52553 .39703 L .52219 .39694 L p .71 .635 .771 r
F P
0 g
s
.52514 .44237 m .52553 .39703 L .52887 .39698 L p .709 .566 .69 r
F P
0 g
s
.52553 .39703 m .52608 .35784 L .52728 .35783 L p .703 .629 .771 r
F P
0 g
s
.52728 .35783 m .52887 .39698 L .52553 .39703 L p .703 .629 .771 r
F P
0 g
s
.52887 .39698 m .53001 .44223 L .52514 .44237 L p .709 .566 .69 r
F P
0 g
s
.53001 .44223 m .52887 .39698 L .5322 .39679 L p .699 .558 .691 r
F P
0 g
s
.52887 .39698 m .52728 .35783 L .52848 .35777 L p .696 .624 .771 r
F P
0 g
s
.52848 .35777 m .5322 .39679 L .52887 .39698 L p .696 .624 .771 r
F P
0 g
s
.51544 .44201 m .51888 .3967 L .52219 .39694 L p .729 .581 .69 r
F P
0 g
s
.52219 .39694 m .52028 .44229 L .51544 .44201 L p .729 .581 .69 r
F P
0 g
s
.52488 .3578 m .52219 .39694 L .51888 .3967 L p .717 .641 .771 r
F P
0 g
s
.52219 .39694 m .52488 .3578 L .52608 .35784 L p .71 .635 .771 r
F P
0 g
s
.5322 .39679 m .53487 .44189 L .53001 .44223 L p .699 .558 .691 r
F P
0 g
s
.53487 .44189 m .5322 .39679 L .53551 .39646 L p .689 .55 .692 r
F P
0 g
s
.5322 .39679 m .52848 .35777 L .52966 .35765 L p .689 .619 .772 r
F P
0 g
s
.52966 .35765 m .53551 .39646 L .5322 .39679 L p .689 .619 .772 r
F P
0 g
s
.51065 .4415 m .51559 .39632 L .51888 .3967 L p .738 .589 .69 r
F P
0 g
s
.51888 .3967 m .51544 .44201 L .51065 .4415 L p .738 .589 .69 r
F P
0 g
s
.52369 .35771 m .51888 .3967 L .51559 .39632 L p .723 .647 .772 r
F P
0 g
s
.51888 .3967 m .52369 .35771 L .52488 .3578 L p .717 .641 .771 r
F P
0 g
s
.53551 .39646 m .53971 .44134 L .53487 .44189 L p .689 .55 .692 r
F P
0 g
s
.53971 .44134 m .53551 .39646 L .53878 .396 L p .677 .542 .693 r
F P
0 g
s
.53551 .39646 m .52966 .35765 L .53084 .35748 L p .682 .613 .773 r
F P
0 g
s
.53084 .35748 m .53878 .396 L .53551 .39646 L p .682 .613 .773 r
F P
0 g
s
.50592 .44077 m .51234 .3958 L .51559 .39632 L p .747 .598 .691 r
F P
0 g
s
.51559 .39632 m .51065 .4415 L .50592 .44077 L p .747 .598 .691 r
F P
0 g
s
.52251 .35757 m .51559 .39632 L .51234 .3958 L p .73 .653 .773 r
F P
0 g
s
.51559 .39632 m .52251 .35757 L .52369 .35771 L p .723 .647 .772 r
F P
0 g
s
.53878 .396 m .5445 .44061 L .53971 .44134 L p .677 .542 .693 r
F P
0 g
s
.5445 .44061 m .53878 .396 L .542 .39539 L p .665 .534 .694 r
F P
0 g
s
.53878 .396 m .53084 .35748 L .53199 .35727 L p .674 .608 .774 r
F P
0 g
s
.53199 .35727 m .542 .39539 L .53878 .396 L p .674 .608 .774 r
F P
0 g
s
.5509 .694 m .54864 .66245 L .56387 .66723 L p .842 .683 .685 r
F P
0 g
s
.55832 .63402 m .56387 .66723 L .54864 .66245 L p .832 .732 .754 r
F P
0 g
s
.56387 .66723 m .55832 .63402 L .57247 .63575 L p .807 .711 .758 r
F P
0 g
s
.50127 .43983 m .50915 .39514 L .51234 .3958 L p .756 .606 .691 r
F P
0 g
s
.51234 .3958 m .50592 .44077 L .50127 .43983 L p .756 .606 .691 r
F P
0 g
s
.52134 .35738 m .51234 .3958 L .50915 .39514 L p .736 .659 .774 r
F P
0 g
s
.51234 .3958 m .52134 .35738 L .52251 .35757 L p .73 .653 .773 r
F P
0 g
s
.542 .39539 m .54923 .43969 L .5445 .44061 L p .665 .534 .694 r
F P
0 g
s
.54923 .43969 m .542 .39539 L .54517 .39466 L p .653 .525 .695 r
F P
0 g
s
.542 .39539 m .53199 .35727 L .53313 .357 L p .667 .604 .775 r
F P
0 g
s
.53313 .357 m .54517 .39466 L .542 .39539 L p .667 .604 .775 r
F P
0 g
s
.67335 .65621 m .65104 .62091 L .64183 .62624 L p .554 .575 .83 r
F P
0 g
s
.65104 .62091 m .67335 .65621 L .68102 .64821 L p .465 .54 .849 r
F P
0 g
s
.67335 .65621 m .68872 .69348 L .69722 .68372 L p .409 .419 .758 r
F P
0 g
s
.69722 .68372 m .68102 .64821 L .67335 .65621 L p .409 .419 .758 r
F P
0 g
s
.4967 .43867 m .50602 .39434 L .50915 .39514 L p .765 .615 .692 r
F P
0 g
s
.50915 .39514 m .50127 .43983 L .4967 .43867 L p .765 .615 .692 r
F P
0 g
s
.52019 .35714 m .50915 .39514 L .50602 .39434 L p .742 .666 .775 r
F P
0 g
s
.50915 .39514 m .52019 .35714 L .52134 .35738 L p .736 .659 .774 r
F P
0 g
s
.54517 .39466 m .55387 .4386 L .54923 .43969 L p .653 .525 .695 r
F P
0 g
s
.55387 .4386 m .54517 .39466 L .54826 .3938 L p .64 .517 .697 r
F P
0 g
s
.54517 .39466 m .53313 .357 L .53424 .35669 L p .659 .599 .777 r
F P
0 g
s
.53424 .35669 m .54826 .3938 L .54517 .39466 L p .659 .599 .777 r
F P
0 g
s
.68872 .69348 m .6933 .72621 L .702 .71521 L p .255 .178 .573 r
F P
0 g
s
.702 .71521 m .69722 .68372 L .68872 .69348 L p .255 .178 .573 r
F P
0 g
s
.56685 .74672 m .5688 .72934 L .58772 .73682 L p .833 .478 .384 r
F P
0 g
s
.58772 .73682 m .58493 .75551 L .56685 .74672 L p .833 .478 .384 r
F P
0 g
s
.49224 .4373 m .50297 .39341 L .50602 .39434 L p .774 .624 .694 r
F P
0 g
s
.50602 .39434 m .4967 .43867 L .49224 .4373 L p .774 .624 .694 r
F P
0 g
s
.51907 .35685 m .50602 .39434 L .50297 .39341 L p .748 .672 .777 r
F P
0 g
s
.50602 .39434 m .51907 .35685 L .52019 .35714 L p .742 .666 .775 r
F P
0 g
s
.54826 .3938 m .55841 .43733 L .55387 .4386 L p .64 .517 .697 r
F P
0 g
s
.55841 .43733 m .54826 .3938 L .55126 .39281 L p .626 .508 .699 r
F P
0 g
s
.54826 .3938 m .53424 .35669 L .53531 .35633 L p .651 .595 .779 r
F P
0 g
s
.53531 .35633 m .55126 .39281 L .54826 .3938 L p .651 .595 .779 r
F P
0 g
s
.52493 .4862 m .52514 .44237 L .53001 .44223 L p .714 .519 .625 r
F P
0 g
s
.53001 .44223 m .53061 .48587 L .52493 .4862 L p .714 .519 .625 r
F P
0 g
s
.53061 .48587 m .53001 .44223 L .53487 .44189 L p .702 .511 .626 r
F P
0 g
s
.51929 .48626 m .52028 .44229 L .52514 .44237 L p .725 .527 .623 r
F P
0 g
s
.52514 .44237 m .52493 .4862 L .51929 .48626 L p .725 .527 .623 r
F P
0 g
s
.53487 .44189 m .5363 .48531 L .53061 .48587 L p .702 .511 .626 r
F P
0 g
s
.5363 .48531 m .53487 .44189 L .53971 .44134 L p .689 .502 .628 r
F P
0 g
s
.5137 .48604 m .51544 .44201 L .52028 .44229 L p .735 .535 .622 r
F P
0 g
s
.52028 .44229 m .51929 .48626 L .5137 .48604 L p .735 .535 .622 r
F P
0 g
s
.4879 .43573 m .50002 .39235 L .50297 .39341 L p .783 .633 .695 r
F P
0 g
s
.50297 .39341 m .49224 .4373 L .4879 .43573 L p .783 .633 .695 r
F P
0 g
s
.51798 .35651 m .50297 .39341 L .50002 .39235 L p .754 .68 .779 r
F P
0 g
s
.50297 .39341 m .51798 .35651 L .51907 .35685 L p .748 .672 .777 r
F P
0 g
s
.53971 .44134 m .54199 .48452 L .5363 .48531 L p .689 .502 .628 r
F P
0 g
s
.54199 .48452 m .53971 .44134 L .5445 .44061 L p .675 .492 .63 r
F P
0 g
s
.50816 .48555 m .51065 .4415 L .51544 .44201 L p .745 .542 .621 r
F P
0 g
s
.51544 .44201 m .5137 .48604 L .50816 .48555 L p .745 .542 .621 r
F P
0 g
s
.64183 .62624 m .61955 .59596 L .61025 .5994 L p .631 .664 .864 r
F P
0 g
s
.61955 .59596 m .64183 .62624 L .65104 .62091 L p .567 .642 .884 r
F P
0 g
s
.55126 .39281 m .56282 .43591 L .55841 .43733 L p .626 .508 .699 r
F P
0 g
s
.53531 .35633 m .55126 .39281 L .55417 .3917 L p .642 .59 .781 r
F P
0 g
s
.55126 .39281 m .56282 .43591 L .56709 .43433 L p .612 .499 .701 r
F P
0 g
s
.56709 .43433 m .55417 .3917 L .55126 .39281 L p .612 .499 .701 r
F P
0 g
s
.5445 .44061 m .54765 .48351 L .54199 .48452 L p .675 .492 .63 r
F P
0 g
s
.54765 .48351 m .5445 .44061 L .54923 .43969 L p .66 .481 .631 r
F P
0 g
s
.50269 .48476 m .50592 .44077 L .51065 .4415 L p .754 .55 .62 r
F P
0 g
s
.51065 .4415 m .50816 .48555 L .50269 .48476 L p .754 .55 .62 r
F P
0 g
s
.4837 .43396 m .49716 .39116 L .50002 .39235 L p .792 .644 .697 r
F P
0 g
s
.50002 .39235 m .4879 .43573 L .4837 .43396 L p .792 .644 .697 r
F P
0 g
s
.51692 .35612 m .50002 .39235 L .49716 .39116 L p .76 .687 .781 r
F P
0 g
s
.50002 .39235 m .51692 .35612 L .51798 .35651 L p .754 .68 .779 r
F P
0 g
s
.54923 .43969 m .55325 .48232 L .54765 .48351 L p .66 .481 .631 r
F P
0 g
s
.55325 .48232 m .54923 .43969 L .55387 .4386 L p .643 .469 .633 r
F P
0 g
s
.55417 .3917 m .53635 .35592 L .53531 .35633 L p .642 .59 .781 r
F P
0 g
s
.53635 .35592 m .55417 .3917 L .55697 .39047 L p .634 .587 .783 r
F P
0 g
s
.55417 .3917 m .56709 .43433 L .57119 .4326 L p .598 .491 .702 r
F P
0 g
s
.57119 .4326 m .55697 .39047 L .55417 .3917 L p .598 .491 .702 r
F P
0 g
s
.49729 .48368 m .50127 .43983 L .50592 .44077 L p .763 .558 .62 r
F P
0 g
s
.50592 .44077 m .50269 .48476 L .49729 .48368 L p .763 .558 .62 r
F P
0 g
s
.56383 .60613 m .57247 .63575 L .55832 .63402 L p .808 .754 .803 r
F P
0 g
s
.57247 .63575 m .56383 .60613 L .5758 .6056 L p .781 .735 .811 r
F P
0 g
s
.47966 .43202 m .49442 .38985 L .49716 .39116 L p .802 .655 .7 r
F P
0 g
s
.49716 .39116 m .4837 .43396 L .47966 .43202 L p .802 .655 .7 r
F P
0 g
s
.51591 .35569 m .49716 .39116 L .49442 .38985 L p .766 .695 .784 r
F P
0 g
s
.49716 .39116 m .51591 .35569 L .51692 .35612 L p .76 .687 .781 r
F P
0 g
s
.55387 .4386 m .55875 .48096 L .55325 .48232 L p .643 .469 .633 r
F P
0 g
s
.55875 .48096 m .55387 .4386 L .55841 .43733 L p .625 .456 .634 r
F P
0 g
s
.68092 .73503 m .674 .75719 L .68576 .74816 L p .131 0 .179 r
F P
0 g
s
.68576 .74816 m .6933 .72621 L .68092 .73503 L p .131 0 .179 r
F P
0 g
s
.49197 .48231 m .4967 .43867 L .50127 .43983 L p .772 .566 .621 r
F P
0 g
s
.50127 .43983 m .49729 .48368 L .49197 .48231 L p .772 .566 .621 r
F P
0 g
s
.55697 .39047 m .53735 .35547 L .53635 .35592 L p .634 .587 .783 r
F P
0 g
s
.53735 .35547 m .55697 .39047 L .55965 .38913 L p .626 .583 .786 r
F P
0 g
s
.55697 .39047 m .57119 .4326 L .57511 .43073 L p .584 .482 .704 r
F P
0 g
s
.57511 .43073 m .55965 .38913 L .55697 .39047 L p .584 .482 .704 r
F P
0 g
s
.47579 .4299 m .49181 .38842 L .49442 .38985 L p .812 .667 .703 r
F P
0 g
s
.49442 .38985 m .47966 .43202 L .47579 .4299 L p .812 .667 .703 r
F P
0 g
s
.51493 .35522 m .49442 .38985 L .49181 .38842 L p .772 .703 .787 r
F P
0 g
s
.49442 .38985 m .51493 .35522 L .51591 .35569 L p .766 .695 .784 r
F P
0 g
s
.55841 .43733 m .56413 .47943 L .55875 .48096 L p .625 .456 .634 r
F P
0 g
s
.56413 .47943 m .55841 .43733 L .56282 .43591 L p .604 .442 .635 r
F P
0 g
s
.48675 .48066 m .49224 .4373 L .4967 .43867 L p .781 .575 .621 r
F P
0 g
s
.4967 .43867 m .49197 .48231 L .48675 .48066 L p .781 .575 .621 r
F P
0 g
s
.55965 .38913 m .5383 .35498 L .53735 .35547 L p .626 .583 .786 r
F P
0 g
s
.5383 .35498 m .55965 .38913 L .56219 .38768 L p .617 .579 .789 r
F P
0 g
s
.55965 .38913 m .57511 .43073 L .57884 .42872 L p .569 .473 .707 r
F P
0 g
s
.57884 .42872 m .56219 .38768 L .55965 .38913 L p .569 .473 .707 r
F P
0 g
s
.47211 .42763 m .48933 .38689 L .49181 .38842 L p .822 .679 .706 r
F P
0 g
s
.49181 .38842 m .47579 .4299 L .47211 .42763 L p .822 .679 .706 r
F P
0 g
s
.514 .35471 m .49181 .38842 L .48933 .38689 L p .778 .712 .79 r
F P
0 g
s
.49181 .38842 m .514 .35471 L .51493 .35522 L p .772 .703 .787 r
F P
0 g
s
.56282 .43591 m .56935 .47777 L .56413 .47943 L p .604 .442 .635 r
F P
0 g
s
.56282 .43591 m .56935 .47777 L .57438 .47598 L p .585 .428 .636 r
F P
0 g
s
.57438 .47598 m .56709 .43433 L .56282 .43591 L p .585 .428 .636 r
F P
0 g
s
.48163 .47874 m .4879 .43573 L .49224 .4373 L p .791 .585 .622 r
F P
0 g
s
.49224 .4373 m .48675 .48066 L .48163 .47874 L p .791 .585 .622 r
F P
0 g
s
.56219 .38768 m .53921 .35444 L .5383 .35498 L p .617 .579 .789 r
F P
0 g
s
.53921 .35444 m .56219 .38768 L .5646 .38612 L p .608 .576 .792 r
F P
0 g
s
.56219 .38768 m .57884 .42872 L .58235 .42657 L p .553 .464 .709 r
F P
0 g
s
.58235 .42657 m .5646 .38612 L .56219 .38768 L p .553 .464 .709 r
F P
0 g
s
.46864 .42521 m .48699 .38526 L .48933 .38689 L p .833 .693 .709 r
F P
0 g
s
.48933 .38689 m .47211 .42763 L .46864 .42521 L p .833 .693 .709 r
F P
0 g
s
.51312 .35415 m .48933 .38689 L .48699 .38526 L p .783 .721 .793 r
F P
0 g
s
.48933 .38689 m .51312 .35415 L .514 .35471 L p .778 .712 .79 r
F P
0 g
s
.53631 .71043 m .53606 .68615 L .5509 .694 L p .888 .646 .567 r
F P
0 g
s
.5509 .694 m .55154 .7203 L .53631 .71043 L p .888 .646 .567 r
F P
0 g
s
.54864 .66245 m .5509 .694 L .53606 .68615 L p .866 .706 .682 r
F P
0 g
s
.47663 .47656 m .4837 .43396 L .4879 .43573 L p .801 .596 .624 r
F P
0 g
s
.4879 .43573 m .48163 .47874 L .47663 .47656 L p .801 .596 .624 r
F P
0 g
s
.56709 .43433 m .57438 .47598 L .57918 .47406 L p .565 .414 .635 r
F P
0 g
s
.57918 .47406 m .57119 .4326 L .56709 .43433 L p .565 .414 .635 r
F P
0 g
s
.5646 .38612 m .54007 .35387 L .53921 .35444 L p .608 .576 .792 r
F P
0 g
s
.54007 .35387 m .5646 .38612 L .56685 .38447 L p .599 .573 .796 r
F P
0 g
s
.5646 .38612 m .58235 .42657 L .58564 .42428 L p .535 .455 .712 r
F P
0 g
s
.58564 .42428 m .56685 .38447 L .5646 .38612 L p .535 .455 .712 r
F P
0 g
s
.55036 .73631 m .55154 .7203 L .5688 .72934 L p .871 .512 .366 r
F P
0 g
s
.5688 .72934 m .56685 .74672 L .55036 .73631 L p .871 .512 .366 r
F P
0 g
s
.52583 .34494 m .52535 .34514 L .52534 .34512 L .672 .728 .891 r
F
.52613 .3453 m .51017 .3516 L p .52583 .34494 L F P
0 g
s
.52574 .34439 m .52646 .34529 L p .52559 .34451 L .672 .728 .891 r
F P
0 g
s
.52646 .34529 m .52638 .34529 L .52637 .34529 L .672 .728 .891 r
F
.52646 .34529 m .52637 .34529 L .52519 .34418 L F
.52646 .34529 m .52519 .34418 L .52521 .34417 L F
.50959 .35088 m .50908 .35015 L p .52464 .3453 L F P
0 g
s
.52672 .34562 m .52665 .34564 L .52665 .34563 L .672 .728 .891 r
F
.52672 .34562 m .52665 .34563 L .52474 .34377 L F
.52672 .34562 m .52474 .34377 L .52475 .34377 L F
.52704 .34601 m .52697 .34603 L .52696 .34602 L F
.52704 .34601 m .52696 .34602 L .52442 .34346 L F
.50864 .34939 m .50827 .34861 L p .51354 .3475 L F P
0 g
s
.52638 .34475 m .52638 .34477 L .5269 .3446 L .672 .728 .891 r
F
.52689 .34459 m .5269 .3446 L .54329 .33948 L F
.52638 .34475 m .5269 .3446 L .52689 .34459 L F
.52656 .3452 m .52656 .34519 L .52648 .34528 L F
.52656 .34519 m .5259 .34439 L .52647 .34528 L F
.52656 .34519 m .52647 .34528 L .52648 .34528 L F
.54272 .33876 m .54208 .33806 L p .52746 .34426 L F P
0 g
s
.52217 .33951 m .51736 .33394 L .52528 .34363 L .672 .728 .891 r
F
.52579 .34403 m .52561 .34404 L .5259 .34439 L F
.52609 .3444 m .5259 .34439 L .52656 .34519 L F
.52609 .3444 m .52656 .34519 L .52665 .3451 L F
.52579 .34403 m .5259 .34439 L .52609 .3444 L F
.52583 .34494 m .5272 .34493 L .5269 .3446 L F
.5272 .34493 m .54329 .33948 L p .5269 .3446 L F P
0 g
s
.52612 .34529 m .5272 .34493 L p .52583 .34494 L .672 .728 .891 r
F P
0 g
s
.5259 .34439 m .52586 .34439 L .52648 .34528 L .672 .728 .891 r
F
.52561 .34404 m .52558 .34404 L .52582 .34438 L F
.52585 .34438 m .52582 .34438 L .52648 .34528 L F
.52561 .34404 m .52582 .34438 L .52585 .34438 L F
.52514 .34364 m .52547 .34405 L p .52528 .34363 L F P
0 g
s
.52547 .34405 m .52672 .34562 L p .52556 .34402 L .672 .728 .891 r
F P
0 g
s
.52528 .34363 m .52547 .34405 L .52556 .34402 L .672 .728 .891 r
F
.52607 .34485 m .52585 .34496 L .52583 .34494 L F
.52495 .34529 m .50959 .35088 L .52464 .3453 L F
.50959 .35088 m .52612 .34529 L p .52583 .34494 L F P
0 g
s
.51017 .3516 m .50959 .35088 L p .52534 .34512 L .672 .728 .891 r
F P
0 g
s
.52535 .34514 m .51017 .3516 L .52534 .34512 L .672 .728 .891 r
F
.52578 .34529 m .51796 .34805 L .52495 .34529 L F
.52558 .34547 m .51796 .34805 L p .52578 .34529 L F P
0 g
s
.5249 .34535 m .52069 .34713 L .5256 .34551 L .672 .728 .891 r
F
.51796 .34805 m .50959 .35088 L p .52495 .34529 L F P
0 g
s
.51017 .3516 m .52218 .34686 L p .52069 .34713 L .672 .728 .891 r
F P
0 g
s
.52218 .34686 m .5256 .34551 L p .52069 .34713 L .672 .728 .891 r
F P
0 g
s
.51081 .35228 m .51017 .3516 L p .51858 .34803 L .672 .728 .891 r
F P
0 g
s
.5249 .34535 m .52031 .34761 L .51858 .34803 L .672 .728 .891 r
F
.52031 .34761 m .51081 .35228 L .51858 .34803 L F
.52414 .34622 m .51081 .35228 L p .5249 .34535 L F P
0 g
s
.52464 .3453 m .513 .34892 L .52389 .34591 L .672 .728 .891 r
F
.50908 .35015 m .51434 .34864 L p .513 .34892 L F P
0 g
s
.51434 .34864 m .52389 .34591 L p .513 .34892 L .672 .728 .891 r
F P
0 g
s
.52389 .34591 m .5177 .34768 L p .5207 .34624 L .672 .728 .891 r
F P
0 g
s
.5177 .34768 m .51487 .3482 L .5207 .34624 L .672 .728 .891 r
F
.5249 .34535 m .5256 .34551 L .5258 .34532 L F
.5274 .34647 m .52715 .34658 L .52708 .34649 L F
.5274 .34647 m .52708 .34649 L .5256 .34465 L F
.52629 .3448 m .52604 .3452 L .52585 .34496 L F
.54272 .33876 m .52604 .3452 L .52629 .3448 L F
.54272 .33876 m .52613 .3453 L p .52604 .3452 L F P
0 g
s
.52191 .34593 m .52389 .34591 L .5207 .34624 L .672 .728 .891 r
F
.52715 .34658 m .52708 .3466 L .527 .3465 L F
.52708 .34649 m .527 .3465 L .5256 .34465 L F
.52715 .34658 m .527 .3465 L .52708 .34649 L F
.5256 .34465 m .527 .3465 L .52442 .34346 L F
.527 .3465 m .52708 .3466 L .527 .3465 L F
.527 .3465 m .527 .3465 L .52442 .34346 L F
.52611 .34524 m .52612 .34529 L .52586 .34529 L F
.52509 .34437 m .52542 .34475 L .5254 .34478 L F
.52509 .34437 m .52535 .34471 L .52512 .34436 L F
.52612 .34529 m .52558 .34547 L p .52578 .34529 L F P
0 g
s
.5256 .34551 m .52613 .3453 L p .5258 .34532 L .672 .728 .891 r
F P
0 g
s
.5254 .34478 m .53007 .35022 L .53424 .35669 L .672 .728 .891 r
F
.52535 .34471 m .52578 .34529 L .52537 .34471 L F
.52535 .34471 m .52537 .34471 L .52512 .34436 L F
.52481 .34392 m .53531 .35633 L .52478 .34394 L F
.52611 .34524 m .52586 .34529 L .52578 .34529 L F
.52611 .34524 m .52578 .34529 L .52582 .34525 L F
.52578 .34529 m .5258 .34532 L .52588 .3452 L F
.5258 .34532 m .52613 .3453 L .52586 .34525 L F
.54329 .33948 m .54272 .33876 L p .52612 .34484 L F P
0 g
s
.52725 .34448 m .52683 .34491 L .53456 .34198 L .672 .728 .891 r
F
.52717 .34489 m .53456 .34198 L p .52683 .34491 L F P
0 g
s
.53191 .34303 m .5272 .34493 L .52739 .34444 L .672 .728 .891 r
F
.54329 .33948 m .53076 .34372 L p .53191 .34303 L F P
0 g
s
.53076 .34372 m .5272 .34493 L p .53191 .34303 L .672 .728 .891 r
F P
0 g
s
.54208 .33806 m .54138 .3374 L p .54088 .33764 L .672 .728 .891 r
F P
0 g
s
.52776 .34481 m .52889 .34449 L p .5273 .34479 L .672 .728 .891 r
F P
0 g
s
.53557 .35622 m .53635 .35592 L p .52716 .34529 L .672 .728 .891 r
F P
0 g
s
.54272 .33876 m .52585 .34496 L .52607 .34485 L .672 .728 .891 r
F
.52716 .34529 m .52559 .34346 L .52694 .34546 L F
.52559 .34346 m .5254 .34354 L .52694 .34546 L F
.53456 .34198 m .54272 .33876 L p .52817 .34414 L F P
0 g
s
.52725 .34448 m .53456 .34198 L .52817 .34414 L .672 .728 .891 r
F
.52746 .34426 m .52725 .34448 L .54272 .33876 L F
.54379 .34023 m .54329 .33948 L p .53191 .34303 L F P
0 g
s
.53191 .34303 m .52739 .34444 L .53009 .34375 L .672 .728 .891 r
F
.53191 .34303 m .53009 .34375 L .54379 .34023 L F
.52739 .34444 m .52782 .34445 L .54379 .34023 L F
.54208 .33806 m .52864 .34418 L p .52827 .3442 L F P
0 g
s
.54208 .33806 m .52793 .34423 L p .52746 .34426 L .672 .728 .891 r
F P
0 g
s
.52634 .34514 m .52612 .34529 L .5261 .34488 L .672 .728 .891 r
F
.52634 .34514 m .52614 .34493 L .52615 .3449 L F
.52559 .34346 m .52217 .33951 L .5254 .34354 L F
.52547 .34362 m .52528 .34363 L .52561 .34404 L F
.52547 .34362 m .52561 .34404 L .52579 .34403 L F
.5259 .34439 m .52561 .34404 L .52586 .34439 L F
.52561 .34404 m .52528 .34363 L .52558 .34404 L F
.52602 .34474 m .5239 .3421 L .52627 .34452 L F
.52217 .33951 m .52528 .34363 L .52547 .34362 L F
.52442 .34346 m .52481 .34392 L .52478 .34394 L F
.51736 .33394 m .52475 .34316 L p .52442 .34346 L F P
0 g
s
.52163 .3397 m .52509 .34437 L .52066 .33811 L .672 .728 .891 r
F
.51736 .33394 m .52514 .34364 L p .52528 .34363 L F P
0 g
s
.52586 .344 m .52358 .3417 L .52099 .33848 L .672 .728 .891 r
F
.52163 .3397 m .52066 .33811 L .52055 .338 L F
.52163 .3397 m .52029 .3376 L .51964 .33678 L F
.52478 .34394 m .52512 .34434 L .52509 .34437 L F
.52509 .34437 m .52512 .34436 L .52038 .33771 L F
.52512 .34434 m .53531 .35633 L .52509 .34437 L F
.52578 .34529 m .52588 .3452 L .52557 .34477 L F
.52521 .34417 m .52519 .34418 L .52442 .34346 L F
.52455 .34334 m .52523 .34418 L .52442 .34346 L F
.52542 .34478 m .52557 .34477 L .52099 .33848 L F
.52578 .34529 m .52557 .34477 L .52542 .34478 L F
.52864 .34418 m .52764 .34463 L p .52746 .34426 L F P
0 g
s
.52795 .34603 m .52697 .34506 L .52786 .34608 L .672 .728 .891 r
F
.52707 .34465 m .52889 .34449 L .52782 .34445 L F
.52475 .34316 m .52574 .34439 L p .52523 .34418 L F P
0 g
s
.52574 .34439 m .52559 .34451 L .52523 .34418 L .672 .728 .891 r
F
.52475 .34316 m .52523 .34418 L .52455 .34334 L F
.5256 .34476 m .52602 .34474 L .5239 .34209 L F
.52598 .34476 m .5239 .3421 L .52602 .34474 L F
.52612 .34484 m .52583 .34494 L .52632 .34479 L F
.52615 .3449 m .52557 .34428 L .52614 .34494 L F
.52614 .34497 m .52683 .34491 L .52618 .34494 L F
.52614 .34507 m .52683 .34491 L .52614 .34497 L F
.52588 .3452 m .52618 .34494 L .52607 .34474 L F
.52614 .34494 m .52598 .34476 L p .52605 .34478 L F P
0 g
s
.52612 .34484 m .52632 .34479 L .52617 .34482 L .672 .728 .891 r
F
.52618 .34494 m .52605 .34478 L .52666 .34492 L F
.52614 .34494 m .52605 .34478 L .52618 .34494 L F
.52614 .34494 m .52615 .34494 L p .52615 .3449 L F P
0 g
s
.52614 .34493 m .5261 .34488 L .52615 .3449 L .672 .728 .891 r
F
.52504 .34426 m .52473 .34379 L .52471 .34379 L F
.52666 .34492 m .52627 .34452 L .52666 .34492 L F
.52471 .34379 m .52099 .33848 L .52038 .33771 L F
.52475 .34377 m .52474 .34377 L .52442 .34346 L F
.52473 .34379 m .52099 .33848 L .52471 .34379 L F
.52509 .34437 m .52038 .33771 L .52029 .3376 L F
.52217 .33951 m .52045 .33765 L .52007 .33708 L F
.52045 .33765 m .51964 .33678 L .52007 .33708 L F
.52557 .34477 m .5256 .34476 L .5239 .34209 L F
.5264 .34441 m .52033 .33765 L .52217 .33951 L F
.52055 .338 m .52066 .33811 L .52029 .3376 L F
.5263 .3445 m .52099 .33848 L .5264 .34441 L F
.51736 .33394 m .52163 .3397 L .51964 .33678 L F
.52099 .33848 m .5171 .33405 L .52033 .33765 L F
.52099 .33848 m .52033 .33765 L .5264 .34441 L F
.52007 .33708 m .51964 .33678 L .51736 .33394 L F
.51763 .33385 m .51736 .33394 L p .51964 .33678 L F P
0 g
s
.52376 .34192 m .5239 .34209 L .51844 .33357 L .672 .728 .891 r
F
.52557 .34477 m .5239 .34209 L .52376 .34192 L F
.52033 .33765 m .5171 .33405 L .51964 .33678 L F
.52033 .33765 m .51964 .33678 L .52217 .33951 L F
.52677 .34493 m .5263 .3445 L .52685 .34493 L F
.52685 .34493 m .5263 .3445 L .5264 .34441 L F
.52683 .34491 m .52665 .3451 L .52717 .34489 L F
.5272 .34493 m .52666 .34511 L p .52685 .34493 L F P
0 g
s
.52708 .34531 m .5263 .3445 L .52716 .34529 L .672 .728 .891 r
F
.52614 .34489 m .52683 .34491 L .52701 .34473 L F
.52614 .34489 m .52701 .34473 L .52688 .34465 L F
.52599 .34495 m .52719 .34454 L .52713 .34453 L F
.52617 .34482 m .52632 .34479 L .52638 .34477 L F
.52617 .34482 m .52638 .34477 L .52638 .34475 L F
.52598 .34476 m .52627 .34452 L .52666 .34492 L F
.5262 .34492 m .52607 .34474 L p .52618 .34494 L F P
0 g
s
.52099 .33848 m .52557 .34477 L .52376 .34192 L .672 .728 .891 r
F
.5239 .3421 m .51631 .33436 L .5239 .34209 L F
.5239 .34209 m .51631 .33436 L .52358 .3417 L F
.52358 .3417 m .51631 .33436 L .52099 .33848 L F
.52598 .34476 m .51631 .33436 L p .5239 .3421 L F P
0 g
s
.52339 .34146 m .51631 .33436 L .52304 .34157 L .672 .728 .891 r
F
.52688 .34465 m .52701 .34473 L .52719 .34454 L F
.52712 .34452 m .52713 .34453 L .52725 .34448 L F
.52713 .34453 m .52719 .34454 L .52725 .34448 L F
.52739 .34444 m .52696 .34472 L .52681 .34462 L F
.52583 .34495 m .52713 .34453 L .52712 .34452 L F
.52739 .34444 m .52638 .34475 L .52782 .34445 L F
.52638 .34475 m .52665 .34476 L .52782 .34445 L F
.52626 .34504 m .52665 .3451 L .52683 .34491 L F
.52588 .3452 m .52607 .34474 L .52607 .34474 L F
.52542 .34475 m .53531 .35633 L .5254 .34478 L F
.52639 .3452 m .52612 .34529 L p .52634 .34514 L F P
0 g
s
.52634 .34514 m .52665 .3451 L .52626 .34504 L .672 .728 .891 r
F
.52639 .3452 m .52634 .34514 L .52665 .34493 L F
.52614 .34494 m .52666 .34492 L .52618 .34494 L F
.52618 .34494 m .52683 .34491 L .52614 .34489 L F
.5262 .34492 m .5262 .34492 L p .52615 .3449 L F P
0 g
s
.52668 .34493 m .5263 .3445 L .52672 .34493 L .672 .728 .891 r
F
.52565 .34428 m .52556 .34427 L .52615 .3449 L F
.52339 .34146 m .52556 .34427 L .52565 .34428 L F
.52339 .34146 m .52304 .34157 L .52556 .34427 L F
.52557 .34428 m .52516 .34384 L .52556 .34428 L F
.52516 .34384 m .52304 .34157 L .52513 .34385 L F
.51631 .33436 m .52302 .34158 L p .52304 .34157 L F P
0 g
s
.52302 .34158 m .52513 .34385 L p .52304 .34157 L .672 .728 .891 r
F P
0 g
s
.52513 .34385 m .52614 .34494 L p .52516 .34384 L .672 .728 .891 r
F P
0 g
s
.52339 .34146 m .52565 .34428 L .52534 .34458 L .672 .728 .891 r
F
.52607 .34474 m .52607 .34473 L p .52607 .34474 L F P
0 g
s
.52627 .34452 m .5239 .3421 L .52627 .34452 L .672 .728 .891 r
F
.5239 .3421 m .5239 .34209 L .52627 .34452 L F
.52581 .34405 m .5239 .34209 L .52586 .344 L F
.5239 .34209 m .52358 .3417 L .52586 .344 L F
.52607 .34473 m .51844 .33357 L p .5239 .34209 L F P
0 g
s
.52602 .34474 m .52607 .34473 L .5239 .34209 L .672 .728 .891 r
F
.52569 .34422 m .5262 .34492 L .52615 .3449 L F
.52372 .34133 m .5257 .3442 L .52569 .34422 L F
.5257 .3442 m .5262 .34492 L .52569 .34422 L F
.52681 .34462 m .52674 .34475 L .5266 .34468 L F
.52674 .34475 m .52665 .34493 L .5266 .34468 L F
.52557 .34428 m .52556 .34428 L .52614 .34494 L F
.52565 .34428 m .52615 .3449 L .52547 .34463 L F
.52613 .34489 m .5261 .34488 L .5261 .34488 L F
.52613 .34489 m .5261 .34488 L .5261 .34484 L F
.52615 .3449 m .52613 .34489 L .5261 .34484 L F
.52608 .34487 m .52613 .34489 L .52614 .34489 L F
.52612 .34486 m .52614 .34489 L .52713 .34453 L F
.52608 .34487 m .52614 .34489 L .52612 .34486 L F
.5266 .34468 m .52665 .34493 L .5261 .34484 L F
.52665 .34493 m .52634 .34514 L .52618 .34494 L F
.5262 .34492 m .5262 .34492 L p .52618 .34494 L F P
0 g
s
.52618 .34494 m .52666 .34492 L .52668 .34493 L .672 .728 .891 r
F
.52665 .34493 m .52618 .34494 L .5261 .34484 L F
.52638 .34475 m .52615 .34482 L .52665 .34476 L F
.5261 .34484 m .52546 .34527 L .52542 .34515 L F
.52588 .3452 m .52607 .34473 L .5256 .34476 L F
.5261 .34484 m .52611 .34524 L .52546 .34527 L F
.52615 .34494 m .52614 .34494 L p .52618 .34494 L F P
0 g
s
.52599 .34495 m .52618 .34494 L .52615 .3449 L .672 .728 .891 r
F
.52599 .34495 m .52615 .3449 L .52614 .3449 L F
.52602 .34509 m .52614 .34507 L .52614 .34497 L F
.52602 .34509 m .52618 .34494 L .52599 .34495 L F
.52597 .34512 m .52597 .34515 L .52618 .34494 L F
.52588 .3452 m .52597 .34515 L .52597 .34512 L F
.52588 .3452 m .5259 .34522 L .52597 .34515 L F
.52464 .3453 m .52456 .34536 L .5249 .34525 L F
.52456 .34536 m .52389 .34591 L .5249 .34525 L F
.52487 .34516 m .52469 .34563 L .52191 .34593 L F
.52518 .34529 m .52634 .34514 L .52626 .34504 L F
.52601 .34512 m .52587 .3452 L .52601 .3451 L F
.52587 .3452 m .52488 .34579 L .52601 .3451 L F
.52488 .34579 m .52487 .34578 L .52601 .3451 L F
.52601 .3451 m .5242 .34618 L .52603 .34498 L F
.5242 .34618 m .5242 .34618 L .52603 .34498 L F
.52605 .34486 m .52593 .34534 L .52604 .34486 L F
.52613 .3453 m .5263 .34523 L p .52593 .34527 L F P
0 g
s
.5263 .34523 m .52639 .3452 L p .52593 .34527 L .672 .728 .891 r
F P
0 g
s
.52586 .34525 m .52593 .34527 L .52639 .3452 L .672 .728 .891 r
F
.5259 .34522 m .52623 .34568 L .52618 .34494 L F
.52623 .34568 m .52643 .34554 L .52618 .34494 L F
.52579 .34547 m .52575 .34545 L .52588 .3454 L F
.52575 .34545 m .52557 .34538 L .52588 .3454 L F
.52618 .34495 m .52597 .34532 L .52598 .34525 L F
.5262 .34492 m .52597 .34532 L .52618 .34495 L F
.5258 .34532 m .5259 .34522 L .52588 .3452 L F
.52582 .34525 m .52578 .34529 L .52464 .3453 L F
.52517 .34531 m .52639 .3452 L .52634 .34514 L F
.5249 .34535 m .52517 .34532 L .52517 .34531 L F
.52517 .34532 m .52639 .3452 L .52517 .34531 L F
.5262 .34492 m .52597 .34536 L .52597 .34532 L F
.5258 .34532 m .52607 .34569 L .5259 .34522 L F
.52588 .3454 m .52557 .34538 L .52601 .34512 L F
.52682 .34649 m .52717 .34639 L .52684 .3459 L F
.52661 .34599 m .52684 .3459 L .52618 .34494 L F
.52682 .34649 m .52684 .3459 L .52661 .34599 L F
.52639 .3452 m .52615 .34494 L p .52618 .34494 L F P
0 g
s
.52517 .34531 m .52634 .34514 L .52518 .34529 L .672 .728 .891 r
F
.52618 .34494 m .52653 .34545 L .52632 .34511 L F
.52639 .3452 m .52618 .34494 L .52652 .34493 L F
.52618 .34494 m .52632 .34511 L .5262 .34492 L F
.5262 .34492 m .52639 .3452 L p .52597 .34536 L F P
0 g
s
.52716 .34529 m .52694 .34546 L .53557 .35622 L .672 .728 .891 r
F
.52665 .3451 m .52656 .34519 L .53557 .35622 L F
.52685 .34555 m .52656 .3452 L .52672 .34562 L F
.52718 .34596 m .52685 .34555 L .52704 .34601 L F
.53531 .35633 m .53557 .35622 L p .52718 .34596 L F P
0 g
s
.52704 .34601 m .53531 .35633 L p .52718 .34596 L .672 .728 .891 r
F P
0 g
s
.53635 .35592 m .5266 .34543 L p .52693 .34539 L .672 .728 .891 r
F P
0 g
s
.52672 .34562 m .52704 .34601 L p .52685 .34555 L .672 .728 .891 r
F P
0 g
s
.52661 .3454 m .527 .34586 L .52702 .34584 L .672 .728 .891 r
F
.52656 .3452 m .52648 .34528 L .52672 .34562 L F
.5266 .34543 m .52639 .3452 L p .52693 .34539 L F P
0 g
s
.52615 .3449 m .5266 .34541 L .52661 .3454 L .672 .728 .891 r
F
.5266 .34541 m .527 .34586 L .52661 .3454 L F
.52685 .34493 m .52665 .34493 L .52719 .34457 L F
.52723 .34458 m .52719 .34457 L .52739 .34444 L F
.52685 .34493 m .52719 .34457 L .52723 .34458 L F
.52639 .3452 m .52665 .3451 L p .52634 .34514 L F P
0 g
s
.52666 .34511 m .52639 .3452 L p .52665 .34493 L .672 .728 .891 r
F P
0 g
s
.52666 .34511 m .52665 .34493 L .52685 .34493 L .672 .728 .891 r
F
.52374 .34132 m .52537 .34371 L p .52372 .34133 L F P
0 g
s
.5254 .34375 m .5262 .34492 L p .52539 .34375 L .672 .728 .891 r
F P
0 g
s
.52537 .34371 m .52536 .34371 L .52372 .34133 L .672 .728 .891 r
F
.52537 .34371 m .5254 .34375 L p .52536 .34371 L F P
0 g
s
.5254 .34375 m .52539 .34375 L .52536 .34371 L .672 .728 .891 r
F
.52099 .33848 m .52376 .34192 L .51844 .33357 L F
.52666 .34492 m .52581 .34405 L .52586 .344 L F
.52372 .34133 m .5257 .34424 L .52339 .34146 L F
.5257 .34424 m .52565 .34428 L .52339 .34146 L F
.5257 .34424 m .52615 .3449 L .52565 .34428 L F
.52621 .34429 m .5262 .3443 L .52621 .3443 L F
.52615 .34482 m .52623 .34485 L .52665 .34476 L F
.52674 .34469 m .5264 .34489 L .52643 .34471 L F
.5262 .34492 m .52598 .34525 L .52605 .34486 L F
.52601 .34512 m .52603 .34498 L .52615 .3449 L F
.52617 .34493 m .5268 .34482 L .52614 .3449 L F
.52643 .3449 m .52616 .34482 L .52643 .34492 L F
.52616 .34482 m .52615 .3449 L .52643 .34492 L F
.52619 .34495 m .52615 .3449 L .52623 .34484 L F
.52628 .34485 m .52623 .34484 L .52643 .34471 L F
.52627 .34486 m .5268 .34482 L .52665 .34476 L F
.52614 .3449 m .52632 .34488 L .52627 .34486 L F
.52632 .34488 m .5268 .34482 L .52627 .34486 L F
.52627 .34452 m .52627 .34452 L .52666 .34492 L F
.52693 .34539 m .52639 .3452 L .52652 .34493 L F
.52643 .34492 m .52661 .3454 L .52679 .34504 L F
.52553 .34413 m .52549 .34408 L .52539 .34447 L F
.52529 .34337 m .52524 .34336 L .52615 .3449 L F
.52565 .34428 m .52547 .34463 L .52534 .34458 L F
.52576 .34469 m .52557 .34378 L .52547 .34463 L F
.52518 .34326 m .52489 .34333 L .52615 .3449 L F
.52621 .34429 m .52529 .34337 L .52615 .3449 L F
.52549 .34408 m .52461 .34298 L .52604 .34424 L F
.52568 .34432 m .52557 .3438 L .52557 .3438 L F
.52576 .34469 m .52568 .34432 L .52568 .34432 L F
.52519 .34524 m .52602 .34509 L .52599 .34495 L F
.52583 .34495 m .52613 .34489 L .52608 .34487 L F
.5262 .34492 m .52604 .34486 L .52615 .3449 L F
.52614 .3449 m .52615 .3449 L .52614 .34489 L F
.52729 .34444 m .52583 .34495 L .52725 .34448 L F
.5261 .34484 m .52583 .34495 L .52729 .34444 L F
.5261 .34484 m .52514 .34528 L .52518 .34513 L F
.5261 .34484 m .52577 .34494 L .52584 .34493 L F
.52605 .34486 m .52604 .34486 L .52604 .34486 L F
.52615 .3449 m .52605 .34486 L .52605 .34486 L F
.52605 .34486 m .52604 .34486 L .52605 .34486 L F
.52542 .34515 m .52546 .34527 L .52514 .34528 L F
.5249 .34535 m .52517 .34531 L .52518 .34529 L F
.5249 .34535 m .52518 .34529 L .52519 .34524 L F
.52518 .34529 m .52602 .34509 L .52519 .34524 L F
.52583 .34495 m .5249 .34535 L .52599 .34495 L F
.5261 .34484 m .52508 .34556 L .5249 .34535 L F
.52508 .34556 m .52414 .34622 L .52482 .34545 L F
.52508 .34556 m .52482 .34545 L .5249 .34535 L F
.5383 .35498 m .53921 .35444 L p .53114 .34823 L F P
0 g
s
.52599 .34488 m .52584 .34493 L .52601 .34489 L .672 .728 .891 r
F
.52583 .34495 m .52599 .34495 L .52613 .34489 L F
.5249 .34535 m .5258 .34532 L .52586 .34525 L F
.52603 .34498 m .52453 .34597 L .52604 .34488 L F
.52453 .34597 m .52414 .34622 L .52451 .34596 L F
.52453 .34597 m .52451 .34596 L .52604 .34488 L F
.53921 .35444 m .54007 .35387 L p .53487 .35036 L F P
0 g
s
.52588 .3454 m .52601 .34512 L .52597 .34532 L .672 .728 .891 r
F
.52598 .34525 m .52593 .34534 L .52605 .34486 L F
.52599 .34488 m .52601 .34489 L .52603 .34489 L F
.52603 .34498 m .52604 .34488 L .5261 .34484 L F
.52604 .34487 m .52603 .34489 L .52612 .34487 L F
.52599 .34488 m .52603 .34489 L .52604 .34487 L F
.5261 .34484 m .52599 .34488 L .52612 .34487 L F
.52518 .34326 m .52339 .34146 L .52489 .34333 L F
.52529 .34337 m .52518 .34326 L .52524 .34336 L F
.52619 .34427 m .52439 .3427 L .52339 .34146 L F
.52463 .34301 m .52436 .34209 L .5239 .3416 L F
.52539 .34447 m .52499 .34345 L .52463 .34301 L F
.52328 .34181 m .52327 .3418 L .52449 .34283 L F
.5245 .34284 m .52449 .34283 L .52619 .34427 L F
.52339 .34146 m .52535 .3446 L .52439 .34271 L F
.52328 .34181 m .52449 .34283 L .5245 .34284 L F
.52535 .3446 m .52539 .34447 L .52463 .34301 L F
.5245 .34284 m .52463 .34301 L .52376 .34133 L F
.52535 .3446 m .52463 .34301 L .5245 .34284 L F
.52303 .3416 m .52309 .34158 L .52439 .3427 L F
.52449 .34283 m .52439 .3427 L .52619 .34427 L F
.52303 .3416 m .52439 .3427 L .52449 .34283 L F
.52439 .34271 m .52376 .34133 L .5237 .34135 L F
.52535 .3446 m .5245 .34284 L .52439 .34271 L F
.5245 .34284 m .52376 .34133 L .52439 .34271 L F
.52499 .34345 m .5241 .34121 L .52463 .34301 L F
.52328 .34181 m .52303 .3416 L .52327 .3418 L F
.52623 .34568 m .52682 .34649 L .52643 .34554 L F
.52607 .34569 m .52619 .34562 L .5259 .34522 L F
.5274 .34647 m .53531 .35633 L p .52708 .3466 L F P
0 g
s
.52682 .34649 m .53424 .35669 L .52717 .34639 L .672 .728 .891 r
F
.52653 .34545 m .52717 .34639 L .52654 .34544 L F
.53424 .35669 m .52719 .34638 L p .52717 .34639 L F P
0 g
s
.52719 .34638 m .52686 .34589 L p .52717 .34639 L .672 .728 .891 r
F P
0 g
s
.52646 .34529 m .52672 .34562 L p .52638 .34529 L .672 .728 .891 r
F P
0 g
s
.52686 .34589 m .5262 .34492 L p .52685 .3459 L .672 .728 .891 r
F P
0 g
s
.52717 .34639 m .52686 .34589 L .52685 .3459 L .672 .728 .891 r
F
.5322 .34383 m .53341 .34354 L p .53202 .34384 L F P
0 g
s
.53341 .34354 m .54422 .34099 L p .53255 .3436 L .672 .728 .891 r
F P
0 g
s
.53341 .34354 m .5322 .34383 L p .53488 .34297 L .672 .728 .891 r
F P
0 g
s
.52554 .34415 m .52604 .34424 L .52627 .34444 L .672 .728 .891 r
F
.5268 .34482 m .52706 .34479 L .52706 .34478 L F
.52597 .34532 m .52601 .34512 L .52622 .34499 L F
.52618 .34494 m .5268 .34483 L .52617 .34493 L F
.52615 .34494 m .52618 .34494 L .52668 .34493 L F
.53199 .35727 m .53084 .35748 L p .52755 .34954 L F P
0 g
s
.52601 .34512 m .52615 .3449 L .52619 .34495 L .672 .728 .891 r
F
.52556 .34512 m .52622 .34499 L .52568 .34502 L F
.52622 .34499 m .52755 .34474 L .52618 .34494 L F
.52622 .34499 m .52618 .34494 L .52568 .34502 L F
.52617 .34493 m .5268 .34483 L .5268 .34482 L F
.52643 .34492 m .52615 .3449 L .52661 .3454 L F
.5264 .34489 m .52622 .34499 L .52628 .34485 L F
.52622 .34499 m .52601 .34512 L .52619 .34495 L F
.52794 .34467 m .52793 .34465 L .52755 .34471 L F
.53313 .357 m .53199 .35727 L p .52671 .34706 L F P
0 g
s
.51938 .34685 m .52163 .34632 L p .5207 .34624 L .672 .728 .891 r
F P
0 g
s
.52518 .34513 m .52514 .34528 L .52464 .3453 L .672 .728 .891 r
F
.52389 .34591 m .52592 .34533 L p .5249 .34525 L F P
0 g
s
.52566 .34529 m .52469 .34563 L .52487 .34516 L .672 .728 .891 r
F
.52682 .34499 m .52661 .3454 L .52702 .34584 L F
.52788 .34629 m .52745 .34581 L .52802 .34628 L F
.51081 .35228 m .52414 .34622 L p .52244 .34662 L F P
0 g
s
.52051 .34826 m .51152 .35294 L p .52244 .34662 L .672 .728 .891 r
F P
0 g
s
.52051 .34826 m .52152 .34773 L p .519 .34878 L .672 .728 .891 r
F P
0 g
s
.52737 .34572 m .52668 .34493 L .52744 .34569 L .672 .728 .891 r
F
.52549 .34408 m .52604 .34424 L .52554 .34415 L F
.5262 .3443 m .52615 .3449 L .52621 .3443 L F
.52508 .34396 m .52627 .34444 L .52616 .34458 L F
.52568 .34432 m .52603 .34475 L .52557 .3438 L F
.52615 .34482 m .5261 .34484 L .52623 .34485 L F
.5261 .34484 m .52612 .34487 L .52623 .34485 L F
.52643 .34471 m .52615 .3449 L .5261 .34484 L F
.5268 .34484 m .5268 .34483 L .52568 .34502 L F
.52628 .34507 m .52622 .34499 L .52674 .34469 L F
.52615 .3449 m .52603 .34498 L .5261 .34484 L F
.52577 .34494 m .52568 .34502 L .52665 .34476 L F
.52616 .34482 m .52616 .34482 L .52643 .3449 L F
.52619 .34495 m .52623 .34484 L .52628 .34485 L F
.5264 .34489 m .52628 .34485 L .52643 .34471 L F
.52746 .34426 m .5261 .34484 L .52729 .34444 L F
.5264 .34471 m .52643 .34471 L .5261 .34484 L F
.52621 .3443 m .52616 .34482 L .52643 .3449 L F
.52668 .34493 m .52666 .34492 L .52666 .34492 L F
.52615 .34491 m .52603 .34475 L .52675 .34493 L F
.52603 .34475 m .52567 .3443 L .52611 .34456 L F
.52663 .34486 m .52657 .34483 L .52674 .34469 L F
.52657 .34494 m .52657 .34483 L .52663 .34486 L F
.52755 .34474 m .52755 .34473 L .5268 .34484 L F
.5268 .34485 m .5268 .34484 L .52568 .34502 L F
.5272 .34493 m .52685 .34493 L .52739 .34444 L F
.52755 .34474 m .5268 .34484 L .5268 .34485 L F
.52568 .34502 m .52618 .34494 L .52617 .34493 L F
.52602 .34493 m .52617 .34493 L .52614 .3449 L F
.52568 .34502 m .52602 .34496 L .52602 .34493 L F
.52602 .34496 m .52617 .34493 L .52602 .34493 L F
.52474 .3453 m .5207 .34624 L .52435 .34543 L F
.52557 .34477 m .52588 .3452 L .5256 .34476 L F
.52604 .34486 m .52592 .34533 L .52543 .3447 L F
.52546 .34464 m .52543 .3447 L .52536 .34461 L F
.52604 .34486 m .52543 .3447 L .52546 .34464 L F
.52625 .34503 m .52776 .34481 L .52622 .34499 L F
.5268 .34483 m .52706 .34479 L .5268 .34482 L F
.52657 .34494 m .52647 .34491 L .52657 .34483 L F
.52629 .34439 m .52643 .3449 L .52682 .34499 L F
.52643 .3449 m .52643 .34492 L .52662 .34495 L F
.52639 .3452 m .52579 .34547 L p .52632 .34511 L F P
0 g
s
.52597 .34532 m .52622 .34499 L .52628 .34507 L .672 .728 .891 r
F
.52615 .34494 m .52659 .34542 L p .52615 .3449 L F P
0 g
s
.52593 .34534 m .52592 .34533 L .52604 .34486 L .672 .728 .891 r
F
.52657 .34494 m .52632 .34511 L .52647 .34491 L F
.52632 .34511 m .52598 .34535 L .52629 .34507 L F
.52702 .34532 m .52652 .34493 L .52668 .34493 L F
.53635 .35592 m .52689 .34535 L .52702 .34532 L F
.52689 .34535 m .52652 .34493 L .52702 .34532 L F
.52598 .34535 m .52597 .34535 L .52647 .34491 L F
.52597 .34535 m .52597 .34532 L .52647 .34491 L F
.52598 .34525 m .52597 .34536 L .52591 .34536 L F
.52592 .34533 m .52639 .3452 L p .52599 .34508 L F P
0 g
s
.52626 .34504 m .52634 .34514 L .52648 .345 L .672 .728 .891 r
F
.52634 .34514 m .52639 .3452 L .52648 .345 L F
.52716 .34529 m .52677 .34493 L .52685 .34493 L F
.52639 .3452 m .52776 .34481 L p .52648 .345 L F P
0 g
s
.52634 .34514 m .52632 .34511 L .52649 .34499 L .672 .728 .891 r
F
.52622 .34499 m .52776 .34481 L .5273 .34479 L F
.52634 .34514 m .52649 .34499 L .52696 .34467 L F
.52639 .3452 m .52634 .34514 L .52696 .34467 L F
.52643 .3449 m .52662 .34495 L .52682 .34499 L F
.5268 .34482 m .52706 .34478 L .52681 .34477 L F
.52696 .34472 m .52665 .34493 L .52681 .34462 L F
.52665 .34476 m .52706 .34478 L .52707 .34465 L F
.52681 .34501 m .52665 .34496 L .52696 .34467 L F
.52655 .34497 m .52685 .34493 L .52665 .34493 L F
.52603 .34475 m .52615 .34491 L .52612 .34476 L F
.52622 .34499 m .52619 .34495 L .52628 .34485 L F
.52632 .34511 m .52629 .34507 L .52647 .34491 L F
.52528 .34517 m .52625 .34503 L .52622 .34499 L F
.52531 .34518 m .52776 .34481 L .52528 .34517 L F
.52621 .34498 m .52655 .34497 L .52637 .34491 L F
.52624 .34502 m .5259 .34521 L .52615 .34491 L F
.52603 .34475 m .52612 .34476 L .52557 .3438 L F
.52568 .34432 m .52557 .3438 L .52568 .34432 L F
.52553 .34413 m .52557 .34378 L .52549 .34408 L F
.52613 .34477 m .52557 .34377 L .52557 .34378 L F
.52624 .34438 m .52643 .34492 L .52629 .34439 L F
.52616 .34458 m .52627 .34444 L .52683 .34493 L F
.52697 .34494 m .52681 .34501 L p .52696 .34467 L F P
0 g
s
.52755 .34473 m .52755 .34471 L .5268 .34483 L .672 .728 .891 r
F
.52755 .34473 m .5268 .34483 L .5268 .34484 L F
.52706 .34479 m .52889 .34449 L .52707 .34465 L F
.52764 .34463 m .52697 .34494 L p .52696 .34467 L F P
0 g
s
.52681 .34501 m .52764 .34463 L p .52683 .34496 L .672 .728 .891 r
F P
0 g
s
.5261 .34484 m .52619 .34486 L .52612 .34483 L .672 .728 .891 r
F
.52619 .34486 m .52624 .34487 L .52619 .34485 L F
.52615 .34491 m .52618 .34487 L .52612 .34476 L F
.52619 .34486 m .52619 .34485 L .52612 .34483 L F
.5261 .34484 m .52615 .34491 L .52624 .34487 L F
.52615 .34491 m .52619 .34487 L .52618 .34487 L F
.52612 .34483 m .5262 .34486 L .52612 .34483 L F
.52615 .34478 m .52619 .34485 L p .52612 .34483 L F P
0 g
s
.52619 .34485 m .5262 .34486 L p .52612 .34483 L .672 .728 .891 r
F P
0 g
s
.52612 .34483 m .52624 .34487 L .52706 .34452 L .672 .728 .891 r
F
.52712 .34442 m .52706 .34452 L .53514 .34109 L F
.52789 .34464 m .53341 .34354 L .53255 .3436 L F
.52685 .34493 m .52631 .34439 L .52682 .34499 L F
.52631 .34439 m .52629 .34439 L .52682 .34499 L F
.52622 .3443 m .52621 .3443 L .52682 .34499 L F
.52616 .34458 m .52683 .34493 L .52675 .34493 L F
.5249 .34525 m .52592 .34533 L .52599 .34508 L F
.52592 .34533 m .52589 .34533 L .52543 .3447 L F
.52543 .3447 m .52543 .3447 L .52536 .34461 L F
.52592 .34533 m .52543 .3447 L .52543 .3447 L F
.52469 .34608 m .52051 .34826 L p .5248 .34588 L F P
0 g
s
.52745 .34581 m .52737 .34572 L .52754 .3458 L .672 .728 .891 r
F
.52737 .34572 m .52744 .34569 L .52754 .3458 L F
.53635 .35592 m .52788 .34629 L .52802 .34628 L F
.52734 .34559 m .52702 .34584 L .53635 .35592 L F
.53635 .35592 m .53735 .35547 L p .52795 .34603 L F P
0 g
s
.52795 .34603 m .52786 .34608 L .53635 .35592 L .672 .728 .891 r
F
.52745 .34581 m .52754 .3458 L .52802 .34628 L F
.52802 .34628 m .52708 .34531 L .52716 .34529 L F
.52697 .34506 m .52684 .34502 L .5278 .34612 L F
.52786 .34608 m .5278 .34612 L .53635 .35592 L F
.52697 .34506 m .5278 .34612 L .52786 .34608 L F
.52572 .34519 m .52566 .34529 L .52554 .34527 L F
.52572 .34519 m .52554 .34527 L .52516 .34521 L F
.52577 .34473 m .52576 .34469 L .52576 .34469 L F
.52589 .34531 m .52577 .34473 L .52589 .34532 L F
.52534 .34458 m .52589 .34533 L .5258 .34531 L F
.5259 .34491 m .52572 .34519 L .52516 .34521 L F
.52579 .34547 m .52414 .34622 L p .52557 .34538 L F P
0 g
s
.5242 .34618 m .52414 .34622 L .5242 .34618 L .672 .728 .891 r
F
.52414 .34622 m .52496 .34585 L p .52327 .34642 L F P
0 g
s
.52586 .34539 m .52628 .34596 L .52585 .34539 L .672 .728 .891 r
F
.52607 .34569 m .53424 .35669 L .52619 .34562 L F
.52628 .34596 m .53424 .35669 L .52627 .34596 L F
.52628 .34596 m .52627 .34596 L .52585 .34539 L F
.5258 .34531 m .52586 .34539 L .52585 .34539 L F
.52653 .34545 m .52654 .34544 L .5262 .34492 L F
.52639 .3452 m .52652 .34544 L .52597 .34536 L F
.52596 .34539 m .52639 .3452 L p .52591 .34539 L F P
0 g
s
.52501 .34574 m .52596 .34539 L .52591 .34539 L .672 .728 .891 r
F
.52463 .34542 m .52551 .34523 L .52464 .34541 L F
.52628 .34507 m .52655 .34497 L .52621 .34498 L F
.52659 .34496 m .52652 .34498 L .52639 .34494 L F
.52652 .34498 m .52601 .34517 L .52639 .34494 L F
.52601 .34517 m .5259 .34521 L .52601 .34514 L F
.52599 .34508 m .52639 .3452 L .52626 .34504 L F
.52601 .34517 m .52601 .34514 L .52639 .34494 L F
.52625 .3448 m .52615 .34491 L .52597 .34489 L F
.52615 .34491 m .52607 .34504 L .52621 .34498 L F
.52582 .34496 m .52605 .34503 L .52568 .34432 L F
.52607 .34504 m .52628 .34507 L .52621 .34498 L F
.52586 .34525 m .5249 .34557 L .5259 .34521 L F
.5249 .34557 m .52389 .34591 L .52491 .34555 L F
.5249 .34557 m .52491 .34555 L .5259 .34521 L F
.52582 .34496 m .52586 .34498 L .52587 .34497 L F
.52586 .34498 m .52603 .34505 L .52587 .34497 L F
.52587 .34497 m .52603 .34505 L .52605 .34503 L F
.52598 .34519 m .52628 .34507 L .52607 .34504 L F
.52592 .34533 m .52571 .3453 L .5263 .3451 L F
.52591 .34529 m .52667 .345 L .52594 .34524 L F
.52639 .3452 m .52592 .34533 L p .5263 .3451 L F P
0 g
s
.52603 .34528 m .52683 .34496 L .52603 .34527 L .672 .728 .891 r
F
.52592 .34533 m .52591 .34536 L .52589 .34533 L F
.52586 .34536 m .52603 .34529 L .52588 .34534 L F
.52603 .34529 m .52683 .34496 L .52603 .34528 L F
.52603 .34529 m .52603 .34528 L .52588 .34534 L F
.5269 .34499 m .52663 .34476 L .52691 .345 L F
.52613 .34477 m .52557 .34377 L .52613 .34477 L F
.52549 .34408 m .52557 .34378 L .52499 .34345 L F
.52603 .34423 m .52461 .34298 L .52619 .34427 L F
.52557 .3438 m .52557 .3438 L .52557 .34378 L F
.52558 .34378 m .52573 .34406 L p .52517 .34351 L F P
0 g
s
.52629 .34508 m .52667 .345 L .52655 .34497 L .672 .728 .891 r
F
.526 .3452 m .5263 .34509 L .5263 .34509 L F
.52594 .34524 m .52632 .34512 L .52629 .34508 L F
.52632 .34512 m .52667 .345 L .52629 .34508 L F
.526 .3452 m .526 .3452 L .5263 .34509 L F
.52643 .34492 m .52679 .34504 L .52682 .34499 L F
.52667 .345 m .52685 .34493 L .52655 .34497 L F
.52609 .34491 m .52615 .34491 L .52697 .34506 L F
.52685 .34493 m .52682 .34499 L .52684 .34502 L F
.52668 .345 m .52683 .34496 L .52685 .34493 L F
.52603 .34475 m .52611 .34456 L .52675 .34493 L F
.52637 .34491 m .52639 .34492 L .52691 .34481 L F
.52639 .34492 m .52655 .34497 L .52665 .34493 L F
.5268 .34482 m .52681 .34477 L .52665 .34476 L F
.52696 .34467 m .52657 .34494 L .52674 .34469 L F
.52639 .34492 m .52665 .34493 L .52691 .34481 L F
.52663 .34476 m .52666 .34478 L .52684 .34493 L F
.52689 .34503 m .52685 .34493 L .52684 .34502 L F
.52794 .34467 m .52755 .34471 L .52755 .34473 L F
.52755 .34474 m .52794 .34467 L .52755 .34473 L F
.52776 .34481 m .52639 .3452 L p .52842 .34441 L F P
0 g
s
.52889 .34449 m .54379 .34023 L p .52782 .34445 L .672 .728 .891 r
F P
0 g
s
.52849 .34443 m .52842 .34441 L .52888 .34422 L .672 .728 .891 r
F
.52776 .34481 m .52842 .34441 L .52849 .34443 L F
.52577 .34473 m .52576 .34469 L .52577 .34473 L F
.52539 .34447 m .52549 .34408 L .52499 .34345 L F
.52508 .34396 m .52549 .34408 L .52554 .34415 L F
.52605 .34503 m .52615 .34491 L .52568 .34432 L F
.52576 .34469 m .52557 .3438 L .52576 .34469 L F
.52609 .34491 m .52508 .34396 L .52567 .3443 L F
.52547 .34463 m .52553 .34413 L .52539 .34447 L F
.52586 .34525 m .5259 .34521 L .52628 .34507 L F
.52628 .34507 m .52629 .34508 L .52655 .34497 L F
.52629 .34508 m .52628 .34507 L .52659 .34496 L F
.52586 .34525 m .52628 .34507 L .52629 .34508 L F
.526 .3452 m .52586 .34525 L .526 .3452 L F
.52604 .34486 m .52536 .34461 L .52538 .34459 L F
.52586 .34537 m .52576 .34469 L .52547 .34463 L F
.52496 .34585 m .52596 .34539 L p .52501 .34574 L F P
0 g
s
.52589 .34533 m .52594 .34539 L .5258 .34531 L .672 .728 .891 r
F
.52598 .34535 m .52597 .34535 L .52597 .34535 L F
.52597 .34535 m .52579 .34547 L .52597 .34532 L F
.52639 .3452 m .52681 .34501 L p .52501 .34573 L F P
0 g
s
.52327 .34642 m .52501 .34574 L .52501 .34573 L .672 .728 .891 r
F
.52501 .34574 m .52639 .3452 L .52501 .34573 L F
.52607 .3449 m .52507 .34397 L p .52608 .3449 L F P
0 g
s
.52507 .34397 m .52509 .34397 L .526 .34482 L .672 .728 .891 r
F
.52589 .34532 m .52577 .34473 L .52586 .34537 L F
.52577 .34473 m .52576 .34469 L .52577 .34473 L F
.52577 .34473 m .52577 .34473 L .52586 .34537 L F
.52589 .34531 m .52606 .34506 L .52582 .34496 L F
.52615 .34491 m .52566 .34529 L .5259 .34491 L F
.52597 .34489 m .5259 .34491 L .52593 .34488 L F
.52615 .34491 m .5259 .34491 L .52597 .34489 L F
.52609 .34491 m .52567 .3443 L .52615 .34491 L F
.5261 .34484 m .52609 .34491 L .52615 .34491 L F
.52605 .34503 m .52607 .34504 L .52615 .34491 L F
.5259 .34521 m .52566 .34529 L .52615 .34491 L F
.52609 .34491 m .52607 .34504 L .52615 .34491 L F
.526 .34482 m .526 .34482 L .52609 .34491 L F
.52607 .34504 m .52633 .34513 L .52615 .34491 L F
.52609 .34491 m .52609 .34491 L .52633 .34513 L F
.526 .34482 m .52609 .34491 L .52609 .34491 L F
.52585 .34539 m .52627 .34596 L .52621 .34596 L F
.52594 .34539 m .52586 .34539 L .5258 .34531 L F
.52681 .34501 m .52639 .3452 L p .52665 .34496 L F P
0 g
s
.52593 .34534 m .52591 .34536 L .52592 .34533 L .672 .728 .891 r
F
.52631 .34439 m .52622 .3443 L .52629 .34439 L F
.52621 .34429 m .52624 .34438 L .52629 .34439 L F
.52691 .345 m .52619 .34437 L .52622 .3443 L F
.52674 .34493 m .52685 .34493 L .52688 .34488 L F
.52674 .34493 m .52688 .34488 L .52691 .34481 L F
.52663 .34476 m .52684 .34493 L .52684 .34493 L F
.52665 .34493 m .52674 .34493 L .52691 .34481 L F
.52746 .34426 m .52746 .34426 L .52746 .34426 L F
.52764 .34463 m .52674 .34469 L .52746 .34426 L F
.52691 .34481 m .52764 .34463 L .52813 .34427 L F
.52557 .34377 m .51956 .33325 L p .52557 .34378 L F P
0 g
s
.52376 .34133 m .5241 .34121 L .51956 .33325 L .672 .728 .891 r
F
.5239 .3416 m .5241 .34121 L .52376 .34133 L F
.52436 .34209 m .5241 .34121 L .5239 .3416 L F
.52461 .34298 m .5245 .34284 L .52619 .34427 L F
.52499 .34345 m .52557 .34378 L .5241 .34121 L F
.51956 .33325 m .52557 .34377 L p .52486 .34329 L F P
0 g
s
.52412 .34306 m .51531 .33482 L .52328 .34181 L .672 .728 .891 r
F
.52412 .34306 m .52328 .34181 L .52461 .34298 L F
.52458 .34295 m .51531 .33482 L .5245 .34298 L F
.52508 .34396 m .52412 .34306 L .52461 .34298 L F
.52458 .34295 m .5245 .34298 L .52486 .34329 L F
.51956 .33325 m .52486 .34329 L .52458 .34295 L F
.52344 .34075 m .52458 .34295 L .52413 .34141 L F
.52508 .34396 m .52461 .34298 L .52549 .34408 L F
.52458 .34295 m .52486 .34329 L .52471 .34319 L F
.52481 .34315 m .52458 .34295 L .52486 .34329 L F
.52486 .34329 m .52506 .34395 L .5254 .34397 L F
.52506 .34395 m .52533 .34421 L p .52518 .34396 L F P
0 g
s
.52507 .34397 m .526 .34482 L .526 .34482 L .672 .728 .891 r
F
.52533 .34421 m .52607 .34491 L p .52518 .34396 L F P
0 g
s
.5254 .34397 m .52518 .34396 L .52607 .34491 L .672 .728 .891 r
F
.52571 .34471 m .52561 .34468 L .52471 .34319 L F
.52458 .34295 m .52541 .34455 L .52494 .3434 L F
.52507 .34397 m .51531 .33482 L p .52509 .34397 L F P
0 g
s
.51531 .33482 m .52506 .34395 L p .52486 .34329 L .672 .728 .891 r
F P
0 g
s
.52597 .34479 m .52571 .34471 L .52486 .34329 L .672 .728 .891 r
F
.52552 .34439 m .52541 .34398 L .52528 .34382 L F
.52557 .34377 m .52558 .34378 L p .52486 .34329 L F P
0 g
s
.52614 .34432 m .52481 .34315 L .52613 .34444 L .672 .728 .891 r
F
.52517 .34351 m .52615 .34478 L .52486 .34329 L F
.52481 .34315 m .52486 .34329 L .5254 .34397 L F
.52541 .34455 m .52561 .34461 L .52473 .34251 L F
.52447 .34223 m .52473 .34251 L .52071 .33298 L F
.52486 .34329 m .52571 .34471 L .52471 .34319 L F
.52471 .34319 m .52561 .34468 L .52545 .34463 L F
.52541 .34455 m .52473 .34251 L .52447 .34223 L F
.52554 .34422 m .52322 .34238 L .52528 .34382 L F
.52609 .34469 m .52557 .34377 L .52607 .34465 L F
.52664 .34496 m .52659 .34496 L .52909 .34408 L F
.52615 .34491 m .5273 .3445 L .52716 .34448 L F
.52714 .34457 m .52615 .34491 L .52625 .3448 L F
.52615 .34491 m .52635 .34492 L .5273 .3445 L F
.52726 .34459 m .52615 .34491 L .52714 .34457 L F
.52615 .34491 m .52675 .34493 L .52686 .34499 L F
.52637 .34491 m .52691 .34481 L .52701 .34463 L F
.52726 .34459 m .52659 .34496 L .52615 .34491 L F
.52764 .34463 m .53277 .3423 L p .52813 .34427 L F P
0 g
s
.53277 .3423 m .54208 .33806 L p .53229 .34241 L .672 .728 .891 r
F P
0 g
s
.52813 .34427 m .53277 .3423 L .53229 .34241 L .672 .728 .891 r
F
.52931 .344 m .52749 .34464 L .52726 .34459 L F
.52749 .34464 m .52659 .34496 L .52726 .34459 L F
.52625 .3448 m .52632 .34481 L .5278 .34465 L F
.5278 .34465 m .5278 .34465 L .52789 .34464 L F
.52625 .3448 m .5278 .34465 L .5278 .34465 L F
.52697 .34506 m .52691 .345 L .52689 .34503 L F
.52691 .345 m .52685 .34493 L .52689 .34503 L F
.52684 .34493 m .52684 .34493 L .52691 .345 L F
.52701 .34463 m .52691 .34481 L .52921 .34378 L F
.52725 .34454 m .52625 .3448 L .52789 .34464 L F
.52691 .34499 m .52702 .34486 L .52888 .34422 L F
.52664 .34497 m .52664 .34496 L .5273 .34473 L F
.526 .3452 m .5273 .34473 L .5273 .34473 L F
.52683 .34496 m .52764 .34463 L .52691 .34481 L F
.52733 .34475 m .526 .3452 L .5273 .34473 L F
.52649 .34495 m .52809 .34467 L .52789 .34464 L F
.52625 .3448 m .5261 .34484 L .52632 .34481 L F
.52612 .34483 m .52608 .34485 L .5261 .34484 L F
.5254 .34397 m .52607 .3449 L .52608 .34482 L F
.52608 .34485 m .52597 .34489 L .52608 .34485 L F
.52607 .3449 m .52607 .34491 L .52608 .34485 L F
.52608 .34485 m .52608 .34485 L .52608 .34482 L F
.52607 .3449 m .52608 .34485 L .52608 .34485 L F
.52539 .34245 m .52188 .33276 L p .52528 .34279 L F P
0 g
s
.52609 .34469 m .52607 .34465 L .52613 .34477 L .672 .728 .891 r
F
.52619 .34485 m .52557 .34377 L p .52619 .34486 L F P
0 g
s
.52573 .34406 m .52615 .34478 L p .52517 .34351 L .672 .728 .891 r
F P
0 g
s
.52481 .34315 m .5261 .34469 L .52613 .34444 L .672 .728 .891 r
F
.52523 .34373 m .52522 .34374 L .52486 .34329 L F
.52619 .34436 m .52528 .34382 L .52458 .34295 L F
.52528 .34382 m .52541 .34398 L .52071 .33298 L F
.52611 .34483 m .5261 .34484 L .52611 .34483 L F
.52746 .34426 m .5261 .34484 L .52746 .34426 L F
.52746 .34426 m .52643 .34471 L .5264 .34471 L F
.52611 .34483 m .52611 .34483 L .52783 .34412 L F
.52746 .34426 m .52726 .34438 L .52643 .34471 L F
.52611 .34483 m .52783 .34412 L .52782 .34412 L F
.5308 .34255 m .52765 .34408 L .52979 .3433 L F
.52765 .34408 m .52611 .34483 L .52782 .34412 L F
.52765 .34408 m .52782 .34412 L .52979 .3433 L F
.52611 .34483 m .52611 .34483 L .52611 .34483 L F
.52613 .34484 m .52597 .34489 L .52612 .34483 L F
.5261 .34484 m .52611 .34485 L .52669 .34489 L F
.5261 .34486 m .52611 .34483 L .52611 .34483 L F
.52611 .34483 m .5261 .34484 L .5261 .34484 L F
.52611 .34483 m .52611 .34485 L .52608 .34482 L F
.5261 .34484 m .52669 .34489 L .52632 .34481 L F
.52612 .34483 m .52611 .34485 L .52611 .34483 L F
.52615 .34478 m .52522 .34374 L .52523 .34373 L F
.52481 .34315 m .5254 .34397 L .5261 .34469 L F
.52615 .34478 m .52612 .34483 L .52522 .34374 L F
.5254 .34397 m .52608 .34482 L .5261 .34469 L F
.52608 .34482 m .52608 .34482 L .5261 .34469 L F
.5261 .34484 m .52597 .34489 L .52593 .34488 L F
.52589 .34532 m .52577 .34473 L .52577 .34473 L F
.52578 .34529 m .52537 .34471 L .52537 .34471 L F
.52593 .34488 m .5259 .34491 L .52487 .34516 L F
.5249 .34525 m .52531 .34518 L .52528 .34517 L F
.52577 .34494 m .52464 .3453 L .52568 .34502 L F
.52464 .3453 m .52556 .34512 L .52568 .34502 L F
.5259 .34491 m .52516 .34521 L .52487 .34516 L F
.52608 .34484 m .52487 .34516 L .52474 .3453 L F
.5261 .34484 m .52608 .34484 L .52608 .34484 L F
.52608 .34484 m .52487 .34516 L .52608 .34484 L F
.52608 .34484 m .52608 .34482 L .52608 .34482 L F
.52607 .3449 m .52608 .34484 L .52608 .34484 L F
.52608 .34484 m .52608 .34482 L .52608 .34484 L F
.52488 .34579 m .52414 .34622 L .52487 .34578 L F
.52327 .34642 m .52496 .34585 L .52501 .34574 L F
.52448 .34562 m .52437 .34568 L .52449 .34564 L F
.52437 .34568 m .52292 .34638 L .52434 .34578 L F
.52292 .34638 m .52297 .34639 L .52351 .34615 L F
.52429 .3458 m .52389 .34591 L p .52453 .3457 L F P
0 g
s
.52429 .3458 m .52453 .3457 L .52571 .3453 L .672 .728 .891 r
F
.52592 .34533 m .52429 .3458 L p .52571 .3453 L F P
0 g
s
.52352 .34613 m .52351 .34615 L .52607 .34504 L .672 .728 .891 r
F
.52292 .34638 m .52351 .34615 L .52352 .34613 L F
.52353 .34614 m .52432 .34584 L .52433 .34579 L F
.52664 .34496 m .52909 .34408 L .5291 .34408 L F
.5273 .34473 m .5273 .34473 L .52931 .344 L F
.52888 .34422 m .52733 .34475 L .52931 .344 L F
.52733 .34475 m .5273 .34473 L .52931 .344 L F
.52889 .34449 m .52776 .34481 L p .53031 .34374 L F P
0 g
s
.52794 .34467 m .52889 .34449 L .52793 .34465 L .672 .728 .891 r
F
.52776 .34481 m .52888 .34422 L .53031 .34374 L F
.54379 .34023 m .52889 .34449 L p .53031 .34374 L F P
0 g
s
.52725 .34454 m .52789 .34464 L .52974 .34423 L .672 .728 .891 r
F
.53023 .34401 m .52974 .34423 L .53255 .3436 L F
.52725 .34454 m .52974 .34423 L .53023 .34401 L F
.5251 .34533 m .5241 .34598 L .52331 .3462 L F
.52677 .34493 m .52683 .34493 L .5269 .34499 L F
.52687 .34499 m .5269 .34499 L .52697 .34506 L F
.52677 .34493 m .5269 .34499 L .52687 .34499 L F
.52691 .345 m .52702 .34486 L .52691 .34499 L F
.52639 .3452 m .52679 .34498 L .52691 .345 L F
.52675 .34493 m .52677 .34493 L .52697 .34506 L F
.52679 .34498 m .52702 .34486 L .52691 .345 L F
.52668 .34493 m .52672 .34493 L .52785 .34611 L F
.52785 .34611 m .52785 .34611 L .52802 .34628 L F
.52668 .34493 m .52785 .34611 L .52785 .34611 L F
.51152 .35294 m .52051 .34826 L p .519 .34878 L F P
0 g
s
.51571 .35153 m .51229 .35356 L p .519 .34878 L .672 .728 .891 r
F P
0 g
s
.51571 .35153 m .51676 .35091 L p .51503 .35183 L .672 .728 .891 r
F P
0 g
s
.52682 .34499 m .52702 .34584 L .52734 .34559 L .672 .728 .891 r
F
.52795 .34603 m .52699 .34575 L .52697 .34506 L F
.53685 .35497 m .52726 .346 L .52795 .34603 L F
.52726 .346 m .52699 .34575 L .52795 .34603 L F
.52603 .34529 m .52681 .34501 L .52683 .34496 L F
.52586 .34525 m .52659 .34496 L .52664 .34496 L F
.52603 .34527 m .5267 .34501 L .52668 .345 L F
.5267 .34501 m .52683 .34496 L .52668 .345 L F
.52639 .3452 m .5263 .3451 L .52702 .34486 L F
.5263 .34509 m .5263 .34509 L .52664 .34496 L F
.5263 .34509 m .52664 .34496 L .52664 .34497 L F
.52615 .34491 m .52621 .34498 L .52635 .34492 L F
.52639 .34494 m .52624 .34502 L .52615 .34491 L F
.52698 .34549 m .52609 .34491 L .52697 .34506 L F
.52699 .34575 m .5267 .34547 L .52698 .34549 L F
.5267 .34547 m .52609 .34491 L .52698 .34549 L F
.52437 .34568 m .52434 .34578 L .52607 .34504 L F
.52432 .34584 m .52628 .34507 L .52433 .34579 L F
.52519 .34528 m .52493 .34564 L .5251 .34533 L F
.52175 .34606 m .52477 .34558 L .52469 .34553 L F
.52389 .34573 m .52389 .34572 L .52519 .34539 L F
.52614 .34477 m .52613 .34477 L .52633 .34513 L F
.52512 .34545 m .52598 .34519 L .52607 .34504 L F
.52633 .34513 m .52613 .34477 L .52613 .34477 L F
.5255 .34538 m .52542 .34535 L .52616 .34491 L F
.52611 .34485 m .52644 .34494 L .52669 .34489 L F
.52617 .34493 m .52616 .34491 L .5264 .34477 L F
.5261 .34484 m .52448 .34562 L .52607 .34504 L F
.5255 .34538 m .52616 .34491 L .52617 .34493 L F
.52575 .34538 m .52685 .34493 L .52572 .34537 L F
.52639 .3452 m .52607 .3449 L p .52633 .34513 L F P
0 g
s
.52603 .34532 m .52681 .34501 L .52603 .34529 L .672 .728 .891 r
F
.52596 .3452 m .52594 .34524 L .52629 .34508 L F
.52554 .34536 m .52629 .34508 L .52628 .34507 L F
.52594 .34553 m .52637 .34519 L .52606 .34506 L F
.52612 .34483 m .5262 .34497 L .52611 .34485 L F
.52638 .34519 m .52614 .34478 L .52633 .34513 L F
.52669 .3454 m .52671 .34533 L .52645 .34494 L F
.52637 .34477 m .5262 .3448 L .52628 .34477 L F
.52641 .34493 m .52645 .34494 L .52613 .34444 L F
.52669 .3454 m .52645 .34494 L .52641 .34493 L F
.52626 .34489 m .52669 .3454 L .52641 .34493 L F
.52628 .34506 m .52662 .34499 L .52623 .34501 L F
.52662 .34499 m .52688 .34493 L .52655 .34497 L F
.52662 .34499 m .52655 .34497 L .52623 .34501 L F
.52688 .34493 m .52809 .34467 L .52678 .34491 L F
.52688 .34493 m .52678 .34491 L .52623 .34501 L F
.52614 .34478 m .52613 .34476 L .52614 .34478 L F
.52614 .34478 m .52614 .34478 L .52633 .34513 L F
.52613 .34476 m .52609 .34469 L .52613 .34476 L F
.52613 .34476 m .52613 .34476 L .52633 .34513 L F
.52702 .34446 m .52709 .34447 L .52712 .34442 L F
.5275 .34432 m .52667 .34479 L .52717 .34432 L F
.52615 .34491 m .52686 .34499 L .52697 .34506 L F
.52628 .34507 m .52689 .34501 L .52691 .34494 L F
.52603 .34505 m .52637 .34519 L .52605 .34503 L F
.52648 .34548 m .52605 .34505 L .52608 .34494 L F
.52531 .34552 m .52591 .34529 L .52594 .34524 L F
.52244 .34662 m .52327 .34642 L .52432 .34596 L F
.52244 .34662 m .52432 .34596 L .52353 .34614 L F
.5241 .34598 m .52179 .3475 L .5232 .34629 L F
.5232 .34645 m .52269 .34673 L .52368 .34626 L F
.52292 .34638 m .52244 .34662 L .52297 .34639 L F
.52331 .3462 m .52051 .34826 L .52244 .34662 L F
.52269 .34673 m .519 .34878 L .52368 .34626 L F
.52327 .34642 m .52426 .34603 L .52426 .34602 L F
.52433 .34579 m .5251 .34551 L .52512 .34545 L F
.52448 .34562 m .52449 .34564 L .52607 .34504 L F
.52327 .34642 m .52448 .34592 L .52432 .34596 L F
.52353 .34614 m .52432 .34596 L .52565 .34537 L F
.52353 .34614 m .52565 .34537 L .52554 .34536 L F
.52493 .34564 m .5234 .34655 L .5251 .34533 L F
.5234 .34655 m .52179 .3475 L .52311 .34663 L F
.5234 .34655 m .52311 .34663 L .5251 .34533 L F
.52608 .34559 m .52651 .34544 L .52637 .34519 L F
.52676 .34585 m .52601 .34517 L .52604 .34507 L F
.52589 .34507 m .52493 .34564 L .5259 .34506 L F
.5259 .34506 m .52493 .34564 L .5259 .34505 L F
.5207 .34624 m .52562 .34527 L .52568 .3452 L F
.52395 .34563 m .52396 .34561 L .52494 .34534 L F
.52541 .34519 m .52597 .34513 L .526 .34506 L F
.5207 .34624 m .52549 .34523 L .52541 .34519 L F
.52538 .34534 m .52537 .34534 L .52609 .34485 L F
.52541 .34535 m .52538 .34534 L .5262 .3448 L F
.52549 .34523 m .52597 .34513 L .52541 .34519 L F
.5258 .34531 m .52635 .34612 L .52623 .34612 L F
.52448 .34592 m .52685 .34493 L .52432 .34596 L F
.52588 .34534 m .52603 .34528 L .52603 .34527 L F
.52594 .34553 m .52606 .34506 L .52589 .34531 L F
.52426 .34603 m .52681 .34501 L .52426 .34602 L F
.52575 .34538 m .52572 .34537 L .52505 .34564 L F
.52532 .34553 m .52667 .345 L .52531 .34552 L F
.52502 .34575 m .52498 .34574 L .52601 .34516 L F
.52607 .3449 m .52608 .3449 L .52633 .34513 L F
.52613 .34488 m .52614 .3449 L .52614 .34489 L F
.52609 .34485 m .52614 .3449 L .52613 .34488 L F
.52609 .34485 m .52607 .34491 L .52614 .3449 L F
.52609 .34485 m .52614 .34489 L .52611 .34485 L F
.52469 .34563 m .52389 .34591 L .52191 .34593 L F
.52163 .34632 m .52477 .34558 L p .52175 .34606 L F P
0 g
s
.52033 .34661 m .52021 .34663 L .5254 .34521 L .672 .728 .891 r
F
.52608 .34482 m .52607 .34492 L .52596 .34478 L F
.5261 .34486 m .52538 .34534 L .52609 .34485 L F
.52611 .34485 m .52609 .34485 L .52611 .34483 L F
.5261 .34486 m .52609 .34485 L .52611 .34485 L F
.52608 .34485 m .52608 .34485 L .5261 .34484 L F
.52608 .34495 m .52541 .34535 L .5261 .34486 L F
.52611 .34485 m .52608 .34494 L .52607 .34492 L F
.5261 .34484 m .52537 .34534 L .52519 .34528 L F
.5261 .34484 m .52537 .34534 L .5261 .34484 L F
.5261 .34484 m .52525 .34512 L .52602 .34503 L F
.52605 .34505 m .52602 .34502 L .52608 .34494 L F
.52589 .34507 m .5259 .34506 L .52608 .34495 L F
.52663 .34494 m .52646 .34495 L .52671 .34501 L F
.52646 .34491 m .52635 .34489 L .52651 .34478 L F
.52632 .34481 m .52669 .34489 L .52789 .34464 L F
.52629 .34488 m .5264 .34477 L .52645 .34478 L F
.5261 .34484 m .52709 .34447 L .52702 .34446 L F
.52726 .34438 m .52674 .34469 L .52643 .34471 L F
.52645 .34478 m .5264 .34477 L .52717 .34432 L F
.52616 .34448 m .52644 .34491 L .52663 .34494 L F
.52615 .34491 m .52633 .34513 L .52619 .34487 L F
.5262 .34486 m .52639 .3452 L p .52612 .34483 L F P
0 g
s
.52655 .34544 m .52722 .34641 L p .52594 .34539 L .672 .728 .891 r
F P
0 g
s
.52687 .34607 m .52638 .34519 L .52633 .34513 L .672 .728 .891 r
F
.52722 .34641 m .53424 .35669 L p .52675 .3465 L F P
0 g
s
.52594 .34539 m .52675 .3465 L .52586 .34539 L .672 .728 .891 r
F
.52675 .3465 m .53424 .35669 L .52669 .34651 L F
.52675 .3465 m .52669 .34651 L .52586 .34539 L F
.52626 .34489 m .52614 .34489 L .52667 .34544 L F
.52667 .34543 m .52667 .34544 L .52669 .34545 L F
.52626 .34489 m .52667 .34544 L .52667 .34543 L F
.5263 .34509 m .52677 .34503 L .52628 .34507 L F
.52646 .34495 m .52674 .34537 L .52671 .34501 L F
.52674 .34537 m .52699 .34577 L .5268 .34527 L F
.52674 .34537 m .5268 .34527 L .52671 .34501 L F
.52596 .34535 m .5263 .34509 L .52633 .34513 L F
.5264 .34546 m .52571 .34471 L .52648 .34548 L F
.52616 .34449 m .52645 .34494 L .52616 .34448 L F
.52645 .34494 m .52699 .34577 L .52646 .34495 L F
.52692 .34446 m .52623 .34487 L .52693 .34443 L F
.52607 .34491 m .52639 .3452 L p .52614 .34489 L F P
0 g
s
.52605 .34503 m .52637 .34519 L .52633 .34513 L .672 .728 .891 r
F
.52611 .34485 m .52652 .34549 L .52608 .34494 L F
.52623 .34487 m .52589 .34507 L .52622 .34487 L F
.52623 .34487 m .52622 .34487 L .52693 .34443 L F
.52645 .34494 m .52646 .34495 L .52644 .34491 L F
.52692 .34444 m .52637 .34477 L .52625 .34477 L F
.52643 .34491 m .52644 .34491 L .52616 .34448 L F
.52645 .34494 m .52644 .34491 L .52643 .34491 L F
.52639 .3452 m .52693 .34507 L p .52635 .34515 L F P
0 g
s
.52671 .34501 m .52699 .34577 L .52733 .34591 L .672 .728 .891 r
F
.52747 .34576 m .52733 .34591 L .52783 .34611 L F
.52671 .34501 m .52733 .34591 L .52747 .34576 L F
.52693 .34507 m .52639 .3452 L p .52695 .34504 L F P
0 g
s
.52639 .3452 m .52659 .34513 L .52695 .34504 L .672 .728 .891 r
F
.52722 .34641 m .52675 .3465 L .52594 .34539 L F
.52615 .3449 m .52659 .34542 L .5266 .34541 L F
.52701 .34578 m .52639 .3452 L p .52701 .34576 L F P
0 g
s
.52639 .3452 m .52633 .34513 L .52701 .34576 L .672 .728 .891 r
F
.52639 .3452 m .52699 .34577 L p .52648 .34524 L F P
0 g
s
.52638 .3452 m .52619 .34485 L .52638 .3452 L .672 .728 .891 r
F
.52656 .3455 m .52619 .34485 L .52656 .3455 L F
.52639 .3452 m .52622 .34499 L .52612 .34483 L F
.52614 .34489 m .52639 .3452 L .52648 .34524 L F
.52638 .3452 m .52619 .34485 L .52619 .34486 L F
.52656 .3455 m .52638 .3452 L .52638 .3452 L F
.53424 .35669 m .53313 .357 L p .52621 .34596 L F P
0 g
s
.52627 .34596 m .53424 .35669 L .52621 .34596 L .672 .728 .891 r
F
.53278 .35645 m .52656 .3455 L .52656 .3455 L F
.52601 .34518 m .52601 .34516 L .52667 .34479 L F
.52595 .34516 m .52631 .3451 L .52596 .34514 L F
.52631 .3451 m .52689 .34501 L .5263 .34509 L F
.52596 .34535 m .526 .34521 L .52628 .34506 L F
.52631 .3451 m .5263 .34509 L .52596 .34514 L F
.52625 .34487 m .52669 .34545 L .52671 .34542 L F
.5263 .34509 m .52628 .34506 L .52652 .34492 L F
.52596 .34535 m .52628 .34506 L .5263 .34509 L F
.52636 .34516 m .52633 .34513 L .52666 .34494 L F
.52634 .34513 m .52693 .34507 L .52682 .34504 L F
.52592 .34521 m .52635 .34515 L .52634 .34513 L F
.52635 .34515 m .52693 .34507 L .52634 .34513 L F
.5268 .34504 m .52679 .34503 L .5268 .34505 L F
.52697 .34506 m .5269 .34499 L .52691 .345 L F
.52633 .34513 m .52711 .34498 L .52631 .3451 L F
.52672 .34495 m .52671 .34501 L .52679 .34503 L F
.52662 .34499 m .5269 .34494 L .52688 .34493 L F
.52691 .34493 m .52639 .3452 L p .52691 .34486 L F P
0 g
s
.52639 .3452 m .52593 .34544 L p .52637 .34518 L .672 .728 .891 r
F P
0 g
s
.52659 .34504 m .5266 .34504 L .52628 .34507 L .672 .728 .891 r
F
.52677 .34503 m .5266 .34504 L .52659 .34504 L F
.52677 .34503 m .52676 .34503 L .5266 .34504 L F
.52639 .3452 m .52637 .34518 L .52691 .34486 L F
.52614 .34531 m .52666 .34494 L .52669 .34495 L F
.52665 .34494 m .52663 .34494 L .52671 .34501 L F
.52636 .34517 m .52691 .3448 L .52637 .34518 L F
.52639 .3452 m .52683 .34497 L p .52629 .34507 L F P
0 g
s
.52663 .34499 m .5269 .34494 L .52662 .34499 L .672 .728 .891 r
F
.52665 .34494 m .52671 .34501 L .52672 .34495 L F
.52622 .34499 m .52623 .34501 L .52649 .34495 L F
.52644 .34494 m .52649 .34495 L .52789 .34464 L F
.52622 .34499 m .52649 .34495 L .52644 .34494 L F
.52644 .34491 m .52646 .34495 L .52663 .34494 L F
.52665 .345 m .52663 .34499 L .52628 .34506 L F
.52628 .34506 m .52663 .34499 L .52662 .34499 L F
.52628 .34506 m .5269 .34494 L .52628 .34506 L F
.52633 .34513 m .52652 .34492 L .52666 .34494 L F
.52674 .34496 m .52691 .3448 L .52691 .34486 L F
.52637 .34518 m .52669 .34495 L .52674 .34496 L F
.52651 .34496 m .52809 .34467 L .52649 .34495 L F
.52669 .34495 m .52691 .3448 L .52674 .34496 L F
.52679 .34488 m .52678 .34487 L .52691 .3448 L F
.52669 .34495 m .52678 .34487 L .52679 .34488 L F
.52669 .34495 m .52666 .34494 L .52678 .34487 L F
.52623 .34501 m .52651 .34496 L .52649 .34495 L F
.52628 .34506 m .52626 .34505 L .52691 .34468 L F
.52691 .34469 m .52691 .34468 L .52753 .34432 L F
.52628 .34506 m .52691 .34468 L .52691 .34469 L F
.52663 .34476 m .52603 .34423 L .52666 .34478 L F
.52622 .34488 m .52614 .34489 L .52626 .34489 L F
.52611 .34485 m .52614 .34489 L .52622 .34488 L F
.52611 .34485 m .52622 .34499 L .52644 .34494 L F
.52625 .34487 m .52626 .34489 L .52639 .3449 L F
.52554 .34536 m .52594 .34524 L .52596 .3452 L F
.5261 .34484 m .52706 .34452 L .52709 .34447 L F
.5262 .34497 m .52653 .34549 L .52611 .34485 L F
.52608 .34559 m .52675 .34586 L .52651 .34544 L F
.52653 .34549 m .52676 .34585 L .52652 .34549 L F
.52653 .34549 m .52652 .34549 L .52611 .34485 L F
.5207 .34624 m .52163 .34632 L .52175 .34606 L F
.52563 .34542 m .52561 .34542 L .52626 .34505 L F
.52554 .34536 m .52565 .34537 L .52594 .34524 L F
.5251 .34551 m .52598 .34519 L .52512 .34545 L F
.52537 .34534 m .52493 .34564 L .52519 .34528 L F
.52341 .34571 m .52587 .34532 L .52592 .34521 L F
.5234 .34575 m .52587 .34532 L .52341 .34571 L F
.52267 .34589 m .52587 .34532 L .52266 .34588 L F
.52581 .34528 m .52586 .34517 L .52692 .34448 L F
.52581 .34528 m .52692 .34448 L .52692 .34449 L F
.52611 .34485 m .52622 .34488 L .52625 .34487 L F
.52607 .34496 m .52621 .34487 L .52622 .34487 L F
.5261 .34484 m .52602 .34503 L .52611 .34485 L F
.52612 .34483 m .52608 .34482 L .52522 .34374 L F
.52608 .34482 m .52607 .34491 L .52611 .34471 L F
.52609 .34483 m .52608 .34484 L .52608 .34482 L F
.52637 .34477 m .52608 .34495 L .5262 .3448 L F
.52625 .3448 m .52613 .34484 L .52612 .34483 L F
.52609 .34469 m .52613 .34477 L .52614 .34477 L F
.52625 .34477 m .5261 .34486 L .52611 .34483 L F
.52611 .34471 m .52609 .34485 L .52625 .34487 L F
.52611 .34485 m .52608 .34484 L .52609 .34483 L F
.52611 .34485 m .52607 .34492 L .52608 .34484 L F
.52622 .34526 m .52633 .34513 L .52636 .34516 L F
.52614 .34531 m .52619 .34527 L .52622 .34526 L F
.52619 .34527 m .52633 .34513 L .52622 .34526 L F
.52693 .34507 m .52815 .34478 L p .52682 .34504 L F P
0 g
s
.52693 .34507 m .52695 .34504 L .52697 .34503 L .672 .728 .891 r
F
.52762 .34561 m .52684 .34493 L .52754 .34569 L F
.52689 .34501 m .52711 .34498 L .52692 .34494 L F
.52696 .34503 m .52691 .34499 L .52691 .34499 L F
.52677 .34503 m .52689 .34501 L .52676 .34503 L F
.52684 .34493 m .5268 .34505 L .52684 .34509 L F
.52603 .34506 m .52602 .34506 L .52603 .34505 L F
.52605 .34504 m .52617 .34493 L .52619 .34495 L F
.52483 .34583 m .52606 .345 L .52605 .34504 L F
.52606 .345 m .52617 .34493 L .52605 .34504 L F
.52619 .34527 m .52612 .34526 L .52633 .34513 L F
.52652 .34549 m .52648 .34548 L .52608 .34494 L F
.52614 .34531 m .52636 .34517 L .52637 .34518 L F
.52655 .34544 m .52594 .34539 L .52591 .34536 L F
.52634 .34549 m .52617 .34547 L .52612 .34539 L F
.52627 .34543 m .52612 .34539 L .526 .34519 L F
.52634 .34549 m .52612 .34539 L .52627 .34543 L F
.52587 .34532 m .52639 .3452 L p .52592 .34521 L F P
0 g
s
.52622 .34524 m .52587 .34532 L p .52625 .34522 L .672 .728 .891 r
F P
0 g
s
.52469 .34608 m .526 .34521 L .52596 .34535 L .672 .728 .891 r
F
.52505 .34564 m .52532 .34553 L .52531 .34552 L F
.52327 .34642 m .52586 .34536 L .52588 .34534 L F
.52483 .34583 m .52542 .34535 L .5255 .34538 L F
.52469 .34553 m .52577 .34535 L .52587 .34532 L F
.52502 .34575 m .52601 .34516 L .52601 .34518 L F
.52538 .34534 m .52493 .34564 L .52537 .34534 L F
.52541 .34535 m .52493 .34564 L .52538 .34534 L F
.52477 .34558 m .52577 .34535 L p .52469 .34553 L F P
0 g
s
.52536 .34461 m .52536 .34461 L .52534 .34458 L .672 .728 .891 r
F
.52592 .34533 m .52536 .34461 L .52536 .34461 L F
.52538 .34459 m .52536 .34461 L .52534 .34458 L F
.52535 .3446 m .52594 .34553 L .52539 .34447 L F
.52587 .34532 m .52577 .34535 L p .52586 .34532 L F P
0 g
s
.52594 .34553 m .52608 .34559 L .52637 .34519 L .672 .728 .891 r
F
.52646 .34598 m .52598 .34528 L .52599 .34525 L F
.53797 .33507 m .53699 .33459 L p .53687 .3347 L F P
0 g
s
.52594 .34553 m .52747 .34798 L .52675 .34586 L .672 .728 .891 r
F
.52747 .34798 m .52813 .34902 L .5276 .3478 L F
.52747 .34798 m .5276 .3478 L .52675 .34586 L F
.5389 .3356 m .53797 .33507 L p .53475 .33771 L F P
0 g
s
.52645 .34597 m .52598 .34528 L .52646 .34598 L .672 .728 .891 r
F
.52592 .34521 m .52639 .3452 L .52635 .34515 L F
.52657 .34551 m .52654 .34551 L .52612 .34483 L F
.52622 .34524 m .52625 .34522 L .52659 .34513 L F
.52614 .34531 m .52613 .34529 L .52619 .34527 L F
.52613 .34529 m .52612 .34526 L .52619 .34527 L F
.52684 .34493 m .52679 .34503 L .5268 .34504 L F
.52577 .34535 m .52587 .34523 L .52669 .34502 L F
.52681 .34501 m .5267 .34492 L .52696 .34503 L F
.52679 .34503 m .52671 .34501 L .52729 .34558 L F
.52673 .34504 m .52669 .34502 L .52677 .345 L F
.52684 .34493 m .52684 .34509 L .52689 .34513 L F
.52693 .34507 m .52689 .34513 L .52711 .34533 L F
.52684 .34493 m .52689 .34513 L .52693 .34507 L F
.52684 .34493 m .52672 .34495 L .52682 .34497 L F
.52629 .34507 m .52683 .34497 L .52683 .34495 L F
.5267 .34492 m .52681 .34493 L .52696 .34503 L F
.52681 .34501 m .52677 .345 L .52701 .34494 L F
.52673 .34504 m .52677 .345 L .52681 .34501 L F
.52681 .34501 m .52701 .34494 L .5269 .34502 L F
.53084 .35748 m .52966 .35765 L p .52667 .34806 L F P
0 g
s
.52592 .34521 m .52778 .34486 L .52778 .34485 L .672 .728 .891 r
F
.52585 .34552 m .52254 .34749 L p .52576 .34549 L F P
0 g
s
.52813 .34902 m .52823 .34885 L .52675 .34586 L .672 .728 .891 r
F
.52906 .3505 m .52921 .35019 L .52675 .34586 L F
.52673 .34668 m .53313 .357 L .52671 .34706 L F
.52674 .34641 m .52645 .34597 L .52646 .34598 L F
.52674 .34641 m .52673 .34651 L .52649 .34612 L F
.52674 .34641 m .52649 .34612 L .52654 .34612 L F
.52639 .3452 m .52657 .34551 L p .52622 .34499 L F P
0 g
s
.52676 .34585 m .5264 .34546 L .52648 .34548 L .672 .728 .891 r
F
.52676 .34585 m .52674 .34641 L .52617 .34547 L F
.52906 .3505 m .53278 .35645 L .52921 .35019 L F
.53278 .35645 m .52688 .34607 L .52687 .34607 L F
.53302 .35681 m .52676 .34585 L p .53278 .35645 L F P
0 g
s
.53278 .35645 m .52676 .34585 L .52676 .34585 L .672 .728 .891 r
F
.52676 .34585 m .53313 .357 L p .52674 .34641 L F P
0 g
s
.52656 .34668 m .52693 .34708 L .52639 .3452 L .672 .728 .891 r
F
.52674 .34641 m .53313 .357 L .52673 .34651 L F
.5276 .34781 m .52719 .34692 L p .52693 .34708 L F P
0 g
s
.52719 .34692 m .52639 .3452 L p .52693 .34708 L .672 .728 .891 r
F P
0 g
s
.52635 .34612 m .52673 .34668 L .52623 .34612 L .672 .728 .891 r
F
.52813 .34902 m .52906 .3505 L .52823 .34885 L F
.53313 .357 m .53302 .35681 L p .53278 .35645 L F P
0 g
s
.52673 .34651 m .53313 .357 L .52673 .34668 L .672 .728 .891 r
F
.53199 .35727 m .5276 .34781 L p .52678 .3472 L F P
0 g
s
.52755 .34822 m .52755 .34846 L .5265 .34638 L .672 .728 .891 r
F
.52636 .34665 m .52755 .34846 L .52755 .34954 L F
.52577 .34535 m .52589 .3453 L .52589 .34531 L F
.52389 .34573 m .52519 .34539 L .52521 .34539 L F
.52577 .34535 m .52335 .34592 L p .52568 .34528 L F P
0 g
s
.52335 .34592 m .52031 .34663 L p .52372 .34577 L .672 .728 .891 r
F P
0 g
s
.52335 .34592 m .52372 .34577 L .52568 .34528 L .672 .728 .891 r
F
.52432 .34596 m .52504 .34567 L .52505 .34564 L F
.52483 .34583 m .52051 .34826 L .52493 .34564 L F
.52179 .3475 m .52051 .34826 L .52331 .3462 L F
.52152 .34773 m .52491 .34597 L p .52008 .34823 L F P
0 g
s
.52298 .34716 m .52305 .34693 L .5251 .34564 L .672 .728 .891 r
F
.52176 .34604 m .5234 .34575 L .52341 .34571 L F
.52267 .34589 m .52266 .34588 L .52176 .34604 L F
.52603 .34505 m .526 .34507 L .52601 .34504 L F
.52474 .3453 m .52469 .34535 L .52623 .34501 L F
.52525 .34512 m .52474 .3453 L .52536 .34517 L F
.5207 .34624 m .52463 .34542 L .52464 .34541 L F
.52487 .34516 m .5207 .34624 L .52474 .3453 L F
.52474 .3453 m .52435 .34543 L .52469 .34535 L F
.5254 .34521 m .51938 .34685 L .52492 .34508 L F
.52175 .34606 m .52267 .34589 L .52176 .34604 L F
.5207 .34624 m .52175 .34606 L .52176 .34604 L F
.50908 .35015 m .50864 .34939 L p .5207 .34624 L F P
0 g
s
.50864 .34939 m .51938 .34685 L p .5207 .34624 L .672 .728 .891 r
F P
0 g
s
.52492 .34508 m .51938 .34685 L .51354 .3475 L .672 .728 .891 r
F
.52033 .34661 m .5254 .34521 L .52542 .34521 L F
.51354 .3475 m .5245 .34556 L .52451 .34554 L F
.52316 .3458 m .52301 .34579 L .52323 .34575 L F
.52483 .34583 m .52493 .34564 L .52542 .34535 L F
.52602 .34503 m .52623 .34501 L .52622 .34499 L F
.52474 .3453 m .526 .34505 L .52602 .34503 L F
.526 .34505 m .52623 .34501 L .52602 .34503 L F
.52551 .34523 m .52628 .34507 L .5255 .34523 L F
.52547 .34467 m .52587 .34531 L .5258 .34531 L F
.52587 .34531 m .52589 .34533 L .52587 .34532 L F
.52426 .34602 m .52603 .34532 L .52603 .34529 L F
.52469 .34608 m .5248 .34588 L .526 .34521 L F
.52587 .34531 m .52587 .34532 L .5258 .34531 L F
.52545 .34463 m .52548 .34467 L .52547 .34467 L F
.52548 .34467 m .52589 .34533 L .52547 .34467 L F
.52374 .34671 m .52371 .34669 L .52494 .34587 L F
.52682 .34497 m .52672 .34495 L .52679 .34503 L F
.52678 .34506 m .52681 .34501 L .5269 .34502 L F
.52589 .34531 m .52673 .34504 L .52678 .34506 L F
.52667 .34479 m .52646 .34491 L .52651 .34478 L F
.52667 .34479 m .52651 .34478 L .52717 .34432 L F
.52638 .34486 m .52689 .34476 L .52696 .34458 L F
.52602 .34506 m .526 .34507 L .52603 .34505 L F
.52607 .34496 m .52608 .34495 L .52621 .34487 L F
.52602 .34502 m .52607 .34493 L .52608 .34494 L F
.52611 .34485 m .52602 .34503 L .52622 .34499 L F
.52626 .34489 m .52641 .34493 L .52639 .3449 L F
.5259 .34506 m .5259 .34505 L .52692 .34444 L F
.5261 .34469 m .52625 .34487 L .52613 .34444 L F
.52625 .34487 m .5264 .34477 L .52629 .34488 L F
.52628 .34477 m .5262 .3448 L .52625 .34477 L F
.52625 .34487 m .52639 .3449 L .52613 .34444 L F
.52642 .34492 m .52604 .34461 L .5267 .34492 L F
.52604 .34461 m .52554 .34422 L .52605 .34453 L F
.52604 .34461 m .52605 .34453 L .5267 .34492 L F
.52628 .34491 m .52654 .3449 L .52638 .34486 L F
.52601 .34516 m .52603 .34512 L .52635 .34489 L F
.52619 .34496 m .52645 .34492 L .52628 .34491 L F
.52646 .34491 m .52625 .34503 L .52635 .34489 L F
.52625 .34503 m .52622 .345 L .52635 .34489 L F
.52621 .34498 m .52648 .34492 L .52619 .34496 L F
.52573 .34535 m .52667 .34479 L .5267 .34479 L F
.5248 .34588 m .52572 .34534 L .52573 .34535 L F
.52572 .34534 m .52667 .34479 L .52573 .34535 L F
.52648 .34492 m .52654 .3449 L .52645 .34492 L F
.52621 .34439 m .52665 .34494 L .52672 .34495 L F
.52614 .34432 m .5262 .34439 L .52621 .34439 L F
.5262 .34439 m .52665 .34494 L .52621 .34439 L F
.52684 .34493 m .52623 .34439 L .52672 .34495 L F
.52716 .34448 m .5273 .3445 L .53514 .34109 L F
.52803 .34418 m .52921 .34378 L .54208 .33806 L F
.5308 .34255 m .52979 .3433 L .53514 .34109 L F
.53228 .34213 m .52894 .34387 L p .5308 .34255 L F P
0 g
s
.52931 .344 m .52726 .34459 L .52714 .34457 L .672 .728 .891 r
F
.52894 .34387 m .52691 .34493 L p .52873 .34382 L F P
0 g
s
.52894 .34387 m .52873 .34382 L .5308 .34255 L .672 .728 .891 r
F
.52691 .34493 m .52894 .34387 L p .52689 .34476 L F P
0 g
s
.52691 .34493 m .52691 .34486 L .52868 .3438 L .672 .728 .891 r
F
.52873 .34382 m .52868 .3438 L .5308 .34255 L F
.52701 .34463 m .52921 .34378 L .52803 .34418 L F
.52691 .34493 m .52868 .3438 L .52873 .34382 L F
.53356 .3433 m .52749 .34482 L .53385 .34319 L F
.52749 .34482 m .52775 .34474 L .53385 .34319 L F
.52809 .34467 m .53341 .34354 L .52789 .34464 L F
.5269 .34494 m .5322 .34383 L .52688 .34493 L F
.52854 .34462 m .52864 .34453 L .53356 .3433 L F
.52778 .34485 m .52815 .34478 L .52815 .34477 L F
.52778 .34486 m .52815 .34478 L .52778 .34485 L F
.52815 .34478 m .52841 .34472 L p .52815 .34477 L F P
0 g
s
.52688 .34493 m .5322 .34383 L .53202 .34384 L .672 .728 .891 r
F
.52841 .34472 m .5322 .34383 L p .52814 .34468 L F P
0 g
s
.5322 .34383 m .53198 .34388 L p .53356 .3433 L .672 .728 .891 r
F P
0 g
s
.53198 .34388 m .52705 .34504 L p .53162 .34382 L .672 .728 .891 r
F P
0 g
s
.53198 .34388 m .53162 .34382 L .53356 .3433 L .672 .728 .891 r
F
.52554 .34422 m .52586 .34427 L .52608 .34444 L F
.52605 .34453 m .52608 .34444 L .5267 .34492 L F
.52554 .34422 m .52608 .34444 L .52605 .34453 L F
.52623 .34439 m .52621 .34439 L .52672 .34495 L F
.52782 .34412 m .52783 .34412 L .52979 .3433 L F
.52666 .34494 m .52652 .34492 L .52843 .34386 L F
.52844 .34389 m .52843 .34386 L .52924 .34341 L F
.52666 .34494 m .52843 .34386 L .52844 .34389 L F
.52684 .34493 m .52691 .34493 L .52689 .34476 L F
.52691 .34494 m .52841 .34472 L .52814 .34468 L F
.52697 .34501 m .52701 .34494 L .52864 .34453 L F
.52711 .34498 m .52841 .34472 L .52691 .34494 L F
.52697 .34503 m .52766 .34481 L .52771 .34484 L F
.52601 .34516 m .52581 .34528 L .52603 .34512 L F
.52597 .34513 m .52648 .34598 L .52594 .34518 L F
.52648 .34598 m .52674 .34641 L .52646 .34598 L F
.52648 .34598 m .52646 .34598 L .52594 .34518 L F
.52589 .34531 m .52673 .34504 L .52589 .34531 L F
.52594 .34553 m .52589 .34532 L .52586 .34537 L F
.52594 .34553 m .52589 .34531 L .52589 .34532 L F
.52593 .34544 m .52469 .34608 L p .52596 .34535 L F P
0 g
s
.52587 .34543 m .52587 .34542 L .52585 .34538 L .672 .728 .891 r
F
.52598 .34528 m .52595 .34537 L .52589 .34527 L F
.52592 .34521 m .52594 .34517 L .52568 .3452 L F
.52568 .3452 m .52595 .34516 L .52596 .34514 L F
.52395 .3461 m .5242 .346 L .5242 .34599 L F
.52323 .34643 m .52397 .34611 L .52395 .3461 L F
.52323 .34643 m .52397 .34611 L .52323 .34643 L F
.52397 .34611 m .52598 .34523 L .52397 .34611 L F
.52397 .34611 m .52397 .34611 L .52323 .34643 L F
.51938 .34685 m .50864 .34939 L p .51354 .3475 L F P
0 g
s
.51267 .34778 m .5245 .34556 L p .51354 .3475 L .672 .728 .891 r
F P
0 g
s
.51267 .34778 m .51265 .34779 L .52328 .34578 L .672 .728 .891 r
F
.52368 .34626 m .52362 .34629 L .52374 .34623 L F
.52362 .34629 m .519 .34878 L .52374 .34623 L F
.52374 .34623 m .519 .34878 L .52488 .34579 L F
.5248 .34588 m .52051 .34826 L .52483 .34583 L F
.52388 .34607 m .52329 .34678 L .52371 .34616 L F
.52592 .34521 m .52589 .34527 L .52548 .34466 L F
.52599 .34525 m .52598 .34528 L .52561 .34468 L F
.52589 .34507 m .52608 .34495 L .52607 .34496 L F
.52602 .34502 m .52571 .34471 L .52607 .34493 L F
.52608 .34494 m .52571 .34471 L .52597 .34479 L F
.52608 .34482 m .52596 .34478 L .52486 .34329 L F
.52601 .34504 m .52597 .34513 L .52571 .34471 L F
.52594 .34515 m .52615 .34491 L .52561 .34423 L F
.52525 .34512 m .52536 .34517 L .52602 .34503 L F
.52621 .34498 m .52605 .34503 L .52618 .34495 L F
.52598 .34528 m .52589 .34527 L .52592 .34521 L F
.52594 .3453 m .52596 .34527 L .52592 .34518 L F
.52571 .34471 m .52597 .34513 L .52561 .34468 L F
.52597 .34513 m .52594 .34518 L .52561 .34468 L F
.5259 .3452 m .52592 .34518 L .52556 .34434 L F
.52594 .3453 m .52592 .34518 L .5259 .3452 L F
.5257 .3447 m .52569 .34469 L .52601 .34554 L F
.52599 .34482 m .52617 .34491 L .52611 .3449 L F
.52625 .34487 m .52622 .34488 L .52626 .34489 L F
.52619 .34495 m .52625 .34487 L .52629 .34488 L F
.52608 .34495 m .5261 .34486 L .5262 .3448 L F
.52529 .34428 m .5263 .34491 L .52616 .34491 L F
.52511 .34415 m .52529 .34427 L .52529 .34428 L F
.52571 .3447 m .52561 .34423 L .52556 .34434 L F
.52628 .34506 m .52563 .34542 L .52626 .34505 L F
.52601 .34517 m .526 .34519 L .52597 .34513 L F
.52633 .34513 m .52631 .3451 L .52568 .3452 L F
.52589 .34521 m .52631 .3451 L .52631 .3451 L F
.52521 .34539 m .52589 .34521 L .52589 .34521 L F
.52592 .34521 m .52633 .34513 L .52594 .34517 L F
.52589 .34521 m .52631 .3451 L .52589 .34521 L F
.52597 .34524 m .52594 .34515 L .52596 .34527 L F
.52594 .34515 m .52578 .3447 L .52593 .34517 L F
.52521 .34539 m .52519 .34539 L .52589 .34521 L F
.52589 .34521 m .52589 .34521 L .52631 .3451 L F
.52521 .34539 m .52589 .34521 L .52589 .34521 L F
.52594 .34515 m .52593 .34517 L .52596 .34527 L F
.52552 .34539 m .52601 .34517 L .52536 .34537 L F
.52625 .34503 m .52601 .34516 L .52622 .345 L F
.52601 .34517 m .52689 .34476 L .52605 .3451 L F
.52562 .34527 m .52592 .34521 L .52568 .3452 L F
.52601 .34517 m .52597 .34513 L .52604 .34507 L F
.52628 .34507 m .52628 .34506 L .5255 .34523 L F
.52596 .34514 m .5263 .34509 L .52628 .34507 L F
.526 .34506 m .52628 .34506 L .52623 .34501 L F
.52604 .34507 m .526 .34507 L .52603 .34506 L F
.52604 .34507 m .52597 .34513 L .526 .34507 L F
.52597 .34513 m .52628 .34506 L .526 .34506 L F
.52631 .3451 m .52589 .3452 L .52622 .34499 L F
.52464 .34541 m .52628 .34506 L .52628 .34506 L F
.52585 .34546 m .52593 .34544 L .5259 .34543 L F
.52452 .3461 m .52584 .34548 L .52585 .34546 L F
.52584 .34548 m .52593 .34544 L .52585 .34546 L F
.52591 .34551 m .52594 .34552 L .52588 .3454 L F
.52577 .34535 m .52589 .34531 L .52589 .34531 L F
.52589 .34533 m .52638 .34612 L .5258 .34531 L F
.52638 .34612 m .52673 .34668 L .52635 .34612 L F
.52638 .34612 m .52635 .34612 L .5258 .34531 L F
.52374 .34671 m .52298 .34716 L .52371 .34669 L F
.52298 .34716 m .51571 .35153 L .52305 .34693 L F
.52073 .34822 m .52245 .34746 L .52471 .34613 L F
.52587 .34542 m .52588 .3454 L .52582 .34528 L F
.52591 .34551 m .52582 .34528 L .52581 .3453 L F
.52584 .34538 m .52585 .34538 L .52581 .3453 L F
.52584 .34538 m .52581 .3453 L .52581 .3453 L F
.52587 .34543 m .52585 .34538 L .52584 .34538 L F
.5258 .34531 m .52587 .34543 L .52581 .3453 L F
.52456 .34609 m .52593 .34544 L .52452 .3461 L F
.52491 .34597 m .52593 .34544 L p .52493 .34591 L F P
0 g
s
.52585 .34544 m .52374 .34671 L .52588 .34527 L .672 .728 .891 r
F
.52581 .3453 m .52582 .34528 L .52548 .34457 L F
.52542 .34521 m .5254 .34521 L .52605 .34503 L F
.52605 .34503 m .52605 .34503 L .52621 .34498 L F
.52624 .34502 m .52654 .3449 L .52621 .34498 L F
.52622 .34498 m .52621 .34498 L .52637 .34494 L F
.52605 .34503 m .52621 .34498 L .52622 .34498 L F
.52589 .3452 m .52602 .34506 L .52622 .34499 L F
.52604 .34504 m .52604 .34504 L .52622 .34499 L F
.52605 .3451 m .52624 .34502 L .52611 .345 L F
.5239 .34571 m .52395 .34563 L .52493 .34535 L F
.52551 .34523 m .5255 .34523 L .52464 .34541 L F
.52595 .34537 m .52594 .34541 L .52589 .34533 L F
.52594 .34534 m .52589 .34533 L .52548 .34467 L F
.5258 .34531 m .52581 .3453 L .52548 .34457 L F
.52552 .34523 m .52547 .34522 L .52603 .34505 L F
.52602 .34506 m .52603 .34505 L .52622 .34499 L F
.52604 .34555 m .5257 .3447 L .52601 .34554 L F
.52561 .34468 m .52598 .34528 L .52545 .34463 L F
.52552 .34523 m .52603 .34505 L .52602 .34506 L F
.52588 .34539 m .52588 .34539 L .52584 .34527 L F
.52584 .34527 m .52584 .34527 L .52561 .34461 L F
.52588 .34539 m .52584 .34527 L .52584 .34527 L F
.52603 .34505 m .52604 .34504 L .52622 .34499 L F
.52612 .34483 m .52522 .34374 L .52522 .34373 L F
.52577 .34535 m .5269 .34502 L .52687 .34503 L F
.52631 .3451 m .52631 .3451 L .52672 .345 L F
.52628 .34507 m .52665 .345 L .52628 .34506 L F
.5263 .34509 m .52652 .34492 L .52633 .34513 L F
.52617 .34491 m .5269 .3453 L .5269 .34544 L F
.52618 .34495 m .5254 .34521 L .52617 .34493 L F
.52615 .34491 m .52611 .345 L .52619 .34496 L F
.52617 .34493 m .52625 .34487 L .52619 .34495 L F
.52615 .34491 m .52619 .34496 L .52628 .34491 L F
.52581 .3453 m .52581 .3453 L .52548 .34457 L F
.52617 .34493 m .5254 .34521 L .52525 .34517 L F
.5263 .34491 m .52634 .34494 L .52616 .34491 L F
.52625 .34492 m .52618 .34495 L .52623 .34492 L F
.52621 .34498 m .52618 .34495 L .52635 .34489 L F
.52587 .34523 m .52589 .34521 L .52775 .34474 L F
.52629 .34507 m .52691 .34493 L .52659 .34492 L F
.52691 .34499 m .52667 .34483 L .52691 .34499 L F
.52683 .34497 m .52684 .34497 L p .52683 .34497 L F P
0 g
s
.52684 .34497 m .52691 .34493 L p .52683 .34497 L .672 .728 .891 r
F P
0 g
s
.52665 .345 m .53078 .34413 L .52663 .34499 L .672 .728 .891 r
F
.52683 .34495 m .52683 .34497 L .52691 .34493 L F
.52669 .3454 m .52699 .34577 L .52671 .34533 L F
.5269 .34562 m .52675 .3455 L p .5269 .34552 L F P
0 g
s
.53717 .3553 m .52701 .34578 L p .53685 .35497 L .672 .728 .891 r
F P
0 g
s
.52701 .34578 m .52701 .34576 L .53685 .35497 L .672 .728 .891 r
F
.52699 .34577 m .53735 .35547 L p .52783 .34611 L F P
0 g
s
.52896 .34731 m .5269 .34562 L p .52805 .34634 L .672 .728 .891 r
F P
0 g
s
.53735 .35547 m .53717 .3553 L p .53685 .35497 L .672 .728 .891 r
F P
0 g
s
.52787 .34583 m .52729 .34558 L .53735 .35547 L .672 .728 .891 r
F
.5269 .34562 m .5269 .34544 L .52875 .34677 L F
.52675 .3455 m .52886 .34723 L p .52687 .3453 L F P
0 g
s
.52781 .34472 m .52631 .3451 L .52761 .34468 L .672 .728 .891 r
F
.52634 .34494 m .5269 .3453 L .52617 .34491 L F
.52577 .34535 m .52679 .34506 L .52682 .34507 L F
.52605 .34503 m .5261 .34497 L .52618 .34495 L F
.5261 .34501 m .52615 .34491 L .52605 .34502 L F
.52584 .34527 m .52587 .34523 L .52561 .34461 L F
.52612 .34495 m .52525 .34517 L .52616 .3449 L F
.52603 .34491 m .52611 .345 L .52615 .34491 L F
.52614 .34491 m .52525 .34517 L .52601 .34489 L F
.52597 .3449 m .52603 .34494 L .52603 .34491 L F
.52603 .34494 m .52611 .345 L .52603 .34491 L F
.52578 .3447 m .52561 .34423 L .52571 .3447 L F
.52529 .34427 m .5263 .34491 L .52529 .34428 L F
.5257 .3447 m .52556 .34435 L .52569 .34469 L F
.52601 .34489 m .52511 .34415 L p .52609 .3449 L F P
0 g
s
.52624 .34502 m .52621 .34498 L .52611 .345 L .672 .728 .891 r
F
.52611 .345 m .52621 .34498 L .52619 .34496 L F
.52589 .3453 m .52669 .34502 L .52589 .34531 L F
.52601 .34517 m .52629 .34507 L .52627 .34505 L F
.52598 .34523 m .52639 .3452 L .52629 .34507 L F
.52608 .34532 m .52639 .3452 L .52615 .34491 L F
.52691 .34499 m .52667 .34483 L .52669 .3448 L F
.52659 .34492 m .52684 .34493 L .52689 .34476 L F
.52642 .34492 m .5267 .34492 L .52681 .34501 L F
.52642 .34492 m .52681 .34501 L .5266 .34498 L F
.52627 .34505 m .52629 .34507 L .52689 .34476 L F
.52631 .3451 m .52622 .34499 L .52745 .34465 L F
.52757 .34467 m .52745 .34465 L .52845 .34437 L F
.52631 .3451 m .52745 .34465 L .52757 .34467 L F
.52366 .34324 m .52372 .34325 L .52554 .34428 L F
.52761 .34468 m .52884 .34427 L .52884 .34428 L F
.52631 .3451 m .52759 .34468 L .52761 .34468 L F
.52759 .34468 m .52884 .34427 L .52761 .34468 L F
.52553 .34442 m .52556 .34433 L .52552 .34439 L F
.52556 .34435 m .52556 .34433 L .52553 .34442 L F
.52552 .34439 m .52556 .34433 L .52541 .34398 L F
.52556 .34435 m .52556 .34434 L .52556 .34433 L F
.52529 .34426 m .52554 .34422 L .52647 .34496 L F
.52511 .34415 m .52532 .34418 L .52529 .34426 L F
.52532 .34418 m .52554 .34422 L .52529 .34426 L F
.52609 .3449 m .52599 .34482 L .52611 .3449 L F
.52614 .34491 m .52601 .34489 L .52611 .34485 L F
.52622 .34487 m .52621 .34487 L .52693 .34443 L F
.52614 .34432 m .52663 .34494 L .52665 .34494 L F
.5267 .34492 m .52589 .34429 L .52681 .34493 L F
.52614 .34432 m .52613 .34444 L .52663 .34494 L F
.52613 .34444 m .52616 .34449 L .52616 .34448 L F
.52589 .34429 m .52595 .34431 L .52618 .34447 L F
.52617 .34449 m .52618 .34447 L .52696 .34503 L F
.52589 .34429 m .52618 .34447 L .52617 .34449 L F
.52587 .34532 m .52586 .34532 L .52625 .34522 L F
.52565 .34527 m .52565 .34527 L .52672 .345 L F
.52601 .34517 m .52598 .34523 L .52629 .34507 L F
.52595 .34537 m .52589 .34533 L .52594 .34534 L F
.52593 .34544 m .52612 .34526 L .52614 .34531 L F
.52598 .34528 m .52649 .34612 L .52595 .34537 L F
.52649 .34612 m .52673 .34651 L .52647 .34612 L F
.52649 .34612 m .52647 .34612 L .52595 .34537 L F
.52654 .34612 m .52649 .34612 L .52598 .34528 L F
.52673 .34651 m .52673 .34668 L .52594 .34541 L F
.52673 .34651 m .52594 .34541 L .52595 .34537 L F
.52623 .34612 m .52673 .34668 L .52671 .34706 L F
.52656 .34668 m .52644 .34568 L .52609 .34557 L F
.52655 .34617 m .52653 .34628 L .52611 .34551 L F
.52589 .3452 m .52485 .34547 L .52602 .34506 L F
.52595 .34519 m .52596 .34513 L .52594 .34515 L F
.52597 .34524 m .52596 .34513 L .52595 .34519 L F
.52597 .34524 m .5261 .34501 L .52596 .34513 L F
.52592 .34521 m .52548 .34466 L .52548 .34466 L F
.52548 .34457 m .52588 .34539 L .52561 .34461 L F
.52504 .34567 m .52575 .34538 L .52505 .34564 L F
.52581 .34528 m .52483 .34583 L .52586 .34517 L F
.52601 .34517 m .52605 .3451 L .52536 .34537 L F
.52542 .34521 m .52637 .34494 L .52638 .34494 L F
.5261 .34501 m .52605 .34502 L .52594 .34515 L F
.5258 .34531 m .5258 .34531 L .52581 .3453 L F
.5258 .34531 m .52568 .34528 L .52581 .3453 L F
.52581 .3453 m .52568 .34528 L .52587 .34523 L F
.52577 .34535 m .52568 .34528 L .5258 .34531 L F
.5242 .34599 m .52598 .34523 L .52601 .34517 L F
.52528 .34558 m .5251 .34564 L .52608 .34503 L F
.52587 .34523 m .52389 .34573 L .52589 .34521 L F
.52567 .34527 m .52589 .34523 L .52566 .34526 L F
.5261 .34519 m .52615 .34491 L .52599 .3452 L F
.5261 .34519 m .52599 .3452 L .52597 .34524 L F
.52595 .34539 m .52596 .34535 L .526 .34533 L F
.52595 .34539 m .526 .34533 L .52612 .34526 L F
.52593 .34544 m .52595 .34539 L .52612 .34526 L F
.52587 .34542 m .52601 .34536 L .52597 .34524 L F
.52608 .34533 m .52639 .3452 L .5261 .34522 L F
.52597 .34524 m .526 .34523 L .52598 .34523 L F
.52605 .34547 m .5261 .34519 L .52597 .34524 L F
.52608 .34536 m .52639 .3452 L p .52607 .34535 L F P
0 g
s
.5259 .34543 m .52608 .34536 L .52607 .34535 L .672 .728 .891 r
F
.52593 .34544 m .52608 .34536 L p .5259 .34543 L F P
0 g
s
.52589 .34429 m .52528 .34382 L .52595 .34431 L .672 .728 .891 r
F
.52561 .34423 m .52528 .34382 L .52586 .34427 L F
.52541 .34398 m .52615 .34491 L .52576 .34405 L F
.52485 .34547 m .5239 .34571 L .5249 .3454 L F
.52401 .34562 m .52467 .34551 L .524 .34558 L F
.52499 .34545 m .5232 .34645 L .52532 .34539 L F
.52499 .34545 m .52532 .34539 L .52611 .345 L F
.52485 .34547 m .52547 .34522 L .52552 .34523 L F
.5249 .3454 m .52604 .34504 L .52603 .34505 L F
.52561 .34461 m .52556 .34435 L .52553 .34442 L F
.52601 .34554 m .52567 .34462 L .52561 .34461 L F
.52567 .34462 m .52556 .34435 L .52561 .34461 L F
.5297 .34453 m .53132 .34423 L .53132 .34423 L F
.52698 .34503 m .5297 .34453 L .5297 .34453 L F
.5297 .34453 m .53132 .34423 L .5297 .34453 L F
.52542 .34521 m .52605 .34503 L .52542 .34521 L F
.52542 .34521 m .52605 .34503 L .52605 .34503 L F
.52605 .34503 m .52599 .34505 L .52606 .34502 L F
.52545 .34519 m .5254 .34521 L .52546 .34519 L F
.52609 .34499 m .52608 .34498 L .5261 .34497 L F
.52597 .3449 m .52499 .34545 L .52611 .345 L F
.52605 .34547 m .52612 .34541 L .52608 .34532 L F
.52679 .34439 m .52686 .34439 L .54061 .33676 L F
.52767 .34389 m .52657 .34464 L .52757 .34389 L F
.52397 .34611 m .52598 .34523 L .52395 .3461 L F
.5232 .34645 m .52552 .34539 L .52536 .34537 L F
.52419 .34601 m .52488 .34579 L .52598 .34523 L F
.52417 .34607 m .52488 .34579 L .52419 .34601 L F
.52509 .34553 m .52475 .34576 L .52517 .34535 L F
.52475 .34576 m .52329 .34678 L .52452 .34585 L F
.52475 .34576 m .52452 .34585 L .52517 .34535 L F
.52599 .34482 m .526 .34479 L .52617 .34491 L F
.52614 .34491 m .52611 .34485 L .52615 .3449 L F
.52597 .3449 m .52615 .34491 L .5261 .34484 L F
.52603 .34487 m .52603 .34491 L .52612 .34488 L F
.52606 .3449 m .52609 .3449 L .52623 .34501 L F
.52606 .3449 m .52623 .34501 L .52683 .34547 L F
.52601 .34489 m .52606 .3449 L .52683 .34547 L F
.52603 .34491 m .52639 .3452 L p .52612 .34488 L F P
0 g
s
.5261 .34469 m .52608 .34482 L .52611 .34471 L .672 .728 .891 r
F
.52511 .34415 m .5264 .34492 L .5263 .34491 L F
.52556 .34434 m .52558 .3443 L .52549 .34418 L F
.52558 .3443 m .52561 .34423 L .52549 .34418 L F
.52549 .34418 m .52561 .34423 L .52541 .34398 L F
.53078 .34413 m .53198 .34388 L .53079 .34412 L F
.53078 .34413 m .53079 .34412 L .52663 .34499 L F
.53198 .34388 m .5322 .34383 L .53198 .34387 L F
.53198 .34388 m .53198 .34387 L .52663 .34499 L F
.53034 .34425 m .53066 .34434 L .53999 .34262 L F
.52705 .34504 m .52697 .34503 L .53351 .34332 L F
.53031 .34374 m .53255 .3436 L .54422 .34099 L F
.53351 .34332 m .53351 .34332 L .53356 .3433 L F
.52705 .34504 m .53351 .34332 L .53351 .34332 L F
.52391 .34345 m .52145 .34207 L .52416 .3435 L F
.52376 .34342 m .52145 .34207 L .52378 .34343 L F
.52495 .34416 m .52366 .34324 L p .52505 .34418 L F P
0 g
s
.52511 .34415 m .51435 .33532 L p .52554 .34422 L .672 .728 .891 r
F P
0 g
s
.52322 .34238 m .51435 .33532 L .52305 .34209 L .672 .728 .891 r
F
.52322 .34238 m .52305 .34209 L .52528 .34382 L F
.51435 .33532 m .52511 .34415 L p .52501 .34352 L F P
0 g
s
.52463 .34375 m .52403 .34327 L .52434 .34335 L .672 .728 .891 r
F
.52463 .34376 m .52403 .34327 L .52463 .34375 L F
.52463 .34376 m .52352 .34313 L .52403 .34327 L F
.52366 .34324 m .52491 .34414 L p .52346 .34264 L F P
0 g
s
.52515 .3437 m .52603 .34491 L .52604 .34478 L .672 .728 .891 r
F
.52614 .34485 m .52582 .34468 L .52611 .34479 L F
.52623 .34492 m .52618 .34495 L .52617 .34493 L F
.52616 .34491 m .52617 .34491 L .52617 .34491 L F
.52639 .3452 m .52611 .34494 L .52613 .34488 L F
.5261 .34484 m .52628 .34491 L .52722 .34444 L F
.52667 .34483 m .5254 .34391 L .52669 .3448 L F
.5254 .34391 m .52528 .34382 L .5254 .3439 L F
.5254 .34391 m .5254 .3439 L .52669 .3448 L F
.52622 .34484 m .52619 .34479 L p .52615 .34491 L F P
0 g
s
.52615 .3449 m .52618 .34485 L .5262 .34485 L .672 .728 .891 r
F
.52618 .34485 m .52619 .34482 L .5262 .34485 L F
.5262 .34485 m .52619 .34482 L .52622 .34484 L F
.52615 .34491 m .52618 .34475 L .52608 .34474 L F
.52615 .34491 m .52619 .34479 L .52617 .34478 L F
.52615 .34491 m .52628 .34491 L .5261 .34484 L F
.52634 .34494 m .52617 .34491 L .52616 .34491 L F
.52616 .3449 m .52614 .34491 L .52625 .3448 L F
.52589 .34531 m .52669 .34502 L .52673 .34504 L F
.52611 .3449 m .52617 .34491 L .5269 .34544 L F
.52639 .3452 m .52622 .34484 L p .52615 .34491 L F P
0 g
s
.52639 .3452 m .52615 .34485 L .52617 .34482 L .672 .728 .891 r
F
.52635 .34489 m .52625 .34492 L .52623 .34492 L F
.52648 .34492 m .52645 .34492 L .52619 .34496 L F
.5264 .34492 m .52647 .34496 L .5263 .34491 L F
.52642 .34492 m .52627 .34494 L .52635 .34489 L F
.52644 .34492 m .52627 .34494 L .52642 .34492 L F
.5263 .34491 m .52647 .34496 L .52634 .34494 L F
.52633 .34494 m .52621 .34498 L .52627 .34494 L F
.52644 .34492 m .52637 .34494 L .52633 .34494 L F
.52637 .34494 m .52621 .34498 L .52633 .34494 L F
.52645 .34492 m .52654 .3449 L .52628 .34491 L F
.52617 .34489 m .52634 .34493 L .52656 .3449 L F
.52625 .34489 m .52626 .34491 L .52646 .34491 L F
.52617 .34491 m .5269 .3453 L .52617 .34491 L F
.52565 .34527 m .52672 .345 L .52672 .345 L F
.52609 .3449 m .52611 .3449 L .5269 .34544 L F
.52626 .34491 m .52639 .3452 L .52645 .34496 L F
.52615 .3449 m .52611 .34485 L .52619 .34482 L F
.52639 .3452 m .52613 .34488 L .52615 .34485 L F
.5269 .34502 m .52698 .345 L .52691 .34502 L F
.52631 .3451 m .52672 .345 L .52673 .345 L F
.5269 .3453 m .52642 .34492 L .5269 .34508 L F
.52668 .34501 m .52653 .34498 L .52687 .3453 L F
.5269 .34544 m .5269 .3453 L .52875 .34677 L F
.52689 .34525 m .52687 .3453 L .52729 .34571 L F
.52668 .34501 m .52687 .3453 L .52689 .34525 L F
.5249 .3454 m .52493 .34535 L .52604 .34504 L F
.52536 .34537 m .52605 .3451 L .52611 .345 L F
.52609 .34557 m .52597 .34524 L .52596 .34527 L F
.52602 .34537 m .52598 .34535 L .52597 .34533 L F
.52596 .34527 m .52578 .3447 L .52571 .3447 L F
.52612 .34491 m .52547 .34541 L .52605 .34487 L F
.52608 .34503 m .52547 .34541 L .52612 .34491 L F
.52609 .34483 m .52509 .34553 L .52517 .34535 L F
.52531 .34511 m .52598 .34509 L .52591 .345 L F
.52537 .34555 m .52608 .34503 L .52606 .34509 L F
.52008 .34823 m .52456 .34609 L .52452 .3461 L F
.52298 .34716 m .52528 .34558 L .52537 .34555 L F
.52528 .34558 m .52608 .34503 L .52537 .34555 L F
.52589 .34523 m .52589 .34522 L .52566 .34526 L F
.52619 .34496 m .52612 .34491 L .52613 .34488 L F
.52612 .34491 m .52605 .34487 L .52613 .34488 L F
.52617 .34482 m .52525 .34517 L .52609 .34483 L F
.52619 .34482 m .52525 .34517 L .52617 .34482 L F
.5259 .3452 m .52556 .34434 L .5259 .3452 L F
.5259 .3452 m .52556 .34434 L .5259 .3452 L F
.52609 .34483 m .52525 .34517 L .52492 .34508 L F
.52613 .34488 m .52374 .34535 L .52606 .34498 L F
.52374 .34535 m .52323 .34545 L .52378 .34536 L F
.52374 .34535 m .52378 .34536 L .52606 .34498 L F
.54007 .35387 m .54086 .35327 L p .53009 .34686 L F P
0 g
s
.52515 .34371 m .52515 .34372 L .52517 .34374 L .672 .728 .891 r
F
.52515 .34372 m .52511 .34415 L .52517 .34374 L F
.52599 .34482 m .52511 .34415 L .526 .34479 L F
.52511 .34415 m .52603 .34491 L p .52517 .34374 L F P
0 g
s
.52509 .34359 m .52552 .34444 L .52547 .34449 L .672 .728 .891 r
F
.52366 .34324 m .52554 .34428 L .52551 .34427 L F
.52505 .34426 m .52473 .34379 L .52504 .34426 L F
.52505 .34418 m .52366 .34324 L .52551 .34427 L F
.52463 .34376 m .52434 .34335 L .52501 .34352 L F
.52346 .34264 m .52491 .34414 L .52544 .34426 L F
.52522 .34427 m .52145 .34207 L .52524 .34427 L F
.52524 .34427 m .52145 .34207 L .52542 .3443 L F
.52514 .34369 m .52603 .34491 L .52515 .3437 L F
.52618 .34475 m .52498 .34217 L p .52608 .34474 L F P
0 g
s
.52612 .34541 m .52639 .3452 L .52608 .34532 L .672 .728 .891 r
F
.52614 .34551 m .52639 .3452 L .52605 .34547 L F
.52639 .3452 m .5262 .34545 L .52604 .34513 L F
.52501 .3457 m .52509 .34553 L .52609 .34483 L F
.52611 .34494 m .52604 .34513 L .52582 .34468 L F
.52639 .3452 m .52604 .34513 L .52611 .34494 L F
.52602 .34537 m .52597 .34533 L .52598 .34529 L F
.52601 .34521 m .52601 .34521 L .52612 .3454 L F
.52604 .34555 m .52596 .34527 L .52594 .3453 L F
.52597 .34533 m .52598 .34535 L .52596 .34535 L F
.52596 .34535 m .52625 .34503 L .5263 .34509 L F
.52634 .34514 m .52606 .34531 L .5263 .34509 L F
.52589 .34523 m .52639 .3452 L .52635 .34515 L F
.52584 .34525 m .52635 .34515 L .52635 .34515 L F
.52619 .34496 m .52608 .34503 L .52612 .34491 L F
.52613 .34488 m .52606 .34498 L .52619 .34496 L F
.52609 .34483 m .52613 .34488 L .52616 .34484 L F
.5272 .34454 m .52628 .34506 L .52753 .34432 L F
.5272 .3446 m .52616 .3449 L .52625 .3448 L F
.52609 .34483 m .52656 .3449 L .5263 .34482 L F
.52616 .3448 m .52613 .34488 L .52609 .34483 L F
.52546 .34397 m .52576 .34405 L .52571 .34394 L F
.52599 .34431 m .52528 .34382 L .52619 .34436 L F
.52617 .34482 m .52531 .34364 L .52559 .34379 L F
.52613 .34488 m .52605 .34487 L .52609 .34483 L F
.52609 .34483 m .52602 .34485 L .52613 .34488 L F
.52604 .34478 m .52603 .34487 L .52612 .34488 L F
.52611 .34494 m .52582 .34468 L .52614 .34485 L F
.52552 .34444 m .52591 .3452 L .52547 .34449 L F
.52588 .3454 m .52592 .34534 L .52587 .34523 L F
.52588 .3454 m .52587 .34523 L .52584 .34527 L F
.52563 .34542 m .5248 .34588 L .52561 .34542 L F
.52588 .34539 m .52588 .3454 L .52588 .34539 L F
.5248 .34588 m .52483 .34583 L .52498 .34574 L F
.5248 .34588 m .52498 .34574 L .52502 .34575 L F
.52423 .34612 m .52587 .34542 L .52598 .34523 L F
.52585 .34544 m .52588 .34527 L .52602 .34518 L F
.52591 .3452 m .52597 .34533 L .5259 .34521 L F
.52591 .3452 m .5259 .34521 L .52547 .34449 L F
.52485 .34547 m .5249 .3454 L .52547 .34522 L F
.52395 .34563 m .52494 .34534 L .52493 .34535 L F
.52498 .34217 m .52441 .34094 L p .52495 .34218 L F P
0 g
s
.52608 .34474 m .52498 .34217 L .52495 .34218 L .672 .728 .891 r
F
.52608 .34474 m .52441 .34094 L .52438 .34095 L F
.52541 .34398 m .52576 .34405 L .52546 .34397 L F
.52541 .34398 m .52571 .34394 L .52541 .34395 L F
.52578 .3439 m .52587 .34408 L p .52559 .34379 L F P
0 g
s
.52619 .34479 m .52618 .34475 L p .52617 .34478 L .672 .728 .891 r
F P
0 g
s
.52587 .34408 m .52639 .3452 L p .52579 .34415 L .672 .728 .891 r
F P
0 g
s
.52511 .34263 m .52364 .33928 L .52356 .33922 L .672 .728 .891 r
F
.52615 .34491 m .52514 .34264 L .52511 .34263 L F
.52514 .34264 m .52364 .33928 L .52511 .34263 L F
.5271 .345 m .54014 .34261 L .53999 .34262 L F
.52703 .34502 m .52703 .34502 L .53092 .34427 L F
.52699 .34503 m .5335 .34384 L .52698 .34503 L F
.5335 .34384 m .53879 .34286 L .53349 .34383 L F
.5335 .34384 m .53349 .34383 L .52698 .34503 L F
.52691 .34502 m .52766 .34481 L .52697 .34503 L F
.52732 .34484 m .52697 .34502 L .52836 .34476 L F
.52682 .34507 m .52691 .34502 L .52697 .34503 L F
.5269 .34502 m .52691 .34502 L .52687 .34503 L F
.52787 .34583 m .52681 .34501 L .52696 .34503 L F
.52685 .34505 m .52699 .34503 L .52698 .34503 L F
.52634 .34494 m .52647 .34496 L .5269 .3453 L F
.52653 .34498 m .52675 .3455 L .52687 .3453 L F
.52634 .34493 m .52697 .34502 L .52656 .3449 L F
.52646 .34491 m .52649 .34497 L .52653 .34498 L F
.52649 .34497 m .52675 .3455 L .52653 .34498 L F
.52709 .34501 m .5271 .345 L .52683 .34505 L F
.52601 .34489 m .52683 .34547 L .52682 .34547 L F
.52639 .3452 m .52601 .34489 L p .5264 .34517 L F P
0 g
s
.52639 .3452 m .52622 .34524 L p .52659 .34513 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .5264 .34517 L .5269 .34552 L .672 .728 .891 r
F
.52675 .3455 m .52639 .3452 L p .5269 .34552 L F P
0 g
s
.5269 .34552 m .52609 .3449 L .5269 .34544 L .672 .728 .891 r
F
.52639 .3452 m .52672 .34547 L p .52649 .34497 L F P
0 g
s
.52585 .34552 m .52583 .34551 L .52595 .34544 L .672 .728 .891 r
F
.52606 .34498 m .52622 .34499 L .52619 .34496 L F
.52611 .34479 m .52531 .34364 L .52617 .34482 L F
.52604 .34477 m .52613 .34488 L .5261 .34456 L F
.52613 .34488 m .52639 .3452 L .52626 .34491 L F
.52612 .34495 m .52616 .3449 L .5272 .3446 L F
.52613 .34488 m .52619 .34496 L .52617 .34489 L F
.52613 .34488 m .52617 .34489 L .52616 .34484 L F
.52613 .34488 m .52626 .34491 L .52625 .34489 L F
.52622 .34484 m .52619 .34482 L .52625 .3448 L F
.52625 .3448 m .52619 .34482 L .52617 .34482 L F
.52624 .34475 m .52621 .34489 L .52613 .34488 L F
.52692 .34449 m .52692 .34448 L .52717 .34432 L F
.52692 .34444 m .5259 .34506 L .52692 .34444 L F
.5261 .34484 m .52722 .34444 L .52696 .34442 L F
.52617 .34482 m .52615 .34481 L .52617 .34482 L F
.52615 .34481 m .52615 .34481 L .52617 .34482 L F
.52615 .34485 m .52613 .34488 L .52614 .34485 L F
.52624 .34475 m .52613 .34488 L .52616 .3448 L F
.52615 .34481 m .52611 .34479 L .52615 .34481 L F
.52615 .34485 m .52611 .34479 L .52617 .34482 L F
.52613 .34488 m .52625 .34489 L .5261 .34456 L F
.52617 .34489 m .52619 .34496 L .52621 .3449 L F
.52621 .3449 m .52619 .34496 L .52634 .34493 L F
.52621 .34489 m .52619 .34496 L .52613 .34488 L F
.52645 .34496 m .52639 .3452 L .52649 .34497 L F
.52612 .3454 m .52568 .34463 L .52612 .3454 L F
.52622 .34499 m .52697 .34502 L .52619 .34496 L F
.5259 .34519 m .52606 .34509 L .52589 .34524 L F
.52626 .34491 m .52645 .34496 L .52646 .34491 L F
.52696 .3455 m .52687 .34543 L .52706 .34514 L F
.52606 .34509 m .52686 .34454 L .52604 .34514 L F
.52759 .34468 m .52845 .34437 L .52849 .34438 L F
.52631 .3451 m .52757 .34467 L .52759 .34468 L F
.52757 .34467 m .52845 .34437 L .52759 .34468 L F
.52615 .3444 m .52509 .34359 L .5261 .34456 L F
.52541 .34398 m .52538 .34322 L .52483 .34262 L F
.52582 .34468 m .52568 .34463 L .52509 .34359 L F
.52552 .34462 m .52563 .3444 L .52555 .34415 L F
.52541 .34395 m .52571 .34394 L .52538 .34322 L F
.52611 .34479 m .52582 .34468 L .52531 .34364 L F
.52615 .3444 m .5251 .34359 L .52509 .34359 L F
.52538 .34394 m .52555 .34415 L .5252 .34306 L F
.52568 .34463 m .52564 .34461 L .52509 .34359 L F
.52568 .34463 m .52568 .34463 L .52509 .34359 L F
.52554 .34422 m .52528 .34382 L .52561 .34423 L F
.52409 .34115 m .52513 .34328 L .52506 .3435 L F
.52522 .34373 m .52522 .34374 L .52486 .34329 L F
.52515 .34331 m .52558 .34419 L .52509 .34359 L F
.52506 .3435 m .52509 .34359 L .5252 .34306 L F
.52509 .34359 m .52507 .34359 L .52564 .34429 L F
.52509 .34359 m .52604 .34477 L .5261 .34456 L F
.52571 .34421 m .52554 .34414 L .52576 .3441 L F
.52564 .34461 m .5256 .3446 L .52509 .34359 L F
.52509 .34359 m .52552 .34462 L .52538 .34394 L F
.52509 .34359 m .52564 .34429 L .52566 .34429 L F
.52554 .34414 m .52463 .34376 L .52543 .344 L F
.52554 .34414 m .52543 .344 L .52576 .3441 L F
.52509 .34359 m .52538 .34394 L .52529 .34352 L F
.52559 .34379 m .52531 .34364 L .52409 .34115 L F
.52526 .34353 m .52529 .34352 L .52521 .34313 L F
.52526 .34353 m .52521 .34313 L .5252 .34306 L F
.52509 .34359 m .52526 .34353 L .5252 .34306 L F
.52528 .34382 m .51435 .33532 L .52458 .34295 L F
.52509 .34359 m .52501 .34352 L .52507 .34359 L F
.52566 .34429 m .52564 .34429 L .52639 .3452 L F
.52684 .34504 m .52697 .34502 L .52679 .34501 L F
.52679 .34506 m .52691 .34502 L .52682 .34507 L F
.52673 .34504 m .52681 .34501 L .52678 .34506 L F
.5266 .34498 m .52681 .34501 L .5269 .34508 L F
.52675 .34503 m .52669 .34501 L .52622 .34499 L F
.52687 .34495 m .52666 .34493 L .52675 .34503 L F
.52698 .34508 m .52675 .34503 L .52692 .34521 L F
.5267 .34508 m .52685 .34505 L .52685 .34505 L F
.52591 .345 m .52598 .34509 L .52606 .34498 L F
.52583 .34471 m .52604 .34513 L .52571 .34468 L F
.52323 .34545 m .52324 .34546 L .52606 .34498 L F
.52538 .34394 m .52542 .34408 L .52509 .34359 L F
.52558 .34419 m .52542 .34408 L .52538 .34394 L F
.52558 .34419 m .52582 .34468 L .52542 .34408 L F
.52552 .34462 m .52555 .34415 L .52538 .34394 L F
.52501 .34352 m .52514 .34369 L .52515 .3437 L F
.52501 .34352 m .52504 .34372 L .52515 .34371 L F
.52504 .34372 m .52511 .34415 L .52515 .34371 L F
.52576 .3441 m .52463 .34376 L .525 .34352 L F
.52646 .34491 m .52645 .34496 L .52649 .34497 L F
.52615 .34491 m .52609 .34483 L .5261 .34498 L F
.52607 .34509 m .526 .34469 L .52593 .34468 L F
.52582 .34468 m .52583 .34471 L .52568 .34463 L F
.5259 .3452 m .52556 .34434 L .52556 .34435 L F
.52596 .34512 m .52564 .34461 L .52568 .34463 L F
.52595 .34514 m .52564 .34461 L .52596 .34512 L F
.52598 .34529 m .52597 .34533 L .5256 .3446 L F
.52551 .34427 m .52554 .34428 L .52574 .34439 L F
.52575 .3444 m .52574 .34439 L .52599 .34453 L F
.52568 .34457 m .52569 .34433 L .52562 .34437 L F
.52551 .34427 m .52574 .34439 L .52575 .3444 L F
.52554 .34428 m .52463 .34376 L .52554 .34414 L F
.52567 .3443 m .52554 .34414 L .52614 .3444 L F
.52562 .34437 m .52528 .34279 L .5252 .34306 L F
.52554 .34428 m .52554 .34414 L .52567 .3443 L F
.52614 .3444 m .52577 .34424 L .52576 .3441 L F
.52589 .34459 m .52587 .34401 L .52576 .34418 L F
.52593 .34468 m .52592 .34462 L .52589 .34459 L F
.52569 .34433 m .52567 .3443 L .52562 .34437 L F
.52724 .34459 m .52609 .34483 L .5274 .34463 L F
.52686 .34454 m .52686 .34455 L .52604 .34514 L F
.52693 .34503 m .52684 .34493 L .52691 .34503 L F
.52693 .34503 m .52691 .34503 L .52729 .34558 L F
.52754 .34569 m .52693 .34503 L .52729 .34558 L F
.52709 .34501 m .52683 .34505 L .52684 .34505 L F
.52687 .34503 m .52692 .34502 L .52692 .34502 L F
.52692 .34502 m .52698 .345 L .52692 .34502 L F
.52692 .34502 m .52698 .345 L .52697 .34501 L F
.52705 .34504 m .52693 .34507 L p .52697 .34503 L F P
0 g
s
.52701 .34506 m .52687 .34495 L .52698 .34508 L .672 .728 .891 r
F
.52615 .3444 m .5261 .34456 L .52653 .34498 L F
.52614 .3444 m .5261 .34456 L .52615 .3444 L F
.52686 .34454 m .5269 .34452 L .52686 .34455 L F
.52631 .3451 m .52684 .34504 L .52622 .34499 L F
.52654 .3449 m .52685 .34477 L .52652 .3449 L F
.52638 .34494 m .52637 .34494 L .52905 .34421 L F
.52655 .34489 m .52656 .3449 L .52657 .34489 L F
.5291 .34408 m .52909 .34408 L .52931 .344 L F
.53031 .34374 m .52888 .34422 L .52931 .344 L F
.53031 .34374 m .52725 .34454 L .53255 .3436 L F
.52691 .34486 m .52691 .3448 L .52865 .34379 L F
.52868 .3438 m .52865 .34379 L .5308 .34255 L F
.52691 .34486 m .52865 .34379 L .52868 .3438 L F
.52781 .34472 m .52761 .34468 L .52851 .34438 L F
.52724 .34459 m .5274 .34463 L .52979 .34425 L F
.53385 .34319 m .52869 .3445 L .52905 .34421 L F
.52724 .34459 m .52979 .34425 L .52981 .34424 L F
.52724 .34459 m .53012 .34419 L .53001 .34416 L F
.52655 .34489 m .52657 .34489 L .52766 .34471 L F
.52652 .3449 m .52685 .34477 L .52638 .34486 L F
.52654 .3449 m .52689 .34476 L .52685 .34477 L F
.52905 .34421 m .52644 .34492 L .52635 .34489 L F
.5263 .34482 m .52655 .34489 L .52766 .34471 L F
.52713 .34445 m .52709 .34447 L .52718 .34441 L F
.5267 .34479 m .52667 .34479 L .52974 .34306 L F
.52634 .34514 m .52709 .34447 L .52713 .34445 L F
.52659 .34499 m .52697 .34502 L .52634 .34493 L F
.52661 .34492 m .52653 .34498 L .52668 .34501 L F
.52693 .34443 m .52692 .34444 L .52692 .34444 L F
.52704 .34431 m .52597 .3449 L .52701 .3444 L F
.52686 .34441 m .52648 .34478 L .52624 .34475 L F
.52704 .34431 m .52701 .3444 L .54138 .3374 L F
.52717 .34432 m .52692 .34446 L .52693 .34443 L F
.52872 .34337 m .52686 .34454 L .52686 .34441 L F
.52686 .34454 m .52648 .34478 L .52686 .34441 L F
.52623 .34439 m .52614 .34432 L .52621 .34439 L F
.52669 .3448 m .52599 .34431 L .52619 .34436 L F
.52615 .3444 m .52614 .3444 L .52615 .3444 L F
.52737 .34463 m .52612 .34495 L .5272 .3446 L F
.52609 .34483 m .52775 .34469 L .5274 .34463 L F
.52659 .34492 m .52652 .34492 L .52709 .34447 L F
.52614 .3444 m .525 .34352 L .52615 .3444 L F
.51951 .34184 m .5187 .34145 L p .52044 .342 L F P
0 g
s
.5187 .34145 m .51105 .33772 L p .52044 .342 L .672 .728 .891 r
F P
0 g
s
.52587 .34408 m .52579 .34415 L .52559 .34379 L .672 .728 .891 r
F
.52557 .34429 m .52554 .34428 L .52567 .3443 L F
.52391 .34345 m .52416 .3435 L .52515 .34403 L F
.52569 .34541 m .52642 .34491 L .52643 .34491 L F
.52557 .34548 m .52568 .34541 L .52569 .34541 L F
.52568 .34541 m .52642 .34491 L .52569 .34541 L F
.52677 .34548 m .52639 .3452 L p .52685 .34547 L F P
0 g
s
.52629 .3451 m .52631 .3451 L .5262 .34505 L .672 .728 .891 r
F
.52686 .3446 m .5269 .34452 L .52713 .34443 L F
.52609 .34483 m .52766 .34471 L .52769 .3447 L F
.52589 .34524 m .52686 .34455 L .52686 .3446 L F
.52686 .34455 m .5269 .34452 L .52686 .3446 L F
.52631 .3451 m .52622 .34499 L .52606 .34498 L F
.52557 .34548 m .5264 .34491 L .52642 .34491 L F
.52595 .34515 m .52629 .3451 L .52606 .34498 L F
.52585 .34524 m .52614 .34494 L .52617 .34493 L F
.52673 .345 m .52672 .345 L .52749 .3448 L F
.52631 .3451 m .52749 .3448 L .52749 .3448 L F
.52672 .345 m .52672 .345 L .52775 .34474 L F
.52689 .34501 m .52692 .34494 L .52691 .34494 L F
.52749 .34482 m .52587 .34523 L .52775 .34474 L F
.52656 .3449 m .5269 .345 L .52732 .34484 L F
.52687 .34495 m .52682 .34492 L .52682 .34494 L F
.52687 .34495 m .52682 .34492 L .52687 .34495 L F
.52682 .34492 m .52615 .3444 L .52682 .34494 L F
.52926 .34344 m .52924 .34341 L .5308 .34255 L F
.53001 .34299 m .5276 .34433 L .52974 .34306 L F
.5276 .34433 m .52753 .34432 L .52974 .34306 L F
.52974 .34306 m .5275 .34432 L .52717 .34432 L F
.54088 .33764 m .5308 .34255 L .53514 .34109 L F
.5308 .34255 m .53001 .34299 L .52974 .34306 L F
.54138 .3374 m .53228 .34213 L p .5308 .34255 L F P
0 g
s
.52696 .34442 m .52722 .34444 L .54138 .3374 L .672 .728 .891 r
F
.52666 .34494 m .52861 .34378 L .52865 .34379 L F
.5276 .34433 m .5272 .34454 L .52753 .34432 L F
.52753 .34432 m .52628 .34506 L .52753 .34432 L F
.52696 .34458 m .52689 .34476 L .53104 .34266 L F
.52689 .34476 m .52894 .34387 L .52807 .34417 L F
.52854 .34392 m .52686 .34492 L p .52853 .34389 L F P
0 g
s
.52684 .34504 m .52679 .34501 L .52669 .34501 L .672 .728 .891 r
F
.52875 .34677 m .5269 .3453 L .52787 .34583 L F
.52666 .34493 m .52729 .34571 L .52743 .34574 L F
.52743 .34574 m .52743 .34574 L .52744 .34574 L F
.52666 .34493 m .52743 .34574 L .52743 .34574 L F
.52711 .34533 m .52684 .34509 L .52729 .34558 L F
.52787 .34583 m .52762 .34561 L .52754 .34569 L F
.5269 .3453 m .5269 .34508 L .52787 .34583 L F
.52699 .34509 m .52692 .34521 L .52763 .34594 L F
.52766 .3459 m .52763 .34594 L .52811 .34645 L F
.52699 .34509 m .52763 .34594 L .52766 .3459 L F
.52615 .3444 m .52649 .34491 L .52661 .34492 L F
.52616 .34484 m .52617 .34489 L .52656 .3449 L F
.52648 .34478 m .52619 .34496 L .52624 .34475 L F
.52615 .3444 m .52661 .34492 L .52666 .34493 L F
.52619 .34496 m .52659 .34499 L .52634 .34493 L F
.5263 .34509 m .52625 .34503 L .52686 .34462 L F
.52686 .34465 m .52686 .34462 L .52718 .34441 L F
.5263 .34509 m .52686 .34462 L .52686 .34465 L F
.52699 .34509 m .52698 .34508 L .52699 .34509 L F
.52685 .34505 m .52699 .34503 L .52685 .34505 L F
.52701 .34506 m .52699 .34509 L .52811 .34645 L F
.52706 .34514 m .52687 .34503 L .52707 .34511 L F
.52684 .34504 m .52669 .34501 L .52675 .34503 L F
.52669 .34508 m .52708 .34507 L .52709 .34501 L F
.52687 .34495 m .52675 .34503 L .52698 .34508 L F
.52637 .34518 m .52688 .34482 L .52696 .34483 L F
.52639 .3452 m .52708 .34507 L p .52669 .34508 L F P
0 g
s
.52701 .34506 m .52698 .34508 L .52699 .34509 L .672 .728 .891 r
F
.52687 .34503 m .52687 .345 L .52697 .34505 L F
.52643 .34518 m .52662 .34512 L .52697 .34505 L F
.52727 .34526 m .52687 .34495 L .52687 .34495 L F
.52708 .34507 m .53673 .34325 L p .52709 .34501 L F P
0 g
s
.53673 .34325 m .53879 .34286 L p .53672 .34324 L .672 .728 .891 r
F P
0 g
s
.52709 .34501 m .53673 .34325 L .53672 .34324 L .672 .728 .891 r
F
.52702 .34506 m .52697 .34505 L .52846 .34476 L F
.52643 .34518 m .52697 .34505 L .52702 .34506 L F
.52606 .34509 m .52604 .34514 L .52589 .34524 L F
.52676 .34585 m .52617 .34547 L .52634 .34549 L F
.52676 .34585 m .526 .34519 L .52601 .34517 L F
.52644 .34568 m .52639 .3452 L .52609 .34557 L F
.52604 .34513 m .5265 .34606 L .52601 .34521 L F
.52602 .3452 m .52602 .34518 L .52608 .34514 L F
.52602 .3452 m .52608 .34514 L .52625 .34503 L F
.52619 .34552 m .52596 .34512 L .52596 .34512 L F
.52597 .34535 m .52602 .3452 L .52625 .34503 L F
.52596 .34512 m .52596 .34512 L .52601 .34521 L F
.52557 .34548 m .52548 .34551 L .52603 .34515 L F
.52603 .34517 m .52603 .34515 L .5264 .34491 L F
.52557 .34548 m .52603 .34515 L .52603 .34517 L F
.52604 .34555 m .5259 .3452 L .52604 .34555 L F
.52604 .34555 m .52609 .34557 L .52596 .34527 L F
.52636 .34638 m .52604 .34555 L .52604 .34555 L F
.52636 .34638 m .52656 .34668 L .52609 .34557 L F
.52636 .34638 m .52609 .34557 L .52604 .34555 L F
.52636 .34638 m .52604 .34555 L .52601 .34554 L F
.52588 .3454 m .52636 .34638 L .52592 .34534 L F
.52598 .34535 m .52669 .34676 L .52592 .34548 L F
.52452 .3461 m .52639 .3452 L .52423 .34612 L F
.52583 .34551 m .52636 .34516 L .52637 .34518 L F
.52598 .34543 m .52598 .34542 L .52588 .34547 L F
.52598 .34535 m .52592 .34548 L .52596 .34535 L F
.52592 .34548 m .52592 .34548 L .52592 .34548 L F
.52592 .34548 m .52592 .34548 L .52596 .34535 L F
.52493 .34594 m .5249 .34602 L .52583 .34547 L F
.52591 .34551 m .52588 .3454 L .52587 .34542 L F
.52587 .34543 m .52591 .34551 L .52587 .34542 L F
.52583 .34551 m .52585 .34544 L .52688 .34482 L F
.52595 .34538 m .52585 .34544 L .52596 .34535 L F
.5259 .3452 m .5259 .3452 L .52604 .34555 L F
.52604 .34555 m .5259 .3452 L .5259 .3452 L F
.52585 .34544 m .52602 .34518 L .52596 .34535 L F
.52596 .34535 m .52592 .34548 L .5258 .34529 L F
.52591 .34551 m .52636 .34638 L .52594 .34552 L F
.52587 .34547 m .52669 .34676 L .52636 .34665 L F
.5258 .34529 m .52591 .34548 L .52587 .34547 L F
.52591 .34548 m .52669 .34676 L .52587 .34547 L F
.52596 .34535 m .52596 .34535 L .52597 .34535 L F
.52596 .34535 m .52602 .3452 L .52597 .34535 L F
.52593 .34515 m .52605 .34503 L .52593 .34468 L F
.52612 .34514 m .52601 .3452 L .52634 .34514 L F
.52596 .34512 m .52597 .34514 L .52597 .34514 L F
.52597 .34514 m .52601 .34521 L .52597 .34514 L F
.52597 .34514 m .52601 .34521 L .52601 .34521 L F
.52604 .34513 m .52601 .34521 L .52571 .34468 L F
.52595 .34515 m .52601 .3452 L .52612 .34514 L F
.52609 .34539 m .52593 .34516 L .52595 .34514 L F
.52595 .34515 m .5259 .34522 L .52601 .3452 L F
.52626 .34504 m .52654 .34492 L .52647 .34492 L F
.52627 .34505 m .52654 .34492 L .52626 .34504 L F
.52687 .34503 m .52666 .34492 L .52687 .345 L F
.52666 .34492 m .52599 .34453 L .52671 .34492 L F
.52631 .3451 m .52634 .34514 L .52697 .34502 L F
.52661 .34492 m .52729 .34571 L .52666 .34493 L F
.52638 .34519 m .52686 .34489 L .52686 .34489 L F
.52638 .34519 m .52686 .34489 L .52638 .34519 L F
.52884 .34425 m .52737 .34463 L .5272 .3446 L F
.52686 .34492 m .52686 .34491 L .52853 .34389 L F
.52771 .34484 m .52864 .34453 L .52854 .34462 L F
.52766 .34481 m .52864 .34453 L .52771 .34484 L F
.52749 .3448 m .52749 .3448 L .52775 .34474 L F
.52656 .3449 m .52836 .34476 L .52836 .34465 L F
.52686 .34489 m .52686 .34489 L .52696 .34483 L F
.52684 .34505 m .52683 .34505 L .52566 .34526 L F
.52589 .34523 m .52669 .34508 L .5267 .34508 L F
.52585 .34552 m .52696 .34483 L .52698 .34483 L F
.52638 .34519 m .52771 .34442 L .52635 .34516 L F
.52771 .34442 m .52786 .34432 L .5277 .34442 L F
.52696 .34458 m .53104 .34266 L .53088 .3427 L F
.52865 .34379 m .52924 .34341 L .52926 .34344 L F
.52861 .34378 m .52924 .34341 L .52865 .34379 L F
.52696 .34458 m .53219 .34207 L .53183 .34215 L F
.52849 .34438 m .52845 .34437 L .52884 .34427 L F
.52884 .34428 m .52884 .34427 L .52905 .34421 L F
.52877 .34444 m .52851 .34438 L .52905 .34421 L F
.52905 .34421 m .52884 .34426 L .52884 .34425 L F
.52884 .34426 m .52737 .34463 L .52884 .34425 L F
.52968 .34407 m .52724 .34459 L .53001 .34416 L F
.54138 .3374 m .54061 .33676 L p .52704 .34431 L F P
0 g
s
.52698 .34483 m .52696 .34483 L .53176 .34192 L .672 .728 .891 r
F
.53176 .34192 m .53176 .34192 L .5332 .34104 L F
.52698 .34483 m .53176 .34192 L .53176 .34192 L F
.52703 .34502 m .53093 .34426 L .52703 .34502 L F
.52836 .34465 m .52836 .34476 L .53066 .34434 L F
.52862 .34471 m .53093 .34426 L .52862 .34471 L F
.52862 .34471 m .52862 .34471 L .52691 .34504 L F
.52709 .34501 m .54014 .34261 L .5271 .345 L F
.52691 .34504 m .52862 .34471 L .52691 .34504 L F
.5271 .345 m .54014 .34261 L .5271 .345 L F
.52834 .34483 m .52834 .34482 L .53131 .34426 L F
.52702 .34504 m .52703 .34502 L .53092 .34427 L F
.52941 .34463 m .52836 .34483 L p .52943 .34462 L F P
0 g
s
.52836 .34483 m .52639 .3452 L p .52835 .34483 L .672 .728 .891 r
F P
0 g
s
.52836 .34483 m .52835 .34483 L .52943 .34462 L .672 .728 .891 r
F
.52376 .34342 m .52378 .34343 L .52522 .34427 L F
.52771 .34442 m .5277 .34442 L .52635 .34516 L F
.52612 .3454 m .52611 .3454 L .52596 .34512 L F
.52608 .34538 m .52593 .34516 L .52609 .34539 L F
.52596 .34512 m .52612 .3454 L .52612 .3454 L F
.52606 .34531 m .52601 .34533 L .5263 .34509 L F
.52595 .34538 m .52596 .34535 L .5263 .34509 L F
.5259 .34521 m .52597 .34533 L .52584 .3453 L F
.52517 .34535 m .52452 .34585 L .52388 .34607 L F
.52467 .34551 m .52584 .3453 L .52462 .34548 L F
.5265 .34609 m .52595 .34514 L .52596 .34512 L F
.52655 .34617 m .5265 .34609 L .5265 .34609 L F
.5265 .34609 m .52595 .34514 L .5265 .34609 L F
.52633 .34513 m .52635 .34516 L .52677 .34492 L F
.52636 .34516 m .52688 .34482 L .52637 .34518 L F
.52635 .34515 m .52639 .3452 L .52669 .34508 L F
.52581 .34528 m .52676 .34507 L .52662 .34512 L F
.52569 .34427 m .52528 .34279 L .52562 .34437 L F
.52483 .34262 m .52538 .34322 L .52071 .33298 L F
.52578 .3439 m .52559 .34379 L .52409 .34115 L F
.52502 .34279 m .52585 .34375 L .52538 .34394 L F
.52576 .34418 m .52539 .34245 L .52528 .34279 L F
.52587 .34401 m .52539 .34245 L .52576 .34418 L F
.52534 .34269 m .52588 .34379 L .52502 .34279 L F
.52593 .34393 m .52539 .34245 L p .52587 .34401 L F P
0 g
s
.52441 .34094 m .52364 .33928 L p .52438 .34095 L .672 .728 .891 r
F P
0 g
s
.52364 .33928 m .52071 .33298 L p .52356 .33922 L .672 .728 .891 r
F P
0 g
s
.52071 .33298 m .52482 .34183 L p .52409 .34115 L .672 .728 .891 r
F P
0 g
s
.5252 .34306 m .52528 .34279 L .52188 .33276 L .672 .728 .891 r
F
.52482 .34183 m .52578 .3439 L p .52409 .34115 L F P
0 g
s
.52506 .3435 m .5252 .34306 L .52188 .33276 L .672 .728 .891 r
F
.5247 .34054 m .52588 .34379 L p .52436 .34069 L F P
0 g
s
.52436 .34069 m .52534 .34269 L .52502 .34279 L .672 .728 .891 r
F
.52588 .34379 m .52593 .34393 L p .52584 .34389 L F P
0 g
s
.526 .34374 m .52307 .33259 L p .52579 .34419 L .672 .728 .891 r
F P
0 g
s
.52541 .34338 m .52544 .34315 L .52539 .34327 L .672 .728 .891 r
F
.52574 .34439 m .52573 .34438 L .52599 .34452 L F
.52551 .34427 m .52599 .34454 L .52599 .34454 L F
.52577 .34424 m .52571 .34421 L .52572 .34419 L F
.52577 .34424 m .52572 .34419 L .52576 .3441 L F
.52551 .34427 m .52599 .34453 L .52599 .34454 L F
.52557 .34429 m .52567 .3443 L .52614 .3444 L F
.52577 .34461 m .52571 .34436 L .52568 .34457 L F
.52599 .34451 m .52572 .34437 L .526 .34437 L F
.52572 .34437 m .52557 .34429 L .52568 .34431 L F
.52572 .34437 m .52568 .34431 L .526 .34437 L F
.526 .34469 m .52587 .34401 L .52592 .34462 L F
.52598 .34469 m .52592 .34462 L .52593 .34468 L F
.52649 .34491 m .52653 .34498 L .52661 .34492 L F
.52634 .34514 m .52652 .34492 L .52659 .34492 L F
.52665 .34492 m .52657 .34492 L .52628 .34507 L F
.52606 .34509 m .52608 .34503 L .5269 .34452 L F
.5261 .34456 m .52625 .34489 L .52646 .34491 L F
.52682 .34494 m .52681 .34494 L .52686 .34491 L F
.52687 .34495 m .52672 .34492 L .52682 .34492 L F
.52869 .3445 m .52781 .34472 L .52851 .34438 L F
.52869 .3445 m .52851 .34438 L .52877 .34444 L F
.52656 .3449 m .53066 .34434 L .53034 .34425 L F
.5274 .34463 m .52775 .34469 L .53034 .34425 L F
.5295 .34454 m .52689 .34504 L .5287 .3444 L F
.52689 .34504 m .5268 .34506 L .52687 .34503 L F
.52687 .34503 m .52687 .34504 L .52687 .34503 L F
.52687 .34503 m .52687 .34503 L .52687 .34503 L F
.52689 .34504 m .52687 .34503 L .5287 .3444 L F
.5269 .34502 m .52701 .34494 L .52698 .345 L F
.5269 .345 m .52697 .34502 L .52732 .34484 L F
.52701 .34506 m .52687 .345 L .52687 .34495 L F
.52841 .34481 m .52834 .34482 L .52846 .34476 L F
.52834 .34482 m .52643 .34518 L .52823 .34481 L F
.52834 .34482 m .52823 .34481 L .52846 .34476 L F
.52639 .3452 m .5277 .34439 L .52771 .3444 L F
.52634 .34514 m .5263 .34509 L .52652 .34492 L F
.52596 .3453 m .52667 .34492 L .52665 .34492 L F
.52593 .34516 m .5256 .3446 L .52564 .34461 L F
.52547 .34449 m .5259 .34521 L .5258 .34529 L F
.524 .34558 m .52585 .34529 L .52589 .34523 L F
.52298 .34716 m .5259 .34519 L .52589 .34524 L F
.5259 .34521 m .52584 .3453 L .5258 .34529 L F
.52707 .34511 m .52697 .34505 L .52701 .34506 L F
.52697 .34505 m .52687 .345 L .52701 .34506 L F
.52687 .345 m .52672 .34492 L .52687 .34495 L F
.52571 .34436 m .52569 .34427 L .52569 .34433 L F
.52571 .34436 m .52569 .34433 L .52568 .34457 L F
.52505 .34418 m .52551 .34427 L .52575 .34441 L F
.52587 .34456 m .52575 .34441 L .52666 .34492 L F
.52505 .34418 m .52575 .34441 L .52587 .34456 L F
.52572 .34436 m .52586 .34454 L .52568 .34424 L F
.52586 .34454 m .52589 .34459 L .52568 .34424 L F
.52568 .34424 m .52589 .34459 L .52528 .34279 L F
.52547 .3433 m .52544 .34315 L .52541 .34338 L F
.52539 .34327 m .52507 .34113 L .52498 .34141 L F
.52544 .34315 m .52507 .34113 L .52539 .34327 L F
.52547 .34329 m .52555 .34317 L .52507 .34113 L F
.52547 .3433 m .52547 .34329 L .52507 .34113 L F
.52498 .34141 m .52507 .34113 L .52307 .33259 L F
.52307 .33259 m .52606 .34395 L p .52544 .34364 L F P
0 g
s
.52592 .34548 m .52591 .34548 L .5258 .34529 L .672 .728 .891 r
F
.52498 .34585 m .52609 .34532 L .5256 .34551 L F
.52073 .34822 m .52493 .34594 L .52498 .34585 L F
.52493 .34594 m .52609 .34532 L .52498 .34585 L F
.52592 .34538 m .52595 .34539 L .52593 .34536 L F
.52596 .34531 m .52598 .34535 L .52598 .34529 L F
.52593 .34537 m .52598 .34535 L .52596 .34531 L F
.50755 .3454 m .50756 .34458 L p .51971 .34472 L F P
0 g
s
.52545 .34517 m .52595 .34515 L .52598 .34509 L .672 .728 .891 r
F
.52285 .34552 m .52552 .3452 L .52545 .34517 L F
.52552 .3452 m .52595 .34515 L .52545 .34517 L F
.52605 .34558 m .52601 .34542 L .526 .34556 L F
.5259 .34542 m .5259 .34543 L .52609 .34532 L F
.52585 .34492 m .52585 .34493 L .52568 .34463 L F
.52596 .34512 m .52585 .34493 L .52585 .34492 L F
.52596 .34512 m .52596 .34512 L .52585 .34493 L F
.52596 .34512 m .52568 .34463 L .52596 .34512 L F
.5256 .34543 m .526 .34522 L .52557 .34543 L F
.52585 .34529 m .52639 .3452 L .52589 .34523 L F
.52582 .3453 m .52579 .34529 L .52662 .34512 L F
.52597 .34528 m .52593 .34515 L .52595 .34533 L F
.52593 .34515 m .52569 .34427 L .52591 .34518 L F
.52566 .34526 m .5271 .345 L .5271 .345 L F
.52639 .3452 m .52638 .34519 L .52686 .3449 L F
.52639 .3452 m .52686 .3449 L .52686 .34491 L F
.52595 .34515 m .52634 .34514 L .52631 .3451 L F
.52629 .3451 m .5262 .34505 L .52606 .34498 L F
.52585 .34524 m .52622 .345 L .52631 .3451 L F
.526 .34522 m .52657 .34492 L .52602 .3452 L F
.52767 .34421 m .52634 .34514 L .52718 .34441 L F
.52831 .34396 m .52769 .34433 L .52767 .34421 L F
.52769 .34433 m .52634 .34514 L .52767 .34421 L F
.52616 .34491 m .52626 .34504 L .52647 .34492 L F
.52622 .345 m .5264 .34488 L .52631 .3451 L F
.52602 .3452 m .52654 .34492 L .52603 .34517 L F
.52595 .34488 m .52687 .34545 L .52687 .34548 L F
.52593 .34515 m .52593 .34468 L .5259 .34468 L F
.52589 .34484 m .52595 .34488 L .52595 .34488 L F
.52657 .34492 m .52655 .34492 L .52602 .3452 L F
.52616 .34491 m .5259 .34459 L .52658 .34492 L F
.5262 .34496 m .52621 .34472 L .52613 .34471 L F
.52653 .34628 m .52592 .34518 L .52593 .34516 L F
.52578 .34532 m .52639 .3452 L p .52577 .34531 L F P
0 g
s
.52608 .34526 m .52584 .3453 L p .5261 .34525 L .672 .728 .891 r
F P
0 g
s
.52584 .3453 m .52639 .3452 L .52585 .34529 L .672 .728 .891 r
F
.52608 .34526 m .5261 .34525 L .52638 .34519 L F
.52639 .3452 m .52608 .34526 L p .52638 .34519 L F P
0 g
s
.52598 .34529 m .52609 .34532 L .52635 .34516 L .672 .728 .891 r
F
.52643 .34518 m .52582 .3453 L .52662 .34512 L F
.52636 .34558 m .52627 .34505 L .5262 .34496 L F
.52642 .34491 m .52698 .34452 L .52643 .34491 L F
.52642 .34491 m .5264 .34491 L .52698 .34452 L F
.52616 .34491 m .52647 .34492 L .52687 .34468 L F
.52696 .34483 m .52688 .34482 L .5363 .33916 L F
.52667 .34492 m .52677 .34492 L .52803 .34417 L F
.52863 .34441 m .52617 .34493 L .52616 .34491 L F
.52623 .34477 m .52621 .34472 L p .52622 .34479 L F P
0 g
s
.52657 .34492 m .52751 .34441 L .52655 .34492 L .672 .728 .891 r
F
.52667 .34492 m .52803 .34417 L .52665 .34492 L F
.52698 .34483 m .5332 .34104 L .5332 .34104 L F
.52698 .34483 m .53531 .33976 L .53531 .33976 L F
.52682 .34494 m .52615 .3444 L .52666 .34493 L F
.52615 .3444 m .52615 .3444 L .52615 .3444 L F
.52615 .3444 m .52615 .3444 L .52666 .34493 L F
.52622 .345 m .52617 .34493 L .5264 .34488 L F
.52682 .34494 m .52639 .3452 L p .52681 .34494 L F P
0 g
s
.52589 .34523 m .52669 .34508 L .52589 .34523 L .672 .728 .891 r
F
.52589 .34523 m .52634 .34514 L .52589 .34522 L F
.52634 .34514 m .52709 .34501 L .52634 .34514 L F
.52634 .34514 m .52634 .34514 L .52566 .34526 L F
.5268 .34506 m .52585 .34524 L .52666 .345 L F
.52635 .34515 m .5268 .34506 L .52679 .34506 L F
.52682 .34493 m .52682 .34493 L .52638 .34519 L F
.52638 .34519 m .52638 .34519 L .52577 .34554 L F
.52682 .34493 m .52638 .34519 L .52638 .34519 L F
.52634 .34515 m .5268 .34506 L .52635 .34515 L F
.52598 .34529 m .52677 .34492 L .52667 .34492 L F
.52678 .34506 m .52681 .34506 L .52678 .34506 L F
.52662 .34512 m .52693 .34505 L .52697 .34505 L F
.52649 .34501 m .52665 .34492 L .52644 .34501 L F
.52649 .34501 m .52644 .34501 L .52628 .34507 L F
.52631 .34511 m .52649 .34501 L .52628 .34507 L F
.52681 .34506 m .52681 .34506 L .52573 .34527 L F
.52687 .34503 m .52697 .34505 L .52688 .34504 L F
.52669 .34508 m .52699 .34503 L .5267 .34508 L F
.52703 .34502 m .52703 .34502 L .52573 .34527 L F
.52635 .34515 m .52635 .34515 L .52676 .34507 L F
.52676 .34507 m .52676 .34507 L .52703 .34502 L F
.52582 .34525 m .52676 .34507 L .52676 .34507 L F
.52573 .34527 m .52703 .34502 L .52703 .34502 L F
.52635 .34515 m .52691 .34504 L .52691 .34504 L F
.52573 .34527 m .52635 .34515 L .52635 .34515 L F
.52635 .34515 m .52691 .34504 L .52635 .34515 L F
.52495 .34416 m .52518 .34427 L .52518 .34431 L F
.52609 .34483 m .52605 .34478 L .5261 .34498 L F
.52617 .34493 m .52595 .34488 L .52616 .34491 L F
.52602 .34485 m .52323 .34544 L .52613 .34488 L F
.52323 .34544 m .52285 .34552 L .52323 .34545 L F
.52323 .34544 m .52323 .34545 L .52613 .34488 L F
.52616 .34492 m .52615 .34491 L .5261 .34498 L F
.52495 .34416 m .52621 .34498 L .52626 .34505 L F
.52966 .35765 m .52848 .35777 L p .52624 .34737 L F P
0 g
s
.52616 .34491 m .52658 .34492 L .52681 .34503 L .672 .728 .891 r
F
.52631 .3451 m .5264 .34488 L .52667 .345 L F
.52621 .34498 m .52616 .34492 L .52687 .34505 L F
.5261 .34473 m .52593 .34393 L .52587 .34401 L F
.52597 .34533 m .52596 .34535 L .5258 .34529 L F
.52582 .34533 m .52592 .34538 L .52587 .34522 L F
.52581 .34528 m .52587 .34522 L .5257 .34465 L F
.5245 .34556 m .52578 .34532 L p .52451 .34554 L F P
0 g
s
.52448 .34555 m .52445 .34555 L .52472 .3455 L .672 .728 .891 r
F
.52584 .3453 m .52585 .34529 L .52462 .34548 L F
.5247 .34551 m .52472 .3455 L .52662 .34512 L F
.52448 .34555 m .52472 .3455 L .5247 .34551 L F
.52572 .34434 m .52562 .34346 L .52559 .34343 L F
.52599 .34454 m .52687 .34503 L .52687 .34503 L F
.52686 .34492 m .52682 .34494 L p .52686 .34491 L F P
0 g
s
.52639 .3452 m .52771 .34442 L p .52638 .34519 L .672 .728 .891 r
F P
0 g
s
.52686 .34491 m .52686 .3449 L .5277 .34439 L .672 .728 .891 r
F
.52666 .34492 m .52671 .34492 L .52687 .345 L F
.52682 .34492 m .52686 .34494 L .52686 .34494 L F
.52682 .34493 m .52786 .34432 L .52682 .34493 L F
.52682 .34492 m .52682 .34492 L .52686 .34494 L F
.52687 .34495 m .52682 .34492 L .52682 .34492 L F
.52667 .345 m .5264 .34488 L .52872 .3444 L F
.52672 .34492 m .52557 .34429 L .52682 .34492 L F
.52645 .34487 m .52661 .34493 L .52707 .34488 L F
.5268 .34506 m .5276 .34472 L .52767 .34476 L F
.52645 .34487 m .52707 .34488 L .52794 .34479 L F
.52762 .34441 m .52786 .34432 L .52789 .34425 L F
.52635 .34516 m .5277 .34442 L .52762 .34441 L F
.5277 .34442 m .52786 .34432 L .52762 .34441 L F
.52568 .34465 m .5257 .34465 L .52563 .3444 L F
.5259 .34468 m .52593 .34468 L .52589 .34459 L F
.52593 .34515 m .52589 .34459 L .52572 .34436 L F
.5261 .34491 m .52505 .34418 L .5259 .34459 L F
.52596 .34489 m .52589 .34484 L p .52596 .34489 L F P
0 g
s
.52582 .34473 m .52579 .34469 L .52621 .34498 L .672 .728 .891 r
F
.52552 .34462 m .52582 .34533 L .52566 .34457 L F
.52557 .34453 m .52566 .34457 L .52563 .3444 L F
.52552 .34462 m .52566 .34457 L .52557 .34453 L F
.52592 .34538 m .52593 .34536 L .52563 .3444 L F
.52395 .34563 m .52604 .34504 L .52604 .34504 L F
.52395 .34563 m .52604 .34504 L .52395 .34563 L F
.52547 .34541 m .5254 .34539 L .52609 .34483 L F
.52493 .34535 m .52494 .34534 L .52604 .34504 L F
.52285 .34552 m .5259 .34522 L .52595 .34515 L F
.52544 .34516 m .52598 .34509 L .52531 .34511 L F
.52565 .34527 m .52567 .34527 L .52566 .34526 L F
.52567 .34527 m .52566 .34526 L .52566 .34526 L F
.52585 .34524 m .52475 .34545 L .52614 .34494 L F
.52285 .34552 m .52234 .34587 L .5259 .34522 L F
.52475 .34545 m .52369 .34565 L .52488 .34531 L F
.52475 .34545 m .52488 .34531 L .52614 .34494 L F
.52518 .34425 m .52666 .34492 L .52658 .34492 L F
.52505 .34418 m .52518 .34425 L .52518 .34425 L F
.52518 .34425 m .52666 .34492 L .52518 .34425 L F
.52599 .34451 m .526 .34437 L .52614 .3444 L F
.52608 .34453 m .52593 .34393 L .52602 .34436 L F
.52682 .34492 m .52599 .34451 L .52614 .3444 L F
.52608 .34453 m .52602 .34436 L .5261 .34473 L F
.52614 .34475 m .52608 .34453 L .5261 .34473 L F
.52626 .34472 m .52609 .34483 L .52623 .34478 L F
.52619 .34479 m .52616 .3448 L .5262 .34476 L F
.526 .34469 m .52592 .34462 L .52598 .34469 L F
.52599 .34453 m .52574 .34439 L .52599 .34452 L F
.52574 .34439 m .52557 .34429 L .52573 .34438 L F
.52609 .3447 m .52603 .3447 L .52605 .34478 L F
.52609 .3447 m .52587 .34401 L .52603 .3447 L F
.52585 .34524 m .52617 .34493 L .52622 .345 L F
.52611 .34502 m .52587 .34401 L .52607 .34509 L F
.52584 .34389 m .52619 .34479 L .52599 .34471 L F
.5262 .34496 m .52614 .34475 L .52615 .34491 L F
.52611 .34486 m .52661 .34493 L .52639 .34485 L F
.52592 .34518 m .5256 .3446 L .52593 .34516 L F
.52595 .34514 m .52593 .34516 L .52564 .34461 L F
.52615 .34493 m .52499 .34518 L .5259 .34487 L F
.52595 .34488 m .52596 .34488 L .52616 .34491 L F
.52601 .34491 m .526 .34491 L .52595 .34488 L F
.52596 .34488 m .52607 .34491 L .52601 .34491 L F
.52596 .34488 m .52596 .34484 L .52607 .34491 L F
.52616 .34491 m .52596 .34488 L .52609 .34483 L F
.52596 .34488 m .5259 .34487 L .52609 .34483 L F
.52609 .34483 m .52596 .34491 L .52616 .34491 L F
.52609 .34483 m .52608 .3449 L .52599 .34489 L F
.5262 .34476 m .52616 .3448 L .52609 .34483 L F
.52623 .34478 m .52609 .34483 L .52616 .34491 L F
.5261 .34491 m .5259 .34459 L .52616 .34491 L F
.52609 .34483 m .52603 .34485 L .5261 .34485 L F
.52662 .34482 m .52616 .34491 L .52623 .34484 L F
.52551 .34427 m .52687 .34504 L .52687 .34504 L F
.52626 .34472 m .52616 .34491 L .52735 .3444 L F
.52662 .34482 m .52623 .34484 L .52627 .3448 L F
.52638 .34519 m .52771 .34442 L .52771 .34442 L F
.52872 .3444 m .52662 .34482 L .52627 .3448 L F
.52643 .34491 m .52698 .34452 L .52698 .34454 L F
.52609 .34483 m .5261 .34485 L .52749 .34478 L F
.52627 .3448 m .52616 .34491 L .52609 .34483 L F
.52615 .34491 m .52609 .3447 L .52609 .34483 L F
.52616 .3448 m .52611 .34486 L .52609 .34483 L F
.52611 .34486 m .52608 .3449 L .52609 .34483 L F
.52612 .3454 m .52568 .34463 L .52568 .34463 L F
.52591 .34518 m .52577 .34461 L .52588 .3452 L F
.50797 .34782 m .50775 .34702 L p .52349 .34513 L F P
0 g
s
.52595 .34488 m .52601 .34491 L .52595 .34488 L .672 .728 .891 r
F
.52587 .34487 m .52614 .34489 L .52611 .34486 L F
.52623 .34484 m .5262 .34487 L .5262 .34496 L F
.52614 .34489 m .52661 .34493 L .52611 .34486 L F
.52665 .34492 m .5288 .34372 L .52657 .34492 L F
.52725 .34464 m .52609 .34483 L .52749 .34478 L F
.52618 .3448 m .52612 .34487 L .52616 .3448 L F
.51363 .3476 m .52525 .34536 L .52525 .34536 L F
.52525 .34536 m .52573 .34527 L .52525 .34536 L F
.52525 .34536 m .52573 .34527 L .52573 .34527 L F
.5239 .34571 m .52493 .34535 L .5249 .3454 L F
.52234 .34588 m .52589 .34523 L .52589 .34523 L F
.52234 .34588 m .52589 .34523 L .52234 .34588 L F
.5209 .34615 m .52589 .34523 L .5209 .34614 L F
.52491 .34592 m .52494 .34587 L .52548 .34551 L F
.52491 .34592 m .52548 .34551 L .52557 .34548 L F
.52298 .34716 m .5251 .34564 L .52528 .34558 L F
.52008 .34823 m .52491 .34597 L .52493 .34591 L F
.52073 .34822 m .5256 .34551 L .52513 .34569 L F
.52419 .34638 m .52417 .34631 L .52521 .34561 L F
.5257 .34545 m .52575 .34542 L .52575 .34542 L F
.52575 .34542 m .52596 .34531 L .52575 .34542 L F
.52575 .34542 m .52596 .34531 L .52596 .3453 L F
.52405 .34507 m .5237 .34531 L .52349 .34513 L F
.51939 .34642 m .52565 .34527 L .52566 .34526 L F
.51354 .3475 m .51939 .34642 L .51939 .34642 L F
.51939 .34642 m .52565 .34527 L .51939 .34642 L F
.52478 .34629 m .51312 .35415 L p .52459 .34622 L F P
0 g
s
.52425 .34664 m .5259 .34553 L p .5237 .34684 L .672 .728 .891 r
F P
0 g
s
.52343 .347 m .52367 .34689 L .5237 .34684 L .672 .728 .891 r
F
.52367 .34689 m .52425 .34664 L .5237 .34684 L F
.52615 .34491 m .52614 .34475 L .5261 .34473 L F
.52612 .34487 m .52611 .34486 L .52616 .3448 L F
.52587 .34487 m .52512 .34503 L .52516 .34498 L F
.52495 .34416 m .52505 .34418 L .52518 .34427 L F
.52479 .34419 m .52145 .34207 L p .52518 .34426 L F P
0 g
s
.52352 .34313 m .51344 .33587 L p .52501 .34352 L .672 .728 .891 r
F P
0 g
s
.52346 .34264 m .52457 .34355 L .52465 .34357 L .672 .728 .891 r
F
.52592 .34462 m .52587 .34401 L .52589 .34459 L F
.52569 .34433 m .52569 .34427 L .52567 .3443 L F
.52584 .34389 m .52599 .34471 L .52567 .34431 L F
.54061 .33676 m .53978 .33616 L p .52679 .34439 L F P
0 g
s
.52905 .34301 m .52759 .34398 L .52877 .34313 L .672 .728 .891 r
F
.52759 .34398 m .52758 .34396 L .52877 .34313 L F
.52771 .3444 m .5277 .34439 L .5363 .33916 L F
.5332 .34104 m .5332 .34104 L .53531 .33976 L F
.53531 .33976 m .53531 .33976 L .5363 .33916 L F
.53714 .33882 m .52854 .34392 L p .5363 .33916 L F P
0 g
s
.52854 .34392 m .52853 .34389 L .5363 .33916 L .672 .728 .891 r
F
.52945 .34328 m .52831 .34396 L .52872 .34337 L F
.5363 .33916 m .52945 .34328 L .52872 .34337 L F
.54061 .33676 m .53714 .33882 L p .5363 .33916 L F P
0 g
s
.52878 .34332 m .52879 .34357 L .54061 .33676 L .672 .728 .891 r
F
.52877 .34313 m .52767 .34389 L .52757 .34389 L F
.53114 .34182 m .52724 .34437 L .53065 .34194 L F
.52626 .34472 m .52735 .3444 L .52699 .34439 L F
.52713 .34443 m .5269 .34452 L .52872 .34337 L F
.52626 .34472 m .52879 .34357 L .52878 .34332 L F
.52698 .34454 m .52698 .34452 L .52872 .34337 L F
.52724 .34437 m .52677 .34456 L .53065 .34194 L F
.52677 .34456 m .52665 .34461 L .53065 .34194 L F
.53065 .34194 m .52905 .34301 L .52877 .34313 L F
.53978 .33616 m .53114 .34182 L .53065 .34194 L F
.5275 .3438 m .5283 .34377 L .53978 .33616 L F
.52789 .34352 m .5271 .34427 L .52789 .34352 L F
.52639 .34485 m .52645 .34487 L .52794 .34479 L F
.5268 .34506 m .52666 .345 L .52686 .34503 L F
.52658 .34492 m .52666 .34492 L .52706 .34514 L F
.52619 .34477 m .52619 .34479 L .52584 .34389 L F
.52618 .3448 m .52616 .3448 L .52619 .34479 L F
.52589 .34484 m .52596 .34484 L .52596 .34488 L F
.52609 .34483 m .5259 .34487 L .52587 .34487 L F
.52595 .34485 m .52598 .34486 L .526 .34486 L F
.52594 .34488 m .52599 .34491 L p .52599 .34471 L F P
0 g
s
.52619 .34479 m .5262 .34483 L .52559 .34454 L .672 .728 .891 r
F
.52617 .34493 m .52614 .34494 L .52615 .34493 L F
.52584 .34524 m .52678 .34506 L .52584 .34525 L F
.52616 .34491 m .52603 .34517 L .52626 .34504 L F
.52616 .34492 m .5261 .34498 L .52611 .34502 L F
.52542 .34533 m .52634 .34515 L .52635 .34515 L F
.52596 .34531 m .52667 .34492 L .52596 .3453 L F
.52597 .34544 m .52638 .34519 L .52638 .34519 L F
.52589 .34548 m .52639 .3452 L .52632 .34523 L F
.52575 .34528 m .52573 .34527 L .52676 .34507 L F
.52616 .34492 m .52611 .34502 L .52625 .34563 L F
.52616 .34492 m .52611 .34502 L .52616 .34492 L F
.5257 .34545 m .52596 .3453 L .5256 .34543 L F
.52583 .34526 m .52676 .34507 L .52581 .34528 L F
.52583 .3453 m .52582 .3453 L .52638 .34519 L F
.52584 .3453 m .52583 .3453 L .52638 .34519 L F
.52596 .3453 m .52631 .34511 L .52598 .34526 L F
.526 .34556 m .52591 .34518 L .52588 .3452 L F
.52596 .3453 m .52598 .34526 L .5256 .34543 L F
.52598 .34526 m .52607 .34509 L .52605 .34503 L F
.52596 .34526 m .52605 .34503 L .52593 .34515 L F
.52572 .34527 m .52584 .34524 L .52573 .34527 L F
.52584 .34524 m .52584 .34525 L .52573 .34527 L F
.52542 .34533 m .52541 .34532 L .52572 .34527 L F
.52542 .34533 m .52572 .34527 L .52572 .34527 L F
.52573 .34527 m .52573 .34527 L .52582 .34525 L F
.52573 .34527 m .52582 .34525 L .52582 .34525 L F
.52547 .34541 m .52501 .3457 L .5254 .34539 L F
.52597 .34544 m .52595 .34544 L .52686 .34489 L F
.52598 .34543 m .52682 .34493 L .52598 .34542 L F
.52636 .34558 m .5262 .34496 L .52615 .34491 L F
.52631 .3451 m .52631 .3451 L .526 .34491 L F
.52451 .34554 m .52578 .34532 L .52577 .34531 L F
.52582 .3453 m .52448 .34555 L .52579 .34529 L F
.5242 .346 m .52598 .34523 L .5242 .34599 L F
.5245 .34556 m .52582 .3453 L .52583 .3453 L F
.52584 .3453 m .5245 .34556 L p .52583 .3453 L F P
0 g
s
.52616 .34491 m .52516 .34549 L .52603 .34517 L .672 .728 .891 r
F
.52516 .34549 m .52414 .34606 L .52509 .34561 L F
.52516 .34549 m .52509 .34561 L .52603 .34517 L F
.52722 .3448 m .52794 .34479 L .52784 .34477 L F
.52611 .34485 m .52722 .34481 L .52722 .3448 L F
.52495 .34629 m .52495 .34629 L .52595 .34535 L F
.52583 .34471 m .52571 .34468 L .52568 .34463 L F
.52518 .34431 m .52579 .34469 L .52582 .34473 L F
.52518 .34431 m .52518 .34427 L .52579 .34469 L F
.52589 .34484 m .52585 .34477 L .5259 .34482 L F
.52589 .34484 m .52495 .34416 L p .52585 .34477 L F P
0 g
s
.52491 .34414 m .52594 .34488 L p .52544 .34426 L .672 .728 .891 r
F P
0 g
s
.52532 .34434 m .52534 .34434 L .52593 .34468 L .672 .728 .891 r
F
.52601 .34491 m .52631 .3451 L .526 .34491 L F
.52601 .34491 m .52607 .34491 L .52626 .34505 L F
.52572 .34527 m .52572 .34527 L .5268 .34506 L F
.52631 .34511 m .52628 .34507 L .5256 .34543 L F
.5263 .34521 m .52623 .34479 L .5263 .34521 L F
.52601 .34491 m .52626 .34505 L .52631 .3451 L F
.52598 .34529 m .52635 .34516 L .52633 .34513 L F
.52603 .34517 m .52627 .34505 L .52626 .34504 L F
.52639 .3452 m .52585 .34552 L p .52638 .34519 L F P
0 g
s
.50761 .34621 m .50755 .3454 L p .52009 .345 L .672 .728 .891 r
F P
0 g
s
.52678 .34506 m .52678 .34506 L .52573 .34527 L .672 .728 .891 r
F
.52626 .34505 m .52621 .34498 L .52706 .34556 L F
.52744 .34574 m .52729 .34571 L .52886 .34723 L F
.52702 .34555 m .52706 .34556 L .52839 .34648 L F
.52649 .34497 m .52672 .34547 L .52673 .34545 L F
.52626 .34505 m .52706 .34556 L .52702 .34555 L F
.52722 .34481 m .52794 .34479 L .52722 .3448 L F
.52643 .34519 m .52643 .34518 L .527 .34508 L F
.52643 .34519 m .527 .34508 L .527 .34508 L F
.52662 .34512 m .52676 .34507 L .52703 .34502 L F
.52687 .34543 m .52621 .34498 L .52687 .34505 L F
.5282 .34597 m .52701 .34506 L .52811 .34645 L F
.52735 .34535 m .52727 .34527 L .52727 .34526 L F
.52839 .34648 m .52727 .34527 L .52735 .34535 L F
.52839 .34648 m .52696 .3455 L .52727 .34527 L F
.52698 .34508 m .52692 .34521 L .52699 .34509 L F
.52687 .34543 m .52687 .34505 L .52706 .34514 L F
.52706 .34514 m .52706 .34514 L .52727 .34526 L F
.52727 .34526 m .52706 .34514 L .52707 .34511 L F
.52688 .34504 m .52697 .34505 L .52707 .34511 L F
.52706 .3451 m .53032 .34464 L p .52695 .34506 L F P
0 g
s
.53032 .34464 m .53377 .34415 L p .53032 .34461 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .52638 .34519 L .52943 .34462 L .672 .728 .891 r
F
.52695 .34506 m .53032 .34464 L .53032 .34461 L F
.53735 .35547 m .5383 .35498 L p .52787 .34583 L F P
0 g
s
.5383 .35498 m .53026 .34838 L p .52787 .34583 L .672 .728 .891 r
F P
0 g
s
.53114 .34823 m .5282 .34597 L .52886 .34723 L .672 .728 .891 r
F
.53026 .34838 m .52896 .34731 L p .52875 .34677 L F P
0 g
s
.52886 .34723 m .5383 .35498 L p .53114 .34823 L .672 .728 .891 r
F P
0 g
s
.53817 .35365 m .52887 .34699 L .52727 .34526 L .672 .728 .891 r
F
.53921 .35444 m .53802 .35358 L p .53817 .35365 L F P
0 g
s
.53802 .35358 m .52887 .34699 L p .53817 .35365 L .672 .728 .891 r
F P
0 g
s
.50765 .34377 m .50781 .34296 L p .51227 .3434 L .672 .728 .891 r
F P
0 g
s
.52709 .3451 m .52905 .34698 L .52914 .34685 L .672 .728 .891 r
F
.52623 .34479 m .52623 .34477 L .52623 .34478 L F
.52623 .34479 m .52623 .34478 L .52622 .34479 L F
.52623 .34484 m .52621 .34472 L .5262 .34487 L F
.52621 .34472 m .52593 .34393 L p .52613 .34471 L F P
0 g
s
.52624 .34479 m .52621 .34482 L .52584 .34389 L .672 .728 .891 r
F
.52626 .34472 m .52618 .3448 L .5262 .34476 L F
.52589 .34431 m .52561 .34431 L .52646 .34497 L F
.52654 .34499 m .52646 .34497 L .5267 .34516 L F
.52624 .34481 m .52624 .34482 L .52623 .34477 L F
.5263 .34521 m .52624 .34482 L .52624 .34481 L F
.52631 .3451 m .52626 .34505 L .52687 .34545 L F
.5263 .34521 m .52635 .34521 L .52624 .34482 L F
.52625 .34482 m .52625 .34482 L .52622 .34481 L F
.5263 .34521 m .52623 .34479 L .52622 .34479 L F
.52624 .34479 m .52625 .34482 L p .52622 .34481 L F P
0 g
s
.52636 .34474 m .52615 .3449 L .52626 .34472 L .672 .728 .891 r
F
.52582 .34533 m .5257 .34465 L .52568 .34465 L F
.52614 .34494 m .52499 .34518 L .52615 .34493 L F
.52612 .34491 m .52603 .34499 L .52616 .34491 L F
.52596 .34491 m .52603 .34499 L .52612 .34491 L F
.5247 .34551 m .52643 .34518 L .5247 .34551 L F
.5252 .34539 m .52516 .34547 L .52603 .34499 L F
.52596 .34491 m .5252 .34539 L .52603 .34499 L F
.52596 .34491 m .5254 .34544 L .5252 .34539 L F
.52481 .34517 m .52461 .34538 L .52567 .34524 L F
.52639 .3452 m .5276 .3478 L p .5262 .34545 L F P
0 g
s
.52632 .34523 m .52639 .3452 L .52638 .34519 L .672 .728 .891 r
F
.52652 .34557 m .52623 .34477 L p .52646 .34562 L F P
0 g
s
.52637 .34521 m .52635 .34522 L .5262 .34483 L .672 .728 .891 r
F
.5262 .34483 m .5262 .34483 L .52619 .34479 L F
.52637 .34521 m .5262 .34483 L .5262 .34483 L F
.52592 .34538 m .52632 .34655 L .52595 .34539 L F
.52598 .34543 m .52588 .34547 L .52589 .34548 L F
.52592 .34548 m .52592 .34548 L .52591 .34548 L F
.52585 .34552 m .52595 .34544 L .52597 .34544 L F
.52587 .34547 m .52632 .34655 L .52592 .34538 L F
.52653 .34628 m .5265 .34638 L .52598 .34535 L F
.52632 .34655 m .52605 .34558 L .526 .34556 L F
.52587 .34552 m .52647 .34605 L .52602 .34599 L F
.5247 .34551 m .52643 .34518 L .52643 .34519 L F
.52582 .34533 m .52587 .34522 L .52581 .34528 L F
.52593 .34515 m .52591 .34518 L .52595 .34533 L F
.52582 .34525 m .52582 .34525 L .52635 .34515 L F
.526 .34522 m .52602 .3452 L .52557 .34543 L F
.52597 .34528 m .52595 .34533 L .52596 .3454 L F
.52606 .34531 m .52595 .34538 L .52601 .34533 L F
.52617 .34551 m .52611 .34551 L .52593 .34516 L F
.52598 .34535 m .52609 .34532 L .52598 .34529 L F
.52557 .34543 m .52602 .3452 L .52603 .34517 L F
.52369 .34565 m .5239 .34541 L .52499 .34518 L F
.52324 .34546 m .52544 .34516 L .52531 .34511 L F
.52488 .34531 m .52499 .34518 L .52614 .34494 L F
.52369 .34565 m .52499 .34518 L .52488 .34531 L F
.52567 .3444 m .52547 .34329 L .52547 .3433 L F
.52693 .34505 m .52703 .34502 L .52697 .34505 L F
.52697 .34505 m .52703 .34502 L .52702 .34504 L F
.527 .34508 m .527 .34508 L .52834 .34482 L F
.52643 .34519 m .52834 .34482 L .52834 .34483 L F
.5268 .345 m .52695 .34506 L .52835 .34488 L F
.52707 .34508 m .5268 .3449 L .52706 .3451 L F
.52657 .34464 m .52641 .34475 L .52646 .34468 L F
.52644 .34475 m .52665 .34461 L .52648 .34475 L F
.5268 .3449 m .52592 .3443 L .5268 .34493 L F
.52686 .34503 m .52666 .345 L .5276 .34472 L F
.52631 .3451 m .52631 .34511 L .52595 .34488 L F
.52596 .34489 m .52641 .34518 L .52641 .34518 L F
.52639 .3452 m .52596 .34489 L p .52641 .34518 L F P
0 g
s
.52639 .34567 m .52616 .34492 L .52625 .34563 L .672 .728 .891 r
F
.52621 .34498 m .5261 .34491 L .52616 .34492 L F
.52616 .34492 m .52612 .34492 L .52621 .34498 L F
.52612 .34492 m .52599 .34491 L .52621 .34498 L F
.52596 .34489 m .52596 .34489 L .52641 .34518 L F
.52599 .34491 m .52639 .3452 L p .52621 .34498 L F P
0 g
s
.52628 .34502 m .52635 .34522 L .52614 .34503 L .672 .728 .891 r
F
.52644 .34475 m .52612 .34496 L .52641 .34475 L F
.52612 .34496 m .5254 .34544 L .52613 .34494 L F
.52627 .34505 m .52623 .34484 L .5262 .34496 L F
.5262 .34483 m .52628 .34502 L .52611 .34498 L F
.5262 .34483 m .52616 .34491 L .52614 .3449 L F
.52616 .34491 m .52611 .34498 L .52614 .3449 L F
.52599 .34486 m .52599 .34491 L .52616 .34492 L F
.52614 .3449 m .52616 .34492 L .52626 .34492 L F
.52603 .34485 m .52619 .34485 L .52619 .34484 L F
.5262 .34483 m .52614 .3449 L .52618 .34482 L F
.52615 .3449 m .52609 .3449 L .52626 .34472 L F
.52599 .34486 m .52616 .34492 L .52614 .3449 L F
.52641 .34475 m .52616 .34492 L .52638 .34474 L F
.52619 .34552 m .52618 .34552 L .52611 .3454 L F
.52619 .34552 m .52611 .3454 L .52612 .3454 L F
.52617 .34551 m .52608 .34538 L .52609 .34539 L F
.52625 .34563 m .52622 .34552 L .52621 .34551 L F
.52612 .3454 m .52612 .3454 L .52619 .34552 L F
.52619 .34552 m .52596 .34512 L .52619 .34552 L F
.52619 .34552 m .52612 .3454 L .52612 .3454 L F
.52651 .34562 m .52618 .34557 L .526 .34528 L F
.52599 .34489 m .52594 .34505 L .52596 .34491 L F
.52587 .34487 m .52578 .34502 L .52606 .34499 L F
.52613 .34494 m .5254 .34544 L .52614 .34491 L F
.52614 .3449 m .52611 .34498 L .52608 .34498 L F
.52635 .34522 m .52624 .3453 L .52607 .3451 L F
.52611 .34498 m .52611 .34499 L .52594 .34512 L F
.52617 .34493 m .52618 .34494 L .52594 .34512 L F
.52614 .3449 m .52594 .34505 L .52609 .3449 L F
.52614 .3449 m .52594 .34505 L .52614 .3449 L F
.52608 .3449 m .52594 .34505 L .52599 .34489 L F
.52587 .34487 m .52606 .34499 L .52611 .34494 L F
.52612 .34487 m .52594 .34505 L .52611 .34486 L F
.52595 .34488 m .5259 .34487 L .52596 .34488 L F
.52587 .34487 m .52611 .34494 L .52614 .34489 L F
.52616 .34492 m .52613 .34494 L .52615 .34491 L F
.52613 .34494 m .52614 .34491 L .52615 .34491 L F
.52615 .3449 m .52614 .3449 L .52614 .3449 L F
.52611 .34494 m .52621 .34497 L .52614 .3449 L F
.52611 .34494 m .52614 .3449 L .52614 .34489 L F
.52594 .34515 m .5261 .34501 L .52609 .34504 L F
.52611 .345 m .52607 .3451 L .52602 .34504 L F
.52587 .34487 m .52599 .34486 L .52598 .34486 L F
.52589 .34484 m .52591 .34481 L .52596 .34484 L F
.5259 .34482 m .52585 .34477 L .52591 .34481 L F
.52544 .34426 m .52594 .34488 L .52599 .34471 L F
.52599 .3447 m .52599 .34471 L .526 .34471 L F
.52544 .34426 m .52599 .34471 L .52599 .3447 L F
.52609 .34483 m .52595 .34485 L .52603 .34485 L F
.52595 .34485 m .526 .34486 L .52603 .34485 L F
.52602 .34475 m .52608 .34498 L .52559 .34454 L F
.52609 .3447 m .52605 .34478 L .52609 .34483 L F
.52618 .34482 m .52613 .34488 L .52602 .34475 L F
.52598 .34486 m .52611 .34486 L .52611 .34485 L F
.52603 .34485 m .526 .34486 L .52619 .34485 L F
.52599 .34471 m .52599 .34486 L .52626 .34492 L F
.52613 .34488 m .52608 .34498 L .52602 .34475 L F
.52595 .34485 m .52587 .34487 L .52598 .34486 L F
.52608 .34498 m .52602 .34504 L .52559 .34454 L F
.52501 .3457 m .52329 .34678 L .52509 .34553 L F
.5232 .34645 m .52417 .34607 L .52419 .34601 L F
.52452 .34585 m .52329 .34678 L .52388 .34607 L F
.52008 .34823 m .52452 .3461 L .52423 .34612 L F
.519 .34878 m .52152 .34773 L .52008 .34823 L F
.52329 .34678 m .51571 .35153 L .52371 .34616 L F
.52412 .34608 m .52073 .34822 L .52513 .34569 L F
.52479 .34587 m .52541 .34545 L .52478 .3459 L F
.52252 .34589 m .52572 .34527 L .52573 .34527 L F
.52541 .34545 m .52617 .34493 L .52543 .34545 L F
.52596 .34526 m .52598 .34526 L .52605 .34503 L F
.52628 .34502 m .52614 .34503 L .52611 .345 L F
.52628 .34502 m .52611 .345 L .52611 .34498 L F
.52637 .34521 m .5262 .34483 L .52621 .34482 L F
.52622 .34481 m .52639 .3452 L .52621 .34482 L F
.52625 .34482 m .52639 .3452 L p .52622 .34481 L F P
0 g
s
.52615 .34489 m .52621 .34497 L .52661 .34493 L .672 .728 .891 r
F
.52614 .34489 m .52614 .3449 L .52615 .34489 L F
.52626 .34492 m .52616 .34492 L .52687 .34547 L F
.52641 .34518 m .52641 .34518 L .52839 .34648 L F
.52682 .34547 m .52683 .34547 L .5269 .34552 L F
.52677 .34548 m .52685 .34547 L .52839 .34648 L F
.52688 .34543 m .52687 .34547 L .52826 .34655 L F
.52626 .34492 m .52687 .34547 L .52688 .34543 L F
.52635 .34522 m .52607 .3451 L .52611 .345 L F
.52641 .34491 m .52646 .34497 L .52646 .34491 L F
.52598 .34526 m .52612 .34524 L .52607 .34509 L F
.52594 .34515 m .52594 .34512 L .5261 .34501 L F
.52602 .34504 m .52607 .3451 L .52601 .34506 L F
.52607 .3451 m .52651 .34562 L .52606 .34512 L F
.52593 .34524 m .52593 .34516 L .52609 .34505 L F
.52625 .3449 m .52628 .34493 L .52638 .34491 L F
.52605 .34514 m .52609 .34505 L .52629 .3449 L F
.52682 .34492 m .52614 .3444 L .52682 .34492 L F
.52658 .34473 m .52614 .3444 L .52658 .34473 L F
.52658 .34473 m .52658 .34473 L .52682 .34492 L F
.52682 .34492 m .52658 .34473 L .52682 .34492 L F
.52616 .34491 m .52687 .34468 L .52688 .34461 L F
.52634 .3449 m .52629 .3449 L .52677 .34456 L F
.52616 .34492 m .52621 .34498 L .52623 .34497 L F
.52621 .34498 m .52639 .3452 L .52623 .34497 L F
.52639 .3452 m .52634 .34515 L .52621 .34482 L F
.52623 .34497 m .52639 .3452 L .5265 .34518 L F
.52621 .34498 m .52647 .34497 L .52621 .34497 L F
.52605 .34514 m .52629 .3449 L .52634 .3449 L F
.52593 .34524 m .52609 .34505 L .52605 .34514 L F
.52607 .3451 m .52606 .34512 L .52601 .34506 L F
.52604 .34516 m .52592 .3453 L .52593 .34524 L F
.52626 .34504 m .52602 .34523 L .52625 .34503 L F
.52625 .34503 m .52593 .34524 L .52623 .345 L F
.52621 .34551 m .52611 .34502 L .52607 .34509 L F
.52596 .34511 m .5263 .3451 L .526 .34507 L F
.52628 .34493 m .52678 .34534 L .52646 .34497 L F
.5263 .3451 m .52695 .34506 L .52628 .34507 L F
.5263 .3451 m .52628 .34507 L .526 .34507 L F
.52625 .34503 m .52602 .34523 L .52604 .34516 L F
.52657 .34517 m .52628 .34493 L .52628 .34493 L F
.52625 .34503 m .52623 .345 L .52634 .3449 L F
.52638 .34491 m .52634 .3449 L .52677 .34456 L F
.5261 .34491 m .52681 .34503 L .52687 .34505 L F
.52625 .34503 m .52634 .3449 L .52638 .34491 L F
.526 .34471 m .52599 .34471 L .52623 .3449 L F
.52623 .3449 m .52623 .3449 L .52688 .34543 L F
.526 .34471 m .52623 .3449 L .52623 .3449 L F
.52688 .34543 m .52688 .34543 L .52706 .34557 L F
.526 .34471 m .52688 .34543 L .52688 .34543 L F
.52625 .34502 m .5266 .345 L .52621 .34498 L F
.52643 .34491 m .52626 .34504 L .52625 .34503 L F
.52614 .3449 m .52621 .34497 L .52615 .34489 L F
.5266 .345 m .52647 .34497 L .52621 .34498 L F
.52621 .34497 m .52647 .34497 L .5264 .34495 L F
.52649 .34491 m .52627 .34506 L .52643 .34491 L F
.52627 .34506 m .52592 .3453 L .52626 .34504 L F
.52627 .34506 m .52626 .34504 L .52643 .34491 L F
.526 .34507 m .52627 .34505 L .52602 .34504 L F
.52627 .34505 m .5268 .345 L .52625 .34503 L F
.52627 .34505 m .52625 .34503 L .52602 .34504 L F
.52617 .34493 m .52617 .34493 L .52543 .34545 L F
.52475 .34601 m .52476 .34598 L .5262 .34496 L F
.5262 .34497 m .5262 .34496 L .52677 .34456 L F
.52513 .34569 m .5256 .34543 L .52557 .34543 L F
.52475 .34601 m .5262 .34496 L .5262 .34497 L F
.52611 .34673 m .52648 .34719 L .52624 .34737 L F
.52589 .34548 m .52588 .34547 L .52577 .34554 L F
.52579 .34554 m .52598 .34543 L .52577 .34554 L F
.52606 .34512 m .52592 .34515 L .52601 .34506 L F
.52657 .34517 m .52657 .34517 L .52628 .34493 L F
.526 .34507 m .52674 .34507 L .5268 .345 L F
.52603 .34485 m .52722 .3448 L .52722 .34479 L F
.52639 .3452 m .52635 .34516 L .52682 .34478 L F
.52647 .34492 m .52841 .34392 L .52821 .34391 L F
.52682 .34482 m .52682 .34478 L .52762 .34413 L F
.52681 .34506 m .5269 .34504 L .52681 .34506 L F
.5269 .34504 m .52703 .34502 L .5269 .34504 L F
.5269 .34504 m .5269 .34504 L .52681 .34506 L F
.52687 .34503 m .52706 .34514 L .52706 .34514 L F
.5268 .34505 m .52695 .34506 L .52685 .34502 L F
.52706 .3451 m .52675 .34503 L .5267 .34516 L F
.52679 .34506 m .5268 .34506 L .52848 .34473 L F
.52674 .34507 m .52688 .34506 L .5268 .34505 L F
.52688 .34506 m .52695 .34506 L .5268 .34505 L F
.52706 .34511 m .52706 .3451 L .5267 .34516 L F
.52674 .34507 m .52685 .34502 L .5268 .345 L F
.52687 .34504 m .52706 .34514 L .52687 .34503 L F
.52687 .34504 m .52687 .34504 L .52706 .34514 L F
.52706 .3451 m .52679 .34492 L .52675 .34503 L F
.52611 .34486 m .52722 .34481 L .52611 .34485 L F
.52599 .34486 m .52611 .34486 L .52598 .34486 L F
.52647 .34497 m .52835 .34488 L .5264 .34495 L F
.52646 .34491 m .52646 .34497 L .52654 .34499 L F
.52665 .34501 m .5266 .345 L .52602 .34504 L F
.52635 .34516 m .52627 .34506 L .52681 .34469 L F
.52688 .34461 m .52687 .34468 L .52735 .3444 L F
.52682 .34478 m .52681 .34469 L .52762 .34413 L F
.52635 .34516 m .52681 .34469 L .52682 .34478 L F
.52696 .3455 m .52706 .34514 L .52727 .34526 L F
.52709 .3451 m .5267 .34516 L .52789 .34608 L F
.52705 .34535 m .52685 .34524 L .52705 .34534 L F
.52625 .34502 m .52621 .34498 L .52606 .34499 L F
.52742 .34481 m .52794 .34479 L .52743 .34481 L F
.52676 .34585 m .52619 .34485 L p .52676 .34585 L F P
0 g
s
.52542 .34533 m .52848 .34473 L .52848 .34474 L .672 .728 .891 r
F
.5266 .345 m .52835 .34488 L .52647 .34497 L F
.52722 .34479 m .52722 .3448 L .52784 .34477 L F
.52725 .34464 m .52749 .34478 L .52764 .34472 L F
.52719 .34486 m .52721 .34482 L .52805 .34462 L F
.5268 .345 m .52835 .34488 L .52676 .34499 L F
.52638 .34519 m .52706 .3451 L .52637 .34518 L F
.52784 .34477 m .52794 .34479 L .52838 .34474 L F
.5264 .34495 m .52835 .34488 L .52794 .34479 L F
.52567 .34524 m .52696 .34511 L .52695 .34506 L F
.52696 .34511 m .52706 .3451 L .52699 .34508 L F
.52696 .34511 m .52699 .34508 L .52695 .34506 L F
.52481 .34517 m .52567 .34524 L .52547 .34514 L F
.526 .34508 m .526 .34508 L .52465 .34544 L F
.52465 .34544 m .52558 .34519 L .52562 .3452 L F
.52437 .34541 m .52572 .34526 L .52567 .34524 L F
.52465 .34543 m .526 .34508 L .52465 .34544 L F
.52591 .34548 m .52639 .3452 L .52589 .34548 L F
.5259 .34553 m .52627 .34506 L .52635 .34516 L F
.52609 .34557 m .52614 .34551 L .52605 .34547 L F
.52653 .34628 m .52598 .34535 L .52602 .34537 L F
.52632 .34655 m .52612 .34524 L .52596 .34526 L F
.52606 .34538 m .52618 .34557 L .52595 .3454 L F
.52582 .34533 m .52587 .34547 L .52592 .34538 L F
.5257 .34545 m .52593 .34537 L .52596 .34531 L F
.52573 .34545 m .52609 .34532 L .5257 .34545 L F
.52584 .34545 m .52584 .34546 L .5259 .34543 L F
.52584 .34545 m .5259 .34543 L .5259 .34542 L F
.52583 .34551 m .52576 .34549 L .52585 .34544 L F
.52581 .34547 m .52584 .34546 L .52584 .34545 L F
.52581 .34547 m .52583 .34547 L .52584 .34546 L F
.52478 .34613 m .52591 .34548 L .52589 .34548 L F
.52471 .34613 m .52638 .34519 L .52635 .34516 L F
.52482 .34613 m .52639 .3452 L p .52479 .34613 L F P
0 g
s
.5259 .34553 m .52478 .34629 L p .52592 .3453 L .672 .728 .891 r
F P
0 g
s
.52597 .34535 m .52595 .3454 L .52579 .34527 L .672 .728 .891 r
F
.52601 .34542 m .52597 .34528 L .52596 .3454 L F
.52606 .34538 m .52595 .3454 L .52597 .34535 L F
.52622 .34552 m .52611 .34502 L .52621 .34551 L F
.52474 .34613 m .52638 .34519 L .52471 .34613 L F
.52642 .34553 m .526 .34528 L .52606 .34512 L F
.52636 .34558 m .52646 .34562 L .52635 .34521 L F
.52651 .34562 m .52629 .34547 L .52642 .34553 L F
.52629 .34547 m .526 .34528 L .52642 .34553 L F
.52602 .34523 m .52592 .3453 L .52604 .34516 L F
.52603 .34518 m .526 .34528 L .52596 .34521 L F
.52579 .34527 m .52595 .3454 L .52587 .34552 L F
.52601 .34542 m .52596 .3454 L .526 .34556 L F
.52595 .3454 m .52618 .34557 L .5259 .34553 L F
.5259 .34553 m .52592 .3453 L .52601 .34524 L F
.5259 .34553 m .52601 .34524 L .5259 .34553 L F
.52595 .3454 m .5259 .34553 L .52587 .34552 L F
.5259 .34553 m .52601 .34524 L .52627 .34506 L F
.52412 .34608 m .52513 .34569 L .52603 .34517 L F
.52419 .34638 m .52594 .34512 L .52594 .34515 L F
.52585 .34524 m .52587 .34522 L .52567 .34524 L F
.52603 .34518 m .52596 .34521 L .52592 .34515 L F
.52606 .34512 m .52603 .34518 L .52592 .34515 L F
.52541 .34545 m .5254 .34544 L .52644 .34475 L F
.52547 .34514 m .52567 .34524 L .52634 .34515 L F
.5244 .3459 m .52442 .34591 L .52616 .34491 L F
.52594 .34505 m .5254 .34544 L .52596 .34491 L F
.52588 .3452 m .52577 .34461 L .52568 .34457 L F
.52602 .34504 m .52601 .34506 L .52557 .34457 L F
.52588 .34534 m .52587 .34456 L .52581 .34448 L F
.52594 .34538 m .52639 .3452 L .52598 .34535 L F
.52562 .34554 m .52593 .34541 L .52594 .34538 L F
.52593 .34541 m .52639 .3452 L .52594 .34538 L F
.52589 .34548 m .52589 .34534 L .52588 .34534 L F
.52587 .34552 m .5259 .34553 L .52593 .34541 L F
.5259 .34557 m .5259 .34547 L .52589 .34548 L F
.5259 .34547 m .52589 .34534 L .52589 .34548 L F
.52594 .3451 m .52611 .34498 L .52594 .34512 L F
.52601 .34506 m .52592 .34515 L .52557 .34457 L F
.52589 .34518 m .52587 .34462 L .52588 .34519 L F
.52567 .34431 m .52599 .34471 L .52559 .34454 L F
.526 .34471 m .526 .34469 L .52594 .34465 L F
.52527 .3436 m .52538 .34394 L .52541 .34338 L F
.52465 .34357 m .52594 .34465 L .52578 .34444 L F
.52538 .34394 m .52567 .34431 L .52557 .34457 L F
.52538 .34394 m .52588 .34379 L .52567 .34431 L F
.52589 .34431 m .52536 .34394 L .52561 .34431 L F
.52536 .34394 m .52346 .34264 L .52521 .344 L F
.52536 .34394 m .52521 .344 L .52561 .34431 L F
.52457 .34355 m .526 .34471 L .52465 .34357 L F
.5251 .34405 m .52515 .34403 L .52567 .3443 L F
.52709 .3451 m .52789 .34608 L .52798 .34595 L F
.52768 .3457 m .52725 .34545 L .52796 .34575 L F
.52725 .34545 m .52643 .34497 L .52735 .34544 L F
.52725 .34545 m .52735 .34544 L .52796 .34575 L F
.52499 .34518 m .52511 .34504 L .5259 .34487 L F
.52587 .34487 m .52516 .34498 L .52578 .34502 L F
.52541 .34545 m .52644 .34475 L .52644 .34475 L F
.52479 .34587 m .5254 .34545 L .52541 .34545 L F
.5254 .34545 m .52644 .34475 L .52541 .34545 L F
.52637 .34518 m .52706 .3451 L .52636 .34517 L F
.52671 .34515 m .52639 .3452 L p .52666 .34512 L F P
0 g
s
.52671 .34515 m .52666 .34512 L .52689 .34505 L .672 .728 .891 r
F
.52713 .34509 m .52671 .34515 L p .52689 .34505 L F P
0 g
s
.5268 .345 m .52676 .34499 L .5266 .345 L .672 .728 .891 r
F
.5268 .345 m .5266 .345 L .52665 .34501 L F
.52679 .34492 m .52646 .34491 L .5267 .34516 L F
.52685 .34524 m .52638 .34496 L .52685 .34522 L F
.52639 .3452 m .52668 .34492 L .52671 .34492 L F
.5263 .3451 m .52634 .34515 L .52664 .34511 L F
.52672 .34508 m .52664 .34511 L .52695 .34506 L F
.5263 .3451 m .52664 .34511 L .52672 .34508 L F
.52592 .34515 m .52606 .34538 L .52581 .34528 L F
.52585 .34524 m .52637 .34518 L .52587 .34522 L F
.52637 .34518 m .52636 .34517 L .52567 .34524 L F
.52578 .34529 m .52639 .3452 L p .52575 .34527 L F P
0 g
s
.52639 .3452 m .52706 .3451 L p .52642 .34519 L .672 .728 .891 r
F P
0 g
s
.52575 .34527 m .52639 .3452 L .52642 .34519 L .672 .728 .891 r
F
.52363 .34571 m .5247 .34551 L .52363 .34571 L F
.5247 .34551 m .52643 .34518 L .5247 .34551 L F
.5247 .34551 m .5247 .34551 L .52363 .34571 L F
.52599 .3447 m .52594 .34465 L .52518 .34401 L F
.5257 .34545 m .5256 .34543 L .52513 .34569 L F
.52593 .34524 m .52475 .34601 L .52593 .34516 L F
.52592 .34515 m .52581 .34528 L .52579 .34527 L F
.5268 .34455 m .52625 .34503 L .52677 .34456 L F
.52724 .34437 m .52681 .34466 L .5268 .34455 L F
.52619 .34484 m .52619 .34485 L .52722 .3448 L F
.52638 .34491 m .52628 .34493 L .52646 .34497 L F
.52681 .34466 m .52625 .34503 L .5268 .34455 L F
.52609 .34504 m .5261 .34501 L .52677 .34456 L F
.52621 .34482 m .52619 .34479 L .52619 .34477 L F
.5262 .34483 m .52619 .34479 L .52621 .34482 L F
.52617 .34493 m .52644 .34475 L .52617 .34493 L F
.52617 .34493 m .52644 .34475 L .52618 .34494 L F
.52616 .34492 m .52615 .34491 L .52638 .34474 L F
.52594 .34512 m .52644 .34475 L .52648 .34475 L F
.52578 .34444 m .52625 .3449 L .52638 .34491 L F
.52602 .34474 m .52601 .34473 L .52685 .34522 L F
.52685 .34522 m .52685 .34522 L .52705 .34534 L F
.52639 .3452 m .5268 .34492 L p .52598 .34535 L F P
0 g
s
.52639 .3452 m .52632 .34511 L .52666 .34501 L .672 .728 .891 r
F
.52683 .3449 m .52639 .3452 L p .52682 .34482 L F P
0 g
s
.52646 .34497 m .52678 .34534 L .52679 .34522 L .672 .728 .891 r
F
.52602 .34474 m .52685 .34522 L .52685 .34522 L F
.52624 .34501 m .52624 .34501 L .526 .34508 L F
.52641 .34497 m .526 .34508 L .526 .34508 L F
.52481 .34517 m .52596 .34511 L .526 .34507 L F
.52583 .345 m .52592 .34515 L .52591 .34517 L F
.52583 .345 m .52591 .34517 L .52579 .34527 L F
.52557 .34457 m .52583 .345 L .52579 .34527 L F
.526 .34507 m .52602 .34504 L .52537 .34509 L F
.52539 .3451 m .52537 .34509 L .52486 .34512 L F
.526 .34507 m .52537 .34509 L .52539 .3451 L F
.52587 .34533 m .52576 .34455 L .52586 .34533 L F
.52587 .34552 m .52584 .34531 L .52583 .34531 L F
.52587 .34553 m .5259 .34553 L .52587 .34552 L F
.52588 .34555 m .52587 .34552 L .52587 .34552 L F
.52587 .34552 m .52584 .34531 L .52587 .34552 L F
.5256 .34551 m .52573 .34545 L .5257 .34545 L F
.52564 .34549 m .52581 .34542 L .52597 .34531 L F
.52639 .3452 m .52581 .34528 L p .52632 .34511 L F P
0 g
s
.52547 .34514 m .52634 .34515 L .5263 .3451 L .672 .728 .891 r
F
.52558 .34519 m .52642 .34497 L .52562 .3452 L F
.52611 .34486 m .52742 .34481 L .52611 .34486 L F
.52679 .34439 m .52626 .34472 L .52686 .34439 L F
.52694 .34429 m .52636 .34474 L .52626 .34472 L F
.52599 .34453 m .52599 .34452 L .52687 .345 L F
.52599 .34454 m .52687 .34503 L .52599 .34454 L F
.52641 .34475 m .52638 .34474 L .52646 .34468 L F
.52599 .34454 m .52599 .34453 L .52687 .34504 L F
.52679 .34492 m .52589 .34431 L .52646 .34491 L F
.52671 .34492 m .52682 .34478 L .52682 .34482 L F
.52668 .34492 m .52682 .34478 L .52671 .34492 L F
.52589 .34431 m .52641 .34491 L .52646 .34491 L F
.5265 .34491 m .52593 .34459 L .5268 .3449 L F
.52577 .34435 m .52567 .3443 L .526 .34436 L F
.52574 .34439 m .52579 .34426 L .52573 .34433 L F
.52585 .34522 m .52581 .34447 L .52574 .34439 L F
.52571 .34436 m .52567 .3443 L .52592 .34444 L F
.52581 .34447 m .52579 .34426 L .52574 .34439 L F
.52593 .34459 m .52587 .34456 L .52592 .34453 L F
.52583 .34523 m .52572 .34437 L .52568 .34441 L F
.52572 .34437 m .52572 .34434 L .52571 .34436 L F
.52572 .34437 m .52571 .34436 L .52568 .34441 L F
.52505 .34433 m .52532 .34434 L .52603 .34475 L F
.52616 .34492 m .52626 .34504 L .52658 .34491 L F
.5267 .34491 m .52681 .34485 L .52681 .34485 L F
.52633 .34513 m .5268 .34492 L .52681 .34485 L F
.52588 .34539 m .52635 .34515 L .52633 .34513 L F
.52635 .34515 m .5268 .34492 L .52633 .34513 L F
.52626 .34505 m .52725 .34474 L .52721 .34482 L F
.52562 .3452 m .52625 .34503 L .52626 .34505 L F
.5263 .3451 m .52661 .34494 L .52647 .34498 L F
.52661 .34494 m .52681 .34484 L .52647 .34498 L F
.52593 .34459 m .52592 .34453 L .5268 .3449 L F
.52647 .34498 m .52681 .34484 L .52681 .34476 L F
.52742 .34481 m .52743 .34481 L .52611 .34486 L F
.52679 .34492 m .52679 .34492 L .52706 .34511 L F
.5268 .3449 m .5268 .34493 L .52706 .3451 L F
.52707 .34508 m .5265 .34491 L .5268 .3449 L F
.52709 .3451 m .52707 .34508 L .52706 .34511 L F
.52969 .34457 m .53131 .34426 L .53131 .34426 L F
.52643 .34519 m .52969 .34457 L .52969 .34457 L F
.52969 .34457 m .53131 .34426 L .52969 .34457 L F
.52632 .34511 m .52721 .34482 L .52719 .34486 L F
.52633 .34513 m .52671 .34491 L .52633 .34513 L F
.52633 .34512 m .52681 .34484 L .5263 .3451 L F
.52631 .3451 m .52662 .345 L .52632 .34511 L F
.52662 .345 m .52721 .34482 L .52663 .34501 L F
.52662 .345 m .52663 .34501 L .52632 .34511 L F
.52633 .34513 m .52671 .34491 L .5267 .34491 L F
.52587 .34462 m .52587 .34456 L .52587 .34462 L F
.52594 .34465 m .52628 .34493 L .52578 .34444 L F
.52593 .34465 m .52669 .34502 L .52658 .345 L F
.52592 .3453 m .52563 .3455 L .52593 .34524 L F
.52289 .34723 m .52479 .34613 L .52478 .34613 L F
.52254 .34749 m .52249 .34746 L .52576 .34549 L F
.52289 .34723 m .52579 .34554 L .52281 .34724 L F
.52579 .34554 m .52577 .34554 L .52281 .34724 L F
.52459 .34613 m .52471 .34613 L .5249 .34602 L F
.52459 .34613 m .5249 .34602 L .52493 .34594 L F
.52374 .34671 m .52494 .34587 L .52491 .34592 L F
.52073 .34822 m .52471 .34613 L .52459 .34613 L F
.52289 .34723 m .52482 .34613 L .52479 .34613 L F
.52563 .3455 m .51312 .35415 L .52557 .34549 L F
.52563 .3455 m .52557 .34549 L .52593 .34524 L F
.51354 .3475 m .5209 .34615 L .5209 .34614 L F
.52323 .34545 m .52285 .34552 L .52324 .34546 L F
.52594 .34534 m .52548 .34467 L .52548 .34466 L F
.5229 .34593 m .52604 .34504 L .5229 .34593 L F
.51354 .3475 m .52401 .34562 L .524 .34558 L F
.52561 .34493 m .5258 .34531 L .52564 .34493 L F
.52561 .34493 m .52564 .34493 L .52548 .34457 L F
.52548 .34466 m .52548 .34467 L .52545 .34463 L F
.52548 .34466 m .52548 .34466 L .52545 .34463 L F
.52545 .34463 m .52561 .34493 L .52548 .34457 L F
.52285 .34552 m .51354 .3475 L .52234 .34587 L F
.52602 .34298 m .52427 .33247 L p .52582 .34321 L F P
0 g
s
.5257 .343 m .52571 .34299 L .52551 .34152 L .672 .728 .891 r
F
.5252 .34249 m .52556 .34194 L .52551 .34152 L F
.52586 .34406 m .52594 .34403 L .52427 .33247 L F
.52427 .33247 m .52602 .34298 L p .52548 .34268 L F P
0 g
s
.52577 .34313 m .52595 .34282 L .52548 .3324 L .672 .728 .891 r
F
.52575 .34329 m .52575 .34329 L .52571 .34299 L F
.52618 .34396 m .52602 .34298 L p .52612 .34402 L F P
0 g
s
.52593 .34463 m .52669 .34502 L .52595 .34466 L .672 .728 .891 r
F
.52611 .34486 m .52611 .34486 L .52598 .34486 L F
.52611 .345 m .52602 .34504 L .52608 .34498 L F
.52614 .3449 m .52608 .34498 L .52618 .34482 L F
.526 .34508 m .52616 .34492 L .52587 .34456 L F
.52593 .34463 m .52595 .34466 L .52593 .34465 L F
.52593 .34463 m .52595 .34466 L .52593 .34463 L F
.53487 .35036 m .53095 .3477 L .53164 .34899 L F
.53095 .3477 m .52709 .3451 L .53068 .34817 L F
.53095 .3477 m .53068 .34817 L .53164 .34899 L F
.52604 .34399 m .52606 .34396 L .52604 .34397 L F
.52621 .34498 m .52607 .344 L .52604 .34399 L F
.52607 .344 m .52606 .34396 L .52604 .34399 L F
.52863 .34441 m .52617 .34493 L .52863 .34441 L F
.52869 .3444 m .52617 .34493 L .52869 .3444 L F
.52769 .3447 m .52766 .34471 L .52775 .34469 L F
.52767 .34476 m .5276 .34472 L .52872 .3444 L F
.52981 .34424 m .52979 .34425 L .53012 .34419 L F
.53001 .34416 m .53012 .34419 L .53999 .34262 L F
.53923 .34267 m .53814 .34288 L .53999 .34262 L F
.54422 .34099 m .53341 .34354 L p .53488 .34297 L F P
0 g
s
.53488 .34297 m .53814 .34288 L .53923 .34267 L .672 .728 .891 r
F
.5322 .34383 m .53356 .3433 L .53488 .34297 L F
.53488 .34297 m .53356 .3433 L .53385 .34319 L F
.53488 .34297 m .52968 .34407 L .53814 .34288 L F
.52968 .34407 m .53001 .34416 L .53999 .34262 L F
.53012 .34419 m .53034 .34425 L .53999 .34262 L F
.5274 .34463 m .53034 .34425 L .53012 .34419 L F
.53488 .34297 m .53999 .34262 L .54457 .34177 L F
.53976 .34257 m .5295 .34454 L .52872 .3444 L F
.52691 .34504 m .53093 .34426 L .53092 .34427 L F
.53083 .34432 m .52976 .34452 L .53092 .34427 L F
.53076 .34437 m .52976 .34452 L .53083 .34432 L F
.53076 .34437 m .52841 .34481 L .52976 .34452 L F
.52841 .34481 m .52846 .34476 L .53092 .34427 L F
.53078 .34437 m .52941 .34463 L p .53086 .34435 L F P
0 g
s
.52941 .34463 m .52943 .34462 L .53086 .34435 L .672 .728 .891 r
F
.52848 .34474 m .52848 .34473 L .53093 .34426 L F
.52771 .34456 m .52838 .34474 L .53377 .34415 L F
.52851 .34486 m .5279 .34476 L .52881 .3445 L F
.52794 .34479 m .52835 .34488 L .53377 .34415 L F
.53132 .34423 m .53879 .34286 L .53873 .34287 L F
.53132 .34423 m .53879 .34286 L .53132 .34423 L F
.53131 .34426 m .53131 .34426 L .5389 .34283 L F
.52869 .3444 m .52863 .34441 L .52863 .34441 L F
.52872 .3444 m .52869 .3444 L .52869 .3444 L F
.5295 .34454 m .5287 .3444 L .52872 .3444 L F
.53879 .34286 m .53078 .34437 L p .5389 .34283 L F P
0 g
s
.53078 .34437 m .53086 .34435 L .5389 .34283 L .672 .728 .891 r
F
.53092 .34427 m .53093 .34426 L .53976 .34257 L F
.5389 .34283 m .53076 .34437 L .53976 .34257 L F
.53076 .34437 m .53092 .34427 L .53976 .34257 L F
.53148 .34394 m .52771 .34456 L .53377 .34415 L F
.53377 .34415 m .54485 .34257 L p .53148 .34394 L F P
0 g
s
.54485 .34257 m .52848 .3449 L p .52881 .3445 L .672 .728 .891 r
F P
0 g
s
.52771 .34456 m .52725 .34464 L .52838 .34474 L .672 .728 .891 r
F
.52805 .34462 m .52753 .3447 L .52818 .34457 L F
.52753 .3447 m .52756 .34467 L .52818 .34457 L F
.52737 .34467 m .52728 .34468 L .52729 .34468 L F
.52725 .34464 m .52784 .34477 L .52838 .34474 L F
.52753 .34465 m .5274 .34467 L .52737 .34467 L F
.52818 .34457 m .52757 .34467 L .52753 .34465 L F
.52881 .3445 m .52805 .34462 L .52818 .34457 L F
.52881 .3445 m .52729 .34468 L .53029 .34482 L F
.52654 .34492 m .5288 .34372 L .52647 .34492 L F
.52766 .34435 m .52683 .3449 L p .52762 .34413 L F P
0 g
s
.52681 .34476 m .52773 .34429 L .52777 .34412 L .672 .728 .891 r
F
.52751 .34441 m .5275 .34441 L .52602 .3452 L F
.52683 .3449 m .52682 .34482 L .52762 .34413 L F
.52681 .34484 m .52773 .34429 L .52681 .34476 L F
.52831 .34396 m .52718 .34441 L .52872 .34337 L F
.52699 .34439 m .52735 .3444 L .52879 .34357 L F
.53978 .33616 m .52766 .34435 L p .52762 .34413 L F P
0 g
s
.5261 .34485 m .52631 .34492 L .52625 .34492 L .672 .728 .891 r
F
.52581 .34528 m .52579 .34527 L .52632 .34511 L F
.52579 .34527 m .52582 .34525 L .52632 .34511 L F
.5259 .34547 m .52602 .34521 L .526 .34508 L F
.52589 .34518 m .526 .34508 L .52587 .34456 L F
.52459 .34542 m .52575 .34527 L .52454 .34539 L F
.52575 .34527 m .52638 .34519 L .52573 .34526 L F
.52575 .34527 m .52573 .34526 L .52454 .34539 L F
.526 .34471 m .52623 .3449 L .526 .34469 L F
.52623 .3449 m .52657 .34517 L .52625 .3449 L F
.52623 .3449 m .52625 .3449 L .526 .34469 L F
.52612 .34496 m .52613 .34494 L .52619 .3449 L F
.5262 .3449 m .52619 .3449 L .52641 .34475 L F
.52612 .34496 m .52619 .3449 L .5262 .3449 L F
.5263 .34509 m .5263 .3451 L .52658 .34491 L F
.52582 .34525 m .52595 .34512 L .52626 .34505 L F
.5259 .34547 m .52592 .34536 L .52589 .34534 L F
.52588 .34539 m .52597 .34534 L .52588 .3454 L F
.52597 .34534 m .52766 .34435 L .52597 .34534 L F
.52597 .34534 m .52597 .34534 L .52588 .3454 L F
.52582 .34525 m .52626 .34505 L .52631 .3451 L F
.52582 .34525 m .52631 .3451 L .52632 .34511 L F
.52607 .34511 m .52599 .34527 L .5263 .34509 L F
.52588 .34539 m .52633 .34513 L .52633 .34513 L F
.52642 .34497 m .52644 .34497 L .52575 .34517 L F
.52575 .34516 m .52575 .34517 L .52562 .3452 L F
.52642 .34497 m .52575 .34517 L .52575 .34516 L F
.51312 .35415 m .51273 .35388 L p .52162 .34806 L F P
0 g
s
.5256 .34551 m .5257 .34545 L .52513 .34569 L .672 .728 .891 r
F
.52281 .34724 m .52322 .34701 L .52329 .34697 L F
.52322 .34701 m .52474 .34613 L .52329 .34697 L F
.52329 .34697 m .52474 .34613 L .52471 .34613 L F
.523 .34721 m .52482 .34613 L p .52289 .34723 L F P
0 g
s
.52593 .34524 m .52178 .34812 L .52162 .34806 L .672 .728 .891 r
F
.52178 .34812 m .51312 .35415 L .52162 .34806 L F
.52559 .34454 m .52602 .34504 L .52557 .34457 L F
.52584 .34535 m .52568 .34441 L .52568 .34442 L F
.52587 .34552 m .52588 .3455 L .52583 .34523 L F
.5259 .34557 m .52587 .34533 L .52586 .34533 L F
.52562 .34554 m .52594 .34538 L .52588 .34539 L F
.52594 .34538 m .52598 .34535 L .52595 .34537 L F
.52594 .34538 m .52595 .34537 L .52588 .34539 L F
.52587 .34552 m .52584 .34535 L .52584 .34535 L F
.52588 .34555 m .52587 .34552 L .52587 .34552 L F
.52587 .34552 m .52584 .34535 L .52587 .34552 L F
.52534 .34507 m .52602 .34504 L .52606 .34499 L F
.52486 .34512 m .52537 .34509 L .52534 .34507 L F
.52537 .34509 m .52602 .34504 L .52534 .34507 L F
.52584 .34535 m .52584 .34532 L .52584 .34535 L F
.52584 .34532 m .52568 .34441 L .52584 .34532 L F
.52584 .34532 m .52584 .34532 L .52584 .34535 L F
.52522 .34427 m .52593 .34463 L .52593 .34465 L F
.52522 .34427 m .52542 .3443 L .52587 .34456 L F
.52588 .34457 m .52587 .34456 L .52593 .34459 L F
.52583 .34531 m .52567 .3444 L .52564 .34443 L F
.52522 .34427 m .52587 .34456 L .52588 .34457 L F
.52538 .34394 m .52556 .34452 L .5255 .3441 L F
.52538 .34394 m .5255 .3441 L .52548 .3439 L F
.52522 .34427 m .52593 .34459 L .52593 .34463 L F
.52505 .34433 m .52603 .34475 L .5261 .34485 L F
.52576 .34455 m .52573 .34433 L .52575 .34454 L F
.52587 .34456 m .5255 .34435 L .52581 .34448 L F
.52587 .34462 m .52587 .34462 L .52588 .34519 L F
.52586 .34533 m .52576 .34455 L .52575 .34454 L F
.52328 .34578 m .52328 .34578 L .52364 .34571 L F
.52363 .34571 m .52364 .34571 L .52643 .34518 L F
.52178 .34625 m .5217 .34624 L .52396 .34561 L F
.52328 .34578 m .52364 .34571 L .52363 .34571 L F
.52574 .3433 m .52571 .34299 L .5257 .343 L F
.52562 .34471 m .52588 .34555 L .52571 .34477 L F
.52562 .34471 m .52571 .34477 L .52564 .34443 L F
.52556 .34452 m .52562 .34471 L .52564 .34443 L F
.52541 .34455 m .52545 .34463 L .52548 .34457 L F
.52537 .34471 m .52505 .34426 L .52504 .34426 L F
.52586 .34487 m .52503 .34434 L p .52608 .34491 L F P
0 g
s
.52503 .34434 m .52503 .34434 L .52608 .34491 L .672 .728 .891 r
F
.52607 .34511 m .5263 .34509 L .52626 .34504 L F
.52628 .34493 m .52628 .34493 L .526 .34469 L F
.52762 .34413 m .52649 .34491 L .52643 .34491 L F
.52593 .34468 m .52593 .34468 L .52685 .34521 L F
.52611 .34486 m .52658 .34491 L .52743 .34435 L F
.52582 .34524 m .52567 .3444 L .52582 .34525 L F
.52583 .34524 m .52583 .34523 L .52568 .34441 L F
.52615 .34491 m .52567 .34499 L .52611 .34485 L F
.52631 .3451 m .52626 .34505 L .52721 .34482 L F
.52626 .34504 m .5263 .34509 L .52658 .34491 L F
.52625 .34503 m .52644 .34497 L .52626 .34505 L F
.52641 .34497 m .52624 .34501 L .52624 .34501 L F
.52639 .3452 m .52658 .34507 L .52661 .34512 L F
.52608 .34491 m .52661 .34509 L .52651 .34514 L F
.52582 .34525 m .52567 .3444 L .52567 .3444 L F
.52505 .34433 m .52631 .34495 L .52608 .34491 L F
.52644 .34497 m .52649 .34498 L .52626 .34505 L F
.52641 .34497 m .52642 .34497 L .52624 .34501 L F
.52681 .34485 m .52681 .34485 L .52681 .34485 L F
.52591 .34467 m .52685 .34521 L .52685 .34522 L F
.52534 .34434 m .52591 .34467 L .52591 .34467 L F
.52701 .34429 m .52594 .34505 L .52694 .34429 L F
.52591 .34467 m .52685 .34521 L .52591 .34467 L F
.52641 .34497 m .52617 .34492 L .52725 .34474 L F
.52616 .34492 m .52617 .34492 L .52641 .34497 L F
.52532 .34434 m .52641 .34497 L .5264 .34496 L F
.52611 .34498 m .52617 .34493 L .52611 .34499 L F
.52602 .34504 m .52625 .34502 L .52606 .34499 L F
.52611 .34494 m .52606 .34499 L .52621 .34497 L F
.52611 .34498 m .52611 .345 L .52608 .34498 L F
.52606 .34499 m .52621 .34498 L .52621 .34497 L F
.526 .34508 m .52616 .34492 L .52641 .34497 L F
.526 .34471 m .52706 .34557 L .52706 .34557 L F
.52631 .34495 m .52661 .34509 L .52608 .34491 L F
.52639 .3452 m .52626 .34472 L p .52622 .34499 L F P
0 g
s
.52593 .34463 m .52593 .34459 L .52669 .34502 L .672 .728 .891 r
F
.52592 .34446 m .52592 .34444 L .5268 .3449 L F
.5259 .3446 m .52575 .34329 L .52574 .3433 L F
.52642 .34497 m .52685 .34522 L .52642 .34497 L F
.52567 .34499 m .52594 .34488 L .52599 .34489 L F
.52594 .34493 m .52596 .34493 L .52596 .34492 L F
.52602 .34521 m .52616 .34492 L .526 .34508 L F
.52636 .34558 m .52635 .34521 L .5263 .34521 L F
.52636 .34558 m .5263 .34521 L .5263 .34521 L F
.52635 .34522 m .52651 .34562 L .52624 .3453 L F
.5263 .34554 m .5262 .34485 L .5263 .34554 L F
.52593 .34393 m .52624 .34479 L p .52584 .34389 L F P
0 g
s
.5259 .3443 m .52679 .34492 L .52679 .34492 L .672 .728 .891 r
F
.52538 .34394 m .5259 .3443 L .5259 .3443 L F
.5259 .3443 m .52679 .34492 L .5259 .3443 L F
.5262 .34485 m .5262 .34485 L .5263 .34554 L F
.52576 .34514 m .52582 .34497 L .52616 .34492 L F
.52596 .34493 m .52613 .34499 L .52616 .34492 L F
.52613 .34499 m .52626 .34504 L .52616 .34492 L F
.52596 .34493 m .52626 .34504 L .52596 .34493 L F
.52599 .34527 m .52597 .34531 L .5263 .3451 L F
.526 .34508 m .52641 .34497 L .526 .34508 L F
.52613 .34499 m .52607 .34511 L .52626 .34504 L F
.5259 .34557 m .52587 .3452 L .52585 .34522 L F
.52588 .3454 m .52596 .34535 L .52581 .34542 L F
.52596 .34535 m .52681 .34484 L .52596 .34533 L F
.52596 .34535 m .52596 .34533 L .52581 .34542 L F
.52638 .34519 m .52637 .34518 L .52453 .34539 L F
.52454 .34539 m .52453 .34539 L .52437 .34541 L F
.52638 .34519 m .52453 .34539 L .52454 .34539 L F
.52581 .34542 m .52611 .34525 L .52611 .34522 L F
.52611 .34525 m .52633 .34512 L .52611 .34522 L F
.52611 .34522 m .52633 .34512 L .5263 .3451 L F
.52587 .34553 m .5259 .34553 L .5259 .34553 L F
.52618 .34557 m .52647 .34605 L .52587 .34552 L F
.52639 .3452 m .5259 .34553 L p .52635 .34516 L F P
0 g
s
.5259 .34553 m .52639 .3452 L p .52593 .34541 L .672 .728 .891 r
F P
0 g
s
.52655 .34617 m .52611 .34551 L .52617 .34551 L .672 .728 .891 r
F
.52618 .34586 m .52617 .34496 L .52602 .34521 L F
.52632 .34655 m .52663 .34674 L .52612 .34524 L F
.52647 .34605 m .52643 .34617 L .52602 .34599 L F
.52632 .34646 m .52625 .3458 L .52618 .34586 L F
.5265 .34606 m .52618 .34552 L .52619 .34552 L F
.52625 .3458 m .52617 .34496 L .52618 .34586 L F
.52639 .3452 m .52586 .34487 L p .52621 .34498 L F P
0 g
s
.52633 .34569 m .52639 .3452 L .52622 .34499 L .672 .728 .891 r
F
.52629 .34514 m .52629 .34514 L .52639 .3452 L F
.52597 .34528 m .5263 .3451 L .5263 .34509 L F
.5262 .34525 m .52621 .34498 L .52616 .34492 L F
.52625 .3458 m .52622 .34525 L .5262 .34525 L F
.52622 .34525 m .52621 .34498 L .5262 .34525 L F
.52596 .34492 m .52629 .34514 L .52629 .34514 L F
.52576 .34514 m .52616 .34492 L .52616 .34492 L F
.52576 .34514 m .52617 .34492 L .526 .34508 L F
.52594 .34493 m .52607 .34511 L .52613 .34499 L F
.52596 .34493 m .52629 .34514 L p .52596 .34492 L F P
0 g
s
.52617 .34496 m .52615 .34496 L .52602 .34521 L .672 .728 .891 r
F
.52594 .34493 m .52596 .34493 L .52596 .34493 L F
.5256 .34531 m .52535 .34527 L .52595 .34512 L F
.52594 .34493 m .52525 .34542 L .52607 .34511 L F
.52595 .34495 m .52595 .34509 L .52594 .34493 L F
.52596 .34492 m .52595 .34495 L .52594 .34493 L F
.52617 .34492 m .52499 .3451 L .52618 .3449 L F
.5259 .34487 m .52313 .34548 L .52587 .34487 L F
.52313 .34548 m .52127 .34588 L .52313 .34547 L F
.52313 .34548 m .52313 .34547 L .52587 .34487 L F
.5262 .3445 m .52588 .34436 L .526 .34436 L F
.52592 .3443 m .5259 .3443 L .52706 .34511 L F
.5268 .3449 m .52588 .34436 L .5262 .3445 L F
.5268 .3449 m .52577 .34435 L .52588 .34436 L F
.5262 .34485 m .52606 .34395 L .5262 .34485 L F
.52619 .34437 m .52603 .34423 L .52622 .3443 L F
.52626 .34472 m .52606 .34396 L p .5262 .34485 L F P
0 g
s
.52606 .34396 m .52606 .34395 L p .52606 .34396 L .672 .728 .891 r
F P
0 g
s
.5262 .34485 m .52606 .34396 L .52606 .34396 L .672 .728 .891 r
F
.52622 .34499 m .52626 .34472 L .5262 .34485 L F
.5261 .34485 m .52603 .34475 L .52631 .34492 L F
.52479 .34419 m .52532 .34434 L .52505 .34433 L F
.52564 .34443 m .52561 .34423 L .52559 .3442 L F
.5251 .34405 m .52567 .3443 L .52571 .34436 L F
.52556 .34452 m .52559 .3442 L .52553 .34414 L F
.52599 .3447 m .52518 .34401 L .52517 .34401 L F
.52521 .34426 m .52522 .34427 L .52535 .34434 L F
.52521 .34426 m .52535 .34434 L .52534 .34434 L F
.5255 .34435 m .52391 .34345 L .5257 .34435 L F
.52555 .34416 m .52507 .34437 L .52569 .34433 L F
.52523 .3443 m .52541 .3444 L .52523 .3443 L F
.52657 .34464 m .52646 .34468 L .52757 .34389 L F
.52594 .34489 m .52608 .34491 L .52621 .34498 L F
.52608 .34492 m .52608 .34492 L .52596 .34492 L F
.52596 .34493 m .52608 .34492 L .52596 .34492 L F
.52609 .34491 m .52595 .34509 L .52596 .34492 L F
.52579 .34527 m .52577 .34526 L .52582 .34525 L F
.52588 .3455 m .52585 .34522 L .52583 .34523 L F
.5259 .34557 m .52589 .34549 L .52588 .3455 L F
.52589 .34549 m .52585 .34522 L .52588 .3455 L F
.52564 .34549 m .52597 .34531 L .52597 .34528 L F
.52588 .34555 m .52582 .34524 L .52582 .34525 L F
.52588 .34555 m .52583 .34523 L .52583 .34524 L F
.52529 .34559 m .52521 .34561 L .52594 .34512 L F
.52478 .3459 m .52594 .3451 L .52594 .34512 L F
.52525 .34542 m .52564 .34549 L .52599 .34527 L F
.52589 .34534 m .526 .34508 L .52589 .34518 L F
.52592 .34536 m .526 .34508 L .52589 .34534 L F
.52589 .34529 m .52589 .34518 L .52588 .34529 L F
.52589 .34529 m .52588 .34529 L .52588 .34534 L F
.52589 .34534 m .52589 .34529 L .52588 .34534 L F
.52414 .34606 m .52414 .34607 L .52603 .34517 L F
.52589 .34518 m .52588 .34519 L .52588 .34534 L F
.52572 .34526 m .52585 .34524 L .52567 .34524 L F
.5209 .34614 m .52234 .34588 L .52234 .34588 L F
.52369 .34565 m .51252 .3478 L .5239 .34541 L F
.52285 .34552 m .52326 .34547 L .52324 .34546 L F
.52326 .34547 m .52598 .34509 L .52324 .34546 L F
.52499 .34518 m .51252 .3478 L .52511 .34504 L F
.52123 .34586 m .52578 .34529 L .52575 .34527 L F
.50827 .34861 m .51267 .34778 L p .51354 .3475 L F P
0 g
s
.52516 .34498 m .51252 .3478 L .50797 .34782 L .672 .728 .891 r
F
.51483 .34669 m .52124 .34587 L .52123 .34586 L F
.52124 .34587 m .52578 .34529 L .52123 .34586 L F
.52364 .34571 m .52583 .34526 L .52581 .34528 L F
.5257 .3453 m .5256 .34531 L p .52572 .34528 L F P
0 g
s
.52411 .34561 m .52573 .34527 L .52575 .34528 L .672 .728 .891 r
F
.5257 .3453 m .52572 .34528 L .52577 .34526 L F
.52581 .34528 m .5257 .3453 L p .52577 .34526 L F P
0 g
s
.52577 .34526 m .52595 .34512 L .52582 .34525 L .672 .728 .891 r
F
.5256 .34531 m .52572 .34525 L .52577 .34526 L F
.52584 .34531 m .52567 .3444 L .52583 .34531 L F
.52572 .34525 m .52595 .34512 L .52577 .34526 L F
.52525 .34542 m .52599 .34527 L .52607 .34511 L F
.52594 .34502 m .52551 .34552 L .52594 .34493 L F
.52595 .34509 m .52552 .34551 L .52594 .34502 L F
.52503 .34434 m .52505 .34433 L .52621 .34498 L F
.52502 .34433 m .52502 .34433 L .52503 .34434 L F
.52502 .34433 m .52505 .34433 L .52503 .34434 L F
.5265 .34606 m .52619 .34552 L .52619 .34552 L F
.5265 .34606 m .52649 .34607 L .52618 .34552 L F
.52678 .3472 m .52704 .34739 L .52656 .34668 L F
.52636 .34638 m .52678 .3472 L .52656 .34668 L F
.52669 .34676 m .52755 .34846 L .52636 .34665 L F
.5265 .34606 m .52655 .34617 L .52649 .34607 L F
.52768 .34984 m .52639 .34567 L .52625 .34563 L F
.52755 .34822 m .52697 .34719 L .52698 .34715 L F
.52697 .34719 m .5265 .34638 L .52698 .34715 L F
.52698 .34715 m .5265 .34638 L .52653 .34628 L F
.52632 .34655 m .52768 .34984 L .52663 .34674 L F
.52617 .34648 m .52704 .34699 L .52667 .34806 L F
.52602 .34599 m .52677 .34654 L .52617 .34648 L F
.52588 .34555 m .52653 .34762 L .52622 .34603 L F
.52653 .34762 m .52678 .34842 L .52657 .34752 L F
.52653 .34762 m .52657 .34752 L .52622 .34603 L F
.5259 .34557 m .52612 .34563 L .52602 .34521 L F
.52633 .34569 m .5263 .34554 L .5263 .34554 L F
.5259 .34557 m .52622 .34603 L .52612 .34563 L F
.5265 .34564 m .52614 .34607 L .52594 .34544 L F
.52503 .34434 m .52502 .34433 L p .52503 .34434 L F P
0 g
s
.52538 .34394 m .52346 .34264 L .52536 .34394 L .672 .728 .891 r
F
.52366 .34324 m .52352 .34313 L p .52372 .34325 L F P
0 g
s
.51344 .33587 m .52366 .34324 L p .52346 .34264 L .672 .728 .891 r
F P
0 g
s
.52538 .34394 m .52145 .34207 L .52335 .34257 L .672 .728 .891 r
F
.52145 .34207 m .51258 .33645 L p .52335 .34257 L F P
0 g
s
.51258 .33645 m .52477 .34418 L p .52397 .34327 L .672 .728 .891 r
F P
0 g
s
.52479 .34419 m .52518 .34426 L .52532 .34434 L .672 .728 .891 r
F
.52502 .34433 m .52479 .34419 L p .52505 .34433 L F P
0 g
s
.52516 .34429 m .52479 .34409 L .52503 .34434 L .672 .728 .891 r
F
.52555 .34416 m .52479 .34409 L .52516 .34429 L F
.52517 .34401 m .52518 .34401 L .52465 .34357 L F
.52567 .3443 m .52145 .34207 L .52552 .34412 L F
.52376 .34342 m .52522 .34427 L .52521 .34426 L F
.52532 .34434 m .52376 .34342 L .52534 .34434 L F
.52391 .34345 m .52515 .34403 L .5251 .34405 L F
.52552 .34412 m .52145 .34207 L .52538 .34394 L F
.52555 .34416 m .52387 .34316 L .52479 .34409 L F
.52477 .34418 m .52503 .34434 L p .52387 .34316 L F P
0 g
s
.52496 .34441 m .51179 .33707 L p .52535 .3444 L .672 .728 .891 r
F P
0 g
s
.52383 .34358 m .52385 .34358 L .52541 .3444 L .672 .728 .891 r
F
.52848 .3449 m .5279 .34476 L .52851 .34486 L F
.52721 .34482 m .52725 .34474 L .52805 .34462 L F
.52764 .34472 m .52749 .34478 L .52784 .34477 L F
.52639 .3452 m .52805 .34462 L .52881 .3445 L F
.52862 .34498 m .53029 .34482 L p .52729 .34468 L F P
0 g
s
.52723 .34497 m .52736 .34486 L .53141 .34441 L .672 .728 .891 r
F
.52862 .34498 m .52877 .34476 L .53141 .34441 L F
.53029 .34482 m .54506 .34337 L p .52881 .3445 L F P
0 g
s
.53081 .34477 m .53022 .34465 L .53125 .34451 L .672 .728 .891 r
F
.53081 .34477 m .52862 .34498 L p .53022 .34465 L F P
0 g
s
.53141 .34441 m .52895 .34468 L .52907 .34459 L .672 .728 .891 r
F
.54506 .34337 m .53081 .34477 L p .53141 .34441 L F P
0 g
s
.52946 .34504 m .53296 .34485 L p .52972 .34454 L .672 .728 .891 r
F P
0 g
s
.53066 .34465 m .52949 .3448 L .52941 .3447 L .672 .728 .891 r
F
.52608 .34492 m .52616 .34492 L .52608 .34492 L F
.52617 .34496 m .52616 .34492 L .52615 .34496 L F
.52616 .34491 m .52596 .34492 L .52639 .3452 L F
.5263 .34554 m .52622 .34499 L .52621 .34498 L F
.52658 .34573 m .52635 .34522 L .52637 .34521 L F
.52639 .3452 m .52649 .34559 L p .52609 .34498 L F P
0 g
s
.52599 .34489 m .5261 .34484 L .52611 .34485 L .672 .728 .891 r
F
.52608 .34482 m .52594 .34493 L .5261 .34485 L F
.52599 .34489 m .526 .34486 L .5261 .34484 L F
.52594 .34488 m .526 .34486 L .52599 .34489 L F
.52596 .34492 m .52616 .34492 L .52611 .34486 L F
.52648 .34475 m .52665 .34461 L .52677 .34456 L F
.5261 .34485 m .52743 .34435 L .5271 .34436 L F
.52599 .34489 m .52611 .34485 L .52611 .34485 L F
.52594 .34493 m .52611 .34486 L .5261 .34485 L F
.52644 .34475 m .52644 .34475 L .52665 .34461 L F
.52611 .34486 m .52743 .34435 L .5261 .34485 L F
.526 .34471 m .52594 .34465 L .52599 .3447 L F
.52643 .34497 m .52522 .34427 L .52658 .345 L F
.52611 .34485 m .52627 .3448 L .52628 .3448 L F
.52521 .34426 m .52642 .34497 L .52642 .34497 L F
.52638 .34496 m .52532 .34434 L .5264 .34496 L F
.52567 .3444 m .52547 .3433 L .52564 .34443 L F
.5255 .34435 m .5257 .34435 L .52571 .34436 L F
.52581 .34448 m .52571 .34436 L .5268 .3449 L F
.52571 .34436 m .52571 .34435 L .52568 .34441 L F
.52556 .34452 m .52564 .34443 L .52559 .3442 L F
.52568 .34442 m .52568 .34441 L .52547 .34329 L F
.52575 .34454 m .52573 .34433 L .52572 .34434 L F
.5255 .34435 m .52571 .34436 L .52581 .34448 L F
.52572 .34434 m .52571 .34435 L .52571 .34436 L F
.52621 .34498 m .526 .34374 L .52587 .34456 L F
.52611 .34485 m .52627 .3448 L .52611 .34485 L F
.52608 .34482 m .52609 .34491 L .52596 .34492 L F
.52594 .34488 m .52608 .34491 L .52594 .34489 L F
.52595 .34487 m .52596 .34492 L .52616 .34491 L F
.52613 .3449 m .52591 .34488 L .52614 .34493 L F
.52608 .34482 m .52595 .34487 L .52613 .3449 L F
.52595 .34487 m .52591 .34488 L .52613 .3449 L F
.52593 .34469 m .52593 .34468 L .52601 .34473 L F
.52593 .34469 m .52601 .34473 L .52602 .34474 L F
.52594 .34465 m .52595 .34487 L .52616 .34491 L F
.52616 .34491 m .52609 .34498 L .52584 .3446 L F
.52616 .34492 m .52658 .34491 L .52619 .34487 L F
.52618 .3449 m .52615 .34491 L .52628 .34481 L F
.52618 .3449 m .52628 .34481 L .52628 .34481 L F
.52627 .3448 m .52639 .3452 L .52619 .34488 L F
.52628 .34479 m .52628 .34481 L p .52627 .3448 L F P
0 g
s
.52625 .34492 m .52631 .34492 L .52661 .34509 L .672 .728 .891 r
F
.52628 .34481 m .52639 .3452 L p .52627 .3448 L F P
0 g
s
.52628 .34481 m .52628 .34481 L .52629 .3448 L .672 .728 .891 r
F
.52628 .3448 m .52627 .3448 L .52629 .3448 L F
.52618 .34491 m .52639 .3452 L .52627 .34491 L F
.52661 .34473 m .52642 .34491 L .52628 .34468 L F
.52616 .34492 m .52619 .34487 L .52611 .34486 L F
.52616 .34492 m .52616 .34492 L .52617 .34492 L F
.52621 .34486 m .52616 .34491 L .52678 .34505 L F
.52611 .34485 m .5261 .34484 L .52627 .3448 L F
.52615 .34491 m .52611 .34485 L .52628 .3448 L F
.52628 .34481 m .52628 .3448 L .52629 .3448 L F
.52615 .34491 m .52628 .3448 L .52628 .34481 L F
.52622 .34499 m .52607 .344 L .52621 .34498 L F
.52607 .344 m .52606 .34395 L .52607 .344 L F
.52607 .344 m .52607 .344 L .52621 .34498 L F
.52862 .34498 m .52825 .34483 L .52868 .3449 L F
.52959 .34478 m .5279 .34488 L .52946 .34504 L F
.52638 .34496 m .5264 .34496 L .52685 .34522 L F
.52657 .34517 m .52678 .34534 L .52657 .34517 L F
.52651 .34514 m .52661 .34509 L .53017 .34718 L F
.52632 .34495 m .52687 .34551 L .52652 .34499 L F
.52661 .34512 m .52666 .34501 L .52684 .34504 L F
.52658 .345 m .52669 .34502 L .52835 .34595 L F
.52597 .34528 m .52597 .34531 L .52599 .34527 L F
.52595 .34535 m .52612 .34487 L .52615 .34491 L F
.52608 .34482 m .52614 .34493 L .52616 .34491 L F
.52608 .34482 m .52616 .34491 L .52621 .34486 L F
.52595 .34535 m .52595 .34509 L .52612 .34487 L F
.52608 .34482 m .5261 .34485 L .5271 .34436 L F
.52629 .3448 m .52506 .34504 L .52517 .34493 L F
.52617 .34481 m .52608 .34482 L .52615 .34484 L F
.52617 .34481 m .52615 .34484 L .52678 .34505 L F
.52615 .34491 m .52612 .34487 L .52622 .34476 L F
.52538 .34394 m .52536 .34394 L .52679 .34492 L F
.52592 .3443 m .52538 .34394 L .5259 .3443 L F
.526 .34436 m .52552 .34412 L .52538 .34394 L F
.52553 .34414 m .52559 .3442 L .52552 .34389 L F
.52548 .3439 m .52552 .34389 L .52541 .34338 L F
.52567 .3444 m .52547 .34329 L .52567 .3444 L F
.52568 .34441 m .52562 .34386 L .52558 .34387 L F
.52561 .34423 m .52547 .3433 L .52559 .3442 L F
.52544 .34364 m .5258 .34423 L .52555 .34416 L F
.5262 .34478 m .52609 .34491 L .52608 .34482 L F
.52587 .34456 m .52581 .34448 L .52592 .34453 L F
.52572 .34434 m .52572 .34433 L .52571 .34435 L F
.52571 .34436 m .52592 .34444 L .52592 .34446 L F
.52581 .34448 m .52587 .34456 L .52579 .34419 L F
.5258 .34423 m .52639 .3452 L .52569 .34433 L F
.52572 .34433 m .52555 .34317 L .52568 .34441 L F
.52567 .3443 m .52552 .34412 L .526 .34436 L F
.52573 .34433 m .52579 .34419 L .52573 .34431 L F
.52579 .34426 m .52579 .34419 L .52573 .34433 L F
.5258 .34423 m .52569 .34433 L .52555 .34416 L F
.52617 .34481 m .52678 .34505 L .52679 .34505 L F
.52835 .34595 m .52669 .34502 L .52707 .34508 L F
.5268 .34505 m .52679 .34505 L .52684 .34506 L F
.52617 .34481 m .52679 .34505 L .5268 .34505 L F
.52629 .3448 m .52617 .34481 L .52695 .3451 L F
.52627 .3448 m .52619 .34488 L .52618 .34485 L F
.52672 .34437 m .52608 .34482 L .52706 .34436 L F
.52624 .34471 m .5262 .34478 L .52608 .34482 L F
.52606 .34396 m .52606 .34395 L .52606 .34395 L F
.52606 .34396 m .52606 .34395 L .52604 .34397 L F
.52585 .34375 m .52588 .34379 L .52538 .34394 L F
.52573 .34431 m .52579 .34419 L .52562 .34346 L F
.52587 .34456 m .526 .34374 L .52579 .34419 L F
.52606 .34395 m .52628 .34479 L p .52544 .34364 L F P
0 g
s
.52628 .34468 m .52622 .34476 L .52624 .34471 L .672 .728 .891 r
F
.52622 .34476 m .5262 .34478 L .52624 .34471 L F
.52573 .34433 m .52562 .34346 L .52572 .34434 L F
.52623 .34474 m .5261 .34472 L .52544 .34364 L F
.52627 .3448 m .52621 .34477 L .52623 .34474 L F
.52621 .34477 m .5261 .34472 L .52623 .34474 L F
.52621 .34477 m .52618 .34485 L .5261 .34472 L F
.52631 .34494 m .52631 .34495 L .52594 .34455 L F
.52627 .3448 m .52618 .34485 L .52621 .34477 L F
.5261 .34505 m .52622 .34476 L .52628 .34468 L F
.52611 .34503 m .52603 .34503 L .52608 .34498 L F
.5268 .34492 m .52766 .34435 L p .52681 .34485 L F P
0 g
s
.52729 .34468 m .52618 .3449 L .52629 .3448 L .672 .728 .891 r
F
.52644 .34497 m .52725 .34474 L .52649 .34498 L F
.52671 .34491 m .52681 .34485 L .5267 .34491 L F
.52642 .34497 m .52725 .34474 L .52644 .34497 L F
.52641 .34497 m .52725 .34474 L .52642 .34497 L F
.52753 .3447 m .52617 .34492 L .52756 .34467 L F
.52617 .34492 m .52618 .3449 L .52748 .34469 L F
.52748 .34469 m .52748 .34469 L .52756 .34467 L F
.52617 .34492 m .52748 .34469 L .52748 .34469 L F
.52598 .34535 m .5268 .34492 L .52588 .34539 L F
.52646 .34558 m .52608 .34509 L .52611 .34503 L F
.526 .34531 m .5261 .34505 L .52616 .34492 L F
.52552 .34551 m .52552 .34551 L .52594 .34502 L F
.52595 .34535 m .52622 .34476 L .5261 .34505 L F
.52608 .34509 m .52603 .34503 L .52611 .34503 L F
.52639 .3452 m .52612 .345 L .52616 .34491 L F
.52612 .345 m .52609 .34498 L .52616 .34491 L F
.52541 .34545 m .52543 .34545 L .52478 .3459 L F
.52493 .34594 m .52583 .34547 L .52581 .34547 L F
.52479 .34613 m .52639 .3452 L .52478 .34613 L F
.52478 .34629 m .52459 .34622 L .52592 .3453 L F
.52127 .34588 m .51252 .3478 L .52128 .34587 L F
.52512 .34503 m .51252 .3478 L .52516 .34498 L F
.5133 .34706 m .52006 .3461 L p .51483 .34669 L F P
0 g
s
.52006 .3461 m .52578 .34529 L p .51994 .34604 L .672 .728 .891 r
F P
0 g
s
.51483 .34669 m .52006 .3461 L .51994 .34604 L .672 .728 .891 r
F
.52587 .3452 m .52579 .34426 L .52585 .34522 L F
.52594 .34493 m .52579 .34514 L .5258 .34503 L F
.52419 .34638 m .52521 .34561 L .52529 .34559 L F
.52475 .34601 m .52419 .34638 L .52476 .34598 L F
.52044 .34883 m .52479 .34587 L .52478 .3459 L F
.52479 .34587 m .5248 .34584 L .5254 .34544 L F
.52479 .34587 m .5254 .34544 L .52541 .34545 L F
.52044 .34883 m .5248 .34584 L .52479 .34587 L F
.52419 .34638 m .52044 .34883 L .52417 .34631 L F
.52254 .34749 m .51571 .35153 L p .52249 .34746 L F P
0 g
s
.51694 .35071 m .51571 .35153 L .51614 .35118 L .672 .728 .891 r
F
.51694 .35071 m .51614 .35118 L .519 .34878 L F
.5232 .34645 m .52323 .34643 L .52323 .34643 L F
.52371 .34616 m .51694 .35071 L .519 .34878 L F
.51611 .3512 m .52289 .34723 L .52281 .34724 L F
.51676 .35091 m .523 .34721 L p .51611 .3512 L F P
0 g
s
.51611 .3512 m .523 .34721 L .52289 .34723 L .672 .728 .891 r
F
.5254 .34544 m .52387 .34646 L .5252 .34539 L F
.52525 .34542 m .51876 .3501 L .5257 .3455 L F
.52579 .34514 m .52495 .34629 L .5258 .34503 L F
.5258 .34503 m .52495 .34629 L .52525 .34542 L F
.52585 .34522 m .52572 .34434 L .52583 .34523 L F
.52453 .34547 m .52582 .34497 L .52576 .34514 L F
.5258 .34486 m .52563 .34518 L .5259 .34516 L F
.52627 .34505 m .526 .34531 L .52616 .34492 L F
.52627 .34578 m .52621 .34498 L .52625 .3458 L F
.52653 .34574 m .52639 .3452 L p .52633 .34569 L F P
0 g
s
.5265 .34564 m .52594 .34544 L .52608 .3451 L .672 .728 .891 r
F
.52606 .34501 m .5259 .34516 L .52628 .34514 L F
.5258 .34486 m .5259 .34516 L .52606 .34501 L F
.52649 .34559 m .52646 .34558 L .52608 .34498 L F
.52569 .34433 m .52586 .34487 L .52594 .34465 L F
.52609 .34498 m .52608 .34498 L .52555 .34416 L F
.52649 .34559 m .52608 .34498 L .52609 .34498 L F
.52597 .34531 m .52597 .34531 L .52599 .34527 L F
.526 .34531 m .52595 .34535 L .5261 .34505 L F
.5259 .34557 m .52602 .34521 L .5259 .34547 L F
.52595 .34535 m .526 .34531 L .526 .34531 L F
.52608 .3451 m .52598 .34535 L .52568 .34459 L F
.52588 .34555 m .52588 .3455 L .52587 .34552 L F
.52562 .34554 m .52587 .34553 L .52593 .34541 L F
.52592 .34549 m .5249 .34635 L .52599 .34531 L F
.52598 .34535 m .52594 .34544 L .5259 .34531 L F
.52595 .34535 m .52595 .34535 L .526 .34531 L F
.52481 .34517 m .526 .34507 L .52486 .34512 L F
.52598 .34535 m .5259 .34531 L .52568 .34459 L F
.52127 .34588 m .52128 .34587 L .52587 .34487 L F
.526 .34508 m .526 .34508 L .52465 .34544 L F
.51483 .34669 m .5244 .34545 L .52437 .34541 L F
.5237 .34531 m .50797 .34782 L .52349 .34513 L F
.52327 .3453 m .52288 .34561 L .52461 .34538 L F
.52327 .3453 m .51483 .34669 L .52288 .34561 L F
.50797 .34782 m .5133 .34706 L p .51483 .34669 L F P
0 g
s
.52453 .34547 m .50797 .34782 L p .52392 .34528 L .672 .728 .891 r
F P
0 g
s
.52327 .3453 m .52461 .34538 L .52481 .34517 L .672 .728 .891 r
F
.52563 .34518 m .51925 .34564 L .52562 .34519 L F
.52516 .34498 m .52531 .34506 L .52578 .34502 L F
.52499 .3451 m .525 .3451 L .52618 .3449 L F
.52516 .34498 m .52412 .34515 L .52531 .34506 L F
.52412 .34515 m .52419 .3452 L .52578 .34502 L F
.52327 .3453 m .52481 .34517 L .52486 .34512 L F
.52567 .34499 m .5238 .3453 L .526 .34486 L F
.5258 .34486 m .52517 .34493 L .52563 .34518 L F
.52499 .3451 m .5238 .3453 L .525 .3451 L F
.52412 .34515 m .52327 .3453 L .52419 .3452 L F
.5244 .34545 m .52459 .34542 L .52437 .34541 L F
.52459 .34542 m .52454 .34539 L .52437 .34541 L F
.52453 .34547 m .52392 .34528 L .52582 .34497 L F
.52517 .34493 m .5238 .3453 L .52405 .34507 L F
.52506 .34504 m .5238 .3453 L .52517 .34493 L F
.5238 .3453 m .5237 .34531 L .52405 .34507 L F
.52517 .34493 m .51925 .34564 L .52563 .34518 L F
.52532 .34434 m .52593 .34468 L .52593 .34469 L F
.52534 .34434 m .52535 .34434 L .52593 .34468 L F
.52534 .34434 m .52593 .34468 L .52593 .34468 L F
.52507 .34437 m .52586 .34487 L p .52569 .34433 L F P
0 g
s
.52607 .345 m .52634 .34514 L .52614 .34493 L .672 .728 .891 r
F
.52621 .34498 m .52609 .345 L .52619 .34495 L F
.52564 .34549 m .5257 .3455 L .52581 .34542 L F
.52562 .34554 m .52588 .3454 L .52581 .34542 L F
.52562 .34554 m .52588 .34539 L .52588 .3454 L F
.52343 .347 m .5259 .34553 L .52562 .34554 L F
.52595 .34535 m .52495 .34629 L .52595 .34509 L F
.52582 .34527 m .52594 .34541 L .52586 .34545 L F
.5259 .34531 m .52594 .34541 L .52582 .34527 L F
.52631 .3451 m .52687 .34545 L .52631 .34511 L F
.52679 .34522 m .52706 .34557 L .52727 .3456 L F
.52678 .34534 m .52706 .34557 L .52679 .34522 L F
.52639 .3452 m .52621 .34498 L .52802 .34598 L F
.52594 .34455 m .52682 .34547 L .52682 .34545 L F
.52639 .3452 m .52714 .34513 L p .52635 .34516 L F P
0 g
s
.52643 .34497 m .52658 .345 L .52835 .34595 L .672 .728 .891 r
F
.52685 .34524 m .52685 .34522 L .52705 .34534 L F
.52665 .34502 m .52659 .34501 L .52703 .34537 L F
.52642 .34497 m .52685 .34522 L .52685 .34522 L F
.52658 .34507 m .52666 .34501 L .52661 .34512 L F
.52684 .34521 m .52705 .34534 L .52685 .34522 L F
.52684 .34521 m .52685 .34522 L .5264 .34496 L F
.52641 .34497 m .52684 .34521 L .5264 .34496 L F
.5264 .34496 m .52705 .34534 L .52705 .34534 L F
.52646 .3449 m .52687 .34551 L .52722 .34552 L F
.52588 .34518 m .52714 .34513 L .527 .3451 L F
.52669 .34502 m .5265 .34491 L .52707 .34508 L F
.52629 .3448 m .52688 .34507 L .52704 .34509 L F
.52688 .34507 m .527 .3451 L .52704 .34509 L F
.52685 .34522 m .528 .34588 L .52685 .34522 L F
.52685 .34522 m .52685 .34521 L .528 .34588 L F
.52788 .34554 m .52679 .3449 L .52722 .34552 L F
.52688 .34507 m .52695 .3451 L .527 .3451 L F
.52728 .34468 m .52618 .3449 L .52729 .34468 L F
.5274 .34467 m .52618 .3449 L .52737 .34467 L F
.52757 .34467 m .52618 .3449 L .52753 .34465 L F
.52729 .34468 m .52629 .3448 L .52704 .34509 L F
.52679 .3449 m .52656 .3449 L .52672 .34497 L F
.52656 .3449 m .52653 .3449 L .52672 .34497 L F
.52672 .34497 m .52653 .3449 L .52667 .34502 L F
.52688 .34507 m .52667 .34502 L .52703 .34535 L F
.52684 .34504 m .52666 .34501 L .52805 .34462 L F
.52679 .3449 m .52667 .34502 L .52688 .34507 L F
.52706 .34529 m .52703 .34535 L .52722 .34552 L F
.52679 .3449 m .52703 .34535 L .52706 .34529 L F
.52683 .34508 m .5267 .34511 L .52695 .3451 L F
.52684 .34506 m .52678 .34505 L .52695 .3451 L F
.52682 .34511 m .52681 .34505 L .52788 .34554 L F
.52681 .34505 m .52681 .34503 L .52688 .34506 L F
.52681 .34505 m .52688 .34506 L .52788 .34554 L F
.52703 .34514 m .52639 .3452 L p .52689 .34506 L F P
0 g
s
.52713 .34509 m .52689 .34505 L .5279 .34476 L .672 .728 .891 r
F
.52707 .3451 m .52689 .34506 L .52722 .34497 L F
.52703 .34514 m .52689 .34506 L .52707 .3451 L F
.52725 .3449 m .52704 .34509 L .52722 .34508 L F
.52722 .34498 m .52722 .34497 L .52723 .34497 L F
.52703 .34514 m .52722 .34497 L .52722 .34498 L F
.52602 .34444 m .52703 .34537 L .52703 .34535 L F
.52607 .34532 m .52627 .34505 L .52611 .3453 L F
.5258 .34526 m .52639 .3452 L p .52588 .34518 L F P
0 g
s
.52594 .34465 m .52594 .34492 L .52596 .34492 L .672 .728 .891 r
F
.52586 .34487 m .52594 .34488 L .52594 .34489 L F
.52586 .34487 m .52594 .34492 L p .52594 .34486 L F P
0 g
s
.52594 .34465 m .52587 .34485 L .52594 .34486 L .672 .728 .891 r
F
.52587 .34485 m .52586 .34487 L .52594 .34486 L F
.52595 .34487 m .5258 .34486 L .52591 .34488 L F
.52608 .34482 m .52587 .34485 L .52595 .34487 L F
.52587 .34485 m .5258 .34486 L .52595 .34487 L F
.52608 .34498 m .52568 .34459 L .52585 .34462 L F
.52647 .34655 m .52621 .34498 L .52632 .34646 L F
.52611 .3453 m .52627 .34505 L .5263 .3451 L F
.52563 .34518 m .52566 .34519 L .52695 .3451 L F
.52581 .34523 m .52592 .34514 L .5263 .34509 L F
.52618 .34494 m .52666 .3451 L .52676 .34506 L F
.52631 .34494 m .52682 .34547 L .52631 .34495 L F
.52639 .3452 m .52641 .34518 L .52685 .34547 L F
.52639 .3452 m .52826 .34655 L p .5265 .34518 L F P
0 g
s
.52639 .3452 m .52682 .34547 L p .52627 .34491 L .672 .728 .891 r
F P
0 g
s
.52618 .34494 m .52634 .34514 L .5267 .34511 L .672 .728 .891 r
F
.52596 .34553 m .52663 .3449 L .5267 .3449 L F
.52679 .34489 m .52596 .34553 L p .52678 .34483 L F P
0 g
s
.52639 .3452 m .52678 .3449 L p .52632 .34512 L .672 .728 .891 r
F P
0 g
s
.526 .34531 m .526 .34531 L .52642 .34491 L .672 .728 .891 r
F
.52588 .34518 m .52639 .3452 L .52635 .34516 L F
.52597 .34509 m .52597 .3451 L .526 .34529 L F
.52586 .34558 m .52593 .34543 L .52591 .34515 L F
.52596 .34546 m .52607 .34532 L .52611 .3453 L F
.52582 .3454 m .52586 .34545 L .52583 .34546 L F
.52618 .34527 m .52592 .34549 L .52612 .3453 L F
.52596 .34553 m .52596 .34546 L .52663 .3449 L F
.52596 .3454 m .52599 .34531 L .52596 .34546 L F
.52596 .34553 m .52639 .3452 L p .52597 .34536 L F P
0 g
s
.52542 .34556 m .52588 .34553 L .52597 .34536 L .672 .728 .891 r
F
.52588 .34555 m .5259 .34557 L .52588 .3455 L F
.52657 .34623 m .52677 .34654 L .52602 .34599 L F
.52594 .34541 m .52648 .34719 L .52583 .34546 L F
.52592 .34549 m .52596 .3454 L .52596 .34546 L F
.52588 .34553 m .52596 .34553 L .52597 .34536 L F
.52606 .34578 m .526 .34529 L .52606 .34578 L F
.526 .34529 m .52591 .34461 L .526 .34529 L F
.526 .34529 m .526 .34529 L .52606 .34578 L F
.526 .34529 m .526 .34529 L .52606 .34578 L F
.52639 .3452 m .52578 .34526 L p .52634 .34514 L F P
0 g
s
.52302 .34538 m .5258 .34526 L .52588 .34518 L .672 .728 .891 r
F
.52299 .34538 m .52303 .34538 L .52302 .34538 L F
.52303 .34538 m .5258 .34526 L .52302 .34538 L F
.52578 .34526 m .52581 .34524 L .52634 .34514 L F
.52602 .34444 m .52555 .34416 L .52599 .34452 L F
.52602 .34444 m .52574 .34439 L .52555 .34416 L F
.52599 .34508 m .52594 .34403 L .52586 .34406 L F
.52594 .34492 m .52596 .34493 L p .52596 .34492 L F P
0 g
s
.5258 .34486 m .52607 .345 L .52614 .34493 L .672 .728 .891 r
F
.52616 .34491 m .52584 .3446 L .52594 .34465 L F
.52605 .34503 m .52594 .34403 L .52599 .34508 L F
.52597 .34509 m .526 .34529 L .526 .34529 L F
.52579 .34526 m .52586 .34545 L .52582 .3454 L F
.52563 .3445 m .52582 .34527 L .52579 .34526 L F
.52582 .34527 m .52586 .34545 L .52579 .34526 L F
.52579 .34526 m .52586 .3453 L .52586 .34454 L F
.52563 .34518 m .52601 .34507 L .52592 .34514 L F
.52303 .34542 m .52467 .34537 L .52464 .34533 L F
.52301 .34553 m .52555 .34514 L .52563 .34518 L F
.52555 .34514 m .52601 .34507 L .52563 .34518 L F
.52645 .34557 m .52568 .34459 L .52646 .34558 L F
.52591 .34461 m .52597 .3451 L .52597 .34509 L F
.52578 .34526 m .52557 .34528 L p .52581 .34524 L F P
0 g
s
.52577 .34524 m .52563 .34518 L .52592 .34514 L .672 .728 .891 r
F
.52586 .34519 m .52591 .34515 L .52586 .34454 L F
.52609 .345 m .52541 .34507 L .52613 .34496 L F
.52609 .345 m .52613 .34496 L .52619 .34495 L F
.52555 .34514 m .52609 .345 L .52601 .34507 L F
.52616 .34491 m .52614 .34493 L .52618 .34494 L F
.52018 .34939 m .52425 .34664 L p .51876 .3501 L F P
0 g
s
.51876 .3501 m .52425 .34664 L .52343 .347 L .672 .728 .891 r
F
.52044 .34883 m .5205 .3487 L .5248 .34584 L F
.5249 .34635 m .514 .35471 L p .52525 .34542 L F P
0 g
s
.52527 .34548 m .52495 .34574 L .52524 .34556 L .672 .728 .891 r
F
.52603 .34503 m .52568 .34459 L .52608 .34498 L F
.52607 .34502 m .52608 .34501 L .52604 .34477 L F
.52618 .34527 m .52612 .3453 L .52676 .34466 L F
.52676 .34466 m .52676 .34466 L .52692 .34449 L F
.52618 .34527 m .52676 .34466 L .52676 .34466 L F
.52639 .3452 m .52634 .34514 L .52682 .34504 L F
.52633 .34513 m .5263 .34509 L .52692 .34501 L F
.52642 .34497 m .52646 .345 L .52695 .3451 L F
.52616 .34491 m .52646 .345 L .52642 .34497 L F
.52616 .34491 m .52618 .34494 L .52646 .345 L F
.52642 .34491 m .52627 .34491 L .52628 .34468 L F
.52602 .34444 m .52638 .3448 L .52645 .34483 L F
.5263 .3451 m .52627 .34505 L .52642 .34491 L F
.52649 .3449 m .52642 .34491 L .5271 .34427 L F
.52639 .34496 m .52616 .34491 L .52639 .34497 L F
.52639 .34496 m .52639 .34497 L .52695 .3451 L F
.52678 .34505 m .52639 .34496 L .52695 .3451 L F
.52632 .34495 m .52652 .34499 L .52646 .3449 L F
.5263 .3451 m .52642 .34491 L .52649 .3449 L F
.52638 .3448 m .52649 .3449 L .52645 .34483 L F
.52649 .3449 m .52659 .34501 L .52651 .3449 L F
.52649 .3449 m .52651 .3449 L .52645 .34483 L F
.52678 .34478 m .52663 .3449 L .52676 .34466 L F
.52651 .3449 m .52659 .34501 L .52653 .3449 L F
.52663 .3449 m .52618 .34527 L .52653 .3449 L F
.52663 .3449 m .52653 .3449 L .52676 .34466 L F
.52653 .3449 m .52659 .34501 L .52665 .34502 L F
.52645 .34483 m .52651 .3449 L .52653 .3449 L F
.52576 .34433 m .52629 .34491 L .52646 .3449 L F
.52555 .34416 m .52572 .34433 L .52576 .34433 L F
.52572 .34433 m .52629 .34491 L .52576 .34433 L F
.52757 .34389 m .52701 .34429 L .52694 .34429 L F
.5275 .3438 m .52672 .34437 L .5283 .34377 L F
.52759 .34398 m .52644 .34475 L .52758 .34396 L F
.52644 .34475 m .52641 .34475 L .52842 .34337 L F
.52842 .34337 m .52842 .34337 L .52877 .34313 L F
.52644 .34475 m .52842 .34337 L .52842 .34337 L F
.5267 .3449 m .52663 .3449 L .52756 .34413 L F
.53978 .33616 m .5389 .3356 L p .5275 .3438 L F P
0 g
s
.52757 .34417 m .52756 .34413 L .53084 .3414 L .672 .728 .891 r
F
.5267 .3449 m .52756 .34413 L .52757 .34417 L F
.52629 .34491 m .52632 .34495 L .52646 .3449 L F
.52642 .34491 m .52627 .34505 L .52627 .34491 L F
.52623 .34501 m .52624 .34502 L .5264 .34491 L F
.52595 .34535 m .52642 .34491 L .52642 .34491 L F
.52642 .34491 m .52595 .34535 L .52642 .34491 L F
.52614 .34493 m .52634 .34514 L .52618 .34494 L F
.52601 .34507 m .52609 .345 L .52637 .34497 L F
.52702 .34503 m .5267 .3449 L .52674 .34489 L F
.52666 .3451 m .5267 .34511 L .52676 .34506 L F
.52627 .34505 m .52616 .34492 L .52628 .34468 L F
.52594 .34456 m .52618 .34491 L .52627 .34491 L F
.52581 .34523 m .5263 .34509 L .52633 .34513 L F
.52632 .34512 m .52678 .3449 L .52678 .34489 L F
.52596 .34529 m .52632 .34512 L .52632 .34512 L F
.52632 .34512 m .52678 .3449 L .52632 .34512 L F
.52657 .3449 m .52659 .3449 L .52692 .34507 L F
.52691 .34507 m .52692 .34507 L .52715 .34518 L F
.52657 .3449 m .52692 .34507 L .52691 .34507 L F
.52674 .34503 m .52736 .34486 L .52723 .34497 L F
.5263 .34509 m .52664 .34502 L .52674 .34503 L F
.52555 .34416 m .52594 .34456 L .52594 .34455 L F
.52642 .34491 m .52642 .34491 L .52675 .3446 L F
.52678 .3449 m .52602 .34444 L .52653 .3449 L F
.52679 .3449 m .52678 .34489 L .52678 .3449 L F
.52678 .34489 m .52602 .34444 L .52678 .3449 L F
.52604 .34477 m .52599 .34471 L .52639 .34491 L F
.52604 .34477 m .52639 .34491 L .52634 .34492 L F
.52656 .345 m .52587 .34464 L .52587 .34464 L F
.52683 .34514 m .52656 .345 L .52656 .345 L F
.52632 .34646 m .52627 .34578 L .52625 .3458 L F
.5276 .3478 m .52753 .34778 L .5262 .34545 L F
.52783 .34829 m .52759 .3483 L .5262 .34545 L F
.52678 .34842 m .52647 .34655 L .52632 .34646 L F
.52679 .34632 m .52656 .34567 L p .52663 .34644 L F P
0 g
s
.52663 .34644 m .52656 .34567 L .52636 .34558 L .672 .728 .891 r
F
.52651 .34562 m .52704 .34699 L .52618 .34557 L F
.52704 .34739 m .5276 .34781 L .52656 .34668 L F
.52655 .34617 m .52755 .34822 L .52653 .34628 L F
.52677 .34654 m .52704 .34699 L .52617 .34648 L F
.52755 .34846 m .53199 .35727 L .52755 .34954 L F
.52831 .3505 m .52679 .34632 L p .52768 .34984 L F P
0 g
s
.52768 .34984 m .52679 .34632 L .52663 .34644 L .672 .728 .891 r
F
.52755 .34822 m .53199 .35727 L .52755 .34846 L F
.53084 .35748 m .52831 .3505 L p .52768 .34984 L F P
0 g
s
.52704 .34699 m .53084 .35748 L p .52667 .34806 L .672 .728 .891 r
F P
0 g
s
.52761 .34983 m .52653 .34574 L p .52678 .34842 L .672 .728 .891 r
F P
0 g
s
.52647 .34605 m .52657 .34623 L .52643 .34617 L .672 .728 .891 r
F
.52678 .34842 m .52653 .34574 L .52633 .34569 L F
.52966 .35765 m .52761 .34983 L p .52678 .34842 L F P
0 g
s
.5265 .34564 m .52966 .35765 L p .52614 .34607 L .672 .728 .891 r
F P
0 g
s
.52702 .34503 m .5263 .34467 L .52629 .3446 L .672 .728 .891 r
F
.52602 .34444 m .52599 .34452 L .52659 .34501 L F
.5263 .34467 m .52574 .34439 L .52629 .3446 L F
.52629 .3446 m .52574 .34439 L .52602 .34444 L F
.52632 .34512 m .52678 .34489 L .52624 .34502 L F
.52595 .34535 m .52675 .3446 L .52595 .34535 L F
.52714 .34513 m .52862 .34498 L p .527 .3451 L F P
0 g
s
.52848 .3449 m .52713 .34509 L p .5279 .34476 L .672 .728 .891 r
F P
0 g
s
.52736 .34469 m .52722 .34508 L .52862 .34498 L .672 .728 .891 r
F
.52862 .34498 m .5272 .34512 L p .52825 .34483 L F P
0 g
s
.5272 .34512 m .52703 .34514 L p .52714 .34511 L .672 .728 .891 r
F P
0 g
s
.5272 .34512 m .52714 .34511 L .52825 .34483 L .672 .728 .891 r
F
.52688 .34506 m .52715 .34518 L .52717 .3452 L F
.52681 .34503 m .52688 .34506 L .52688 .34506 L F
.52688 .34506 m .52715 .34518 L .52688 .34506 L F
.5258 .34486 m .52628 .34514 L .52633 .34513 L F
.52601 .34507 m .52623 .34501 L .52625 .34503 L F
.52656 .345 m .52598 .3447 L .52656 .345 L F
.52672 .34437 m .52706 .34436 L .5283 .34377 L F
.52608 .34482 m .5271 .34436 L .52707 .34436 L F
.52789 .34352 m .52661 .34473 L .52628 .34468 L F
.52608 .34481 m .52677 .34461 L .52676 .34458 L F
.52656 .345 m .52656 .345 L .52587 .34464 L F
.52681 .34502 m .52715 .34518 L .52681 .34503 L F
.52788 .34554 m .52758 .34553 L .52799 .34575 L F
.52758 .34553 m .52722 .34552 L .52799 .34575 L F
.52803 .34583 m .528 .34577 L .52835 .34595 L F
.52768 .3457 m .528 .34577 L .52803 .34583 L F
.52768 .3457 m .52796 .34575 L .528 .34577 L F
.52685 .34522 m .528 .34588 L .528 .34588 L F
.52705 .34534 m .52705 .34534 L .52979 .34692 L F
.52705 .34535 m .52705 .34534 L .52979 .34692 L F
.52639 .3452 m .52802 .34598 L .52803 .34606 L F
.52799 .34575 m .52722 .34552 L .52835 .34644 L F
.52683 .34514 m .52937 .34647 L .52683 .34514 L F
.52835 .34609 m .52768 .3457 L .52835 .34595 L F
.52891 .34717 m .52805 .34634 L .52875 .34677 L F
.52896 .34731 m .52805 .34634 L .52891 .34717 L F
.5282 .34597 m .52811 .34645 L .52886 .34723 L F
.52798 .34595 m .52789 .34608 L .52905 .34698 L F
.52981 .34697 m .52705 .34535 L .52979 .34692 L F
.52803 .34606 m .52802 .34598 L .53017 .34718 L F
.528 .34588 m .528 .34588 L .52979 .34692 L F
.52979 .34692 m .52835 .34609 L .52835 .34595 L F
.53009 .34686 m .52788 .34554 L .52835 .34644 L F
.52914 .34685 m .52905 .34698 L .53164 .34899 L F
.53063 .34762 m .52639 .3452 L .53017 .34718 L F
.53147 .34842 m .5299 .34743 L p .53063 .34762 L F P
0 g
s
.52687 .34548 m .52687 .34545 L .52839 .34648 L .672 .728 .891 r
F
.52842 .34667 m .52677 .34548 L p .52839 .34648 L F P
0 g
s
.52706 .34557 m .52826 .34655 L .52727 .3456 L .672 .728 .891 r
F
.5299 .34743 m .52639 .3452 L p .53063 .34762 L F P
0 g
s
.53017 .34718 m .52981 .34697 L .52979 .34692 L .672 .728 .891 r
F
.53164 .34899 m .53921 .35444 L p .53487 .35036 L F P
0 g
s
.54007 .35387 m .53147 .34842 L p .53017 .34718 L .672 .728 .891 r
F P
0 g
s
.52835 .34644 m .54007 .35387 L p .53009 .34686 L .672 .728 .891 r
F P
0 g
s
.52702 .34546 m .52728 .34544 L .53194 .34796 L .672 .728 .891 r
F
.52949 .3448 m .52729 .34509 L .52941 .3447 L F
.52724 .34515 m .52675 .34507 L .52719 .34533 L F
.52628 .34507 m .5266 .34501 L .5263 .34509 L F
.52729 .34468 m .52704 .34509 L .52725 .3449 L F
.5266 .34501 m .52736 .34486 L .52664 .34502 L F
.5266 .34501 m .52664 .34502 L .5263 .34509 L F
.52617 .34493 m .52526 .34554 L .5262 .34497 L F
.52561 .3444 m .52563 .34449 L .52563 .3445 L F
.52594 .34456 m .52631 .34494 L .52594 .34455 L F
.52628 .34479 m .52627 .3448 L .52544 .34364 L F
.52622 .3443 m .52621 .34429 L .52621 .3443 L F
.52622 .3443 m .52603 .34423 L .52619 .34427 L F
.52621 .34498 m .52618 .34397 L .52612 .34402 L F
.52596 .34529 m .52678 .3449 L .52596 .34529 L F
.52629 .34514 m .52628 .34514 L .52629 .34514 L F
.52629 .34514 m .52629 .34514 L .52629 .34514 L F
.52629 .34514 m .52629 .34514 L .52634 .34514 L F
.52665 .34492 m .52803 .34417 L .52792 .34421 L F
.52588 .3454 m .52766 .34435 L .52764 .34435 L F
.52633 .34513 m .52629 .34514 L .52634 .34514 L F
.526 .34528 m .52639 .3452 L .52632 .34512 L F
.52596 .34546 m .52599 .34531 L .52627 .34505 L F
.52601 .34527 m .526 .34528 L .52632 .34512 L F
.52632 .34512 m .52632 .34512 L .52678 .3449 L F
.52601 .34527 m .52632 .34512 L .52632 .34512 L F
.52634 .34514 m .52677 .34504 L .52681 .34505 L F
.52577 .34524 m .52633 .34513 L .52634 .34514 L F
.52633 .34513 m .52677 .34504 L .52634 .34514 L F
.52632 .3462 m .52626 .34505 L .52621 .34498 L F
.52646 .34766 m .52635 .34614 L .52632 .3462 L F
.52635 .34614 m .52626 .34505 L .52632 .3462 L F
.5271 .34436 m .52743 .34435 L .5283 .34377 L F
.52679 .34489 m .52678 .34483 L .52958 .34246 L F
.52959 .34248 m .52958 .34246 L .53084 .3414 L F
.52679 .34489 m .52958 .34246 L .52959 .34248 L F
.53212 .34461 m .54518 .34419 L p .53141 .34441 L F P
0 g
s
.53125 .34451 m .53022 .34465 L .53141 .34441 L .672 .728 .891 r
F
.53155 .34445 m .52972 .34454 L .53296 .34485 L F
.54518 .34419 m .53043 .34498 L p .53066 .34465 L F P
0 g
s
.5263 .34509 m .52683 .3452 L .52685 .34528 L .672 .728 .891 r
F
.52726 .34515 m .52946 .34504 L p .52713 .34513 L F P
0 g
s
.5279 .34488 m .52832 .34508 L .52946 .34504 L .672 .728 .891 r
F
.52587 .34426 m .52575 .34329 L .52575 .34329 L F
.52597 .34414 m .52564 .3435 L .52576 .34353 L F
.5255 .34504 m .52538 .34506 L .52567 .34498 L F
.52547 .34502 m .52536 .34506 L .52599 .34506 L F
.52676 .34506 m .5267 .34511 L .52683 .34508 L F
.52639 .3452 m .52682 .34504 L .52723 .34497 L F
.52682 .34511 m .52665 .34502 L .52681 .34505 L F
.52563 .34449 m .52586 .34545 L .52563 .3445 L F
.52596 .34553 m .5249 .34635 L p .52596 .34546 L F P
0 g
s
.52495 .34629 m .5249 .34635 L .52495 .34629 L .672 .728 .891 r
F
.52495 .34629 m .5249 .34635 L .52497 .34616 L F
.52495 .34629 m .52497 .34616 L .52525 .34542 L F
.5249 .34635 m .52596 .34553 L p .52429 .34628 L F P
0 g
s
.52586 .34558 m .52588 .34559 L .52587 .34562 L .672 .728 .891 r
F
.52583 .34546 m .52588 .34559 L .52586 .34558 L F
.52588 .34559 m .52588 .34559 L .52586 .34558 L F
.52595 .34509 m .52495 .34629 L .52551 .34552 L F
.52595 .34535 m .52495 .34629 L .52595 .34535 L F
.52495 .34629 m .52595 .34535 L .52595 .34535 L F
.52495 .34629 m .52595 .34535 L .52595 .34535 L F
.52429 .34628 m .52584 .34558 L .5254 .34556 L F
.52584 .34558 m .52596 .34553 L .52566 .34555 L F
.52584 .34558 m .52566 .34555 L .5254 .34556 L F
.52592 .34514 m .52628 .34507 L .5263 .34509 L F
.52607 .34513 m .52632 .34512 L .52624 .34502 L F
.52583 .34528 m .52586 .34534 L .52586 .3453 L F
.52579 .34526 m .52586 .34534 L .52583 .34528 L F
.52579 .34526 m .52586 .34558 L .52586 .34534 L F
.52586 .34558 m .52591 .34515 L .52586 .34519 L F
.52601 .34507 m .52625 .34503 L .52592 .34514 L F
.52605 .34503 m .52604 .34477 L .52602 .34474 L F
.52615 .3459 m .52607 .34502 L .52605 .34503 L F
.52607 .34502 m .52604 .34477 L .52605 .34503 L F
.5254 .34556 m .52601 .34527 L .52607 .34513 L F
.52601 .34527 m .52632 .34512 L .52607 .34513 L F
.52586 .34454 m .52595 .34538 L .5259 .3446 L F
.52595 .34538 m .52611 .34672 L .52597 .34534 L F
.52595 .34538 m .52597 .34534 L .5259 .3446 L F
.52611 .34672 m .52611 .34676 L .52611 .34672 L F
.54161 .35263 m .54228 .35195 L p .52831 .34559 L F P
0 g
s
.52609 .34658 m .5261 .34658 L .5259 .3446 L .672 .728 .891 r
F
.52593 .34464 m .5259 .3446 L .52681 .34504 L F
.52555 .34416 m .5259 .34531 L .52582 .34527 L F
.52563 .34449 m .52586 .34545 L .52563 .34449 L F
.52563 .3445 m .52579 .34526 L .52586 .34454 L F
.526 .34534 m .52591 .34457 L .526 .34534 L F
.52591 .34457 m .52587 .34426 L .52591 .34457 L F
.52591 .34461 m .52591 .34461 L .526 .34534 L F
.52597 .3451 m .52587 .34426 L .52597 .3451 L F
.526 .34538 m .52591 .34461 L .5259 .3446 L F
.52537 .34471 m .52505 .34426 L .52537 .34471 L F
.52512 .34449 m .52611 .34485 L .52588 .34487 L F
.52589 .34458 m .52586 .34454 L .52659 .3449 L F
.52555 .34416 m .52594 .34465 L .52594 .34456 L F
.52591 .34457 m .52591 .34457 L .52591 .34461 L F
.52586 .34458 m .52586 .34457 L .52681 .34503 L F
.52591 .34457 m .52591 .34461 L .52591 .34461 L F
.52587 .34499 m .5255 .34504 L .52587 .34493 L F
.52587 .34499 m .52587 .34493 L .52599 .34489 L F
.52591 .34457 m .52588 .34425 L .52587 .34426 L F
.52613 .34501 m .52623 .34501 L .5262 .34497 L F
.52577 .34524 m .52592 .34514 L .52581 .34523 L F
.52601 .34538 m .52591 .34461 L .526 .34538 L F
.526 .34528 m .52592 .34457 L .526 .34529 L F
.52613 .34496 m .52587 .34499 L .52599 .34489 L F
.52592 .34495 m .52594 .34508 L .52617 .34493 L F
.52609 .34509 m .52623 .34501 L .52613 .34501 L F
.52594 .34494 m .52592 .34495 L .52617 .34493 L F
.5265 .34499 m .5266 .34501 L .52592 .34514 L F
.52609 .34509 m .52624 .34502 L .52623 .34501 L F
.52628 .34639 m .52621 .34498 L .52617 .34493 L F
.52639 .3452 m .52576 .34485 L p .52647 .34517 L F P
0 g
s
.52597 .34536 m .52639 .3452 L .526 .34528 L .672 .728 .891 r
F
.52625 .34503 m .52627 .34505 L .52592 .34514 L F
.52608 .34511 m .52624 .34502 L .52609 .34509 L F
.52612 .3453 m .52617 .34493 L .52608 .34501 L F
.52592 .34494 m .52639 .3452 L p .526 .34493 L F P
0 g
s
.52538 .34506 m .52526 .345 L .52632 .3448 L .672 .728 .891 r
F
.52674 .34489 m .52586 .34454 L .52574 .34439 L F
.52586 .34457 m .52681 .34502 L .52586 .34457 L F
.52608 .34501 m .52617 .34493 L .52604 .34477 L F
.52613 .34496 m .52599 .34489 L .52617 .34493 L F
.52595 .34514 m .52603 .34493 L .5261 .34493 L F
.5262 .34497 m .5264 .34491 L .52628 .34492 L F
.52611 .34485 m .52642 .34497 L .52617 .34493 L F
.52617 .34493 m .5262 .34497 L .52628 .34492 L F
.52621 .34498 m .52619 .34495 L .52626 .34494 L F
.52681 .34505 m .52586 .34458 L .52681 .34503 L F
.52586 .34457 m .52681 .34502 L .52681 .34503 L F
.52665 .34502 m .52593 .34464 L .52681 .34504 L F
.5264 .34491 m .52678 .34489 L .52677 .34468 L F
.52589 .34458 m .52659 .3449 L .52657 .3449 L F
.52642 .34491 m .52642 .34491 L .5271 .34427 L F
.52595 .34535 m .52595 .34535 L .52675 .3446 L F
.52675 .3446 m .52675 .3446 L .5271 .34427 L F
.52595 .34535 m .52675 .3446 L .52675 .3446 L F
.5254 .3444 m .52541 .3444 L .52683 .34514 L F
.52683 .34515 m .52683 .34514 L .52791 .34571 L F
.5264 .34491 m .52665 .34502 L .52656 .345 L F
.52541 .3444 m .52644 .34491 L .5264 .34491 L F
.52624 .34502 m .5265 .34496 L .5264 .34492 L F
.52652 .34495 m .52678 .34489 L .52644 .34491 L F
.5264 .34492 m .52644 .34491 L .5264 .34491 L F
.52644 .34491 m .52665 .34502 L .5264 .34491 L F
.52624 .34492 m .52628 .34492 L .52651 .34478 L F
.52624 .34492 m .52651 .34478 L .52692 .34453 L F
.52715 .34518 m .52659 .3449 L .52702 .34503 L F
.52659 .3449 m .52586 .34454 L .5267 .3449 L F
.52659 .3449 m .5267 .3449 L .52702 .34503 L F
.52617 .34493 m .52624 .34492 L .52692 .34453 L F
.52734 .34472 m .52623 .34494 L .52632 .3448 L F
.52623 .34494 m .52613 .34496 L .52617 .34493 L F
.52587 .34465 m .52655 .345 L .52655 .345 L F
.52585 .34462 m .52568 .34459 L .52555 .34416 L F
.5254 .3444 m .52587 .34465 L .52587 .34465 L F
.52587 .34465 m .52655 .345 L .52587 .34465 L F
.52623 .34501 m .52637 .34497 L .52625 .34503 L F
.52623 .34501 m .5264 .34491 L .5262 .34497 L F
.52637 .34497 m .52621 .34498 L .52626 .34494 L F
.52625 .34503 m .5265 .34499 L .52627 .34505 L F
.52625 .34503 m .52637 .34497 L .5265 .34499 L F
.52617 .34493 m .52642 .34497 L .5263 .34509 L F
.52623 .34494 m .52617 .34493 L .52628 .34487 L F
.52626 .34505 m .52624 .34477 L .52621 .34498 L F
.52576 .34485 m .52588 .34487 L .526 .34494 L F
.52591 .34487 m .52592 .34494 L .526 .34493 L F
.52611 .34485 m .52617 .34493 L .52588 .34487 L F
.52617 .34493 m .52599 .34489 L .52611 .34486 L F
.5267 .3449 m .52586 .34454 L .52674 .34489 L F
.52598 .3447 m .52683 .34514 L .52598 .3447 L F
.52624 .34478 m .52617 .34493 L .52657 .34471 L F
.52628 .34487 m .52617 .34493 L .52632 .3448 L F
.52608 .34481 m .52657 .34471 L .52648 .34469 L F
.52625 .34486 m .5263 .34465 L .52624 .34477 L F
.52591 .34461 m .52591 .34461 L .52597 .3451 L F
.52594 .34465 m .52639 .3452 L .52594 .34456 L F
.5251 .34446 m .52535 .3444 L .52642 .34497 L F
.52496 .34441 m .52506 .34441 L .5251 .34446 L F
.52506 .34441 m .52535 .3444 L .5251 .34446 L F
.52611 .34676 m .52628 .34754 L .52618 .34679 L F
.52617 .34493 m .52611 .34486 L .52617 .34493 L F
.52583 .3446 m .52584 .34458 L .52665 .34502 L F
.52621 .34498 m .52611 .344 L .52604 .34477 L F
.52608 .34481 m .52617 .34493 L .52624 .34478 L F
.52748 .34555 m .52604 .34477 L .52737 .34543 L F
.52624 .34477 m .5262 .34485 L .52621 .34498 L F
.52617 .34493 m .52611 .34486 L .52632 .3448 L F
.52608 .34481 m .52594 .34494 L .52617 .34493 L F
.5261 .34493 m .52603 .34493 L .52611 .34486 L F
.52608 .34481 m .5259 .34488 L .52577 .34484 L F
.52632 .3448 m .52594 .34487 L .52608 .34481 L F
.52594 .34487 m .5259 .34488 L .52608 .34481 L F
.52596 .34494 m .526 .34494 L .52647 .34517 L F
.52608 .34481 m .52577 .34484 L .5261 .34485 L F
.52577 .34484 m .52579 .34484 L .52625 .34485 L F
.5261 .34493 m .52611 .34486 L .52613 .34488 L F
.52579 .34484 m .52614 .34489 L .5261 .34485 L F
.52576 .34485 m .526 .34494 L .52596 .34494 L F
.5259 .34488 m .52574 .34491 L .52576 .34485 L F
.52576 .34485 m .52496 .34441 L p .52588 .34487 L F P
0 g
s
.5259 .34488 m .52576 .34485 L .52577 .34484 L .672 .728 .891 r
F
.52576 .34485 m .52592 .34494 L p .52585 .34485 L F P
0 g
s
.52579 .34479 m .52577 .34484 L .52585 .34485 L .672 .728 .891 r
F
.52577 .34484 m .52576 .34485 L .52585 .34485 L F
.52592 .34494 m .52592 .34494 L .526 .34493 L F
.52611 .3448 m .52595 .34494 L .52608 .34481 L F
.52563 .34518 m .52562 .34519 L .52566 .34519 L F
.52557 .34528 m .52563 .34518 L .52577 .34524 L F
.52592 .34495 m .52526 .34554 L .52594 .34508 L F
.52595 .34494 m .52523 .34557 L .52594 .34494 L F
.52588 .34487 m .52617 .34493 L .5263 .34509 L F
.52595 .34494 m .52594 .34494 L .52608 .34481 L F
.52595 .34488 m .52603 .34493 L .52601 .34489 L F
.52541 .34507 m .52538 .34506 L .52626 .34494 L F
.52587 .34562 m .52632 .34677 L .52611 .34673 L F
.52611 .34676 m .52618 .34679 L .52616 .3466 L F
.52611 .34672 m .52616 .3466 L .5259 .3446 L F
.52611 .34676 m .52616 .3466 L .52611 .34672 L F
.52588 .34559 m .52632 .34677 L .52587 .34562 L F
.526 .34623 m .52606 .34626 L .52586 .34454 L F
.52599 .34535 m .52489 .34651 L .52597 .34528 L F
.52585 .34567 m .52489 .34651 L p .52599 .34535 L F P
0 g
s
.52613 .34631 m .526 .34528 L .526 .34529 L .672 .728 .891 r
F
.52611 .34672 m .52611 .34672 L .5261 .34658 L F
.52611 .34672 m .5261 .34658 L .52609 .34658 L F
.52586 .34558 m .526 .34623 L .52593 .34543 L F
.52606 .34578 m .526 .34534 L .526 .34534 L F
.52613 .34631 m .52617 .34633 L .52593 .34464 L F
.52593 .34463 m .52593 .34464 L .52588 .34425 L F
.52613 .34631 m .52593 .34464 L .52593 .34463 L F
.52599 .3447 m .52671 .34508 L .52671 .34508 L F
.52561 .3444 m .52563 .34449 L .52561 .3444 L F
.52563 .34449 m .52563 .34449 L .52561 .3444 L F
.52593 .34464 m .52535 .34432 L .5259 .3446 L F
.52555 .34416 m .52561 .3444 L .52561 .3444 L F
.52594 .34465 m .52584 .3446 L .52555 .34416 L F
.52555 .34416 m .52563 .3445 L .52586 .34454 L F
.52586 .34458 m .52535 .34432 L .52586 .34457 L F
.52535 .34432 m .52586 .34457 L .52586 .34457 L F
.52587 .34464 m .52587 .34464 L .52541 .3444 L F
.52598 .3447 m .52598 .3447 L .52541 .3444 L F
.52535 .34432 m .52547 .34434 L .52586 .34454 L F
.52535 .34432 m .52586 .34454 L .52589 .34458 L F
.52541 .3444 m .52584 .34458 L .52583 .3446 L F
.52604 .34477 m .52486 .34413 L .52599 .34471 L F
.52486 .34413 m .52383 .34358 L .52484 .3441 L F
.52486 .34413 m .52484 .3441 L .52599 .34471 L F
.52553 .34436 m .52591 .34485 L .52588 .34457 L F
.52571 .34484 m .52589 .34486 L .52579 .34484 L F
.52385 .34358 m .52483 .34409 L .52483 .34409 L F
.5251 .34446 m .52611 .34485 L .52512 .34449 L F
.52358 .34326 m .52576 .34485 L .52579 .34479 L F
.52401 .34361 m .51179 .33707 L .52487 .34375 L F
.52335 .3431 m .52356 .34325 L .52358 .34326 L F
.52336 .34332 m .52344 .3433 L .52549 .3444 L F
.52356 .34325 m .52576 .34485 L .52358 .34326 L F
.52574 .34491 m .52414 .34521 L .52577 .34484 L F
.52577 .34484 m .52571 .34484 L .52579 .34484 L F
.52634 .34492 m .52639 .34491 L .52737 .34543 L F
.52683 .34514 m .52656 .345 L .52656 .345 L F
.5263 .34509 m .52642 .34497 L .52683 .3452 L F
.52656 .345 m .52665 .34502 L .52682 .34511 L F
.52668 .34503 m .52639 .3452 L .52675 .34507 L F
.52685 .34528 m .52683 .3452 L .52728 .34544 L F
.52703 .34535 m .52703 .34537 L .52722 .34552 L F
.52671 .34508 m .52714 .34531 L .52714 .34531 L F
.52675 .34507 m .52708 .34558 L .52719 .34533 L F
.52489 .34651 m .52503 .34613 L .52597 .34528 L F
.52489 .34651 m .52585 .34567 L p .52454 .34645 L F P
0 g
s
.52454 .34645 m .52585 .34567 L .52581 .34566 L .672 .728 .891 r
F
.52581 .34542 m .52586 .34566 L .52585 .34567 L F
.52584 .34566 m .52585 .34567 L .52584 .3457 L F
.52581 .34542 m .52585 .34567 L .52584 .34566 L F
.52608 .34572 m .52586 .34567 L .52581 .34542 L F
.52584 .34566 m .52585 .34547 L .52583 .34545 L F
.52584 .3457 m .52584 .34565 L .52584 .34566 L F
.52584 .34565 m .52585 .34547 L .52584 .34566 L F
.52584 .3457 m .52587 .3455 L .52585 .34547 L F
.52562 .34562 m .52589 .34556 L .52571 .34555 L F
.52601 .34534 m .52608 .34572 L .52581 .34542 L F
.52601 .34553 m .52585 .34567 L p .5259 .34555 L F P
0 g
s
.52601 .34553 m .5259 .34555 L .52599 .34535 L .672 .728 .891 r
F
.52589 .34556 m .52601 .34553 L .5259 .34554 L F
.52581 .34542 m .52584 .34566 L .52583 .34545 L F
.52589 .34556 m .5259 .34554 L .52571 .34555 L F
.52454 .34645 m .52581 .34566 L .52562 .34562 L F
.52584 .34566 m .52584 .34566 L .52583 .34545 L F
.52581 .34566 m .52601 .34553 L .52562 .34562 L F
.52584 .34566 m .52584 .3457 L .52584 .34566 L F
.52639 .3452 m .52632 .34479 L p .52626 .34505 L F P
0 g
s
.52655 .345 m .52683 .34514 L .52655 .345 L .672 .728 .891 r
F
.52639 .3452 m .52622 .34488 L .52624 .34486 L F
.52639 .3452 m .52627 .34505 L .5262 .34484 L F
.52616 .34492 m .52639 .3452 L .52668 .34503 L F
.52595 .34535 m .5271 .34427 L .5271 .34427 L F
.52648 .34469 m .52657 .34471 L .52677 .34461 L F
.52707 .34436 m .5271 .34436 L .52773 .34405 L F
.52608 .34482 m .52773 .34405 L .52772 .34405 L F
.5271 .34427 m .52675 .3446 L .5271 .34427 L F
.52675 .3446 m .52675 .3446 L .5271 .34427 L F
.52731 .34434 m .52692 .34449 L .5279 .34352 L F
.52608 .34481 m .52692 .34453 L .52813 .34378 L F
.52772 .34405 m .52773 .34405 L .5283 .34377 L F
.52857 .34352 m .52679 .34489 L p .5285 .34342 L F P
0 g
s
.52809 .34378 m .52813 .34378 L .52857 .34352 L .672 .728 .891 r
F
.52809 .34378 m .52857 .34352 L .52865 .34347 L F
.52806 .34377 m .52809 .34378 L .52865 .34347 L F
.52608 .34481 m .52813 .34378 L .52806 .34377 L F
.52616 .34492 m .52639 .3452 L .52616 .34492 L F
.52639 .34675 m .52639 .3452 L .52626 .34505 L F
.52646 .34766 m .52643 .34671 L .52639 .34675 L F
.52643 .34671 m .52639 .3452 L .52639 .34675 L F
.52646 .34562 m .52618 .34491 L .52621 .34488 L F
.52603 .34493 m .52639 .3452 L .52616 .34492 L F
.52495 .34574 m .52538 .34558 L .52607 .34513 L F
.52608 .34511 m .52607 .34513 L .52624 .34502 L F
.52495 .34574 m .52607 .34513 L .52608 .34511 L F
.526 .34529 m .52597 .3451 L .52597 .3451 L F
.526 .34534 m .526 .34529 L .526 .34529 L F
.526 .34529 m .52597 .3451 L .526 .34529 L F
.52634 .34643 m .52621 .34498 L .52628 .34639 L F
.52631 .34523 m .52614 .34498 L .52618 .34491 L F
.52624 .34688 m .52605 .34503 L .52599 .34508 L F
.52634 .34758 m .52626 .34686 L .52624 .34688 L F
.52626 .34686 m .52605 .34503 L .52624 .34688 L F
.53043 .34498 m .52946 .34504 L p .53066 .34465 L F P
0 g
s
.52946 .34504 m .5288 .34493 L .53066 .34465 L .672 .728 .891 r
F
.52679 .34506 m .52675 .34507 L .52724 .34515 L F
.52682 .34507 m .52694 .34513 L .52713 .34513 L F
.52686 .34507 m .52713 .34513 L .52832 .34508 L F
.52682 .34507 m .52713 .34513 L .52686 .34507 L F
.53536 .34936 m .52731 .34516 L .5359 .3503 L F
.52731 .34516 m .52697 .34499 L .52724 .34515 L F
.52731 .34516 m .52724 .34515 L .53591 .35031 L F
.5359 .3503 m .53591 .35031 L .54086 .35327 L F
.52731 .34516 m .53591 .35031 L .5359 .3503 L F
.52726 .34515 m .52729 .34509 L .53066 .34465 L F
.52975 .34517 m .53267 .34514 L p .5296 .34497 L F P
0 g
s
.53267 .34514 m .53653 .34509 L p .5296 .34497 L .672 .728 .891 r
F P
0 g
s
.52941 .3447 m .5296 .34497 L .53653 .34509 L .672 .728 .891 r
F
.53241 .34514 m .5282 .34518 L p .53257 .34486 L F P
0 g
s
.52604 .34521 m .52597 .34528 L .52607 .34515 L .672 .728 .891 r
F
.52615 .3459 m .52622 .346 L .52608 .34501 L F
.52615 .3459 m .52608 .34501 L .52607 .34502 L F
.52631 .34523 m .52601 .34534 L .526 .34531 L F
.5263 .34465 m .52618 .34396 L p .52624 .34477 L F P
0 g
s
.52628 .34465 m .52627 .3447 L .5263 .34465 L .672 .728 .891 r
F
.52628 .34465 m .52627 .3447 L .52628 .34465 L F
.52628 .34465 m .52627 .34471 L .52627 .3447 L F
.52624 .34477 m .52618 .34396 L .5262 .34485 L F
.52628 .34465 m .52608 .34481 L .52627 .34471 L F
.52618 .34397 m .52618 .34396 L .52618 .34397 L F
.52618 .34397 m .52618 .34397 L .52612 .34402 L F
.52606 .34395 m .526 .34374 L p .52604 .34397 L F P
0 g
s
.52618 .34396 m .52629 .34462 L p .52585 .34379 L .672 .728 .891 r
F P
0 g
s
.52678 .34478 m .52676 .34466 L .52692 .34449 L .672 .728 .891 r
F
.52628 .34492 m .5264 .34491 L .52709 .34447 L F
.52692 .34453 m .52709 .34447 L .52865 .34347 L F
.52596 .34546 m .5271 .34427 L .52714 .34427 L F
.52675 .3446 m .52642 .34491 L .52675 .3446 L F
.52628 .34492 m .52709 .34447 L .52692 .34453 L F
.52625 .34485 m .52661 .34495 L .52643 .34485 L F
.5261 .34485 m .52622 .34487 L .52625 .34485 L F
.52626 .34505 m .52632 .34479 L .52629 .34478 L F
.52622 .34487 m .52661 .34495 L .52625 .34485 L F
.52628 .34483 m .5263 .34465 L .52625 .34486 L F
.52632 .34479 m .5263 .34465 L p .52629 .34478 L F P
0 g
s
.52629 .34462 m .52632 .34479 L p .52623 .34477 L .672 .728 .891 r
F P
0 g
s
.52637 .34497 m .52626 .34494 L .52654 .34491 L .672 .728 .891 r
F
.52729 .34468 m .52722 .34508 L .52736 .34469 L F
.52659 .34494 m .52654 .34491 L .52907 .34459 L F
.52637 .34497 m .52654 .34491 L .52659 .34494 L F
.52632 .3448 m .52639 .3452 L .52625 .34485 L F
.52632 .34479 m .52632 .3448 L p .52632 .3448 L F P
0 g
s
.52756 .34478 m .52613 .34496 L .52759 .34472 L .672 .728 .891 r
F
.52768 .34474 m .52759 .34472 L .52784 .34468 L F
.52756 .34478 m .52759 .34472 L .52768 .34474 L F
.52624 .34473 m .52603 .34493 L .52627 .34467 L F
.52589 .34486 m .52616 .34492 L .52614 .34489 L F
.53211 .34825 m .52953 .34688 L .53194 .34796 L F
.52953 .34688 m .52976 .34687 L .53194 .34796 L F
.52639 .3452 m .52647 .34517 L .53194 .34796 L F
.52937 .34648 m .52937 .34647 L .53009 .34686 L F
.5301 .34697 m .52793 .34579 L .53009 .34686 L F
.52793 .34579 m .52791 .34571 L .53009 .34686 L F
.53194 .34796 m .5301 .34697 L .53009 .34686 L F
.54086 .35327 m .53223 .34846 L p .53194 .34796 L F P
0 g
s
.52945 .34647 m .52805 .34583 L .54086 .35327 L .672 .728 .891 r
F
.52714 .34531 m .52937 .34647 L .52937 .34648 L F
.53009 .34686 m .52791 .34569 L .52788 .34554 L F
.52726 .34516 m .52805 .34583 L .52945 .34647 L F
.52717 .3452 m .52715 .34518 L .52788 .34554 L F
.52683 .34514 m .52682 .34511 L .52937 .34647 L F
.52791 .34569 m .52682 .34511 L .52788 .34554 L F
.52714 .34531 m .52937 .34647 L .52714 .34531 L F
.52671 .34508 m .52937 .34647 L .52671 .34508 L F
.52788 .34554 m .52715 .34518 L .52702 .34503 L F
.52726 .34516 m .52719 .34533 L .52805 .34583 L F
.52953 .34688 m .52639 .3452 L .52976 .34687 L F
.53223 .34846 m .53181 .34822 L p .53211 .34825 L F P
0 g
s
.53181 .34822 m .52639 .3452 L p .53211 .34825 L .672 .728 .891 r
F P
0 g
s
.52793 .34579 m .52748 .34555 L .52791 .34571 L .672 .728 .891 r
F
.52748 .34555 m .52737 .34543 L .52791 .34571 L F
.52708 .34558 m .54086 .35327 L p .52719 .34533 L F P
0 g
s
.53019 .3468 m .52719 .34544 L .5302 .34667 L .672 .728 .891 r
F
.52598 .3447 m .52671 .34508 L .52599 .3447 L F
.52632 .3448 m .52608 .34481 L .52625 .34485 L F
.52632 .34479 m .52625 .34485 L .52623 .34477 L F
.52614 .34498 m .52616 .34492 L .52618 .34491 L F
.52616 .34492 m .52637 .34497 L .52614 .34489 L F
.52513 .34562 m .52609 .34509 L .52613 .34501 L F
.52597 .34528 m .52595 .34514 L .52616 .34491 L F
.52622 .34488 m .5262 .34484 L .52624 .34486 L F
.52623 .34477 m .52617 .34472 L .52621 .34474 L F
.52632 .3448 m .52639 .3452 L p .52632 .3448 L F P
0 g
s
.52626 .34505 m .52628 .34483 L .52625 .34486 L .672 .728 .891 r
F
.52619 .3449 m .52637 .34497 L .52661 .34495 L F
.52614 .34489 m .52618 .34491 L .52619 .3449 L F
.52618 .34491 m .52637 .34497 L .52619 .3449 L F
.52625 .34485 m .52621 .34481 L .52623 .34477 L F
.52639 .3452 m .52624 .34486 L .52625 .34485 L F
.52624 .34486 m .52621 .34481 L .52625 .34485 L F
.52621 .34481 m .52617 .34472 L .52623 .34477 L F
.5268 .34505 m .52681 .34504 L .52681 .34505 L F
.52681 .34505 m .52692 .34501 L .52682 .34504 L F
.52677 .34504 m .52692 .34501 L .52681 .34505 L F
.52682 .34504 m .52692 .34501 L .52723 .34497 L F
.52703 .34514 m .52723 .34497 L .52825 .34483 L F
.52661 .34495 m .52678 .34505 L .52817 .34508 L F
.52819 .34507 m .52817 .34508 L .52832 .34508 L F
.52661 .34495 m .52817 .34508 L .52819 .34507 L F
.52624 .34492 m .52616 .34492 L .52665 .34437 L F
.52616 .34492 m .52618 .34489 L .52665 .34437 L F
.5263 .34465 m .52627 .34471 L .52636 .34467 L F
.52635 .34463 m .52624 .34473 L .52631 .34462 L F
.52624 .34473 m .52627 .34467 L .52631 .34462 L F
.52614 .34489 m .52661 .34495 L .5261 .34485 L F
.52638 .3449 m .52625 .34492 L .52665 .34439 L F
.52621 .34474 m .52612 .34462 L .52617 .34463 L F
.52592 .34457 m .52588 .34425 L .52591 .34457 L F
.52624 .34486 m .5262 .34484 L .52621 .34481 L F
.52628 .34465 m .52636 .34467 L .52848 .34355 L F
.52618 .34489 m .52624 .34473 L .52674 .34427 L F
.52602 .34474 m .52604 .34477 L .52594 .34403 L F
.52714 .34427 m .5271 .34427 L .5279 .34352 L F
.52833 .34349 m .52731 .34434 L .5279 .34352 L F
.5271 .34427 m .5271 .34427 L .52789 .34352 L F
.5271 .34427 m .5271 .34427 L .52789 .34352 L F
.52707 .344 m .52628 .34465 L .52848 .34355 L F
.5279 .34352 m .52789 .34352 L .52789 .34352 L F
.53084 .3414 m .52833 .34349 L .5279 .34352 L F
.52881 .34258 m .52707 .344 L .52865 .34347 L F
.52707 .344 m .52848 .34355 L .52865 .34347 L F
.52675 .34488 m .52573 .34434 L .52645 .3449 L F
.52591 .34461 m .52575 .34329 L .52591 .34461 L F
.52597 .3451 m .52587 .34426 L .52587 .34426 L F
.52591 .34461 m .52575 .34329 L .5259 .3446 L F
.52587 .34426 m .52588 .34425 L .52575 .34329 L F
.5261 .34468 m .52588 .34457 L .52564 .3435 L F
.52586 .34454 m .52436 .34379 L .52555 .34416 L F
.52568 .34431 m .52553 .34436 L .52588 .34457 L F
.52588 .34457 m .52585 .34455 L .52585 .34453 L F
.52555 .34416 m .5259 .3446 L .52574 .3433 L F
.52588 .34457 m .52585 .34453 L .52564 .3435 L F
.52623 .34475 m .52621 .34476 L .52624 .34473 L F
.52586 .34456 m .52588 .34457 L .5261 .34468 L F
.52617 .34472 m .52612 .34462 L .52621 .34474 L F
.52618 .34491 m .52592 .34422 L .52621 .34488 L F
.52592 .34422 m .52591 .34418 L .52592 .34422 L F
.52604 .34477 m .52602 .34305 L .52582 .34321 L F
.52602 .34305 m .52602 .34298 L .52599 .34301 L F
.52602 .34305 m .52599 .34301 L .52582 .34321 L F
.52914 .34621 m .52737 .34544 L .52911 .34611 L F
.52719 .34544 m .52721 .34538 L .5302 .34667 L F
.52496 .34441 m .5251 .34446 L .52512 .34449 L F
.52421 .34399 m .52576 .34485 L p .52475 .34412 L F P
0 g
s
.5245 .34421 m .52454 .34422 L .52586 .34479 L .672 .728 .891 r
F
.5259 .34554 m .52601 .34553 L .52596 .34539 L F
.52584 .3457 m .52584 .3457 L .52584 .34568 L F
.52629 .34676 m .52634 .34703 L .52611 .34673 L F
.52632 .34677 m .52634 .34703 L .52629 .34676 L F
.52632 .34677 m .52648 .34719 L .52634 .34703 L F
.52634 .34758 m .52646 .34766 L .52622 .346 L F
.52634 .34758 m .52622 .346 L .52615 .3459 L F
.52628 .34754 m .52601 .34538 L .526 .34538 L F
.52628 .34754 m .52606 .34578 L .52606 .34578 L F
.526 .34623 m .52611 .34676 L .52606 .34626 L F
.52628 .34754 m .52634 .34758 L .52617 .34633 L F
.52628 .34754 m .52617 .34633 L .52613 .34631 L F
.52648 .34719 m .52966 .35765 L .52624 .34737 L F
.52723 .35028 m .52684 .34793 L p .52677 .34984 L F P
0 g
s
.52677 .34984 m .52684 .34793 L .52646 .34766 L .672 .728 .891 r
F
.52642 .34819 m .52655 .34827 L .52646 .34766 L F
.52642 .34819 m .52646 .34766 L .52634 .34758 L F
.52628 .34754 m .52642 .34819 L .52634 .34758 L F
.52642 .34819 m .52677 .34984 L .52655 .34827 L F
.52848 .35777 m .52723 .35028 L p .52677 .34984 L F P
0 g
s
.52608 .34572 m .52848 .35777 L .52586 .34567 L .672 .728 .891 r
F
.52584 .3457 m .52607 .34575 L .52584 .34568 L F
.52568 .34431 m .52588 .34457 L .52645 .3449 L F
.52621 .34471 m .5262 .34471 L .52645 .3449 L F
.52611 .344 m .52603 .34391 L .52604 .34477 L F
.52573 .34434 m .5262 .34471 L .52621 .34471 L F
.52573 .34434 m .52572 .34434 L .5262 .34471 L F
.52629 .34462 m .52623 .34477 L .52585 .34379 L F
.52675 .34488 m .52593 .34463 L .52593 .34445 L F
.52586 .34456 m .52585 .34455 L .52588 .34457 L F
.52483 .34409 m .52598 .3447 L .52599 .3447 L F
.52541 .3444 m .52598 .3447 L .52541 .3444 L F
.52541 .3444 m .52549 .3444 L .52584 .34458 L F
.52732 .34543 m .52733 .34543 L .5302 .34667 L F
.52737 .34544 m .52721 .34538 L .52729 .34535 L F
.52737 .34544 m .52729 .34535 L .52911 .34611 L F
.52619 .34527 m .52617 .34493 L .52612 .3453 L F
.52631 .34523 m .526 .34531 L .52614 .34498 L F
.52597 .34528 m .52616 .34491 L .5262 .34497 L F
.52614 .34497 m .52612 .34496 L .52615 .34493 L F
.52614 .34497 m .52615 .34493 L .52616 .34492 L F
.52614 .34498 m .52614 .34497 L .52616 .34492 L F
.52616 .34492 m .52616 .34491 L .52618 .34489 L F
.52608 .34481 m .5261 .34485 L .52625 .34485 L F
.52603 .34493 m .52602 .34493 L .52627 .34466 L F
.52627 .34467 m .52627 .34466 L .52631 .34462 L F
.52603 .34493 m .52627 .34466 L .52627 .34467 L F
.52616 .34484 m .52615 .34482 L .52621 .34476 L F
.52613 .34488 m .52615 .34482 L .52616 .34484 L F
.52613 .34488 m .52611 .34486 L .52615 .34482 L F
.52618 .34489 m .52595 .34466 L .5261 .34468 L F
.52595 .34466 m .52589 .34458 L .5261 .34468 L F
.52618 .34491 m .52617 .3449 L .52618 .34489 L F
.52617 .3449 m .52586 .34456 L .52618 .34489 L F
.5261 .34484 m .52609 .34483 L .52627 .34466 L F
.52627 .34466 m .52627 .34466 L .52631 .34462 L F
.5261 .34484 m .52627 .34466 L .52627 .34466 L F
.52631 .34462 m .52611 .3448 L .52608 .34481 L F
.52631 .34462 m .52609 .34483 L .52608 .34482 L F
.5262 .34484 m .52591 .34418 L .52597 .34414 L F
.52621 .34488 m .5262 .34484 L .5262 .34484 L F
.5262 .34484 m .52591 .34418 L .5262 .34484 L F
.52613 .34488 m .52621 .34476 L .52623 .34475 L F
.52621 .34481 m .5262 .34484 L .52612 .34462 L F
.52588 .34457 m .52616 .34492 L .52645 .3449 L F
.52588 .34457 m .52616 .34492 L .52588 .34457 L F
.52601 .34493 m .52599 .34494 L .52609 .34483 L F
.52593 .34502 m .52609 .34483 L .5261 .34484 L F
.52616 .34491 m .52624 .34473 L .52618 .34489 L F
.5254 .34556 m .52596 .34529 L .52596 .34529 L F
.52552 .34551 m .52551 .34552 L .52552 .34551 L F
.52542 .34556 m .52564 .34548 L .52568 .34543 L F
.52564 .34548 m .52597 .34536 L .52568 .34543 L F
.52568 .34543 m .52597 .34536 L .526 .34528 L F
.5254 .34556 m .526 .34528 L .52601 .34527 L F
.52597 .34528 m .52516 .34601 L .52595 .34514 L F
.52579 .34523 m .52601 .34534 L .52581 .34542 L F
.52603 .34493 m .52593 .34502 L .52602 .34493 L F
.52598 .34494 m .52598 .34494 L .52599 .34494 L F
.52593 .34502 m .52598 .34494 L .52598 .34494 L F
.52593 .34502 m .52593 .34499 L .52598 .34494 L F
.52593 .34502 m .52599 .34494 L .52601 .34493 L F
.5255 .34504 m .52567 .34498 L .52632 .3448 L F
.52571 .34484 m .52563 .34501 L .52609 .34498 L F
.52595 .34514 m .5261 .34493 L .52615 .34492 L F
.52609 .34498 m .52547 .34502 L .52603 .34503 L F
.52595 .34514 m .52593 .34502 L .52603 .34493 L F
.52124 .34553 m .52303 .34542 L .5212 .34551 L F
.52303 .34542 m .5258 .34526 L .52302 .34541 L F
.52303 .34542 m .52302 .34541 L .5212 .34551 L F
.52415 .34692 m .5249 .34635 L p .5248 .34633 L F P
0 g
s
.52429 .34628 m .52415 .34692 L .5248 .34633 L .672 .728 .891 r
F
.514 .35471 m .52415 .34692 L p .52429 .34628 L F P
0 g
s
.52489 .34651 m .51493 .35522 L p .52503 .34613 L .672 .728 .891 r
F P
0 g
s
.52301 .34844 m .52293 .34833 L .52429 .34683 L .672 .728 .891 r
F
.5261 .34493 m .52613 .34488 L .52615 .34492 L F
.52603 .34493 m .52616 .34492 L .52616 .34492 L F
.52615 .34492 m .52613 .34488 L .52616 .34491 L F
.52601 .34489 m .52616 .34492 L .52588 .34457 L F
.52603 .34493 m .52616 .34492 L .52601 .34489 L F
.52495 .34574 m .52608 .34511 L .52609 .34509 L F
.52614 .34498 m .526 .34531 L .52596 .34509 L F
.52513 .34564 m .52609 .34509 L .52513 .34562 L F
.52608 .34482 m .52532 .34559 L .52523 .34557 L F
.52571 .34484 m .52613 .34495 L .52616 .34493 L F
.52571 .34484 m .52609 .34498 L .52613 .34495 L F
.52579 .34479 m .52592 .34494 L .52591 .34487 L F
.52608 .34481 m .52523 .34557 L .52527 .34548 L F
.52571 .34484 m .52637 .34497 L .52589 .34486 L F
.52589 .34486 m .52614 .34489 L .52579 .34484 L F
.52591 .34485 m .52595 .34488 L .52588 .34457 L F
.526 .34529 m .52592 .34457 L .52591 .34457 L F
.52595 .34488 m .52601 .34489 L .52588 .34457 L F
.52612 .34496 m .52596 .34509 L .52585 .34455 L F
.52614 .34498 m .52596 .34509 L .52612 .34496 L F
.52616 .34493 m .52621 .34497 L .52617 .34493 L F
.52613 .34495 m .52621 .34497 L .52616 .34493 L F
.52559 .34343 m .52562 .34346 L .52555 .34317 L F
.52562 .34386 m .52555 .34317 L .52558 .34387 L F
.52559 .3442 m .52547 .3433 L .52541 .34338 L F
.52544 .34364 m .52564 .34374 L .52574 .3433 L F
.5256 .34327 m .52577 .34415 L .52556 .34329 L F
.52301 .34553 m .52257 .34539 L .52489 .34513 L F
.52477 .34523 m .52489 .34513 L .52609 .345 L F
.52302 .34541 m .5258 .34526 L .52299 .34538 L F
.52301 .34553 m .52489 .34513 L .52477 .34523 L F
.52604 .34521 m .52607 .34515 L .5262 .34497 L F
.52628 .34639 m .52619 .34527 L .52612 .3453 L F
.52646 .34562 m .52613 .34592 L .52601 .34534 L F
.52611 .34583 m .52614 .34587 L .52612 .34543 L F
.52312 .34552 m .52467 .34537 L p .52303 .34542 L F P
0 g
s
.52301 .34553 m .52547 .3451 L .52555 .34514 L .672 .728 .891 r
F
.52473 .34516 m .52479 .34522 L .5257 .34518 L F
.52625 .34503 m .52604 .34521 L .5262 .34497 L F
.52664 .34502 m .52736 .34486 L .52674 .34503 L F
.5265 .34499 m .52736 .34486 L .5266 .34501 L F
.5279 .34488 m .52661 .34495 L .52832 .34508 L F
.5265 .34499 m .52637 .34497 L .52736 .34486 L F
.52675 .34488 m .52645 .3449 L .52675 .34507 L F
.52639 .3452 m .52633 .34522 L .52627 .34505 L F
.52895 .34468 m .52637 .34497 L .52907 .34459 L F
.52643 .34485 m .52661 .34495 L .5279 .34488 L F
.52675 .34488 m .52639 .3452 L p .5267 .34462 L F P
0 g
s
.52646 .34562 m .52601 .34534 L .52631 .34523 L .672 .728 .891 r
F
.52639 .3452 m .52601 .34553 L p .52632 .34512 L F P
0 g
s
.52626 .34504 m .52676 .34507 L .52625 .34503 L .672 .728 .891 r
F
.52645 .3449 m .52616 .34492 L .52668 .34503 L F
.52665 .34502 m .52681 .34504 L .5268 .34505 L F
.52661 .34495 m .52609 .34498 L .52678 .34505 L F
.52639 .3452 m .52632 .34512 L .5267 .34462 L F
.52625 .34503 m .52676 .34507 L .52681 .34505 L F
.52603 .34503 m .52626 .34504 L .52625 .34503 L F
.52601 .34553 m .52597 .34528 L .52625 .34503 L F
.526 .34493 m .52639 .3452 L .52603 .34493 L F
.52609 .34498 m .52603 .34503 L .52678 .34505 L F
.52632 .34512 m .52625 .34503 L .5267 .34462 L F
.52601 .34553 m .52625 .34503 L .52632 .34512 L F
.52634 .34514 m .52653 .34515 L .52656 .34514 L F
.52564 .34515 m .52635 .34515 L .52634 .34514 L F
.52635 .34515 m .52653 .34515 L .52634 .34514 L F
.52601 .34553 m .52639 .3452 L p .52596 .34539 L F P
0 g
s
.5254 .34556 m .52542 .34556 L .526 .34528 L .672 .728 .891 r
F
.52516 .34601 m .52593 .34502 L .52595 .34514 L F
.52553 .34508 m .52564 .34515 L .52656 .34514 L F
.52655 .345 m .52683 .34514 L .52683 .34515 L F
.52683 .34514 m .52683 .34514 L .52656 .345 L F
.5263 .34509 m .52728 .34544 L .52702 .34546 L F
.52656 .345 m .52682 .34511 L .52683 .34514 L F
.52639 .3452 m .52708 .34558 L p .52675 .34507 L F P
0 g
s
.52661 .34512 m .52656 .34514 L .52694 .34513 L .672 .728 .891 r
F
.52553 .34508 m .52656 .34514 L .52661 .34512 L F
.52564 .34515 m .5257 .34518 L .52585 .34518 L F
.52589 .34515 m .52585 .34518 L .52653 .34515 L F
.52516 .34601 m .52504 .34585 L .52593 .34502 L F
.52564 .34515 m .52585 .34518 L .52589 .34515 L F
.52572 .3443 m .52596 .34509 L .52569 .34439 L F
.52577 .34428 m .52596 .34509 L .52572 .3443 L F
.52596 .34509 m .52593 .34511 L .52569 .34439 L F
.52596 .34509 m .52601 .34534 L .52593 .34511 L F
.52589 .34523 m .52579 .34523 L p .52617 .34493 L F P
0 g
s
.52613 .34495 m .52609 .34498 L .52621 .34497 L .672 .728 .891 r
F
.52676 .34507 m .52694 .34513 L .52682 .34507 L F
.52609 .34483 m .52532 .34559 L .52608 .34482 L F
.52547 .3451 m .52609 .345 L .52555 .34514 L F
.52848 .35777 m .52728 .35783 L p .526 .34707 L F P
0 g
s
.52615 .34711 m .52848 .35777 L .526 .34707 L .672 .728 .891 r
F
.52586 .34566 m .52848 .35777 L .52584 .3457 L F
.52646 .34766 m .52677 .34787 L .52639 .3452 L F
.52684 .34793 m .52682 .34782 L p .52677 .34787 L F P
0 g
s
.52682 .34782 m .52639 .3452 L p .52677 .34787 L .672 .728 .891 r
F P
0 g
s
.52646 .34766 m .52634 .34643 L .52628 .34639 L .672 .728 .891 r
F
.52646 .34562 m .52848 .35777 L p .52613 .34592 L F P
0 g
s
.52674 .35014 m .52642 .3456 L p .52634 .34989 L .672 .728 .891 r
F P
0 g
s
.52549 .34506 m .52661 .34512 L .52676 .34507 L .672 .728 .891 r
F
.52553 .34508 m .52661 .34512 L .52549 .34506 L F
.52605 .34532 m .52675 .34488 L .5267 .34489 L F
.52603 .34503 m .52599 .34506 L .52676 .34507 L F
.52639 .3452 m .52589 .34523 L p .52617 .34493 L F P
0 g
s
.52625 .34503 m .52622 .345 L .52797 .34579 L .672 .728 .891 r
F
.5279 .34578 m .52797 .34579 L .53224 .34774 L F
.52625 .34503 m .52797 .34579 L .5279 .34578 L F
.52638 .34512 m .52675 .34488 L .52638 .34511 L F
.5257 .34518 m .52639 .3452 L .52635 .34516 L F
.52638 .34512 m .52638 .34511 L .52605 .34532 L F
.52609 .34531 m .52638 .34512 L .52605 .34532 L F
.52656 .34514 m .52653 .34515 L .52694 .34513 L F
.52674 .34518 m .52726 .34515 L p .52667 .34516 L F P
0 g
s
.52635 .34516 m .52674 .34518 L .52667 .34516 L .672 .728 .891 r
F
.52639 .3452 m .52674 .34518 L p .52635 .34516 L F P
0 g
s
.52732 .34477 m .52613 .34496 L .52734 .34472 L .672 .728 .891 r
F
.52731 .34434 m .52678 .34478 L .52692 .34449 L F
.52678 .3449 m .52865 .34347 L p .52677 .34468 L F P
0 g
s
.52632 .3448 m .52625 .34485 L .5279 .34488 L .672 .728 .891 r
F
.52648 .3449 m .52683 .34465 L .52645 .34491 L F
.52648 .3449 m .52645 .34491 L .52606 .34518 L F
.52683 .34465 m .52683 .34465 L .52645 .34491 L F
.52645 .34491 m .52645 .34491 L .52606 .34518 L F
.52683 .34465 m .52645 .34491 L .52645 .34491 L F
.52592 .34422 m .52592 .34422 L .52621 .34488 L F
.52603 .34476 m .52604 .34387 L .526 .34396 L F
.52606 .34534 m .52605 .34478 L .52603 .34476 L F
.52641 .34491 m .52605 .34477 L .52675 .34488 L F
.5258 .34427 m .52601 .34534 L .52578 .34429 L F
.52547 .34502 m .52576 .34504 L .52576 .34502 L F
.52576 .34504 m .52599 .34506 L .52576 .34502 L F
.52576 .34502 m .52599 .34506 L .52603 .34503 L F
.5257 .34447 m .52593 .34511 L .52579 .34523 L F
.52579 .34443 m .5258 .34427 L .52579 .34428 L F
.52534 .34443 m .52591 .34485 L .52553 .34436 L F
.54086 .35327 m .54161 .35263 L p .53536 .34936 L F P
0 g
s
.53536 .34936 m .5359 .3503 L .54086 .35327 L .672 .728 .891 r
F
.52529 .34444 m .526 .34493 L .52533 .34443 L F
.52581 .34542 m .5258 .34447 L .52579 .34446 L F
.52588 .34457 m .52616 .34492 L .52616 .34492 L F
.52612 .34496 m .52586 .34456 L .52618 .34491 L F
.52608 .34481 m .52605 .34478 L .52606 .34539 L F
.52604 .34523 m .52648 .3449 L .52606 .34518 L F
.52516 .34601 m .51493 .35522 L .52504 .34585 L F
.52495 .34574 m .52513 .34564 L .52513 .34562 L F
.52495 .34574 m .52429 .34628 L .52538 .34558 L F
.52532 .34559 m .52136 .34926 L .52517 .34556 L F
.52517 .34564 m .52221 .34841 L .52576 .34543 L F
.52583 .34545 m .52584 .34526 L .52583 .34526 L F
.52517 .34564 m .52576 .34543 L .52606 .34518 L F
.52609 .34511 m .52606 .34518 L .52624 .34502 L F
.52593 .34511 m .52601 .34534 L .52579 .34523 L F
.52575 .34521 m .52639 .3452 L .5257 .34518 L F
.52579 .34523 m .52581 .34542 L .52581 .34524 L F
.52517 .34564 m .52606 .34518 L .52609 .34511 L F
.52571 .34555 m .52693 .34473 L .52699 .34456 L F
.52606 .34534 m .52606 .34518 L .52606 .34534 L F
.52606 .34518 m .52605 .34478 L .52606 .34519 L F
.52599 .34534 m .52656 .3449 L .52602 .34526 L F
.52656 .3449 m .52653 .3449 L .52595 .3453 L F
.52639 .3452 m .52675 .34488 L p .52609 .34531 L F P
0 g
s
.52679 .34505 m .52641 .34491 L .52675 .34488 L .672 .728 .891 r
F
.52661 .34512 m .52694 .34513 L .52676 .34507 L F
.52617 .34493 m .52621 .34497 L .52637 .34497 L F
.52587 .34456 m .52587 .34456 L .52583 .34526 L F
.52584 .34568 m .52603 .34476 L .52598 .3447 L F
.52586 .3448 m .52586 .34479 L .52621 .34494 L F
.52625 .34503 m .5262 .34497 L .52625 .34492 L F
.52702 .3451 m .52639 .3452 L .52617 .34493 L F
.52618 .34493 m .52621 .34494 L .52733 .34543 L F
.52605 .34477 m .52593 .34463 L .52675 .34488 L F
.52608 .34481 m .52608 .34462 L .52607 .34461 L F
.52609 .34511 m .52608 .34482 L .52609 .34512 L F
.52609 .34511 m .5261 .34508 L .5261 .34499 L F
.52609 .34511 m .5261 .34499 L .52609 .345 L F
.52587 .3455 m .52602 .34446 L .52585 .34547 L F
.52579 .34523 m .52578 .34523 L p .52617 .34493 L F P
0 g
s
.52581 .34542 m .52583 .34545 L .5258 .34427 L .672 .728 .891 r
F
.52457 .3453 m .52485 .34528 L p .52465 .34522 L F P
0 g
s
.52557 .34528 m .52529 .34523 L .52563 .34518 L .672 .728 .891 r
F
.52485 .34528 m .52639 .3452 L p .52479 .34522 L F P
0 g
s
.52465 .34522 m .52485 .34528 L .52479 .34522 L .672 .728 .891 r
F
.52221 .34841 m .52489 .34651 L .52454 .34645 L F
.52443 .34699 m .52434 .34689 L .5253 .34577 L F
.52586 .3448 m .52616 .34492 L .52617 .34493 L F
.52609 .34512 m .52608 .34482 L .52608 .34481 L F
.52609 .345 m .5261 .34499 L .52608 .34462 L F
.52597 .34538 m .52609 .34531 L .52605 .34532 L F
.52596 .34539 m .52609 .34531 L .52597 .34538 L F
.52585 .34567 m .52601 .34553 L p .52581 .34566 L F P
0 g
s
.52584 .34568 m .52607 .34575 L .52605 .3452 L .672 .728 .891 r
F
.52585 .34563 m .52605 .3452 L .52603 .34476 L F
.52584 .34568 m .52605 .3452 L .52585 .34563 L F
.52571 .34555 m .52596 .34539 L .52597 .34538 L F
.52617 .34493 m .52578 .34523 L .52607 .3448 L F
.52588 .34488 m .52588 .34488 L .52628 .34507 L F
.52617 .34493 m .52609 .34511 L .52624 .34502 L F
.5262 .34497 m .52616 .34492 L .52624 .34492 L F
.52638 .3449 m .52625 .34503 L .52625 .34492 L F
.52617 .34493 m .52624 .34502 L .52637 .34491 L F
.52617 .34493 m .52621 .34494 L .52618 .34493 L F
.52617 .34493 m .52618 .34493 L .52617 .34493 L F
.52618 .34493 m .52621 .34494 L .52617 .34493 L F
.52593 .34463 m .52593 .34463 L .52675 .34488 L F
.52613 .34488 m .52624 .34473 L .52616 .34491 L F
.52609 .34483 m .52626 .34474 L .52608 .34462 L F
.5261 .34508 m .52617 .34493 L .52609 .34483 L F
.52612 .34487 m .52605 .34477 L .52679 .34505 L F
.52617 .34493 m .52626 .34474 L .52609 .34483 L F
.52681 .34516 m .52612 .34487 L .52679 .34505 L F
.52588 .34449 m .52587 .34448 L .52583 .34526 L F
.52572 .34448 m .52593 .34511 L .5257 .34447 L F
.52569 .34439 m .52572 .34448 L .5257 .34447 L F
.52568 .34431 m .52579 .34523 L .52578 .34445 L F
.52629 .34894 m .52642 .3456 L .52612 .34543 L F
.52634 .34989 m .52636 .34871 L .52629 .34894 L F
.52636 .34871 m .52642 .3456 L .52629 .34894 L F
.52661 .34838 m .52607 .34776 L .52607 .34771 L F
.52584 .3457 m .52615 .34711 L .526 .34707 L F
.52621 .34882 m .52614 .34587 L .52611 .34583 L F
.52584 .3457 m .52621 .34882 L .52607 .34575 L F
.52647 .3479 m .52607 .34771 L .52583 .34573 L F
.52621 .34882 m .52629 .34888 L .52614 .34587 L F
.52661 .34838 m .52607 .34771 L .52647 .3479 L F
.52584 .34526 m .52587 .34456 L .52583 .34526 L F
.52593 .34463 m .52578 .34445 L .52593 .34445 L F
.52585 .34547 m .52589 .34424 L .52583 .34545 L F
.52593 .34502 m .52532 .34559 L .52593 .34499 L F
.52578 .34523 m .5255 .34507 L .52607 .3448 L F
.52577 .34484 m .52414 .34521 L .52384 .34509 L F
.52389 .34498 m .52384 .34509 L .52363 .345 L F
.52577 .34484 m .52384 .34509 L .52389 .34498 L F
.50775 .34702 m .50761 .34621 L p .52363 .345 L F P
0 g
s
.51925 .34564 m .52124 .34553 L .5212 .34551 L .672 .728 .891 r
F
.51761 .34606 m .52312 .34552 L p .51925 .34564 L F P
0 g
s
.51925 .34564 m .52312 .34552 L .52303 .34542 L .672 .728 .891 r
F
.50775 .34702 m .51761 .34606 L p .51925 .34564 L F P
0 g
s
.52414 .34521 m .50775 .34702 L .52363 .345 L .672 .728 .891 r
F
.54228 .35195 m .5429 .35125 L p .53099 .34655 L F P
0 g
s
.52571 .34484 m .52134 .34517 L .52563 .34501 L .672 .728 .891 r
F
.52553 .34501 m .5256 .34487 L .5257 .34485 L F
.52553 .34501 m .5257 .34485 L .52574 .34485 L F
.5255 .34507 m .52553 .34501 L .52574 .34485 L F
.5261 .34494 m .52562 .34472 L .52617 .34493 L F
.52562 .34472 m .5245 .34421 L .52563 .3447 L F
.526 .34493 m .52603 .34493 L .52444 .34376 L F
.52436 .34379 m .52401 .34361 L .52497 .34381 L F
.52444 .34376 m .52444 .34376 L .5243 .34365 L F
.52503 .34434 m .52507 .34437 L p .52555 .34416 L F P
0 g
s
.52336 .34332 m .52549 .3444 L .52541 .3444 L .672 .728 .891 r
F
.526 .34493 m .52444 .34376 L .52444 .34376 L F
.52562 .34472 m .52563 .3447 L .52617 .34493 L F
.52595 .34466 m .52586 .34456 L .52589 .34458 L F
.52585 .34547 m .52602 .34446 L .52589 .34443 L F
.5259 .34488 m .52574 .34485 L .52607 .3448 L F
.52617 .34493 m .52517 .34564 L .52609 .34511 L F
.52594 .34489 m .52622 .345 L .52625 .34503 L F
.52616 .34492 m .52621 .34494 L .52617 .34493 L F
.52619 .34493 m .52616 .34492 L .52619 .34493 L F
.52611 .34532 m .52626 .34474 L .5261 .34508 L F
.52612 .34543 m .52615 .3453 L .52611 .34532 L F
.52596 .34539 m .52639 .3452 L .52609 .34531 L F
.52615 .3453 m .52626 .34474 L .52611 .34532 L F
.52589 .3449 m .52628 .34507 L .5263 .3451 L F
.5259 .34496 m .52517 .34564 L .52617 .34493 L F
.52588 .34488 m .52628 .34507 L .52589 .3449 L F
.5267 .34462 m .52638 .3449 L .52665 .34439 L F
.52784 .34468 m .52732 .34477 L .52734 .34472 L F
.52754 .3447 m .52632 .3448 L .5279 .34488 L F
.52675 .34488 m .52593 .34463 L .52675 .34488 L F
.5389 .3356 m .53227 .34069 L p .53084 .3414 L F P
0 g
s
.53475 .33771 m .52881 .34258 L .53308 .34007 L .672 .728 .891 r
F
.53227 .34069 m .52857 .34352 L p .53084 .3414 L F P
0 g
s
.52857 .34352 m .5285 .34342 L .53084 .3414 L .672 .728 .891 r
F
.52865 .34347 m .53308 .34007 L p .52881 .34258 L F P
0 g
s
.53059 .34111 m .52712 .34425 L .52674 .34427 L .672 .728 .891 r
F
.52696 .34428 m .52782 .3437 L .52757 .34378 L F
.52712 .34425 m .5267 .34462 L .52674 .34427 L F
.52617 .34493 m .52705 .34427 L .52696 .34428 L F
.52705 .34427 m .52782 .3437 L .52696 .34428 L F
.5258 .34541 m .52603 .34525 L .52576 .34543 L F
.52603 .34525 m .52701 .34452 L .52604 .34523 L F
.52603 .34525 m .52604 .34523 L .52576 .34543 L F
.5261 .34541 m .52609 .34512 L .52606 .34539 L F
.52609 .34512 m .52608 .34481 L .52607 .34517 L F
.52609 .34512 m .52607 .34517 L .52606 .34539 L F
.52612 .34543 m .52626 .34504 L .52621 .34498 L F
.53026 .34145 m .5299 .34174 L .53059 .34111 L F
.52751 .34422 m .5299 .34174 L .53026 .34145 L F
.52751 .34422 m .52712 .34425 L .5299 .34174 L F
.53119 .341 m .52751 .34422 L p .53059 .34111 L F P
0 g
s
.53308 .34007 m .5389 .3356 L p .53475 .33771 L .672 .728 .891 r
F P
0 g
s
.53797 .33507 m .53119 .341 L p .53059 .34111 L .672 .728 .891 r
F P
0 g
s
.52667 .34432 m .52696 .34428 L .53512 .33756 L .672 .728 .891 r
F
.53686 .33472 m .52816 .34313 L .53512 .33756 L F
.53687 .3347 m .52816 .34313 L .53686 .33472 L F
.52608 .34462 m .52626 .34474 L .52622 .34409 L F
.52611 .344 m .52603 .34305 L .52603 .34391 L F
.52603 .34305 m .52602 .34298 L .52602 .34305 L F
.52604 .34388 m .52622 .34409 L .52548 .3324 L F
.52608 .34462 m .52622 .34409 L .52604 .34388 L F
.52634 .34456 m .52624 .34316 L p .52626 .34474 L F P
0 g
s
.52624 .34316 m .52548 .3324 L p .52616 .34305 L .672 .728 .891 r
F P
0 g
s
.52626 .34474 m .52624 .34316 L .52616 .34305 L .672 .728 .891 r
F
.53687 .3347 m .52733 .34362 L .52816 .34313 L F
.52733 .34362 m .52607 .3448 L .52762 .34356 L F
.52733 .34362 m .52762 .34356 L .52816 .34313 L F
.5267 .34462 m .52665 .34439 L .52674 .34427 L F
.52633 .3446 m .52626 .34474 L .52696 .34428 L F
.52626 .34474 m .52617 .34493 L .52651 .34465 L F
.52597 .34528 m .52665 .34437 L .52665 .34439 L F
.52626 .34474 m .52651 .34465 L .52696 .34428 L F
.52617 .34493 m .52637 .34491 L .52715 .34426 L F
.52607 .3448 m .52617 .34493 L .52633 .3446 L F
.52623 .34489 m .52635 .34479 L .52626 .34474 L F
.52635 .34479 m .52617 .34493 L .52607 .3448 L F
.52656 .3449 m .52687 .34466 L .52653 .3449 L F
.52687 .34466 m .52687 .34465 L .52595 .3453 L F
.52751 .34422 m .52675 .34488 L p .52712 .34425 L F P
0 g
s
.52675 .34488 m .52693 .34473 L p .5267 .34489 L .672 .728 .891 r
F P
0 g
s
.52699 .34456 m .52701 .34452 L .5258 .34541 L .672 .728 .891 r
F
.52785 .34475 m .52617 .34493 L .52635 .34479 L F
.52868 .3449 m .52825 .34483 L .52877 .34476 L F
.52754 .3447 m .5279 .34488 L .52959 .34478 L F
.52941 .3447 m .52796 .3448 L .52785 .34475 L F
.52796 .3448 m .52617 .34493 L .52785 .34475 L F
.52514 .34453 m .526 .3449 L .52594 .34489 L F
.52607 .3448 m .52574 .34485 L .52562 .34483 L F
.52563 .34482 m .52562 .34483 L .52558 .34482 L F
.52602 .34495 m .52514 .34453 L .52606 .34494 L F
.52607 .3448 m .52562 .34483 L .52563 .34482 L F
.52504 .34442 m .52502 .34439 L .52605 .34477 L F
.52579 .34523 m .52579 .34428 L .52578 .34428 L F
.52589 .34424 m .52589 .34424 L .52583 .34545 L F
.52605 .34477 m .52454 .34422 L .52593 .34463 L F
.52593 .34463 m .52454 .34422 L .52593 .34463 L F
.52383 .34358 m .52541 .3444 L .5254 .3444 L F
.52458 .34396 m .52523 .3443 L .52458 .34396 L F
.52523 .3443 m .52523 .3443 L .52385 .34358 L F
.52453 .34392 m .52529 .34444 L .5243 .34365 L F
.52529 .34444 m .52533 .34443 L .5243 .34365 L F
.52593 .34463 m .52533 .34445 L .52578 .34445 L F
.52541 .3444 m .52541 .3444 L .52523 .3443 L F
.52533 .34445 m .52454 .34422 L .52552 .34438 L F
.52533 .34445 m .52552 .34438 L .52593 .34445 L F
.52583 .34526 m .52587 .34455 L .52581 .34448 L F
.52616 .34492 m .52586 .34479 L .52612 .34487 L F
.52586 .34479 m .52454 .34422 L .52585 .34476 L F
.52586 .34479 m .52585 .34476 L .52612 .34487 L F
.52697 .34499 m .52675 .34488 L .52675 .34507 L F
.52681 .34505 m .52676 .34507 L .52832 .34508 L F
.52697 .34499 m .52679 .34506 L .52724 .34515 L F
.52726 .34514 m .52679 .34505 L .52675 .34488 L F
.5268 .34505 m .52679 .34505 L .52726 .34514 L F
.52739 .34484 m .52702 .3451 L .52617 .34493 L F
.52941 .3447 m .5273 .34505 L .52739 .34484 L F
.5273 .34505 m .52702 .3451 L .52739 .34484 L F
.52743 .34476 m .52635 .34479 L .52738 .34501 L F
.52763 .34487 m .52738 .34501 L .5282 .34518 L F
.52743 .34476 m .52738 .34501 L .52763 .34487 L F
.52611 .34583 m .52612 .34543 L .5261 .34541 L F
.52621 .34882 m .5261 .34541 L .52606 .34539 L F
.52646 .34562 m .52618 .34491 L .52646 .34562 L F
.52639 .3452 m .52646 .34562 L p .52633 .34522 L F P
0 g
s
.52639 .3452 m .52661 .34838 L p .52583 .34573 L .672 .728 .891 r
F P
0 g
s
.52598 .34563 m .52615 .34586 L .52619 .34529 L .672 .728 .891 r
F
.52606 .34539 m .52606 .34534 L .52606 .34534 L F
.52642 .3456 m .52639 .3452 L p .52612 .34543 L F P
0 g
s
.52621 .34498 m .52617 .34493 L .52683 .34522 L .672 .728 .891 r
F
.52619 .34493 m .52619 .34493 L .52667 .34511 L F
.52639 .3452 m .52636 .3448 L p .52626 .34505 L F P
0 g
s
.52612 .34543 m .52639 .3452 L .52626 .34505 L .672 .728 .891 r
F
.5261 .34494 m .52617 .34493 L .52617 .34493 L F
.5261 .34494 m .52617 .34493 L .52621 .34498 L F
.5261 .34541 m .52612 .34543 L .5261 .34508 L F
.52639 .3452 m .52583 .34573 L .526 .34532 L F
.52606 .34553 m .52581 .34578 L p .52602 .34537 L F P
0 g
s
.52639 .3452 m .52591 .34497 L p .5263 .3451 L .672 .728 .891 r
F P
0 g
s
.52592 .34502 m .52541 .34558 L .5259 .34496 L .672 .728 .891 r
F
.52541 .34558 m .52429 .34683 L .52534 .34561 L F
.52541 .34558 m .52534 .34561 L .5259 .34496 L F
.52591 .34497 m .5259 .34496 L .5263 .3451 L F
.52575 .34329 m .52571 .34299 L .52574 .3433 L F
.52558 .34387 m .52555 .34317 L .52547 .34329 L F
.52544 .34364 m .52574 .3433 L .52556 .34194 L F
.52618 .34396 m .52585 .34379 L .52548 .34268 L F
.52589 .34424 m .52595 .34282 L .52589 .34424 L F
.52589 .34443 m .52602 .34446 L .52595 .34282 L F
.52634 .34456 m .52615 .34453 L .52574 .34336 L F
.52635 .34479 m .52607 .3448 L .52626 .34487 L F
.52676 .34458 m .52677 .34461 L .52692 .34453 L F
.52675 .34488 m .5267 .34462 L .52712 .34425 L F
.52606 .34518 m .52701 .34452 L .5271 .3443 L F
.52636 .3448 m .52626 .34487 L .52669 .34501 L F
.52617 .34493 m .52715 .34426 L .52705 .34427 L F
.52621 .34498 m .52635 .34479 L .52623 .34489 L F
.52635 .34479 m .52626 .34487 L .52636 .3448 L F
.52626 .34474 m .52636 .3448 L .52634 .34456 L F
.52634 .34456 m .52636 .3448 L p .52624 .34477 L F P
0 g
s
.52636 .3448 m .52639 .3452 L p .52627 .34486 L .672 .728 .891 r
F P
0 g
s
.52636 .3448 m .52627 .34486 L .52624 .34477 L .672 .728 .891 r
F
.52631 .34459 m .52623 .3447 L .52631 .34459 L F
.52633 .34456 m .52624 .34477 L .52615 .34453 L F
.52634 .34456 m .52624 .34477 L .52633 .34456 L F
.52636 .34454 m .52631 .34459 L .52636 .34453 L F
.52631 .34459 m .52631 .34459 L .52636 .34453 L F
.52636 .34491 m .52623 .3447 L .52636 .34454 L F
.52612 .34487 m .52504 .34442 L .52605 .34477 L F
.52632 .34457 m .52597 .34496 L .52633 .34456 L F
.52608 .34481 m .52604 .34387 L .52605 .34478 L F
.52615 .34453 m .52624 .34477 L .52577 .34446 L F
.52616 .34492 m .52612 .34487 L .52723 .34533 L F
.52626 .34504 m .52635 .34479 L .52621 .34498 L F
.52626 .34504 m .52636 .3448 L .52635 .34479 L F
.52612 .34543 m .52626 .34505 L .52626 .34504 L F
.52626 .34505 m .52636 .3448 L .52626 .34504 L F
.5271 .34511 m .52639 .3452 L .52702 .3451 L F
.52684 .34528 m .52622 .345 L .52683 .34522 L F
.52622 .345 m .5261 .34494 L .52621 .34498 L F
.52622 .345 m .52621 .34498 L .52683 .34522 L F
.52658 .34502 m .52639 .3452 L .52667 .34508 L F
.52624 .34477 m .52627 .34486 L .52617 .34493 L F
.52617 .34493 m .52612 .34486 L .52623 .3447 L F
.52608 .34482 m .52608 .34462 L .52608 .34481 L F
.52587 .34456 m .52588 .34449 L .52587 .34456 L F
.52598 .3447 m .52603 .34476 L .52602 .34446 L F
.52624 .34477 m .52617 .34494 L .52577 .34446 L F
.52607 .3448 m .52616 .34492 L .52669 .34501 L F
.52636 .34491 m .52617 .34493 L .52623 .3447 L F
.52579 .34444 m .52618 .34493 L .52658 .34502 L F
.52627 .34486 m .52639 .3452 L .52617 .34493 L F
.52663 .34512 m .52619 .34493 L .52667 .34511 L F
.52618 .34493 m .52639 .3452 L .52658 .34502 L F
.52946 .34504 m .52726 .34515 L p .5288 .34493 L F P
0 g
s
.52915 .34517 m .52975 .34517 L p .52743 .34476 L .672 .728 .891 r
F P
0 g
s
.5282 .34518 m .5284 .34501 L .53257 .34486 L .672 .728 .891 r
F
.52941 .3447 m .52743 .34476 L .52975 .34517 L F
.53257 .34486 m .5284 .34501 L .52862 .34482 L F
.52924 .34482 m .52741 .3448 L .53097 .3453 L F
.52597 .34535 m .52599 .34534 L .52595 .3453 L F
.52571 .34555 m .5259 .34554 L .52596 .34539 L F
.52602 .34537 m .52495 .34646 L .526 .3453 L F
.52599 .34534 m .52602 .34526 L .52595 .3453 L F
.52576 .34543 m .52604 .34523 L .52606 .34518 L F
.52581 .34578 m .52578 .34581 L p .52596 .34542 L F P
0 g
s
.52596 .34535 m .52595 .3453 L .5258 .34541 L .672 .728 .891 r
F
.52597 .34535 m .52595 .3453 L .52596 .34535 L F
.52597 .34535 m .5258 .34541 L .52561 .34556 L F
.526 .34532 m .52583 .34573 L .52579 .34539 L F
.52603 .34527 m .52593 .34538 L .52617 .34493 L F
.52571 .34555 m .52597 .34535 L .52561 .34556 L F
.52593 .34538 m .52495 .34646 L .52576 .34545 L F
.52593 .34538 m .52576 .34545 L .52617 .34493 L F
.52636 .34453 m .52632 .34457 L .52633 .34456 L F
.52622 .34483 m .52641 .3444 L .52626 .34436 L F
.526 .3449 m .52622 .345 L .52594 .34489 L F
.52607 .3448 m .5259 .34496 L .52617 .34493 L F
.52633 .34456 m .52597 .34496 L .5259 .34496 L F
.52588 .34487 m .52589 .34496 L .52618 .34493 L F
.52579 .34523 m .52581 .34524 L .52579 .34428 L F
.5255 .34507 m .52574 .34485 L .5259 .34488 L F
.52582 .34486 m .52588 .34488 L .52589 .3449 L F
.52587 .34487 m .52588 .34488 L .52582 .34486 L F
.5261 .34541 m .52609 .34511 L .52609 .34512 L F
.52606 .34518 m .52606 .34519 L .52606 .34534 L F
.5261 .34541 m .5261 .34508 L .52609 .34511 L F
.52576 .34545 m .52566 .34548 L .52605 .34495 L F
.52578 .3452 m .52639 .3452 L .52579 .34539 L F
.52558 .34482 m .52614 .34495 L .52618 .34492 L F
.52597 .34496 m .52592 .34502 L .52591 .34497 L F
.5259 .34496 m .52599 .34495 L .5263 .3451 L F
.52589 .34496 m .5259 .34496 L .5259 .34496 L F
.5259 .34496 m .52599 .34495 L .5259 .34496 L F
.52602 .34495 m .52606 .34494 L .52625 .34503 L F
.52597 .34496 m .52591 .34497 L .5259 .34496 L F
.52602 .34495 m .52625 .34503 L .52627 .34506 L F
.52618 .34493 m .52611 .34494 L .52639 .3452 L F
.52591 .34497 m .52589 .34496 L p .5259 .34496 L F P
0 g
s
.52589 .34496 m .52591 .34497 L p .52611 .34494 L .672 .728 .891 r
F P
0 g
s
.52591 .34497 m .52639 .3452 L p .52611 .34494 L .672 .728 .891 r
F P
0 g
s
.52617 .34493 m .52597 .34519 L .52605 .34495 L .672 .728 .891 r
F
.52597 .34519 m .52576 .34545 L .52595 .34512 L F
.52597 .34519 m .52595 .34512 L .52605 .34495 L F
.52593 .34507 m .52592 .34504 L .52636 .34453 L F
.52607 .3448 m .52589 .34486 L .52616 .34492 L F
.52617 .34493 m .52605 .34495 L .52612 .34486 L F
.52563 .34482 m .52594 .34488 L .52616 .34492 L F
.52616 .34492 m .52616 .34492 L .52669 .34501 L F
.52563 .34482 m .52616 .34492 L .52616 .34492 L F
.52594 .3451 m .52593 .34507 L .52611 .34485 L F
.52612 .34486 m .52611 .34485 L .52636 .34453 L F
.52594 .3451 m .52611 .34485 L .52612 .34486 L F
.52581 .34445 m .52588 .34487 L .52617 .34493 L F
.52607 .3448 m .52563 .34482 L .52589 .34486 L F
.5258 .34447 m .52565 .34477 L .52574 .34484 L F
.52495 .34646 m .52503 .34622 L .52534 .34582 L F
.52495 .34646 m .52534 .34582 L .52538 .34587 L F
.52495 .34646 m .52443 .34699 L .52503 .34622 L F
.52578 .34581 m .51665 .35495 L p .52561 .34578 L F P
0 g
s
.51665 .35495 m .51591 .35569 L p .51661 .35497 L .672 .728 .891 r
F P
0 g
s
.51665 .35495 m .51661 .35497 L .52561 .34578 L .672 .728 .891 r
F
.52434 .34689 m .52429 .34683 L .52516 .34586 L F
.52484 .34675 m .52555 .34604 L p .52436 .34661 L F P
0 g
s
.52398 .34731 m .52489 .34651 L p .52431 .34693 L .672 .728 .891 r
F P
0 g
s
.52221 .34841 m .52398 .34731 L .52431 .34693 L .672 .728 .891 r
F
.52273 .3484 m .52398 .34731 L p .52221 .34841 L F P
0 g
s
.52301 .34844 m .52429 .34683 L .52434 .34689 L .672 .728 .891 r
F
.52443 .34699 m .52301 .34844 L .52434 .34689 L F
.52301 .34844 m .52071 .35079 L .52293 .34833 L F
.51493 .35522 m .52273 .3484 L p .52221 .34841 L F P
0 g
s
.52411 .34663 m .52071 .35079 L .52048 .35003 L .672 .728 .891 r
F
.52429 .34683 m .52071 .35079 L .52411 .34663 L F
.52136 .34926 m .51493 .35522 L .52129 .34874 L F
.52071 .35079 m .51616 .35544 L .52048 .35003 L F
.51616 .35544 m .51591 .35569 L .51612 .35543 L F
.51616 .35544 m .51612 .35543 L .52048 .35003 L F
.51591 .35569 m .52484 .34675 L p .52436 .34661 L F P
0 g
s
.52505 .34645 m .51692 .35612 L .52496 .3463 L .672 .728 .891 r
F
.52436 .34661 m .52555 .34604 L .52459 .3464 L F
.52505 .34645 m .52496 .3463 L .52526 .34593 L F
.52454 .34645 m .52571 .34555 L .52561 .34556 L F
.52443 .34699 m .5253 .34577 L .52534 .34582 L F
.52434 .34689 m .52516 .34586 L .52512 .34598 L F
.52555 .34604 m .52606 .34553 L p .52483 .34625 L F P
0 g
s
.52459 .3464 m .52479 .34632 L .52483 .34625 L .672 .728 .891 r
F
.52479 .34632 m .52555 .34604 L .52483 .34625 L F
.52228 .3432 m .52227 .34318 L .52599 .34495 L F
.52618 .34492 m .52617 .34493 L .52669 .34501 L F
.52616 .34493 m .52639 .3452 L .52578 .3452 L F
.52618 .34493 m .52617 .34493 L .52618 .34493 L F
.52617 .34493 m .52639 .3452 L .52617 .34494 L F
.52617 .34493 m .52619 .34496 L .52669 .34501 L F
.52636 .34491 m .52625 .34503 L .52617 .34493 L F
.52625 .34503 m .52603 .34527 L .52617 .34493 L F
.52627 .34506 m .52625 .34503 L .5279 .34578 L F
.52488 .3578 m .52369 .35771 L p .52549 .34691 L F P
0 g
s
.5263 .3451 m .52628 .34507 L .52971 .3467 L .672 .728 .891 r
F
.5263 .3451 m .52971 .3467 L .52971 .3467 L F
.5263 .3451 m .53028 .34697 L .53028 .34697 L F
.52728 .35783 m .52608 .35784 L p .5258 .34581 L F P
0 g
s
.52589 .34969 m .52596 .34897 L .52596 .34871 L .672 .728 .891 r
F
.53229 .34793 m .52708 .34545 L .53224 .34774 L F
.52708 .34545 m .52602 .34495 L .52713 .34544 L F
.52708 .34545 m .52713 .34544 L .53224 .34774 L F
.5255 .34507 m .52523 .34492 L .5256 .34487 L F
.52539 .34495 m .52631 .3451 L .52624 .34502 L F
.52498 .34491 m .52544 .34498 L .52539 .34495 L F
.52544 .34498 m .52631 .3451 L .52539 .34495 L F
.51526 .3458 m .52457 .3453 L p .51642 .34555 L F P
0 g
s
.51642 .34555 m .52457 .3453 L .52465 .34522 L .672 .728 .891 r
F
.52485 .34505 m .51642 .34555 L .52465 .34522 L F
.52574 .34485 m .52136 .34547 L .52558 .34482 L F
.52508 .34483 m .52498 .34491 L .52539 .34495 L F
.52526 .34486 m .52539 .34495 L .52676 .34506 L F
.52508 .34483 m .52539 .34495 L .52526 .34486 L F
.52602 .34537 m .52625 .34503 L .52627 .34505 L F
.52667 .34508 m .52661 .34511 L .52675 .34514 L F
.52635 .34516 m .52726 .34515 L .52713 .34513 L F
.52661 .34511 m .52639 .3452 L .52675 .34514 L F
.52586 .3448 m .52733 .34543 L .52732 .34543 L F
.52639 .3452 m .52772 .34585 L p .52675 .34514 L F P
0 g
s
.52624 .34502 m .52697 .3452 L .52676 .34506 L .672 .728 .891 r
F
.52631 .3451 m .52697 .3452 L .52624 .34502 L F
.53292 .34823 m .53519 .34931 L .53519 .34931 L F
.5263 .3451 m .53292 .34823 L .53292 .34823 L F
.53292 .34823 m .53519 .34931 L .53292 .34823 L F
.52621 .34882 m .52634 .34989 L .52629 .34888 L F
.52728 .35783 m .52674 .35014 L p .52634 .34989 L F P
0 g
s
.52661 .34838 m .52728 .35783 L p .52607 .34776 L .672 .728 .891 r
F P
0 g
s
.52583 .34573 m .52728 .35783 L .5258 .34581 L .672 .728 .891 r
F
.52627 .34984 m .52638 .34558 L p .52589 .34969 L F P
0 g
s
.5262 .34496 m .52676 .34506 L .5262 .34496 L .672 .728 .891 r
F
.52589 .34496 m .52356 .34382 L p .52599 .34495 L F P
0 g
s
.52587 .34487 m .52574 .34484 L .52589 .34496 L .672 .728 .891 r
F
.52534 .34582 m .52592 .34504 L .52593 .34507 L F
.5258 .34521 m .52639 .3452 L p .52544 .34498 L F P
0 g
s
.52663 .34512 m .52667 .34511 L .52723 .34533 L .672 .728 .891 r
F
.52726 .34515 m .52639 .3452 L p .5271 .34511 L F P
0 g
s
.52726 .34514 m .5271 .34511 L .52729 .34509 L .672 .728 .891 r
F
.52726 .34515 m .5271 .34511 L .52726 .34514 L F
.52681 .34516 m .52679 .34505 L .52782 .34543 L F
.52679 .34505 m .52679 .34505 L .5268 .34505 L F
.52679 .34505 m .5268 .34505 L .52782 .34543 L F
.52639 .3452 m .52697 .3452 L p .52657 .34514 L F P
0 g
s
.52544 .34498 m .52639 .3452 L .52657 .34514 L .672 .728 .891 r
F
.52617 .34493 m .52614 .34495 L .52619 .34496 L F
.52538 .34506 m .52414 .34521 L .52526 .345 L F
.52485 .34505 m .52553 .34508 L .52549 .34506 L F
.52485 .34505 m .52564 .34515 L .52553 .34508 L F
.52479 .34522 m .52575 .34521 L .5257 .34518 L F
.52465 .34522 m .52479 .34522 L .52479 .34522 L F
.52479 .34522 m .52639 .3452 L .52479 .34522 L F
.52473 .34516 m .5257 .34518 L .52564 .34515 L F
.52541 .34507 m .52414 .34521 L .52538 .34506 L F
.52485 .34505 m .52473 .34516 L .52564 .34515 L F
.52473 .34516 m .52465 .34522 L .52479 .34522 L F
.52547 .34502 m .52485 .34505 L .52536 .34506 L F
.52578 .34523 m .52136 .34547 L p .52523 .34492 L F P
0 g
s
.52491 .34497 m .5248 .34505 L .52571 .34519 L .672 .728 .891 r
F
.52491 .34497 m .52571 .34519 L .5258 .34521 L F
.52134 .34517 m .52177 .34523 L .52563 .34501 L F
.52498 .34491 m .52491 .34497 L .5258 .34521 L F
.52459 .34522 m .52498 .34522 L p .5248 .34505 L F P
0 g
s
.52498 .34522 m .5258 .34521 L p .5248 .34505 L .672 .728 .891 r
F P
0 g
s
.52534 .34561 m .52429 .34683 L .52511 .34569 L .672 .728 .891 r
F
.52532 .34559 m .52436 .34661 L .52545 .34558 L F
.52538 .34587 m .52534 .34582 L .52593 .34507 L F
.52538 .34587 m .52593 .34507 L .52594 .3451 L F
.52512 .34598 m .52516 .34586 L .52527 .34574 L F
.52512 .34598 m .52527 .34574 L .5253 .34577 L F
.52561 .34556 m .5258 .34541 L .52576 .34543 L F
.52576 .34545 m .52495 .34646 L .52566 .34548 L F
.52578 .34581 m .52561 .34578 L .52596 .34542 L F
.52579 .34539 m .52583 .34573 L .52581 .34578 L F
.5258 .34578 m .52581 .34578 L .5258 .34581 L F
.52579 .34539 m .52581 .34578 L .5258 .34578 L F
.52536 .34566 m .52606 .34553 L .52545 .34558 L F
.52493 .34607 m .52563 .34573 L .52536 .34566 L F
.52563 .34573 m .52606 .34553 L .52536 .34566 L F
.52459 .3464 m .52483 .34625 L .52493 .34607 L F
.52483 .34625 m .52606 .34553 L .52493 .34607 L F
.52592 .34512 m .5263 .34509 L .5263 .3451 L F
.52519 .34516 m .52593 .34511 L .52592 .34512 L F
.52593 .34511 m .5263 .34509 L .52592 .34512 L F
.52606 .34481 m .52616 .34493 L .52578 .3452 L F
.5253 .34577 m .52527 .34574 L .52541 .34558 L F
.52548 .34555 m .52541 .34558 L .52636 .34453 L F
.5253 .34577 m .52541 .34558 L .52548 .34555 L F
.5258 .34447 m .52574 .34484 L .52587 .34487 L F
.5258 .34447 m .52589 .34496 L .52581 .34445 L F
.52577 .34443 m .52578 .3452 L .52607 .3448 L F
.52508 .34483 m .52611 .34497 L .52614 .34495 L F
.52356 .34382 m .52355 .34379 L .52599 .34495 L F
.52389 .34395 m .52587 .34487 L .52582 .34486 L F
.52389 .34395 m .52588 .34488 L .52389 .34395 L F
.52363 .34382 m .52588 .34488 L .52362 .34383 L F
.52504 .34442 m .52454 .34422 L .52502 .34439 L F
.52154 .34284 m .52588 .34488 L .52588 .34488 L F
.52514 .34453 m .52517 .34451 L .52622 .345 L F
.52514 .34453 m .52395 .34396 L .52517 .34451 L F
.5245 .34421 m .52586 .34479 L .52586 .3448 L F
.52483 .34409 m .52598 .3447 L .52483 .34409 L F
.52454 .34422 m .52395 .34396 L .52593 .34445 L F
.52428 .34417 m .52589 .34496 L p .52487 .34415 L F P
0 g
s
.52458 .34396 m .52458 .34396 L .52385 .34358 L .672 .728 .891 r
F
.52385 .34358 m .52458 .34396 L .52385 .34358 L F
.52335 .3431 m .52421 .34399 L .52475 .34412 L F
.52573 .34434 m .52568 .34431 L .52572 .34434 L F
.52555 .34416 m .52436 .34379 L .52497 .34381 L F
.52568 .34431 m .52335 .3431 L .52553 .34436 L F
.52535 .34432 m .52436 .34379 L .52547 .34434 L F
.5243 .34365 m .52534 .34443 L .52553 .34436 L F
.52593 .34445 m .52395 .34396 L .52491 .34392 L F
.52445 .34383 m .52435 .34403 L .52487 .34415 L F
.5245 .34421 m .52395 .34396 L .52454 .34422 L F
.52435 .34403 m .52428 .34417 L .52487 .34415 L F
.52577 .34485 m .52576 .34485 L .52594 .34488 L F
.52563 .34482 m .52576 .34485 L .52577 .34485 L F
.52563 .34482 m .52558 .34482 L .52576 .34485 L F
.52558 .34482 m .52508 .34483 L .52555 .34489 L F
.52627 .34506 m .52856 .34607 L .52854 .34608 L F
.52639 .3452 m .5263 .3451 L .5359 .34965 L F
.52721 .34538 m .52723 .34533 L .52729 .34535 L F
.52724 .34515 m .52719 .34533 L .52726 .34516 L F
.52782 .34543 m .5268 .34505 L .52726 .34514 L F
.52785 .34558 m .52681 .34516 L .52782 .34543 L F
.52746 .3452 m .52696 .3451 L .52772 .34585 L F
.52697 .3452 m .52742 .34519 L p .52676 .34506 L F P
0 g
s
.52742 .34519 m .5282 .34518 L p .52682 .34507 L .672 .728 .891 r
F P
0 g
s
.52676 .34506 m .52742 .34519 L .52682 .34507 L .672 .728 .891 r
F
.52831 .34559 m .52746 .3452 L .52772 .34585 L F
.52743 .34476 m .5282 .34518 L .52755 .34479 L F
.52729 .34509 m .5273 .34505 L .52941 .3447 L F
.52789 .34503 m .52747 .34504 L .52773 .3449 L F
.52635 .34479 m .52669 .34501 L .52751 .34511 L F
.52754 .34504 m .52751 .34511 L .5282 .34518 L F
.52635 .34479 m .52751 .34511 L .52754 .34504 L F
.52714 .34491 m .52631 .34496 L .52741 .3448 L F
.52612 .3443 m .52623 .34427 L .52649 .34097 L F
.52587 .34426 m .52575 .34329 L .52587 .34426 L F
.52591 .34418 m .52564 .3435 L .52597 .34414 L F
.52603 .34305 m .52602 .34305 L .52604 .34477 L F
.52602 .34298 m .52618 .34396 L p .52548 .34268 L F P
0 g
s
.52577 .34322 m .52589 .34291 L .52577 .34313 L .672 .728 .891 r
F
.52581 .34438 m .52589 .34291 L .52577 .34322 L F
.52581 .34438 m .52595 .34282 L .52589 .34291 L F
.52626 .34345 m .52634 .34456 L p .52574 .34336 L F P
0 g
s
.52642 .344 m .52641 .34443 L p .52589 .34372 L .672 .728 .891 r
F P
0 g
s
.52617 .34463 m .52612 .34462 L .52585 .34379 L .672 .728 .891 r
F
.52605 .34478 m .52604 .34387 L .52603 .34476 L F
.52581 .34445 m .52617 .34493 L .52618 .34493 L F
.52588 .34449 m .52588 .34432 L .52587 .34448 L F
.52579 .34446 m .5258 .34444 L .52579 .34443 L F
.5258 .34447 m .5258 .34444 L .52579 .34446 L F
.5258 .34444 m .5258 .34427 L .52579 .34443 L F
.52581 .34448 m .52588 .34432 L .52581 .34438 L F
.52587 .34455 m .52588 .34432 L .52581 .34448 L F
.52607 .34461 m .52608 .34462 L .52604 .34387 L F
.52577 .34415 m .5258 .34427 L .52576 .34419 L F
.5258 .34427 m .52578 .34429 L .52576 .34419 L F
.52588 .34432 m .52595 .34282 L .52581 .34438 L F
.52579 .34428 m .5258 .34427 L .52578 .3435 L F
.52578 .34428 m .52579 .34428 L .52578 .34355 L F
.52575 .34353 m .52578 .34355 L .52578 .3435 L F
.52574 .34336 m .52615 .34453 L .52577 .34446 L F
.52579 .34444 m .5258 .34447 L .52581 .34445 L F
.52579 .34444 m .52445 .34383 L .52565 .34477 L F
.52576 .34419 m .52577 .34428 L .52572 .3443 L F
.52577 .34415 m .52576 .34419 L .52556 .34329 L F
.52568 .34431 m .52578 .34445 L .52578 .34355 L F
.52581 .34445 m .52577 .34443 L .52577 .34443 L F
.52577 .34443 m .52607 .3448 L .52616 .34396 L F
.526 .34396 m .52604 .34387 L .52548 .3324 L F
.52548 .3324 m .52626 .34345 L p .52574 .34336 L F P
0 g
s
.52593 .34366 m .52616 .34396 L .52649 .34097 L .672 .728 .891 r
F
.52577 .34443 m .52616 .34396 L .52593 .34366 L F
.52614 .34495 m .5262 .34496 L .5262 .34496 L F
.52631 .34496 m .52477 .34506 L .52611 .34492 L F
.52558 .34482 m .52136 .34547 L .52009 .345 L F
.52538 .34478 m .5248 .34505 L .52524 .34478 L F
.52574 .34485 m .5248 .34505 L .52538 .34478 L F
.52558 .34482 m .52555 .34489 L .52614 .34495 L F
.52644 .34499 m .52675 .34505 L .52669 .34501 L F
.52627 .34506 m .5279 .34578 L .52788 .34577 L F
.52719 .34544 m .52684 .34528 L .52721 .34538 L F
.52684 .34528 m .52683 .34522 L .52721 .34538 L F
.52721 .34538 m .52663 .34512 L .52723 .34533 L F
.52671 .34486 m .52642 .3449 L .5273 .34555 L F
.52733 .34547 m .5273 .34555 L .52772 .34585 L F
.52671 .34486 m .5273 .34555 L .52733 .34547 L F
.52742 .34518 m .52639 .3452 L .52715 .34513 L F
.52747 .34519 m .52742 .34519 L p .52742 .34518 L F P
0 g
s
.52742 .34519 m .52639 .3452 L p .52742 .34518 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .52669 .34477 L .5267 .3448 L .672 .728 .891 r
F
.52619 .34496 m .52675 .34505 L .52644 .34499 L F
.52614 .34495 m .5262 .34496 L .52619 .34496 L F
.5262 .34496 m .52675 .34505 L .52619 .34496 L F
.52606 .34553 m .52602 .34537 L .52629 .34508 L F
.52911 .34611 m .52785 .34558 L .52782 .34543 L F
.5302 .34667 m .52914 .34621 L .52911 .34611 L F
.52831 .34559 m .52791 .34577 L .531 .34701 L F
.52788 .34577 m .5279 .34578 L .52856 .34607 L F
.52791 .34577 m .52772 .34585 L .531 .34701 L F
.52971 .3467 m .52971 .3467 L .53028 .34697 L F
.53028 .34697 m .53028 .34697 L .53052 .34709 L F
.5305 .34709 m .53052 .34709 L .53519 .34931 L F
.5263 .3451 m .53052 .34709 L .5305 .34709 L F
.53519 .34931 m .53519 .34931 L .5359 .34965 L F
.52854 .34608 m .52856 .34607 L .53224 .34774 L F
.5361 .34994 m .53482 .34932 L p .5359 .34965 L F P
0 g
s
.53482 .34932 m .52639 .3452 L p .53549 .34946 L .672 .728 .891 r
F P
0 g
s
.53482 .34932 m .53549 .34946 L .5359 .34965 L .672 .728 .891 r
F
.53224 .34774 m .53019 .3468 L .5302 .34667 L F
.5359 .34965 m .53229 .34793 L .53224 .34774 L F
.54161 .35263 m .5361 .34994 L p .5359 .34965 L F P
0 g
s
.52772 .34585 m .54161 .35263 L p .531 .34701 L .672 .728 .891 r
F P
0 g
s
.53477 .34865 m .52685 .34534 L .53473 .34851 L .672 .728 .891 r
F
.52636 .34517 m .52629 .34508 L .52667 .3447 L F
.52611 .34497 m .52622 .34499 L .52614 .34495 L F
.52622 .34499 m .52676 .34506 L .5262 .34496 L F
.52622 .34499 m .5262 .34496 L .52614 .34495 L F
.52667 .3447 m .52629 .34508 L .52664 .34459 L F
.52629 .34508 m .52602 .34537 L .52627 .34505 L F
.52629 .34508 m .52627 .34505 L .52664 .34459 L F
.5263 .34509 m .5267 .34487 L .52618 .34494 L F
.52636 .34517 m .52667 .3447 L .52669 .34477 L F
.52647 .34489 m .52635 .34485 L .52642 .3449 L F
.52671 .34486 m .52635 .34485 L .52647 .34489 L F
.52671 .34486 m .52579 .34444 L .52635 .34485 L F
.52675 .345 m .5254 .34449 L .52672 .3449 L F
.52687 .34466 m .52699 .34456 L .52687 .34465 L F
.52683 .34465 m .52701 .34452 L .52683 .34465 L F
.52718 .34441 m .52672 .34487 L p .5271 .34427 L F P
0 g
s
.52672 .34487 m .52639 .3452 L p .5267 .3448 L .672 .728 .891 r
F P
0 g
s
.52672 .34487 m .5267 .3448 L .5271 .34427 L .672 .728 .891 r
F
.52528 .34518 m .52618 .34511 L .52622 .34513 L F
.52639 .3452 m .5258 .34521 L p .52633 .34512 L F P
0 g
s
.5251 .34455 m .52503 .34446 L .52659 .34502 L .672 .728 .891 r
F
.52605 .34503 m .52612 .34497 L .52631 .34496 L F
.52546 .34452 m .52546 .34452 L .52675 .345 L F
.52675 .345 m .52675 .345 L .52831 .34559 L F
.526 .34472 m .52675 .345 L .526 .34472 L F
.52575 .34463 m .52574 .34462 L .52691 .34506 L F
.5271 .34511 m .52702 .3451 L .5273 .34505 L F
.52742 .34519 m .52674 .34487 L .52696 .3451 L F
.52694 .34507 m .52694 .34507 L .52702 .3451 L F
.52729 .34509 m .5271 .34511 L .5273 .34505 L F
.52669 .34501 m .52676 .34506 L .5282 .34518 L F
.52674 .34487 m .52674 .34489 L .52772 .34585 L F
.52691 .34506 m .52694 .34507 L .52694 .34507 L F
.52691 .34506 m .52691 .34506 L .52694 .34507 L F
.52575 .34463 m .52691 .34506 L .52691 .34506 L F
.52613 .34461 m .5262 .34466 L .52623 .34427 L F
.52579 .34444 m .52565 .34477 L .5258 .34447 L F
.52674 .34487 m .52671 .34486 L .52674 .34489 L F
.52695 .34496 m .52573 .34459 L .52581 .34445 L F
.52607 .3448 m .5262 .34466 L .52613 .34461 L F
.52601 .34473 m .52601 .34473 L .52701 .3451 L F
.52627 .34505 m .52625 .34503 L .52664 .34459 L F
.52539 .34449 m .5254 .34449 L .52546 .34451 L F
.5258 .34521 m .52588 .34515 L .52633 .34512 L F
.52595 .3451 m .52594 .34528 L .526 .34507 L F
.5258 .34521 m .52594 .34528 L .52595 .3451 L F
.5258 .34521 m .52594 .3453 L .52594 .34528 L F
.52553 .3455 m .52605 .34522 L .52611 .34495 L F
.52602 .34537 m .526 .3453 L .52625 .34503 L F
.52595 .3451 m .52602 .34505 L .52652 .345 L F
.52503 .34446 m .52689 .34508 L .52659 .34502 L F
.52395 .34407 m .52501 .34444 L .52503 .34446 L F
.52501 .34444 m .52689 .34508 L .52503 .34446 L F
.52582 .34573 m .52601 .3453 L .52607 .3448 L F
.52606 .34553 m .52629 .34508 L .52636 .34517 L F
.52639 .3452 m .52636 .34517 L .52669 .34477 L F
.52578 .3452 m .5258 .34578 L .52594 .3453 L F
.5258 .34578 m .5258 .34581 L .52582 .34573 L F
.5258 .34578 m .52582 .34573 L .52594 .3453 L F
.52639 .3452 m .52606 .34553 L p .52636 .34517 L F P
0 g
s
.52606 .34553 m .52639 .3452 L p .52598 .34536 L .672 .728 .891 r
F P
0 g
s
.52545 .34558 m .5259 .34554 L .52598 .34536 L .672 .728 .891 r
F
.52581 .34578 m .52596 .34542 L .52602 .34537 L F
.5259 .34554 m .52606 .34553 L .52598 .34536 L F
.52639 .3452 m .52672 .34487 L p .52631 .3451 L F P
0 g
s
.52631 .3451 m .52632 .34512 L .52622 .34513 L .672 .728 .891 r
F
.5262 .34496 m .52676 .34506 L .52675 .34505 L F
.52672 .34507 m .52595 .3451 L .52673 .34498 L F
.52601 .3453 m .52618 .34494 L .52604 .34503 L F
.52598 .34536 m .52639 .3452 L .52603 .34525 L F
.52598 .34563 m .52618 .34494 L .52601 .3453 L F
.52603 .34525 m .52639 .3452 L .52631 .3451 L F
.52534 .34582 m .5253 .34577 L .52592 .34504 L F
.52545 .34558 m .52598 .34536 L .52603 .34525 L F
.52618 .34511 m .52631 .3451 L .52622 .34513 L F
.52631 .3451 m .52672 .34507 L .52632 .34512 L F
.52631 .3451 m .52672 .34487 L .5263 .3451 L F
.52594 .3453 m .52672 .34487 L .52594 .3453 L F
.52627 .34505 m .52652 .345 L .52655 .34501 L F
.52595 .3451 m .52626 .34505 L .52627 .34505 L F
.52626 .34505 m .52652 .345 L .52627 .34505 L F
.5263 .3451 m .52672 .34487 L .5267 .34487 L F
.52594 .3453 m .52631 .3451 L .5263 .3451 L F
.52545 .34558 m .52594 .3453 L .52594 .3453 L F
.52605 .34522 m .52616 .34498 L .52611 .34495 L F
.52604 .34503 m .52618 .34494 L .52607 .3448 L F
.52593 .34489 m .5251 .34455 L .52659 .34502 L F
.52616 .34492 m .52611 .34492 L .52606 .34479 L F
.52611 .34492 m .52574 .34485 L .52606 .34479 L F
.5258 .34521 m .526 .34507 L .52607 .3448 L F
.52606 .34479 m .52589 .34497 L .52615 .3449 L F
.5258 .34521 m .52459 .34522 L p .52588 .34515 L F P
0 g
s
.52578 .3452 m .5258 .34521 L .52607 .3448 L .672 .728 .891 r
F
.52589 .34497 m .52532 .34559 L .52609 .34495 L F
.52565 .34483 m .52593 .34489 L .52657 .34515 L F
.52589 .34497 m .52609 .34495 L .52615 .3449 L F
.52498 .34491 m .5258 .34521 L .52544 .34498 L F
.52506 .34513 m .52476 .34506 L .52612 .34497 L F
.52436 .34486 m .52459 .34522 L .52498 .34491 L F
.52476 .34506 m .52475 .34506 L .52477 .34506 L F
.52476 .34506 m .52477 .34506 L .52612 .34497 L F
.52605 .34522 m .5263 .34509 L .52616 .34498 L F
.52616 .34498 m .52618 .34494 L .52611 .34495 L F
.52605 .34503 m .52631 .34496 L .52642 .34499 L F
.5263 .34509 m .52618 .34494 L .52616 .34498 L F
.52639 .3452 m .5267 .3448 L .5267 .3448 L F
.52569 .34544 m .5267 .34487 L .52553 .3455 L F
.52598 .34563 m .52621 .34498 L .52618 .34494 L F
.52532 .34559 m .52545 .34558 L .52611 .34495 L F
.52601 .34473 m .52701 .3451 L .527 .3451 L F
.52675 .345 m .52672 .3449 L .52695 .34496 L F
.52523 .34512 m .52714 .34491 L .52701 .34496 L F
.52506 .34513 m .52524 .34511 L .52523 .34512 L F
.52532 .34559 m .52611 .34495 L .5261 .34495 L F
.52611 .34492 m .5248 .34505 L .52574 .34485 L F
.52596 .34496 m .52565 .34483 L .52597 .34496 L F
.5259 .34496 m .52534 .34561 L .52511 .34569 L F
.52528 .34518 m .52519 .34516 L .52672 .34507 L F
.52532 .34559 m .52615 .34491 L .52615 .3449 L F
.526 .34472 m .52675 .345 L .52675 .345 L F
.5264 .34491 m .52645 .3449 L .52689 .34508 L F
.52642 .34499 m .52631 .34496 L .52714 .34491 L F
.52707 .34511 m .52693 .34506 L .52695 .34496 L F
.52747 .34504 m .52672 .34507 L .52751 .34494 L F
.5268 .34506 m .52701 .34496 L .52773 .3449 L F
.5262 .34648 m .52636 .34516 L .52634 .34514 L F
.52621 .34647 m .52636 .34516 L .5262 .34648 L F
.52615 .34716 m .52636 .34516 L .52613 .34718 L F
.52506 .34513 m .52612 .34497 L .52605 .34503 L F
.52587 .34498 m .52596 .34496 L .52632 .34512 L F
.5258 .34581 m .52595 .34583 L .52601 .3453 L F
.5258 .34581 m .52583 .347 L .52595 .34583 L F
.52592 .34601 m .52593 .34689 L .52573 .34595 L F
.52638 .34558 m .52592 .34585 L .52591 .34554 L F
.52611 .34552 m .52574 .34595 L p .52602 .3453 L F P
0 g
s
.52608 .35784 m .52488 .3578 L p .52573 .34598 L .672 .728 .891 r
F P
0 g
s
.52573 .34597 m .52608 .35784 L .52573 .34598 L .672 .728 .891 r
F
.5256 .34779 m .52603 .34527 L .52595 .34545 L F
.5256 .34779 m .52604 .34539 L .52602 .3454 L F
.5258 .34581 m .52601 .3453 L .52582 .34573 L F
.52574 .34595 m .52572 .34598 L p .52602 .3453 L F P
0 g
s
.52572 .34598 m .52548 .34595 L .52602 .3453 L .672 .728 .891 r
F
.52577 .34537 m .52585 .3457 L .52573 .34595 L F
.52585 .3457 m .52592 .34601 L .52574 .34595 L F
.52585 .3457 m .52574 .34595 L .52573 .34595 L F
.52602 .3453 m .52547 .34595 L .52594 .3451 L F
.52591 .34533 m .52591 .34554 L .52577 .34537 L F
.52591 .34554 m .52592 .34601 L .52585 .3457 L F
.52591 .34554 m .52585 .3457 L .52577 .34537 L F
.52578 .34583 m .52586 .34548 L .52586 .34547 L F
.52572 .34598 m .51984 .35276 L p .52548 .34595 L F P
0 g
s
.51984 .35276 m .51965 .35288 L .52602 .3453 L .672 .728 .891 r
F
.52608 .34535 m .52619 .34529 L .52621 .34498 L F
.52607 .34507 m .52607 .34507 L .52638 .34519 L F
.52491 .34691 m .52572 .34598 L p .52458 .34673 L F P
0 g
s
.52545 .34558 m .52569 .34544 L .52553 .3455 L .672 .728 .891 r
F
.52631 .34496 m .52618 .34494 L .52741 .3448 L F
.52636 .34516 m .5264 .34481 L .5264 .34481 L F
.52542 .34479 m .52596 .34496 L .52587 .34498 L F
.52586 .34498 m .52542 .34479 L p .52587 .34498 L F P
0 g
s
.5248 .34505 m .52438 .34508 L .52524 .34478 L .672 .728 .891 r
F
.52607 .34501 m .52596 .34496 L .52604 .34499 L F
.52615 .34494 m .52659 .34502 L .52678 .34509 L F
.52593 .34489 m .52618 .34494 L .52615 .34494 L F
.52618 .34494 m .52659 .34502 L .52615 .34494 L F
.5261 .34495 m .52611 .34495 L .52615 .34491 L F
.52607 .34507 m .52586 .34498 L p .52607 .34507 L F P
0 g
s
.52596 .34496 m .52597 .34496 L .52604 .34499 L .672 .728 .891 r
F
.52629 .34553 m .52633 .34513 L .52618 .34546 L F
.5263 .3451 m .52672 .34507 L .52672 .34507 L F
.5263 .3451 m .5263 .34509 L .52672 .34507 L F
.52622 .34513 m .52672 .34507 L .52663 .34511 L F
.52683 .34526 m .52593 .34489 L .52678 .34509 L F
.52633 .34513 m .52637 .3448 L .52629 .34508 L F
.52633 .34513 m .52629 .34508 L .52618 .34546 L F
.52521 .34513 m .52523 .34512 L .52673 .34498 L F
.52586 .34498 m .52587 .34498 L .52638 .34519 L F
.52618 .34546 m .52627 .34515 L .5262 .34512 L F
.52627 .34515 m .52629 .34508 L .5262 .34512 L F
.5262 .34512 m .52629 .34508 L .52621 .34498 L F
.52586 .34498 m .52638 .34519 L .52638 .34519 L F
.52607 .34507 m .52636 .34518 L .52637 .34519 L F
.52632 .34555 m .52639 .3452 L .52636 .34517 L F
.52639 .3452 m .52658 .34573 L p .52634 .34515 L F P
0 g
s
.52636 .34518 m .52638 .34519 L .52637 .34519 L .672 .728 .891 r
F
.52637 .34519 m .52638 .34519 L .52638 .3452 L F
.52519 .34516 m .52521 .34513 L .5263 .34509 L F
.52587 .34498 m .52632 .34512 L .52638 .34519 L F
.52602 .3453 m .52594 .3451 L .52607 .34496 L F
.52618 .34494 m .52622 .34483 L .52626 .34436 L F
.52625 .34435 m .52626 .34436 L .52627 .34411 L F
.52618 .34494 m .52626 .34436 L .52625 .34435 L F
.52526 .34451 m .52539 .34449 L .52645 .3449 L F
.52607 .3448 m .52618 .34494 L .5262 .34466 L F
.52565 .34483 m .52155 .34312 L .52593 .34489 L F
.52155 .34312 m .51708 .34125 L .52148 .34306 L F
.52155 .34312 m .52148 .34306 L .52593 .34489 L F
.5255 .3448 m .52615 .3449 L .52613 .34488 L F
.52639 .3452 m .52633 .34512 L .52663 .34511 L F
.52565 .34483 m .52683 .34526 L .52684 .34532 L F
.52606 .34479 m .52594 .3451 L .52589 .34497 L F
.52586 .34498 m .52589 .34499 L p .52583 .34487 L F P
0 g
s
.52477 .34506 m .5248 .34505 L .52611 .34492 L .672 .728 .891 r
F
.52583 .34487 m .52589 .34499 L .526 .34497 L F
.52596 .34871 m .52629 .34553 L .52618 .34546 L F
.52613 .34718 m .52621 .34647 L .5262 .34648 L F
.52589 .34969 m .52615 .34716 L .52613 .34718 L F
.52589 .34969 m .52638 .34558 L .52632 .34555 L F
.52596 .34897 m .52627 .34576 L .52596 .34871 L F
.52627 .34576 m .52627 .34576 L .52596 .34871 L F
.52583 .347 m .52606 .34714 L .52615 .34586 L F
.52583 .347 m .52615 .34586 L .52598 .34563 L F
.52608 .35784 m .52627 .34984 L p .52589 .34969 L F P
0 g
s
.52638 .34558 m .52608 .35784 L p .52592 .34585 L .672 .728 .891 r
F P
0 g
s
.52583 .347 m .52589 .34969 L .52606 .34714 L .672 .728 .891 r
F
.52593 .34689 m .52608 .35784 L .52576 .3469 L F
.52589 .34937 m .52634 .34556 L p .5255 .34915 L F P
0 g
s
.52636 .34517 m .5264 .34481 L .52636 .34516 L .672 .728 .891 r
F
.52639 .3452 m .5264 .34481 L p .52636 .34517 L F P
0 g
s
.52546 .34452 m .52546 .34451 L .52692 .34506 L .672 .728 .891 r
F
.52682 .34492 m .52614 .3444 L .52615 .3444 L F
.52664 .34459 m .52636 .34491 L .52636 .34453 L F
.52674 .34427 m .52635 .34463 L .52631 .34462 L F
.52641 .34443 m .52622 .34484 L .52663 .34445 L F
.52637 .3448 m .52641 .3444 L .52622 .34491 L F
.52546 .34452 m .52692 .34506 L .52691 .34506 L F
.52618 .34494 m .52611 .34492 L .52616 .34492 L F
.52611 .34495 m .52673 .34485 L .52662 .34447 L F
.52638 .34479 m .52624 .34487 L .5262 .34479 L F
.52624 .34487 m .52616 .34492 L .5262 .34479 L F
.52617 .34488 m .52617 .34489 L .52622 .34484 L F
.52615 .3449 m .52617 .34489 L .52617 .34488 L F
.52615 .3449 m .52615 .34491 L .52617 .34489 L F
.52606 .34479 m .52615 .3449 L .52622 .34484 L F
.5262 .34479 m .52616 .34492 L .52606 .34479 L F
.52629 .34508 m .52637 .3448 L .52621 .34498 L F
.52565 .34483 m .52657 .34515 L .52655 .34516 L F
.52618 .34494 m .52621 .34498 L .52622 .34491 L F
.52618 .34494 m .52622 .34491 L .52622 .34483 L F
.52618 .34494 m .52616 .34492 L .52621 .34492 L F
.5267 .34487 m .52673 .34485 L .52611 .34495 L F
.52618 .34494 m .52621 .34492 L .52741 .3448 L F
.52606 .34496 m .52604 .34496 L .52611 .34485 L F
.52611 .34485 m .52594 .3451 L .52606 .34479 L F
.52612 .34493 m .52583 .34487 L .526 .34497 L F
.52669 .34496 m .52669 .34496 L .52523 .34512 L F
.52607 .34501 m .52604 .34499 L .52631 .3451 L F
.52632 .34512 m .52607 .34501 L .52631 .3451 L F
.52614 .34494 m .526 .34497 L .52639 .3452 L F
.52618 .34494 m .52607 .34496 L .52613 .34489 L F
.52672 .34487 m .52673 .34485 L p .5267 .34487 L F P
0 g
s
.52741 .3448 m .52616 .34492 L .52638 .34479 L .672 .728 .891 r
F
.52629 .34487 m .52657 .34494 L .5265 .34489 L F
.52622 .34491 m .52635 .34456 L .52622 .34483 L F
.52611 .34485 m .52627 .34488 L .52629 .34487 L F
.52621 .34498 m .52637 .3448 L .52622 .34491 L F
.52634 .34514 m .5264 .34478 L .52637 .3448 L F
.52636 .34516 m .5264 .34481 L .52634 .34514 L F
.52638 .34479 m .52642 .34483 L .52728 .34492 L F
.5264 .34481 m .5264 .34478 L .52639 .3448 L F
.5264 .34481 m .52639 .3448 L .52634 .34514 L F
.52639 .3452 m .5262 .34492 L .52621 .34492 L F
.52637 .34483 m .52637 .3448 L .52637 .34483 L F
.52687 .34551 m .52835 .34644 L p .52722 .34552 L F P
0 g
s
.53853 .35036 m .52639 .3452 L p .53812 .35006 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .52607 .34507 L p .52638 .3452 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .52638 .3452 L .53794 .34998 L .672 .728 .891 r
F
.52637 .34483 m .52637 .34483 L .52633 .34513 L F
.52633 .34513 m .52633 .34513 L .52627 .34576 L F
.52637 .34483 m .52633 .34513 L .52633 .34513 L F
.52627 .34576 m .52637 .34483 L .52627 .34576 L F
.5264 .34481 m .5264 .34489 L p .52629 .34487 L F P
0 g
s
.5264 .34489 m .52639 .3452 L p .52629 .34487 L .672 .728 .891 r
F P
0 g
s
.52629 .34487 m .52639 .3452 L .52625 .34489 L .672 .728 .891 r
F
.52573 .34598 m .52575 .34598 L .52584 .34545 L F
.52589 .34499 m .52639 .3452 L p .526 .34497 L F P
0 g
s
.52606 .34496 m .52594 .3451 L .52604 .34496 L .672 .728 .891 r
F
.52542 .3449 m .5259 .3451 L .52614 .34496 L F
.52508 .34483 m .52436 .34486 L .52498 .34491 L F
.52524 .34478 m .52438 .34508 L .5239 .34477 L F
.52342 .34476 m .52564 .34506 L .52542 .3449 L F
.52524 .34511 m .52669 .34496 L .52523 .34512 L F
.52564 .34506 m .5259 .3451 L .52542 .3449 L F
.52582 .34543 m .52584 .34545 L .52587 .34523 L F
.52501 .34444 m .52645 .3449 L .5264 .34491 L F
.52612 .34493 m .526 .34497 L .52614 .34494 L F
.52613 .34488 m .52606 .34496 L .52611 .34485 L F
.52538 .34478 m .52613 .34488 L .52611 .34485 L F
.5255 .3448 m .52591 .34488 L .52615 .3449 L F
.52546 .34452 m .526 .34472 L .526 .34472 L F
.52606 .34479 m .52574 .34485 L .52538 .34478 L F
.52606 .34479 m .52538 .34478 L .52593 .34483 L F
.52574 .34454 m .52542 .34478 L .52612 .34493 L F
.52573 .34459 m .5254 .34449 L .52568 .34446 L F
.5254 .34449 m .52578 .34444 L .52581 .34445 L F
.52564 .34443 m .52553 .34461 L .52574 .34454 L F
.52575 .34463 m .52546 .34452 L .52574 .34462 L F
.52553 .34461 m .52542 .34478 L .52574 .34454 L F
.52595 .34507 m .52591 .34509 L .5259 .34472 L F
.52547 .34595 m .52526 .34593 L .52594 .3451 L F
.52589 .3451 m .52591 .34533 L .52579 .34516 L F
.52701 .3451 m .52702 .3451 L .52831 .34559 L F
.52625 .34489 m .5262 .34489 L .52622 .34483 L F
.52639 .3452 m .52621 .34492 L .52625 .34489 L F
.52613 .34488 m .52615 .3449 L .52657 .34494 L F
.52621 .34492 m .5262 .34489 L .52625 .34489 L F
.52642 .34491 m .52657 .34494 L .52642 .3449 L F
.52642 .34491 m .52642 .3449 L .52629 .34487 L F
.52627 .34488 m .52642 .34491 L .52629 .34487 L F
.52635 .34456 m .52641 .3444 L .52622 .34483 L F
.52642 .3444 m .52606 .34479 L .52622 .34484 L F
.5264 .34481 m .5264 .34478 L p .5264 .34481 L F P
0 g
s
.5264 .34478 m .5264 .34481 L p .52612 .34461 L .672 .728 .891 r
F P
0 g
s
.52626 .34475 m .52626 .34471 L .52628 .3447 L .672 .728 .891 r
F
.52606 .34479 m .52593 .34483 L .52611 .34485 L F
.52535 .34583 m .51692 .35612 L .52515 .34589 L F
.5246 .34669 m .52572 .34598 L .52582 .34575 L F
.52606 .34479 m .52611 .34485 L .52718 .34495 L F
.5282 .34518 m .52915 .34517 L p .52755 .34479 L F P
0 g
s
.52725 .34492 m .52718 .34495 L .52879 .3451 L .672 .728 .891 r
F
.52606 .34479 m .52718 .34495 L .52725 .34492 L F
.5264 .34481 m .52625 .34489 L .52622 .34483 L F
.52638 .34479 m .52606 .34479 L .52642 .34483 L F
.5264 .34481 m .52622 .34483 L .52627 .34472 L F
.52639 .3452 m .52629 .34523 L .5262 .34492 L F
.52598 .34563 m .52619 .34529 L .52608 .34535 L F
.52638 .34558 m .52625 .34557 L .5262 .34489 L F
.52625 .34557 m .52591 .34554 L .52599 .34537 L F
.52625 .34557 m .52599 .34537 L .5262 .34489 L F
.52509 .34473 m .52506 .34471 L p .52562 .34483 L F P
0 g
s
.52395 .34407 m .525 .34442 L .52501 .34444 L .672 .728 .891 r
F
.525 .34442 m .52645 .3449 L .52501 .34444 L F
.52542 .34479 m .51781 .34156 L p .52565 .34483 L F P
0 g
s
.51781 .34156 m .51708 .34125 L p .51781 .34155 L .672 .728 .891 r
F P
0 g
s
.51781 .34156 m .51781 .34155 L .52565 .34483 L .672 .728 .891 r
F
.52539 .34449 m .52546 .34451 L .52546 .34452 L F
.5251 .34455 m .52395 .34407 L .52503 .34446 L F
.52356 .34382 m .52228 .3432 L p .52355 .34379 L F P
0 g
s
.52228 .3432 m .52154 .34284 L p .52227 .34318 L .672 .728 .891 r
F P
0 g
s
.52546 .34452 m .52539 .34449 L .52546 .34452 L .672 .728 .891 r
F
.52539 .34449 m .5249 .3443 L .5254 .34449 L F
.5254 .34449 m .5249 .3443 L .52578 .34444 L F
.52362 .34383 m .52389 .34395 L .52389 .34395 L F
.52154 .34284 m .52363 .34382 L .52362 .34383 L F
.52154 .34284 m .52161 .34285 L .52588 .34488 L F
.52383 .34358 m .52336 .34332 L .52385 .34358 L F
.52336 .34332 m .52385 .34358 L .52385 .34358 L F
.52331 .34349 m .52421 .34399 L p .52335 .3431 L F P
0 g
s
.52336 .34332 m .51179 .33707 L .52344 .3433 L .672 .728 .891 r
F
.51179 .33707 m .52331 .34349 L p .52335 .3431 L F P
0 g
s
.52154 .34284 m .51951 .34184 L p .52161 .34285 L .672 .728 .891 r
F P
0 g
s
.52335 .3431 m .52453 .34392 L .5243 .34365 L .672 .728 .891 r
F
.52491 .34392 m .51951 .34184 L .5216 .34219 L F
.52395 .34396 m .51951 .34184 L .52491 .34392 L F
.51105 .33772 m .52428 .34417 L p .52445 .34383 L F P
0 g
s
.52395 .34407 m .52411 .34399 L .52539 .34449 L .672 .728 .891 r
F
.52395 .34407 m .52539 .34449 L .52526 .34451 L F
.52395 .34407 m .51708 .34125 L .52411 .34399 L F
.52577 .34443 m .52034 .34252 L .52097 .34224 L F
.52577 .34443 m .52034 .34252 L .52577 .34443 L F
.5249 .3443 m .52034 .34252 L .52581 .34445 L F
.52564 .34443 m .51995 .34218 L .52542 .34479 L F
.52097 .34224 m .51708 .34125 L .51945 .34155 L F
.52034 .34252 m .51708 .34125 L .52097 .34224 L F
.51708 .34125 m .51038 .3384 L p .51945 .34155 L F P
0 g
s
.51038 .3384 m .51781 .34156 L p .51995 .34218 L .672 .728 .891 r
F P
0 g
s
.51781 .34156 m .52542 .34479 L p .51995 .34218 L .672 .728 .891 r
F P
0 g
s
.5282 .34518 m .52747 .34519 L p .5284 .34501 L .672 .728 .891 r
F P
0 g
s
.52783 .34508 m .52775 .3452 L .53097 .3453 L .672 .728 .891 r
F
.52786 .34504 m .52901 .34516 L .52887 .34513 L F
.52639 .3452 m .53794 .34998 L .53794 .34998 L F
.52684 .34532 m .52683 .34526 L .53473 .34851 L F
.52685 .34534 m .52684 .34532 L .53473 .34851 L F
.52838 .34566 m .5277 .34539 L .52831 .34559 L F
.5289 .34611 m .52872 .34604 L .52901 .3459 L F
.52872 .34604 m .52838 .34566 L .52901 .3459 L F
.52901 .3459 m .52838 .34566 L .52831 .34559 L F
.53473 .34851 m .5289 .34611 L .52901 .3459 L F
.53099 .34655 m .52771 .34525 L .52884 .34624 L F
.52655 .34501 m .52652 .345 L .52673 .34498 L F
.52742 .34518 m .52674 .34487 L .52742 .34519 L F
.52693 .34506 m .52675 .345 L .52695 .34496 L F
.52677 .34505 m .52701 .34496 L .5268 .34506 L F
.52704 .34511 m .52675 .345 L .52707 .34511 L F
.52663 .34511 m .52672 .34507 L .52684 .34507 L F
.52696 .34509 m .52684 .34507 L .5284 .34501 L F
.52663 .34511 m .52684 .34507 L .52696 .34509 L F
.52699 .3451 m .52743 .34526 L .52743 .34526 L F
.52601 .34473 m .527 .3451 L .52699 .3451 L F
.527 .3451 m .52743 .34526 L .52699 .3451 L F
.52672 .34507 m .52673 .34498 L .52681 .34504 L F
.52747 .34519 m .52715 .34513 L .5284 .34501 L F
.52639 .3452 m .52663 .34511 L .52696 .34509 L F
.52742 .34518 m .52707 .34511 L .52695 .34496 L F
.52715 .34513 m .52696 .34509 L .5284 .34501 L F
.52639 .3452 m .52696 .34509 L .52715 .34513 L F
.52831 .34559 m .52708 .34512 L .52707 .34511 L F
.52746 .3452 m .52742 .34518 L .52742 .34519 L F
.52831 .34559 m .52707 .34511 L .52742 .34518 L F
.52619 .34496 m .52775 .3452 L .52783 .34508 L F
.52767 .34524 m .52693 .34494 L .52724 .34516 L F
.527 .3451 m .52701 .3451 L .52743 .34526 L F
.52672 .34507 m .52677 .34505 L .5268 .34506 L F
.52708 .34512 m .52704 .34511 L .52707 .34511 L F
.5277 .34539 m .52601 .34473 L .52778 .34539 L F
.5267 .34504 m .52671 .34505 L .52775 .3452 L F
.52632 .34512 m .52631 .3451 L .52684 .34532 L F
.52671 .34505 m .52639 .3452 L .52724 .34516 L F
.52659 .34502 m .52689 .34508 L .52838 .34566 L F
.52671 .34505 m .52688 .34518 L .52742 .34519 L F
.52671 .34505 m .52742 .34519 L .52775 .3452 L F
.52638 .34519 m .52638 .34519 L .53227 .34763 L F
.52638 .3452 m .52638 .34519 L .52866 .34614 L F
.52638 .3452 m .52866 .34614 L .52865 .34614 L F
.52638 .34519 m .52632 .34512 L .53039 .34682 L F
.52655 .34516 m .52657 .34515 L .52683 .34526 L F
.52685 .34534 m .52632 .34512 L .52684 .34532 L F
.52683 .34526 m .52678 .34509 L .52838 .34566 L F
.52639 .3452 m .52884 .34624 L p .52724 .34516 L F P
0 g
s
.52681 .34504 m .52673 .34498 L .52701 .34496 L .672 .728 .891 r
F
.52693 .34494 m .52671 .34505 L .52724 .34516 L F
.52699 .34502 m .52698 .345 L .52767 .34524 L F
.52705 .34499 m .52756 .34506 L .52755 .34503 L F
.52767 .34524 m .52693 .34494 L .52767 .34524 L F
.52767 .34524 m .5271 .34504 L .52715 .34503 L F
.52712 .34523 m .52682 .34503 L .52771 .34501 L F
.52785 .34506 m .52901 .34516 L .52786 .34504 L F
.52755 .34503 m .52756 .34506 L .52901 .34516 L F
.52669 .34496 m .52714 .34491 L .52669 .34496 L F
.5265 .34489 m .52657 .34494 L .53097 .3453 L F
.52701 .34496 m .52714 .34491 L .52862 .34482 L F
.5284 .34501 m .52789 .34503 L .52862 .34482 L F
.52789 .34503 m .52773 .3449 L .52862 .34482 L F
.52741 .3448 m .52749 .34494 L .53097 .3453 L F
.52768 .34517 m .52771 .34501 L .52964 .34497 L F
.52753 .34521 m .52699 .34502 L .52767 .34524 L F
.52712 .34523 m .52771 .34501 L .52768 .34517 L F
.52594 .3451 m .52559 .34553 L .52589 .34497 L F
.52602 .3453 m .52591 .34533 L .52591 .34509 L F
.52595 .3451 m .52521 .34513 L .52602 .34505 L F
.52564 .34506 m .52575 .34514 L .52635 .34516 L F
.52602 .3453 m .52607 .34496 L .52618 .34494 L F
.52618 .34494 m .52602 .3453 L .52591 .34509 L F
.52671 .34505 m .52618 .34494 L .52619 .34496 L F
.52662 .34509 m .52619 .34496 L .52639 .3452 L F
.52619 .34496 m .52688 .34518 L .52671 .34505 L F
.52702 .34516 m .52634 .34515 L .52682 .34503 L F
.52611 .34552 m .52602 .3453 L .52618 .34494 L F
.52613 .34488 m .52657 .34494 L .52611 .34485 L F
.52708 .34498 m .52785 .34506 L .52786 .34504 L F
.52591 .34488 m .52706 .34499 L .52708 .34498 L F
.52706 .34499 m .52785 .34506 L .52708 .34498 L F
.5259 .3451 m .52625 .34515 L .52596 .34506 L F
.52611 .34552 m .52621 .34498 L .52633 .34513 L F
.52625 .34515 m .52631 .34515 L .52618 .34513 L F
.52631 .34515 m .52635 .34516 L .52618 .34513 L F
.52615 .3453 m .52618 .34494 L .52621 .34498 L F
.52611 .34552 m .52613 .34531 L .52615 .3453 L F
.52613 .34531 m .52618 .34494 L .52615 .3453 L F
.52639 .3452 m .52772 .34524 L p .52638 .34519 L F P
0 g
s
.52582 .34514 m .52772 .34524 L .52772 .34524 L .672 .728 .891 r
F
.52721 .34519 m .52582 .34514 L .52715 .34521 L F
.52694 .34522 m .52639 .3452 L p .52702 .34516 L F P
0 g
s
.52559 .34553 m .52551 .34556 L .52589 .34497 L .672 .728 .891 r
F
.52602 .3453 m .52591 .34554 L .52591 .34533 L F
.52586 .34548 m .52591 .34554 L .52601 .34505 L F
.52573 .34555 m .52596 .34543 L .52595 .34534 L F
.52596 .34543 m .52639 .3452 L .52601 .34532 L F
.52591 .34554 m .52595 .34545 L .52601 .34505 L F
.52595 .34545 m .52598 .3453 L .52597 .3453 L F
.52596 .34506 m .52635 .34516 L .52614 .34496 L F
.52588 .34514 m .526 .34506 L .52626 .34504 L F
.52603 .34527 m .5261 .34485 L .52595 .34545 L F
.52613 .34488 m .52611 .34485 L .52638 .34445 L F
.52642 .3444 m .52611 .34485 L .52606 .34479 L F
.52627 .34472 m .52622 .34483 L .52612 .34461 L F
.52621 .34492 m .5262 .34492 L .5262 .34489 L F
.52621 .34498 m .52618 .34494 L .52626 .34475 L F
.52629 .34491 m .52626 .34475 L .52647 .34488 L F
.52618 .34494 m .52613 .34489 L .52626 .34475 L F
.52622 .34483 m .5262 .34489 L .52612 .34461 L F
.52626 .34475 m .52594 .3451 L .52626 .34471 L F
.5262 .34489 m .52618 .34494 L .5259 .34448 L F
.52667 .34484 m .52583 .34451 L .52618 .34494 L F
.5257 .34456 m .52571 .34456 L .52592 .34462 L F
.52593 .34463 m .52592 .34462 L .52693 .34494 L F
.5259 .34447 m .5259 .34448 L .52584 .34443 L F
.52591 .3453 m .52591 .3453 L .52584 .3445 L F
.52885 .34508 m .52879 .3451 L .53097 .3453 L F
.52887 .34513 m .52901 .34516 L .53097 .3453 L F
.53097 .3453 m .52799 .34521 L .53099 .34535 L F
.53074 .34484 m .52924 .34482 L .53097 .3453 L F
.53624 .3449 m .53234 .34486 L .53653 .34509 L F
.53563 .34449 m .53234 .34486 L .53624 .3449 L F
.53563 .34449 m .52941 .3447 L .53234 .34486 L F
.53653 .34509 m .54523 .345 L p .53563 .34449 L F P
0 g
s
.54523 .345 m .53241 .34514 L p .53257 .34486 L .672 .728 .891 r
F P
0 g
s
.53732 .34491 m .53074 .34484 L .53804 .34558 L .672 .728 .891 r
F
.53099 .34535 m .53804 .34558 L p .53074 .34484 L F P
0 g
s
.53804 .34558 m .54521 .34582 L p .53732 .34491 L .672 .728 .891 r
F P
0 g
s
.54521 .34582 m .52931 .3453 L p .52964 .34497 L .672 .728 .891 r
F P
0 g
s
.53058 .34529 m .53158 .34558 L .539 .34617 L .672 .728 .891 r
F
.52772 .34524 m .52805 .34526 L p .52772 .34524 L F P
0 g
s
.52805 .34526 m .53099 .34535 L p .52799 .34521 L .672 .728 .891 r
F P
0 g
s
.52931 .3453 m .52772 .34524 L p .52929 .34502 L .672 .728 .891 r
F P
0 g
s
.52955 .34506 m .52929 .34502 L .52964 .34497 L .672 .728 .891 r
F
.52931 .3453 m .52929 .34502 L .52955 .34506 L F
.52506 .34471 m .52086 .34318 L p .52506 .34463 L F P
0 g
s
.52086 .34318 m .50977 .33911 L p .52078 .34308 L .672 .728 .891 r
F P
0 g
s
.52086 .34318 m .52078 .34308 L .52506 .34463 L .672 .728 .891 r
F
.52799 .34521 m .52721 .34519 L .52805 .34526 L F
.52772 .34524 m .52745 .34519 L .52964 .34497 L F
.52753 .34497 m .52792 .34529 L .52817 .34531 L F
.52841 .34511 m .52817 .34531 L .53158 .34558 L F
.52753 .34497 m .52817 .34531 L .52841 .34511 L F
.52618 .34494 m .52627 .34411 L .52626 .3441 L F
.52613 .34488 m .52638 .34445 L .52638 .34447 L F
.52607 .3448 m .52623 .34427 L .52612 .3443 L F
.5264 .34478 m .52612 .34461 L .52589 .34372 L F
.52612 .34487 m .52618 .34494 L .5263 .34407 L F
.52641 .3444 m .52649 .34097 L p .52626 .34436 L F P
0 g
s
.52627 .34376 m .5263 .34379 L .52649 .34097 L .672 .728 .891 r
F
.52574 .34353 m .52578 .3435 L .52573 .34168 L F
.52574 .34353 m .52573 .34168 L .52548 .3324 L F
.52576 .34353 m .52564 .3435 L .52548 .34268 L F
.5256 .34367 m .52574 .34353 L .52548 .3324 L F
.5257 .34171 m .52577 .34443 L .52649 .34097 L F
.52649 .34097 m .5267 .33239 L p .5257 .34171 L F P
0 g
s
.5267 .33239 m .52642 .344 L p .52589 .34372 L .672 .728 .891 r
F P
0 g
s
.52628 .34404 m .5263 .34407 L .52636 .34362 L .672 .728 .891 r
F
.52618 .34494 m .5263 .34379 L .52627 .34376 L F
.52641 .34443 m .52622 .34441 L .52589 .34372 L F
.52612 .34487 m .5263 .34407 L .52628 .34404 L F
.5264 .34478 m .52641 .3444 L p .52637 .3448 L F P
0 g
s
.52641 .34443 m .5264 .34478 L p .52632 .34461 L .672 .728 .891 r
F P
0 g
s
.52665 .34439 m .52665 .34437 L .52674 .34427 L .672 .728 .891 r
F
.52633 .3446 m .52696 .34428 L .52667 .34432 L F
.53199 .33926 m .52675 .34462 L .52636 .34453 L F
.5265 .34442 m .52629 .34468 L .52642 .3444 L F
.52629 .34468 m .52613 .34488 L .52638 .34447 L F
.52641 .34443 m .52632 .34461 L .52639 .34443 L F
.52629 .34468 m .52638 .34447 L .52642 .3444 L F
.52639 .34443 m .52632 .34461 L .52622 .34441 L F
.52665 .34456 m .52626 .34471 L .5265 .34442 L F
.52637 .34452 m .52623 .34482 L .52678 .34422 L F
.52626 .34475 m .52628 .3447 L .52665 .34456 L F
.52644 .34477 m .52651 .34421 L p .52618 .34494 L F P
0 g
s
.52747 .34504 m .52751 .34494 L .52773 .3449 L .672 .728 .891 r
F
.52606 .34479 m .52879 .3451 L .52885 .34508 L F
.52638 .34447 m .52638 .34445 L .52642 .3444 L F
.52618 .34494 m .52596 .34467 L .52658 .34488 L F
.52594 .34489 m .52615 .34491 L .52591 .34488 L F
.52575 .34463 m .52702 .3451 L .52701 .3451 L F
.52615 .34491 m .52785 .34506 L .52615 .3449 L F
.52615 .34491 m .52615 .3449 L .52591 .34488 L F
.52675 .34494 m .52667 .34484 L .52618 .34494 L F
.52619 .34496 m .52671 .34505 L .52658 .34502 L F
.52619 .34496 m .52635 .34516 L .52688 .34518 L F
.52621 .34492 m .52702 .345 L .52705 .34499 L F
.52699 .34502 m .5267 .34492 L .52698 .345 L F
.52542 .34478 m .52542 .34479 L .52612 .34493 L F
.52538 .34478 m .52591 .34488 L .5255 .3448 L F
.52562 .34483 m .52514 .34466 L .52596 .34467 L F
.52542 .34479 m .52565 .34483 L .52596 .34496 L F
.52542 .34479 m .52586 .34498 L p .52583 .34487 L F P
0 g
s
.52538 .34478 m .52536 .34484 L .52591 .34488 L .672 .728 .891 r
F
.52604 .34477 m .5254 .3449 L .52519 .34473 L F
.5267 .34492 m .52658 .34488 L .52669 .34491 L F
.52536 .34484 m .52866 .34513 L .52536 .34484 L F
.52866 .34513 m .52901 .34516 L .52867 .34513 L F
.52866 .34513 m .52867 .34513 L .52536 .34484 L F
.52668 .34486 m .52639 .3452 L p .52661 .34466 L F P
0 g
s
.52658 .34488 m .52564 .34456 L .5266 .34488 L .672 .728 .891 r
F
.5267 .3448 m .5271 .34427 L .5271 .34427 L F
.5267 .3448 m .5271 .34427 L .5267 .3448 L F
.52669 .34477 m .52667 .3447 L .52714 .34422 L F
.5267 .3448 m .52669 .34477 L .5271 .34427 L F
.52675 .34462 m .52667 .3447 L .52664 .34459 L F
.52673 .34485 m .52718 .34441 L p .52665 .34459 L F P
0 g
s
.5271 .34438 m .52668 .34486 L p .52665 .34456 L .672 .728 .891 r
F P
0 g
s
.52672 .34486 m .52592 .34462 L .52583 .34451 L .672 .728 .891 r
F
.52693 .34494 m .52672 .34486 L .52675 .34494 L F
.52693 .34494 m .52668 .34486 L .52672 .34486 L F
.52647 .34488 m .52626 .34475 L .52658 .34459 L F
.5266 .34464 m .52658 .34459 L .52665 .34456 L F
.52647 .34488 m .52658 .34459 L .5266 .34464 L F
.52672 .34486 m .52667 .34484 L .52675 .34494 L F
.52668 .34486 m .52668 .34486 L .52672 .34486 L F
.52668 .34486 m .52592 .34462 L .52667 .34485 L F
.52668 .34486 m .52667 .34485 L .52672 .34486 L F
.52618 .34513 m .52635 .34516 L .52596 .34506 L F
.52602 .3454 m .52604 .34539 L .52607 .34518 L F
.5259 .34448 m .52591 .3453 L .52584 .3445 L F
.52459 .34477 m .52614 .34496 L .52619 .34493 L F
.52584 .34443 m .52589 .3451 L .52579 .34516 L F
.52583 .34451 m .52578 .3452 L .52597 .34446 L F
.52579 .34516 m .52591 .34533 L .52577 .34537 L F
.52573 .34595 m .52573 .34597 L .52573 .34598 L F
.52578 .3452 m .52573 .34598 L .52586 .34515 L F
.52595 .34507 m .5259 .34472 L .5259 .34448 L F
.52601 .34473 m .52575 .34463 L .52601 .34473 L F
.52578 .3452 m .52586 .34515 L .52597 .34446 L F
.52581 .34518 m .52639 .3452 L p .52579 .34516 L F P
0 g
s
.52579 .34516 m .52639 .3452 L .52638 .34519 L .672 .728 .891 r
F
.52582 .34514 m .52579 .34516 L .52772 .34524 L F
.52639 .3452 m .52581 .34518 L p .52634 .34515 L F P
0 g
s
.52576 .34518 m .52581 .34518 L p .52579 .34516 L .672 .728 .891 r
F P
0 g
s
.52519 .34516 m .52506 .34513 L .52521 .34513 L .672 .728 .891 r
F
.52521 .34513 m .52506 .34513 L .52523 .34512 L F
.52317 .34524 m .52459 .34522 L p .52436 .34486 L F P
0 g
s
.52506 .34513 m .52171 .34525 L .52475 .34506 L .672 .728 .891 r
F
.52458 .34673 m .52572 .34598 L .5246 .34669 L F
.5245 .34689 m .52491 .34691 L .52458 .34673 L F
.52436 .34688 m .5245 .34689 L .52458 .34673 L F
.52547 .34595 m .52505 .34645 L .52526 .34593 L F
.52436 .34688 m .52582 .34575 L .52573 .34555 L F
.52433 .34691 m .52507 .34619 L .52498 .34619 L F
.52441 .34691 m .52491 .34691 L .52436 .34688 L F
.51984 .35276 m .51692 .35612 L p .51965 .35288 L F P
0 g
s
.51692 .35612 m .52491 .34691 L p .52433 .34691 L .672 .728 .891 r
F P
0 g
s
.52523 .34676 m .51798 .35651 L p .5249 .34619 L .672 .728 .891 r
F P
0 g
s
.52497 .3463 m .52415 .3475 L .52502 .34639 L .672 .728 .891 r
F
.52583 .34451 m .52574 .34454 L .52639 .3452 L F
.52583 .3455 m .52601 .34472 L .52596 .34467 L F
.52575 .34598 m .52585 .34549 L .52583 .3455 L F
.52585 .34549 m .52601 .34472 L .52583 .3455 L F
.52691 .34506 m .52692 .34506 L .52831 .34559 L F
.52767 .34524 m .52724 .34516 L .52764 .34543 L F
.52721 .34519 m .52715 .34521 L .52805 .34526 L F
.52767 .34524 m .52712 .34523 L .52745 .34519 L F
.52772 .34524 m .52767 .34524 L p .52767 .34524 L F P
0 g
s
.52767 .34524 m .52712 .34523 L p .52767 .34524 L .672 .728 .891 r
F P
0 g
s
.5277 .34539 m .52778 .34539 L .52831 .34559 L .672 .728 .891 r
F
.52771 .34525 m .52767 .34524 L .52884 .34624 L F
.52743 .34526 m .52743 .34526 L .52831 .34559 L F
.52872 .34604 m .52683 .34526 L .52838 .34566 L F
.52767 .34524 m .52764 .34543 L .52884 .34624 L F
.52771 .34525 m .52767 .34524 L .52767 .34524 L F
.52693 .34494 m .52679 .34494 L .52688 .34497 L F
.52679 .34494 m .52618 .34494 L .52688 .34497 L F
.52658 .34502 m .52671 .34505 L .5267 .34504 L F
.52619 .34493 m .52756 .34506 L .52621 .34492 L F
.52619 .34493 m .52614 .34496 L .52756 .34506 L F
.52688 .34497 m .52618 .34494 L .52671 .34505 L F
.5267 .34492 m .52669 .34491 L .52698 .345 L F
.52639 .3452 m .52633 .34513 L .5266 .34464 L F
.52661 .34466 m .5266 .34464 L .52665 .34456 L F
.52639 .3452 m .5266 .34464 L .52661 .34466 L F
.52614 .34497 m .5262 .34497 L .52607 .34501 L F
.52631 .3451 m .52665 .34487 L .52626 .34504 L F
.52695 .34496 m .52665 .34487 L .52693 .34494 L F
.52665 .34487 m .5257 .34456 L .52668 .34486 L F
.52665 .34487 m .52668 .34486 L .52693 .34494 L F
.52741 .3448 m .52638 .34479 L .52728 .34492 L F
.5264 .34491 m .52671 .34483 L .52664 .34467 L F
.52633 .34513 m .52629 .34491 L .52647 .34488 L F
.52626 .34504 m .52662 .34487 L .5264 .34491 L F
.52662 .34487 m .52671 .34483 L .5264 .34491 L F
.52665 .34487 m .52671 .34483 L .52662 .34487 L F
.52665 .34487 m .52662 .34487 L .52626 .34504 L F
.52616 .34494 m .52753 .34521 L .5277 .34527 L F
.52618 .34494 m .52595 .34507 L .5259 .34448 L F
.52586 .34522 m .52587 .34523 L .526 .34445 L F
.52391 .34483 m .52575 .34514 L .52564 .34506 L F
.52481 .34503 m .52623 .34491 L .52614 .34497 L F
.52477 .34506 m .52438 .34508 L .5248 .34505 L F
.52391 .34483 m .52438 .3451 L .52575 .34514 L F
.52464 .34504 m .52482 .34503 L .52481 .34503 L F
.52482 .34503 m .52623 .34491 L .52481 .34503 L F
.52631 .3451 m .52647 .345 L .52646 .345 L F
.52647 .345 m .52668 .34486 L .52646 .345 L F
.52646 .345 m .52668 .34486 L .52665 .34487 L F
.52639 .3452 m .52668 .34486 L p .52631 .3451 L F P
0 g
s
.52621 .34498 m .52626 .34475 L .52633 .34513 L .672 .728 .891 r
F
.52618 .34494 m .5267 .34492 L .52674 .34505 L F
.52626 .34504 m .52706 .34492 L .5268 .34503 L F
.52614 .34496 m .52635 .34516 L .52619 .34496 L F
.52602 .34505 m .52624 .34502 L .52626 .34504 L F
.52624 .34502 m .52706 .34492 L .52626 .34504 L F
.52634 .34515 m .52588 .34514 L .52626 .34504 L F
.52604 .34524 m .52607 .34518 L .5261 .34499 L F
.52591 .3453 m .52591 .34533 L .52591 .3453 L F
.52586 .34548 m .52601 .34505 L .52595 .34509 L F
.52581 .34518 m .52588 .34514 L .52634 .34515 L F
.52598 .3453 m .52604 .34503 L .52597 .3453 L F
.52586 .34537 m .52624 .34501 L .52568 .34543 L F
.52624 .34501 m .527 .3443 L .52621 .34498 L F
.52582 .34543 m .52587 .34523 L .52586 .34522 L F
.52624 .34501 m .52621 .34498 L .52568 .34543 L F
.52618 .34494 m .52753 .34521 L .52616 .34494 L F
.5262 .34497 m .52706 .34492 L .52622 .345 L F
.52618 .34494 m .52658 .34488 L .5267 .34492 L F
.52674 .34505 m .5267 .34492 L .52753 .34521 L F
.52609 .345 m .5261 .34499 L .52616 .34457 L F
.5266 .34488 m .5266 .34488 L .5266 .34488 L F
.5266 .34488 m .5266 .34488 L .52669 .34491 L F
.52658 .34488 m .5266 .34488 L .52669 .34491 L F
.52595 .34509 m .52601 .34505 L .52609 .34451 L F
.52608 .3445 m .52609 .34451 L .52613 .34426 L F
.52595 .34509 m .52609 .34451 L .52608 .3445 L F
.52601 .34505 m .52605 .34491 L .52603 .34491 L F
.52605 .34491 m .52607 .34481 L .52603 .34491 L F
.52603 .34491 m .52607 .34481 L .52605 .34478 L F
.52586 .34522 m .526 .34445 L .52599 .34446 L F
.52598 .34441 m .52608 .34392 L .52605 .34397 L F
.52614 .34497 m .52607 .34501 L .5256 .34505 L F
.52607 .34501 m .52706 .34492 L .52602 .34505 L F
.5261 .34485 m .52608 .34482 L .52595 .34544 L F
.52464 .34504 m .52495 .34489 L .526 .34491 L F
.52459 .34477 m .52442 .34483 L .52614 .34496 L F
.52509 .34473 m .52594 .345 L .5259 .34501 L F
.5262 .34497 m .52622 .345 L .52607 .34501 L F
.52604 .34524 m .5261 .34499 L .52609 .345 L F
.52597 .3453 m .52604 .34503 L .52601 .34505 L F
.52604 .34524 m .52616 .34457 L .52603 .34527 L F
.52568 .34543 m .52614 .34504 L .52611 .34495 L F
.52614 .34504 m .52626 .34493 L .52618 .34494 L F
.52604 .34525 m .52631 .3451 L .52626 .34504 L F
.52602 .34529 m .52631 .3451 L .52604 .34525 L F
.52604 .34525 m .5264 .34491 L .52607 .34519 L F
.5261 .34485 m .52595 .34544 L .52595 .34544 L F
.5264 .34491 m .52634 .34492 L .52592 .34531 L F
.52592 .34531 m .52592 .34531 L .52586 .34537 L F
.5264 .34491 m .52592 .34531 L .52592 .34531 L F
.52506 .34471 m .52506 .34463 L .52562 .34483 L F
.52642 .3444 m .52641 .34443 L .5284 .34258 L F
.52642 .3444 m .53276 .33853 L .53274 .33853 L F
.52705 .34427 m .52715 .34426 L .52782 .3437 L F
.5271 .34427 m .5271 .34427 L .52714 .34422 L F
.52757 .34378 m .52782 .3437 L .53512 .33756 L F
.53241 .33917 m .52739 .34419 L p .53199 .33926 L F P
0 g
s
.52739 .34419 m .52714 .34422 L .53199 .33926 L .672 .728 .891 r
F
.53699 .33459 m .53241 .33917 L p .53199 .33926 L F P
0 g
s
.52641 .34443 m .52663 .34445 L .53688 .33469 L .672 .728 .891 r
F
.53596 .33415 m .52642 .3444 L .53688 .33469 L F
.52662 .34447 m .52665 .34459 L .53688 .33469 L F
.52701 .34452 m .52801 .34378 L .5271 .3443 L F
.52739 .34419 m .52718 .34441 L p .52714 .34422 L F P
0 g
s
.52718 .34441 m .5271 .34427 L .52714 .34422 L .672 .728 .891 r
F
.52718 .34441 m .53688 .33469 L p .52665 .34459 L F P
0 g
s
.5271 .34438 m .52665 .34456 L .52721 .34356 L .672 .728 .891 r
F
.52601 .34472 m .52613 .34426 L .5261 .34428 L F
.52586 .34547 m .52602 .34474 L .52601 .34472 L F
.5262 .34489 m .5259 .34448 L .52607 .34441 L F
.52602 .34474 m .52613 .34426 L .52601 .34472 L F
.5271 .34504 m .52595 .34466 L .52715 .34503 L F
.52595 .34466 m .52479 .34426 L .52593 .34464 L F
.52595 .34466 m .52593 .34464 L .52715 .34503 L F
.52479 .34426 m .52451 .34417 L .52478 .34426 L F
.52586 .34548 m .52602 .34475 L .52586 .34547 L F
.52602 .34475 m .52613 .34426 L .52602 .34474 L F
.52602 .34475 m .52602 .34474 L .52586 .34547 L F
.52479 .34426 m .52478 .34426 L .52593 .34463 L F
.52593 .34464 m .52593 .34463 L .52715 .34503 L F
.52479 .34426 m .52593 .34463 L .52593 .34464 L F
.5255 .34915 m .52634 .34556 L .52605 .34535 L F
.52634 .34556 m .52619 .34688 L p .52605 .34569 L F P
0 g
s
.52618 .34615 m .52624 .34588 L p .52587 .34597 L .672 .728 .891 r
F P
0 g
s
.5264 .34491 m .5268 .34452 L .52634 .34492 L .672 .728 .891 r
F
.52784 .34351 m .52713 .34418 L .52721 .34356 L F
.52786 .34351 m .52713 .34418 L .52784 .34351 L F
.52786 .34351 m .5271 .34438 L p .52713 .34418 L F P
0 g
s
.5268 .34452 m .52792 .34343 L .52674 .34454 L .672 .728 .891 r
F
.52668 .34486 m .52661 .34466 L .52665 .34456 L F
.5268 .34452 m .52674 .34454 L .52634 .34492 L F
.52862 .34482 m .52714 .34491 L .52741 .3448 L F
.52741 .3448 m .52728 .34492 L .52745 .34486 L F
.52762 .34486 m .52718 .34487 L .52726 .34484 L F
.52964 .34497 m .52772 .34494 L .52762 .34486 L F
.52845 .3449 m .52641 .34479 L .52817 .34499 L F
.52595 .34534 m .52639 .3452 L .52631 .3451 L F
.52605 .34535 m .52639 .3452 L .52618 .34494 L F
.5262 .34496 m .5277 .34527 L .52767 .3453 L F
.52562 .34483 m .52616 .34494 L .52613 .34495 L F
.52573 .34598 m .52595 .34466 L .52594 .34465 L F
.52562 .34483 m .52596 .34467 L .52618 .34494 L F
.526 .34491 m .52568 .34484 L .52604 .34477 L F
.52604 .34477 m .52587 .34499 L .52609 .34482 L F
.52582 .34514 m .52329 .34507 L .52576 .34518 L F
.52459 .34522 m .52506 .34513 L .52528 .34518 L F
.52581 .34518 m .52336 .3451 L p .52588 .34514 L F P
0 g
s
.52535 .34583 m .52515 .34589 L .52589 .34497 L .672 .728 .891 r
F
.52587 .34499 m .52546 .3455 L .52594 .34498 L F
.52536 .34484 m .52594 .34489 L .52591 .34488 L F
.52459 .34477 m .52619 .34493 L .52621 .34492 L F
.526 .34491 m .5254 .3449 L .52568 .34484 L F
.52562 .34483 m .52618 .34494 L .52616 .34494 L F
.52607 .34518 m .52618 .34494 L .52612 .34487 L F
.52614 .34504 m .52618 .34494 L .52611 .34495 L F
.52546 .3455 m .52568 .34543 L .52573 .34537 L F
.52546 .3455 m .52573 .34537 L .52615 .34491 L F
.52559 .34553 m .52535 .34583 L .52551 .34556 L F
.52546 .3455 m .52433 .34691 L .52568 .34543 L F
.52498 .34619 m .52586 .34537 L .52568 .34543 L F
.52639 .3452 m .52651 .34515 L .52702 .34516 L F
.52634 .34515 m .52626 .34504 L .52682 .34503 L F
.52712 .34523 m .52694 .34522 L p .52702 .34516 L F P
0 g
s
.52729 .34543 m .52583 .34491 L .52802 .34539 L .672 .728 .891 r
F
.52713 .34545 m .52752 .34552 L .52748 .34557 L F
.52725 .34544 m .52752 .34552 L .52713 .34545 L F
.52686 .34537 m .52743 .34558 L p .52744 .3452 L F P
0 g
s
.5269 .34524 m .52811 .34533 L p .52687 .34521 L .672 .728 .891 r
F P
0 g
s
.52811 .34533 m .53438 .34581 L p .52792 .34529 L .672 .728 .891 r
F P
0 g
s
.52792 .34529 m .53438 .34581 L .53443 .34581 L .672 .728 .891 r
F
.52808 .3454 m .52753 .34521 L .52767 .34524 L F
.52785 .34528 m .52744 .3452 L .52743 .34558 L F
.52687 .34521 m .52811 .34533 L .52792 .34529 L F
.5429 .35125 m .54344 .35053 L p .5337 .34722 L F P
0 g
s
.5337 .34722 m .52814 .34534 L .53501 .34809 L .672 .728 .891 r
F
.5337 .34722 m .53501 .34809 L .5429 .35125 L F
.52587 .34499 m .52567 .34553 L .52529 .34571 L F
.52554 .34555 m .52568 .34554 L .52582 .34536 L F
.52605 .34535 m .52618 .34494 L .52607 .34518 L F
.50756 .34458 m .50765 .34377 L p .52038 .34446 L F P
0 g
s
.52506 .34472 m .51963 .34468 L .52038 .34446 L .672 .728 .891 r
F
.51963 .34468 m .50756 .34458 L .52038 .34446 L F
.52583 .34491 m .52562 .34483 L .52581 .34487 L F
.52583 .34491 m .52581 .34487 L .52808 .3454 L F
.52464 .34504 m .526 .34491 L .52608 .34492 L F
.52587 .34499 m .52594 .34498 L .52609 .34482 L F
.52594 .3449 m .52616 .34494 L .52616 .34494 L F
.52562 .34483 m .52616 .34494 L .52594 .3449 L F
.52553 .345 m .52614 .34497 L .5256 .34505 L F
.52589 .34499 m .52628 .34507 L .52633 .34513 L F
.5252 .34476 m .52595 .34498 L .52589 .34499 L F
.52604 .34503 m .52621 .34421 L .52601 .34505 L F
.52595 .34498 m .52628 .34507 L .52589 .34499 L F
.52615 .34491 m .526 .34491 L .52604 .34477 L F
.52608 .34492 m .526 .34491 L .52623 .34491 L F
.52594 .34498 m .52615 .34491 L .52609 .34482 L F
.52573 .34598 m .52595 .34466 L .52595 .34466 L F
.5256 .34505 m .52607 .34501 L .52602 .34505 L F
.52546 .3455 m .5261 .34495 L .52594 .34498 L F
.5261 .34495 m .52615 .34491 L .52594 .34498 L F
.52715 .34503 m .52695 .34496 L .52693 .34494 L F
.52649 .34487 m .52684 .34508 L .52729 .34495 L F
.52669 .34485 m .52671 .34483 L p .52669 .34485 L F P
0 g
s
.52665 .34487 m .52669 .34485 L .52669 .34485 L .672 .728 .891 r
F
.52668 .34486 m .52669 .34485 L p .52665 .34487 L F P
0 g
s
.52614 .34497 m .52623 .34491 L .52706 .34492 L .672 .728 .891 r
F
.52564 .34456 m .52563 .34455 L .52698 .345 L F
.52691 .34492 m .52662 .34482 L .52671 .34503 L F
.52618 .34494 m .52664 .34308 L .52648 .34277 L F
.52604 .34477 m .52609 .34482 L .52637 .34452 L F
.52651 .34421 m .52664 .34308 L p .52618 .34494 L F P
0 g
s
.52604 .34477 m .52637 .34452 L .52643 .34438 L .672 .728 .891 r
F
.52609 .34482 m .52615 .34491 L .52623 .34482 L F
.52608 .34501 m .52616 .34457 L .52615 .34456 L F
.52603 .34527 m .52608 .34501 L .52608 .34501 L F
.52608 .34501 m .52616 .34457 L .52608 .34501 L F
.52641 .34479 m .52615 .34491 L .52604 .34477 L F
.52726 .34484 m .52624 .3449 L .52641 .34479 L F
.52626 .34493 m .527 .3443 L .52611 .34495 L F
.52624 .3449 m .52615 .34491 L .52641 .34479 L F
.52609 .34482 m .52623 .34482 L .52637 .34452 L F
.52702 .345 m .52756 .34506 L .52705 .34499 L F
.52684 .34508 m .52785 .34528 L .52729 .34495 L F
.52789 .34525 m .52691 .34492 L .52671 .34503 L F
.52705 .34512 m .52672 .34505 L .52691 .34492 L F
.52671 .34505 m .52665 .34489 L .52691 .34492 L F
.52641 .34431 m .52615 .34491 L .52604 .34477 L F
.52643 .34435 m .52615 .34491 L .52641 .34431 L F
.52645 .34433 m .52615 .34491 L .5265 .34421 L F
.52643 .34482 m .52644 .34477 L p .52641 .34479 L F P
0 g
s
.52618 .34494 m .52643 .34482 L .52641 .34479 L .672 .728 .891 r
F
.5259 .34501 m .52633 .34513 L .52637 .34518 L F
.52613 .34495 m .52619 .34495 L .5262 .34496 L F
.52616 .34494 m .52619 .34495 L .52613 .34495 L F
.52514 .34513 m .52532 .34506 L .52626 .34504 L F
.52594 .345 m .52633 .34513 L .5259 .34501 L F
.52589 .34502 m .52639 .3452 L p .52618 .34494 L F P
0 g
s
.52639 .3452 m .52611 .34552 L p .52633 .34513 L .672 .728 .891 r
F P
0 g
s
.52619 .34495 m .5277 .34527 L .5262 .34496 L .672 .728 .891 r
F
.52639 .3452 m .52643 .34482 L p .52618 .34494 L F P
0 g
s
.52632 .34487 m .52633 .34521 L .52614 .34503 L .672 .728 .891 r
F
.52632 .34555 m .52636 .34517 L .52636 .34516 L F
.52611 .34552 m .52639 .3452 L p .52596 .34543 L F P
0 g
s
.52638 .34558 m .52639 .3452 L p .52632 .34555 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .52638 .34558 L p .52629 .34523 L .672 .728 .891 r
F P
0 g
s
.52634 .34556 m .52639 .3452 L p .52605 .34535 L .672 .728 .891 r
F P
0 g
s
.52633 .34521 m .52634 .34556 L .52622 .34524 L .672 .728 .891 r
F
.52633 .34521 m .52622 .34524 L .52614 .34503 L F
.52747 .3456 m .52639 .3452 L p .52748 .34557 L F P
0 g
s
.52639 .3452 m .52526 .34479 L p .52642 .3452 L .672 .728 .891 r
F P
0 g
s
.52526 .34479 m .52525 .34478 L .52642 .3452 L .672 .728 .891 r
F
.52629 .34469 m .52627 .34472 L .52627 .34469 L F
.52626 .3441 m .52627 .34411 L .5263 .34379 L F
.52612 .34487 m .52636 .34362 L .52631 .34355 L F
.5261 .34485 m .52621 .34421 L .52608 .34482 L F
.5263 .34467 m .52618 .34494 L .52596 .34454 L F
.52616 .34492 m .527 .3443 L .52615 .34491 L F
.52644 .34477 m .52632 .34487 L .5263 .34467 L F
.52632 .34487 m .5262 .34497 L .52618 .34494 L F
.52636 .34485 m .52668 .34504 L .52649 .34487 L F
.52595 .34534 m .52602 .34529 L .52604 .34525 L F
.52595 .34544 m .52595 .34544 L .52595 .34545 L F
.52604 .34525 m .52607 .34519 L .52586 .34537 L F
.52596 .34543 m .52601 .34532 L .52595 .34534 L F
.52591 .34554 m .52611 .34552 L .52596 .34543 L F
.52591 .34554 m .52593 .34556 L .52595 .34545 L F
.52572 .34598 m .52611 .34552 L p .52582 .34575 L F P
0 g
s
.52575 .34598 m .52579 .34582 L .52578 .34583 L .672 .728 .891 r
F
.52579 .34582 m .52586 .34548 L .52578 .34583 L F
.52582 .34575 m .52611 .34552 L .52591 .34554 L F
.52575 .34598 m .52587 .34599 L .52593 .34556 L F
.52575 .34598 m .52593 .34556 L .52586 .34548 L F
.52595 .34534 m .52604 .34525 L .52586 .34537 L F
.526 .34522 m .52589 .34543 L .52587 .34499 L F
.52573 .34598 m .52584 .34545 L .52582 .34543 L F
.52589 .34543 m .52523 .34676 L .52567 .34553 L F
.52589 .34543 m .52567 .34553 L .52587 .34499 L F
.52514 .34511 m .52639 .3452 L p .52513 .3451 L F P
0 g
s
.52588 .34514 m .52514 .34513 L .526 .34506 L .672 .728 .891 r
F
.52602 .34498 m .526 .34522 L .52589 .34502 L F
.52634 .34556 m .52605 .34569 L .52601 .34532 L F
.52615 .345 m .526 .34522 L .52615 .34491 L F
.52603 .34528 m .526 .34522 L .52615 .345 L F
.52608 .34518 m .52601 .34532 L .52598 .34504 L F
.52602 .3454 m .52607 .34518 L .52604 .34524 L F
.52634 .34556 m .52601 .34532 L .52608 .34518 L F
.52634 .34556 m .52598 .34504 L .52612 .34497 L F
.52753 .34497 m .53158 .34558 L .53058 .34529 L F
.52785 .34528 m .52792 .34529 L .52753 .34497 L F
.53242 .34551 m .52658 .34511 L .53152 .34537 L F
.52611 .34495 m .52616 .34492 L .52615 .34491 L F
.52528 .34474 m .52618 .34494 L .52636 .34485 L F
.52615 .34491 m .52613 .34495 L .52604 .34477 L F
.52613 .34495 m .526 .34522 L .52602 .34498 L F
.52613 .34495 m .52602 .34498 L .52604 .34477 L F
.52617 .34493 m .52573 .34469 L .52578 .34485 L F
.52602 .34498 m .52589 .34502 L .52587 .34499 L F
.5259 .34508 m .52601 .34529 L .5259 .34531 L F
.52604 .34477 m .52602 .34498 L .52587 .34499 L F
.52618 .34494 m .52578 .34486 L .52589 .34502 L F
.52597 .34504 m .52601 .34529 L .5259 .34508 L F
.52459 .34477 m .52536 .34484 L .52536 .34484 L F
.52538 .34478 m .52459 .34477 L .52536 .34484 L F
.52506 .34472 m .52503 .34507 L .52579 .34513 L F
.52618 .34494 m .52614 .34503 L .52612 .34497 L F
.5262 .34497 m .52614 .34503 L .52618 .34494 L F
.52643 .34482 m .52634 .34556 L p .52632 .34487 L F P
0 g
s
.52616 .34531 m .52603 .34528 L .52615 .345 L .672 .728 .891 r
F
.52639 .3452 m .52634 .34515 L .52651 .34515 L F
.52633 .34513 m .52752 .34552 L .52637 .34518 L F
.52636 .34517 m .52639 .3452 L .52643 .34518 L F
.52636 .34517 m .52643 .34518 L .5265 .34514 L F
.52618 .34494 m .52636 .34517 L .5265 .34514 L F
.52617 .34494 m .52579 .34513 L .52646 .34518 L F
.52684 .34508 m .52618 .34494 L .52699 .34533 L F
.52617 .34494 m .52646 .34518 L .52683 .34508 L F
.52658 .34511 m .5263 .34509 L .52667 .34507 L F
.52639 .3452 m .52616 .34551 L p .52616 .34531 L F P
0 g
s
.52639 .3452 m .52616 .34531 L .52615 .34491 L .672 .728 .891 r
F
.52594 .34464 m .52601 .34529 L .52588 .34457 L F
.52607 .34481 m .52621 .34421 L .52605 .34478 L F
.52588 .34457 m .526 .34472 L .52634 .3449 L F
.52604 .34477 m .52766 .34312 L .52754 .34318 L F
.52618 .34494 m .52605 .34478 L .52596 .34454 L F
.52605 .34478 m .52621 .34421 L .52613 .34426 L F
.52601 .34472 m .5261 .34428 L .52596 .34467 L F
.5263 .34467 m .52596 .34454 L .52605 .34451 L F
.52595 .34466 m .52607 .34401 L .52607 .34401 L F
.52607 .34441 m .5259 .34448 L .52589 .34372 L F
.526 .34442 m .52608 .34392 L .52598 .34441 L F
.52599 .34446 m .526 .34445 L .52607 .34401 L F
.52595 .3442 m .52639 .34445 L .52591 .34442 L F
.52602 .34433 m .52622 .34365 L .52608 .34392 L F
.5261 .34428 m .52622 .34365 L .52602 .34433 L F
.5261 .34428 m .52613 .34426 L .52622 .34365 L F
.52608 .34392 m .52622 .34365 L .52792 .33243 L F
.52607 .34401 m .52607 .34401 L .52608 .34392 L F
.5259 .34448 m .52584 .3445 L .52584 .34443 L F
.52583 .34451 m .52597 .34446 L .52792 .33243 L F
.52617 .34288 m .52636 .34421 L .52595 .3442 L F
.5265 .34421 m .52604 .34477 L .52657 .34421 L F
.52636 .34421 m .52639 .34445 L .52595 .3442 L F
.53596 .33415 m .53494 .33377 L p .5265 .34421 L F P
0 g
s
.53472 .33397 m .5265 .34421 L .53494 .33377 L .672 .728 .891 r
F
.5265 .34421 m .52657 .34421 L .53596 .33415 L F
.52729 .34543 m .52802 .34539 L .52808 .3454 L F
.52639 .3452 m .52642 .3452 L .52748 .34557 L F
.52639 .3452 m .52686 .34537 L p .5265 .34514 L F P
0 g
s
.52637 .34518 m .52725 .34544 L .52713 .34545 L .672 .728 .891 r
F
.52633 .34513 m .52628 .34507 L .52752 .34552 L F
.52767 .3453 m .5277 .34527 L .52808 .3454 L F
.5278 .34564 m .52639 .3452 L p .52814 .34534 L F P
0 g
s
.5263 .34509 m .52598 .34507 L .52628 .34507 L .672 .728 .891 r
F
.52598 .34507 m .526 .34506 L .52628 .34506 L F
.52618 .34494 m .52668 .34504 L .52636 .34485 L F
.52671 .34503 m .52617 .34493 L .52668 .34504 L F
.52668 .34504 m .52684 .34508 L .52649 .34487 L F
.52662 .34482 m .52634 .3449 L .52671 .34503 L F
.52671 .34503 m .52634 .3449 L .52621 .34493 L F
.52617 .34493 m .52618 .34494 L .52668 .34504 L F
.52618 .34494 m .52633 .34497 L .52633 .34497 L F
.52633 .34497 m .52668 .34505 L .52633 .34497 L F
.52633 .34497 m .52668 .34505 L .52668 .34504 L F
.52618 .34494 m .52668 .34505 L .52618 .34494 L F
.52668 .34481 m .52639 .3452 L p .52632 .3449 L F P
0 g
s
.52639 .3452 m .52668 .34481 L p .5263 .34509 L .672 .728 .891 r
F P
0 g
s
.52699 .34533 m .52618 .34494 L .52686 .34537 L .672 .728 .891 r
F
.52628 .34507 m .52628 .34506 L .52667 .34507 L F
.52598 .34507 m .52628 .34506 L .52628 .34507 L F
.52641 .34479 m .52527 .34473 L .52636 .34485 L F
.52632 .34487 m .52618 .34494 L .5263 .34467 L F
.52639 .3452 m .52615 .34491 L .52627 .34469 L F
.52621 .34493 m .52615 .3449 L .52617 .34493 L F
.52643 .34482 m .52636 .34485 L .52649 .34487 L F
.52641 .34479 m .52636 .34485 L .52643 .34482 L F
.52644 .34477 m .52643 .34482 L p .52632 .34487 L F P
0 g
s
.52661 .34479 m .52632 .3449 L .52627 .34472 L .672 .728 .891 r
F
.52639 .34445 m .52644 .34477 L .5263 .34467 L F
.52669 .34448 m .5265 .34442 L .52721 .34356 L F
.52665 .34456 m .5265 .34442 L .52669 .34448 L F
.52615 .34491 m .527 .3443 L .52684 .34416 L F
.52661 .34479 m .52627 .34472 L .52629 .34469 L F
.52668 .34481 m .52662 .34482 L .52661 .34479 L F
.52718 .34487 m .52615 .34491 L .52726 .34484 L F
.52745 .34486 m .52728 .34492 L .52749 .34494 L F
.52772 .34494 m .52615 .34491 L .52762 .34486 L F
.52559 .34627 m .52523 .34676 L p .52547 .34628 L F P
0 g
s
.52601 .34532 m .52619 .34688 L .52585 .34569 L .672 .728 .891 r
F
.52573 .34598 m .52571 .34627 L .52575 .34598 L F
.52616 .34551 m .52561 .34625 L p .52603 .34528 L F P
0 g
s
.52561 .34625 m .52559 .34627 L p .52603 .34528 L .672 .728 .891 r
F P
0 g
s
.52582 .34575 m .52591 .34554 L .52573 .34555 L .672 .728 .891 r
F
.52573 .34555 m .52591 .34554 L .52596 .34543 L F
.52559 .34627 m .52547 .34628 L .526 .34522 L F
.52571 .34611 m .52589 .34587 L p .52524 .34611 L F P
0 g
s
.52593 .34689 m .52576 .3469 L .52573 .34595 L .672 .728 .891 r
F
.5256 .34779 m .52604 .34524 L .52603 .34527 L F
.52571 .34627 m .52581 .3464 L .52587 .34599 L F
.52571 .34627 m .52587 .34599 L .52575 .34598 L F
.52576 .34534 m .5261 .34655 L .52549 .34691 L F
.52571 .34626 m .52594 .34555 L .52566 .34627 L F
.52592 .34553 m .52616 .34551 L .52598 .3454 L F
.52603 .34528 m .52559 .34627 L .526 .34522 L F
.52589 .34587 m .52616 .34551 L p .52585 .3457 L F P
0 g
s
.52576 .34534 m .52561 .34624 L .52586 .34546 L .672 .728 .891 r
F
.52561 .34624 m .52549 .34691 L .52574 .34594 L F
.52561 .34624 m .52574 .34594 L .52586 .34546 L F
.52543 .34584 m .52595 .34534 L .52539 .34583 L F
.5253 .34602 m .52585 .3457 L .52568 .34554 L F
.52585 .3457 m .52616 .34551 L .52592 .34553 L F
.52601 .34532 m .52585 .34569 L .52576 .34534 L F
.52574 .34594 m .52592 .34553 L .52586 .34546 L F
.52585 .3457 m .52592 .34553 L .52568 .34554 L F
.5253 .34602 m .52576 .3459 L .52585 .3457 L F
.52576 .3459 m .52589 .34587 L .52585 .3457 L F
.52566 .34627 m .52594 .34555 L .52592 .34553 L F
.52566 .34627 m .52592 .34553 L .52574 .34594 L F
.52549 .34691 m .52611 .34537 L .52602 .3453 L F
.52601 .34533 m .52602 .3453 L .52602 .3453 L F
.52549 .34691 m .52602 .3453 L .52601 .34533 L F
.52616 .34551 m .52607 .34535 L .52616 .34531 L F
.52616 .34551 m .52639 .3452 L p .52598 .3454 L F P
0 g
s
.52594 .34555 m .52602 .3453 L .52586 .34546 L .672 .728 .891 r
F
.52568 .34554 m .52592 .34553 L .52598 .3454 L F
.52581 .34514 m .52639 .3452 L .52579 .34513 L F
.52575 .34515 m .52639 .3452 L .52639 .3452 L F
.52575 .34515 m .52639 .3452 L .52575 .34515 L F
.52579 .34513 m .52639 .3452 L .52646 .34518 L F
.52639 .3452 m .52583 .34516 L p .52635 .34515 L F P
0 g
s
.52513 .3451 m .52575 .34515 L .52575 .34515 L .672 .728 .891 r
F
.52513 .3451 m .52639 .3452 L .52513 .3451 L F
.52513 .3451 m .52639 .3452 L .52509 .34507 L F
.52583 .34516 m .52514 .34511 L p .52587 .34513 L F P
0 g
s
.52583 .34516 m .52587 .34513 L .52635 .34515 L .672 .728 .891 r
F
.52134 .34517 m .51642 .34555 L .52177 .34523 L F
.50761 .34621 m .51526 .3458 L p .51642 .34555 L F P
0 g
s
.52136 .34547 m .50761 .34621 L p .52009 .345 L .672 .728 .891 r
F P
0 g
s
.50755 .3454 m .52317 .34524 L p .52436 .34486 L .672 .728 .891 r
F P
0 g
s
.52438 .34508 m .52171 .34525 L .5239 .34477 L .672 .728 .891 r
F
.52342 .34476 m .52336 .34507 L .52438 .3451 L F
.52342 .34476 m .52438 .3451 L .52391 .34483 L F
.52459 .34477 m .52342 .34476 L .52442 .34483 L F
.5239 .34477 m .52171 .34525 L .51971 .34472 L F
.52171 .34525 m .50755 .3454 L p .51971 .34472 L F P
0 g
s
.52342 .34476 m .50756 .34458 L .52336 .34507 L .672 .728 .891 r
F
.5254 .3449 m .50756 .34458 L .52519 .34473 L F
.52526 .34479 m .52509 .34473 L p .52525 .34478 L F P
0 g
s
.52509 .34473 m .5252 .34476 L .5252 .34476 L .672 .728 .891 r
F
.5252 .34476 m .52628 .34507 L .5252 .34476 L F
.52509 .34473 m .52562 .34483 L .52628 .34507 L F
.52506 .34471 m .52583 .345 L p .52578 .34486 L F P
0 g
s
.52583 .345 m .52589 .34502 L p .52578 .34486 L .672 .728 .891 r
F P
0 g
s
.52506 .34472 m .52579 .34513 L .52617 .34494 L .672 .728 .891 r
F
.52615 .3449 m .52573 .34469 L .52617 .34493 L F
.52607 .34481 m .52573 .34469 L .52615 .3449 L F
.52612 .34497 m .52598 .34504 L .52594 .34464 L F
.52595 .34466 m .526 .34442 L .52594 .34465 L F
.52605 .34478 m .52594 .34464 L .52591 .34442 L F
.52612 .34497 m .52594 .34464 L .52605 .34478 L F
.52634 .3449 m .52607 .34481 L .52621 .34493 L F
.52607 .34481 m .52615 .3449 L .52621 .34493 L F
.52601 .34505 m .52609 .34483 L .52598 .34507 L F
.52595 .34466 m .52607 .34401 L .52595 .34466 L F
.52615 .34456 m .52616 .34457 L .52621 .34421 L F
.52596 .34467 m .5261 .34428 L .52602 .34433 L F
.52639 .34445 m .5263 .34467 L .52591 .34442 L F
.52609 .34483 m .52637 .34404 L .52607 .34481 L F
.52532 .34477 m .52618 .34494 L .52528 .34474 L F
.52617 .34493 m .5251 .34472 L .52618 .34494 L F
.52609 .34483 m .52607 .34481 L .52598 .34507 L F
.52634 .3449 m .52632 .3449 L .52634 .3449 L F
.52662 .34482 m .52656 .3448 L .52661 .34479 L F
.52662 .34482 m .52588 .34457 L .52634 .3449 L F
.52607 .34481 m .52604 .34477 L .52662 .34482 L F
.52744 .3452 m .52684 .34508 L .52699 .34533 L F
.52683 .34508 m .52646 .34518 L .52792 .34529 L F
.52578 .34519 m .5259 .34531 L .52576 .34534 L F
.52576 .34534 m .52586 .34546 L .52596 .34508 L F
.52588 .34457 m .52597 .34504 L .5259 .34508 L F
.52662 .34482 m .52604 .34477 L .52588 .34457 L F
.52514 .34466 m .52479 .34427 L .52596 .34467 L F
.52573 .34459 m .52568 .34446 L .52581 .34445 L F
.52583 .34451 m .52564 .34443 L .52574 .34454 L F
.52592 .34462 m .52451 .34417 L .52583 .34451 L F
.52545 .34443 m .52513 .34448 L .52634 .3449 L F
.5257 .34456 m .52592 .34462 L .52593 .34463 L F
.52604 .34477 m .52552 .34472 L .52588 .34457 L F
.52581 .34517 m .52596 .34508 L .52604 .34476 L F
.52597 .34468 m .52604 .34476 L .52638 .3434 L F
.52581 .34517 m .52604 .34476 L .52597 .34468 L F
.52579 .34513 m .5259 .34531 L .52578 .34519 L F
.5259 .34508 m .5259 .34531 L .52579 .34513 L F
.52576 .34534 m .52596 .34508 L .52581 .34517 L F
.52589 .34513 m .52704 .34514 L .52712 .3452 L F
.52519 .34508 m .52592 .34511 L .52589 .34513 L F
.52592 .34511 m .52704 .34514 L .52589 .34513 L F
.52509 .34473 m .50756 .34458 L .52506 .34472 L F
.52329 .34507 m .52215 .34503 L .52332 .34508 L F
.50756 .34458 m .52224 .34507 L p .52215 .34503 L F P
0 g
s
.52335 .3451 m .50756 .34458 L p .52239 .34484 L .672 .728 .891 r
F P
0 g
s
.51045 .34392 m .52513 .3451 L .52509 .34507 L .672 .728 .891 r
F
.52335 .3451 m .52553 .345 L .5256 .34505 L F
.52366 .34499 m .52524 .34506 L .52519 .34508 L F
.52588 .34457 m .5259 .34508 L .52579 .34513 L F
.5265 .34421 m .52643 .34435 L .52641 .34431 L F
.52631 .34355 m .52636 .34362 L .52792 .33243 L F
.52634 .34286 m .52641 .34285 L .52792 .33243 L F
.52613 .34426 m .52641 .34285 L .52634 .34286 L F
.52613 .34426 m .52621 .34421 L .52641 .34285 L F
.52605 .34397 m .52608 .34392 L .52792 .33243 L F
.52667 .34281 m .52644 .34477 L p .52617 .34288 L F P
0 g
s
.52652 .34418 m .52645 .34433 L .5265 .34421 L .672 .728 .891 r
F
.52596 .34508 m .52606 .3448 L .52604 .34476 L F
.52591 .34442 m .52594 .34464 L .52588 .34457 L F
.52594 .34465 m .526 .34442 L .52598 .34441 L F
.52605 .34451 m .52596 .34454 L .52591 .34442 L F
.5263 .34509 m .52668 .34481 L .52619 .34492 L F
.52618 .34494 m .52607 .34481 L .52665 .34489 L F
.52637 .34452 m .52678 .34422 L .5266 .34426 L F
.52698 .3444 m .52627 .34469 L .52652 .34418 L F
.52618 .34494 m .52631 .34466 L .52613 .34497 L F
.52631 .34466 m .52656 .3441 L .52629 .34464 L F
.52631 .34466 m .52629 .34464 L .52613 .34497 L F
.5263 .34509 m .52619 .34492 L .52618 .34494 L F
.52665 .34489 m .52607 .34481 L .52662 .34482 L F
.52616 .34492 m .52668 .34481 L .52649 .3445 L F
.52607 .34535 m .52603 .34528 L .52616 .34531 L F
.52568 .34554 m .52639 .3452 L .5263 .34509 L F
.52602 .3453 m .52605 .34525 L .52602 .3453 L F
.52602 .34505 m .52604 .34503 L .52626 .34504 L F
.52602 .3453 m .52613 .34498 L .52594 .34524 L F
.52601 .34529 m .52601 .34532 L .52576 .34534 L F
.52602 .3453 m .52594 .34524 L .52586 .34546 L F
.52586 .34546 m .52594 .34524 L .52592 .34523 L F
.52568 .34554 m .52603 .34529 L .52616 .34492 L F
.52524 .34506 m .52632 .34511 L .52519 .34508 L F
.52603 .34529 m .5263 .34509 L .52618 .34494 L F
.52564 .34505 m .52626 .34504 L .52628 .34506 L F
.52606 .34519 m .52615 .34496 L .52613 .34497 L F
.52603 .34529 m .52618 .34494 L .52615 .34495 L F
.52671 .34505 m .52607 .34501 L .52618 .34494 L F
.52631 .34486 m .5262 .34493 L .52605 .34525 L F
.52564 .34505 m .52604 .34503 L .52602 .34505 L F
.52611 .34537 m .52631 .34486 L .52605 .34525 L F
.52611 .34537 m .52605 .34525 L .52602 .3453 L F
.52224 .34507 m .52576 .34518 L p .52215 .34503 L F P
0 g
s
.52335 .3451 m .52239 .34484 L .52495 .34489 L .672 .728 .891 r
F
.52335 .3451 m .52495 .34489 L .52464 .34504 L F
.52506 .34472 m .51045 .34392 L .52503 .34507 L F
.52347 .34485 m .51454 .3443 L .5226 .34475 L F
.52605 .34437 m .52625 .34382 L .52624 .34381 L F
.52578 .34519 m .52606 .34438 L .52605 .34437 L F
.52606 .34438 m .52625 .34382 L .52605 .34437 L F
.52578 .34519 m .52581 .34517 L .52606 .34439 L F
.52578 .34519 m .52606 .34439 L .52606 .34438 L F
.52657 .34346 m .52656 .34345 L .52596 .34508 L F
.52607 .34501 m .52607 .34501 L .52671 .34505 L F
.52606 .34502 m .52671 .34505 L .52604 .34503 L F
.52606 .34502 m .52607 .34501 L .52671 .34505 L F
.52628 .34506 m .52626 .34504 L .52667 .34507 L F
.52594 .34509 m .52598 .34507 L .52704 .34514 L F
.52632 .34553 m .52648 .34476 L p .52611 .34537 L F P
0 g
s
.52632 .34489 m .5262 .34576 L .52621 .34493 L .672 .728 .891 r
F
.5262 .34576 m .52609 .34658 L .52615 .3457 L F
.52624 .34588 m .52632 .34553 L p .52601 .34562 L F P
0 g
s
.52601 .34562 m .52632 .34553 L .52611 .34537 L .672 .728 .891 r
F
.5262 .34576 m .52615 .3457 L .52621 .34493 L F
.52598 .34507 m .52618 .34452 L .52596 .34508 L F
.52618 .34494 m .52619 .34492 L .52616 .34492 L F
.52588 .34457 m .52578 .34519 L .52596 .34466 L F
.52618 .34494 m .52612 .34497 L .52605 .34478 L F
.52602 .3453 m .52605 .34525 L .52613 .34497 L F
.52613 .34498 m .52613 .34497 L .52638 .34418 L F
.52602 .3453 m .52613 .34497 L .52613 .34498 L F
.52671 .34505 m .52618 .34494 L .52665 .34489 L F
.52673 .34505 m .52618 .34494 L .52645 .3448 L F
.5251 .34472 m .52618 .34494 L .52618 .34494 L F
.5251 .34472 m .52506 .34472 L .52668 .34505 L F
.5251 .34472 m .5251 .34472 L .52668 .34504 L F
.52519 .34473 m .52509 .34473 L .52506 .34472 L F
.5251 .34472 m .5251 .34472 L .52668 .34504 L F
.52618 .34494 m .52536 .34478 L .52607 .34481 L F
.52527 .34473 m .52528 .34474 L .52649 .34487 L F
.52514 .34466 m .51027 .33929 L .52479 .34427 L F
.51027 .33929 m .50977 .33911 L .51021 .33926 L F
.51027 .33929 m .51021 .33926 L .52479 .34427 L F
.52573 .34469 m .51045 .33935 L .52578 .34485 L F
.51045 .33935 m .50977 .33911 L .51035 .33932 L F
.51045 .33935 m .51035 .33932 L .52578 .34485 L F
.5251 .34472 m .52532 .34477 L .52528 .34474 L F
.52527 .34473 m .5251 .34472 L .52528 .34474 L F
.52578 .34485 m .51035 .33932 L .52506 .34471 L F
.5251 .34472 m .52506 .34471 L .5251 .34472 L F
.52536 .34478 m .52444 .34459 L .52549 .34473 L F
.52588 .34457 m .52545 .34443 L .526 .34472 L F
.52588 .34457 m .52502 .34467 L .52568 .3445 L F
.52571 .34479 m .5257 .34476 L .52607 .34481 L F
.52536 .34478 m .5257 .34476 L .52571 .34479 L F
.52536 .34478 m .52549 .34473 L .5257 .34476 L F
.52631 .34497 m .52663 .34503 L .52662 .34502 L F
.52618 .34494 m .52481 .34487 L .52516 .34474 L F
.52607 .34501 m .52467 .34492 L .52618 .34494 L F
.52467 .34492 m .52347 .34485 L .52474 .34489 L F
.52467 .34492 m .52474 .34489 L .52618 .34494 L F
.52613 .34498 m .52641 .3441 L .52601 .34505 L F
.52616 .34495 m .52598 .34492 L .52618 .34494 L F
.52578 .34519 m .52576 .34534 L .52581 .34517 L F
.52554 .34555 m .5257 .34539 L .52567 .3454 L F
.52601 .34505 m .52598 .34507 L .52592 .34523 L F
.5257 .34539 m .52616 .34492 L .52567 .3454 L F
.52565 .34541 m .52584 .34519 L .52584 .34517 L F
.52554 .34555 m .52567 .3454 L .52565 .34541 L F
.52594 .34524 m .52601 .34505 L .52592 .34523 L F
.52613 .34498 m .52601 .34505 L .52594 .34524 L F
.5257 .34539 m .52582 .34536 L .52616 .34492 L F
.52554 .34555 m .52582 .34536 L .5257 .34539 L F
.52671 .34505 m .52607 .34501 L .52671 .34505 L F
.52604 .34503 m .52671 .34505 L .52667 .34507 L F
.52632 .34511 m .52704 .34514 L .52632 .34512 L F
.5263 .34509 m .52628 .34507 L .52667 .34507 L F
.52639 .3452 m .52639 .3452 L .52639 .3452 L F
.52639 .3452 m .5269 .34524 L p .52639 .3452 L F P
0 g
s
.52646 .34518 m .5269 .34524 L .52687 .34521 L .672 .728 .891 r
F
.52639 .3452 m .5269 .34524 L .52646 .34518 L F
.52639 .3452 m .52635 .34515 L .52648 .34516 L F
.52789 .34532 m .52639 .3452 L p .52795 .34525 L F P
0 g
s
.52639 .3452 m .52648 .34516 L .52795 .34525 L .672 .728 .891 r
F
.52639 .3452 m .52618 .34494 L .52698 .34511 L F
.52846 .34585 m .52729 .34543 L .52808 .3454 L F
.53794 .34998 m .53794 .34998 L .53812 .35006 L F
.53226 .34763 m .53227 .34763 L .53812 .35006 L F
.52638 .34519 m .53227 .34763 L .53226 .34763 L F
.52865 .34614 m .52866 .34614 L .53812 .35006 L F
.5303 .34681 m .53039 .34682 L .53812 .35006 L F
.52638 .34519 m .53039 .34682 L .5303 .34681 L F
.53812 .35006 m .53477 .34865 L .53473 .34851 L F
.54228 .35195 m .53853 .35036 L p .53812 .35006 L F P
0 g
s
.52884 .34624 m .54228 .35195 L p .53099 .34655 L .672 .728 .891 r
F P
0 g
s
.52748 .34557 m .52752 .34552 L .53745 .3491 L .672 .728 .891 r
F
.53747 .34927 m .52747 .3456 L p .53745 .3491 L F P
0 g
s
.52747 .3456 m .52748 .34557 L .53745 .3491 L .672 .728 .891 r
F
.52743 .34558 m .52819 .34586 L p .52789 .34525 L F P
0 g
s
.53745 .3491 m .52846 .34585 L .52808 .3454 L .672 .728 .891 r
F
.5429 .35125 m .53747 .34927 L p .53745 .3491 L F P
0 g
s
.52819 .34586 m .5429 .35125 L p .52811 .34534 L .672 .728 .891 r
F P
0 g
s
.52789 .34525 m .52819 .34586 L .52811 .34534 L .672 .728 .891 r
F
.52789 .34532 m .52795 .34525 L .52809 .34526 L F
.52811 .34533 m .52809 .34526 L .53314 .34556 L F
.52811 .34533 m .52789 .34525 L .52811 .34534 L F
.52789 .34532 m .52809 .34526 L .52811 .34533 L F
.52811 .34533 m .52789 .34532 L p .52811 .34533 L F P
0 g
s
.52639 .3452 m .52698 .34511 L .52814 .34534 L .672 .728 .891 r
F
.52632 .34553 m .52623 .34555 L .52627 .34522 L F
.52618 .34494 m .52642 .34479 L .52645 .3448 L F
.52611 .34537 m .52648 .34476 L .52631 .34486 L F
.52613 .34488 m .52629 .34469 L .52612 .34487 L F
.52618 .34494 m .52516 .34474 L .52642 .34479 L F
.52613 .34488 m .52612 .34487 L .52603 .34497 L F
.52604 .34497 m .52603 .34497 L .52584 .34517 L F
.52586 .345 m .52598 .34492 L .52616 .34495 L F
.52347 .34485 m .5226 .34475 L .52481 .34487 L F
.52474 .34489 m .52481 .34487 L .52618 .34494 L F
.52347 .34485 m .52481 .34487 L .52474 .34489 L F
.52585 .34498 m .52598 .34492 L .52586 .345 L F
.52336 .34486 m .5234 .34485 L .52607 .34501 L F
.52088 .3447 m .52093 .34469 L .52607 .34501 L F
.52603 .34475 m .52583 .34504 L .52605 .34478 L F
.52366 .34499 m .52598 .34507 L .52594 .34509 L F
.52583 .34504 m .52557 .34543 L .52605 .34478 L F
.52098 .34473 m .52606 .34502 L .52604 .34503 L F
.52598 .34507 m .52564 .34505 L .526 .34506 L F
.52605 .34478 m .52557 .34543 L .52608 .34482 L F
.52632 .34511 m .52632 .34512 L .52519 .34508 L F
.52592 .34523 m .52598 .34507 L .52596 .34508 L F
.52567 .3454 m .52616 .34492 L .52613 .34488 L F
.52639 .3452 m .52589 .34505 L p .52618 .34494 L F P
0 g
s
.52589 .34505 m .52639 .3452 L p .52618 .34494 L .672 .728 .891 r
F P
0 g
s
.52618 .34452 m .52617 .34451 L .52596 .34508 L .672 .728 .891 r
F
.52584 .34517 m .52629 .34469 L .52631 .34466 L F
.52613 .34497 m .52649 .34424 L .52638 .34418 L F
.52622 .34469 m .52631 .34466 L .52638 .34449 L F
.52584 .34517 m .52631 .34466 L .52622 .34469 L F
.52643 .34479 m .52603 .34475 L .52659 .34498 L F
.52607 .34481 m .52502 .34467 L .52604 .34477 L F
.51045 .34392 m .52363 .34498 L .52361 .34498 L F
.50963 .34392 m .52514 .34511 L p .51045 .34392 L F P
0 g
s
.51045 .34392 m .52514 .34511 L .52513 .3451 L .672 .728 .891 r
F
.52514 .34474 m .52444 .34459 L .52514 .34473 L F
.52448 .3446 m .52444 .34459 L p .52514 .34474 L F P
0 g
s
.52645 .3448 m .52516 .34474 L .52514 .34474 L .672 .728 .891 r
F
.51028 .3393 m .52506 .34471 L p .51035 .33932 L F P
0 g
s
.52444 .34459 m .52228 .34392 L p .52428 .34423 L .672 .728 .891 r
F P
0 g
s
.52228 .34392 m .52448 .3446 L p .52287 .34375 L .672 .728 .891 r
F P
0 g
s
.52529 .34468 m .52514 .34474 L .52448 .3446 L .672 .728 .891 r
F
.52502 .34467 m .52444 .34459 L .52568 .3445 L F
.52529 .34468 m .52448 .3446 L .52448 .3446 L F
.52516 .34474 m .51454 .3443 L .52444 .3446 L F
.52526 .34485 m .52448 .3446 L p .52514 .34474 L F P
0 g
s
.52448 .3446 m .52579 .34501 L p .52514 .34473 L .672 .728 .891 r
F P
0 g
s
.52571 .34627 m .5256 .34779 L .52581 .3464 L .672 .728 .891 r
F
.5261 .34655 m .52602 .34689 L .52549 .34691 L F
.5256 .34779 m .52569 .34784 L .52604 .34539 L F
.52591 .3474 m .52618 .34615 L p .52549 .34691 L F P
0 g
s
.52549 .34691 m .52618 .34615 L .52587 .34597 L .672 .728 .891 r
F
.52542 .34654 m .52604 .34682 L .52541 .347 L F
.52533 .34687 m .52541 .347 L .52529 .34703 L F
.52542 .34654 m .52541 .347 L .52533 .34687 L F
.52507 .34619 m .52543 .34584 L .52498 .34619 L F
.52543 .34584 m .52539 .34583 L .52498 .34619 L F
.52529 .34571 m .52523 .34676 L .5249 .34619 L F
.52497 .3463 m .52502 .34639 L .5253 .34602 L F
.52513 .34607 m .52497 .3463 L .5253 .34602 L F
.52523 .34676 m .52571 .34611 L p .52475 .34673 L F P
0 g
s
.52475 .34673 m .52571 .34611 L .52524 .34611 L .672 .728 .891 r
F
.52464 .34755 m .52523 .34676 L p .52415 .3475 L F P
0 g
s
.52415 .3475 m .52523 .34676 L .52475 .34673 L .672 .728 .891 r
F
.51798 .35651 m .52464 .34755 L p .52415 .3475 L F P
0 g
s
.52566 .34636 m .51907 .35685 L p .52513 .34607 L .672 .728 .891 r
F P
0 g
s
.52544 .34664 m .52533 .34687 L .52552 .34659 L .672 .728 .891 r
F
.52532 .3469 m .52534 .34688 L p .52533 .34687 L F P
0 g
s
.52534 .34688 m .52552 .34659 L p .52533 .34687 L .672 .728 .891 r
F P
0 g
s
.52609 .34658 m .52604 .34682 L p .52542 .34654 L .672 .728 .891 r
F P
0 g
s
.5256 .34779 m .5255 .34915 L .52569 .34784 L .672 .728 .891 r
F
.52488 .3578 m .52589 .34937 L p .5255 .34915 L F P
0 g
s
.52619 .34688 m .52488 .3578 L p .52549 .34691 L .672 .728 .891 r
F P
0 g
s
.52369 .35771 m .52591 .3474 L p .52549 .34691 L .672 .728 .891 r
F P
0 g
s
.52529 .34703 m .52591 .3474 L .52522 .34732 L .672 .728 .891 r
F
.52604 .34682 m .52591 .3474 L p .52529 .34703 L F P
0 g
s
.52369 .35771 m .52251 .35757 L p .52522 .34732 L .672 .728 .891 r
F P
0 g
s
.52591 .3474 m .52369 .35771 L p .52522 .34732 L .672 .728 .891 r
F P
0 g
s
.52458 .34971 m .52466 .34967 L .5261 .34532 L .672 .728 .891 r
F
.52615 .34495 m .52618 .34494 L .52616 .34492 L F
.52613 .34488 m .52603 .34497 L .52604 .34497 L F
.52567 .3454 m .52629 .34469 L .52565 .34541 L F
.52579 .34501 m .52618 .34494 L .52618 .34494 L F
.52641 .3441 m .52637 .34404 L .52601 .34505 L F
.52618 .34495 m .52599 .34501 L .52603 .34475 L F
.52542 .34479 m .52631 .34497 L .52662 .34502 L F
.52484 .34467 m .52543 .34479 L .52542 .34479 L F
.52543 .34479 m .52631 .34497 L .52542 .34479 L F
.52614 .34538 m .52622 .34499 L .52624 .34501 L F
.52621 .34493 m .52609 .34658 L .52603 .3453 L F
.52612 .34536 m .52612 .34535 L .52614 .34538 L F
.52635 .34521 m .52632 .34489 L .52639 .34487 L F
.52648 .34501 m .52664 .34504 L .52663 .34503 L F
.52789 .34525 m .52671 .34503 L .52785 .34528 L F
.52712 .3452 m .52704 .34514 L .53314 .34556 L F
.52845 .3449 m .52817 .34499 L .539 .34617 L F
.52667 .34507 m .52671 .34505 L .53308 .34545 L F
.52668 .34504 m .52668 .34505 L .52792 .34529 L F
.52671 .34503 m .52668 .34504 L .52785 .34528 L F
.52658 .34511 m .52667 .34507 L .52687 .34508 L F
.52811 .34533 m .52705 .34512 L .52691 .34492 L F
.52718 .34514 m .52687 .34508 L .53308 .34545 L F
.52658 .34511 m .52687 .34508 L .52718 .34514 L F
.52814 .34534 m .52705 .34512 L .52705 .34512 L F
.52814 .34534 m .52811 .34533 L .52813 .34534 L F
.52814 .34534 m .52705 .34512 L .52811 .34533 L F
.53324 .34573 m .52811 .34533 L p .53314 .34556 L F P
0 g
s
.52811 .34533 m .52811 .34533 L .53314 .34556 L .672 .728 .891 r
F
.52663 .34503 m .52664 .34504 L .54483 .34743 L F
.52663 .34503 m .54483 .34743 L .54483 .34743 L F
.5266 .34503 m .5278 .34564 L .52699 .34511 L F
.52645 .345 m .52663 .34503 L .52631 .34497 L F
.52623 .34493 m .5278 .34564 L .52633 .34489 L F
.52633 .34498 m .52715 .34536 L .52713 .34534 L F
.52673 .34505 m .52671 .34505 L .52671 .34505 L F
.52705 .34512 m .52671 .34505 L .52672 .34505 L F
.52705 .34512 m .52672 .34505 L .52705 .34512 L F
.52904 .34552 m .54492 .34744 L p .52664 .34504 L F P
0 g
s
.5268 .34503 m .52706 .34492 L .52964 .34497 L .672 .728 .891 r
F
.52641 .34479 m .52649 .34487 L .52963 .34519 L F
.52973 .34518 m .52963 .34519 L .53214 .34545 L F
.52641 .34479 m .52963 .34519 L .52973 .34518 L F
.52641 .34479 m .53214 .34545 L .53232 .34544 L F
.52691 .34492 m .52665 .34489 L .52662 .34482 L F
.52729 .34495 m .52785 .34528 L .52753 .34497 L F
.52969 .34511 m .52673 .34505 L .52645 .3448 L F
.53308 .34545 m .53015 .34527 L .52969 .34511 L F
.53015 .34527 m .52673 .34505 L .52969 .34511 L F
.52629 .34469 m .52677 .34415 L .52638 .34449 L F
.52648 .34476 m .52663 .34406 L p .52631 .34486 L F P
0 g
s
.52613 .34488 m .52616 .34492 L .52677 .34415 L .672 .728 .891 r
F
.52666 .34387 m .52664 .34416 L .53455 .33419 L F
.52666 .34387 m .53455 .33419 L .5345 .33424 L F
.52656 .3441 m .52664 .34416 L .52666 .34387 L F
.52663 .34406 m .52669 .34379 L p .52656 .3441 L F P
0 g
s
.52669 .34379 m .5267 .34377 L p .52656 .3441 L .672 .728 .891 r
F P
0 g
s
.52638 .34418 m .52656 .3441 L .5267 .34377 L .672 .728 .891 r
F
.5265 .34406 m .52656 .3441 L .52666 .34387 L F
.5267 .34377 m .5269 .34393 L .5265 .34406 L F
.52721 .34356 m .5265 .34442 L .52642 .3444 L F
.52643 .34438 m .52637 .34452 L .52766 .34312 L F
.52839 .34258 m .5284 .34258 L .53276 .33853 L F
.52642 .3444 m .5284 .34258 L .52839 .34258 L F
.53596 .33415 m .52786 .34351 L p .5274 .34354 L F P
0 g
s
.53596 .33415 m .52726 .34355 L p .52721 .34356 L .672 .728 .891 r
F P
0 g
s
.5266 .34426 m .52678 .34422 L .53596 .33415 L .672 .728 .891 r
F
.52754 .34318 m .52766 .34312 L .53596 .33415 L F
.52684 .34416 m .52792 .34343 L .52813 .34274 L F
.527 .3443 m .52792 .34343 L .52684 .34416 L F
.52792 .34343 m .53596 .33415 L p .52813 .34274 L F P
0 g
s
.53489 .33376 m .527 .34438 L p .52652 .34418 L .672 .728 .891 r
F P
0 g
s
.52661 .3442 m .52677 .34415 L .53489 .33376 L .672 .728 .891 r
F
.53489 .33376 m .53379 .33341 L p .52668 .3438 L F P
0 g
s
.52668 .3438 m .5265 .34406 L .52673 .34379 L .672 .728 .891 r
F
.52668 .3438 m .52673 .34379 L .53489 .33376 L F
.52444 .3446 m .51454 .3443 L .51314 .34374 L F
.52595 .34534 m .52586 .34537 L .52498 .34619 L F
.52583 .34552 m .52575 .34557 L .52557 .34543 L F
.52586 .345 m .52583 .34552 L .52557 .34543 L F
.52564 .34505 m .52559 .34501 L .52604 .34503 L F
.52589 .34497 m .52538 .3456 L .52534 .34556 L F
.52589 .34505 m .52579 .34501 L p .52586 .345 L F P
0 g
s
.52579 .34501 m .52585 .34498 L .52586 .345 L .672 .728 .891 r
F
.52579 .34501 m .52526 .34485 L p .52598 .34492 L F P
0 g
s
.52579 .34501 m .52589 .34505 L p .52567 .34467 L .672 .728 .891 r
F P
0 g
s
.52468 .34475 m .52472 .34477 L .52614 .34496 L .672 .728 .891 r
F
.52526 .34485 m .52514 .34473 L .52618 .34494 L F
.52514 .34473 m .52579 .34501 L .52573 .34485 L F
.52467 .34474 m .52614 .34496 L .52615 .34496 L F
.52468 .34475 m .52614 .34496 L .52467 .34474 L F
.52294 .3445 m .52553 .34487 L .52294 .34449 L F
.52553 .34487 m .52614 .34496 L .52553 .34487 L F
.52407 .34483 m .52429 .34471 L .52516 .34474 L F
.52553 .34487 m .52553 .34487 L .52294 .34449 L F
.52603 .34475 m .52579 .34484 L .52625 .34492 L F
.52646 .34484 m .52632 .34553 L .52639 .34487 L F
.52635 .34488 m .52625 .34492 L .52659 .34498 L F
.52603 .34475 m .52625 .34492 L .52635 .34488 L F
.52605 .34525 m .52663 .34406 L .52656 .3441 L F
.52635 .34466 m .52621 .34493 L .52631 .34466 L F
.52621 .34493 m .52603 .3453 L .52618 .34494 L F
.52621 .34493 m .52618 .34494 L .52631 .34466 L F
.52557 .34543 m .52565 .34541 L .52622 .34469 L F
.52618 .3447 m .52622 .34469 L .52664 .34416 L F
.52557 .34543 m .52622 .34469 L .52618 .3447 L F
.52614 .34496 m .52611 .34496 L .52618 .34494 L F
.52589 .34505 m .52611 .34496 L .52614 .34496 L F
.52589 .34505 m .52586 .345 L .52611 .34496 L F
.52621 .34498 m .52622 .34499 L .52614 .34534 L F
.52618 .34495 m .52616 .34499 L .52618 .34494 L F
.52618 .34495 m .52591 .34569 L .52599 .34501 L F
.52618 .34494 m .52603 .3453 L .52601 .34501 L F
.52635 .34521 m .52629 .34508 L .52635 .34515 L F
.52584 .34519 m .52613 .34488 L .52584 .34517 L F
.52603 .34475 m .52594 .34512 L .52586 .345 L F
.52098 .34473 m .52607 .34501 L .52606 .34502 L F
.52633 .34498 m .52618 .34494 L .52715 .34536 L F
.5262 .34496 m .5262 .34497 L .52663 .34503 L F
.52629 .34498 m .52651 .34501 L .52648 .34501 L F
.5262 .34497 m .52651 .34501 L .52629 .34498 L F
.5262 .34497 m .52664 .34504 L .52651 .34501 L F
.52635 .34515 m .52629 .34508 L .52632 .34489 L F
.52617 .34495 m .52645 .345 L .52631 .34497 L F
.52614 .3449 m .52662 .34502 L .52659 .34498 L F
.52448 .3446 m .52448 .3446 L .52514 .34473 L F
.52444 .3446 m .52617 .34493 L .52614 .3449 L F
.52617 .34493 m .52662 .34502 L .52614 .3449 L F
.52662 .34502 m .52663 .34503 L .52752 .34514 L F
.52659 .34498 m .52662 .34502 L .52752 .34514 L F
.52669 .34379 m .52657 .34437 L p .52668 .3438 L F P
0 g
s
.52657 .34437 m .52632 .34553 L p .52656 .34438 L .672 .728 .891 r
F P
0 g
s
.52649 .34424 m .52656 .3441 L .52644 .34416 L .672 .728 .891 r
F
.52649 .34424 m .52644 .34416 L .52638 .34418 L F
.5265 .34406 m .52603 .34475 L .52664 .34416 L F
.52657 .34437 m .52656 .34438 L .52668 .3438 L F
.52634 .34489 m .52633 .34489 L .52647 .34494 L F
.52638 .34449 m .52677 .34415 L .52661 .3442 L F
.52668 .3438 m .52646 .34484 L .52645 .34433 L F
.52698 .3444 m .52668 .34481 L p .52627 .34469 L F P
0 g
s
.527 .34438 m .52698 .3444 L p .52652 .34418 L .672 .728 .891 r
F P
0 g
s
.52668 .34481 m .53489 .33376 L p .52649 .3445 L .672 .728 .891 r
F P
0 g
s
.53379 .33341 m .52726 .34381 L p .5269 .34393 L .672 .728 .891 r
F P
0 g
s
.52666 .34478 m .52646 .3443 L .52654 .34424 L .672 .728 .891 r
F
.52726 .34381 m .52666 .34478 L p .5265 .34406 L F P
0 g
s
.52666 .34478 m .52882 .34133 L p .52641 .34448 L .672 .728 .891 r
F P
0 g
s
.52634 .34489 m .52647 .34494 L .52828 .34553 L .672 .728 .891 r
F
.52634 .34489 m .52828 .34553 L .52826 .34552 L F
.52643 .34479 m .52659 .34498 L .52752 .34514 L F
.52656 .34481 m .52634 .34489 L .52826 .34552 L F
.52629 .34465 m .52618 .34495 L .52603 .34475 L F
.52631 .34466 m .52618 .34494 L .52599 .3446 L F
.52631 .34486 m .52663 .34406 L .5262 .34493 L F
.52635 .34466 m .52632 .34489 L .52621 .34493 L F
.52622 .34499 m .52629 .34465 L .52624 .34501 L F
.52621 .34498 m .52618 .34494 L .52629 .34465 L F
.52607 .3448 m .52623 .34493 L .52633 .34489 L F
.52611 .34486 m .52693 .34501 L .52695 .34505 L F
.52448 .3446 m .52448 .3446 L .52444 .3446 L F
.52645 .3448 m .52514 .34474 L .52529 .34468 L F
.52603 .34475 m .52444 .3446 L .52579 .34484 L F
.52572 .3447 m .52623 .34493 L .52573 .34469 L F
.52544 .3448 m .52551 .34486 L .52631 .34497 L F
.52572 .3447 m .52589 .34505 L .52623 .34493 L F
.52567 .34467 m .52569 .34471 L .52572 .3447 L F
.52569 .34471 m .52589 .34505 L .52572 .3447 L F
.52562 .34489 m .52637 .34518 L .5262 .34497 L F
.52614 .34495 m .52616 .34495 L .52616 .34495 L F
.52616 .34495 m .52616 .34495 L .52616 .34495 L F
.52616 .34495 m .52617 .34495 L .52617 .34495 L F
.52618 .34494 m .52601 .34501 L .526 .34472 L F
.52613 .34488 m .52623 .34493 L .52607 .3448 L F
.52551 .34486 m .52585 .34491 L .52585 .34491 L F
.52585 .34491 m .52614 .34495 L .52585 .34491 L F
.52585 .34491 m .52614 .34495 L .52616 .34495 L F
.52593 .34463 m .52601 .34501 L .5258 .34509 L F
.52594 .34512 m .52583 .34563 L .52586 .345 L F
.52593 .34552 m .52583 .34563 L .52603 .34475 L F
.52587 .34566 m .52583 .34563 L .52593 .34552 L F
.52583 .34552 m .52583 .34563 L .52575 .34557 L F
.52549 .34691 m .52571 .34626 L .52566 .34627 L F
.52587 .34566 m .52577 .34589 L .52583 .34563 L F
.52567 .34556 m .52566 .34557 L .52568 .34554 L F
.52583 .34563 m .52566 .34636 L .52557 .34543 L F
.5258 .34509 m .5259 .34559 L .52542 .34654 L F
.5259 .34559 m .52609 .34658 L .52548 .34655 L F
.52567 .34553 m .52523 .34676 L .52529 .34571 L F
.52513 .34607 m .52566 .34557 L .52567 .34556 L F
.52513 .34607 m .5253 .34602 L .52566 .34557 L F
.52513 .34607 m .52568 .34554 L .52554 .34555 L F
.52557 .34543 m .52513 .34607 L .52565 .34541 L F
.52524 .34611 m .52589 .34587 L .5253 .34602 L F
.52557 .34543 m .52566 .34636 L .52513 .34607 L F
.5259 .34559 m .52548 .34655 L .52542 .34654 L F
.52591 .34569 m .52566 .34636 L .52577 .34589 L F
.52591 .34569 m .52577 .34589 L .52587 .34566 L F
.52591 .34569 m .52587 .34566 L .52593 .34552 L F
.52509 .34507 m .52581 .34514 L .52579 .34513 L F
.52514 .34511 m .52519 .34508 L .52635 .34515 L F
.52601 .34501 m .52603 .3453 L .5258 .34509 L F
.52603 .3453 m .52604 .34555 L .52597 .34542 L F
.52603 .3453 m .52597 .34542 L .5258 .34509 L F
.52587 .34597 m .52624 .34588 L .52601 .34562 L F
.52604 .34555 m .52609 .34658 L .52584 .34529 L F
.52604 .34555 m .52584 .34529 L .5258 .34509 L F
.52558 .34491 m .52637 .34518 L .52562 .34489 L F
.52529 .345 m .52581 .34509 L .52558 .34491 L F
.52581 .34509 m .52637 .34518 L .52558 .34491 L F
.52615 .34496 m .52614 .34496 L .5262 .34497 L F
.52616 .34495 m .52619 .34496 L .52616 .34495 L F
.52656 .34481 m .52639 .3452 L .52627 .34491 L F
.5261 .34484 m .52642 .34491 L .52611 .34486 L F
.52642 .34491 m .52693 .34501 L .5264 .34491 L F
.52646 .34484 m .52639 .34487 L .52645 .34433 L F
.52666 .34478 m .52656 .34481 L .52645 .34426 L F
.52656 .34481 m .52627 .34491 L .5264 .34443 L F
.52656 .34481 m .5264 .34443 L .52645 .34426 L F
.52693 .34501 m .52662 .34493 L .52687 .3449 L F
.52615 .3449 m .52631 .34459 L .52629 .34457 L F
.52639 .3452 m .5278 .34564 L p .52618 .34494 L F P
0 g
s
.52621 .34498 m .52622 .34493 L .52622 .34499 L .672 .728 .891 r
F
.52623 .34493 m .52618 .34494 L .52633 .34498 L F
.52622 .34493 m .52623 .34493 L .52622 .34499 L F
.52619 .34496 m .52645 .345 L .52619 .34495 L F
.52617 .34495 m .52645 .345 L .52617 .34495 L F
.52626 .34504 m .52647 .3449 L .52618 .34495 L F
.52637 .34518 m .52684 .34526 L .5262 .34497 L F
.52639 .3452 m .52624 .34501 L .52627 .34491 L F
.52633 .34489 m .5266 .34503 L .52699 .34511 L F
.52741 .345 m .5272 .34504 L .52752 .34514 L F
.52904 .34552 m .52656 .34481 L .52812 .34534 L F
.52904 .34552 m .52812 .34534 L .52923 .34571 L F
.52904 .34552 m .52812 .34534 L .52904 .34552 L F
.52733 .34488 m .52643 .34479 L .5272 .34504 L F
.52624 .34501 m .52629 .34465 L .52634 .34463 L F
.52599 .3446 m .526 .34472 L .52593 .34463 L F
.52656 .34481 m .52593 .34463 L .52633 .34489 L F
.52564 .34456 m .52451 .34417 L .52563 .34455 L F
.5257 .34456 m .52451 .34417 L .52571 .34456 L F
.52545 .34443 m .50977 .33911 L .52513 .34448 L F
.52568 .3445 m .52444 .34459 L .52539 .34441 L F
.52444 .34459 m .52428 .34423 L .52539 .34441 L F
.52593 .34463 m .52287 .34375 L .52607 .3448 L F
.52603 .34475 m .52608 .34482 L .52664 .34416 L F
.52606 .3448 m .52636 .34401 L .52604 .34476 L F
.52618 .34494 m .526 .34472 L .52599 .3446 L F
.52622 .34493 m .52629 .34465 L .52623 .34493 L F
.52593 .34463 m .52607 .3448 L .52633 .34489 L F
.52573 .34469 m .52613 .34488 L .52607 .3448 L F
.526 .34472 m .52601 .34501 L .52593 .34463 L F
.52687 .3449 m .52602 .34474 L .52593 .34463 L F
.52666 .34478 m .52659 .34488 L p .52656 .34481 L F P
0 g
s
.52659 .34488 m .52639 .3452 L p .52656 .34481 L .672 .728 .891 r
F P
0 g
s
.52635 .34521 m .52627 .34522 L .52629 .34508 L .672 .728 .891 r
F
.52632 .34553 m .52627 .34522 L .52635 .34521 L F
.52639 .3452 m .52603 .34578 L p .52624 .34501 L F P
0 g
s
.52612 .34535 m .52621 .34498 L .52614 .34534 L .672 .728 .891 r
F
.5262 .34497 m .52684 .34526 L .52664 .34504 L F
.52639 .3452 m .52659 .34488 L p .52626 .34504 L F P
0 g
s
.52603 .34578 m .52618 .34494 L .52621 .34498 L .672 .728 .891 r
F
.52615 .34496 m .5262 .34497 L .5262 .34496 L F
.52619 .34496 m .52619 .34495 L .52616 .34495 L F
.52587 .34514 m .52618 .34495 L .52628 .34507 L F
.52626 .34504 m .52618 .34495 L .52608 .34496 L F
.52656 .34481 m .52826 .34552 L .52807 .34539 L F
.52684 .34526 m .52904 .34552 L p .52664 .34504 L F P
0 g
s
.52571 .34512 m .52639 .3452 L p .52577 .3451 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .52587 .34514 L p .52656 .34502 L .672 .728 .891 r
F P
0 g
s
.52666 .34503 m .52663 .34497 L .52695 .34505 L .672 .728 .891 r
F
.52666 .34504 m .52656 .34502 L .52675 .34499 L F
.52639 .3452 m .52656 .34502 L .52666 .34504 L F
.52601 .34525 m .52616 .34492 L .52615 .3449 L F
.52581 .34509 m .52639 .3452 L .52637 .34518 L F
.52444 .3446 m .51314 .34374 L .51544 .34371 L F
.52407 .34483 m .51454 .3443 L .52429 .34471 L F
.52607 .34501 m .51454 .3443 L .52607 .34501 L F
.5203 .34419 m .52583 .34511 L .52581 .34509 L F
.52583 .34511 m .52639 .3452 L .52581 .34509 L F
.52603 .34578 m .52616 .34499 L .52618 .34495 L F
.52585 .34531 m .52639 .3452 L .52626 .34504 L F
.5261 .34532 m .52639 .3452 L .52622 .34499 L F
.52612 .34535 m .52614 .34534 L .52614 .34538 L F
.52603 .34578 m .52612 .34536 L .52614 .34538 L F
.52435 .35057 m .52629 .34547 L .5261 .34532 L F
.52533 .34687 m .52604 .34527 L .52601 .34525 L F
.52533 .34687 m .52601 .34525 L .52593 .34518 L F
.52542 .34654 m .52585 .3454 L .52583 .34539 L F
.52603 .34578 m .52591 .34569 L .52616 .34499 L F
.52603 .34578 m .52639 .3452 L p .52548 .34587 L F P
0 g
s
.52629 .34547 m .52639 .3452 L .5261 .34532 L .672 .728 .891 r
F
.52604 .34527 m .5262 .3449 L .52601 .34525 L F
.52601 .34525 m .52611 .34499 L .52593 .34518 L F
.52611 .34499 m .52599 .34506 L .52593 .34518 L F
.52583 .34539 m .52585 .3454 L .52601 .34495 L F
.52585 .34531 m .52626 .34504 L .52608 .34496 L F
.52583 .34539 m .52601 .34495 L .52601 .34492 L F
.52363 .34498 m .52433 .34504 L .52361 .34498 L F
.52329 .34507 m .52332 .34508 L .52576 .34518 L F
.52514 .34513 m .52335 .3451 L .52532 .34506 L F
.52433 .34504 m .52639 .3452 L .52433 .34504 L F
.52433 .34504 m .52433 .34504 L .52361 .34498 L F
.52593 .34463 m .52564 .34573 L .52605 .34478 L F
.52564 .34573 m .52558 .34592 L .52566 .34574 L F
.52564 .34573 m .52566 .34574 L .52605 .34478 L F
.52558 .34592 m .52547 .34635 L .52565 .34586 L F
.52558 .34592 m .52565 .34586 L .52605 .34478 L F
.52662 .34493 m .52606 .3448 L .52658 .34484 L F
.52659 .34488 m .52666 .34478 L p .52647 .3449 L F P
0 g
s
.52662 .34493 m .52658 .34484 L .52687 .3449 L .672 .728 .891 r
F
.52642 .34491 m .5264 .34491 L .52611 .34486 L F
.52626 .34504 m .52659 .34488 L .52647 .3449 L F
.52666 .34503 m .52563 .34477 L .52663 .34497 L F
.52514 .34473 m .52573 .34485 L .52567 .34467 L F
.52563 .34477 m .52558 .34476 L .52563 .34477 L F
.52612 .34487 m .52635 .34492 L .52635 .34492 L F
.52563 .34477 m .52612 .34487 L .52612 .34487 L F
.52612 .34487 m .52635 .34492 L .52612 .34487 L F
.52611 .34499 m .52615 .3449 L .52599 .34506 L F
.52615 .3449 m .52632 .34449 L .52611 .34486 L F
.52615 .3449 m .52611 .34486 L .52599 .34506 L F
.52593 .3451 m .52594 .3451 L .52605 .34478 L F
.52605 .34478 m .52605 .34478 L .52622 .34432 L F
.52593 .3451 m .52605 .34478 L .52605 .34478 L F
.52639 .3452 m .52684 .34526 L p .52649 .3452 L F P
0 g
s
.52637 .34518 m .52639 .3452 L .52649 .3452 L .672 .728 .891 r
F
.52639 .3452 m .52639 .3452 L p .52637 .34518 L F P
0 g
s
.52716 .3454 m .52639 .3452 L p .52703 .34518 L .672 .728 .891 r
F P
0 g
s
.52587 .34514 m .52571 .34512 L p .52618 .34494 L .672 .728 .891 r
F P
0 g
s
.52591 .34517 m .52591 .34517 L .52594 .3451 L .672 .728 .891 r
F
.52591 .34517 m .52594 .3451 L .52593 .3451 L F
.52565 .34586 m .52605 .34478 L .52565 .34586 L F
.52605 .34478 m .52622 .34432 L .52605 .34478 L F
.52605 .34478 m .52605 .34478 L .52565 .34586 L F
.52565 .34586 m .52605 .34478 L .52605 .34478 L F
.52575 .34518 m .5258 .34539 L .52608 .34496 L F
.52814 .34534 m .52813 .34534 L .5429 .35125 L F
.52811 .34533 m .52811 .34534 L .5429 .35125 L F
.54344 .35053 m .5278 .34564 L p .52814 .34534 L F P
0 g
s
.52656 .34481 m .52941 .3459 L .52923 .34571 L .672 .728 .891 r
F
.52697 .3451 m .52666 .34503 L .52695 .34505 L F
.52699 .34511 m .52695 .34505 L .52774 .34522 L F
.52697 .3451 m .52695 .34505 L .52699 .34511 L F
.52695 .34505 m .52693 .34501 L .52904 .34552 L F
.52733 .34488 m .52752 .34514 L .53217 .34576 L F
.52904 .34552 m .52693 .34501 L .52687 .3449 L F
.52697 .3451 m .52774 .34522 L .52776 .34526 L F
.52639 .3452 m .52675 .34499 L .53101 .34545 L F
.52639 .3452 m .52624 .34501 L .52699 .34517 L F
.52639 .3452 m .52699 .34517 L .52703 .34518 L F
.52547 .34635 m .52565 .34586 L .52565 .34586 L F
.52478 .35034 m .52639 .3452 L p .52435 .35057 L F P
0 g
s
.52542 .34654 m .52544 .34656 L .52585 .3454 L .672 .728 .891 r
F
.52547 .34635 m .52549 .34635 L .52591 .34517 L F
.52547 .34635 m .52591 .34517 L .52591 .34517 L F
.52603 .34578 m .52566 .34636 L .52591 .34569 L F
.52547 .34635 m .52542 .34654 L .52549 .34635 L F
.52552 .34659 m .52603 .34578 L p .52505 .34652 L F P
0 g
s
.52505 .34652 m .52603 .34578 L .52548 .34587 L .672 .728 .891 r
F
.5251 .34725 m .52532 .3469 L p .52462 .34715 L F P
0 g
s
.52462 .34715 m .52532 .3469 L .52544 .34664 L .672 .728 .891 r
F
.52542 .34654 m .52533 .34687 L .52544 .34656 L F
.52462 .34715 m .52552 .34659 L .52505 .34652 L F
.51907 .35685 m .5251 .34725 L p .52462 .34715 L F P
0 g
s
.52593 .34552 m .52019 .35714 L .52575 .3454 L .672 .728 .891 r
F
.52458 .34971 m .5261 .34531 L .52607 .34529 L F
.52458 .34971 m .5261 .34532 L .5261 .34531 L F
.52579 .34584 m .52585 .34692 L .52537 .3468 L F
.52432 .34919 m .52019 .35714 L p .52593 .34552 L F P
0 g
s
.52628 .34521 m .52585 .34692 L .52579 .34584 L .672 .728 .891 r
F
.52602 .34532 m .52575 .3454 L .52591 .34506 L F
.52548 .34587 m .52639 .3452 L .52585 .34531 L F
.52595 .34547 m .52575 .3454 L .52602 .34532 L F
.52606 .34522 m .52579 .34584 L .52576 .34523 L F
.52628 .34521 m .52579 .34584 L .52606 .34522 L F
.5261 .34553 m .52595 .34547 L .52602 .34532 L F
.5252 .34676 m .52256 .35735 L .52432 .34919 L F
.52552 .34472 m .52502 .34467 L .52588 .34457 L F
.52287 .34375 m .52514 .34473 L .52567 .34467 L F
.52256 .34412 m .52615 .3449 L .52617 .34492 L F
.52041 .34364 m .52254 .34411 L .52256 .34412 L F
.52254 .34411 m .52615 .3449 L .52256 .34412 L F
.52479 .3446 m .5247 .34454 L .52615 .3449 L F
.52444 .3446 m .52631 .34497 L .52484 .34467 L F
.52464 .34452 m .52448 .3446 L .52514 .34473 L F
.52041 .34364 m .52567 .34481 L .52574 .34488 L F
.52486 .34865 m .52506 .34829 L .5262 .3449 L F
.52552 .34487 m .52645 .345 L .52551 .34486 L F
.52555 .34491 m .52565 .34487 L .526 .34491 L F
.52599 .34491 m .52617 .34492 L .52614 .34494 L F
.52609 .34493 m .526 .34491 L .52621 .34493 L F
.52555 .34491 m .526 .34491 L .52609 .34493 L F
.52574 .34488 m .52599 .34491 L .52608 .34496 L F
.52617 .34492 m .52623 .34494 L .52618 .34495 L F
.52647 .3449 m .52666 .34478 L .52619 .34493 L F
.52571 .34512 m .52555 .34491 L .52617 .34493 L F
.52617 .34492 m .52615 .3449 L .52697 .3451 L F
.52695 .3451 m .52697 .3451 L .52699 .34511 L F
.52617 .34492 m .52697 .3451 L .52695 .3451 L F
.52656 .34502 m .52621 .34493 L .52675 .34499 L F
.52628 .34507 m .52622 .34495 L .52656 .34502 L F
.52618 .34495 m .52699 .34511 L .52608 .34496 L F
.52623 .34494 m .52695 .3451 L .52618 .34495 L F
.52695 .3451 m .52699 .34511 L .52618 .34495 L F
.52618 .34495 m .52621 .34493 L .52622 .34495 L F
.52618 .34495 m .52622 .34495 L .52628 .34507 L F
.52622 .34495 m .52621 .34493 L .52656 .34502 L F
.52606 .3448 m .52602 .34474 L .52658 .34484 L F
.52601 .34525 m .5262 .3449 L .52631 .34459 L F
.52618 .34495 m .52619 .34493 L .52617 .34493 L F
.52647 .3449 m .52619 .34493 L .52618 .34495 L F
.52618 .34495 m .52619 .34495 L .5262 .3449 L F
.52618 .34494 m .52617 .34493 L .52621 .34493 L F
.5265 .34406 m .52629 .34465 L .52603 .34475 L F
.52635 .34466 m .52599 .3446 L .52616 .34453 L F
.52606 .3448 m .52628 .3445 L .52615 .34455 L F
.52593 .34518 m .5261 .34485 L .52606 .3448 L F
.52565 .34473 m .52571 .34471 L .52693 .34501 L F
.5261 .34485 m .52628 .3445 L .52606 .3448 L F
.52565 .34473 m .52609 .34483 L .52562 .34475 L F
.52609 .34483 m .52693 .34501 L .5261 .34484 L F
.52609 .34483 m .5261 .34484 L .52562 .34475 L F
.52571 .34512 m .52615 .34494 L .52617 .34494 L F
.52614 .34494 m .52618 .34495 L .52608 .34496 L F
.52617 .34492 m .52618 .34495 L .52614 .34494 L F
.52617 .34494 m .52617 .34493 L .52618 .34494 L F
.52615 .34494 m .52617 .34493 L .52617 .34494 L F
.52618 .34495 m .52617 .34493 L .52608 .34496 L F
.52599 .34491 m .52614 .34494 L .52608 .34496 L F
.52481 .34487 m .52513 .34474 L .52516 .34474 L F
.52444 .3446 m .52449 .34471 L .52551 .34486 L F
.52444 .3446 m .52551 .34486 L .52544 .3448 L F
.52041 .34364 m .52215 .34391 L .5247 .34454 L F
.52287 .34375 m .52448 .3446 L .52464 .34452 L F
.52451 .34417 m .50977 .33911 L .52482 .34411 L F
.52228 .34392 m .50923 .33984 L p .52539 .34441 L F P
0 g
s
.50923 .33984 m .52228 .34392 L p .52287 .34375 L .672 .728 .891 r
F P
0 g
s
.52443 .34448 m .50877 .3406 L .52455 .34443 L .672 .728 .891 r
F
.52538 .34463 m .50877 .3406 L .52563 .34454 L F
.52041 .34364 m .52287 .34428 L p .52155 .34362 L F P
0 g
s
.52195 .34435 m .52294 .3445 L .52294 .34449 L .672 .728 .891 r
F
.52444 .3446 m .52195 .34435 L .52449 .34471 L F
.52493 .3447 m .52168 .34437 L .52287 .34428 L F
.52294 .34449 m .52468 .34475 L .52467 .34474 L F
.52195 .34435 m .52201 .34441 L .52472 .34477 L F
.52195 .34435 m .52472 .34477 L .52468 .34475 L F
.52195 .34435 m .52552 .34487 L .52551 .34486 L F
.52465 .34476 m .52122 .3444 L .52493 .3447 L F
.51544 .34371 m .51314 .34374 L .51227 .3434 L F
.50765 .34377 m .50963 .34392 L p .51045 .34392 L F P
0 g
s
.51454 .3443 m .50765 .34377 L p .51227 .3434 L .672 .728 .891 r
F P
0 g
s
.50781 .34296 m .5206 .3445 L p .5203 .34419 L .672 .728 .891 r
F P
0 g
s
.52122 .3444 m .50781 .34296 L .52168 .34437 L .672 .728 .891 r
F
.52122 .3444 m .52168 .34437 L .52493 .3447 L F
.526 .34491 m .52465 .34476 L .52493 .3447 L F
.52575 .34518 m .52462 .34715 L .5258 .34539 L F
.52566 .34535 m .52567 .34558 L .52557 .3455 L F
.52557 .3455 m .52315 .35089 L .5192 .35663 L F
.52567 .34558 m .52315 .35089 L .52557 .3455 L F
.52315 .35089 m .52019 .35714 L .5192 .35663 L F
.52297 .3443 m .52497 .3447 L .52622 .345 L F
.52533 .34687 m .52486 .34865 L .52619 .34495 L F
.52576 .34491 m .52622 .345 L .52624 .34501 L F
.52287 .34428 m .52575 .34489 L .52576 .34491 L F
.52575 .34489 m .52622 .345 L .52576 .34491 L F
.52618 .34452 m .52657 .34346 L .52617 .34451 L F
.52606 .34438 m .52606 .34439 L .52625 .34382 L F
.52624 .34381 m .52625 .34382 L .52638 .3434 L F
.52588 .34457 m .52596 .34466 L .52638 .3434 L F
.52637 .34404 m .52636 .34402 L .52607 .34481 L F
.52604 .34476 m .52636 .34401 L .52627 .34385 L F
.52627 .34385 m .52704 .34218 L .52638 .3434 L F
.52678 .34138 m .52635 .34466 L .52598 .34441 L F
.52632 .34449 m .52628 .3445 L .52627 .34454 L F
.52628 .34456 m .52627 .34454 L .52593 .34518 L F
.52632 .34449 m .52627 .34454 L .52628 .34456 L F
.52574 .34484 m .52547 .3448 L .52584 .3448 L F
.52601 .34492 m .52601 .34495 L .52623 .34432 L F
.52601 .34473 m .52614 .34489 L .52629 .34466 L F
.52617 .34493 m .52619 .34493 L .52615 .3449 L F
.52639 .34447 m .52629 .34465 L .5265 .34406 L F
.52634 .34463 m .52631 .34464 L .52639 .34447 L F
.52631 .34464 m .52629 .34465 L .52639 .34447 L F
.52639 .34487 m .52632 .34489 L .52636 .34453 L F
.52641 .3441 m .52704 .34218 L .52637 .34404 L F
.52644 .34435 m .52636 .34453 L .52658 .34292 L F
.52639 .34487 m .52636 .34453 L .52644 .34435 L F
.52664 .34308 m .52792 .33243 L p .52648 .34277 L F P
0 g
s
.52792 .33243 m .52667 .34281 L p .52617 .34288 L .672 .728 .891 r
F P
0 g
s
.52704 .34218 m .52912 .33252 L p .52638 .3434 L .672 .728 .891 r
F P
0 g
s
.52661 .34289 m .52658 .34292 L .52678 .34138 L .672 .728 .891 r
F
.52636 .34401 m .52704 .34218 L .52627 .34385 L F
.52639 .34487 m .52658 .34292 L .52661 .34289 L F
.52155 .34362 m .5234 .34425 L .52373 .34422 L F
.52287 .34428 m .52041 .34364 L p .52497 .3447 L F P
0 g
s
.52155 .34362 m .52287 .34428 L .5234 .34425 L .672 .728 .891 r
F
.52619 .34493 m .52666 .34478 L .52621 .34489 L F
.52615 .3449 m .52666 .34478 L .52648 .34457 L F
.52635 .34492 m .52635 .34492 L .52663 .34497 L F
.52671 .34483 m .52626 .3449 L .52643 .34479 L F
.52733 .34488 m .5272 .34504 L .52741 .345 L F
.53101 .34545 m .52695 .34498 L .52671 .34483 L F
.52695 .34498 m .52626 .3449 L .52671 .34483 L F
.52631 .34463 m .52648 .34457 L .52641 .34448 L F
.52622 .34499 m .52664 .3444 L .52657 .34415 L F
.52645 .34468 m .52651 .34429 L .52654 .34431 L F
.52621 .34493 m .52622 .34492 L .52681 .34496 L F
.52681 .34496 m .52622 .34492 L .52626 .3449 L F
.52639 .3452 m .52654 .34473 L p .52622 .34499 L F P
0 g
s
.52654 .34473 m .52664 .3444 L p .5263 .34487 L .672 .728 .891 r
F P
0 g
s
.52622 .34499 m .52654 .34473 L .5263 .34487 L .672 .728 .891 r
F
.52619 .34493 m .52621 .34489 L .52615 .3449 L F
.52617 .34493 m .52616 .34492 L .52622 .34492 L F
.52621 .34493 m .5263 .34469 L .52619 .34494 L F
.5263 .34469 m .52647 .34422 L .52622 .34486 L F
.5263 .34469 m .52622 .34486 L .52619 .34494 L F
.52563 .34477 m .52563 .34477 L .52635 .34492 L F
.52558 .34476 m .52562 .34475 L .52663 .34497 L F
.52574 .34484 m .52584 .3448 L .52606 .3448 L F
.52616 .34492 m .52631 .34459 L .52615 .3449 L F
.52608 .34481 m .52606 .3448 L .52643 .34479 L F
.52562 .34475 m .5261 .34484 L .52611 .34486 L F
.52574 .34484 m .52606 .3448 L .52608 .34481 L F
.52614 .34489 m .52625 .3448 L .52631 .34463 L F
.52567 .34481 m .52617 .34492 L .52574 .34488 L F
.52617 .34493 m .526 .34491 L .52616 .34492 L F
.52608 .34496 m .52615 .3449 L .52614 .34489 L F
.52615 .3449 m .52625 .3448 L .52614 .34489 L F
.52625 .3448 m .52648 .34457 L .52632 .34462 L F
.52625 .3448 m .52632 .34462 L .52631 .34463 L F
.52617 .34493 m .52622 .34492 L .52621 .34493 L F
.5264 .3449 m .52643 .34466 L .52645 .34468 L F
.52634 .34515 m .52638 .3449 L .5264 .3449 L F
.52622 .34494 m .52649 .34488 L .52648 .34487 L F
.52643 .34479 m .52601 .34473 L .52648 .34487 L F
.52606 .3448 m .52538 .34463 L .52602 .34474 L F
.52567 .34467 m .52572 .3447 L .52573 .34469 L F
.52643 .34479 m .52547 .3448 L .52535 .34464 L F
.52601 .34473 m .52535 .34464 L .52605 .34478 L F
.52601 .34473 m .52605 .34478 L .52648 .34487 L F
.52628 .34473 m .52612 .34487 L .52608 .3447 L F
.52613 .34488 m .52574 .34484 L .52608 .34481 L F
.52583 .34539 m .52623 .34432 L .52622 .34432 L F
.52601 .34473 m .52594 .34497 L .52614 .34489 L F
.52616 .34492 m .526 .34491 L .52615 .3449 L F
.52585 .345 m .52608 .34496 L .52614 .34489 L F
.52626 .3449 m .526 .34491 L .52547 .3448 L F
.52612 .34487 m .52591 .34506 L .52605 .34478 L F
.52612 .34487 m .52605 .34478 L .52608 .3447 L F
.52638 .3449 m .52643 .34466 L .5264 .3449 L F
.5261 .34531 m .52647 .34422 L .52607 .34529 L F
.52622 .34492 m .52616 .34492 L .52626 .3449 L F
.52616 .34492 m .52615 .3449 L .52626 .3449 L F
.52626 .3449 m .52613 .34488 L .52643 .34479 L F
.52613 .34488 m .52608 .34481 L .52643 .34479 L F
.52585 .345 m .52575 .34518 L .52608 .34496 L F
.52533 .34687 m .52619 .34495 L .52618 .34495 L F
.52555 .34491 m .52551 .34486 L .52565 .34487 L F
.52587 .34514 m .52618 .34494 L .52618 .34495 L F
.52481 .34487 m .52407 .34483 L .52513 .34474 L F
.5203 .34419 m .52529 .345 L .52562 .34489 L F
.52442 .34502 m .52454 .34497 L .52598 .34507 L F
.5206 .3445 m .52571 .34512 L p .5203 .34419 L F P
0 g
s
.5203 .34419 m .52571 .34512 L .52577 .3451 L .672 .728 .891 r
F
.52564 .34505 m .52098 .34473 L .52559 .34501 L F
.52571 .34512 m .50781 .34296 L p .52551 .34486 L F P
0 g
s
.52607 .34529 m .52621 .34493 L .52619 .34494 L .672 .728 .891 r
F
.52639 .3452 m .52526 .34491 L p .52624 .34501 L F P
0 g
s
.52526 .34491 m .52287 .34428 L p .52501 .34475 L .672 .728 .891 r
F P
0 g
s
.52526 .34491 m .52501 .34475 L .52624 .34501 L .672 .728 .891 r
F
.52486 .34865 m .52458 .34971 L .52506 .34829 L F
.52369 .35039 m .52432 .34919 L p .52389 .3492 L F P
0 g
s
.52522 .34732 m .52251 .35757 L .52251 .35755 L .672 .728 .891 r
F
.52458 .34971 m .52435 .35057 L .52466 .34967 L F
.52251 .35757 m .52478 .35034 L p .52435 .35057 L F P
0 g
s
.52585 .34692 m .52253 .3575 L p .52496 .34774 L .672 .728 .891 r
F P
0 g
s
.52253 .3575 m .52256 .35735 L .52496 .34774 L .672 .728 .891 r
F
.52537 .3468 m .52496 .34774 L .5252 .34676 L F
.52585 .34692 m .52496 .34774 L .52537 .3468 L F
.52615 .34565 m .52432 .34919 L p .52593 .34552 L F P
0 g
s
.52614 .346 m .52633 .34513 L .52634 .34515 L .672 .728 .891 r
F
.52615 .34565 m .52605 .34559 L .5261 .34553 L F
.52605 .34559 m .52575 .3454 L .5261 .34553 L F
.52615 .34565 m .52591 .34506 L .52619 .34535 L F
.52614 .346 m .52608 .346 L .52635 .34491 L F
.52637 .3449 m .52635 .34491 L .52651 .34429 L F
.52614 .346 m .52635 .34491 L .52637 .3449 L F
.5261 .34499 m .52591 .34506 L .52612 .34487 L F
.52593 .34508 m .52639 .3452 L p .52607 .34501 L F P
0 g
s
.52606 .34522 m .5261 .34499 L .52618 .34495 L .672 .728 .891 r
F
.52608 .34496 m .52617 .34493 L .52615 .3449 L F
.5261 .34499 m .52612 .34487 L .52618 .34495 L F
.52607 .34501 m .52639 .3452 L .52618 .34495 L F
.52618 .34495 m .52628 .34521 L .52606 .34522 L F
.5261 .34531 m .5261 .34532 L .52647 .34422 L F
.52605 .34478 m .52622 .34494 L .52648 .34487 L F
.5262 .3449 m .52647 .34422 L .52642 .34424 L F
.52619 .34494 m .52622 .34486 L .5262 .3449 L F
.52622 .34486 m .52647 .34422 L .5262 .3449 L F
.52629 .34457 m .52631 .34459 L .52642 .34424 L F
.52632 .34449 m .52642 .34424 L .52628 .3445 L F
.52636 .34412 m .52629 .34466 L .52635 .34456 L F
.5267 .34377 m .52669 .34379 L p .52668 .3438 L F P
0 g
s
.52638 .34418 m .5267 .34377 L .52656 .34366 L .672 .728 .891 r
F
.5267 .34376 m .5267 .34377 L p .5265 .34389 L F P
0 g
s
.52646 .3443 m .52645 .34426 L .52648 .34425 L .672 .728 .891 r
F
.52654 .34424 m .52645 .34426 L .5265 .34406 L F
.5267 .34377 m .52645 .34433 L .5265 .34389 L F
.5267 .34377 m .52704 .34218 L p .52656 .34366 L F P
0 g
s
.52657 .34346 m .52704 .34218 L .52656 .34345 L .672 .728 .891 r
F
.52637 .34404 m .52704 .34218 L .52636 .34402 L F
.52595 .3442 m .52638 .3434 L .52912 .33252 L F
.5267 .34376 m .5265 .34389 L .52678 .34138 L F
.52642 .34424 m .52647 .34422 L .52711 .34229 L F
.5271 .34223 m .52711 .34229 L .53032 .33267 L F
.52642 .34424 m .52711 .34229 L .5271 .34223 L F
.52726 .34115 m .5267 .34376 L p .52678 .34138 L F P
0 g
s
.52717 .34271 m .53032 .33267 L p .52638 .34451 L .672 .728 .891 r
F P
0 g
s
.52636 .34412 m .52657 .34407 L .52687 .34338 L .672 .728 .891 r
F
.52636 .34412 m .52635 .34456 L .52657 .34407 L F
.52737 .3428 m .52682 .34386 L .5267 .34377 L F
.53379 .33341 m .52682 .34386 L .52737 .3428 L F
.53379 .33341 m .5269 .34393 L .52682 .34386 L F
.52646 .3443 m .52648 .34425 L .52654 .34424 L F
.52687 .34338 m .52635 .34456 L .52812 .34192 L F
.52654 .34431 m .52651 .34429 L .52655 .3441 L F
.52716 .34271 m .52657 .34407 L .52636 .34412 L F
.52662 .34395 m .52655 .3441 L .52683 .34299 L F
.53379 .33341 m .53266 .33311 L p .52716 .34271 L F P
0 g
s
.52716 .34271 m .52636 .34412 L .52757 .34237 L .672 .728 .891 r
F
.52716 .34271 m .52757 .34237 L .53379 .33341 L F
.52601 .34473 m .52585 .345 L .52594 .34497 L F
.52535 .34464 m .52518 .34474 L .52592 .34489 L F
.52567 .34477 m .52607 .34501 L .52568 .34476 L F
.52607 .34501 m .52639 .3452 L .52607 .34501 L F
.52591 .34506 m .52589 .34504 L .52601 .34473 L F
.52607 .34501 m .52607 .34501 L .52568 .34476 L F
.52575 .34518 m .52575 .3454 L .52566 .34535 L F
.52601 .34473 m .52586 .34512 L .52575 .34518 L F
.52586 .34512 m .52575 .3454 L .52575 .34518 L F
.52593 .34508 m .52591 .34506 L .5261 .34499 L F
.52567 .34477 m .52593 .34508 L .52607 .34501 L F
.52535 .34464 m .52575 .34482 L .52593 .34476 L F
.52565 .34475 m .52567 .34477 L .52567 .34477 L F
.52567 .34477 m .52593 .34508 L .52567 .34477 L F
.52593 .34476 m .52613 .34488 L .52605 .34478 L F
.52616 .34453 m .52599 .3446 L .52598 .34441 L F
.52593 .34463 m .52605 .34478 L .52621 .34432 L F
.52608 .3447 m .52605 .34478 L .52601 .34473 L F
.52605 .34478 m .52591 .34506 L .52601 .34473 L F
.52536 .34467 m .52568 .34472 L .52565 .34473 L F
.52443 .34448 m .52568 .34472 L .52536 .34467 L F
.52443 .34448 m .52571 .34471 L .52568 .34472 L F
.52443 .34448 m .52455 .34443 L .52571 .34471 L F
.52466 .34436 m .52418 .34435 L .52613 .34489 L F
.52575 .34482 m .52592 .34489 L .52593 .34476 L F
.52588 .34489 m .52607 .34501 L .52618 .34495 L F
.52592 .34489 m .52609 .34497 L .52605 .34492 L F
.52592 .34489 m .52605 .34492 L .52593 .34476 L F
.52609 .34497 m .52616 .34495 L .52593 .34476 L F
.52616 .34495 m .52613 .34488 L .52593 .34476 L F
.5263 .3451 m .52628 .34521 L .52618 .34495 L F
.52618 .34495 m .52619 .34494 L .52621 .34493 L F
.52618 .34495 m .52619 .34494 L .52618 .34495 L F
.52618 .34495 m .52618 .34494 L .52619 .34494 L F
.52618 .34495 m .52613 .34488 L .52616 .34495 L F
.52588 .34489 m .52618 .34495 L .52615 .34491 L F
.52592 .34489 m .52605 .34498 L .52609 .34497 L F
.52606 .3448 m .52618 .34495 L .52591 .34501 L F
.52613 .34488 m .52622 .34494 L .52605 .34478 L F
.52618 .34495 m .52612 .34487 L .52628 .34473 L F
.52628 .34473 m .52608 .3447 L .52629 .34462 L F
.52638 .3445 m .52618 .34495 L .52623 .34456 L F
.52655 .3441 m .52635 .34491 L .52618 .34495 L F
.52635 .34491 m .5263 .3451 L .52618 .34495 L F
.52618 .34495 m .52626 .34496 L .52622 .34494 L F
.52618 .34495 m .52622 .34494 L .52613 .34488 L F
.52618 .34495 m .52639 .3452 L .52626 .34496 L F
.52624 .34501 m .52622 .345 L .52703 .34518 L F
.52608 .34496 m .52666 .34506 L .52671 .34511 L F
.52664 .34438 m .52664 .3444 L p .52654 .34431 L F P
0 g
s
.52675 .34499 m .52617 .34493 L .52681 .34496 L .672 .728 .891 r
F
.52664 .3444 m .52614 .346 L p .52651 .34445 L F P
0 g
s
.52664 .3444 m .52651 .34445 L .52654 .34431 L .672 .728 .891 r
F
.52591 .34506 m .52575 .3454 L .52589 .34504 L F
.52591 .34501 m .52606 .34522 L .52576 .34523 L F
.52583 .34502 m .52591 .34501 L .52576 .34523 L F
.52627 .34543 m .52615 .34565 L .52619 .34535 L F
.52432 .34919 m .52639 .3452 L p .52607 .3452 L F P
0 g
s
.52619 .34535 m .52606 .34522 L .52618 .34495 L .672 .728 .891 r
F
.52607 .3452 m .52639 .3452 L .52608 .34519 L F
.52468 .34751 m .52459 .34792 L .52607 .3452 L F
.52606 .34522 m .52593 .34508 L .5261 .34499 L F
.52618 .34495 m .52606 .34522 L .52591 .34501 L F
.52567 .34484 m .52572 .34503 L .52574 .34486 L F
.52592 .34489 m .52566 .34491 L .52639 .3452 L F
.52486 .34495 m .52599 .34514 L p .52566 .34491 L F P
0 g
s
.52591 .34508 m .52593 .34508 L p .52585 .34498 L .672 .728 .891 r
F P
0 g
s
.52574 .34486 m .52591 .34508 L .52585 .34498 L .672 .728 .891 r
F
.52572 .34503 m .52591 .34508 L p .52574 .34486 L F P
0 g
s
.52599 .34514 m .52639 .3452 L p .52566 .34491 L .672 .728 .891 r
F P
0 g
s
.52609 .34497 m .52627 .34505 L .52616 .34495 L .672 .728 .891 r
F
.52627 .34505 m .52626 .34496 L .52618 .34495 L F
.52622 .34494 m .52626 .34496 L .52649 .34488 L F
.52618 .34495 m .52626 .34496 L .52624 .34492 L F
.52619 .34535 m .52618 .34495 L .52625 .34491 L F
.52605 .34498 m .52639 .3452 L .52609 .34497 L F
.52627 .34505 m .52618 .34495 L .52616 .34495 L F
.52639 .3452 m .52599 .34514 L p .5262 .34497 L F P
0 g
s
.52599 .34513 m .526 .34513 L .52618 .34494 L .672 .728 .891 r
F
.526 .34513 m .52618 .34495 L .52618 .34494 L F
.52588 .34489 m .52588 .34489 L .52604 .3449 L F
.52588 .34489 m .52604 .3449 L .52615 .34491 L F
.52568 .34476 m .52588 .34489 L .52615 .34491 L F
.52596 .34467 m .52591 .34501 L .52583 .34502 L F
.52593 .34463 m .52538 .34463 L .52563 .34454 L F
.52602 .34474 m .52538 .34463 L .52593 .34463 L F
.52596 .34467 m .52466 .34436 L .52613 .34489 L F
.526 .34472 m .52591 .34501 L .52596 .34467 L F
.52568 .34476 m .52615 .34491 L .52613 .34489 L F
.526 .34472 m .52606 .3448 L .52591 .34501 L F
.52596 .34467 m .52576 .34523 L .5261 .34484 L F
.52605 .34478 m .52622 .34432 L .52621 .34432 L F
.52605 .34478 m .52622 .34432 L .52605 .34478 L F
.52615 .34455 m .52642 .34424 L .52623 .34432 L F
.52628 .3445 m .52642 .34424 L .52615 .34455 L F
.52636 .34412 m .52601 .34473 L .52629 .34466 L F
.52629 .34462 m .52608 .3447 L .52636 .34412 L F
.52636 .34412 m .52608 .3447 L .52601 .34473 L F
.52623 .34432 m .52642 .34424 L .53032 .33267 L F
.52622 .34432 m .52623 .34432 L .52661 .34322 L F
.52621 .34432 m .52622 .34432 L .52661 .34322 L F
.52635 .34369 m .52655 .3441 L .52606 .3448 L F
.5263 .34322 m .52598 .34441 L .52661 .34322 L F
.52645 .34331 m .52648 .34354 L .52635 .34369 L F
.52648 .34354 m .52655 .3441 L .52635 .34369 L F
.52659 .3441 m .52717 .34271 L .52662 .34395 L F
.52659 .3441 m .52662 .34395 L .52638 .34451 L F
.52622 .34499 m .52659 .3441 L .52638 .34451 L F
.52654 .34431 m .52655 .3441 L .52662 .34395 L F
.52664 .3444 m .52717 .34271 L p .52657 .34415 L F P
0 g
s
.52717 .34271 m .52673 .34412 L p .52698 .34287 L .672 .728 .891 r
F P
0 g
s
.52718 .34269 m .52703 .34396 L .52657 .34407 L .672 .728 .891 r
F
.52757 .34237 m .52812 .34192 L .53379 .33341 L F
.52687 .34338 m .52812 .34192 L .52757 .34237 L F
.52641 .34448 m .52882 .34133 L .52812 .34192 L F
.53266 .33311 m .5273 .34344 L p .52718 .34269 L F P
0 g
s
.5273 .34344 m .52703 .34396 L p .52718 .34269 L .672 .728 .891 r
F P
0 g
s
.52623 .34456 m .52618 .34495 L .52606 .3448 L .672 .728 .891 r
F
.52596 .34467 m .52613 .34489 L .52624 .34492 L F
.52625 .34491 m .52618 .34495 L .52628 .34473 L F
.52596 .34467 m .52624 .34492 L .52633 .34487 L F
.52611 .34486 m .52607 .34481 L .52649 .34484 L F
.52643 .34479 m .52648 .34487 L .52726 .34503 L F
.52677 .34486 m .52647 .34479 L .5266 .34501 L F
.52647 .34479 m .52596 .34467 L .52633 .34487 L F
.52633 .34513 m .52643 .34466 L .52634 .34515 L F
.52626 .34496 m .52658 .34503 L .52649 .34488 L F
.52647 .34479 m .52633 .34487 L .5266 .34501 L F
.52626 .34496 m .5263 .34503 L .5263 .34497 L F
.5263 .34503 m .52639 .3452 L .5263 .34497 L F
.5263 .34497 m .52639 .3452 L .52658 .34503 L F
.52627 .34505 m .52673 .34526 L .52626 .34496 L F
.52633 .34487 m .52624 .34492 L .5266 .34501 L F
.52624 .34492 m .52626 .34496 L .5266 .34501 L F
.52627 .34505 m .52639 .3452 L .52662 .34521 L F
.52628 .34533 m .52619 .34535 L .52633 .34435 L F
.52628 .34533 m .52633 .34435 L .52634 .34439 L F
.52627 .34543 m .52628 .34533 L .52628 .34533 L F
.52628 .34533 m .52633 .34435 L .52628 .34533 L F
.52666 .34506 m .52699 .34511 L .52671 .34511 L F
.52671 .34511 m .52699 .34511 L .52703 .34518 L F
.52807 .34539 m .52826 .34552 L .52941 .3459 L F
.52923 .34571 m .52941 .3459 L .54344 .35053 L F
.52776 .34526 m .52774 .34522 L .52904 .34552 L F
.52904 .34552 m .52639 .3452 L p .52886 .34533 L F P
0 g
s
.52826 .34552 m .52828 .34553 L .54344 .35053 L .672 .728 .891 r
F
.54344 .35053 m .54392 .34978 L p .52904 .34552 L F P
0 g
s
.52904 .34552 m .52923 .34571 L .54344 .35053 L .672 .728 .891 r
F
.52699 .34511 m .5278 .34564 L .52936 .34589 L F
.52713 .34534 m .52715 .34536 L .5278 .34564 L F
.53078 .34635 m .52716 .3454 L p .53155 .34624 L F P
0 g
s
.52716 .3454 m .52703 .34518 L .53155 .34624 L .672 .728 .891 r
F
.5278 .34564 m .54344 .35053 L p .52936 .34589 L F P
0 g
s
.54389 .34977 m .52904 .34552 L .54392 .34978 L .672 .728 .891 r
F
.54392 .34978 m .53078 .34635 L p .53155 .34624 L F P
0 g
s
.52639 .3452 m .54381 .34975 L p .52682 .34507 L .672 .728 .891 r
F P
0 g
s
.52648 .34487 m .52658 .34503 L .53252 .34622 L .672 .728 .891 r
F
.5266 .34501 m .52658 .34503 L .52682 .34507 L F
.52658 .34503 m .52639 .3452 L .52682 .34507 L F
.5266 .34501 m .54381 .34975 L .54377 .34974 L F
.53248 .34621 m .53252 .34622 L p .52658 .34503 L F P
0 g
s
.53159 .34583 m .52904 .34552 L p .53101 .34545 L .672 .728 .891 r
F P
0 g
s
.52904 .34552 m .52886 .34533 L .53101 .34545 L .672 .728 .891 r
F
.52648 .34487 m .53252 .34622 L .53344 .34631 L F
.52871 .34518 m .52675 .34499 L .52681 .34496 L F
.52873 .3452 m .52675 .34499 L .52871 .34518 L F
.5272 .3449 m .52726 .34503 L .535 .34663 L F
.52755 .34505 m .52732 .34502 L .54371 .34972 L F
.54368 .34971 m .54371 .34972 L .54392 .34978 L F
.52755 .34505 m .54371 .34972 L .54368 .34971 L F
.5272 .3449 m .52643 .34479 L .52726 .34503 L F
.52755 .34505 m .52677 .34486 L .52732 .34502 L F
.54392 .34978 m .54433 .34902 L p .53247 .34621 L F P
0 g
s
.53247 .34621 m .52755 .34505 L .54368 .34971 L .672 .728 .891 r
F
.53247 .34621 m .54368 .34971 L .54392 .34978 L F
.52703 .34518 m .52699 .34511 L .53155 .34624 L F
.53155 .34624 m .52697 .3451 L .52904 .34552 L F
.52677 .34486 m .5266 .34501 L .54392 .34978 L F
.52673 .34526 m .53248 .34621 L p .52658 .34503 L F P
0 g
s
.52626 .34496 m .52673 .34526 L .52658 .34503 L .672 .728 .891 r
F
.53247 .34621 m .52683 .34508 L .52677 .34486 L F
.52639 .3452 m .52673 .34526 L p .52662 .34521 L F P
0 g
s
.52639 .3452 m .53074 .34567 L .53108 .34578 L .672 .728 .891 r
F
.53248 .34621 m .52639 .3452 L p .53108 .34578 L F P
0 g
s
.53437 .34666 m .52685 .34513 L .52683 .34508 L .672 .728 .891 r
F
.53437 .34666 m .52683 .34508 L .53247 .34621 L F
.52639 .3452 m .52655 .34502 L .52656 .34502 L F
.52868 .34545 m .52656 .34502 L .53074 .34567 L F
.52639 .3452 m .52656 .34502 L .52868 .34545 L F
.53101 .34545 m .52873 .3452 L .52871 .34518 L F
.54483 .34743 m .54483 .34743 L .54492 .34744 L F
.53121 .34547 m .53217 .34576 L .54492 .34744 L F
.53438 .34581 m .539 .34617 L p .53443 .34581 L F P
0 g
s
.53859 .34546 m .52845 .3449 L .539 .34617 L .672 .728 .891 r
F
.53651 .34598 m .53324 .34573 L p .53647 .34578 L F P
0 g
s
.53232 .34544 m .53214 .34545 L .539 .34617 L .672 .728 .891 r
F
.53324 .34573 m .53314 .34556 L .53647 .34578 L F
.53012 .34516 m .53121 .34547 L .54492 .34744 L F
.54492 .34744 m .53159 .34583 L p .53101 .34545 L F P
0 g
s
.53101 .34545 m .5272 .3449 L .535 .34663 L .672 .728 .891 r
F
.53108 .34578 m .53074 .34567 L .53272 .34598 L F
.53019 .3455 m .52684 .34507 L .52694 .34488 L F
.53272 .34598 m .53074 .34567 L .53019 .3455 L F
.53074 .34567 m .52684 .34507 L .53019 .3455 L F
.53252 .34622 m .535 .34663 L p .53344 .34631 L F P
0 g
s
.52637 .34518 m .52629 .34508 L .52631 .34488 L .672 .728 .891 r
F
.52679 .34443 m .52652 .34494 L p .52688 .34399 L F P
0 g
s
.52626 .34496 m .52658 .34503 L .5266 .34501 L .672 .728 .891 r
F
.52652 .34494 m .52627 .34543 L p .5265 .34488 L F P
0 g
s
.52652 .34494 m .5265 .34488 L .52688 .34399 L .672 .728 .891 r
F
.5265 .34488 m .52637 .34518 L .52631 .34488 L F
.52613 .34489 m .52615 .34491 L .52624 .34492 L F
.52652 .34494 m .52589 .34489 L .52649 .34486 L F
.52647 .34479 m .52631 .34488 L .52634 .34439 L F
.5265 .34488 m .52631 .34488 L .52647 .34479 L F
.52611 .34486 m .52649 .34484 L .52649 .34486 L F
.52643 .34466 m .52651 .34429 L .52645 .34468 L F
.52673 .34412 m .52664 .34438 L p .5266 .34408 L F P
0 g
s
.52664 .34438 m .52654 .34431 L .5266 .34408 L .672 .728 .891 r
F
.52688 .34399 m .5265 .34488 L .52636 .34412 L F
.52703 .34396 m .52679 .34443 L p .52688 .34399 L F P
0 g
s
.52652 .34494 m .52679 .34443 L p .52621 .34495 L .672 .728 .891 r
F P
0 g
s
.52673 .34412 m .5266 .34408 L .52723 .34145 L .672 .728 .891 r
F
.52673 .34412 m .52723 .34145 L .52727 .34141 L F
.52679 .34443 m .53266 .33311 L p .52642 .34455 L F P
0 g
s
.52621 .34495 m .52679 .34443 L .52642 .34455 L .672 .728 .891 r
F
.52589 .34489 m .52572 .34485 L .52649 .34486 L F
.52296 .3443 m .52497 .3447 L .52297 .3443 L F
.52287 .34428 m .52296 .3443 L .52297 .3443 L F
.52041 .34364 m .5247 .34454 L .52479 .3446 L F
.52287 .34428 m .52572 .34503 L p .5234 .34425 L F P
0 g
s
.52518 .34474 m .52284 .34428 L .52486 .34495 L .672 .728 .891 r
F
.52486 .34468 m .52572 .34503 L .52567 .34484 L F
.5262 .34497 m .52311 .34433 L .52618 .34495 L F
.52596 .34495 m .52589 .34489 L .52618 .34495 L F
.52599 .34514 m .52617 .34496 L .5262 .34497 L F
.52609 .34497 m .52639 .3452 L .52627 .34505 L F
.52608 .34519 m .52639 .3452 L .5262 .34497 L F
.52618 .34495 m .52607 .3452 L .5262 .34497 L F
.526 .34513 m .52632 .34512 L .52618 .34495 L F
.52518 .34474 m .52486 .34495 L .52592 .34489 L F
.5262 .34497 m .52557 .34487 L .52562 .34485 L F
.52565 .34475 m .52567 .34484 L .52574 .34486 L F
.52549 .34485 m .52568 .34478 L .52607 .34481 L F
.52549 .34485 m .52607 .34481 L .52611 .34486 L F
.52565 .34475 m .52567 .34477 L .52568 .34476 L F
.50806 .34216 m .50838 .34137 L p .52297 .3443 L F P
0 g
s
.52558 .34476 m .52443 .34448 L .52562 .34475 L .672 .728 .891 r
F
.52443 .34448 m .52565 .34473 L .52562 .34475 L F
.52535 .34464 m .52547 .3448 L .52284 .34428 L F
.52535 .34464 m .52288 .34428 L .52518 .34474 L F
.5234 .34425 m .52572 .34503 L .52373 .34422 L F
.52287 .34428 m .50781 .34296 L .52284 .34428 L F
.52195 .34435 m .5203 .34419 L .52201 .34441 L F
.52168 .34437 m .50781 .34296 L .52287 .34428 L F
.50781 .34296 m .50806 .34216 L p .52284 .34428 L F P
0 g
s
.52284 .34428 m .51886 .34371 L .52357 .34468 L .672 .728 .891 r
F
.52284 .34428 m .52357 .34468 L .52486 .34495 L F
.50806 .34216 m .51957 .34407 L p .51886 .34371 L F P
0 g
s
.51957 .34407 m .52486 .34495 L p .51886 .34371 L .672 .728 .891 r
F P
0 g
s
.52562 .34485 m .50806 .34216 L .52311 .34433 L .672 .728 .891 r
F
.52288 .34428 m .52284 .34428 L .52518 .34474 L F
.52373 .34422 m .52486 .34468 L .52565 .34475 L F
.52041 .34364 m .50877 .3406 L p .52215 .34391 L F P
0 g
s
.50877 .3406 m .52041 .34364 L p .52155 .34362 L .672 .728 .891 r
F P
0 g
s
.52486 .34468 m .50838 .34137 L .52508 .34446 L .672 .728 .891 r
F
.52311 .34433 m .50806 .34216 L .52297 .3443 L F
.52483 .34472 m .50838 .34137 L .52486 .34468 L F
.52596 .34467 m .5255 .34477 L .52508 .34446 L F
.52677 .34486 m .52607 .34481 L .52596 .34467 L F
.52607 .34481 m .5255 .34477 L .52596 .34467 L F
.52576 .34523 m .52584 .34529 L .52614 .3449 L F
.52576 .34523 m .52614 .3449 L .5261 .34484 L F
.52634 .34439 m .52633 .34435 L .52636 .34412 L F
.5265 .34488 m .52634 .34439 L .52636 .34412 L F
.52655 .3441 m .52638 .3445 L .52623 .34456 L F
.52598 .34441 m .52599 .3446 L .52593 .34463 L F
.52598 .34441 m .52593 .34463 L .52621 .34432 L F
.52605 .34443 m .52596 .34467 L .52655 .34431 L F
.52912 .33252 m .52726 .34115 L p .52678 .34138 L F P
0 g
s
.5263 .34322 m .52661 .34322 L .53032 .33267 L .672 .728 .891 r
F
.52742 .34066 m .52683 .34299 L .52645 .34331 L F
.52683 .34299 m .52655 .3441 L .52645 .34331 L F
.52718 .34269 m .52657 .34407 L .52716 .34271 L F
.52686 .34296 m .52683 .34299 L .52742 .34066 L F
.52654 .34431 m .52683 .34299 L .52686 .34296 L F
.52598 .34441 m .52621 .34432 L .52661 .34322 L F
.52645 .34331 m .526 .34472 L .52596 .34467 L F
.52645 .34331 m .52606 .3448 L .526 .34472 L F
.52622 .34395 m .52605 .34443 L .52655 .3441 L F
.52622 .34395 m .52655 .3441 L .52665 .34389 L F
.52797 .34015 m .52717 .34271 L p .52742 .34066 L F P
0 g
s
.52717 .34271 m .52698 .34287 L .52742 .34066 L .672 .728 .891 r
F
.5265 .34422 m .52634 .34458 L .53266 .33311 L F
.52634 .34458 m .52639 .34457 L .53266 .33311 L F
.52615 .34491 m .52618 .34495 L .52623 .34492 L F
.52615 .34491 m .52623 .34492 L .52624 .34492 L F
.52615 .34491 m .52615 .34491 L .52624 .34492 L F
.52618 .34495 m .52589 .34489 L .52652 .34494 L F
.52618 .34495 m .52621 .34495 L .53266 .33311 L F
.53266 .33311 m .5315 .33287 L p .5265 .34422 L F P
0 g
s
.52695 .34385 m .5315 .33287 L p .52622 .34395 L .672 .728 .891 r
F P
0 g
s
.5315 .33287 m .52599 .3447 L .5265 .34422 L .672 .728 .891 r
F
.52639 .3452 m .52652 .34494 L p .5262 .34497 L F P
0 g
s
.52655 .34502 m .5262 .34497 L .52624 .34496 L .672 .728 .891 r
F
.5262 .34497 m .52652 .34494 L .52621 .34495 L F
.52655 .34502 m .52618 .34495 L .52652 .34494 L F
.52656 .34502 m .52655 .34502 L .52655 .34502 L F
.52656 .34507 m .52649 .34486 L .52677 .34486 L F
.52655 .34502 m .52624 .34496 L .5267 .34485 L F
.52655 .34502 m .52624 .34496 L .52655 .34502 L F
.52618 .34495 m .5262 .34497 L .52621 .34495 L F
.5262 .34497 m .52618 .34495 L .52624 .34496 L F
.52623 .345 m .5262 .34497 L .52628 .34498 L F
.52623 .345 m .52628 .34498 L .52655 .34502 L F
.52639 .3452 m .52623 .345 L .52655 .34502 L F
.52656 .34507 m .52596 .34495 L .52618 .34495 L F
.52656 .34507 m .52618 .34495 L .52655 .34502 L F
.52636 .34517 m .52623 .345 L .52656 .34507 L F
.52661 .34521 m .52656 .34507 L .53192 .34616 L F
.52636 .34517 m .52656 .34507 L .52661 .34521 L F
.53146 .34612 m .53192 .34616 L .53437 .34666 L F
.52636 .34517 m .53192 .34616 L .53146 .34612 L F
.52685 .34513 m .52656 .34507 L .5266 .34503 L F
.52683 .34508 m .5266 .34503 L .52677 .34486 L F
.52685 .34513 m .5266 .34503 L .52683 .34508 L F
.52684 .34507 m .52656 .34502 L .52694 .34488 L F
.52656 .34502 m .52655 .34502 L .52694 .34488 L F
.52655 .34502 m .5267 .34485 L .52694 .34488 L F
.53264 .34653 m .52639 .3452 L p .53437 .34666 L F P
0 g
s
.52627 .34543 m .52623 .34538 L .52628 .34533 L .672 .728 .891 r
F
.52637 .34518 m .52627 .34543 L .52629 .34508 L F
.52431 .34921 m .52639 .3452 L .52635 .34515 L F
.52639 .3452 m .52629 .34515 L .52636 .34517 L F
.52639 .3452 m .52636 .34517 L .53437 .34666 L F
.52536 .34769 m .52639 .3452 L p .52431 .34921 L F P
0 g
s
.54433 .34902 m .53264 .34653 L p .53437 .34666 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .54433 .34902 L p .52636 .34481 L .672 .728 .891 r
F P
0 g
s
.5261 .34484 m .52614 .3449 L .52635 .34463 L .672 .728 .891 r
F
.5261 .34484 m .52635 .34463 L .52634 .34455 L F
.52575 .3454 m .52567 .34558 L .52566 .34535 L F
.52576 .34523 m .52579 .34584 L .5252 .34676 L F
.52432 .34919 m .52432 .34919 L .52607 .3452 L F
.52579 .34584 m .52537 .3468 L .5252 .34676 L F
.52564 .34555 m .52431 .34921 L .52604 .3457 L F
.52468 .34751 m .52607 .3452 L .52618 .34495 L F
.52613 .34489 m .52618 .34495 L .5265 .34422 L F
.52599 .34514 m .50806 .34216 L p .52617 .34496 L F P
0 g
s
.52584 .34529 m .52609 .3452 L .52599 .34513 L .672 .728 .891 r
F
.52584 .34529 m .52599 .34538 L .52607 .34521 L F
.52564 .34555 m .52588 .34564 L .52594 .34551 L F
.52564 .34555 m .52614 .34548 L .52584 .34529 L F
.52468 .34751 m .52618 .34495 L .52613 .34489 L F
.52311 .34433 m .52297 .3443 L .52602 .34474 L F
.52634 .34458 m .52618 .34495 L .52639 .34457 L F
.52584 .34529 m .52666 .34443 L .52644 .3445 L F
.52602 .34474 m .52602 .34474 L .52671 .34484 L F
.52517 .34474 m .52486 .34468 L .52508 .34446 L F
.52311 .34433 m .52602 .34474 L .52602 .34474 L F
.52634 .3448 m .52603 .34475 L .52634 .34479 L F
.52596 .34467 m .5261 .34484 L .52636 .34453 L F
.52599 .3447 m .52613 .34489 L .52629 .3446 L F
.52671 .34484 m .52593 .34473 L .52599 .3447 L F
.52599 .3447 m .52601 .34473 L .52636 .34481 L F
.52635 .34515 m .52639 .3452 L .52638 .34508 L F
.52649 .34486 m .52649 .34484 L .52677 .34486 L F
.52624 .34496 m .5262 .34493 L .5267 .34485 L F
.5262 .34493 m .52603 .34475 L .52634 .3448 L F
.5262 .34493 m .52634 .3448 L .5267 .34485 L F
.5267 .34485 m .52634 .3448 L .52671 .34484 L F
.52671 .34484 m .52636 .34477 L .5267 .34487 L F
.52636 .34477 m .52599 .3447 L .52636 .34479 L F
.52634 .3448 m .52634 .34479 L .52671 .34484 L F
.52636 .34477 m .52636 .34479 L .5267 .34487 L F
.52618 .34494 m .52618 .34495 L .52636 .34476 L F
.52636 .34475 m .52636 .34476 L .52666 .34443 L F
.52618 .34494 m .52636 .34476 L .52636 .34475 L F
.52618 .34495 m .52632 .34512 L .52663 .3445 L F
.52618 .34495 m .52663 .3445 L .52666 .34443 L F
.52618 .34495 m .52603 .34475 L .52624 .34496 L F
.52601 .34473 m .52639 .3452 L .52636 .34481 L F
.52618 .34495 m .52564 .34484 L .52603 .34475 L F
.52486 .34468 m .52567 .34484 L .52565 .34475 L F
.5255 .34477 m .52517 .34474 L .52512 .34458 L F
.52564 .34484 m .52311 .34433 L .52591 .34473 L F
.52564 .34484 m .52591 .34473 L .52603 .34475 L F
.52618 .34495 m .5262 .34511 L .52599 .3447 L F
.52599 .3447 m .52587 .34495 L .52613 .34489 L F
.52576 .34523 m .52564 .34555 L .52584 .34529 L F
.52587 .34495 m .52468 .34751 L .5261 .34495 L F
.52587 .34495 m .5261 .34495 L .52613 .34489 L F
.52609 .3452 m .52632 .34512 L .52599 .34513 L F
.52607 .34521 m .52614 .34548 L .52632 .34512 L F
.5262 .34511 m .52624 .34555 L .52587 .34495 L F
.52524 .34496 m .52623 .345 L .52636 .34517 L F
.52523 .34496 m .52525 .34496 L .52524 .34496 L F
.52525 .34496 m .52623 .345 L .52524 .34496 L F
.52595 .34471 m .52639 .3452 L .52601 .34473 L F
.52639 .3452 m .5262 .34511 L .52618 .34495 L F
.52603 .34475 m .52602 .34474 L .52671 .34484 L F
.52599 .3447 m .52636 .34481 L .52636 .34479 L F
.52639 .3452 m .52618 .34495 L .52613 .3444 L F
.52615 .34464 m .52618 .34495 L .52599 .3447 L F
.52599 .3447 m .5262 .34511 L .52587 .34495 L F
.52599 .3447 m .52595 .34471 L .52601 .34473 L F
.52636 .34479 m .52636 .34481 L .54433 .34902 L F
.52637 .34501 m .52671 .34442 L .52663 .3445 L F
.52623 .34538 m .52619 .34535 L .52628 .34533 L F
.52431 .34921 m .52638 .34508 L .52637 .34501 L F
.52638 .34508 m .52671 .34442 L .52637 .34501 L F
.52639 .3452 m .52671 .34442 L p .52638 .34508 L F P
0 g
s
.52671 .34442 m .52695 .34385 L p .52663 .3445 L .672 .728 .891 r
F P
0 g
s
.52603 .34475 m .52311 .34433 L .52602 .34474 L .672 .728 .891 r
F
.52596 .34467 m .52636 .34453 L .52655 .34431 L F
.52599 .3447 m .52629 .3446 L .5265 .34422 L F
.52596 .34495 m .52549 .34485 L .52589 .34489 L F
.52589 .34489 m .52549 .34485 L .52572 .34485 L F
.52523 .34496 m .52549 .34485 L .52596 .34495 L F
.52525 .34496 m .52596 .34495 L .52623 .345 L F
.52523 .34496 m .52596 .34495 L .52525 .34496 L F
.52639 .3452 m .52523 .34496 L p .52629 .34515 L F P
0 g
s
.52524 .34496 m .52639 .3452 L p .52595 .34471 L .672 .728 .891 r
F P
0 g
s
.52634 .34455 m .52635 .34463 L .52695 .34385 L .672 .728 .891 r
F
.52599 .3447 m .52297 .3443 L .50838 .34137 L F
.5255 .34477 m .52512 .34458 L .52508 .34446 L F
.52593 .34473 m .52297 .3443 L .52599 .3447 L F
.52644 .3445 m .52666 .34443 L .52695 .34385 L F
.52671 .34441 m .52671 .34442 L p .52613 .3444 L F P
0 g
s
.52671 .34442 m .52639 .3452 L p .5262 .34462 L .672 .728 .891 r
F P
0 g
s
.52671 .34442 m .5262 .34462 L .52613 .3444 L .672 .728 .891 r
F
.52639 .3452 m .52624 .34555 L p .5262 .34511 L F P
0 g
s
.52517 .34474 m .52483 .34472 L .52486 .34468 L .672 .728 .891 r
F
.52613 .3444 m .52615 .34464 L .52599 .3447 L F
.52557 .34487 m .50806 .34216 L .52562 .34485 L F
.52523 .34496 m .50838 .34137 L p .52549 .34485 L F P
0 g
s
.52523 .34496 m .52524 .34496 L p .52553 .34462 L .672 .728 .891 r
F P
0 g
s
.52553 .34462 m .52524 .34496 L .52595 .34471 L .672 .728 .891 r
F
.52694 .34488 m .5267 .34485 L .52671 .34484 L F
.53431 .34652 m .53248 .34621 L p .53272 .34598 L F P
0 g
s
.53248 .34621 m .53108 .34578 L .53272 .34598 L .672 .728 .891 r
F
.535 .34663 m .54466 .34823 L p .53101 .34545 L F P
0 g
s
.54466 .34823 m .53431 .34652 L p .53272 .34598 L .672 .728 .891 r
F P
0 g
s
.54433 .34902 m .54466 .34823 L p .52671 .34484 L .672 .728 .891 r
F P
0 g
s
.52671 .34484 m .5267 .34487 L .54433 .34902 L .672 .728 .891 r
F
.52599 .3447 m .52553 .34462 L .52595 .34471 L F
.52549 .34485 m .52483 .34472 L .52568 .34478 L F
.50838 .34137 m .52523 .34496 L p .52553 .34462 L F P
0 g
s
.52599 .34538 m .52614 .34548 L .52607 .34521 L .672 .728 .891 r
F
.52587 .34495 m .52624 .34555 L .52569 .34534 L F
.52665 .34389 m .52655 .3441 L .52695 .34385 L F
.52605 .34443 m .52655 .34431 L .52695 .34385 L F
.5315 .33287 m .52671 .34441 L p .52613 .3444 L F P
0 g
s
.52466 .34436 m .52155 .34362 L .52418 .34435 L .672 .728 .891 r
F
.52594 .34551 m .52604 .3457 L .52614 .34548 L F
.52588 .34564 m .52604 .3457 L .52594 .34551 L F
.52459 .34792 m .52432 .34919 L .52607 .3452 L F
.52389 .3492 m .52432 .34919 L .52459 .34792 L F
.52253 .3575 m .52251 .35757 L p .52256 .35735 L F P
0 g
s
.50838 .34137 m .50877 .3406 L p .52508 .34446 L .672 .728 .891 r
F P
0 g
s
.52468 .34751 m .52389 .3492 L .52459 .34792 L .672 .728 .891 r
F
.52019 .35714 m .52369 .35039 L p .52389 .3492 L F P
0 g
s
.52134 .35738 m .52019 .35714 L p .52569 .34534 L .672 .728 .891 r
F P
0 g
s
.52251 .35757 m .52134 .35738 L p .52432 .34919 L .672 .728 .891 r
F P
0 g
s
.52256 .35735 m .52251 .35757 L .52432 .34919 L .672 .728 .891 r
F
.52134 .35738 m .52536 .34769 L p .52431 .34921 L F P
0 g
s
.52624 .34555 m .52134 .35738 L p .52569 .34534 L .672 .728 .891 r
F P
0 g
s
.54381 .34975 m .54392 .34978 L p .54377 .34974 L .672 .728 .891 r
F P
0 g
s
.52727 .34141 m .52723 .34145 L .52742 .34066 L .672 .728 .891 r
F
.5345 .33424 m .53455 .33419 L .53489 .33376 L F
.52882 .34133 m .53379 .33341 L p .52812 .34192 L F P
0 g
s
.54392 .34978 m .54392 .34978 L p .54389 .34977 L .672 .728 .891 r
F P
0 g
s
.52019 .35714 m .51907 .35685 L p .5192 .35663 L .672 .728 .891 r
F P
0 g
s
.52098 .34473 m .52088 .3447 L .5234 .34485 L .672 .728 .891 r
F
.52098 .34473 m .5234 .34485 L .52336 .34486 L F
.52088 .3447 m .52084 .34469 L .52093 .34469 L F
.53032 .33267 m .52797 .34015 L p .52742 .34066 L F P
0 g
s
.5315 .33287 m .53032 .33267 L p .52622 .34395 L .672 .728 .891 r
F P
0 g
s
.52595 .3442 m .52588 .34457 L .52638 .3434 L .672 .728 .891 r
F
.52366 .34499 m .52359 .34491 L .52454 .34497 L F
.52366 .34499 m .52454 .34497 L .52442 .34502 L F
.52614 .346 m .52585 .34692 L p .52608 .346 L F P
0 g
s
.53494 .33377 m .53489 .33376 L p .53472 .33397 L .672 .728 .891 r
F P
0 g
s
.53314 .34556 m .53242 .34551 L .53308 .34545 L .672 .728 .891 r
F
.53242 .34551 m .53152 .34537 L .53308 .34545 L F
.52361 .34498 m .52513 .3451 L .52513 .3451 L F
.52514 .34511 m .52366 .34499 L p .52519 .34508 L F P
0 g
s
.50877 .3406 m .50923 .33984 L p .52563 .34454 L .672 .728 .891 r
F P
0 g
s
.52632 .34553 m .52609 .34658 L p .52623 .34555 L .672 .728 .891 r
F P
0 g
s
.54466 .34823 m .54492 .34744 L p .53101 .34545 L .672 .728 .891 r
F P
0 g
s
.50977 .33911 m .51028 .3393 L p .51035 .33932 L .672 .728 .891 r
F P
0 g
s
.51907 .35685 m .51798 .35651 L p .52513 .34607 L .672 .728 .891 r
F P
0 g
s
.53274 .33853 m .53276 .33853 L .53688 .33469 L .672 .728 .891 r
F
.50923 .33984 m .50977 .33911 L p .52539 .34441 L F P
0 g
s
.53012 .34516 m .52733 .34488 L .53217 .34576 L .672 .728 .891 r
F
.53647 .34578 m .53314 .34556 L .53308 .34545 L F
.539 .34617 m .5451 .34663 L p .53859 .34546 L F P
0 g
s
.5451 .34663 m .53651 .34598 L p .53647 .34578 L .672 .728 .891 r
F P
0 g
s
.54492 .34744 m .5451 .34663 L p .53012 .34516 L .672 .728 .891 r
F P
0 g
s
.52671 .34483 m .52792 .34343 L p .52664 .34467 L .672 .728 .891 r
F P
0 g
s
.5261 .34655 m .52619 .34688 L .52602 .34689 L .672 .728 .891 r
F
.53032 .33267 m .52912 .33252 L p .5263 .34322 L F P
0 g
s
.52436 .34688 m .52458 .34673 L .5246 .34669 L .672 .728 .891 r
F
.52912 .33252 m .52792 .33243 L p .52595 .3442 L F P
0 g
s
.52589 .34372 m .5259 .34447 L .52584 .34443 L .672 .728 .891 r
F
.52583 .34451 m .52451 .34417 L .52482 .34411 L F
.51692 .35612 m .51591 .35569 L p .52534 .34556 L F P
0 g
s
.52538 .3456 m .51692 .35612 L .52534 .34556 L .672 .728 .891 r
F
.52251 .35757 m .52251 .35757 L p .52251 .35755 L F P
0 g
s
.52098 .34473 m .51454 .3443 L .52084 .34469 L .672 .728 .891 r
F
.52433 .34691 m .52441 .34691 L .52436 .34688 L F
.51798 .35651 m .51692 .35612 L p .5249 .34619 L F P
0 g
s
.52792 .33243 m .5267 .33239 L p .52583 .34451 L .672 .728 .891 r
F P
0 g
s
.52511 .34569 m .52429 .34683 L .52411 .34663 L .672 .728 .891 r
F
.50977 .33911 m .51038 .3384 L p .52482 .34411 L F P
0 g
s
.52459 .34522 m .52449 .34515 L .52506 .34513 L .672 .728 .891 r
F
.52366 .34499 m .51454 .3443 L p .52359 .34491 L F P
0 g
s
.52556 .34329 m .52576 .34419 L .52569 .34439 L .672 .728 .891 r
F
.52548 .34268 m .5256 .34327 L .52556 .34329 L F
.52459 .34522 m .52171 .34525 L p .52449 .34515 L F P
0 g
s
.52646 .34562 m .52646 .34562 L .52646 .34562 L .672 .728 .891 r
F
.5256 .34367 m .52568 .34431 L .52578 .34355 L F
.5256 .34367 m .52578 .34355 L .52575 .34353 L F
.52693 .34473 m .52801 .34378 L p .52699 .34456 L F P
0 g
s
.52699 .34456 m .52801 .34378 L .52701 .34452 L .672 .728 .891 r
F
.5271 .3443 m .52801 .34378 L .52815 .34342 L F
.52527 .34548 m .52523 .34557 L .52517 .34556 L F
.5212 .34551 m .52302 .34541 L .52299 .34538 L F
.5265 .34564 m .52645 .34557 L .52646 .34558 L F
.52907 .34459 m .52756 .34478 L .52784 .34468 L F
.52801 .34378 m .53512 .33756 L p .52815 .34342 L F P
0 g
s
.52888 .3446 m .52754 .3447 L .52959 .34478 L .672 .728 .891 r
F
.5267 .33239 m .52548 .3324 L p .5257 .34171 L F P
0 g
s
.52682 .34547 m .52687 .34551 L p .52682 .34545 L .672 .728 .891 r
F P
0 g
s
.52556 .34452 m .52552 .34389 L .52548 .3439 L .672 .728 .891 r
F
.52538 .34394 m .52548 .3439 L .52541 .34338 L F
.52467 .34537 m .5258 .34526 L p .52464 .34533 L F P
0 g
s
.52656 .34567 m .52652 .34557 L p .52646 .34562 L .672 .728 .891 r
F P
0 g
s
.52649 .34559 m .5265 .34564 L p .52646 .34558 L .672 .728 .891 r
F P
0 g
s
.52557 .34528 m .52301 .34553 L p .52529 .34523 L .672 .728 .891 r
F P
0 g
s
.52453 .34547 m .52465 .34543 L .52465 .34544 L .672 .728 .891 r
F
.5252 .34539 m .5244 .3459 L .52516 .34547 L F
.5256 .34531 m .52453 .34547 L p .52535 .34527 L F P
0 g
s
.5276 .3478 m .52783 .34829 L p .52753 .34778 L .672 .728 .891 r
F P
0 g
s
.52783 .34829 m .53199 .35727 L p .52759 .3483 L .672 .728 .891 r
F P
0 g
s
.52363 .34571 m .5247 .34551 L .5247 .34551 L .672 .728 .891 r
F
.52328 .34578 m .52363 .34571 L .52363 .34571 L F
.52414 .34606 m .52412 .34608 L .52414 .34607 L F
.52387 .34316 m .5225 .34235 L .52397 .34327 L F
.5225 .34235 m .51258 .33645 L .52397 .34327 L F
.51591 .35569 m .51493 .35522 L p .52048 .35003 L F P
0 g
s
.5252 .34249 m .52544 .34364 L .52556 .34194 L .672 .728 .891 r
F
.52515 .34229 m .5252 .34249 L .52551 .34152 L F
.52188 .33276 m .5247 .34054 L p .52436 .34069 L F P
0 g
s
.52526 .34356 m .52539 .34327 L .52307 .33259 L .672 .728 .891 r
F
.52515 .34229 m .52551 .34152 L .52427 .33247 L F
.52548 .3324 m .52427 .33247 L p .5256 .34367 L F P
0 g
s
.52517 .34556 m .52136 .34926 L .52129 .34874 L .672 .728 .891 r
F
.51493 .35522 m .514 .35471 L p .52129 .34874 L F P
0 g
s
.5244 .3459 m .52412 .34608 L .52442 .34591 L .672 .728 .891 r
F
.52771 .34442 m .52786 .34432 L p .52771 .34442 L F P
0 g
s
.52751 .34441 m .5288 .34372 L .5275 .34441 L .672 .728 .891 r
F
.52544 .34364 m .52555 .34416 L .52564 .34374 L F
.52328 .34578 m .52364 .34571 L .52364 .34571 L F
.52364 .34571 m .52583 .34526 L .52364 .34571 L F
.54523 .345 m .54518 .34419 L p .53563 .34449 L F P
0 g
s
.54521 .34582 m .54523 .345 L p .53732 .34491 L .672 .728 .891 r
F P
0 g
s
.5451 .34663 m .54521 .34582 L p .53859 .34546 L .672 .728 .891 r
F P
0 g
s
.52792 .34421 m .52803 .34417 L .5288 .34372 L .672 .728 .891 r
F
.52972 .34454 m .52888 .3446 L .52959 .34478 L F
.52766 .34435 m .52773 .34429 L p .52764 .34435 L F P
0 g
s
.52773 .34429 m .53978 .33616 L p .52777 .34412 L .672 .728 .891 r
F P
0 g
s
.53088 .3427 m .53104 .34266 L .53219 .34207 L .672 .728 .891 r
F
.53183 .34215 m .53219 .34207 L .54138 .3374 L F
.52658 .34573 m .52656 .34577 L .52635 .34522 L F
.52727 .3456 m .52826 .34655 L .52861 .34663 L F
.52125 .34213 m .52044 .34169 L .5216 .34219 L F
.52044 .342 m .52044 .34169 L .52125 .34213 L F
.52044 .342 m .51105 .33772 L .52044 .34169 L F
.52497 .34381 m .52401 .34361 L .52487 .34375 L F
.52821 .34391 m .5288 .34372 L .52879 .34357 L F
.52841 .34392 m .5288 .34372 L .52821 .34391 L F
.52509 .34359 m .525 .34352 L .52501 .34352 L F
.5251 .34359 m .525 .34352 L .52509 .34359 L F
.52658 .34573 m .52704 .34699 L p .52656 .34577 L F P
0 g
s
.52706 .34557 m .52706 .34557 L .52826 .34655 L .672 .728 .891 r
F
.52671 .34542 m .52669 .34545 L .52699 .34577 L F
.52672 .34547 m .52675 .3455 L p .52673 .34545 L F P
0 g
s
.53141 .34441 m .53132 .34442 L .53155 .34445 L .672 .728 .891 r
F
.53132 .34442 m .52972 .34454 L .53155 .34445 L F
.54518 .34419 m .54506 .34337 L p .53141 .34441 L F P
0 g
s
.52526 .34356 m .52527 .3436 L .52539 .34327 L .672 .728 .891 r
F
.52527 .3436 m .52541 .34338 L .52539 .34327 L F
.5229 .34593 m .52395 .34563 L .52395 .34563 L F
.52178 .34625 m .5229 .34593 L .5229 .34593 L F
.51038 .3384 m .51105 .33772 L p .51945 .34155 L F P
0 g
s
.51179 .33707 m .51258 .33645 L p .52487 .34375 L .672 .728 .891 r
F P
0 g
s
.54506 .34337 m .54485 .34257 L p .52881 .3445 L .672 .728 .891 r
F P
0 g
s
.51363 .3476 m .51359 .34761 L .52425 .34555 L .672 .728 .891 r
F
.52425 .34555 m .52425 .34555 L .52573 .34527 L F
.51363 .3476 m .52425 .34555 L .52425 .34555 L F
.52467 .34551 m .52462 .34548 L .524 .34558 L F
.51265 .34779 m .52253 .34588 L .52252 .34589 L F
.52253 .34588 m .52572 .34527 L .52252 .34589 L F
.5239 .34571 m .52178 .34625 L .52395 .34563 L F
.51267 .34778 m .52328 .34578 L .52328 .34578 L F
.52448 .34555 m .52316 .3458 L .52445 .34555 L F
.52328 .34578 m .52413 .3456 L .52411 .34561 L F
.52413 .3456 m .52573 .34527 L .52411 .34561 L F
.52328 .34578 m .52323 .34575 L .52425 .34556 L F
.52413 .3456 m .52425 .34556 L .52573 .34527 L F
.52178 .34625 m .52396 .34561 L .52395 .34563 L F
.52328 .34578 m .52425 .34556 L .52413 .3456 L F
.51312 .35415 m .52018 .34939 L p .51876 .3501 L F P
0 g
s
.51105 .33772 m .51179 .33707 L p .5216 .34219 L .672 .728 .891 r
F P
0 g
s
.54088 .33764 m .53514 .34109 L .54208 .33806 L .672 .728 .891 r
F
.52894 .34387 m .54138 .3374 L p .52807 .34417 L F P
0 g
s
.52879 .34357 m .5288 .34372 L .54061 .33676 L .672 .728 .891 r
F
.52316 .3458 m .52323 .34575 L .52328 .34578 L F
.52427 .33247 m .52307 .33259 L p .52515 .34229 L F P
0 g
s
.52031 .34663 m .51938 .34685 L p .52037 .34661 L .672 .728 .891 r
F P
0 g
s
.52031 .34663 m .52037 .34661 L .52568 .34528 L .672 .728 .891 r
F
.5245 .34556 m .52448 .34555 L .52582 .3453 L F
.52301 .34553 m .50775 .34702 L p .52257 .34539 L F P
0 g
s
.52073 .34822 m .51503 .35183 L .52245 .34746 L .672 .728 .891 r
F
.514 .35471 m .51312 .35415 L p .52525 .34542 L F P
0 g
s
.53512 .33756 m .53797 .33507 L p .53687 .3347 L .672 .728 .891 r
F P
0 g
s
.53688 .33469 m .53699 .33459 L .53694 .33457 L p .672 .728 .891 r
F P
0 g
s
.53694 .33457 m .53596 .33415 L p .53688 .33469 L .672 .728 .891 r
F P
0 g
s
.5245 .34556 m .51267 .34778 L p .52448 .34555 L .672 .728 .891 r
F P
0 g
s
.52044 .34883 m .51273 .35388 L .5205 .3487 L .672 .728 .891 r
F
.52887 .34699 m .52842 .34667 L p .52839 .34648 L F P
0 g
s
.52688 .34607 m .52638 .34519 L .52687 .34607 L .672 .728 .891 r
F
.52652 .34549 m .52676 .34585 L .52648 .34548 L F
.52657 .34551 m .52676 .34585 L p .52654 .34551 L F P
0 g
s
.52179 .34625 m .52183 .34623 L .52565 .34527 L .672 .728 .891 r
F
.52179 .34625 m .52565 .34527 L .52565 .34527 L F
.52316 .3458 m .51363 .3476 L .52301 .34579 L F
.52786 .34432 m .54061 .33676 L p .52789 .34425 L F P
0 g
s
.51503 .35183 m .51676 .35091 L .51611 .3512 L .672 .728 .891 r
F
.52389 .34573 m .52179 .34625 L .52389 .34572 L F
.52179 .34625 m .51938 .34685 L .52183 .34623 L F
.5241 .34598 m .5232 .34629 L .52331 .3462 L F
.52408 .3461 m .52397 .34625 L .52403 .34613 L F
.5252 .34539 m .52397 .34625 L .52408 .3461 L F
.5252 .34539 m .52387 .34646 L .52397 .34625 L F
.52403 .34613 m .5205 .3487 L .52073 .34822 L F
.52387 .34646 m .5205 .3487 L .52403 .34613 L F
.52501 .34352 m .525 .34352 L .52501 .34352 L F
.52307 .33259 m .52188 .33276 L p .52526 .34356 L F P
0 g
s
.52458 .34295 m .52494 .3434 L .52474 .3429 L .672 .728 .891 r
F
.52458 .34295 m .52474 .3429 L .52413 .34141 L F
.52248 .33889 m .52344 .34075 L .52262 .33768 L F
.52344 .34075 m .52413 .34141 L .52262 .33768 L F
.51258 .33645 m .51344 .33587 L p .52335 .34257 L F P
0 g
s
.51344 .33587 m .51435 .33532 L p .52501 .34352 L .672 .728 .891 r
F P
0 g
s
.52826 .34655 m .53164 .34899 L p .52861 .34663 L .672 .728 .891 r
F P
0 g
s
.52178 .34625 m .52033 .34661 L .5217 .34624 L .672 .728 .891 r
F
.51265 .34779 m .51252 .3478 L .52541 .34532 L F
.51265 .34779 m .52541 .34532 L .52542 .34533 L F
.52188 .33276 m .52071 .33298 L p .52506 .3435 L F P
0 g
s
.52033 .34661 m .51938 .34685 L .52021 .34663 L .672 .728 .891 r
F
.52073 .34822 m .51273 .35388 L .51503 .35183 L F
.5205 .3487 m .51273 .35388 L .52073 .34822 L F
.51435 .33532 m .51531 .33482 L p .52458 .34295 L F P
0 g
s
.52461 .34298 m .52328 .34181 L .5245 .34284 L .672 .728 .891 r
F
.53879 .34286 m .54014 .34261 L p .53873 .34287 L F P
0 g
s
.54014 .34261 m .54457 .34177 L p .53999 .34262 L .672 .728 .891 r
F P
0 g
s
.54368 .34194 m .53879 .34286 L p .54395 .34188 L .672 .728 .891 r
F P
0 g
s
.53879 .34286 m .5389 .34283 L .54395 .34188 L .672 .728 .891 r
F
.54395 .34188 m .5389 .34283 L .53976 .34257 L F
.54457 .34177 m .54368 .34194 L p .54395 .34188 L F P
0 g
s
.54485 .34257 m .54457 .34177 L p .53148 .34394 L .672 .728 .891 r
F P
0 g
s
.52303 .3416 m .51531 .33482 L .52309 .34158 L .672 .728 .891 r
F
.51844 .33357 m .52372 .34133 L .52339 .34146 L F
.52071 .33298 m .51956 .33325 L p .52248 .33889 L F P
0 g
s
.52248 .33889 m .52262 .33768 L .52071 .33298 L .672 .728 .891 r
F
.52659 .34542 m .527 .34586 L p .5266 .34541 L F P
0 g
s
.527 .34586 m .53635 .35592 L p .52702 .34584 L .672 .728 .891 r
F P
0 g
s
.52639 .3452 m .52655 .34544 L p .52652 .34544 L .672 .728 .891 r
F P
0 g
s
.52439 .3427 m .52309 .34158 L .52339 .34146 L .672 .728 .891 r
F
.51844 .33357 m .52374 .34132 L p .52372 .34133 L F P
0 g
s
.5237 .34135 m .52376 .34133 L .51956 .33325 L .672 .728 .891 r
F
.52339 .34146 m .52314 .34125 L .51631 .33436 L F
.52314 .34125 m .51531 .33482 L .51631 .33436 L F
.52309 .34158 m .51531 .33482 L .52339 .34146 L F
.51363 .3476 m .51265 .34779 L .51359 .34761 L F
.51844 .33357 m .51763 .33385 L p .52099 .33848 L F P
0 g
s
.51956 .33325 m .51844 .33357 L p .52339 .34146 L .672 .728 .891 r
F P
0 g
s
.52339 .34146 m .52439 .34271 L .51956 .33325 L .672 .728 .891 r
F
.5171 .33405 m .51736 .33394 L p .51964 .33678 L F P
0 g
s
.52038 .33771 m .52099 .33848 L .51763 .33385 L .672 .728 .891 r
F
.52029 .3376 m .52038 .33771 L .51763 .33385 L F
.51964 .33678 m .52029 .3376 L .51763 .33385 L F
.51631 .33436 m .5171 .33405 L p .52099 .33848 L F P
0 g
s
.51265 .34779 m .50827 .34861 L .51252 .3478 L .672 .728 .891 r
F
.51267 .34778 m .50827 .34861 L p .51265 .34779 L F P
0 g
s
.50827 .34861 m .50811 .34819 L p .51252 .3478 L .672 .728 .891 r
F P
0 g
s
.50811 .34819 m .50797 .34782 L p .51252 .3478 L .672 .728 .891 r
F P
0 g
s
.5177 .34768 m .50908 .35015 L p .51487 .3482 L .672 .728 .891 r
F P
0 g
s
.54422 .34099 m .54379 .34023 L p .53031 .34374 L .672 .728 .891 r
F P
0 g
s
.54457 .34177 m .54422 .34099 L p .53488 .34297 L .672 .728 .891 r
F P
0 g
s
.52672 .34562 m .52704 .34601 L p .52665 .34564 L .672 .728 .891 r
F P
0 g
s
.52704 .34601 m .5274 .34647 L p .52697 .34603 L .672 .728 .891 r
F P
0 g
s
.51229 .35356 m .51571 .35153 L p .51503 .35183 L .672 .728 .891 r
F P
0 g
s
.53531 .35633 m .53504 .35642 L p .53007 .35022 L .672 .728 .891 r
F P
0 g
s
.53504 .35642 m .53424 .35669 L p .53007 .35022 L .672 .728 .891 r
F P
0 g
s
.51152 .35294 m .51081 .35228 L p .52244 .34662 L .672 .728 .891 r
F P
0 g
s
.51229 .35356 m .51152 .35294 L p .519 .34878 L .672 .728 .891 r
F P
0 g
s
.51273 .35388 m .51229 .35356 L p .51503 .35183 L .672 .728 .891 r
F P
0 g
s
.46539 .42267 m .48482 .38353 L .48699 .38526 L p .844 .708 .713 r
F P
0 g
s
.48699 .38526 m .46864 .42521 L .46539 .42267 L p .844 .708 .713 r
F P
0 g
s
.51229 .35356 m .48699 .38526 L .48482 .38353 L p .789 .73 .798 r
F P
0 g
s
.48699 .38526 m .51229 .35356 L .51312 .35415 L p .783 .721 .793 r
F P
0 g
s
.47179 .47414 m .47966 .43202 L .4837 .43396 L p .813 .608 .626 r
F P
0 g
s
.4837 .43396 m .47663 .47656 L .47179 .47414 L p .813 .608 .626 r
F P
0 g
s
.53606 .68615 m .53517 .65696 L .54864 .66245 L p .866 .706 .682 r
F P
0 g
s
.54536 .63142 m .54864 .66245 L .53517 .65696 L p .853 .753 .752 r
F P
0 g
s
.54864 .66245 m .54536 .63142 L .55832 .63402 L p .832 .732 .754 r
F P
0 g
s
.57119 .4326 m .57918 .47406 L .58373 .47202 L p .544 .399 .635 r
F P
0 g
s
.58373 .47202 m .57511 .43073 L .57119 .4326 L p .544 .399 .635 r
F P
0 g
s
.56685 .38447 m .54086 .35327 L .54007 .35387 L p .599 .573 .796 r
F P
0 g
s
.54086 .35327 m .56685 .38447 L .56894 .38273 L p .59 .57 .8 r
F P
0 g
s
.56685 .38447 m .58564 .42428 L .58869 .42187 L p .517 .445 .714 r
F P
0 g
s
.58869 .42187 m .56894 .38273 L .56685 .38447 L p .517 .445 .714 r
F P
0 g
s
.65104 .62091 m .62702 .59207 L .61955 .59596 L p .567 .642 .884 r
F P
0 g
s
.62702 .59207 m .65104 .62091 L .65754 .61489 L p .483 .613 .904 r
F P
0 g
s
.68102 .64821 m .65754 .61489 L .65104 .62091 L p .465 .54 .849 r
F P
0 g
s
.46239 .42002 m .48281 .38171 L .48482 .38353 L p .855 .724 .718 r
F P
0 g
s
.48482 .38353 m .46539 .42267 L .46239 .42002 L p .855 .724 .718 r
F P
0 g
s
.51152 .35294 m .48482 .38353 L .48281 .38171 L p .794 .74 .802 r
F P
0 g
s
.48482 .38353 m .51152 .35294 L .51229 .35356 L p .789 .73 .798 r
F P
0 g
s
.46712 .47152 m .47579 .4299 L .47966 .43202 L p .825 .622 .628 r
F P
0 g
s
.47966 .43202 m .47179 .47414 L .46712 .47152 L p .825 .622 .628 r
F P
0 g
s
.55243 .60596 m .55832 .63402 L .54536 .63142 L p .832 .774 .797 r
F P
0 g
s
.55832 .63402 m .55243 .60596 L .56383 .60613 L p .808 .754 .803 r
F P
0 g
s
.65754 .61489 m .68102 .64821 L .68529 .63943 L p .346 .491 .862 r
F P
0 g
s
.68102 .64821 m .69722 .68372 L .70194 .67274 L p .255 .338 .757 r
F P
0 g
s
.70194 .67274 m .68529 .63943 L .68102 .64821 L p .255 .338 .757 r
F P
0 g
s
.57511 .43073 m .58373 .47202 L .58802 .46987 L p .521 .383 .634 r
F P
0 g
s
.58802 .46987 m .57884 .42872 L .57511 .43073 L p .521 .383 .634 r
F P
0 g
s
.56894 .38273 m .54161 .35263 L .54086 .35327 L p .59 .57 .8 r
F P
0 g
s
.54161 .35263 m .56894 .38273 L .57086 .38089 L p .581 .568 .804 r
F P
0 g
s
.56894 .38273 m .58869 .42187 L .59149 .41932 L p .497 .435 .717 r
F P
0 g
s
.59149 .41932 m .57086 .38089 L .56894 .38273 L p .497 .435 .717 r
F P
0 g
s
.45965 .41727 m .48097 .37982 L .48281 .38171 L p .867 .742 .722 r
F P
0 g
s
.48281 .38171 m .46239 .42002 L .45965 .41727 L p .867 .742 .722 r
F P
0 g
s
.51081 .35228 m .48281 .38171 L .48097 .37982 L p .8 .75 .807 r
F P
0 g
s
.48281 .38171 m .51081 .35228 L .51152 .35294 L p .794 .74 .802 r
F P
0 g
s
.46266 .46871 m .47211 .42763 L .47579 .4299 L p .839 .637 .63 r
F P
0 g
s
.47579 .4299 m .46712 .47152 L .46266 .46871 L p .839 .637 .63 r
F P
0 g
s
.69722 .68372 m .702 .71521 L .70681 .70261 L p 0 0 .501 r
F P
0 g
s
.70681 .70261 m .70194 .67274 L .69722 .68372 L p 0 0 .501 r
F P
0 g
s
.57086 .38089 m .54228 .35195 L .54161 .35263 L p .581 .568 .804 r
F P
0 g
s
.54228 .35195 m .57086 .38089 L .57261 .37898 L p .571 .566 .809 r
F P
0 g
s
.57086 .38089 m .59149 .41932 L .59405 .41665 L p .476 .425 .721 r
F P
0 g
s
.59405 .41665 m .57261 .37898 L .57086 .38089 L p .476 .425 .721 r
F P
0 g
s
.57884 .42872 m .58802 .46987 L .59203 .4676 L p .497 .366 .632 r
F P
0 g
s
.59203 .4676 m .58235 .42657 L .57884 .42872 L p .497 .366 .632 r
F P
0 g
s
.5845 .57837 m .59953 .60221 L .58787 .6043 L p .724 .73 .855 r
F P
0 g
s
.59953 .60221 m .5845 .57837 L .59294 .57597 L p .684 .714 .872 r
F P
0 g
s
.59294 .57597 m .61025 .5994 L .59953 .60221 L p .684 .714 .872 r
F P
0 g
s
.6933 .72621 m .68576 .74816 L .69397 .73666 L p 0 0 0 r
F P
0 g
s
.69397 .73666 m .702 .71521 L .6933 .72621 L p 0 0 0 r
F P
0 g
s
.48097 .37982 m .51017 .3516 L .51081 .35228 L p .8 .75 .807 r
F P
0 g
s
.57538 .58045 m .58787 .6043 L .5758 .6056 L p .759 .746 .841 r
F P
0 g
s
.58787 .6043 m .57538 .58045 L .5845 .57837 L p .724 .73 .855 r
F P
0 g
s
.45719 .41443 m .47931 .37785 L .48097 .37982 L p .879 .76 .727 r
F P
0 g
s
.48097 .37982 m .45965 .41727 L .45719 .41443 L p .879 .76 .727 r
F P
0 g
s
.51017 .3516 m .48097 .37982 L .47931 .37785 L p .805 .76 .812 r
F P
0 g
s
.57261 .37898 m .5429 .35125 L .54228 .35195 L p .571 .566 .809 r
F P
0 g
s
.47931 .37785 m .50959 .35088 L .51017 .3516 L p .805 .76 .812 r
F P
0 g
s
.53077 .5222 m .53061 .48587 L .5363 .48531 L p .716 .485 .574 r
F P
0 g
s
.5363 .48531 m .53675 .52137 L .53077 .5222 L p .716 .485 .574 r
F P
0 g
s
.53675 .52137 m .5363 .48531 L .54199 .48452 L p .702 .477 .579 r
F P
0 g
s
.45844 .46576 m .46864 .42521 L .47211 .42763 L p .853 .654 .633 r
F P
0 g
s
.47211 .42763 m .46266 .46871 L .45844 .46576 L p .853 .654 .633 r
F P
0 g
s
.54199 .48452 m .5428 .5203 L .53675 .52137 L p .702 .477 .579 r
F P
0 g
s
.5428 .5203 m .54199 .48452 L .54765 .48351 L p .686 .467 .583 r
F P
0 g
s
.5429 .35125 m .57261 .37898 L .57417 .37699 L p .561 .564 .814 r
F P
0 g
s
.57417 .37699 m .54344 .35053 L .5429 .35125 L p .561 .564 .814 r
F P
0 g
s
.52488 .52277 m .52493 .4862 L .53061 .48587 L p .728 .491 .569 r
F P
0 g
s
.53061 .48587 m .53077 .5222 L .52488 .52277 L p .728 .491 .569 r
F P
0 g
s
.54765 .48351 m .54888 .51903 L .5428 .5203 L p .686 .467 .583 r
F P
0 g
s
.54888 .51903 m .54765 .48351 L .55325 .48232 L p .667 .454 .587 r
F P
0 g
s
.57261 .37898 m .59405 .41665 L .59634 .41385 L p .454 .414 .724 r
F P
0 g
s
.59634 .41385 m .57417 .37699 L .57261 .37898 L p .454 .414 .724 r
F P
0 g
s
.47785 .37582 m .50908 .35015 L .50959 .35088 L p .809 .771 .818 r
F P
0 g
s
.50959 .35088 m .47931 .37785 L .47785 .37582 L p .809 .771 .818 r
F P
0 g
s
.51909 .52304 m .51929 .48626 L .52493 .4862 L p .737 .496 .564 r
F P
0 g
s
.52493 .4862 m .52488 .52277 L .51909 .52304 L p .737 .496 .564 r
F P
0 g
s
.54344 .35053 m .57417 .37699 L .57554 .37493 L p .55 .562 .819 r
F P
0 g
s
.57554 .37493 m .54392 .34978 L .54344 .35053 L p .55 .562 .819 r
F P
0 g
s
.59294 .57597 m .61025 .5994 L .61955 .59596 L p .634 .696 .89 r
F P
0 g
s
.55325 .48232 m .55494 .51759 L .54888 .51903 L p .667 .454 .587 r
F P
0 g
s
.55494 .51759 m .55325 .48232 L .55875 .48096 L p .645 .439 .59 r
F P
0 g
s
.51339 .523 m .5137 .48604 L .51929 .48626 L p .745 .5 .56 r
F P
0 g
s
.51929 .48626 m .51909 .52304 L .51339 .523 L p .745 .5 .56 r
F P
0 g
s
.58235 .42657 m .59203 .4676 L .59574 .4652 L p .47 .347 .63 r
F P
0 g
s
.59574 .4652 m .58564 .42428 L .58235 .42657 L p .47 .347 .63 r
F P
0 g
s
.47658 .37373 m .50864 .34939 L .50908 .35015 L p .813 .782 .824 r
F P
0 g
s
.50908 .35015 m .47785 .37582 L .47658 .37373 L p .813 .782 .824 r
F P
0 g
s
.45501 .41153 m .47785 .37582 L .47931 .37785 L p .891 .78 .732 r
F P
0 g
s
.47931 .37785 m .45719 .41443 L .45501 .41153 L p .891 .78 .732 r
F P
0 g
s
.54392 .34978 m .57554 .37493 L .57671 .37281 L p .539 .561 .825 r
F P
0 g
s
.57671 .37281 m .54433 .34902 L .54392 .34978 L p .539 .561 .825 r
F P
0 g
s
.50777 .52262 m .50816 .48555 L .5137 .48604 L p .751 .503 .557 r
F P
0 g
s
.5137 .48604 m .51339 .523 L .50777 .52262 L p .751 .503 .557 r
F P
0 g
s
.47551 .37159 m .50827 .34861 L .50864 .34939 L p .817 .793 .83 r
F P
0 g
s
.50864 .34939 m .47658 .37373 L .47551 .37159 L p .817 .793 .83 r
F P
0 g
s
.55875 .48096 m .56091 .51601 L .55494 .51759 L p .645 .439 .59 r
F P
0 g
s
.56091 .51601 m .55875 .48096 L .56413 .47943 L p .62 .422 .592 r
F P
0 g
s
.56595 .58214 m .5758 .6056 L .56383 .60613 L p .79 .762 .827 r
F P
0 g
s
.5758 .6056 m .56595 .58214 L .57538 .58045 L p .759 .746 .841 r
F P
0 g
s
.45449 .46267 m .46539 .42267 L .46864 .42521 L p .869 .674 .635 r
F P
0 g
s
.46864 .42521 m .45844 .46576 L .45449 .46267 L p .869 .674 .635 r
F P
0 g
s
.54433 .34902 m .57671 .37281 L .57769 .37064 L p .528 .56 .832 r
F P
0 g
s
.57769 .37064 m .54466 .34823 L .54433 .34902 L p .528 .56 .832 r
F P
0 g
s
.57417 .37699 m .59634 .41385 L .59836 .41094 L p .429 .403 .729 r
F P
0 g
s
.59836 .41094 m .57554 .37493 L .57417 .37699 L p .429 .403 .729 r
F P
0 g
s
.50221 .52188 m .50269 .48476 L .50816 .48555 L p .757 .506 .554 r
F P
0 g
s
.50816 .48555 m .50777 .52262 L .50221 .52188 L p .757 .506 .554 r
F P
0 g
s
.47465 .36941 m .50797 .34782 L .50827 .34861 L p .82 .805 .837 r
F P
0 g
s
.50827 .34861 m .47551 .37159 L .47465 .36941 L p .82 .805 .837 r
F P
0 g
s
.60401 .762 m .62333 .76564 L p .59736 .76694 L .556 0 0 r
F P
0 g
s
.59611 .76661 m .60401 .762 L p .59736 .76694 L .556 0 0 r
F P
0 g
s
.62333 .76564 m .61254 .77127 L .59537 .76704 L p .556 0 0 r
F P
0 g
s
.58493 .75551 m .60401 .762 L p .58081 .76019 L .661 .119 0 r
F P
0 g
s
.5784 .76 m .57919 .75946 L p .58081 .76019 L .661 .119 0 r
F P
0 g
s
.57919 .75946 m .58493 .75551 L p .58081 .76019 L .661 .119 0 r
F P
0 g
s
.60401 .762 m .59537 .76704 L .5784 .76 L p .661 .119 0 r
F P
0 g
s
.56685 .74672 m .58493 .75551 L p .56488 .75124 L .724 .195 0 r
F P
0 g
s
.56233 .7507 m .56303 .75009 L p .56488 .75124 L .724 .195 0 r
F P
0 g
s
.56303 .75009 m .56685 .74672 L p .56488 .75124 L .724 .195 0 r
F P
0 g
s
.58493 .75551 m .5784 .76 L .56233 .7507 L p .724 .195 0 r
F P
0 g
s
.56685 .74672 m .56233 .7507 L .54768 .73986 L p .755 .238 0 r
F P
0 g
s
.56985 .7522 m .55647 .74338 L p .57606 .75823 L 0 .27 .708 r
F P
0 g
s
.5784 .76 m .57731 .75901 L p .57606 .75823 L 0 .27 .708 r
F P
0 g
s
.57731 .75901 m .56985 .7522 L p .57606 .75823 L 0 .27 .708 r
F P
0 g
s
.58395 .759 m .56985 .7522 L p .59318 .76577 L 0 .388 .77 r
F P
0 g
s
.59537 .76704 m .59424 .76625 L p .59318 .76577 L 0 .388 .77 r
F P
0 g
s
.59424 .76625 m .58395 .759 L p .59318 .76577 L 0 .388 .77 r
F P
0 g
s
.59821 .76324 m .58395 .759 L p .61074 .77049 L .017 .543 .856 r
F P
0 g
s
.61254 .77127 m .61154 .77071 L p .61074 .77049 L .017 .543 .856 r
F P
0 g
s
.61154 .77071 m .59821 .76324 L p .61074 .77049 L .017 .543 .856 r
F P
0 g
s
.59537 .76704 m .59611 .76661 L p .59736 .76694 L .556 0 0 r
F P
0 g
s
.61254 .77127 m .62333 .76564 L .64203 .7661 L p .387 0 0 r
F P
0 g
s
.54466 .34823 m .57769 .37064 L .57845 .36842 L p .517 .56 .838 r
F P
0 g
s
.57845 .36842 m .54492 .34744 L .54466 .34823 L p .517 .56 .838 r
F P
0 g
s
.56413 .47943 m .56674 .51431 L .56091 .51601 L p .62 .422 .592 r
F P
0 g
s
.56674 .51431 m .56413 .47943 L .56935 .47777 L p .591 .401 .592 r
F P
0 g
s
.53584 .7251 m .53631 .71043 L .55154 .7203 L p .9 .536 .341 r
F P
0 g
s
.55154 .7203 m .55036 .73631 L .53584 .7251 L p .9 .536 .341 r
F P
0 g
s
.45312 .40856 m .47658 .37373 L .47785 .37582 L p .902 .8 .737 r
F P
0 g
s
.47785 .37582 m .45501 .41153 L .45312 .40856 L p .902 .8 .737 r
F P
0 g
s
.474 .3672 m .50775 .34702 L .50797 .34782 L p .823 .817 .844 r
F P
0 g
s
.50797 .34782 m .47465 .36941 L .474 .3672 L p .823 .817 .844 r
F P
0 g
s
.49669 .52079 m .49729 .48368 L .50269 .48476 L p .762 .51 .553 r
F P
0 g
s
.50269 .48476 m .50221 .52188 L .49669 .52079 L p .762 .51 .553 r
F P
0 g
s
.58564 .42428 m .59574 .4652 L .59917 .46266 L p .44 .326 .627 r
F P
0 g
s
.59917 .46266 m .58869 .42187 L .58564 .42428 L p .44 .326 .627 r
F P
0 g
s
.54492 .34744 m .57845 .36842 L .579 .36617 L p .505 .56 .845 r
F P
0 g
s
.579 .36617 m .5451 .34663 L .54492 .34744 L p .505 .56 .845 r
F P
0 g
s
.64203 .7661 m .62915 .77231 L .61254 .77127 L p .387 0 0 r
F P
0 g
s
.62915 .77231 m .64203 .7661 L .65919 .76326 L p .114 0 0 r
F P
0 g
s
.47356 .36497 m .50761 .34621 L .50775 .34702 L p .825 .828 .851 r
F P
0 g
s
.50775 .34702 m .474 .3672 L .47356 .36497 L p .825 .828 .851 r
F P
0 g
s
.52322 .70051 m .5233 .67817 L .53606 .68615 L p .909 .666 .56 r
F P
0 g
s
.53606 .68615 m .53631 .71043 L .52322 .70051 L p .909 .666 .56 r
F P
0 g
s
.53517 .65696 m .53606 .68615 L .5233 .67817 L p .883 .726 .682 r
F P
0 g
s
.57554 .37493 m .59836 .41094 L .60011 .40791 L p .402 .392 .733 r
F P
0 g
s
.60011 .40791 m .57671 .37281 L .57554 .37493 L p .402 .392 .733 r
F P
0 g
s
.5451 .34663 m .579 .36617 L .57934 .3639 L p .493 .561 .853 r
F P
0 g
s
.57934 .3639 m .54521 .34582 L .5451 .34663 L p .493 .561 .853 r
F P
0 g
s
.45085 .4595 m .46239 .42002 L .46539 .42267 L p .887 .695 .637 r
F P
0 g
s
.46539 .42267 m .45449 .46267 L .45085 .4595 L p .887 .695 .637 r
F P
0 g
s
.4912 .51933 m .49197 .48231 L .49729 .48368 L p .767 .515 .553 r
F P
0 g
s
.49729 .48368 m .49669 .52079 L .4912 .51933 L p .767 .515 .553 r
F P
0 g
s
.56935 .47777 m .57236 .51253 L .56674 .51431 L p .591 .401 .592 r
F P
0 g
s
.56935 .47777 m .57236 .51253 L .5777 .51069 L p .563 .379 .59 r
F P
0 g
s
.5777 .51069 m .57438 .47598 L .56935 .47777 L p .563 .379 .59 r
F P
0 g
s
.47334 .36271 m .50755 .3454 L .50761 .34621 L p .826 .84 .858 r
F P
0 g
s
.50761 .34621 m .47356 .36497 L .47334 .36271 L p .826 .84 .858 r
F P
0 g
s
.54521 .34582 m .57934 .3639 L .57947 .36161 L p .481 .562 .861 r
F P
0 g
s
.57947 .36161 m .54523 .345 L .54521 .34582 L p .481 .562 .861 r
F P
0 g
s
.45154 .40554 m .47551 .37159 L .47658 .37373 L p .913 .822 .743 r
F P
0 g
s
.47658 .37373 m .45312 .40856 L .45154 .40554 L p .913 .822 .743 r
F P
0 g
s
.61955 .59596 m .60035 .57334 L .59294 .57597 L p .634 .696 .89 r
F P
0 g
s
.60035 .57334 m .61955 .59596 L .62702 .59207 L p .569 .674 .91 r
F P
0 g
s
.47333 .36045 m .50756 .34458 L .50755 .3454 L p .826 .852 .866 r
F P
0 g
s
.50755 .3454 m .47334 .36271 L .47333 .36045 L p .826 .852 .866 r
F P
0 g
s
.48571 .51751 m .48675 .48066 L .49197 .48231 L p .774 .521 .554 r
F P
0 g
s
.49197 .48231 m .4912 .51933 L .48571 .51751 L p .774 .521 .554 r
F P
0 g
s
.5233 .67817 m .52358 .65127 L .53517 .65696 L p .883 .726 .682 r
F P
0 g
s
.53389 .62826 m .53517 .65696 L .52358 .65127 L p .867 .771 .753 r
F P
0 g
s
.53517 .65696 m .53389 .62826 L .54536 .63142 L p .853 .753 .752 r
F P
0 g
s
.54193 .60519 m .54536 .63142 L .53389 .62826 L p .851 .792 .793 r
F P
0 g
s
.54536 .63142 m .54193 .60519 L .55243 .60596 L p .832 .774 .797 r
F P
0 g
s
.65754 .61489 m .63241 .58789 L .62702 .59207 L p .483 .613 .904 r
F P
0 g
s
.63241 .58789 m .65754 .61489 L .66119 .60848 L p .372 .574 .918 r
F P
0 g
s
.68529 .63943 m .66119 .60848 L .65754 .61489 L p .346 .491 .862 r
F P
0 g
s
.54523 .345 m .57947 .36161 L .57937 .35931 L p .468 .563 .869 r
F P
0 g
s
.57937 .35931 m .54518 .34419 L .54523 .345 L p .468 .563 .869 r
F P
0 g
s
.58869 .42187 m .59917 .46266 L .6023 .45998 L p .408 .304 .624 r
F P
0 g
s
.6023 .45998 m .59149 .41932 L .58869 .42187 L p .408 .304 .624 r
F P
0 g
s
.57671 .37281 m .60011 .40791 L .60158 .40478 L p .373 .38 .738 r
F P
0 g
s
.60158 .40478 m .57769 .37064 L .57671 .37281 L p .373 .38 .738 r
F P
0 g
s
.47355 .35819 m .50765 .34377 L .50756 .34458 L p .826 .864 .874 r
F P
0 g
s
.50756 .34458 m .47333 .36045 L .47355 .35819 L p .826 .864 .874 r
F P
0 g
s
.57438 .47598 m .5777 .51069 L .58271 .50879 L p .536 .358 .587 r
F P
0 g
s
.58271 .50879 m .57918 .47406 L .57438 .47598 L p .536 .358 .587 r
F P
0 g
s
.54518 .34419 m .57937 .35931 L .57906 .35702 L p .455 .565 .877 r
F P
0 g
s
.57906 .35702 m .54506 .34337 L .54518 .34419 L p .455 .565 .877 r
F P
0 g
s
.48024 .51535 m .48163 .47874 L .48675 .48066 L p .781 .53 .556 r
F P
0 g
s
.48675 .48066 m .48571 .51751 L .48024 .51535 L p .781 .53 .556 r
F P
0 g
s
.44755 .45626 m .45965 .41727 L .46239 .42002 L p .905 .718 .639 r
F P
0 g
s
.46239 .42002 m .45085 .4595 L .44755 .45626 L p .905 .718 .639 r
F P
0 g
s
.55657 .58342 m .56383 .60613 L .55243 .60596 L p .818 .778 .815 r
F P
0 g
s
.56383 .60613 m .55657 .58342 L .56595 .58214 L p .79 .762 .827 r
F P
0 g
s
.47398 .35593 m .50781 .34296 L .50765 .34377 L p .824 .875 .882 r
F P
0 g
s
.50765 .34377 m .47355 .35819 L .47398 .35593 L p .824 .875 .882 r
F P
0 g
s
.45027 .40248 m .47465 .36941 L .47551 .37159 L p .924 .844 .747 r
F P
0 g
s
.47551 .37159 m .45154 .40554 L .45027 .40248 L p .924 .844 .747 r
F P
0 g
s
.54506 .34337 m .57906 .35702 L .57853 .35474 L p .442 .568 .886 r
F P
0 g
s
.57853 .35474 m .54485 .34257 L .54506 .34337 L p .442 .568 .886 r
F P
0 g
s
.65919 .76326 m .64437 .77001 L .65748 .76442 L p 0 0 0 r
F P
0 g
s
.65748 .76442 m .674 .75719 L .65919 .76326 L p 0 0 0 r
F P
0 g
s
.65919 .76326 m .64437 .77001 L .62915 .77231 L p .114 0 0 r
F P
0 g
s
.47463 .35369 m .50806 .34216 L .50781 .34296 L p .821 .886 .891 r
F P
0 g
s
.50781 .34296 m .47398 .35593 L .47463 .35369 L p .821 .886 .891 r
F P
0 g
s
.54485 .34257 m .57853 .35474 L .57778 .35249 L p .428 .571 .895 r
F P
0 g
s
.57778 .35249 m .54457 .34177 L .54485 .34257 L p .428 .571 .895 r
F P
0 g
s
.4748 .51286 m .47663 .47656 L .48163 .47874 L p .79 .54 .559 r
F P
0 g
s
.48163 .47874 m .48024 .51535 L .4748 .51286 L p .79 .54 .559 r
F P
0 g
s
.57769 .37064 m .60158 .40478 L .60276 .40156 L p .342 .367 .742 r
F P
0 g
s
.60276 .40156 m .57845 .36842 L .57769 .37064 L p .342 .367 .742 r
F P
0 g
s
.47549 .35148 m .50838 .34137 L .50806 .34216 L p .816 .897 .899 r
F P
0 g
s
.50806 .34216 m .47463 .35369 L .47549 .35148 L p .816 .897 .899 r
F P
0 g
s
.59149 .41932 m .6023 .45998 L .60515 .45713 L p .373 .28 .621 r
F P
0 g
s
.60515 .45713 m .59405 .41665 L .59149 .41932 L p .373 .28 .621 r
F P
0 g
s
.57918 .47406 m .58271 .50879 L .58736 .50686 L p .506 .334 .581 r
F P
0 g
s
.58736 .50686 m .58373 .47202 L .57918 .47406 L p .506 .334 .581 r
F P
0 g
s
.54457 .34177 m .57778 .35249 L .57682 .35028 L p .414 .575 .904 r
F P
0 g
s
.57682 .35028 m .54422 .34099 L .54457 .34177 L p .414 .575 .904 r
F P
0 g
s
.44932 .39938 m .474 .3672 L .47465 .36941 L p .932 .867 .752 r
F P
0 g
s
.47465 .36941 m .45027 .40248 L .44932 .39938 L p .932 .867 .752 r
F P
0 g
s
.47656 .3493 m .50877 .3406 L .50838 .34137 L p .81 .906 .907 r
F P
0 g
s
.50838 .34137 m .47549 .35148 L .47656 .3493 L p .81 .906 .907 r
F P
0 g
s
.44461 .45298 m .45719 .41443 L .45965 .41727 L p .924 .743 .639 r
F P
0 g
s
.45965 .41727 m .44755 .45626 L .44461 .45298 L p .924 .743 .639 r
F P
0 g
s
.54422 .34099 m .57682 .35028 L .57565 .34812 L p .4 .58 .912 r
F P
0 g
s
.57565 .34812 m .54379 .34023 L .54422 .34099 L p .4 .58 .912 r
F P
0 g
s
.46944 .51009 m .47179 .47414 L .47663 .47656 L p .801 .553 .562 r
F P
0 g
s
.47663 .47656 m .4748 .51286 L .46944 .51009 L p .801 .553 .562 r
F P
0 g
s
.47784 .34717 m .50923 .33984 L .50877 .3406 L p .802 .916 .916 r
F P
0 g
s
.50877 .3406 m .47656 .3493 L .47784 .34717 L p .802 .916 .916 r
F P
0 g
s
.66119 .60848 m .68529 .63943 L .68624 .6303 L p .187 .422 .856 r
F P
0 g
s
.68529 .63943 m .70194 .67274 L .70299 .66111 L p .04 .221 .723 r
F P
0 g
s
.70299 .66111 m .68624 .6303 L .68529 .63943 L p .04 .221 .723 r
F P
0 g
s
.54379 .34023 m .57565 .34812 L .57426 .34601 L p .386 .585 .921 r
F P
0 g
s
.57426 .34601 m .54329 .33948 L .54379 .34023 L p .386 .585 .921 r
F P
0 g
s
.57845 .36842 m .60276 .40156 L .60364 .39826 L p .307 .354 .747 r
F P
0 g
s
.60364 .39826 m .579 .36617 L .57845 .36842 L p .307 .354 .747 r
F P
0 g
s
.47933 .34508 m .50977 .33911 L .50923 .33984 L p .792 .924 .924 r
F P
0 g
s
.50923 .33984 m .47784 .34717 L .47933 .34508 L p .792 .924 .924 r
F P
0 g
s
.54329 .33948 m .57426 .34601 L .57268 .34397 L p .371 .59 .929 r
F P
0 g
s
.57268 .34397 m .54272 .33876 L .54329 .33948 L p .371 .59 .929 r
F P
0 g
s
.58373 .47202 m .58736 .50686 L .59162 .50488 L p .473 .306 .574 r
F P
0 g
s
.59162 .50488 m .58802 .46987 L .58373 .47202 L p .473 .306 .574 r
F P
0 g
s
.702 .71521 m .69397 .73666 L .69843 .72329 L p .678 .765 .279 r
F P
0 g
s
.69843 .72329 m .70681 .70261 L .702 .71521 L p .678 .765 .279 r
F P
0 g
s
.44868 .39625 m .47356 .36497 L .474 .3672 L p .939 .89 .755 r
F P
0 g
s
.474 .3672 m .44932 .39938 L .44868 .39625 L p .939 .89 .755 r
F P
0 g
s
.48101 .34306 m .51038 .3384 L .50977 .33911 L p .78 .931 .932 r
F P
0 g
s
.50977 .33911 m .47933 .34508 L .48101 .34306 L p .78 .931 .932 r
F P
0 g
s
.59405 .41665 m .60515 .45713 L .60771 .45411 L p .334 .255 .616 r
F P
0 g
s
.60771 .45411 m .59634 .41385 L .59405 .41665 L p .334 .255 .616 r
F P
0 g
s
.46418 .50707 m .46712 .47152 L .47179 .47414 L p .814 .568 .566 r
F P
0 g
s
.47179 .47414 m .46944 .51009 L .46418 .50707 L p .814 .568 .566 r
F P
0 g
s
.54272 .33876 m .57268 .34397 L .5709 .34201 L p .357 .596 .937 r
F P
0 g
s
.5709 .34201 m .54208 .33806 L .54272 .33876 L p .357 .596 .937 r
F P
0 g
s
.48289 .34112 m .51105 .33772 L .51038 .3384 L p .766 .937 .939 r
F P
0 g
s
.51038 .3384 m .48101 .34306 L .48289 .34112 L p .766 .937 .939 r
F P
0 g
s
.70194 .67274 m .70681 .70261 L .70782 .68906 L p 0 0 .344 r
F P
0 g
s
.70782 .68906 m .70299 .66111 L .70194 .67274 L p 0 0 .344 r
F P
0 g
s
.44206 .44968 m .45501 .41153 L .45719 .41443 L p .943 .77 .637 r
F P
0 g
s
.45719 .41443 m .44461 .45298 L .44206 .44968 L p .943 .77 .637 r
F P
0 g
s
.62702 .59207 m .60646 .57057 L .60035 .57334 L p .569 .674 .91 r
F P
0 g
s
.60646 .57057 m .62702 .59207 L .63241 .58789 L p .484 .645 .928 r
F P
0 g
s
.54208 .33806 m .5709 .34201 L .56892 .34013 L p .342 .603 .944 r
F P
0 g
s
.56892 .34013 m .54138 .3374 L .54208 .33806 L p .342 .603 .944 r
F P
0 g
s
.579 .36617 m .60364 .39826 L .60422 .3949 L p .268 .339 .752 r
F P
0 g
s
.60422 .3949 m .57934 .3639 L .579 .36617 L p .268 .339 .752 r
F P
0 g
s
.48495 .33925 m .51179 .33707 L .51105 .33772 L p .749 .941 .946 r
F P
0 g
s
.51105 .33772 m .48289 .34112 L .48495 .33925 L p .749 .941 .946 r
F P
0 g
s
.54138 .3374 m .56892 .34013 L .56677 .33834 L p .329 .61 .951 r
F P
0 g
s
.56677 .33834 m .54061 .33676 L .54138 .3374 L p .329 .61 .951 r
F P
0 g
s
.48718 .33748 m .51258 .33645 L .51179 .33707 L p .729 .944 .953 r
F P
0 g
s
.51179 .33707 m .48495 .33925 L .48718 .33748 L p .729 .944 .953 r
F P
0 g
s
.45911 .50384 m .46266 .46871 L .46712 .47152 L p .83 .586 .57 r
F P
0 g
s
.46712 .47152 m .46418 .50707 L .45911 .50384 L p .83 .586 .57 r
F P
0 g
s
.44836 .39309 m .47334 .36271 L .47356 .36497 L p .943 .913 .757 r
F P
0 g
s
.47356 .36497 m .44868 .39625 L .44836 .39309 L p .943 .913 .757 r
F P
0 g
s
.54061 .33676 m .56677 .33834 L .56445 .33665 L p .315 .618 .957 r
F P
0 g
s
.56445 .33665 m .53978 .33616 L .54061 .33676 L p .315 .618 .957 r
F P
0 g
s
.54755 .5843 m .55243 .60596 L .54193 .60519 L p .843 .794 .804 r
F P
0 g
s
.55243 .60596 m .54755 .5843 L .55657 .58342 L p .818 .778 .815 r
F P
0 g
s
.52337 .71395 m .52322 .70051 L .53631 .71043 L p .918 .549 .31 r
F P
0 g
s
.53631 .71043 m .53584 .7251 L .52337 .71395 L p .918 .549 .31 r
F P
0 g
s
.48959 .33581 m .51344 .33587 L .51258 .33645 L p .706 .944 .958 r
F P
0 g
s
.51258 .33645 m .48718 .33748 L .48959 .33581 L p .706 .944 .958 r
F P
0 g
s
.58802 .46987 m .59162 .50488 L .59549 .50286 L p .436 .275 .564 r
F P
0 g
s
.59549 .50286 m .59203 .4676 L .58802 .46987 L p .436 .275 .564 r
F P
0 g
s
.53978 .33616 m .56445 .33665 L .56196 .33507 L p .303 .627 .961 r
F P
0 g
s
.56196 .33507 m .5389 .3356 L .53978 .33616 L p .303 .627 .961 r
F P
0 g
s
.59634 .41385 m .60771 .45411 L .61 .45091 L p .291 .227 .611 r
F P
0 g
s
.61 .45091 m .59836 .41094 L .59634 .41385 L p .291 .227 .611 r
F P
0 g
s
.49215 .33424 m .51435 .33532 L .51344 .33587 L p .681 .942 .963 r
F P
0 g
s
.51344 .33587 m .48959 .33581 L .49215 .33424 L p .681 .942 .963 r
F P
0 g
s
.674 .75719 m .65748 .76442 L .66784 .75582 L p .589 .939 .78 r
F P
0 g
s
.66784 .75582 m .68576 .74816 L .674 .75719 L p .589 .939 .78 r
F P
0 g
s
.57934 .3639 m .60422 .3949 L .60449 .39149 L p .225 .324 .756 r
F P
0 g
s
.60449 .39149 m .57947 .36161 L .57934 .3639 L p .225 .324 .756 r
F P
0 g
s
.5389 .3356 m .56196 .33507 L .55932 .3336 L p .292 .636 .965 r
F P
0 g
s
.55932 .3336 m .53797 .33507 L .5389 .3356 L p .292 .636 .965 r
F P
0 g
s
.49486 .3328 m .51531 .33482 L .51435 .33532 L p .654 .937 .966 r
F P
0 g
s
.51435 .33532 m .49215 .33424 L .49486 .3328 L p .654 .937 .966 r
F P
0 g
s
.43991 .44638 m .45312 .40856 L .45501 .41153 L p .962 .798 .633 r
F P
0 g
s
.45501 .41153 m .44206 .44968 L .43991 .44638 L p .962 .798 .633 r
F P
0 g
s
.53797 .33507 m .55932 .3336 L .55654 .33224 L p .283 .646 .967 r
F P
0 g
s
.55654 .33224 m .53699 .33459 L .53797 .33507 L p .283 .646 .967 r
F P
0 g
s
.4977 .33148 m .51631 .33436 L .51531 .33482 L p .624 .93 .969 r
F P
0 g
s
.51531 .33482 m .49486 .3328 L .4977 .33148 L p .624 .93 .969 r
F P
0 g
s
.45428 .50046 m .45844 .46576 L .46266 .46871 L p .848 .607 .574 r
F P
0 g
s
.46266 .46871 m .45911 .50384 L .45428 .50046 L p .848 .607 .574 r
F P
0 g
s
.51207 .69134 m .51241 .67071 L .5233 .67817 L p .92 .678 .557 r
F P
0 g
s
.5233 .67817 m .52322 .70051 L .51207 .69134 L p .92 .678 .557 r
F P
0 g
s
.52358 .65127 m .5233 .67817 L .51241 .67071 L p .89 .738 .686 r
F P
0 g
s
.53699 .33459 m .55654 .33224 L .55363 .33101 L p .275 .656 .968 r
F P
0 g
s
.55363 .33101 m .53596 .33415 L .53699 .33459 L p .275 .656 .968 r
F P
0 g
s
.44835 .38991 m .47333 .36045 L .47334 .36271 L p .944 .934 .757 r
F P
0 g
s
.47334 .36271 m .44836 .39309 L .44835 .38991 L p .944 .934 .757 r
F P
0 g
s
.55036 .73631 m .56685 .74672 L p .55011 .74073 L .755 .238 0 r
F P
0 g
s
.54817 .73921 m .55036 .73631 L p .55011 .74073 L .755 .238 0 r
F P
0 g
s
.55036 .73631 m .54768 .73986 L .53478 .7283 L p .756 .251 0 r
F P
0 g
s
.55647 .74338 m .54425 .73319 L p .56007 .74852 L 0 .197 .676 r
F P
0 g
s
.56233 .7507 m .56143 .74958 L p .56007 .74852 L 0 .197 .676 r
F P
0 g
s
.56143 .74958 m .55647 .74338 L p .56007 .74852 L 0 .197 .676 r
F P
0 g
s
.54768 .73986 m .54817 .73921 L p .55011 .74073 L .755 .238 0 r
F P
0 g
s
.50067 .33029 m .51736 .33394 L .51631 .33436 L p .592 .92 .97 r
F P
0 g
s
.51631 .33436 m .4977 .33148 L .50067 .33029 L p .592 .92 .97 r
F P
0 g
s
.52358 .65127 m .52398 .62484 L .53389 .62826 L p .867 .771 .753 r
F P
0 g
s
.53257 .60398 m .53389 .62826 L .52398 .62484 L p .864 .808 .792 r
F P
0 g
s
.53389 .62826 m .53257 .60398 L .54193 .60519 L p .851 .792 .793 r
F P
0 g
s
.53596 .33415 m .55363 .33101 L .5506 .3299 L p .271 .668 .969 r
F P
0 g
s
.5506 .3299 m .53489 .33376 L .53596 .33415 L p .271 .668 .969 r
F P
0 g
s
.50067 .33029 m .51736 .33394 L .51844 .33357 L p .56 .908 .97 r
F P
0 g
s
.53489 .33376 m .5506 .3299 L .54747 .32893 L p .269 .68 .968 r
F P
0 g
s
.54747 .32893 m .53379 .33341 L .53489 .33376 L p .269 .68 .968 r
F P
0 g
s
.50376 .32923 m .51844 .33357 L .51956 .33325 L p .528 .895 .97 r
F P
0 g
s
.51844 .33357 m .50376 .32923 L .50067 .33029 L p .56 .908 .97 r
F P
0 g
s
.53379 .33341 m .54747 .32893 L .54425 .32808 L p .27 .693 .967 r
F P
0 g
s
.54425 .32808 m .53266 .33311 L .53379 .33341 L p .27 .693 .967 r
F P
0 g
s
.57947 .36161 m .60449 .39149 L .60444 .38805 L p .177 .307 .759 r
F P
0 g
s
.60444 .38805 m .57937 .35931 L .57947 .36161 L p .177 .307 .759 r
F P
0 g
s
.51241 .67071 m .51368 .64587 L .52358 .65127 L p .89 .738 .686 r
F P
0 g
s
.52398 .62484 m .52358 .65127 L .51368 .64587 L p .872 .782 .76 r
F P
0 g
s
.50694 .32832 m .51956 .33325 L .52071 .33298 L p .496 .879 .969 r
F P
0 g
s
.51956 .33325 m .50694 .32832 L .50376 .32923 L p .528 .895 .97 r
F P
0 g
s
.59203 .4676 m .59549 .50286 L .59897 .50076 L p .395 .241 .551 r
F P
0 g
s
.59897 .50076 m .59574 .4652 L .59203 .4676 L p .395 .241 .551 r
F P
0 g
s
.53266 .33311 m .54425 .32808 L .54095 .32737 L p .275 .707 .966 r
F P
0 g
s
.54095 .32737 m .5315 .33287 L .53266 .33311 L p .275 .707 .966 r
F P
0 g
s
.3058 .6608 m .32704 .62646 L .34607 .63142 L p .74 .601 .702 r
F P
0 g
s
.34607 .63142 m .32701 .66485 L .3058 .6608 L p .74 .601 .702 r
F P
0 g
s
.37362 .60093 m .34607 .63142 L .32704 .62646 L p .713 .632 .765 r
F P
0 g
s
.32701 .66485 m .34607 .63142 L .36646 .63479 L p .71 .567 .691 r
F P
0 g
s
.34607 .63142 m .37362 .60093 L .39068 .60516 L p .69 .601 .751 r
F P
0 g
s
.39068 .60516 m .36646 .63479 L .34607 .63142 L p .69 .601 .751 r
F P
0 g
s
.54322 .5468 m .5428 .5203 L .54888 .51903 L p .725 .495 .577 r
F P
0 g
s
.54888 .51903 m .5497 .54534 L .54322 .5468 L p .725 .495 .577 r
F P
0 g
s
.5497 .54534 m .54888 .51903 L .55494 .51759 L p .703 .484 .588 r
F P
0 g
s
.5102 .32756 m .52071 .33298 L .52188 .33276 L p .464 .863 .968 r
F P
0 g
s
.52071 .33298 m .5102 .32756 L .50694 .32832 L p .496 .879 .969 r
F P
0 g
s
.55494 .51759 m .55624 .54372 L .5497 .54534 L p .703 .484 .588 r
F P
0 g
s
.55624 .54372 m .55494 .51759 L .56091 .51601 L p .676 .468 .596 r
F P
0 g
s
.5315 .33287 m .54095 .32737 L .53759 .32681 L p .283 .722 .965 r
F P
0 g
s
.53759 .32681 m .53032 .33267 L .5315 .33287 L p .283 .722 .965 r
F P
0 g
s
.59836 .41094 m .61 .45091 L .61202 .44752 L p .243 .198 .605 r
F P
0 g
s
.61202 .44752 m .60011 .40791 L .59836 .41094 L p .243 .198 .605 r
F P
0 g
s
.51354 .32694 m .52188 .33276 L .52307 .33259 L p .433 .845 .966 r
F P
0 g
s
.52188 .33276 m .51354 .32694 L .5102 .32756 L p .464 .863 .968 r
F P
0 g
s
.53689 .54805 m .53675 .52137 L .5428 .5203 L p .743 .502 .565 r
F P
0 g
s
.5428 .5203 m .54322 .5468 L .53689 .54805 L p .743 .502 .565 r
F P
0 g
s
.53032 .33267 m .53759 .32681 L .53419 .32638 L p .295 .738 .963 r
F P
0 g
s
.53419 .32638 m .52912 .33252 L .53032 .33267 L p .295 .738 .963 r
F P
0 g
s
.51693 .32647 m .52307 .33259 L .52427 .33247 L p .403 .827 .965 r
F P
0 g
s
.52307 .33259 m .51693 .32647 L .51354 .32694 L p .433 .845 .966 r
F P
0 g
s
.52912 .33252 m .53419 .32638 L .53074 .3261 L p .31 .755 .963 r
F P
0 g
s
.53074 .3261 m .52792 .33243 L .52912 .33252 L p .31 .755 .963 r
F P
0 g
s
.52036 .32615 m .52427 .33247 L .52548 .3324 L p .376 .809 .963 r
F P
0 g
s
.52427 .33247 m .52036 .32615 L .51693 .32647 L p .403 .827 .965 r
F P
0 g
s
.52792 .33243 m .53074 .3261 L .52728 .32597 L p .329 .772 .962 r
F P
0 g
s
.52728 .32597 m .5267 .33239 L .52792 .33243 L p .329 .772 .962 r
F P
0 g
s
.36646 .63479 m .34969 .66688 L .32701 .66485 L p .71 .567 .691 r
F P
0 g
s
.34969 .66688 m .36646 .63479 L .3872 .63666 L p .683 .538 .682 r
F P
0 g
s
.36646 .63479 m .39068 .60516 L .40806 .60826 L p .668 .574 .741 r
F P
0 g
s
.40806 .60826 m .3872 .63666 L .36646 .63479 L p .668 .574 .741 r
F P
0 g
s
.52381 .32599 m .52548 .3324 L .5267 .33239 L p .351 .79 .963 r
F P
0 g
s
.52548 .3324 m .52381 .32599 L .52036 .32615 L p .376 .809 .963 r
F P
0 g
s
.5267 .33239 m .52728 .32597 L .52381 .32599 L p .351 .79 .963 r
F P
0 g
s
.56091 .51601 m .56274 .54197 L .55624 .54372 L p .676 .468 .596 r
F P
0 g
s
.56274 .54197 m .56091 .51601 L .56674 .51431 L p .643 .446 .602 r
F P
0 g
s
.44977 .49698 m .45449 .46267 L .45844 .46576 L p .869 .631 .576 r
F P
0 g
s
.45844 .46576 m .45428 .50046 L .44977 .49698 L p .869 .631 .576 r
F P
0 g
s
.44866 .38671 m .47355 .35819 L .47333 .36045 L p .94 .953 .755 r
F P
0 g
s
.47333 .36045 m .44835 .38991 L .44866 .38671 L p .94 .953 .755 r
F P
0 g
s
.53077 .54905 m .53077 .5222 L .53675 .52137 L p .756 .504 .552 r
F P
0 g
s
.53675 .52137 m .53689 .54805 L .53077 .54905 L p .756 .504 .552 r
F P
0 g
s
.66119 .60848 m .63559 .58364 L .63241 .58789 L p .372 .574 .918 r
F P
0 g
s
.63559 .58364 m .66119 .60848 L .66209 .60201 L p .228 .516 .912 r
F P
0 g
s
.68624 .6303 m .66209 .60201 L .66119 .60848 L p .187 .422 .856 r
F P
0 g
s
.43816 .44308 m .45154 .40554 L .45312 .40856 L p .978 .826 .624 r
F P
0 g
s
.45312 .40856 m .43991 .44638 L .43816 .44308 L p .978 .826 .624 r
F P
0 g
s
.57428 .55957 m .5845 .57837 L .57538 .58045 L p .729 .701 .825 r
F P
0 g
s
.5845 .57837 m .57428 .55957 L .58114 .5575 L p .684 .683 .843 r
F P
0 g
s
.58114 .5575 m .59294 .57597 L .5845 .57837 L p .684 .683 .843 r
F P
0 g
s
.56697 .56155 m .57538 .58045 L .56595 .58214 L p .767 .717 .806 r
F P
0 g
s
.57538 .58045 m .56697 .56155 L .57428 .55957 L p .729 .701 .825 r
F P
0 g
s
.56674 .51431 m .56905 .54013 L .56274 .54197 L p .643 .446 .602 r
F P
0 g
s
.56905 .54013 m .56674 .51431 L .57236 .51253 L p .603 .418 .604 r
F P
0 g
s
.57937 .35931 m .60444 .38805 L .60407 .38461 L p .123 .287 .76 r
F P
0 g
s
.60407 .38461 m .57906 .35702 L .57937 .35931 L p .123 .287 .76 r
F P
0 g
s
.28717 .65473 m .31036 .61999 L .32704 .62646 L p .773 .643 .717 r
F P
0 g
s
.32704 .62646 m .3058 .6608 L .28717 .65473 L p .773 .643 .717 r
F P
0 g
s
.35773 .5956 m .32704 .62646 L .31036 .61999 L p .738 .669 .783 r
F P
0 g
s
.32704 .62646 m .35773 .5956 L .37362 .60093 L p .713 .632 .765 r
F P
0 g
s
.5249 .54979 m .52488 .52277 L .53077 .5222 L p .765 .503 .538 r
F P
0 g
s
.53077 .5222 m .53077 .54905 L .5249 .54979 L p .765 .503 .538 r
F P
0 g
s
.58114 .5575 m .59294 .57597 L .60035 .57334 L p .632 .661 .861 r
F P
0 g
s
.3214 .69546 m .32701 .66485 L .34969 .66688 L p .713 .495 .593 r
F P
0 g
s
.34969 .66688 m .34483 .69582 L .3214 .69546 L p .713 .495 .593 r
F P
0 g
s
.34483 .69582 m .34969 .66688 L .37273 .66706 L p .678 .464 .588 r
F P
0 g
s
.3872 .63666 m .37273 .66706 L .34969 .66688 L p .683 .538 .682 r
F P
0 g
s
.51926 .55021 m .51909 .52304 L .52488 .52277 L p .769 .499 .526 r
F P
0 g
s
.52488 .52277 m .5249 .54979 L .51926 .55021 L p .769 .499 .526 r
F P
0 g
s
.44927 .3835 m .47398 .35593 L .47355 .35819 L p .93 .969 .75 r
F P
0 g
s
.47355 .35819 m .44866 .38671 L .44927 .3835 L p .93 .969 .75 r
F P
0 g
s
.59574 .4652 m .59897 .50076 L .60209 .49855 L p .349 .203 .537 r
F P
0 g
s
.60209 .49855 m .59917 .46266 L .59574 .4652 L p .349 .203 .537 r
F P
0 g
s
.29948 .69275 m .3058 .6608 L .32701 .66485 L p .752 .532 .598 r
F P
0 g
s
.32701 .66485 m .3214 .69546 L .29948 .69275 L p .752 .532 .598 r
F P
0 g
s
.60011 .40791 m .61202 .44752 L .61376 .44395 L p .19 .165 .598 r
F P
0 g
s
.61376 .44395 m .60158 .40478 L .60011 .40791 L p .19 .165 .598 r
F P
0 g
s
.55942 .56337 m .56595 .58214 L .55657 .58342 L p .8 .73 .787 r
F P
0 g
s
.56595 .58214 m .55942 .56337 L .56697 .56155 L p .767 .717 .806 r
F P
0 g
s
.44565 .49347 m .45085 .4595 L .45449 .46267 L p .892 .658 .577 r
F P
0 g
s
.45449 .46267 m .44977 .49698 L .44565 .49347 L p .892 .658 .577 r
F P
0 g
s
.57236 .51253 m .57506 .53825 L .56905 .54013 L p .603 .418 .604 r
F P
0 g
s
.57236 .51253 m .57506 .53825 L .58064 .53635 L p .563 .388 .601 r
F P
0 g
s
.58064 .53635 m .5777 .51069 L .57236 .51253 L p .563 .388 .601 r
F P
0 g
s
.37273 .66706 m .3872 .63666 L .40736 .63721 L p .66 .515 .677 r
F P
0 g
s
.3872 .63666 m .40806 .60826 L .425 .61032 L p .648 .553 .734 r
F P
0 g
s
.425 .61032 m .40736 .63721 L .3872 .63666 L p .648 .553 .734 r
F P
0 g
s
.57906 .35702 m .60407 .38461 L .60338 .3812 L p .063 .266 .757 r
F P
0 g
s
.60338 .3812 m .57853 .35474 L .57906 .35702 L p .063 .266 .757 r
F P
0 g
s
.63241 .58789 m .61109 .56779 L .60646 .57057 L p .484 .645 .928 r
F P
0 g
s
.61109 .56779 m .63241 .58789 L .63559 .58364 L p .372 .602 .937 r
F P
0 g
s
.5138 .55031 m .51339 .523 L .51909 .52304 L p .769 .492 .514 r
F P
0 g
s
.51909 .52304 m .51926 .55021 L .5138 .55031 L p .769 .492 .514 r
F P
0 g
s
.43681 .43978 m .45027 .40248 L .45154 .40554 L p .99 .853 .61 r
F P
0 g
s
.45154 .40554 m .43816 .44308 L .43681 .43978 L p .99 .853 .61 r
F P
0 g
s
.53915 .58479 m .54193 .60519 L .53257 .60398 L p .864 .808 .793 r
F P
0 g
s
.54193 .60519 m .53915 .58479 L .54755 .5843 L p .843 .794 .804 r
F P
0 g
s
.37273 .66706 m .3686 .6941 L .34483 .69582 L p .678 .464 .588 r
F P
0 g
s
.3686 .6941 m .37273 .66706 L .3951 .66573 L p .649 .439 .585 r
F P
0 g
s
.40736 .63721 m .3951 .66573 L .37273 .66706 L p .66 .515 .677 r
F P
0 g
s
.4502 .38029 m .47463 .35369 L .47398 .35593 L p .912 .981 .74 r
F P
0 g
s
.47398 .35593 m .44927 .3835 L .4502 .38029 L p .912 .981 .74 r
F P
0 g
s
.50847 .55004 m .50777 .52262 L .51339 .523 L p .766 .483 .506 r
F P
0 g
s
.51339 .523 m .5138 .55031 L .50847 .55004 L p .766 .483 .506 r
F P
0 g
s
.5777 .51069 m .58064 .53635 L .5857 .53449 L p .525 .356 .594 r
F P
0 g
s
.5857 .53449 m .58271 .50879 L .5777 .51069 L p .525 .356 .594 r
F P
0 g
s
.28022 .6876 m .28717 .65473 L .3058 .6608 L p .798 .578 .603 r
F P
0 g
s
.3058 .6608 m .29948 .69275 L .28022 .6876 L p .798 .578 .603 r
F P
0 g
s
.57853 .35474 m .60338 .3812 L .60236 .37782 L p 0 .241 .75 r
F P
0 g
s
.60236 .37782 m .57778 .35249 L .57853 .35474 L p 0 .241 .75 r
F P
0 g
s
.44198 .48997 m .44755 .45626 L .45085 .4595 L p .918 .688 .575 r
F P
0 g
s
.45085 .4595 m .44565 .49347 L .44198 .48997 L p .918 .688 .575 r
F P
0 g
s
.60158 .40478 m .61376 .44395 L .61522 .44019 L p .13 .13 .59 r
F P
0 g
s
.61522 .44019 m .60276 .40156 L .60158 .40478 L p .13 .13 .59 r
F P
0 g
s
.59917 .46266 m .60209 .49855 L .60489 .49622 L p .299 .162 .52 r
F P
0 g
s
.60489 .49622 m .6023 .45998 L .59917 .46266 L p .299 .162 .52 r
F P
0 g
s
.40293 .57691 m .37362 .60093 L .35773 .5956 L p .682 .64 .802 r
F P
0 g
s
.37362 .60093 m .40293 .57691 L .4163 .58148 L p .663 .611 .786 r
F P
0 g
s
.4163 .58148 m .39068 .60516 L .37362 .60093 L p .663 .611 .786 r
F P
0 g
s
.27216 .64679 m .29696 .61223 L .31036 .61999 L p .811 .694 .737 r
F P
0 g
s
.31036 .61999 m .28717 .65473 L .27216 .64679 L p .811 .694 .737 r
F P
0 g
s
.34384 .58929 m .31036 .61999 L .29696 .61223 L p .763 .713 .805 r
F P
0 g
s
.31036 .61999 m .34384 .58929 L .35773 .5956 L p .738 .669 .783 r
F P
0 g
s
.60035 .57334 m .58731 .55538 L .58114 .5575 L p .632 .661 .861 r
F P
0 g
s
.58731 .55538 m .60035 .57334 L .60646 .57057 L p .569 .634 .875 r
F P
0 g
s
.50318 .54939 m .50221 .52188 L .50777 .52262 L p .761 .475 .5 r
F P
0 g
s
.50777 .52262 m .50847 .55004 L .50318 .54939 L p .761 .475 .5 r
F P
0 g
s
.68576 .74816 m .66784 .75582 L .67503 .74465 L p .803 1 .828 r
F P
0 g
s
.67503 .74465 m .69397 .73666 L .68576 .74816 L p .803 1 .828 r
F P
0 g
s
.55186 .56498 m .55657 .58342 L .54755 .5843 L p .829 .741 .767 r
F P
0 g
s
.55657 .58342 m .55186 .56498 L .55942 .56337 L p .8 .73 .787 r
F P
0 g
s
.53584 .7251 m .55036 .73631 L p .53688 .72938 L .756 .251 0 r
F P
0 g
s
.535 .72766 m .53584 .7251 L p .53688 .72938 L .756 .251 0 r
F P
0 g
s
.52337 .71395 m .53584 .7251 L p .52605 .71849 L .727 .232 0 r
F P
0 g
s
.52371 .71691 m .52362 .71616 L p .52605 .71849 L .727 .232 0 r
F P
0 g
s
.52362 .71616 m .52337 .71395 L p .52605 .71849 L .727 .232 0 r
F P
0 g
s
.53584 .7251 m .53478 .7283 L .52371 .71691 L p .727 .232 0 r
F P
0 g
s
.54425 .73319 m .53345 .72242 L p .54545 .73712 L 0 .166 .673 r
F P
0 g
s
.54571 .73744 m .54568 .73734 L .54545 .73712 L 0 .166 .673 r
F
.54568 .73734 m .54425 .73319 L .54545 .73712 L F
.54768 .73986 m .54709 .7387 L p .54571 .73744 L F P
0 g
s
.54709 .7387 m .54425 .73319 L p .54571 .73744 L 0 .166 .673 r
F P
0 g
s
.53478 .7283 m .535 .72766 L p .53688 .72938 L .756 .251 0 r
F P
0 g
s
.45143 .37709 m .47549 .35148 L .47463 .35369 L p .886 .987 .726 r
F P
0 g
s
.47463 .35369 m .4502 .38029 L .45143 .37709 L p .886 .987 .726 r
F P
0 g
s
.43586 .43648 m .44932 .39938 L .45027 .40248 L p .993 .875 .588 r
F P
0 g
s
.45027 .40248 m .43681 .43978 L .43586 .43648 L p .993 .875 .588 r
F P
0 g
s
.51276 .70373 m .51207 .69134 L .52322 .70051 L p .924 .548 .278 r
F P
0 g
s
.52322 .70051 m .52337 .71395 L .51276 .70373 L p .924 .548 .278 r
F P
0 g
s
.3905 .57167 m .35773 .5956 L .34384 .58929 L p .701 .675 .821 r
F P
0 g
s
.35773 .5956 m .3905 .57167 L .40293 .57691 L p .682 .64 .802 r
F P
0 g
s
.39068 .60516 m .4163 .58148 L .42996 .5853 L p .644 .585 .773 r
F P
0 g
s
.42996 .5853 m .40806 .60826 L .39068 .60516 L p .644 .585 .773 r
F P
0 g
s
.49786 .54834 m .49669 .52079 L .50221 .52188 L p .755 .469 .498 r
F P
0 g
s
.50221 .52188 m .50318 .54939 L .49786 .54834 L p .755 .469 .498 r
F P
0 g
s
.66209 .60201 m .68624 .6303 L .6843 .62126 L p 0 .329 .814 r
F P
0 g
s
.68624 .6303 m .70299 .66111 L .70082 .6494 L p 0 .071 .633 r
F P
0 g
s
.70082 .6494 m .6843 .62126 L .68624 .6303 L p 0 .071 .633 r
F P
0 g
s
.3951 .66573 m .40736 .63721 L .42616 .63678 L p .64 .498 .674 r
F P
0 g
s
.40736 .63721 m .425 .61032 L .44082 .61151 L p .631 .538 .73 r
F P
0 g
s
.44082 .61151 m .42616 .63678 L .40736 .63721 L p .631 .538 .73 r
F P
0 g
s
.58271 .50879 m .5857 .53449 L .59017 .53266 L p .481 .317 .582 r
F P
0 g
s
.59017 .53266 m .58736 .50686 L .58271 .50879 L p .481 .317 .582 r
F P
0 g
s
.57778 .35249 m .60236 .37782 L .60101 .37451 L p 0 .213 .737 r
F P
0 g
s
.60101 .37451 m .57682 .35028 L .57778 .35249 L p 0 .213 .737 r
F P
0 g
s
.70681 .70261 m .69843 .72329 L .69926 .70878 L p .918 .881 .458 r
F P
0 g
s
.69926 .70878 m .70782 .68906 L .70681 .70261 L p .918 .881 .458 r
F P
0 g
s
.49243 .54687 m .4912 .51933 L .49669 .52079 L p .751 .466 .5 r
F P
0 g
s
.49669 .52079 m .49786 .54834 L .49243 .54687 L p .751 .466 .5 r
F P
0 g
s
.50238 .68362 m .50295 .66436 L .51241 .67071 L p .915 .676 .563 r
F P
0 g
s
.51241 .67071 m .51207 .69134 L .50238 .68362 L p .915 .676 .563 r
F P
0 g
s
.51368 .64587 m .51241 .67071 L .50295 .66436 L p .883 .738 .697 r
F P
0 g
s
.3951 .66573 m .39164 .69078 L .3686 .6941 L p .649 .439 .585 r
F P
0 g
s
.39164 .69078 m .3951 .66573 L .41592 .66337 L p .625 .418 .582 r
F P
0 g
s
.42616 .63678 m .41592 .66337 L .3951 .66573 L p .64 .498 .674 r
F P
0 g
s
.51368 .64587 m .51549 .62151 L .52398 .62484 L p .872 .782 .76 r
F P
0 g
s
.5244 .6025 m .52398 .62484 L .51549 .62151 L p .868 .817 .797 r
F P
0 g
s
.52398 .62484 m .5244 .6025 L .53257 .60398 L p .864 .808 .792 r
F P
0 g
s
.43883 .48652 m .44461 .45298 L .44755 .45626 L p .945 .721 .568 r
F P
0 g
s
.44755 .45626 m .44198 .48997 L .43883 .48652 L p .945 .721 .568 r
F P
0 g
s
.60276 .40156 m .61522 .44019 L .61638 .43627 L p .063 .092 .579 r
F P
0 g
s
.61638 .43627 m .60364 .39826 L .60276 .40156 L p .063 .092 .579 r
F P
0 g
s
.45296 .3739 m .47656 .3493 L .47549 .35148 L p .849 .985 .706 r
F P
0 g
s
.47549 .35148 m .45143 .37709 L .45296 .3739 L p .849 .985 .706 r
F P
0 g
s
.48683 .54499 m .48571 .51751 L .4912 .51933 L p .748 .466 .505 r
F P
0 g
s
.4912 .51933 m .49243 .54687 L .48683 .54499 L p .748 .466 .505 r
F P
0 g
s
.6023 .45998 m .60489 .49622 L .60741 .4937 L p .245 .118 .501 r
F P
0 g
s
.60741 .4937 m .60515 .45713 L .6023 .45998 L p .245 .118 .501 r
F P
0 g
s
.50295 .66436 m .50508 .64119 L .51368 .64587 L p .883 .738 .697 r
F P
0 g
s
.51549 .62151 m .51368 .64587 L .50508 .64119 L p .861 .781 .771 r
F P
0 g
s
.57682 .35028 m .60101 .37451 L .59933 .37129 L p 0 .181 .715 r
F P
0 g
s
.59933 .37129 m .57565 .34812 L .57682 .35028 L p 0 .181 .715 r
F P
0 g
s
.48106 .5427 m .48024 .51535 L .48571 .51751 L p .749 .472 .512 r
F P
0 g
s
.48571 .51751 m .48683 .54499 L .48106 .5427 L p .749 .472 .512 r
F P
0 g
s
.43529 .43318 m .44868 .39625 L .44932 .39938 L p .986 .89 .557 r
F P
0 g
s
.44932 .39938 m .43586 .43648 L .43529 .43318 L p .986 .89 .557 r
F P
0 g
s
.70299 .66111 m .70782 .68906 L .70551 .67528 L p .701 .468 0 r
F P
0 g
s
.70551 .67528 m .70082 .6494 L .70299 .66111 L p .701 .468 0 r
F P
0 g
s
.40806 .60826 m .42996 .5853 L .44331 .58834 L p .626 .563 .764 r
F P
0 g
s
.44331 .58834 m .425 .61032 L .40806 .60826 L p .626 .563 .764 r
F P
0 g
s
.29696 .61223 m .33272 .58223 L .34384 .58929 L p .763 .713 .805 r
F P
0 g
s
.37966 .56591 m .34384 .58929 L .33272 .58223 L p .718 .714 .845 r
F P
0 g
s
.34384 .58929 m .37966 .56591 L .3905 .57167 L p .701 .675 .821 r
F P
0 g
s
.58736 .50686 m .59017 .53266 L .59402 .5309 L p .429 .27 .563 r
F P
0 g
s
.59402 .5309 m .59162 .50488 L .58736 .50686 L p .429 .27 .563 r
F P
0 g
s
.47512 .54001 m .4748 .51286 L .48024 .51535 L p .754 .482 .521 r
F P
0 g
s
.48024 .51535 m .48106 .5427 L .47512 .54001 L p .754 .482 .521 r
F P
0 g
s
.45479 .37073 m .47784 .34717 L .47656 .3493 L p .801 .974 .679 r
F P
0 g
s
.47656 .3493 m .45296 .3739 L .45479 .37073 L p .801 .974 .679 r
F P
0 g
s
.26469 .6801 m .27216 .64679 L .28717 .65473 L p .855 .636 .606 r
F P
0 g
s
.28717 .65473 m .28022 .6876 L .26469 .6801 L p .855 .636 .606 r
F P
0 g
s
.55942 .56337 m .55624 .54372 L .56274 .54197 L p .737 .59 .692 r
F P
0 g
s
.56274 .54197 m .56697 .56155 L .55942 .56337 L p .737 .59 .692 r
F P
0 g
s
.56697 .56155 m .56274 .54197 L .56905 .54013 L p .699 .571 .707 r
F P
0 g
s
.60646 .57057 m .59264 .55329 L .58731 .55538 L p .569 .634 .875 r
F P
0 g
s
.59264 .55329 m .60646 .57057 L .61109 .56779 L p .489 .595 .886 r
F P
0 g
s
.55186 .56498 m .5497 .54534 L .55624 .54372 L p .769 .603 .673 r
F P
0 g
s
.55624 .54372 m .55942 .56337 L .55186 .56498 L p .769 .603 .673 r
F P
0 g
s
.5445 .56637 m .54755 .5843 L .53915 .58479 L p .855 .749 .746 r
F P
0 g
s
.54755 .5843 m .5445 .56637 L .55186 .56498 L p .829 .741 .767 r
F P
0 g
s
.57565 .34812 m .59933 .37129 L .59733 .36817 L p 0 .144 .682 r
F P
0 g
s
.59733 .36817 m .57426 .34601 L .57565 .34812 L p 0 .144 .682 r
F P
0 g
s
.60364 .39826 m .61638 .43627 L .61724 .4322 L p 0 .049 .564 r
F P
0 g
s
.61724 .4322 m .60422 .3949 L .60364 .39826 L p 0 .049 .564 r
F P
0 g
s
.46906 .53696 m .46944 .51009 L .4748 .51286 L p .762 .497 .532 r
F P
0 g
s
.4748 .51286 m .47512 .54001 L .46906 .53696 L p .762 .497 .532 r
F P
0 g
s
.56905 .54013 m .57428 .55957 L .56697 .56155 L p .699 .571 .707 r
F P
0 g
s
.43622 .48317 m .44206 .44968 L .44461 .45298 L p .972 .756 .553 r
F P
0 g
s
.44461 .45298 m .43883 .48652 L .43622 .48317 L p .972 .756 .553 r
F P
0 g
s
.57428 .55957 m .56905 .54013 L .57506 .53825 L p .653 .545 .719 r
F P
0 g
s
.57506 .53825 m .58114 .5575 L .57428 .55957 L p .653 .545 .719 r
F P
0 g
s
.5445 .56637 m .54322 .5468 L .5497 .54534 L p .794 .61 .653 r
F P
0 g
s
.5497 .54534 m .55186 .56498 L .5445 .56637 L p .794 .61 .653 r
F P
0 g
s
.53152 .58495 m .53257 .60398 L .5244 .6025 L p .879 .819 .785 r
F P
0 g
s
.53257 .60398 m .53152 .58495 L .53915 .58479 L p .864 .808 .793 r
F P
0 g
s
.60515 .45713 m .60741 .4937 L .60971 .49097 L p .185 .071 .48 r
F P
0 g
s
.60971 .49097 m .60771 .45411 L .60515 .45713 L p .185 .071 .48 r
F P
0 g
s
.45692 .36762 m .47933 .34508 L .47784 .34717 L p .739 .951 .644 r
F P
0 g
s
.47784 .34717 m .45479 .37073 L .45692 .36762 L p .739 .951 .644 r
F P
0 g
s
.46298 .5336 m .46418 .50707 L .46944 .51009 L p .774 .516 .544 r
F P
0 g
s
.46944 .51009 m .46906 .53696 L .46298 .5336 L p .774 .516 .544 r
F P
0 g
s
.41592 .66337 m .42616 .63678 L .44302 .63578 L p .627 .489 .675 r
F P
0 g
s
.42616 .63678 m .44082 .61151 L .45505 .61209 L p .62 .53 .731 r
F P
0 g
s
.45505 .61209 m .44302 .63578 L .42616 .63678 L p .62 .53 .731 r
F P
0 g
s
.26162 .6373 m .28758 .60349 L .29696 .61223 L p .852 .76 .761 r
F P
0 g
s
.29696 .61223 m .27216 .64679 L .26162 .6373 L p .852 .76 .761 r
F P
0 g
s
.33272 .58223 m .29696 .61223 L .28758 .60349 L p .787 .766 .834 r
F P
0 g
s
.43509 .42985 m .44836 .39309 L .44868 .39625 L p .964 .893 .515 r
F P
0 g
s
.44868 .39625 m .43529 .43318 L .43509 .42985 L p .964 .893 .515 r
F P
0 g
s
.57506 .53825 m .58114 .5575 L .58731 .55538 L p .603 .513 .726 r
F P
0 g
s
.58731 .55538 m .58064 .53635 L .57506 .53825 L p .603 .513 .726 r
F P
0 g
s
.41592 .66337 m .41308 .68646 L .39164 .69078 L p .625 .418 .582 r
F P
0 g
s
.41308 .68646 m .41592 .66337 L .43458 .66055 L p .608 .405 .581 r
F P
0 g
s
.44302 .63578 m .43458 .66055 L .41592 .66337 L p .627 .489 .675 r
F P
0 g
s
.63559 .58364 m .61416 .56509 L .61109 .56779 L p .372 .602 .937 r
F P
0 g
s
.61416 .56509 m .63559 .58364 L .63665 .57949 L p .228 .538 .925 r
F P
0 g
s
.66209 .60201 m .63665 .57949 L .63559 .58364 L p .228 .516 .912 r
F P
0 g
s
.63665 .57949 m .66209 .60201 L .66056 .59574 L p .058 .437 .874 r
F P
0 g
s
.6843 .62126 m .66056 .59574 L .66209 .60201 L p 0 .329 .814 r
F P
0 g
s
.53749 .5675 m .53689 .54805 L .54322 .5468 L p .815 .613 .629 r
F P
0 g
s
.54322 .5468 m .5445 .56637 L .53749 .5675 L p .815 .613 .629 r
F P
0 g
s
.57426 .34601 m .59733 .36817 L .59502 .36519 L p 0 .105 .638 r
F P
0 g
s
.59502 .36519 m .57268 .34397 L .57426 .34601 L p 0 .105 .638 r
F P
0 g
s
.59162 .50488 m .59402 .5309 L .59725 .52918 L p .371 .216 .537 r
F P
0 g
s
.59725 .52918 m .59549 .50286 L .59162 .50488 L p .371 .216 .537 r
F P
0 g
s
.457 .53 m .45911 .50384 L .46418 .50707 L p .791 .539 .556 r
F P
0 g
s
.46418 .50707 m .46298 .5336 L .457 .53 L p .791 .539 .556 r
F P
0 g
s
.425 .61032 m .44331 .58834 L .45584 .59068 L p .611 .547 .758 r
F P
0 g
s
.45584 .59068 m .44082 .61151 L .425 .61032 L p .611 .547 .758 r
F P
0 g
s
.45933 .36457 m .48101 .34306 L .47933 .34508 L p .663 .915 .601 r
F P
0 g
s
.47933 .34508 m .45692 .36762 L .45933 .36457 L p .663 .915 .601 r
F P
0 g
s
.60422 .3949 m .61724 .4322 L .61777 .42802 L p 0 .002 .544 r
F P
0 g
s
.61777 .42802 m .60449 .39149 L .60422 .3949 L p 0 .002 .544 r
F P
0 g
s
.33093 .71737 m .3214 .69546 L .34483 .69582 L p .669 .344 .414 r
F P
0 g
s
.34483 .69582 m .35333 .71605 L .33093 .71737 L p .669 .344 .414 r
F P
0 g
s
.35333 .71605 m .34483 .69582 L .3686 .6941 L p .627 .316 .424 r
F P
0 g
s
.43417 .47994 m .43991 .44638 L .44206 .44968 L p .993 .788 .524 r
F P
0 g
s
.44206 .44968 m .43622 .48317 L .43417 .47994 L p .993 .788 .524 r
F P
0 g
s
.5924 .36234 m .5709 .34201 L .57268 .34397 L p 0 .064 .581 r
F P
0 g
s
.5709 .34201 m .5924 .36234 L .58949 .35964 L p 0 .023 .515 r
F P
0 g
s
.58949 .35964 m .56892 .34013 L .57066 .34178 L p 0 .023 .515 r
F P
0 g
s
.57066 .34178 m .5709 .34201 L p .57204 .34309 L 0 .023 .515 r
F P
0 g
s
.58949 .35964 m .57066 .34178 L .57204 .34309 L 0 .023 .515 r
F
.57268 .34397 m .59502 .36519 L .59301 .363 L p 0 .064 .581 r
F P
0 g
s
.59301 .363 m .5924 .36234 L p .58776 .35802 L 0 .064 .581 r
F P
0 g
s
.58776 .35802 m .57268 .34397 L .59301 .363 L 0 .064 .581 r
F
.53094 .56836 m .53077 .54905 L .53689 .54805 L p .829 .609 .605 r
F P
0 g
s
.53689 .54805 m .53749 .5675 L .53094 .56836 L p .829 .609 .605 r
F P
0 g
s
.58064 .53635 m .58731 .55538 L .59264 .55329 L p .551 .476 .724 r
F P
0 g
s
.59264 .55329 m .5857 .53449 L .58064 .53635 L p .551 .476 .724 r
F P
0 g
s
.45127 .52621 m .45428 .50046 L .45911 .50384 L p .811 .566 .568 r
F P
0 g
s
.45911 .50384 m .457 .53 L .45127 .52621 L p .811 .566 .568 r
F P
0 g
s
.60771 .45411 m .60971 .49097 L .61181 .48797 L p .121 .022 .458 r
F P
0 g
s
.61181 .48797 m .61 .45091 L .60771 .45411 L p .121 .022 .458 r
F P
0 g
s
.30997 .71618 m .29948 .69275 L .3214 .69546 L p .717 .373 .394 r
F P
0 g
s
.3214 .69546 m .33093 .71737 L .30997 .71618 L p .717 .373 .394 r
F P
0 g
s
.3686 .6941 m .37605 .71258 L .35333 .71605 L p .627 .316 .424 r
F P
0 g
s
.37605 .71258 m .3686 .6941 L .39164 .69078 L p .59 .289 .426 r
F P
0 g
s
.28758 .60349 m .32497 .57472 L .33272 .58223 L p .787 .766 .834 r
F P
0 g
s
.37096 .55986 m .33272 .58223 L .32497 .57472 L p .733 .76 .874 r
F P
0 g
s
.33272 .58223 m .37096 .55986 L .37966 .56591 L p .718 .714 .845 r
F P
0 g
s
.43525 .42649 m .44835 .38991 L .44836 .39309 L p .924 .883 .463 r
F P
0 g
s
.44836 .39309 m .43509 .42985 L .43525 .42649 L p .924 .883 .463 r
F P
0 g
s
.46204 .3616 m .48289 .34112 L .48101 .34306 L p .575 .866 .55 r
F P
0 g
s
.48101 .34306 m .45933 .36457 L .46204 .3616 L p .575 .866 .55 r
F P
0 g
s
.50355 .6952 m .50238 .68362 L .51207 .69134 L p .916 .529 .255 r
F P
0 g
s
.51207 .69134 m .51276 .70373 L .50355 .6952 L p .916 .529 .255 r
F P
0 g
s
.69397 .73666 m .67503 .74465 L .67888 .73153 L p .896 .974 .817 r
F P
0 g
s
.67888 .73153 m .69843 .72329 L .69397 .73666 L p .896 .974 .817 r
F P
0 g
s
.49346 .67789 m .49424 .65956 L .50295 .66436 L p .886 .651 .578 r
F P
0 g
s
.50295 .66436 m .50238 .68362 L .49346 .67789 L p .886 .651 .578 r
F P
0 g
s
.50508 .64119 m .50295 .66436 L .49424 .65956 L p .854 .717 .711 r
F P
0 g
s
.53749 .5675 m .53915 .58479 L .53152 .58495 L p .876 .753 .723 r
F P
0 g
s
.53915 .58479 m .53749 .5675 L .5445 .56637 L p .855 .749 .746 r
F P
0 g
s
.59549 .50286 m .59725 .52918 L .59991 .52749 L p .305 .154 .505 r
F P
0 g
s
.59991 .52749 m .59897 .50076 L .59549 .50286 L p .305 .154 .505 r
F P
0 g
s
.44592 .52235 m .44977 .49698 L .45428 .50046 L p .836 .598 .578 r
F P
0 g
s
.45428 .50046 m .45127 .52621 L .44592 .52235 L p .836 .598 .578 r
F P
0 g
s
.52487 .56894 m .5249 .54979 L .53077 .54905 L p .836 .598 .579 r
F P
0 g
s
.53077 .54905 m .53094 .56836 L .52487 .56894 L p .836 .598 .579 r
F P
0 g
s
.50508 .64119 m .50808 .61852 L .51549 .62151 L p .861 .781 .771 r
F P
0 g
s
.51731 .60093 m .51549 .62151 L .50808 .61852 L p .857 .813 .806 r
F P
0 g
s
.51549 .62151 m .51731 .60093 L .5244 .6025 L p .868 .817 .797 r
F P
0 g
s
.42759 .55926 m .40293 .57691 L .3905 .57167 L p .662 .633 .81 r
F P
0 g
s
.40293 .57691 m .42759 .55926 L .43757 .56376 L p .645 .602 .79 r
F P
0 g
s
.43757 .56376 m .4163 .58148 L .40293 .57691 L p .645 .602 .79 r
F P
0 g
s
.58395 .759 m .59537 .76704 L .61254 .77127 L p .017 .543 .856 r
F P
0 g
s
.59821 .76324 m .61254 .77127 L .62915 .77231 L p .235 .709 .94 r
F P
0 g
s
.60449 .39149 m .61777 .42802 L .61796 .42376 L p 0 0 .517 r
F P
0 g
s
.61796 .42376 m .60444 .38805 L .60449 .39149 L p 0 0 .517 r
F P
0 g
s
.61109 .56779 m .597 .55127 L .59264 .55329 L p .489 .595 .886 r
F P
0 g
s
.597 .55127 m .61109 .56779 L .61416 .56509 L p .385 .54 .886 r
F P
0 g
s
.49424 .65956 m .49714 .63756 L .50508 .64119 L p .854 .717 .711 r
F P
0 g
s
.50808 .61852 m .50508 .64119 L .49714 .63756 L p .831 .76 .784 r
F P
0 g
s
.46501 .35874 m .48495 .33925 L .48289 .34112 L p 0 0 0 r
F P
0 g
s
.48289 .34112 m .46204 .3616 L .46501 .35874 L p 0 0 0 r
F P
0 g
s
.41832 .55441 m .3905 .57167 L .37966 .56591 L p .678 .668 .834 r
F P
0 g
s
.3905 .57167 m .41832 .55441 L .42759 .55926 L p .662 .633 .81 r
F P
0 g
s
.43458 .66055 m .44302 .63578 L .45764 .63469 L p .625 .491 .68 r
F P
0 g
s
.44302 .63578 m .45505 .61209 L .46742 .61236 L p .618 .534 .737 r
F P
0 g
s
.46742 .61236 m .45764 .63469 L .44302 .63578 L p .618 .534 .737 r
F P
0 g
s
.43458 .66055 m .43227 .68185 L .41308 .68646 L p .608 .405 .581 r
F P
0 g
s
.43227 .68185 m .43458 .66055 L .45073 .65791 L p .604 .403 .582 r
F P
0 g
s
.45764 .63469 m .45073 .65791 L .43458 .66055 L p .625 .491 .68 r
F P
0 g
s
.56985 .7522 m .5784 .76 L .59537 .76704 L p 0 .388 .77 r
F P
0 g
s
.43268 .47684 m .43816 .44308 L .43991 .44638 L p .999 .811 .477 r
F P
0 g
s
.43991 .44638 m .43417 .47994 L .43268 .47684 L p .999 .811 .477 r
F P
0 g
s
.5857 .53449 m .59264 .55329 L .597 .55127 L p .486 .425 .714 r
F P
0 g
s
.597 .55127 m .59017 .53266 L .5857 .53449 L p .486 .425 .714 r
F P
0 g
s
.4163 .58148 m .43757 .56376 L .44781 .5678 L p .629 .573 .773 r
F P
0 g
s
.44781 .5678 m .42996 .5853 L .4163 .58148 L p .629 .573 .773 r
F P
0 g
s
.62915 .77231 m .61199 .76455 L .59821 .76324 L p .235 .709 .94 r
F P
0 g
s
.61199 .76455 m .62915 .77231 L .64437 .77001 L p .461 .84 .987 r
F P
0 g
s
.39164 .69078 m .39807 .70752 L .37605 .71258 L p .59 .289 .426 r
F P
0 g
s
.39807 .70752 m .39164 .69078 L .41308 .68646 L p .558 .263 .424 r
F P
0 g
s
.56892 .34013 m .58949 .35964 L .58629 .35711 L p .548 .016 0 r
F P
0 g
s
.58629 .35711 m .56677 .33834 L .56892 .34013 L p .548 .016 0 r
F P
0 g
s
.25379 .67053 m .26162 .6373 L .27216 .64679 L p .924 .715 .602 r
F P
0 g
s
.27216 .64679 m .26469 .6801 L .25379 .67053 L p .924 .715 .602 r
F P
0 g
s
.61 .45091 m .61181 .48797 L .61377 .48468 L p .053 0 .434 r
F P
0 g
s
.61377 .48468 m .61202 .44752 L .61 .45091 L p .053 0 .434 r
F P
0 g
s
.43574 .42308 m .44866 .38671 L .44835 .38991 L p .867 .857 .403 r
F P
0 g
s
.44835 .38991 m .43525 .42649 L .43574 .42308 L p .867 .857 .403 r
F P
0 g
s
.29159 .7123 m .28022 .6876 L .29948 .69275 L p .774 .403 .354 r
F P
0 g
s
.29948 .69275 m .30997 .71618 L .29159 .7123 L p .774 .403 .354 r
F P
0 g
s
.44082 .61151 m .45584 .59068 L .46718 .59242 L p .601 .539 .757 r
F P
0 g
s
.46718 .59242 m .45505 .61209 L .44082 .61151 L p .601 .539 .757 r
F P
0 g
s
.44111 .51848 m .44565 .49347 L .44977 .49698 L p .866 .635 .587 r
F P
0 g
s
.44977 .49698 m .44592 .52235 L .44111 .51848 L p .866 .635 .587 r
F P
0 g
s
.46826 .35601 m .48718 .33748 L .48495 .33925 L p 0 0 0 r
F P
0 g
s
.48495 .33925 m .46501 .35874 L .46826 .35601 L p 0 0 0 r
F P
0 g
s
.51925 .56924 m .51926 .55021 L .5249 .54979 L p .836 .58 .553 r
F P
0 g
s
.5249 .54979 m .52487 .56894 L .51925 .56924 L p .836 .58 .553 r
F P
0 g
s
.52471 .58483 m .5244 .6025 L .51731 .60093 L p .884 .822 .781 r
F P
0 g
s
.5244 .6025 m .52471 .58483 L .53152 .58495 L p .879 .819 .785 r
F P
0 g
s
.56677 .33834 m .58629 .35711 L .58284 .35474 L p .597 .05 0 r
F P
0 g
s
.58284 .35474 m .56445 .33665 L .56677 .33834 L p .597 .05 0 r
F P
0 g
s
.60444 .38805 m .61796 .42376 L .61777 .41947 L p 0 0 .48 r
F P
0 g
s
.61777 .41947 m .60407 .38461 L .60444 .38805 L p 0 0 .48 r
F P
0 g
s
.4102 .54938 m .37966 .56591 L .37096 .55986 L p .691 .708 .861 r
F P
0 g
s
.37966 .56591 m .4102 .54938 L .41832 .55441 L p .678 .668 .834 r
F P
0 g
s
.59897 .50076 m .59991 .52749 L .6021 .52577 L p .233 .085 .466 r
F P
0 g
s
.6021 .52577 m .60209 .49855 L .59897 .50076 L p .233 .085 .466 r
F P
0 g
s
.47177 .35343 m .48959 .33581 L .48718 .33748 L p 0 0 0 r
F P
0 g
s
.48718 .33748 m .46826 .35601 L .47177 .35343 L p 0 0 0 r
F P
0 g
s
.42996 .5853 m .44781 .5678 L .45789 .57132 L p .613 .549 .758 r
F P
0 g
s
.45789 .57132 m .44331 .58834 L .42996 .5853 L p .613 .549 .758 r
F P
0 g
s
.53152 .58495 m .53094 .56836 L .53749 .5675 L p .876 .753 .723 r
F P
0 g
s
.55647 .74338 m .56233 .7507 L .5784 .76 L p 0 .27 .708 r
F P
0 g
s
.51398 .56924 m .5138 .55031 L .51926 .55021 L p .825 .555 .53 r
F P
0 g
s
.51926 .55021 m .51925 .56924 L .51398 .56924 L p .825 .555 .53 r
F P
0 g
s
.66056 .59574 m .6843 .62126 L .68015 .61268 L p 0 .229 .736 r
F P
0 g
s
.6843 .62126 m .70082 .6494 L .69619 .63814 L p 0 0 .498 r
F P
0 g
s
.69619 .63814 m .68015 .61268 L .6843 .62126 L p 0 0 .498 r
F P
0 g
s
.70782 .68906 m .69926 .70878 L .69692 .6939 L p .99 .877 .54 r
F P
0 g
s
.69692 .6939 m .70551 .67528 L .70782 .68906 L p .99 .877 .54 r
F P
0 g
s
.56445 .33665 m .58284 .35474 L .57914 .35254 L p .633 .079 0 r
F P
0 g
s
.57914 .35254 m .56196 .33507 L .56445 .33665 L p .633 .079 0 r
F P
0 g
s
.25613 .62669 m .28274 .59417 L .28758 .60349 L p .895 .845 .788 r
F P
0 g
s
.28758 .60349 m .26162 .6373 L .25613 .62669 L p .895 .845 .788 r
F P
0 g
s
.32497 .57472 m .28758 .60349 L .28274 .59417 L p .808 .83 .867 r
F P
0 g
s
.43173 .47387 m .43681 .43978 L .43816 .44308 L p .977 .814 .403 r
F P
0 g
s
.43816 .44308 m .43268 .47684 L .43173 .47387 L p .977 .814 .403 r
F P
0 g
s
.64437 .77001 m .62462 .76278 L .6355 .75795 L p .63 .904 .984 r
F P
0 g
s
.6355 .75795 m .65748 .76442 L .64437 .77001 L p .63 .904 .984 r
F P
0 g
s
.64437 .77001 m .62462 .76278 L .61199 .76455 L p .461 .84 .987 r
F P
0 g
s
.43698 .5147 m .44198 .48997 L .44565 .49347 L p .901 .678 .591 r
F P
0 g
s
.44565 .49347 m .44111 .51848 L .43698 .5147 L p .901 .678 .591 r
F P
0 g
s
.59017 .53266 m .597 .55127 L .60035 .54937 L p .407 .358 .692 r
F P
0 g
s
.60035 .54937 m .59402 .5309 L .59017 .53266 L p .407 .358 .692 r
F P
0 g
s
.43655 .41959 m .44927 .3835 L .44866 .38671 L p .794 .816 .336 r
F P
0 g
s
.44866 .38671 m .43574 .42308 L .43655 .41959 L p .794 .816 .336 r
F P
0 g
s
.61202 .44752 m .61377 .48468 L .61558 .48107 L p 0 0 .408 r
F P
0 g
s
.61558 .48107 m .61376 .44395 L .61202 .44752 L p 0 0 .408 r
F P
0 g
s
.47553 .35103 m .49215 .33424 L .48959 .33581 L p 0 0 0 r
F P
0 g
s
.48959 .33581 m .47177 .35343 L .47553 .35103 L p 0 0 0 r
F P
0 g
s
.41308 .68646 m .41854 .70157 L .39807 .70752 L p .558 .263 .424 r
F P
0 g
s
.41854 .70157 m .41308 .68646 L .43227 .68185 L p .533 .241 .416 r
F P
0 g
s
.53094 .56836 m .53152 .58495 L .52471 .58483 L p .89 .75 .7 r
F P
0 g
s
.48446 .67449 m .48545 .65658 L .49424 .65956 L p .823 .596 .595 r
F P
0 g
s
.49424 .65956 m .49346 .67789 L .48446 .67449 L p .823 .596 .595 r
F P
0 g
s
.49714 .63756 m .49424 .65956 L .48545 .65658 L p .8 .671 .721 r
F P
0 g
s
.45073 .65791 m .44887 .67769 L .43227 .68185 L p .604 .403 .582 r
F P
0 g
s
.44887 .67769 m .45073 .65791 L .46435 .65603 L p .62 .418 .587 r
F P
0 g
s
.45073 .65791 m .45764 .63469 L .46998 .63396 L p .639 .51 .69 r
F P
0 g
s
.46998 .63396 m .46435 .65603 L .45073 .65791 L p .639 .51 .69 r
F P
0 g
s
.45764 .63469 m .46742 .61236 L .47791 .61265 L p .631 .554 .749 r
F P
0 g
s
.47791 .61265 m .46998 .63396 L .45764 .63469 L p .631 .554 .749 r
F P
0 g
s
.56196 .33507 m .57914 .35254 L .57521 .35051 L p .656 .101 0 r
F P
0 g
s
.57521 .35051 m .55932 .3336 L .56196 .33507 L p .656 .101 0 r
F P
0 g
s
.60407 .38461 m .61777 .41947 L .61718 .41519 L p 0 0 .431 r
F P
0 g
s
.61718 .41519 m .60338 .3812 L .60407 .38461 L p 0 0 .431 r
F P
0 g
s
.28274 .59417 m .32101 .56711 L .32497 .57472 L p .808 .83 .867 r
F P
0 g
s
.36489 .55375 m .32497 .57472 L .32101 .56711 L p .742 .813 .908 r
F P
0 g
s
.32497 .57472 m .36489 .55375 L .37096 .55986 L p .733 .76 .874 r
F P
0 g
s
.48545 .65658 m .48914 .63516 L .49714 .63756 L p .8 .671 .721 r
F P
0 g
s
.50123 .6161 m .49714 .63756 L .48914 .63516 L p .78 .714 .79 r
F P
0 g
s
.49714 .63756 m .50123 .6161 L .50808 .61852 L p .831 .76 .784 r
F P
0 g
s
.5089 .56893 m .50847 .55004 L .5138 .55031 L p .806 .525 .512 r
F P
0 g
s
.5138 .55031 m .51398 .56924 L .5089 .56893 L p .806 .525 .512 r
F P
0 g
s
.63665 .57949 m .61573 .56257 L .61416 .56509 L p .228 .538 .925 r
F P
0 g
s
.61573 .56257 m .63665 .57949 L .63586 .5756 L p .059 .45 .879 r
F P
0 g
s
.66056 .59574 m .63586 .5756 L .63665 .57949 L p .058 .437 .874 r
F P
0 g
s
.51276 .70373 m .52337 .71395 L p .51545 .70748 L .67 .181 0 r
F P
0 g
s
.52337 .71395 m .52371 .71691 L .51428 .70653 L p .67 .181 0 r
F P
0 g
s
.52413 .71186 m .51614 .7023 L p .52262 .71481 L 0 .219 .736 r
F P
0 g
s
.52371 .71691 m .52378 .71599 L p .52262 .71481 L 0 .219 .736 r
F P
0 g
s
.52378 .71599 m .52413 .71186 L p .52262 .71481 L 0 .219 .736 r
F P
0 g
s
.51428 .70653 m .51399 .706 L p .51545 .70748 L .67 .181 0 r
F P
0 g
s
.51399 .706 m .51276 .70373 L p .51545 .70748 L .67 .181 0 r
F P
0 g
s
.47952 .34882 m .49486 .3328 L .49215 .33424 L p 0 0 0 r
F P
0 g
s
.49215 .33424 m .47553 .35103 L .47952 .34882 L p 0 0 0 r
F P
0 g
s
.49508 .68897 m .49346 .67789 L .50238 .68362 L p .886 .485 .256 r
F P
0 g
s
.50238 .68362 m .50355 .6952 L .49508 .68897 L p .886 .485 .256 r
F P
0 g
s
.55932 .3336 m .57521 .35051 L .57108 .34865 L p .668 .117 0 r
F P
0 g
s
.57108 .34865 m .55654 .33224 L .55932 .3336 L p .668 .117 0 r
F P
0 g
s
.45505 .61209 m .46718 .59242 L .47714 .59374 L p .6 .542 .761 r
F P
0 g
s
.47714 .59374 m .46742 .61236 L .45505 .61209 L p .6 .542 .761 r
F P
0 g
s
.51104 .59941 m .50808 .61852 L .50123 .6161 L p .825 .788 .817 r
F P
0 g
s
.50808 .61852 m .51104 .59941 L .51731 .60093 L p .857 .813 .806 r
F P
0 g
s
.70082 .6494 m .70551 .67528 L .70068 .66191 L p .877 .585 .066 r
F P
0 g
s
.70068 .66191 m .69619 .63814 L .70082 .6494 L p .877 .585 .066 r
F P
0 g
s
.60209 .49855 m .6021 .52577 L .60393 .52397 L p .156 .013 .422 r
F P
0 g
s
.60393 .52397 m .60489 .49622 L .60209 .49855 L p .156 .013 .422 r
F P
0 g
s
.61416 .56509 m .60035 .54937 L .597 .55127 L p .385 .54 .886 r
F P
0 g
s
.40363 .54433 m .37096 .55986 L .36489 .55375 L p .702 .753 .892 r
F P
0 g
s
.37096 .55986 m .40363 .54433 L .4102 .54938 L p .691 .708 .861 r
F P
0 g
s
.44331 .58834 m .45789 .57132 L .46745 .57429 L p .6 .529 .746 r
F P
0 g
s
.46745 .57429 m .45584 .59068 L .44331 .58834 L p .6 .529 .746 r
F P
0 g
s
.43362 .5111 m .43883 .48652 L .44198 .48997 L p .94 .728 .588 r
F P
0 g
s
.44198 .48997 m .43698 .5147 L .43362 .5111 L p .94 .728 .588 r
F P
0 g
s
.60035 .54937 m .61416 .56509 L .61573 .56257 L p .25 .459 .868 r
F P
0 g
s
.52471 .58483 m .52487 .56894 L .53094 .56836 L p .89 .75 .7 r
F P
0 g
s
.48373 .34682 m .4977 .33148 L .49486 .3328 L p .036 0 0 r
F P
0 g
s
.49486 .3328 m .47952 .34882 L .48373 .34682 L p .036 0 0 r
F P
0 g
s
.43767 .41603 m .4502 .38029 L .44927 .3835 L p .71 .764 .267 r
F P
0 g
s
.44927 .3835 m .43655 .41959 L .43757 .41633 L p .71 .764 .267 r
F P
0 g
s
.44927 .3835 m .43757 .41633 L .43842 .41391 L .71 .764 .267 r
F
.43909 .41239 m .45143 .37709 L .45071 .37895 L p 0 0 0 r
F P
0 g
s
.45071 .37895 m .4502 .38029 L p .44744 .38826 L 0 0 0 r
F P
0 g
s
.44744 .38826 m .43909 .41239 L .45071 .37895 L 0 0 0 r
F
.43757 .41633 m .43767 .41603 L p .43842 .41391 L .71 .764 .267 r
F P
0 g
s
.50385 .56828 m .50318 .54939 L .50847 .55004 L p .779 .493 .502 r
F P
0 g
s
.50847 .55004 m .5089 .56893 L .50385 .56828 L p .779 .493 .502 r
F P
0 g
s
.2768 .70576 m .26469 .6801 L .28022 .6876 L p .839 .431 .269 r
F P
0 g
s
.28022 .6876 m .29159 .7123 L .2768 .70576 L p .839 .431 .269 r
F P
0 g
s
.61376 .44395 m .61558 .48107 L .61727 .47714 L p 0 0 .381 r
F P
0 g
s
.61727 .47714 m .61522 .44019 L .61376 .44395 L p 0 0 .381 r
F P
0 g
s
.43128 .471 m .43586 .43648 L .43681 .43978 L p .915 .784 .303 r
F P
0 g
s
.43681 .43978 m .43173 .47387 L .43128 .471 L p .915 .784 .303 r
F P
0 g
s
.55654 .33224 m .57108 .34865 L .56676 .34696 L p .672 .127 0 r
F P
0 g
s
.56676 .34696 m .55363 .33101 L .55654 .33224 L p .672 .127 0 r
F P
0 g
s
.54425 .73319 m .54768 .73986 L .56233 .7507 L p 0 .197 .676 r
F P
0 g
s
.63586 .5756 m .66056 .59574 L .65722 .5899 L p 0 .35 .805 r
F P
0 g
s
.68015 .61268 m .65722 .5899 L .66056 .59574 L p 0 .229 .736 r
F P
0 g
s
.46435 .65603 m .46285 .6747 L .44887 .67769 L p .62 .418 .587 r
F P
0 g
s
.46285 .6747 m .46435 .65603 L .47574 .65547 L p .664 .457 .594 r
F P
0 g
s
.46435 .65603 m .46998 .63396 L .48031 .63402 L p .675 .549 .704 r
F P
0 g
s
.48031 .63402 m .47574 .65547 L .46435 .65603 L p .675 .549 .704 r
F P
0 g
s
.60338 .3812 m .61718 .41519 L .61619 .41098 L p 0 0 .368 r
F P
0 g
s
.61619 .41098 m .60236 .37782 L .60338 .3812 L p 0 0 .368 r
F P
0 g
s
.59402 .5309 m .60035 .54937 L .60271 .54761 L p .31 .272 .653 r
F P
0 g
s
.60271 .54761 m .59725 .52918 L .59402 .5309 L p .31 .272 .653 r
F P
0 g
s
.48813 .34505 m .50067 .33029 L .4977 .33148 L p .12 0 0 r
F P
0 g
s
.4977 .33148 m .48373 .34682 L .48813 .34505 L p .12 0 0 r
F P
0 g
s
.46998 .63396 m .47791 .61265 L .48674 .61323 L p .665 .594 .766 r
F P
0 g
s
.48674 .61323 m .48031 .63402 L .46998 .63396 L p .665 .594 .766 r
F P
0 g
s
.47452 .67349 m .47574 .65547 L .48545 .65658 L p .739 .522 .6 r
F P
0 g
s
.48545 .65658 m .48446 .67449 L .47452 .67349 L p .739 .522 .6 r
F P
0 g
s
.48914 .63516 m .48545 .65658 L .47574 .65547 L p .733 .608 .718 r
F P
0 g
s
.49863 .56728 m .49786 .54834 L .50318 .54939 L p .75 .464 .499 r
F P
0 g
s
.50318 .54939 m .50385 .56828 L .49863 .56728 L p .75 .464 .499 r
F P
0 g
s
.43227 .68185 m .43684 .69552 L .41854 .70157 L p .533 .241 .416 r
F P
0 g
s
.43684 .69552 m .43227 .68185 L .44887 .67769 L p .522 .225 .405 r
F P
0 g
s
.55363 .33101 m .56676 .34696 L .56226 .34544 L p .669 .131 0 r
F P
0 g
s
.56226 .34544 m .5506 .3299 L .55363 .33101 L p .669 .131 0 r
F P
0 g
s
.47574 .65547 m .48031 .63402 L .48914 .63516 L p .733 .608 .718 r
F P
0 g
s
.49432 .61434 m .48914 .63516 L .48031 .63402 L p .718 .652 .783 r
F P
0 g
s
.48914 .63516 m .49432 .61434 L .50123 .6161 L p .78 .714 .79 r
F P
0 g
s
.48813 .34505 m .50067 .33029 L .50376 .32923 L p .192 0 0 r
F P
0 g
s
.49309 .56588 m .49243 .54687 L .49786 .54834 L p .723 .445 .504 r
F P
0 g
s
.49786 .54834 m .49863 .56728 L .49309 .56588 L p .723 .445 .504 r
F P
0 g
s
.51864 .5845 m .51731 .60093 L .51104 .59941 L p .876 .811 .782 r
F P
0 g
s
.51731 .60093 m .51864 .5845 L .52471 .58483 L p .884 .822 .781 r
F P
0 g
s
.47574 .65547 m .47452 .67349 L .46285 .6747 L p .664 .457 .594 r
F P
0 g
s
.65748 .76442 m .6355 .75795 L .6441 .75031 L p .737 .918 .954 r
F P
0 g
s
.6441 .75031 m .66784 .75582 L .65748 .76442 L p .737 .918 .954 r
F P
0 g
s
.45868 .55235 m .46298 .5336 L .46906 .53696 L p .706 .494 .598 r
F P
0 g
s
.46906 .53696 m .46629 .55592 L .45868 .55235 L p .706 .494 .598 r
F P
0 g
s
.46629 .55592 m .46906 .53696 L .47512 .54001 L p .696 .469 .574 r
F P
0 g
s
.48711 .56406 m .48683 .54499 L .49243 .54687 L p .704 .436 .516 r
F P
0 g
s
.49243 .54687 m .49309 .56588 L .48711 .56406 L p .704 .436 .516 r
F P
0 g
s
.47512 .54001 m .47366 .55908 L .46629 .55592 L p .696 .469 .574 r
F P
0 g
s
.47366 .55908 m .47512 .54001 L .48106 .5427 L p .691 .45 .553 r
F P
0 g
s
.5506 .3299 m .56226 .34544 L .55762 .34408 L p .661 .131 0 r
F P
0 g
s
.55762 .34408 m .54747 .32893 L .5506 .3299 L p .661 .131 0 r
F P
0 g
s
.48031 .63402 m .48674 .61323 L .49432 .61434 L p .718 .652 .783 r
F P
0 g
s
.48106 .5427 m .48063 .56179 L .47366 .55908 L p .691 .45 .553 r
F P
0 g
s
.48063 .56179 m .48106 .5427 L .48683 .54499 L p .693 .438 .533 r
F P
0 g
s
.48683 .54499 m .48711 .56406 L .48063 .56179 L p .693 .438 .533 r
F P
0 g
s
.45106 .54843 m .457 .53 L .46298 .5336 L p .722 .523 .622 r
F P
0 g
s
.46298 .5336 m .45868 .55235 L .45106 .54843 L p .722 .523 .622 r
F P
0 g
s
.4502 .38029 m .43767 .41603 L .43909 .41239 L p 0 0 0 r
F P
0 g
s
.49271 .34351 m .50376 .32923 L .50694 .32832 L p .253 0 0 r
F P
0 g
s
.50376 .32923 m .49271 .34351 L .48813 .34505 L p .192 0 0 r
F P
0 g
s
.43112 .50775 m .43622 .48317 L .43883 .48652 L p .979 .782 .567 r
F P
0 g
s
.43883 .48652 m .43362 .5111 L .43112 .50775 L p .979 .782 .567 r
F P
0 g
s
.44367 .54424 m .42759 .55926 L .41832 .55441 L p .684 .616 .773 r
F P
0 g
s
.42759 .55926 m .44367 .54424 L .45106 .54843 L p .668 .579 .746 r
F P
0 g
s
.45106 .54843 m .43757 .56376 L .42759 .55926 L p .668 .579 .746 r
F P
0 g
s
.69843 .72329 m .67888 .73153 L .67953 .71718 L p .925 .925 .79 r
F P
0 g
s
.67953 .71718 m .69926 .70878 L .69843 .72329 L p .925 .925 .79 r
F P
0 g
s
.60489 .49622 m .60393 .52397 L .60553 .52201 L p .078 0 .375 r
F P
0 g
s
.60553 .52201 m .60741 .4937 L .60489 .49622 L p .078 0 .375 r
F P
0 g
s
.44367 .54424 m .45127 .52621 L .457 .53 L p .74 .558 .646 r
F P
0 g
s
.457 .53 m .45106 .54843 L .44367 .54424 L p .74 .558 .646 r
F P
0 g
s
.52487 .56894 m .52471 .58483 L .51864 .5845 L p .895 .737 .678 r
F P
0 g
s
.24813 .65933 m .25613 .62669 L .26162 .6373 L p .992 .814 .564 r
F P
0 g
s
.26162 .6373 m .25379 .67053 L .24813 .65933 L p .992 .814 .564 r
F P
0 g
s
.54747 .32893 m .55762 .34408 L .55285 .34288 L p .648 .127 0 r
F P
0 g
s
.55285 .34288 m .54425 .32808 L .54747 .32893 L p .648 .127 0 r
F P
0 g
s
.61522 .44019 m .61727 .47714 L .61879 .47288 L p 0 0 .352 r
F P
0 g
s
.61879 .47288 m .61638 .43627 L .61522 .44019 L p 0 0 .352 r
F P
0 g
s
.51864 .5845 m .51925 .56924 L .52487 .56894 L p .895 .737 .678 r
F P
0 g
s
.4368 .5399 m .41832 .55441 L .4102 .54938 L p .702 .657 .803 r
F P
0 g
s
.41832 .55441 m .4368 .5399 L .44367 .54424 L p .684 .616 .773 r
F P
0 g
s
.43757 .56376 m .45106 .54843 L .45868 .55235 L p .652 .546 .721 r
F P
0 g
s
.45868 .55235 m .44781 .5678 L .43757 .56376 L p .652 .546 .721 r
F P
0 g
s
.49744 .34222 m .50694 .32832 L .5102 .32756 L p .309 0 0 r
F P
0 g
s
.50694 .32832 m .49744 .34222 L .49271 .34351 L p .253 0 0 r
F P
0 g
s
.46742 .61236 m .47714 .59374 L .48568 .5948 L p .615 .563 .773 r
F P
0 g
s
.48568 .5948 m .47791 .61265 L .46742 .61236 L p .615 .563 .773 r
F P
0 g
s
.60236 .37782 m .61619 .41098 L .61476 .40689 L p 0 0 .291 r
F P
0 g
s
.61476 .40689 m .60101 .37451 L .60236 .37782 L p 0 0 .291 r
F P
0 g
s
.45584 .59068 m .46745 .57429 L .47624 .57673 L p .592 .516 .738 r
F P
0 g
s
.47624 .57673 m .46718 .59242 L .45584 .59068 L p .592 .516 .738 r
F P
0 g
s
.43128 .46819 m .43529 .43318 L .43586 .43648 L p .812 .718 .185 r
F P
0 g
s
.43128 .46819 m .43165 .46539 L p .43393 .44522 L 0 0 0 r
F P
0 g
s
.43529 .43318 m .43413 .44332 L p .43393 .44522 L 0 0 0 r
F P
0 g
s
.43413 .44332 m .43128 .46819 L p .43393 .44522 L 0 0 0 r
F P
0 g
s
.43509 .42985 m .43529 .43318 L p .43393 .44522 L 0 0 0 r
F P
0 g
s
.43165 .46539 m .43509 .42985 L p .43393 .44522 L 0 0 0 r
F P
0 g
s
.43128 .471 m .43128 .46819 L p .43332 .45407 L .812 .718 .185 r
F P
0 g
s
.43316 .4568 m .43128 .471 L p .43332 .45407 L .812 .718 .185 r
F P
0 g
s
.43165 .46539 m .43234 .46255 L p .43398 .44313 L 0 0 .035 r
F P
0 g
s
.43509 .42985 m .434 .44109 L p .43398 .44313 L 0 0 .035 r
F P
0 g
s
.434 .44109 m .43165 .46539 L p .43398 .44313 L 0 0 .035 r
F P
0 g
s
.43525 .42649 m .43509 .42985 L p .43382 .44502 L 0 0 .035 r
F P
0 g
s
.43574 .42308 m .43525 .42649 L p .43389 .44948 L 0 0 .116 r
F P
0 g
s
.43586 .43648 m .43316 .4568 L p .43332 .45407 L .812 .718 .185 r
F P
0 g
s
.43329 .4596 m .43387 .45097 L p .43389 .44948 L 0 0 .116 r
F P
0 g
s
.43387 .45097 m .43574 .42308 L p .43389 .44948 L 0 0 .116 r
F P
0 g
s
.43382 .44502 m .43326 .45168 L .43396 .44254 L 0 0 .035 r
F
.43234 .46255 m .43309 .45333 L p .43326 .45168 L F P
0 g
s
.43309 .45333 m .43396 .44254 L p .43326 .45168 L 0 0 .035 r
F P
0 g
s
.43396 .44254 m .43525 .42649 L p .43382 .44502 L 0 0 .035 r
F P
0 g
s
.54425 .32808 m .55285 .34288 L .54797 .34185 L p .633 .119 .006 r
F P
0 g
s
.54797 .34185 m .54095 .32737 L .54425 .32808 L p .633 .119 .006 r
F P
0 g
s
.4368 .5399 m .44592 .52235 L .45127 .52621 L p .763 .597 .672 r
F P
0 g
s
.45127 .52621 m .44367 .54424 L .4368 .5399 L p .763 .597 .672 r
F P
0 g
s
.50231 .34117 m .5102 .32756 L .51354 .32694 L p .358 0 0 r
F P
0 g
s
.5102 .32756 m .50231 .34117 L .49744 .34222 L p .309 0 0 r
F P
0 g
s
.48652 .68539 m .48446 .67449 L .49346 .67789 L p .811 .408 .287 r
F P
0 g
s
.49346 .67789 m .49508 .68897 L .48652 .68539 L p .811 .408 .287 r
F P
0 g
s
.50521 .59803 m .50123 .6161 L .49432 .61434 L p .772 .738 .821 r
F P
0 g
s
.50123 .6161 m .50521 .59803 L .51104 .59941 L p .825 .788 .817 r
F P
0 g
s
.54095 .32737 m .54797 .34185 L .543 .34099 L p .614 .107 .021 r
F P
0 g
s
.543 .34099 m .53759 .32681 L .54095 .32737 L p .614 .107 .021 r
F P
0 g
s
.50727 .34037 m .51354 .32694 L .51693 .32647 L p .403 0 0 r
F P
0 g
s
.51354 .32694 m .50727 .34037 L .50231 .34117 L p .358 0 0 r
F P
0 g
s
.61573 .56257 m .60271 .54761 L .60035 .54937 L p .25 .459 .868 r
F P
0 g
s
.53759 .32681 m .543 .34099 L .53795 .3403 L p .593 .091 .032 r
F P
0 g
s
.53795 .3403 m .53419 .32638 L .53759 .32681 L p .593 .091 .032 r
F P
0 g
s
.44887 .67769 m .45266 .69018 L .43684 .69552 L p .522 .225 .405 r
F P
0 g
s
.45266 .69018 m .44887 .67769 L .46285 .6747 L p .534 .224 .388 r
F P
0 g
s
.51232 .33981 m .51693 .32647 L .52036 .32615 L p .443 0 .015 r
F P
0 g
s
.51693 .32647 m .51232 .33981 L .50727 .34037 L p .403 0 0 r
F P
0 g
s
.59725 .52918 m .60271 .54761 L .60421 .54598 L p .198 .166 .594 r
F P
0 g
s
.60421 .54598 m .59991 .52749 L .59725 .52918 L p .198 .166 .594 r
F P
0 g
s
.44781 .5678 m .45868 .55235 L .46629 .55592 L p .638 .516 .698 r
F P
0 g
s
.46629 .55592 m .45789 .57132 L .44781 .5678 L p .638 .516 .698 r
F P
0 g
s
.32101 .56711 m .36173 .54789 L .36489 .55375 L p .742 .813 .908 r
F P
0 g
s
.39893 .53947 m .36489 .55375 L .36173 .54789 L p .704 .805 .928 r
F P
0 g
s
.36489 .55375 m .39893 .53947 L .40363 .54433 L p .702 .753 .892 r
F P
0 g
s
.53419 .32638 m .53795 .3403 L .53285 .3398 L p .569 .072 .037 r
F P
0 g
s
.53285 .3398 m .53074 .3261 L .53419 .32638 L p .569 .072 .037 r
F P
0 g
s
.44081 .40867 m .45296 .3739 L .45143 .37709 L p 0 0 0 r
F P
0 g
s
.45143 .37709 m .43909 .41239 L .44081 .40867 L p 0 0 0 r
F P
0 g
s
.43073 .53554 m .4102 .54938 L .40363 .54433 L p .719 .705 .836 r
F P
0 g
s
.4102 .54938 m .43073 .53554 L .4368 .5399 L p .702 .657 .803 r
F P
0 g
s
.51743 .33948 m .52036 .32615 L .52381 .32599 L p .479 0 .026 r
F P
0 g
s
.52036 .32615 m .51743 .33948 L .51232 .33981 L p .443 0 .015 r
F P
0 g
s
.53074 .3261 m .53285 .3398 L .52771 .33948 L p .542 .05 .038 r
F P
0 g
s
.52771 .33948 m .52728 .32597 L .53074 .3261 L p .542 .05 .038 r
F P
0 g
s
.52256 .33937 m .52381 .32599 L .52728 .32597 L p .512 .024 .034 r
F P
0 g
s
.52381 .32599 m .52256 .33937 L .51743 .33948 L p .479 0 .026 r
F P
0 g
s
.43073 .53554 m .44111 .51848 L .44592 .52235 L p .791 .643 .699 r
F P
0 g
s
.44592 .52235 m .4368 .5399 L .43073 .53554 L p .791 .643 .699 r
F P
0 g
s
.52728 .32597 m .52771 .33948 L .52256 .33937 L p .512 .024 .034 r
F P
0 g
s
.50609 .69794 m .50355 .6952 L .51276 .70373 L p .591 .094 0 r
F P
0 g
s
.51276 .70373 m .51428 .70653 L .50609 .69794 L p .591 .094 0 r
F P
0 g
s
.60101 .37451 m .61476 .40689 L .6129 .40295 L p .729 .351 0 r
F P
0 g
s
.6129 .40295 m .59933 .37129 L .60101 .37451 L p .729 .351 0 r
F P
0 g
s
.42949 .5047 m .43417 .47994 L .43622 .48317 L p 1 .826 .511 r
F P
0 g
s
.43622 .48317 m .43112 .50775 L .42949 .5047 L p 1 .826 .511 r
F P
0 g
s
.53345 .72242 m .53478 .7283 L .54768 .73986 L p 0 .166 .673 r
F P
0 g
s
.61638 .43627 m .61879 .47288 L .62013 .46832 L p 0 0 .321 r
F P
0 g
s
.62013 .46832 m .61724 .4322 L .61638 .43627 L p 0 0 .321 r
F P
0 g
s
.60741 .4937 m .60553 .52201 L .60703 .5198 L p .001 0 .329 r
F P
0 g
s
.60703 .5198 m .60971 .49097 L .60741 .4937 L p .001 0 .329 r
F P
0 g
s
.47791 .61265 m .48568 .5948 L .49298 .59578 L p .65 .606 .792 r
F P
0 g
s
.49298 .59578 m .48674 .61323 L .47791 .61265 L p .65 .606 .792 r
F P
0 g
s
.51314 .58399 m .51398 .56924 L .51925 .56924 L p .886 .711 .659 r
F P
0 g
s
.51925 .56924 m .51864 .5845 L .51314 .58399 L p .886 .711 .659 r
F P
0 g
s
.25596 .61549 m .28267 .58474 L .28274 .59417 L p .917 .944 .803 r
F P
0 g
s
.28274 .59417 m .25613 .62669 L .25596 .61549 L p .917 .944 .803 r
F P
0 g
s
.32101 .56711 m .28274 .59417 L .28267 .58474 L p .816 .904 .902 r
F P
0 g
s
.28267 .58474 m .321 .55978 L .32101 .56711 L p .816 .904 .902 r
F P
0 g
s
.36173 .54789 m .32101 .56711 L .321 .55978 L p .736 .871 .943 r
F P
0 g
s
.49935 .59683 m .49432 .61434 L .48674 .61323 L p .707 .669 .811 r
F P
0 g
s
.49432 .61434 m .49935 .59683 L .50521 .59803 L p .772 .738 .821 r
F P
0 g
s
.60271 .54761 m .61573 .56257 L .61599 .56027 L p .086 .348 .819 r
F P
0 g
s
.63586 .5756 m .61599 .56027 L .61573 .56257 L p .059 .45 .879 r
F P
0 g
s
.47707 .68457 m .47452 .67349 L .48446 .67449 L p .691 .315 .33 r
F P
0 g
s
.48446 .67449 m .48652 .68539 L .47707 .68457 L p .691 .315 .33 r
F P
0 g
s
.46718 .59242 m .47624 .57673 L .48412 .5787 L p .594 .516 .736 r
F P
0 g
s
.48412 .5787 m .47714 .59374 L .46718 .59242 L p .594 .516 .736 r
F P
0 g
s
.46285 .6747 m .46596 .68631 L .45266 .69018 L p .534 .224 .388 r
F P
0 g
s
.46596 .68631 m .46285 .6747 L .47452 .67349 L p .587 .249 .364 r
F P
0 g
s
.45789 .57132 m .46629 .55592 L .47366 .55908 L p .628 .49 .676 r
F P
0 g
s
.47366 .55908 m .46745 .57429 L .45789 .57132 L p .628 .49 .676 r
F P
0 g
s
.51314 .58399 m .51104 .59941 L .50521 .59803 L p .846 .779 .786 r
F P
0 g
s
.51104 .59941 m .51314 .58399 L .51864 .5845 L p .876 .811 .782 r
F P
0 g
s
.42569 .53128 m .43698 .5147 L .44111 .51848 L p .824 .699 .727 r
F P
0 g
s
.44111 .51848 m .43073 .53554 L .42569 .53128 L p .824 .699 .727 r
F P
0 g
s
.26648 .69679 m .25379 .67053 L .26469 .6801 L p .871 .428 .072 r
F P
0 g
s
.26469 .6801 m .2768 .70576 L .26648 .69679 L p .871 .428 .072 r
F P
0 g
s
.48674 .61323 m .49298 .59578 L .49935 .59683 L p .707 .669 .811 r
F P
0 g
s
.44284 .40489 m .45479 .37073 L .45296 .3739 L p 0 0 0 r
F P
0 g
s
.45296 .3739 m .44081 .40867 L .44284 .40489 L p 0 0 0 r
F P
0 g
s
.61599 .56027 m .63586 .5756 L .63367 .57205 L p 0 .35 .804 r
F P
0 g
s
.65722 .5899 m .63367 .57205 L .63586 .5756 L p 0 .35 .805 r
F P
0 g
s
.42569 .53128 m .40363 .54433 L .39893 .53947 L p .735 .761 .873 r
F P
0 g
s
.40363 .54433 m .42569 .53128 L .43073 .53554 L p .719 .705 .836 r
F P
0 g
s
.47452 .67349 m .47707 .68457 L .46596 .68631 L p .587 .249 .364 r
F P
0 g
s
.59933 .37129 m .6129 .40295 L .61061 .39922 L p .803 .397 0 r
F P
0 g
s
.61061 .39922 m .59733 .36817 L .59933 .37129 L p .803 .397 0 r
F P
0 g
s
.35324 .72701 m .33093 .71737 L .35333 .71605 L p .484 .007 .046 r
F P
0 g
s
.35333 .71605 m .37304 .72438 L .35324 .72701 L p .484 .007 .046 r
F P
0 g
s
.37304 .72438 m .35333 .71605 L .37605 .71258 L p .453 .01 .106 r
F P
0 g
s
.37605 .71258 m .39313 .7197 L .37304 .72438 L p .453 .01 .106 r
F P
0 g
s
.39313 .7197 m .37605 .71258 L .39807 .70752 L p .415 0 .132 r
F P
0 g
s
.66784 .75582 m .6441 .75031 L .65011 .74026 L p .801 .903 .913 r
F P
0 g
s
.65011 .74026 m .67503 .74465 L .66784 .75582 L p .801 .903 .913 r
F P
0 g
s
.61724 .4322 m .62013 .46832 L .62123 .46352 L p 0 0 .285 r
F P
0 g
s
.62123 .46352 m .61777 .42802 L .61724 .4322 L p 0 0 .285 r
F P
0 g
s
.65722 .5899 m .68015 .61268 L .67475 .60483 L p 0 .159 .661 r
F P
0 g
s
.68015 .61268 m .69619 .63814 L .69016 .62777 L p .601 .168 0 r
F P
0 g
s
.69016 .62777 m .67475 .60483 L .68015 .61268 L p .601 .168 0 r
F P
0 g
s
.59991 .52749 m .60421 .54598 L .60503 .54445 L p .077 .045 .515 r
F P
0 g
s
.60503 .54445 m .6021 .52577 L .59991 .52749 L p .077 .045 .515 r
F P
0 g
s
.50794 .58333 m .5089 .56893 L .51398 .56924 L p .857 .667 .644 r
F P
0 g
s
.51398 .56924 m .51314 .58399 L .50794 .58333 L p .857 .667 .644 r
F P
0 g
s
.70551 .67528 m .69692 .6939 L .69218 .67939 L p .996 .844 .574 r
F P
0 g
s
.69218 .67939 m .70068 .66191 L .70551 .67528 L p .996 .844 .574 r
F P
0 g
s
.42872 .50196 m .43268 .47684 L .43417 .47994 L p .958 .824 .391 r
F P
0 g
s
.42872 .49954 m .43173 .47387 L .43268 .47684 L p .802 .726 .196 r
F P
0 g
s
.41869 .51778 m .42872 .50196 L .42949 .5047 L p .857 .972 .659 r
F P
0 g
s
.41839 .52043 m .41869 .51778 L p .42452 .51072 L .857 .972 .659 r
F P
0 g
s
.42949 .5047 m .42379 .51278 L p .42452 .51072 L .857 .972 .659 r
F P
0 g
s
.42379 .51278 m .41839 .52043 L p .42452 .51072 L .857 .972 .659 r
F P
0 g
s
.42635 .50576 m .41972 .51615 L .42019 .51566 L 0 0 0 r
F
.42659 .50532 m .41869 .51778 L p .42635 .50576 L F P
0 g
s
.42872 .50196 m .42659 .50532 L p .42635 .50576 L 0 0 0 r
F P
0 g
s
.42019 .51566 m .42872 .49954 L .42872 .50196 L p 0 0 0 r
F P
0 g
s
.37726 .53127 m .39844 .52552 L p .40074 .52534 L .326 .811 .807 r
F P
0 g
s
.41046 .52125 m .40261 .52519 L .40074 .52534 L .479 .894 .805 r
F
.41869 .51778 m .42019 .51566 L p .41972 .51615 L 0 0 0 r
F P
0 g
s
.40074 .52534 m .42019 .51566 L .41869 .51778 L p .479 .894 .805 r
F P
0 g
s
.42019 .51566 m .40476 .52334 L p .40559 .52358 L 0 0 0 r
F P
0 g
s
.40476 .52334 m .40074 .52534 L .40559 .52358 L p 0 0 0 r
F P
0 g
s
.39844 .52552 m .40559 .52358 L .40074 .52534 L p .326 .811 .807 r
F P
0 g
s
.40737 .52311 m .39736 .52783 L p .41046 .52125 L .479 .894 .805 r
F P
0 g
s
.39736 .52783 m .41869 .51778 L .41839 .52043 L p .672 .956 .947 r
F P
0 g
s
.40074 .52534 m .3698 .53411 L .37726 .53127 L p .326 .811 .807 r
F P
0 g
s
.38609 .52931 m .40639 .52381 L p .40559 .52358 L 0 0 0 r
F P
0 g
s
.40639 .52381 m .41143 .52245 L .40559 .52358 L p 0 0 0 r
F P
0 g
s
.39736 .52783 m .40074 .52534 L p .40261 .52519 L .479 .894 .805 r
F P
0 g
s
.41869 .51778 m .40737 .52311 L p .41046 .52125 L .479 .894 .805 r
F P
0 g
s
.40559 .52358 m .41842 .51642 L p .4185 .51638 L 0 0 0 r
F P
0 g
s
.42019 .51566 m .41539 .51827 L .4185 .51638 L 0 0 0 r
F
.41539 .51827 m .40559 .52358 L .4185 .51638 L F
.42872 .49954 m .42019 .51566 L .42269 .51404 L p F P
0 g
s
.41842 .51642 m .42066 .51517 L p .42019 .51566 L 0 0 0 r
F P
0 g
s
.42066 .51517 m .42269 .51404 L .42019 .51566 L p 0 0 0 r
F P
0 g
s
.42706 .50354 m .42534 .50766 L .42799 .50089 L 0 0 0 r
F
.42269 .51404 m .425 .5083 L p .42534 .50766 L F P
0 g
s
.425 .5083 m .42799 .50089 L p .42534 .50766 L 0 0 0 r
F P
0 g
s
.42872 .49954 m .42706 .50354 L .42824 .50028 L 0 0 0 r
F
.42799 .50089 m .42824 .50028 L p .42706 .50354 L F P
0 g
s
.43104 .48624 m .42918 .49884 L .42872 .49954 L .802 .726 .196 r
F
.43105 .48662 m .42872 .50196 L .43104 .48624 L F
.4288 .49889 m .42941 .49738 L p .43113 .48003 L 0 0 .018 r
F P
0 g
s
.43118 .47861 m .4288 .49889 L .43113 .48003 L 0 0 .018 r
F
.43173 .47387 m .43118 .47861 L .43113 .48003 L F
.43128 .471 m .43173 .47387 L p .43034 .48797 L F P
0 g
s
.42941 .49738 m .42998 .48933 L p .43034 .48797 L 0 0 .018 r
F P
0 g
s
.42998 .48933 m .43128 .471 L p .43034 .48797 L 0 0 .018 r
F P
0 g
s
.4318 .48245 m .42872 .50196 L p .43153 .48348 L .802 .726 .196 r
F P
0 g
s
.42949 .5047 m .42872 .50196 L p .43095 .49294 L .958 .824 .391 r
F P
0 g
s
.43128 .471 m .42941 .49738 L .43063 .49543 L p 0 0 .187 r
F P
0 g
s
.43099 .48199 m .43084 .48753 L .43098 .48087 L 0 0 .187 r
F
.43063 .49543 m .43078 .48923 L p .43084 .48753 L F P
0 g
s
.43078 .48923 m .43098 .48087 L p .43084 .48753 L 0 0 .187 r
F P
0 g
s
.42824 .50028 m .42941 .49738 L .42872 .49954 L p 0 0 0 r
F P
0 g
s
.42872 .50196 m .42872 .49954 L p .42918 .49884 L .802 .726 .196 r
F P
0 g
s
.43153 .48348 m .43105 .48662 L .43104 .48624 L .802 .726 .196 r
F
.43117 .47535 m .43099 .48199 L .43123 .46997 L 0 0 .187 r
F
.43098 .48087 m .43123 .46997 L p .43099 .48199 L F P
0 g
s
.43268 .47684 m .4318 .48245 L p .43153 .48348 L .802 .726 .196 r
F P
0 g
s
.43128 .46819 m .43128 .471 L p .43117 .47535 L 0 0 .187 r
F P
0 g
s
.43123 .46997 m .43128 .46819 L p .43117 .47535 L 0 0 .187 r
F P
0 g
s
.43417 .47994 m .4309 .49726 L p .43095 .49294 L .958 .824 .391 r
F P
0 g
s
.4309 .49726 m .42949 .5047 L p .43095 .49294 L .958 .824 .391 r
F P
0 g
s
.60971 .49097 m .60703 .5198 L .60855 .51725 L p 0 0 .287 r
F P
0 g
s
.60855 .51725 m .61181 .48797 L .60971 .49097 L p 0 0 .287 r
F P
0 g
s
.42189 .52726 m .43362 .5111 L .43698 .5147 L p .863 .768 .756 r
F P
0 g
s
.43698 .5147 m .42569 .53128 L .42189 .52726 L p .863 .768 .756 r
F P
0 g
s
.61599 .56027 m .60421 .54598 L .60271 .54761 L p .086 .348 .819 r
F P
0 g
s
.39807 .70752 m .41261 .71356 L .39313 .7197 L p .415 0 .132 r
F P
0 g
s
.41261 .71356 m .39807 .70752 L .41854 .70157 L p .374 0 .133 r
F P
0 g
s
.46745 .57429 m .47366 .55908 L .48063 .56179 L p .623 .472 .656 r
F P
0 g
s
.48063 .56179 m .47624 .57673 L .46745 .57429 L p .623 .472 .656 r
F P
0 g
s
.44517 .40107 m .45692 .36762 L .45479 .37073 L p 0 0 0 r
F P
0 g
s
.45479 .37073 m .44284 .40489 L .44517 .40107 L p 0 0 0 r
F P
0 g
s
.33475 .72717 m .30997 .71618 L .33093 .71737 L p .501 0 0 r
F P
0 g
s
.33093 .71737 m .35324 .72701 L .33475 .72717 L p .501 0 0 r
F P
0 g
s
.47714 .59374 m .48412 .5787 L .49108 .58027 L p .612 .533 .741 r
F P
0 g
s
.49108 .58027 m .48568 .5948 L .47714 .59374 L p .612 .533 .741 r
F P
0 g
s
.59733 .36817 m .61061 .39922 L .60788 .39573 L p .853 .431 0 r
F P
0 g
s
.60788 .39573 m .59502 .36519 L .59733 .36817 L p .853 .431 0 r
F P
0 g
s
.50794 .58333 m .50521 .59803 L .49935 .59683 L p .79 .719 .785 r
F P
0 g
s
.50521 .59803 m .50794 .58333 L .51314 .58399 L p .846 .779 .786 r
F P
0 g
s
.50274 .58251 m .50385 .56828 L .5089 .56893 L p .807 .608 .632 r
F P
0 g
s
.5089 .56893 m .50794 .58333 L .50274 .58251 L p .807 .608 .632 r
F P
0 g
s
.47624 .57673 m .48063 .56179 L .48711 .56406 L p .629 .463 .639 r
F P
0 g
s
.63367 .57205 m .65722 .5899 L .65283 .5846 L p 0 .288 .74 r
F P
0 g
s
.67475 .60483 m .65283 .5846 L .65722 .5899 L p 0 .159 .661 r
F P
0 g
s
.321 .55978 m .36161 .54252 L .36173 .54789 L p .736 .871 .943 r
F P
0 g
s
.39629 .53499 m .36173 .54789 L .36161 .54252 L p .691 .86 .963 r
F P
0 g
s
.36173 .54789 m .39629 .53499 L .39893 .53947 L p .704 .805 .928 r
F P
0 g
s
.49855 .69173 m .49508 .68897 L .50355 .6952 L p .501 0 0 r
F P
0 g
s
.50355 .6952 m .50609 .69794 L .49855 .69173 L p .501 0 0 r
F P
0 g
s
.52413 .71186 m .52371 .71691 L .53478 .7283 L p 0 .174 .695 r
F P
0 g
s
.53478 .7283 m .53345 .72242 L .52413 .71186 L p 0 .174 .695 r
F P
0 g
s
.61777 .42802 m .62123 .46352 L .62202 .45854 L p 0 0 .243 r
F P
0 g
s
.62202 .45854 m .61796 .42376 L .61777 .42802 L p 0 0 .243 r
F P
0 g
s
.69619 .63814 m .70068 .66191 L .69441 .64953 L p .939 .624 .175 r
F P
0 g
s
.69441 .64953 m .69016 .62777 L .69619 .63814 L p .939 .624 .175 r
F P
0 g
s
.41854 .70157 m .43072 .70669 L .41261 .71356 L p .374 0 .133 r
F P
0 g
s
.43072 .70669 m .41854 .70157 L .43684 .69552 L p .331 0 .111 r
F P
0 g
s
.44782 .39724 m .45933 .36457 L .45692 .36762 L p 0 0 .038 r
F P
0 g
s
.45692 .36762 m .44517 .40107 L .44782 .39724 L p 0 0 .038 r
F P
0 g
s
.42189 .52726 m .39893 .53947 L .39629 .53499 L p .745 .827 .915 r
F P
0 g
s
.39893 .53947 m .42189 .52726 L .42569 .53128 L p .735 .761 .873 r
F P
0 g
s
.48711 .56406 m .48412 .5787 L .47624 .57673 L p .629 .463 .639 r
F P
0 g
s
.48412 .5787 m .48711 .56406 L .49309 .56588 L p .649 .469 .627 r
F P
0 g
s
.49721 .58151 m .49863 .56728 L .50385 .56828 L p .745 .546 .625 r
F P
0 g
s
.50385 .56828 m .50274 .58251 L .49721 .58151 L p .745 .546 .625 r
F P
0 g
s
.61181 .48797 m .60855 .51725 L .61019 .51428 L p 0 0 .251 r
F P
0 g
s
.61019 .51428 m .61377 .48468 L .61181 .48797 L p 0 0 .251 r
F P
0 g
s
.48568 .5948 m .49108 .58027 L .49721 .58151 L p .654 .576 .755 r
F P
0 g
s
.49721 .58151 m .49298 .59578 L .48568 .5948 L p .654 .576 .755 r
F P
0 g
s
.41944 .52362 m .43112 .50775 L .43362 .5111 L p .906 .854 .78 r
F P
0 g
s
.43362 .5111 m .42189 .52726 L .41944 .52362 L p .906 .854 .78 r
F P
0 g
s
.59502 .36519 m .60788 .39573 L .60475 .39251 L p .88 .453 .057 r
F P
0 g
s
.60475 .39251 m .5924 .36234 L .59502 .36519 L p .88 .453 .057 r
F P
0 g
s
.49309 .56588 m .49108 .58027 L .48412 .5787 L p .649 .469 .627 r
F P
0 g
s
.49108 .58027 m .49309 .56588 L .49863 .56728 L p .688 .497 .622 r
F P
0 g
s
.6021 .52577 m .60503 .54445 L .6054 .54293 L p 0 0 .423 r
F P
0 g
s
.6054 .54293 m .60393 .52397 L .6021 .52577 L p 0 0 .423 r
F P
0 g
s
.24799 .64705 m .25596 .61549 L .25613 .62669 L p .924 .841 .391 r
F P
0 g
s
.25613 .62669 m .24813 .65933 L .24799 .64705 L p .924 .841 .391 r
F P
0 g
s
.49863 .56728 m .49721 .58151 L .49108 .58027 L p .688 .497 .622 r
F P
0 g
s
.50274 .58251 m .49935 .59683 L .49298 .59578 L p .718 .643 .773 r
F P
0 g
s
.49935 .59683 m .50274 .58251 L .50794 .58333 L p .79 .719 .785 r
F P
0 g
s
.31856 .72461 m .29159 .7123 L .30997 .71618 L p .476 0 0 r
F P
0 g
s
.30997 .71618 m .33475 .72717 L .31856 .72461 L p .476 0 0 r
F P
0 g
s
.43525 .42649 m .43234 .46255 L .43329 .4596 L p 0 0 .116 r
F P
0 g
s
.69926 .70878 m .67953 .71718 L .67738 .70239 L p .928 .877 .766 r
F P
0 g
s
.67738 .70239 m .69692 .6939 L .69926 .70878 L p .928 .877 .766 r
F P
0 g
s
.49298 .59578 m .49721 .58151 L .50274 .58251 L p .718 .643 .773 r
F P
0 g
s
.60421 .54598 m .61599 .56027 L .61525 .5582 L p 0 .211 .736 r
F P
0 g
s
.63367 .57205 m .61525 .5582 L .61599 .56027 L p 0 .35 .804 r
F P
0 g
s
.45079 .39345 m .46204 .3616 L .45933 .36457 L p 0 0 .087 r
F P
0 g
s
.45933 .36457 m .44782 .39724 L .45079 .39345 L p 0 0 .087 r
F P
0 g
s
.61796 .42376 m .62202 .45854 L .62243 .45345 L p 0 0 .193 r
F P
0 g
s
.62243 .45345 m .61777 .41947 L .61796 .42376 L p 0 0 .193 r
F P
0 g
s
.43684 .69552 m .44691 .69989 L .43072 .70669 L p .331 0 .111 r
F P
0 g
s
.44691 .69989 m .43684 .69552 L .45266 .69018 L p .291 0 .059 r
F P
0 g
s
.61525 .5582 m .60503 .54445 L .60421 .54598 L p 0 .211 .736 r
F P
0 g
s
.5924 .36234 m .60475 .39251 L .60123 .38955 L p .891 .466 .127 r
F P
0 g
s
.60123 .38955 m .58949 .35964 L .5924 .36234 L p .891 .466 .127 r
F P
0 g
s
.61377 .48468 m .61019 .51428 L .612 .51083 L p 0 0 .225 r
F P
0 g
s
.612 .51083 m .61558 .48107 L .61377 .48468 L p 0 0 .225 r
F P
0 g
s
.28723 .57565 m .32483 .55305 L .321 .55978 L p .783 .97 .918 r
F P
0 g
s
.321 .55978 m .28267 .58474 L .28723 .57565 L p .783 .97 .918 r
F P
0 g
s
.36161 .54252 m .321 .55978 L .32483 .55305 L p .7 .923 .967 r
F P
0 g
s
.39629 .53499 m .41944 .52362 L .42189 .52726 L p .745 .827 .915 r
F P
0 g
s
.49094 .68825 m .48652 .68539 L .49508 .68897 L p .407 0 0 r
F P
0 g
s
.49508 .68897 m .49855 .69173 L .49094 .68825 L p .407 0 0 r
F P
0 g
s
.67503 .74465 m .65011 .74026 L .6534 .72836 L p .837 .877 .872 r
F P
0 g
s
.6534 .72836 m .67888 .73153 L .67503 .74465 L p .837 .877 .872 r
F P
0 g
s
.25379 .67053 m .26648 .69679 L .2612 .68578 L p 0 0 .31 r
F P
0 g
s
.2612 .68578 m .24813 .65933 L .25379 .67053 L p 0 0 .31 r
F P
0 g
s
.41839 .52043 m .42949 .5047 L .43112 .50775 L p .933 .948 .775 r
F P
0 g
s
.43112 .50775 m .41944 .52362 L .41839 .52043 L p .933 .948 .775 r
F P
0 g
s
.4541 .38974 m .46501 .35874 L .46204 .3616 L p 0 0 .132 r
F P
0 g
s
.46204 .3616 m .45079 .39345 L .4541 .38974 L p 0 0 .132 r
F P
0 g
s
.43445 .45649 m .43655 .41959 L .43574 .42308 L p 0 0 .176 r
F P
0 g
s
.43574 .42308 m .43329 .4596 L .43445 .45649 L p 0 0 .176 r
F P
0 g
s
.26099 .60424 m .28723 .57565 L .28267 .58474 L p .839 .992 .738 r
F P
0 g
s
.28267 .58474 m .25596 .61549 L .26099 .60424 L p .839 .992 .738 r
F P
0 g
s
.61525 .5582 m .63367 .57205 L .63068 .56886 L p 0 .267 .731 r
F P
0 g
s
.65283 .5846 m .63068 .56886 L .63367 .57205 L p 0 .288 .74 r
F P
0 g
s
.60393 .52397 m .6054 .54293 L .60559 .54132 L p 0 0 .333 r
F P
0 g
s
.60559 .54132 m .60553 .52201 L .60393 .52397 L p 0 0 .333 r
F P
0 g
s
.45266 .69018 m .4609 .69396 L .44691 .69989 L p .291 0 .059 r
F P
0 g
s
.4609 .69396 m .45266 .69018 L .46596 .68631 L p .261 0 0 r
F P
0 g
s
.61777 .41947 m .62243 .45345 L .6224 .44836 L p 0 0 .132 r
F P
0 g
s
.6224 .44836 m .61735 .41625 L p .61777 .41947 L 0 0 .132 r
F P
0 g
s
.61718 .41519 m .62066 .4373 L p .62186 .44336 L .768 .514 0 r
F P
0 g
s
.62066 .4373 m .6224 .44836 L .62186 .44336 L p .768 .514 0 r
F P
0 g
s
.62186 .44336 m .62571 .46593 L p .62567 .46176 L .714 .459 0 r
F P
0 g
s
.62571 .46593 m .62598 .46752 L .62567 .46176 L p .714 .459 0 r
F P
0 g
s
.63688 .46638 m .62562 .45741 L p .62567 .46176 L .196 .346 .789 r
F P
0 g
s
.62567 .46176 m .62314 .4498 L p .62186 .44336 L .714 .459 0 r
F P
0 g
s
.62598 .46752 m .62186 .44336 L .6224 .44836 L p 0 0 .187 r
F P
0 g
s
.62076 .43855 m .62531 .46009 L p .62446 .45649 L .822 .508 0 r
F P
0 g
s
.62531 .46009 m .62567 .46176 L .62446 .45649 L p .822 .508 0 r
F P
0 g
s
.62446 .45649 m .61906 .43404 L .62076 .43855 L p .822 .508 0 r
F P
0 g
s
.63491 .46085 m .62357 .45275 L p .62446 .45649 L .084 .338 .812 r
F P
0 g
s
.6255 .47358 m .6224 .44836 L .62243 .45345 L p 0 0 .217 r
F P
0 g
s
.6224 .44836 m .6255 .47358 L .62598 .46752 L p 0 0 .187 r
F P
0 g
s
.61906 .43404 m .62403 .45473 L p .62231 .45185 L .902 .548 .079 r
F P
0 g
s
.62403 .45473 m .62446 .45649 L .62231 .45185 L p .902 .548 .079 r
F P
0 g
s
.62231 .45185 m .61676 .42991 L .61906 .43404 L p .902 .548 .079 r
F P
0 g
s
.61676 .42991 m .62184 .44999 L p .61923 .44799 L .937 .568 .192 r
F P
0 g
s
.62184 .44999 m .62231 .45185 L .61923 .44799 L p .937 .568 .192 r
F P
0 g
s
.63146 .4565 m .62054 .4489 L p .62231 .45185 L 0 .277 .774 r
F P
0 g
s
.62054 .4489 m .61923 .44799 L .62231 .45185 L p 0 .277 .774 r
F P
0 g
s
.61923 .44799 m .61385 .42623 L .61676 .42991 L p .937 .568 .192 r
F P
0 g
s
.61385 .42623 m .61923 .44799 L .61528 .44498 L p .937 .573 .289 r
F P
0 g
s
.61923 .44799 m .6301 .45555 L p .62662 .45348 L 0 .12 .574 r
F P
0 g
s
.6301 .45555 m .63146 .4565 L .62662 .45348 L p 0 .12 .574 r
F P
0 g
s
.62662 .45348 m .61658 .44595 L p .61923 .44799 L 0 .12 .574 r
F P
0 g
s
.61658 .44595 m .61528 .44498 L .61923 .44799 L p 0 .12 .574 r
F P
0 g
s
.62357 .45275 m .62231 .45185 L .62446 .45649 L p .084 .338 .812 r
F P
0 g
s
.62231 .45185 m .63491 .46085 L .63146 .4565 L p 0 .277 .774 r
F P
0 g
s
.61528 .44498 m .62535 .45252 L p .62058 .45184 L .647 .088 0 r
F P
0 g
s
.62535 .45252 m .62662 .45348 L .62058 .45184 L p .647 .088 0 r
F P
0 g
s
.62058 .45184 m .61056 .44285 L .61528 .44498 L p .647 .088 0 r
F P
0 g
s
.61056 .44285 m .61949 .45086 L p .6136 .45156 L .734 .241 .067 r
F P
0 g
s
.61949 .45086 m .62058 .45184 L .6136 .45156 L p .734 .241 .067 r
F P
0 g
s
.63166 .44836 m .61583 .45117 L p .62058 .45184 L .322 .789 .934 r
F P
0 g
s
.61583 .45117 m .6136 .45156 L .62058 .45184 L p .322 .789 .934 r
F P
0 g
s
.6136 .45156 m .6052 .44158 L .61056 .44285 L p .734 .241 .067 r
F P
0 g
s
.6052 .44158 m .6136 .45156 L .60596 .45249 L p .753 .332 .251 r
F P
0 g
s
.6136 .45156 m .62684 .44921 L p .62117 .45052 L .098 .653 .713 r
F P
0 g
s
.62684 .44921 m .63166 .44836 L .62117 .45052 L p .098 .653 .713 r
F P
0 g
s
.62117 .45052 m .60783 .45225 L p .6136 .45156 L .098 .653 .713 r
F P
0 g
s
.62314 .4498 m .62076 .43855 L .62186 .44336 L p .714 .459 0 r
F P
0 g
s
.60783 .45225 m .60596 .45249 L .6136 .45156 L p .098 .653 .713 r
F P
0 g
s
.60596 .45249 m .61801 .45093 L p .61028 .4541 L .134 0 0 r
F P
0 g
s
.61801 .45093 m .62117 .45052 L .61028 .4541 L p .134 0 0 r
F P
0 g
s
.61028 .4541 m .598 .4544 L .60596 .45249 L p .134 0 0 r
F P
0 g
s
.598 .4544 m .61028 .4541 L .59948 .45864 L p .307 0 0 r
F P
0 g
s
.61633 .45111 m .60281 .45715 L p .61028 .4541 L .314 .787 .688 r
F P
0 g
s
.60281 .45715 m .59948 .45864 L .61028 .4541 L p .314 .787 .688 r
F P
0 g
s
.63094 .44506 m .61545 .45183 L p .62117 .45052 L .399 .854 .818 r
F P
0 g
s
.61545 .45183 m .61028 .4541 L .62117 .45052 L p .399 .854 .818 r
F P
0 g
s
.64124 .44795 m .62309 .45137 L p .62662 .45348 L .462 .8 .999 r
F P
0 g
s
.62309 .45137 m .62058 .45184 L .62662 .45348 L p .462 .8 .999 r
F P
0 g
s
.62562 .45741 m .62446 .45649 L .62567 .46176 L p .196 .346 .789 r
F P
0 g
s
.61619 .41098 m .62036 .43482 L p .62076 .43855 L .85 .555 .02 r
F P
0 g
s
.62036 .43482 m .62186 .44336 L .62148 .4417 L p .85 .555 .02 r
F P
0 g
s
.62148 .4417 m .62076 .43855 L p .62036 .43482 L .85 .555 .02 r
F P
0 g
s
.61735 .41625 m .61718 .41519 L .61721 .4154 L p 0 0 .132 r
F P
0 g
s
.61721 .4154 m .61777 .41947 L p .61735 .41625 L 0 0 .132 r
F P
0 g
s
.36161 .54252 m .3958 .53107 L .39629 .53499 L p .691 .86 .963 r
F P
0 g
s
.41944 .52362 m .39629 .53499 L .3958 .53107 L p .737 .902 .952 r
F P
0 g
s
.58949 .35964 m .60123 .38955 L .59734 .38688 L p .89 .471 .186 r
F P
0 g
s
.59734 .38688 m .58629 .35711 L .58949 .35964 L p .89 .471 .186 r
F P
0 g
s
.51614 .7023 m .51428 .70653 L .52371 .71691 L p 0 .219 .736 r
F P
0 g
s
.61558 .48107 m .612 .51083 L .61401 .50684 L p 0 0 .209 r
F P
0 g
s
.61401 .50684 m .61727 .47714 L .61558 .48107 L p 0 0 .209 r
F P
0 g
s
.45775 .38616 m .46826 .35601 L .46501 .35874 L p .049 0 .172 r
F P
0 g
s
.46501 .35874 m .4541 .38974 L .45775 .38616 L p .049 0 .172 r
F P
0 g
s
.48254 .68763 m .47707 .68457 L .48652 .68539 L p .313 0 0 r
F P
0 g
s
.48652 .68539 m .49094 .68825 L .48254 .68763 L p .313 0 0 r
F P
0 g
s
.3056 .71932 m .2768 .70576 L .29159 .7123 L p .332 0 0 r
F P
0 g
s
.29159 .7123 m .31856 .72461 L .3056 .71932 L p .332 0 0 r
F P
0 g
s
.32483 .55305 m .36441 .53787 L .36161 .54252 L p .7 .923 .967 r
F P
0 g
s
.3958 .53107 m .36161 .54252 L .36441 .53787 L p .642 .907 .982 r
F P
0 g
s
.46596 .68631 m .47269 .68967 L .4609 .69396 L p .261 0 0 r
F P
0 g
s
.47269 .68967 m .46596 .68631 L .47707 .68457 L p .26 0 0 r
F P
0 g
s
.58629 .35711 m .59734 .38688 L .59313 .38448 L p .882 .472 .235 r
F P
0 g
s
.59313 .38448 m .58284 .35474 L .58629 .35711 L p .882 .472 .235 r
F P
0 g
s
.47707 .68457 m .48254 .68763 L .47269 .68967 L p .26 0 0 r
F P
0 g
s
.43578 .45315 m .43767 .41603 L .43655 .41959 L p 0 0 .221 r
F P
0 g
s
.43655 .41959 m .43445 .45649 L .43578 .45315 L p 0 0 .221 r
F P
0 g
s
.67347 .60365 m .67475 .60483 L .66919 .59784 L p 0 .158 .648 r
F P
0 g
s
.68396 .61854 m .67764 .60913 L .68956 .62687 L .638 .185 0 r
F
.67793 .60956 m .69016 .62777 L p .67764 .60913 L F P
0 g
s
.67475 .60483 m .67793 .60956 L p .67764 .60913 L .638 .185 0 r
F P
0 g
s
.65283 .5846 m .67347 .60365 L p .66919 .59784 L 0 .158 .648 r
F P
0 g
s
.68396 .61854 m .66919 .59784 L .67475 .60483 L p .638 .185 0 r
F P
0 g
s
.66919 .59784 m .68118 .61464 L p .67887 .61054 L 0 0 .438 r
F P
0 g
s
.68118 .61464 m .68396 .61854 L .67887 .61054 L p 0 0 .438 r
F P
0 g
s
.67887 .61054 m .67625 .60705 L p .67644 .60734 L 0 0 .438 r
F P
0 g
s
.66464 .59168 m .67444 .60466 L p .6761 .60366 L 0 .119 .667 r
F P
0 g
s
.67444 .60466 m .67887 .61054 L .6761 .60366 L p 0 .119 .667 r
F P
0 g
s
.67984 .62125 m .67677 .60678 L p .67887 .61054 L .851 .552 .019 r
F P
0 g
s
.67677 .60678 m .6761 .60366 L .67887 .61054 L p .851 .552 .019 r
F P
0 g
s
.68272 .62911 m .679 .61116 L p .68396 .61854 L .945 .62 .189 r
F P
0 g
s
.679 .61116 m .67887 .61054 L .68396 .61854 L p .945 .62 .189 r
F P
0 g
s
.67887 .61054 m .68272 .62911 L .6799 .62141 L p .851 .552 .019 r
F P
0 g
s
.6799 .62141 m .67984 .62125 L p .67982 .62105 L .851 .552 .019 r
F P
0 g
s
.67982 .62105 m .67887 .61054 L .6799 .62141 L .851 .552 .019 r
F
.68036 .61473 m .67772 .60268 L p .67617 .60361 L 0 0 .388 r
F P
0 g
s
.67628 .60411 m .67617 .60361 L .6761 .60366 L 0 0 .388 r
F
.68036 .61473 m .67617 .60361 L .67628 .60411 L F
.67772 .60268 m .67661 .59761 L .6761 .60366 L p F P
0 g
s
.69016 .62777 m .68396 .61854 L p .68956 .62687 L .638 .185 0 r
F P
0 g
s
.67644 .60734 m .66542 .59271 L .66919 .59784 L 0 0 .438 r
F
.67625 .60705 m .66542 .59271 L p .67644 .60734 L F P
0 g
s
.66542 .59271 m .66464 .59168 L .66919 .59784 L p 0 0 .438 r
F P
0 g
s
.3958 .53107 m .41839 .52043 L .41944 .52362 L p .737 .902 .952 r
F P
0 g
s
.62186 .44336 m .61619 .41098 L .61718 .41519 L p .768 .514 0 r
F P
0 g
s
.57268 .74471 m .58395 .759 L .59821 .76324 L p .315 .659 .972 r
F P
0 g
s
.59821 .76324 m .58397 .74836 L .57268 .74471 L p .315 .659 .972 r
F P
0 g
s
.58397 .74836 m .59821 .76324 L .61199 .76455 L p .454 .745 .991 r
F P
0 g
s
.46174 .38277 m .47177 .35343 L .46826 .35601 L p .133 0 .208 r
F P
0 g
s
.46826 .35601 m .45775 .38616 L .46174 .38277 L p .133 0 .208 r
F P
0 g
s
.61392 .55629 m .6054 .54293 L .60503 .54445 L p 0 .072 .634 r
F P
0 g
s
.61392 .55629 m .60529 .5448 L .61513 .55804 L 0 .072 .634 r
F
.61525 .5582 m .61392 .55629 L p .61513 .55804 L F P
0 g
s
.6054 .54293 m .61392 .55629 L .61246 .55444 L p 0 0 .548 r
F P
0 g
s
.613 .55484 m .61283 .55472 L p .61392 .55629 L 0 .24 .709 r
F P
0 g
s
.62758 .56594 m .613 .55484 L p .61392 .55629 L 0 .24 .709 r
F P
0 g
s
.61283 .55472 m .61246 .55444 L .61392 .55629 L p 0 .24 .709 r
F P
0 g
s
.60559 .54132 m .6054 .54293 L p .61175 .55328 L 0 0 .548 r
F P
0 g
s
.61246 .55444 m .61209 .55372 L p .61175 .55328 L 0 0 .548 r
F P
0 g
s
.61209 .55372 m .60559 .54132 L p .61175 .55328 L 0 0 .548 r
F P
0 g
s
.60503 .54445 m .60518 .54466 L p .60529 .5448 L 0 .072 .634 r
F P
0 g
s
.60518 .54466 m .61525 .5582 L p .60529 .5448 L 0 .072 .634 r
F P
0 g
s
.56149 .73893 m .56985 .7522 L .58395 .759 L p .183 .558 .933 r
F P
0 g
s
.58395 .759 m .57268 .74471 L .56149 .73893 L p .183 .558 .933 r
F P
0 g
s
.70068 .66191 m .69218 .67939 L .68611 .6659 L p .985 .816 .592 r
F P
0 g
s
.68611 .6659 m .69441 .64953 L .70068 .66191 L p .985 .816 .592 r
F P
0 g
s
.60553 .52201 m .60559 .54132 L .60589 .53949 L p 0 0 .261 r
F P
0 g
s
.60589 .53949 m .60703 .5198 L .60553 .52201 L p 0 0 .261 r
F P
0 g
s
.63068 .56886 m .61392 .55629 L .61525 .5582 L p 0 .267 .731 r
F P
0 g
s
.61727 .47714 m .61401 .50684 L .61618 .50231 L p 0 0 .203 r
F P
0 g
s
.61618 .50231 m .61879 .47288 L .61727 .47714 L p 0 0 .203 r
F P
0 g
s
.63068 .56886 m .65283 .5846 L .64833 .57987 L p 0 .288 .732 r
F P
0 g
s
.66919 .59784 m .64833 .57987 L .65283 .5846 L p 0 .158 .648 r
F P
0 g
s
.58284 .35474 m .59313 .38448 L .58863 .38233 L p .869 .469 .274 r
F P
0 g
s
.58863 .38233 m .57914 .35254 L .58284 .35474 L p .869 .469 .274 r
F P
0 g
s
.61199 .76455 m .59487 .74957 L .58397 .74836 L p .454 .745 .991 r
F P
0 g
s
.59487 .74957 m .61199 .76455 L .62462 .76278 L p .579 .804 .985 r
F P
0 g
s
.55082 .73149 m .55647 .74338 L .56985 .7522 L p .076 .462 .886 r
F P
0 g
s
.56985 .7522 m .56149 .73893 L .55082 .73149 L p .076 .462 .886 r
F P
0 g
s
.46606 .37963 m .47553 .35103 L .47177 .35343 L p .211 0 .24 r
F P
0 g
s
.47177 .35343 m .46174 .38277 L .46606 .37963 L p .211 0 .24 r
F P
0 g
s
.43727 .44956 m .43909 .41239 L .43767 .41603 L p 0 0 .253 r
F P
0 g
s
.43767 .41603 m .43578 .45315 L .43727 .44956 L p 0 0 .253 r
F P
0 g
s
.50916 .69442 m .50609 .69794 L .51428 .70653 L p 0 .301 .794 r
F P
0 g
s
.51428 .70653 m .51614 .7023 L .50916 .69442 L p 0 .301 .794 r
F P
0 g
s
.62076 .43855 m .61476 .40689 L .61619 .41098 L p .85 .555 .02 r
F P
0 g
s
.69016 .62777 m .69441 .64953 L .68798 .63853 L p .954 .63 .217 r
F P
0 g
s
.68798 .63853 m .68396 .61854 L .69016 .62777 L p .954 .63 .217 r
F P
0 g
s
.36441 .53787 m .39736 .52783 L .3958 .53107 L p .642 .907 .982 r
F P
0 g
s
.41839 .52043 m .3958 .53107 L .39736 .52783 L p .672 .956 .947 r
F P
0 g
s
.57914 .35254 m .58863 .38233 L .58387 .38041 L p .854 .464 .306 r
F P
0 g
s
.58387 .38041 m .57521 .35051 L .57914 .35254 L p .854 .464 .306 r
F P
0 g
s
.61879 .47288 m .61618 .50231 L .61843 .49725 L p 0 0 .205 r
F P
0 g
s
.61843 .49725 m .62013 .46832 L .61879 .47288 L p 0 0 .205 r
F P
0 g
s
.43224 .49357 m .43165 .46539 L .43128 .46819 L p 0 0 .298 r
F P
0 g
s
.43128 .46819 m .43063 .49543 L .43224 .49357 L p 0 0 .298 r
F P
0 g
s
.47071 .37679 m .47952 .34882 L .47553 .35103 L p .282 0 .268 r
F P
0 g
s
.47553 .35103 m .46606 .37963 L .47071 .37679 L p .282 0 .268 r
F P
0 g
s
.25323 .63429 m .26099 .60424 L .25596 .61549 L p 0 0 0 r
F P
0 g
s
.25596 .61549 m .24799 .64705 L .25323 .63429 L p 0 0 0 r
F P
0 g
s
.69692 .6939 m .67738 .70239 L .67315 .68792 L p .92 .839 .748 r
F P
0 g
s
.67315 .68792 m .69218 .67939 L .69692 .6939 L p .92 .839 .748 r
F P
0 g
s
.62462 .76278 m .6049 .74819 L .6136 .74424 L p .671 .831 .961 r
F P
0 g
s
.6136 .74424 m .6355 .75795 L .62462 .76278 L p .671 .831 .961 r
F P
0 g
s
.62462 .76278 m .6049 .74819 L .59487 .74957 L p .579 .804 .985 r
F P
0 g
s
.67888 .73153 m .6534 .72836 L .65407 .71529 L p .853 .847 .837 r
F P
0 g
s
.65407 .71529 m .67953 .71718 L .67888 .73153 L p .853 .847 .837 r
F P
0 g
s
.60703 .5198 m .60589 .53949 L .60654 .53729 L p 0 0 .22 r
F P
0 g
s
.60654 .53729 m .60855 .51725 L .60703 .5198 L p 0 0 .22 r
F P
0 g
s
.541 .72294 m .54425 .73319 L .55647 .74338 L p .005 .385 .845 r
F P
0 g
s
.55647 .74338 m .55082 .73149 L .541 .72294 L p .005 .385 .845 r
F P
0 g
s
.57521 .35051 m .58387 .38041 L .57889 .37869 L p .837 .457 .332 r
F P
0 g
s
.57889 .37869 m .57108 .34865 L .57521 .35051 L p .837 .457 .332 r
F P
0 g
s
.61392 .55629 m .63068 .56886 L .62758 .56594 L p 0 .24 .709 r
F P
0 g
s
.64833 .57987 m .62758 .56594 L .63068 .56886 L p 0 .288 .732 r
F P
0 g
s
.29595 .5673 m .33207 .5472 L .32483 .55305 L p .657 .972 .861 r
F P
0 g
s
.32483 .55305 m .28723 .57565 L .29595 .5673 L p .657 .972 .861 r
F P
0 g
s
.36441 .53787 m .32483 .55305 L .33207 .5472 L p .603 .938 .947 r
F P
0 g
s
.47565 .37428 m .48373 .34682 L .47952 .34882 L p .346 .038 .291 r
F P
0 g
s
.47952 .34882 m .47071 .37679 L .47565 .37428 L p .346 .038 .291 r
F P
0 g
s
.43891 .44569 m .44081 .40867 L .43909 .41239 L p 0 0 .276 r
F P
0 g
s
.43909 .41239 m .43727 .44956 L .43891 .44569 L p 0 0 .276 r
F P
0 g
s
.61476 .40689 m .62076 .43855 L .61906 .43404 L p .909 .583 .103 r
F P
0 g
s
.61906 .43404 m .6129 .40295 L .61476 .40689 L p .909 .583 .103 r
F P
0 g
s
.29662 .71145 m .26648 .69679 L .2768 .70576 L p 0 .403 .842 r
F P
0 g
s
.2768 .70576 m .3056 .71932 L .29662 .71145 L p 0 .403 .842 r
F P
0 g
s
.26123 .6733 m .24799 .64705 L .24813 .65933 L p 0 .015 .568 r
F P
0 g
s
.24813 .65933 m .2612 .68578 L .26123 .6733 L p 0 .015 .568 r
F P
0 g
s
.62013 .46832 m .61843 .49725 L .62064 .49174 L p 0 0 .213 r
F P
0 g
s
.62064 .49174 m .62123 .46352 L .62013 .46832 L p 0 0 .213 r
F P
0 g
s
.57108 .34865 m .57889 .37869 L .57372 .37713 L p .821 .449 .352 r
F P
0 g
s
.57372 .37713 m .56676 .34696 L .57108 .34865 L p .821 .449 .352 r
F P
0 g
s
.33207 .5472 m .3698 .53411 L .36441 .53787 L p .603 .938 .947 r
F P
0 g
s
.39736 .52783 m .36441 .53787 L .3698 .53411 L p .526 .907 .946 r
F P
0 g
s
.48087 .37214 m .48813 .34505 L .48373 .34682 L p .404 .088 .312 r
F P
0 g
s
.48373 .34682 m .47565 .37428 L .48087 .37214 L p .404 .088 .312 r
F P
0 g
s
.50271 .68875 m .49855 .69173 L .50609 .69794 L p .046 .425 .867 r
F P
0 g
s
.50609 .69794 m .50916 .69442 L .50271 .68875 L p .046 .425 .867 r
F P
0 g
s
.28723 .57565 m .26099 .60424 L .27067 .59346 L p .539 .829 .494 r
F P
0 g
s
.27067 .59346 m .29595 .5673 L .28723 .57565 L p .539 .829 .494 r
F P
0 g
s
.43406 .49168 m .43234 .46255 L .43165 .46539 L p 0 0 .368 r
F P
0 g
s
.43165 .46539 m .43224 .49357 L .43406 .49168 L p 0 0 .368 r
F P
0 g
s
.60855 .51725 m .60654 .53729 L .60775 .53457 L p 0 0 .214 r
F P
0 g
s
.60775 .53457 m .61019 .51428 L .60855 .51725 L p 0 0 .214 r
F P
0 g
s
.39861 .72187 m .37304 .72438 L .39313 .7197 L p .076 0 0 r
F P
0 g
s
.39313 .7197 m .41508 .71682 L .39861 .72187 L p .076 0 0 r
F P
0 g
s
.41508 .71682 m .39313 .7197 L .41261 .71356 L p .071 0 0 r
F P
0 g
s
.56676 .34696 m .57372 .37713 L .56838 .37571 L p .804 .44 .368 r
F P
0 g
s
.56838 .37571 m .56226 .34544 L .56676 .34696 L p .804 .44 .368 r
F P
0 g
s
.6355 .75795 m .6136 .74424 L .62059 .73791 L p .733 .837 .929 r
F P
0 g
s
.62059 .73791 m .6441 .75031 L .6355 .75795 L p .733 .837 .929 r
F P
0 g
s
.53221 .71394 m .53345 .72242 L .54425 .73319 L p 0 .335 .816 r
F P
0 g
s
.54425 .73319 m .541 .72294 L .53221 .71394 L p 0 .335 .816 r
F P
0 g
s
.41261 .71356 m .43107 .71054 L .41508 .71682 L p .071 0 0 r
F P
0 g
s
.43107 .71054 m .41261 .71356 L .43072 .70669 L p .04 0 0 r
F P
0 g
s
.48087 .37214 m .48813 .34505 L .49271 .34351 L p .451 .129 .328 r
F P
0 g
s
.44073 .44154 m .44284 .40489 L .44081 .40867 L p 0 0 .295 r
F P
0 g
s
.44081 .40867 m .43891 .44569 L .44073 .44154 L p 0 0 .295 r
F P
0 g
s
.6129 .40295 m .61906 .43404 L .61676 .42991 L p .942 .598 .181 r
F P
0 g
s
.61676 .42991 m .61061 .39922 L .6129 .40295 L p .942 .598 .181 r
F P
0 g
s
.38241 .7251 m .35324 .72701 L .37304 .72438 L p .042 0 0 r
F P
0 g
s
.37304 .72438 m .39861 .72187 L .38241 .7251 L p .042 0 0 r
F P
0 g
s
.62123 .46352 m .62064 .49174 L .62266 .48586 L p 0 0 .222 r
F P
0 g
s
.62266 .48586 m .62202 .45854 L .62123 .46352 L p 0 0 .222 r
F P
0 g
s
.56226 .34544 m .56838 .37571 L .5629 .37439 L p .787 .43 .38 r
F P
0 g
s
.5629 .37439 m .55762 .34408 L .56226 .34544 L p .787 .43 .38 r
F P
0 g
s
.64833 .57987 m .66919 .59784 L .66464 .59168 L p 0 .255 .736 r
F P
0 g
s
.43072 .70669 m .44597 .70371 L .43107 .71054 L p .04 0 0 r
F P
0 g
s
.44597 .70371 m .43072 .70669 L .44691 .69989 L p 0 0 0 r
F P
0 g
s
.3698 .53411 m .40074 .52534 L .39736 .52783 L p .526 .907 .946 r
F P
0 g
s
.48632 .3704 m .49271 .34351 L .49744 .34222 L p .489 .163 .341 r
F P
0 g
s
.49271 .34351 m .48632 .3704 L .48087 .37214 L p .451 .129 .328 r
F P
0 g
s
.62758 .56594 m .64833 .57987 L .64465 .57558 L p 0 .378 .812 r
F P
0 g
s
.66464 .59168 m .64465 .57558 L .64833 .57987 L p 0 .255 .736 r
F P
0 g
s
.60559 .54132 m .61246 .55444 L .61135 .55248 L p 0 0 .511 r
F P
0 g
s
.61135 .55248 m .60589 .53949 L .60559 .54132 L p 0 0 .511 r
F P
0 g
s
.55762 .34408 m .5629 .37439 L .55731 .37316 L p .77 .418 .389 r
F P
0 g
s
.55731 .37316 m .55285 .34288 L .55762 .34408 L p .77 .418 .389 r
F P
0 g
s
.49198 .36905 m .49744 .34222 L .50231 .34117 L p .523 .195 .353 r
F P
0 g
s
.49744 .34222 m .49198 .36905 L .48632 .3704 L p .489 .163 .341 r
F P
0 g
s
.4962 .68563 m .49094 .68825 L .49855 .69173 L p .17 .587 .937 r
F P
0 g
s
.49855 .69173 m .50271 .68875 L .4962 .68563 L p .17 .587 .937 r
F P
0 g
s
.61019 .51428 m .60775 .53457 L .60964 .53121 L p 0 0 .243 r
F P
0 g
s
.60964 .53121 m .612 .51083 L .61019 .51428 L p 0 0 .243 r
F P
0 g
s
.35324 .72701 m .38241 .7251 L .36731 .72611 L p 0 0 0 r
F P
0 g
s
.36731 .72611 m .33475 .72717 L .35324 .72701 L p 0 0 0 r
F P
0 g
s
.44691 .69989 m .45934 .69705 L .44597 .70371 L p 0 0 0 r
F P
0 g
s
.45934 .69705 m .44691 .69989 L .4609 .69396 L p 0 0 0 r
F P
0 g
s
.44276 .43716 m .44517 .40107 L .44284 .40489 L p 0 0 .311 r
F P
0 g
s
.44284 .40489 m .44073 .44154 L .44276 .43716 L p 0 0 .311 r
F P
0 g
s
.43595 .48963 m .43329 .4596 L .43234 .46255 L p 0 0 .411 r
F P
0 g
s
.43234 .46255 m .43406 .49168 L .43595 .48963 L p 0 0 .411 r
F P
0 g
s
.61061 .39922 m .61676 .42991 L .61385 .42623 L p .952 .601 .251 r
F P
0 g
s
.61385 .42623 m .60788 .39573 L .61061 .39922 L p .952 .601 .251 r
F P
0 g
s
.55285 .34288 m .55731 .37316 L .5516 .372 L p .753 .406 .395 r
F P
0 g
s
.5516 .372 m .54797 .34185 L .55285 .34288 L p .753 .406 .395 r
F P
0 g
s
.69441 .64953 m .68611 .6659 L .67991 .65395 L p .976 .802 .604 r
F P
0 g
s
.67991 .65395 m .68798 .63853 L .69441 .64953 L p .976 .802 .604 r
F P
0 g
s
.49779 .3681 m .50231 .34117 L .50727 .34037 L p .555 .225 .363 r
F P
0 g
s
.50231 .34117 m .49779 .3681 L .49198 .36905 L p .523 .195 .353 r
F P
0 g
s
.62202 .45854 m .62266 .48586 L .62434 .47975 L p 0 0 .225 r
F P
0 g
s
.62434 .47975 m .62243 .45345 L .62202 .45854 L p 0 0 .225 r
F P
0 g
s
.52451 .70514 m .52413 .71186 L .53345 .72242 L p 0 .315 .805 r
F P
0 g
s
.53345 .72242 m .53221 .71394 L .52451 .70514 L p 0 .315 .805 r
F P
0 g
s
.54797 .34185 m .5516 .372 L .5458 .37092 L p .735 .392 .399 r
F P
0 g
s
.5458 .37092 m .543 .34099 L .54797 .34185 L p .735 .392 .399 r
F P
0 g
s
.50373 .36752 m .50727 .34037 L .51232 .33981 L p .584 .252 .373 r
F P
0 g
s
.50727 .34037 m .50373 .36752 L .49779 .3681 L p .555 .225 .363 r
F P
0 g
s
.61246 .55444 m .62758 .56594 L .62508 .56314 L p 0 .299 .772 r
F P
0 g
s
.64465 .57558 m .62508 .56314 L .62758 .56594 L p 0 .378 .812 r
F P
0 g
s
.4609 .69396 m .47094 .69131 L .45934 .69705 L p 0 0 0 r
F P
0 g
s
.47094 .69131 m .4609 .69396 L .47269 .68967 L p 0 0 0 r
F P
0 g
s
.543 .34099 m .5458 .37092 L .53992 .36993 L p .717 .377 .401 r
F P
0 g
s
.53992 .36993 m .53795 .3403 L .543 .34099 L p .717 .377 .401 r
F P
0 g
s
.42589 .51281 m .43063 .49543 L .42941 .49738 L p .03 0 .203 r
F P
0 g
s
.42941 .49738 m .42269 .51404 L .42589 .51281 L p .03 0 .203 r
F P
0 g
s
.50975 .3673 m .51232 .33981 L .51743 .33948 L p .611 .278 .381 r
F P
0 g
s
.51232 .33981 m .50975 .3673 L .50373 .36752 L p .584 .252 .373 r
F P
0 g
s
.68396 .61854 m .68798 .63853 L .68272 .62911 L p .945 .62 .189 r
F P
0 g
s
.67953 .71718 m .65407 .71529 L .6525 .70176 L p .858 .819 .809 r
F P
0 g
s
.6525 .70176 m .67738 .70239 L .67953 .71718 L p .858 .819 .809 r
F P
0 g
s
.48907 .68515 m .48254 .68763 L .49094 .68825 L p .263 .74 .935 r
F P
0 g
s
.49094 .68825 m .4962 .68563 L .48907 .68515 L p .263 .74 .935 r
F P
0 g
s
.6441 .75031 m .62059 .73791 L .62564 .72953 L p .776 .831 .895 r
F P
0 g
s
.62564 .72953 m .65011 .74026 L .6441 .75031 L p .776 .831 .895 r
F P
0 g
s
.53795 .3403 m .53992 .36993 L .53396 .36904 L p .699 .36 .4 r
F P
0 g
s
.53396 .36904 m .53285 .3398 L .53795 .3403 L p .699 .36 .4 r
F P
0 g
s
.51581 .36738 m .51743 .33948 L .52256 .33937 L p .635 .301 .388 r
F P
0 g
s
.51743 .33948 m .51581 .36738 L .50975 .3673 L p .611 .278 .381 r
F P
0 g
s
.53285 .3398 m .53396 .36904 L .52794 .36829 L p .679 .342 .398 r
F P
0 g
s
.52794 .36829 m .52771 .33948 L .53285 .3398 L p .679 .342 .398 r
F P
0 g
s
.52189 .36772 m .52256 .33937 L .52771 .33948 L p .658 .323 .394 r
F P
0 g
s
.52256 .33937 m .52189 .36772 L .51581 .36738 L p .635 .301 .388 r
F P
0 g
s
.612 .51083 m .60964 .53121 L .61225 .52709 L p 0 0 .299 r
F P
0 g
s
.61225 .52709 m .61401 .50684 L .612 .51083 L p 0 0 .299 r
F P
0 g
s
.52771 .33948 m .52794 .36829 L .52189 .36772 L p .658 .323 .394 r
F P
0 g
s
.62508 .56314 m .61135 .55248 L .61246 .55444 L p 0 .299 .772 r
F P
0 g
s
.48078 .68717 m .47269 .68967 L .47553 .68908 L p .261 .769 .776 r
F P
0 g
s
.47553 .68908 m .48254 .68763 L p .48078 .68717 L .261 .769 .776 r
F P
0 g
s
.4876 .68452 m .48078 .68717 L .48907 .68515 L p .29 .789 .8 r
F P
0 g
s
.48078 .68717 m .4876 .68452 L .48516 .68557 L p 0 0 0 r
F P
0 g
s
.48254 .68763 m .48907 .68515 L .48078 .68717 L p .261 .769 .776 r
F P
0 g
s
.48516 .68557 m .47961 .68796 L p .48078 .68717 L 0 0 0 r
F P
0 g
s
.47269 .68967 m .48078 .68717 L .47094 .69131 L p 0 0 0 r
F P
0 g
s
.44504 .43258 m .44782 .39724 L .44517 .40107 L p 0 0 .325 r
F P
0 g
s
.44517 .40107 m .44276 .43716 L .44504 .43258 L p 0 0 .325 r
F P
0 g
s
.60788 .39573 m .61385 .42623 L .61037 .42303 L p .947 .598 .31 r
F P
0 g
s
.61037 .42303 m .60475 .39251 L .60788 .39573 L p .947 .598 .31 r
F P
0 g
s
.29214 .70138 m .2612 .68578 L .26648 .69679 L p .216 .451 .871 r
F P
0 g
s
.26648 .69679 m .29662 .71145 L .29214 .70138 L p .216 .451 .871 r
F P
0 g
s
.69218 .67939 m .67315 .68792 L .66777 .67446 L p .91 .813 .739 r
F P
0 g
s
.66777 .67446 m .68611 .6659 L .69218 .67939 L p .91 .813 .739 r
F P
0 g
s
.62243 .45345 m .62434 .47975 L .6255 .47358 L p 0 0 .217 r
F P
0 g
s
.35412 .72462 m .31856 .72461 L .33475 .72717 L p .184 .697 .893 r
F P
0 g
s
.33475 .72717 m .36731 .72611 L .35412 .72462 L p .184 .697 .893 r
F P
0 g
s
.60589 .53949 m .61135 .55248 L .61103 .55021 L p 0 0 .531 r
F P
0 g
s
.61103 .55021 m .60654 .53729 L .60589 .53949 L p 0 0 .531 r
F P
0 g
s
.43778 .48727 m .43445 .45649 L .43329 .4596 L p .001 0 .436 r
F P
0 g
s
.43329 .4596 m .43595 .48963 L .43778 .48727 L p .001 0 .436 r
F P
0 g
s
.33207 .5472 m .29595 .5673 L .30799 .55998 L p .418 .842 .687 r
F P
0 g
s
.3698 .53411 m .33207 .5472 L .34204 .5424 L p .427 .871 .845 r
F P
0 g
s
.30799 .55998 m .34204 .5424 L .33207 .5472 L p .418 .842 .687 r
F P
0 g
s
.34204 .5424 m .37726 .53127 L .3698 .53411 L p .427 .871 .845 r
F P
0 g
s
.26329 .62167 m .27067 .59346 L .26099 .60424 L p 0 0 .247 r
F P
0 g
s
.26099 .60424 m .25323 .63429 L .26329 .62167 L p 0 0 .247 r
F P
0 g
s
.51778 .69719 m .51614 .7023 L .52413 .71186 L p 0 .327 .813 r
F P
0 g
s
.52413 .71186 m .52451 .70514 L .51778 .69719 L p 0 .327 .813 r
F P
0 g
s
.61401 .50684 m .61225 .52709 L .61553 .52216 L p 0 0 .369 r
F P
0 g
s
.61553 .52216 m .61618 .50231 L .61401 .50684 L p 0 0 .369 r
F P
0 g
s
.44764 .4279 m .45079 .39345 L .44782 .39724 L p .01 0 .339 r
F P
0 g
s
.44782 .39724 m .44504 .43258 L .44764 .4279 L p .01 0 .339 r
F P
0 g
s
.60475 .39251 m .61037 .42303 L .60636 .42035 L p .933 .59 .358 r
F P
0 g
s
.60636 .42035 m .60123 .38955 L .60475 .39251 L p .933 .59 .358 r
F P
0 g
s
.2664 .65996 m .25323 .63429 L .24799 .64705 L p .179 .178 .62 r
F P
0 g
s
.24799 .64705 m .26123 .6733 L .2664 .65996 L p .179 .178 .62 r
F P
0 g
s
.42949 .51181 m .43224 .49357 L .43063 .49543 L p .156 0 .326 r
F P
0 g
s
.43063 .49543 m .42589 .51281 L .42949 .51181 L p .156 0 .326 r
F P
0 g
s
.62508 .56314 m .64465 .57558 L .64267 .5715 L p .174 .526 .921 r
F P
0 g
s
.64465 .57558 m .66464 .59168 L .66216 .58616 L p .081 .431 .873 r
F P
0 g
s
.66216 .58616 m .64267 .5715 L .64465 .57558 L p .081 .431 .873 r
F P
0 g
s
.6761 .60366 m .66216 .58616 L .66464 .59168 L p 0 .119 .667 r
F P
0 g
s
.43948 .48449 m .43578 .45315 L .43445 .45649 L p 0 0 .448 r
F P
0 g
s
.43445 .45649 m .43778 .48727 L .43948 .48449 L p 0 0 .448 r
F P
0 g
s
.60654 .53729 m .61103 .55021 L .61183 .54741 L p .05 .087 .579 r
F P
0 g
s
.61183 .54741 m .60775 .53457 L .60654 .53729 L p .05 .087 .579 r
F P
0 g
s
.28409 .58359 m .30799 .55998 L .29595 .5673 L p 0 0 0 r
F P
0 g
s
.29595 .5673 m .27067 .59346 L .28409 .58359 L p 0 0 0 r
F P
0 g
s
.61618 .50231 m .61553 .52216 L .61932 .51643 L p .087 0 .442 r
F P
0 g
s
.61932 .51643 m .61843 .49725 L .61618 .50231 L p .087 0 .442 r
F P
0 g
s
.45059 .4232 m .4541 .38974 L .45079 .39345 L p .072 0 .354 r
F P
0 g
s
.45079 .39345 m .44764 .4279 L .45059 .4232 L p .072 0 .354 r
F P
0 g
s
.61135 .55248 m .62508 .56314 L .62384 .56023 L p .101 .43 .872 r
F P
0 g
s
.64267 .5715 m .62384 .56023 L .62508 .56314 L p .174 .526 .921 r
F P
0 g
s
.62384 .56023 m .61103 .55021 L .61135 .55248 L p .101 .43 .872 r
F P
0 g
s
.65011 .74026 m .62564 .72953 L .62866 .71956 L p .804 .817 .861 r
F P
0 g
s
.62866 .71956 m .6534 .72836 L .65011 .74026 L p .804 .817 .861 r
F P
0 g
s
.60123 .38955 m .60636 .42035 L .60189 .41816 L p .914 .58 .396 r
F P
0 g
s
.60189 .41816 m .59734 .38688 L .60123 .38955 L p .914 .58 .396 r
F P
0 g
s
.51179 .69064 m .50916 .69442 L .51614 .7023 L p .049 .375 .841 r
F P
0 g
s
.51614 .7023 m .51778 .69719 L .51179 .69064 L p .049 .375 .841 r
F P
0 g
s
.34359 .72057 m .3056 .71932 L .31856 .72461 L p .327 .714 .982 r
F P
0 g
s
.31856 .72461 m .35412 .72462 L .34359 .72057 L p .327 .714 .982 r
F P
0 g
s
.41143 .52245 m .42589 .51281 L .42269 .51404 L p .083 0 0 r
F P
0 g
s
.42269 .51404 m .40559 .52358 L .41143 .52245 L p .083 0 0 r
F P
0 g
s
.61843 .49725 m .61932 .51643 L .62339 .50995 L p .163 .082 .51 r
F P
0 g
s
.62339 .50995 m .62064 .49174 L .61843 .49725 L p .163 .082 .51 r
F P
0 g
s
.68798 .63853 m .67991 .65395 L .67484 .64382 L p .975 .811 .616 r
F P
0 g
s
.67484 .64382 m .68272 .62911 L .68798 .63853 L p .975 .811 .616 r
F P
0 g
s
.45396 .41861 m .45775 .38616 L .4541 .38974 L p .139 0 .369 r
F P
0 g
s
.4541 .38974 m .45059 .4232 L .45396 .41861 L p .139 0 .369 r
F P
0 g
s
.44099 .48119 m .43727 .44956 L .43578 .45315 L p 0 0 .447 r
F P
0 g
s
.43578 .45315 m .43948 .48449 L .44099 .48119 L p 0 0 .447 r
F P
0 g
s
.43316 .51086 m .43406 .49168 L .43224 .49357 L p .216 .03 .4 r
F P
0 g
s
.43224 .49357 m .42949 .51181 L .43316 .51086 L p .216 .03 .4 r
F P
0 g
s
.60775 .53457 m .61183 .54741 L .61399 .54388 L p .252 .214 .62 r
F P
0 g
s
.61399 .54388 m .60964 .53121 L .60775 .53457 L p .252 .214 .62 r
F P
0 g
s
.67738 .70239 m .6525 .70176 L .64926 .68849 L p .857 .794 .789 r
F P
0 g
s
.64926 .68849 m .67315 .68792 L .67738 .70239 L p .857 .794 .789 r
F P
0 g
s
.59734 .38688 m .60189 .41816 L .59703 .41644 L p .894 .57 .427 r
F P
0 g
s
.59703 .41644 m .59313 .38448 L .59734 .38688 L p .894 .57 .427 r
F P
0 g
s
.40559 .52358 m .37726 .53127 L .38609 .52931 L p 0 0 0 r
F P
0 g
s
.62064 .49174 m .62339 .50995 L .62746 .50286 L p .22 .157 .57 r
F P
0 g
s
.62746 .50286 m .62266 .48586 L .62064 .49174 L p .22 .157 .57 r
F P
0 g
s
.50618 .68592 m .50271 .68875 L .50916 .69442 L p .12 .466 .892 r
F P
0 g
s
.50916 .69442 m .51179 .69064 L .50618 .68592 L p .12 .466 .892 r
F P
0 g
s
.37726 .53127 m .34204 .5424 L .35382 .53867 L p .215 .726 .676 r
F P
0 g
s
.35382 .53867 m .38609 .52931 L .37726 .53127 L p .215 .726 .676 r
F P
0 g
s
.61103 .55021 m .62384 .56023 L .62438 .55692 L p .378 .528 .88 r
F P
0 g
s
.62438 .55692 m .61183 .54741 L .61103 .55021 L p .378 .528 .88 r
F P
0 g
s
.55524 .72971 m .56149 .73893 L .57268 .74471 L p .187 .564 .935 r
F P
0 g
s
.57298 .73655 m .56409 .73393 L p .56675 .73586 L .334 .664 .974 r
F P
0 g
s
.58397 .74836 m .57298 .73655 L p .56675 .73586 L .334 .664 .974 r
F P
0 g
s
.58158 .73733 m .57298 .73655 L p .57603 .73837 L .471 .743 .988 r
F P
0 g
s
.59487 .74957 m .58158 .73733 L p .57603 .73837 L .471 .743 .988 r
F P
0 g
s
.58158 .73733 m .58956 .73614 L p .58717 .73628 L .28 .781 .857 r
F P
0 g
s
.57298 .73655 m .58158 .73733 L p .5794 .73726 L 0 .574 .72 r
F P
0 g
s
.56409 .73393 m .57268 .74471 L .58397 .74836 L p .334 .664 .974 r
F P
0 g
s
.57298 .73655 m .58397 .74836 L .59487 .74957 L p .471 .743 .988 r
F P
0 g
s
.56668 .73688 m .57298 .73655 L p .5794 .73726 L 0 .574 .72 r
F P
0 g
s
.57385 .73703 m .58158 .73733 L p .58717 .73628 L .28 .781 .857 r
F P
0 g
s
.56409 .73393 m .57298 .73655 L p .57112 .7364 L .281 0 0 r
F P
0 g
s
.57268 .74471 m .56409 .73393 L p .55742 .73158 L .187 .564 .935 r
F P
0 g
s
.5593 .73546 m .56409 .73393 L p .57112 .7364 L .281 0 0 r
F P
0 g
s
.56409 .73393 m .55524 .72971 L p .55742 .73158 L .187 .564 .935 r
F P
0 g
s
.45777 .41425 m .46174 .38277 L .45775 .38616 L p .209 .015 .384 r
F P
0 g
s
.45775 .38616 m .45396 .41861 L .45777 .41425 L p .209 .015 .384 r
F P
0 g
s
.62384 .56023 m .64267 .5715 L .6431 .56731 L p .442 .61 .919 r
F P
0 g
s
.64267 .5715 m .66216 .58616 L .66261 .58097 L p .388 .548 .893 r
F P
0 g
s
.66261 .58097 m .6431 .56731 L .64267 .5715 L p .388 .548 .893 r
F P
0 g
s
.68611 .6659 m .66777 .67446 L .66231 .66254 L p .9 .8 .74 r
F P
0 g
s
.66231 .66254 m .67991 .65395 L .68611 .6659 L p .9 .8 .74 r
F P
0 g
s
.29233 .68959 m .26123 .6733 L .2612 .68578 L p .361 .456 .822 r
F P
0 g
s
.2612 .68578 m .29214 .70138 L .29233 .68959 L p .361 .456 .822 r
F P
0 g
s
.55082 .73149 m .56149 .73893 L p .54853 .72604 L .044 .453 .878 r
F P
0 g
s
.54736 .72538 m .55082 .73149 L p .54853 .72604 L .044 .453 .878 r
F P
0 g
s
.55524 .72971 m .54671 .72423 L p .54838 .72589 L .044 .453 .878 r
F P
0 g
s
.56149 .73893 m .55524 .72971 L p .54838 .72589 L .044 .453 .878 r
F P
0 g
s
.55524 .72971 m .56409 .73393 L p .56262 .73381 L .504 0 0 r
F P
0 g
s
.5519 .73294 m .55524 .72971 L p .56262 .73381 L .504 0 0 r
F P
0 g
s
.541 .72294 m .55082 .73149 L p .54277 .72248 L 0 .343 .809 r
F P
0 g
s
.53871 .71793 m .53988 .72049 L p .54277 .72248 L 0 .343 .809 r
F P
0 g
s
.53988 .72049 m .541 .72294 L p .54277 .72248 L 0 .343 .809 r
F P
0 g
s
.54671 .72423 m .53871 .71793 L p .53989 .71924 L 0 .343 .809 r
F P
0 g
s
.55082 .73149 m .54671 .72423 L p .53989 .71924 L 0 .343 .809 r
F P
0 g
s
.54671 .72423 m .55524 .72971 L p .55418 .72969 L .657 .116 0 r
F P
0 g
s
.54671 .72423 m .54736 .72538 L p .54853 .72604 L .044 .453 .878 r
F P
0 g
s
.54465 .72955 m .54671 .72423 L p .55418 .72969 L .657 .116 0 r
F P
0 g
s
.5519 .73294 m .54465 .72955 L p .55326 .72968 L .657 .116 0 r
F P
0 g
s
.55498 .72971 m .55432 .73041 L .55326 .72968 L .657 .116 0 r
F
.55432 .73041 m .5519 .73294 L .55326 .72968 L F
.55524 .72971 m .55515 .7298 L p .55498 .72971 L F P
0 g
s
.55515 .7298 m .5519 .73294 L p .55498 .72971 L .657 .116 0 r
F P
0 g
s
.6431 .56731 m .62438 .55692 L .62384 .56023 L p .442 .61 .919 r
F P
0 g
s
.60964 .53121 m .61399 .54388 L .61758 .53942 L p .394 .313 .646 r
F P
0 g
s
.61758 .53942 m .61225 .52709 L .60964 .53121 L p .394 .313 .646 r
F P
0 g
s
.44233 .47729 m .43891 .44569 L .43727 .44956 L p 0 0 .437 r
F P
0 g
s
.43727 .44956 m .44099 .48119 L .44233 .47729 L p 0 0 .437 r
F P
0 g
s
.32225 .55384 m .35382 .53867 L .34204 .5424 L p 0 0 0 r
F P
0 g
s
.34204 .5424 m .30799 .55998 L .32225 .55384 L p 0 0 0 r
F P
0 g
s
.59313 .38448 m .59703 .41644 L .59187 .4151 L p .874 .56 .452 r
F P
0 g
s
.59187 .4151 m .58863 .38233 L .59313 .38448 L p .874 .56 .452 r
F P
0 g
s
.66216 .58616 m .6761 .60366 L .67661 .59761 L p .211 .361 .797 r
F P
0 g
s
.67661 .59761 m .66261 .58097 L .66216 .58616 L p .211 .361 .797 r
F P
0 g
s
.58158 .73733 m .59487 .74957 L .6049 .74819 L p .587 .796 .979 r
F P
0 g
s
.62266 .48586 m .62746 .50286 L .63121 .49535 L p .258 .218 .621 r
F P
0 g
s
.63121 .49535 m .62434 .47975 L .62266 .48586 L p .258 .218 .621 r
F P
0 g
s
.6534 .72836 m .62866 .71956 L .62975 .70857 L p .821 .799 .831 r
F P
0 g
s
.62975 .70857 m .65407 .71529 L .6534 .72836 L p .821 .799 .831 r
F P
0 g
s
.41772 .52176 m .42949 .51181 L .42589 .51281 L p .233 0 .026 r
F P
0 g
s
.42589 .51281 m .41143 .52245 L .41772 .52176 L p .233 0 .026 r
F P
0 g
s
.43661 .50971 m .43595 .48963 L .43406 .49168 L p .232 .071 .446 r
F P
0 g
s
.43406 .49168 m .43316 .51086 L .43661 .50971 L p .232 .071 .446 r
F P
0 g
s
.46203 .41023 m .46606 .37963 L .46174 .38277 L p .279 .065 .399 r
F P
0 g
s
.46174 .38277 m .45777 .41425 L .46203 .41023 L p .279 .065 .399 r
F P
0 g
s
.50056 .68331 m .4962 .68563 L .50271 .68875 L p .207 .605 .948 r
F P
0 g
s
.50271 .68875 m .50618 .68592 L .50056 .68331 L p .207 .605 .948 r
F P
0 g
s
.61225 .52709 m .61758 .53942 L .62249 .53392 L p .481 .382 .666 r
F P
0 g
s
.62249 .53392 m .61553 .52216 L .61225 .52709 L p .481 .382 .666 r
F P
0 g
s
.33633 .71407 m .29662 .71145 L .3056 .71932 L p .428 .676 .966 r
F P
0 g
s
.3056 .71932 m .34359 .72057 L .33633 .71407 L p .428 .676 .966 r
F P
0 g
s
.4359 .70964 m .41508 .71682 L .43107 .71054 L p 0 0 0 r
F P
0 g
s
.43107 .71054 m .44826 .7042 L .4359 .70964 L p 0 0 0 r
F P
0 g
s
.44826 .7042 m .43107 .71054 L .44597 .70371 L p 0 0 0 r
F P
0 g
s
.61183 .54741 m .62438 .55692 L .62703 .55291 L p .536 .556 .822 r
F P
0 g
s
.62703 .55291 m .61399 .54388 L .61183 .54741 L p .536 .556 .822 r
F P
0 g
s
.58863 .38233 m .59187 .4151 L .58648 .41408 L p .855 .551 .472 r
F P
0 g
s
.58648 .41408 m .58387 .38041 L .58863 .38233 L p .855 .551 .472 r
F P
0 g
s
.44597 .70371 m .45985 .69837 L .44826 .7042 L p 0 0 0 r
F P
0 g
s
.45985 .69837 m .44597 .70371 L .45934 .69705 L p 0 0 0 r
F P
0 g
s
.27722 .60973 m .28409 .58359 L .27067 .59346 L p .207 0 .363 r
F P
0 g
s
.27067 .59346 m .26329 .62167 L .27722 .60973 L p .207 0 .363 r
F P
0 g
s
.53871 .71793 m .54671 .72423 L p .54488 .7245 L .751 .265 .084 r
F P
0 g
s
.53221 .71394 m .541 .72294 L p .53211 .71216 L 0 .241 .736 r
F P
0 g
s
.541 .72294 m .53871 .71793 L .53138 .71127 L p 0 .241 .736 r
F P
0 g
s
.53767 .72557 m .53864 .71847 L p .54488 .7245 L .751 .265 .084 r
F P
0 g
s
.53864 .71847 m .53871 .71793 L p .54488 .7245 L .751 .265 .084 r
F P
0 g
s
.53138 .71127 m .53146 .71153 L p .53211 .71216 L 0 .241 .736 r
F P
0 g
s
.53146 .71153 m .53221 .71394 L p .53211 .71216 L 0 .241 .736 r
F P
0 g
s
.41508 .71682 m .4183 .71571 L p .42324 .71411 L 0 0 0 r
F P
0 g
s
.4183 .71571 m .4359 .70964 L .42324 .71411 L p 0 0 0 r
F P
0 g
s
.44133 .70946 m .42324 .71411 L .4359 .70964 L p 0 0 0 r
F P
0 g
s
.43214 .71152 m .42722 .71281 L p .42324 .71411 L .211 .733 .737 r
F P
0 g
s
.42722 .71281 m .41083 .71712 L .42324 .71411 L p .211 .733 .737 r
F P
0 g
s
.42324 .71411 m .39861 .72187 L .41508 .71682 L p 0 0 0 r
F P
0 g
s
.44356 .47279 m .44073 .44154 L .43891 .44569 L p 0 0 .42 r
F P
0 g
s
.43891 .44569 m .44233 .47729 L .44356 .47279 L p 0 0 .42 r
F P
0 g
s
.6049 .74819 m .58956 .73614 L .59662 .733 L p .676 .823 .954 r
F P
0 g
s
.59662 .733 m .6136 .74424 L .6049 .74819 L p .676 .823 .954 r
F P
0 g
s
.6049 .74819 m .58956 .73614 L .58158 .73733 L p .587 .796 .979 r
F P
0 g
s
.45934 .69705 m .47036 .69275 L .45985 .69837 L p 0 0 0 r
F P
0 g
s
.47036 .69275 m .45934 .69705 L .47094 .69131 L p 0 0 0 r
F P
0 g
s
.49449 .68288 m .48907 .68515 L .4962 .68563 L p .281 .749 .944 r
F P
0 g
s
.4962 .68563 m .50056 .68331 L .49449 .68288 L p .281 .749 .944 r
F P
0 g
s
.46676 .40666 m .47071 .37679 L .46606 .37963 L p .347 .115 .413 r
F P
0 g
s
.46606 .37963 m .46203 .41023 L .46676 .40666 L p .347 .115 .413 r
F P
0 g
s
.62434 .47975 m .63121 .49535 L .6343 .48766 L p .278 .267 .667 r
F P
0 g
s
.6343 .48766 m .6255 .47358 L .62434 .47975 L p .278 .267 .667 r
F P
0 g
s
.47094 .69131 m .47961 .68796 L .47036 .69275 L p 0 0 0 r
F P
0 g
s
.47961 .68796 m .47094 .69131 L .48078 .68717 L p 0 0 0 r
F P
0 g
s
.62438 .55692 m .6431 .56731 L .6464 .56265 L p .582 .613 .849 r
F P
0 g
s
.6464 .56265 m .62703 .55291 L .62438 .55692 L p .582 .613 .849 r
F P
0 g
s
.48907 .68515 m .49449 .68288 L .4876 .68452 L p .29 .789 .8 r
F P
0 g
s
.61553 .52216 m .62249 .53392 L .62849 .52733 L p .533 .429 .682 r
F P
0 g
s
.62849 .52733 m .61932 .51643 L .61553 .52216 L p .533 .429 .682 r
F P
0 g
s
.6431 .56731 m .66261 .58097 L .66657 .57569 L p .549 .57 .828 r
F P
0 g
s
.66657 .57569 m .6464 .56265 L .6431 .56731 L p .549 .57 .828 r
F P
0 g
s
.27617 .64644 m .26329 .62167 L .25323 .63429 L p .335 .26 .622 r
F P
0 g
s
.25323 .63429 m .2664 .65996 L .27617 .64644 L p .335 .26 .622 r
F P
0 g
s
.67856 .61523 m .67984 .62125 L .68036 .61473 L p 0 0 .388 r
F P
0 g
s
.67252 .62907 m .68036 .61473 L .67984 .62125 L p .945 .932 .584 r
F P
0 g
s
.67682 .62393 m .68212 .61424 L p .68036 .61473 L 0 0 0 r
F P
0 g
s
.68212 .61424 m .68492 .60914 L .68036 .61473 L p 0 0 0 r
F P
0 g
s
.6761 .60366 m .67856 .61523 L p .68036 .61473 L 0 0 .388 r
F P
0 g
s
.41083 .71712 m .38241 .7251 L .39861 .72187 L p .299 .794 .797 r
F P
0 g
s
.39861 .72187 m .42324 .71411 L .41083 .71712 L p .299 .794 .797 r
F P
0 g
s
.58387 .38041 m .58648 .41408 L .58093 .41328 L p .838 .541 .487 r
F P
0 g
s
.58093 .41328 m .57889 .37869 L .58387 .38041 L p .838 .541 .487 r
F P
0 g
s
.30001 .57491 m .32225 .55384 L .30799 .55998 L p .084 0 .008 r
F P
0 g
s
.30799 .55998 m .28409 .58359 L .30001 .57491 L p .084 0 .008 r
F P
0 g
s
.68272 .62911 m .67484 .64382 L .67206 .63558 L p .986 .857 .627 r
F P
0 g
s
.67206 .63558 m .67984 .62125 L .68272 .62911 L p .986 .857 .627 r
F P
0 g
s
.3955 .52803 m .41772 .52176 L .41143 .52245 L p .076 0 0 r
F P
0 g
s
.41143 .52245 m .38609 .52931 L .3955 .52803 L p .076 0 0 r
F P
0 g
s
.43958 .50814 m .43778 .48727 L .43595 .48963 L p .207 .076 .472 r
F P
0 g
s
.43595 .48963 m .43661 .50971 L .43958 .50814 L p .207 .076 .472 r
F P
0 g
s
.53138 .71127 m .53871 .71793 L p .53711 .71863 L .801 .37 .224 r
F P
0 g
s
.52451 .70514 m .53221 .71394 L p .52592 .7062 L 0 .148 .657 r
F P
0 g
s
.52592 .7062 m .52512 .7052 L .52501 .70519 L 0 .148 .657 r
F
.52592 .7062 m .52501 .70519 L .52451 .70514 L F
.53221 .71394 m .53138 .71127 L .52475 .70475 L p F P
0 g
s
.53105 .7213 m .52482 .71706 L p .5309 .71169 L .821 .441 .333 r
F P
0 g
s
.53138 .71127 m .53135 .71218 L p .5309 .71169 L .821 .441 .333 r
F P
0 g
s
.53135 .71218 m .53105 .7213 L p .5309 .71169 L .821 .441 .333 r
F P
0 g
s
.53105 .7213 m .53135 .71218 L p .53711 .71863 L .801 .37 .224 r
F P
0 g
s
.53135 .71218 m .53138 .71127 L p .53711 .71863 L .801 .37 .224 r
F P
0 g
s
.52475 .70475 m .52473 .70477 L p .52512 .7052 L 0 .148 .657 r
F P
0 g
s
.52473 .70477 m .52451 .70514 L p .52512 .7052 L 0 .148 .657 r
F P
0 g
s
.47192 .40366 m .47565 .37428 L .47071 .37679 L p .41 .163 .426 r
F P
0 g
s
.47071 .37679 m .46676 .40666 L .47192 .40366 L p .41 .163 .426 r
F P
0 g
s
.61399 .54388 m .62703 .55291 L .63191 .54794 L p .607 .559 .774 r
F P
0 g
s
.63191 .54794 m .61758 .53942 L .61399 .54388 L p .607 .559 .774 r
F P
0 g
s
.66261 .58097 m .67661 .59761 L .68104 .59197 L p .463 .453 .762 r
F P
0 g
s
.68104 .59197 m .66657 .57569 L .66261 .58097 L p .463 .453 .762 r
F P
0 g
s
.67315 .68792 m .64926 .68849 L .6451 .67611 L p .852 .777 .777 r
F P
0 g
s
.6451 .67611 m .66777 .67446 L .67315 .68792 L p .852 .777 .777 r
F P
0 g
s
.44476 .4677 m .44276 .43716 L .44073 .44154 L p 0 0 .398 r
F P
0 g
s
.44073 .44154 m .44356 .47279 L .44476 .4677 L p 0 0 .398 r
F P
0 g
s
.61932 .51643 m .62849 .52733 L .63518 .51968 L p .564 .463 .699 r
F P
0 g
s
.63518 .51968 m .62339 .50995 L .61932 .51643 L p .564 .463 .699 r
F P
0 g
s
.6255 .47358 m .6343 .48766 L .63643 .48007 L p .277 .304 .71 r
F P
0 g
s
.63643 .48007 m .62598 .46752 L .6255 .47358 L p .277 .304 .71 r
F P
0 g
s
.6136 .74424 m .59662 .733 L .60251 .72804 L p .742 .832 .92 r
F P
0 g
s
.60251 .72804 m .62059 .73791 L .6136 .74424 L p .742 .832 .92 r
F P
0 g
s
.42393 .52124 m .43316 .51086 L .42949 .51181 L p .304 0 .148 r
F P
0 g
s
.42949 .51181 m .41772 .52176 L .42393 .52124 L p .304 0 .148 r
F P
0 g
s
.57889 .37869 m .58093 .41328 L .57527 .41258 L p .822 .533 .499 r
F P
0 g
s
.57527 .41258 m .57372 .37713 L .57889 .37869 L p .822 .533 .499 r
F P
0 g
s
.36635 .53586 m .3955 .52803 L .38609 .52931 L p 0 0 0 r
F P
0 g
s
.38609 .52931 m .35382 .53867 L .36635 .53586 L p 0 0 0 r
F P
0 g
s
.47748 .40127 m .48087 .37214 L .47565 .37428 L p .468 .209 .438 r
F P
0 g
s
.47565 .37428 m .47192 .40366 L .47748 .40127 L p .468 .209 .438 r
F P
0 g
s
.62703 .55291 m .6464 .56265 L .65273 .55715 L p .637 .594 .789 r
F P
0 g
s
.65273 .55715 m .63191 .54794 L .62703 .55291 L p .637 .594 .789 r
F P
0 g
s
.39928 .71829 m .36731 .72611 L .38241 .7251 L p .393 .841 .926 r
F P
0 g
s
.38241 .7251 m .41083 .71712 L .39928 .71829 L p .393 .841 .926 r
F P
0 g
s
.61758 .53942 m .63191 .54794 L .63888 .54179 L p .638 .556 .746 r
F P
0 g
s
.63888 .54179 m .62249 .53392 L .61758 .53942 L p .638 .556 .746 r
F P
0 g
s
.52482 .71706 m .51896 .71315 L p .52428 .70543 L .822 .484 .416 r
F P
0 g
s
.52475 .70475 m .52475 .70601 L p .52428 .70543 L .822 .484 .416 r
F P
0 g
s
.52475 .70601 m .52482 .71706 L p .52428 .70543 L .822 .484 .416 r
F P
0 g
s
.51778 .69719 m .52451 .70514 L p .51963 .6998 L 0 .059 .564 r
F P
0 g
s
.51875 .69883 m .51853 .69846 L p .51963 .6998 L 0 .059 .564 r
F P
0 g
s
.51853 .69846 m .51778 .69719 L p .51963 .6998 L 0 .059 .564 r
F P
0 g
s
.52451 .70514 m .52475 .70475 L .51875 .69883 L p 0 .059 .564 r
F P
0 g
s
.65407 .71529 m .62975 .70857 L .62917 .69715 L p .83 .781 .806 r
F P
0 g
s
.62917 .69715 m .6525 .70176 L .65407 .71529 L p .83 .781 .806 r
F P
0 g
s
.62339 .50995 m .63518 .51968 L .6421 .51113 L p .581 .49 .716 r
F P
0 g
s
.6421 .51113 m .62746 .50286 L .62339 .50995 L p .581 .49 .716 r
F P
0 g
s
.61528 .44498 m .61037 .42303 L .61385 .42623 L p .937 .573 .289 r
F P
0 g
s
.6464 .56265 m .66657 .57569 L .67423 .56987 L p .612 .558 .77 r
F P
0 g
s
.67423 .56987 m .65273 .55715 L .6464 .56265 L p .612 .558 .77 r
F P
0 g
s
.67991 .65395 m .66231 .66254 L .65786 .65252 L p .894 .805 .753 r
F P
0 g
s
.65786 .65252 m .67484 .64382 L .67991 .65395 L p .894 .805 .753 r
F P
0 g
s
.44607 .46213 m .44504 .43258 L .44276 .43716 L p 0 0 .376 r
F P
0 g
s
.44276 .43716 m .44476 .4677 L .44607 .46213 L p 0 0 .376 r
F P
0 g
s
.57372 .37713 m .57527 .41258 L .56954 .4119 L p .807 .524 .508 r
F P
0 g
s
.56954 .4119 m .56838 .37571 L .57372 .37713 L p .807 .524 .508 r
F P
0 g
s
.44191 .50591 m .43948 .48449 L .43778 .48727 L p .136 .045 .478 r
F P
0 g
s
.43778 .48727 m .43958 .50814 L .44191 .50591 L p .136 .045 .478 r
F P
0 g
s
.47748 .40127 m .48087 .37214 L .48632 .3704 L p .513 .246 .447 r
F P
0 g
s
.62598 .46752 m .63643 .48007 L .63735 .47288 L p .254 .331 .751 r
F P
0 g
s
.63735 .47288 m .62567 .46176 L .62598 .46752 L p .254 .331 .751 r
F P
0 g
s
.33744 .54885 m .36635 .53586 L .35382 .53867 L p .012 0 0 r
F P
0 g
s
.35382 .53867 m .32225 .55384 L .33744 .54885 L p .012 0 0 r
F P
0 g
s
.62249 .53392 m .63888 .54179 L .64758 .53433 L p .65 .555 .734 r
F P
0 g
s
.64758 .53433 m .62849 .52733 L .62249 .53392 L p .65 .555 .734 r
F P
0 g
s
.63191 .54794 m .65273 .55715 L .66191 .55048 L p .656 .577 .754 r
F P
0 g
s
.66191 .55048 m .63888 .54179 L .63191 .54794 L p .656 .577 .754 r
F P
0 g
s
.62746 .50286 m .6421 .51113 L .6487 .5019 L p .59 .512 .735 r
F P
0 g
s
.6487 .5019 m .63121 .49535 L .62746 .50286 L p .59 .512 .735 r
F P
0 g
s
.29706 .67669 m .2664 .65996 L .26123 .6733 L p .444 .454 .775 r
F P
0 g
s
.26123 .6733 m .29233 .68959 L .29706 .67669 L p .444 .454 .775 r
F P
0 g
s
.33272 .70541 m .29214 .70138 L .29662 .71145 L p .49 .628 .912 r
F P
0 g
s
.29662 .71145 m .33633 .71407 L .33272 .70541 L p .49 .628 .912 r
F P
0 g
s
.62059 .73791 m .60251 .72804 L .60708 .7215 L p .789 .83 .884 r
F P
0 g
s
.60708 .7215 m .62564 .72953 L .62059 .73791 L p .789 .83 .884 r
F P
0 g
s
.51323 .69391 m .51179 .69064 L .51778 .69719 L p .554 .028 0 r
F P
0 g
s
.51778 .69719 m .51875 .69883 L .51323 .69391 L p .554 .028 0 r
F P
0 g
s
.56838 .37571 m .56954 .4119 L .56378 .41114 L p .793 .514 .515 r
F P
0 g
s
.56378 .41114 m .5629 .37439 L .56838 .37571 L p .793 .514 .515 r
F P
0 g
s
.48337 .39955 m .48632 .3704 L .49198 .36905 L p .548 .276 .456 r
F P
0 g
s
.48632 .3704 m .48337 .39955 L .47748 .40127 L p .513 .246 .447 r
F P
0 g
s
.66657 .57569 m .68104 .59197 L .68961 .58623 L p .557 .472 .714 r
F P
0 g
s
.68961 .58623 m .67423 .56987 L .66657 .57569 L p .557 .472 .714 r
F P
0 g
s
.67661 .59761 m .68036 .61473 L .68492 .60914 L p .258 .178 .571 r
F P
0 g
s
.68492 .60914 m .68104 .59197 L .67661 .59761 L p .258 .178 .571 r
F P
0 g
s
.42954 .52058 m .43661 .50971 L .43316 .51086 L p .316 0 .213 r
F P
0 g
s
.43316 .51086 m .42393 .52124 L .42954 .52058 L p .316 0 .213 r
F P
0 g
s
.38919 .71737 m .35412 .72462 L .36731 .72611 L p .477 .838 .994 r
F P
0 g
s
.36731 .72611 m .39928 .71829 L .38919 .71737 L p .477 .838 .994 r
F P
0 g
s
.61037 .42303 m .61528 .44498 L .61056 .44285 L p .917 .57 .364 r
F P
0 g
s
.61056 .44285 m .60636 .42035 L .61037 .42303 L p .917 .57 .364 r
F P
0 g
s
.40469 .52713 m .42393 .52124 L .41772 .52176 L p .166 0 0 r
F P
0 g
s
.41772 .52176 m .3955 .52803 L .40469 .52713 L p .166 0 0 r
F P
0 g
s
.62849 .52733 m .64758 .53433 L .65746 .52553 L p .653 .556 .732 r
F P
0 g
s
.65746 .52553 m .63518 .51968 L .62849 .52733 L p .653 .556 .732 r
F P
0 g
s
.65273 .55715 m .67423 .56987 L .6854 .56308 L p .634 .543 .735 r
F P
0 g
s
.6854 .56308 m .66191 .55048 L .65273 .55715 L p .634 .543 .735 r
F P
0 g
s
.44762 .45619 m .44764 .4279 L .44504 .43258 L p 0 0 .358 r
F P
0 g
s
.44504 .43258 m .44603 .46119 L p .44762 .45619 L 0 0 .358 r
F P
0 g
s
.44764 .4279 m .44762 .45503 L p .44956 .45008 L 0 0 .347 r
F P
0 g
s
.44762 .45503 m .44762 .45619 L .44956 .45008 L p 0 0 .347 r
F P
0 g
s
.44956 .45008 m .45059 .4232 L .44764 .4279 L p 0 0 .347 r
F P
0 g
s
.45059 .4232 m .44961 .44876 L p .45202 .44399 L 0 0 .343 r
F P
0 g
s
.44961 .44876 m .44956 .45008 L .45202 .44399 L p 0 0 .343 r
F P
0 g
s
.45202 .44399 m .45396 .41861 L .45059 .4232 L p 0 0 .343 r
F P
0 g
s
.45396 .41861 m .45213 .44256 L p .45511 .43816 L .038 0 .348 r
F P
0 g
s
.45213 .44256 m .45202 .44399 L .45511 .43816 L p .038 0 .348 r
F P
0 g
s
.45511 .43816 m .45777 .41425 L .45396 .41861 L p .038 0 .348 r
F P
0 g
s
.45777 .41425 m .45528 .43666 L p .4589 .43282 L .136 0 .358 r
F P
0 g
s
.45528 .43666 m .45511 .43816 L .4589 .43282 L p .136 0 .358 r
F P
0 g
s
.4589 .43282 m .46203 .41023 L .45777 .41425 L p .136 0 .358 r
F P
0 g
s
.46203 .41023 m .45911 .43126 L p .4634 .42819 L .241 .026 .373 r
F P
0 g
s
.45911 .43126 m .4589 .43282 L .4634 .42819 L p .241 .026 .373 r
F P
0 g
s
.46269 .42881 m .4634 .42819 L .4589 .43282 L p .705 .912 .563 r
F P
0 g
s
.4634 .42819 m .45631 .43432 L p .46096 .43011 L .49 .831 .548 r
F P
0 g
s
.45631 .43432 m .45552 .435 L .46096 .43011 L p .49 .831 .548 r
F P
0 g
s
.4634 .42819 m .46676 .40666 L .46203 .41023 L p .241 .026 .373 r
F P
0 g
s
.46676 .40666 m .4634 .42819 L .46859 .42445 L p .345 .099 .39 r
F P
0 g
s
.45349 .4162 m .46589 .42565 L p .46096 .43011 L .699 .835 .948 r
F P
0 g
s
.46096 .43011 m .46785 .425 L p .4634 .42819 L .49 .831 .548 r
F P
0 g
s
.46785 .425 m .46859 .42445 L .4634 .42819 L p .49 .831 .548 r
F P
0 g
s
.45552 .435 m .46269 .42881 L p .4589 .43282 L .705 .912 .563 r
F P
0 g
s
.46859 .42445 m .46177 .42951 L p .46741 .42681 L 0 0 0 r
F P
0 g
s
.46177 .42951 m .46096 .43011 L .46741 .42681 L p 0 0 0 r
F P
0 g
s
.47469 .42525 m .46741 .42681 L p .46871 .42616 L .114 0 0 r
F P
0 g
s
.48073 .42015 m .47469 .42525 L p .46871 .42616 L .114 0 0 r
F P
0 g
s
.48254 .42545 m .47469 .42525 L p .4759 .42472 L .333 0 0 r
F P
0 g
s
.48744 .41967 m .48254 .42545 L p .4759 .42472 L .333 0 0 r
F P
0 g
s
.4907 .42733 m .48254 .42545 L p .4836 .42499 L .504 .001 0 r
F P
0 g
s
.49437 .42028 m .4907 .42733 L p .4836 .42499 L .504 .001 0 r
F P
0 g
s
.49889 .43067 m .4907 .42733 L p .49156 .42688 L .623 .159 .131 r
F P
0 g
s
.50139 .42183 m .49889 .43067 L p .49156 .42688 L .623 .159 .131 r
F P
0 g
s
.50686 .43517 m .49889 .43067 L p .50127 .42903 L .699 .278 .244 r
F P
0 g
s
.50835 .42417 m .50702 .43402 L p .50127 .42903 L .699 .278 .244 r
F P
0 g
s
.50702 .43402 m .50686 .43517 L p .50127 .42903 L .699 .278 .244 r
F P
0 g
s
.50686 .43517 m .50835 .42417 L .51514 .42706 L p .744 .365 .334 r
F P
0 g
s
.52169 .43028 m .5215 .44613 L .51444 .44047 L p .769 .426 .406 r
F P
0 g
s
.51444 .44047 m .5215 .44613 L p .52094 .44567 L 0 .108 .574 r
F P
0 g
s
.50729 .43475 m .50922 .43287 L .51444 .44047 L .744 .365 .334 r
F
.51454 .43868 m .51444 .44047 L p .50922 .43287 L F P
0 g
s
.51444 .44047 m .51514 .42706 L .52169 .43028 L p .769 .426 .406 r
F P
0 g
s
.52798 .43356 m .52801 .45173 L .5215 .44613 L p .78 .469 .462 r
F P
0 g
s
.52801 .45173 m .52819 .45546 L .52083 .44716 L p .61 .074 0 r
F P
0 g
s
.5215 .44613 m .52801 .45173 L p .52095 .44724 L .61 .074 0 r
F P
0 g
s
.52083 .44716 m .52084 .44714 L p .52095 .44724 L .61 .074 0 r
F P
0 g
s
.52084 .44714 m .5215 .44613 L p .52095 .44724 L .61 .074 0 r
F P
0 g
s
.52801 .45173 m .52798 .43356 L .534 .43667 L p .782 .497 .504 r
F P
0 g
s
.5215 .44613 m .52169 .43028 L .52798 .43356 L p .78 .469 .462 r
F P
0 g
s
.52857 .44825 m .51958 .43727 L p .52682 .45256 L .064 .368 .836 r
F P
0 g
s
.52801 .45173 m .534 .45687 L p .52839 .45551 L .752 .236 0 r
F P
0 g
s
.52819 .45546 m .52819 .45531 L p .52839 .45551 L .752 .236 0 r
F P
0 g
s
.52819 .45531 m .52801 .45173 L p .52839 .45551 L .752 .236 0 r
F P
0 g
s
.5398 .4394 m .5396 .46119 L .534 .45687 L p .78 .515 .535 r
F P
0 g
s
.534 .45687 m .534 .43667 L .5398 .4394 L p .78 .515 .535 r
F P
0 g
s
.534 .43667 m .534 .45687 L .52801 .45173 L p .782 .497 .504 r
F P
0 g
s
.534 .45687 m .5396 .46119 L p .5349 .4629 L .819 .348 .09 r
F P
0 g
s
.5347 .46297 m .53467 .46268 L p .5349 .4629 L .819 .348 .09 r
F P
0 g
s
.53467 .46268 m .534 .45687 L p .5349 .4629 L .819 .348 .09 r
F P
0 g
s
.5396 .46119 m .54496 .46443 L p .54071 .469 L .819 .401 .251 r
F P
0 g
s
.54055 .46916 m .54051 .46885 L p .54071 .469 L .819 .401 .251 r
F P
0 g
s
.54051 .46885 m .5396 .46119 L p .54071 .469 L .819 .401 .251 r
F P
0 g
s
.55029 .46643 m .55155 .47624 L .54605 .47366 L p .782 .408 .348 r
F P
0 g
s
.54605 .47366 m .54496 .46443 L .55029 .46643 L p .782 .408 .348 r
F P
0 g
s
.54496 .46443 m .54605 .47366 L .54055 .46916 L p .819 .401 .251 r
F P
0 g
s
.54918 .47202 m .54297 .46621 L p .54574 .47292 L .068 .439 .876 r
F P
0 g
s
.54605 .47366 m .54644 .47346 L p .54574 .47292 L .068 .439 .876 r
F P
0 g
s
.54644 .47346 m .54918 .47202 L p .54574 .47292 L .068 .439 .876 r
F P
0 g
s
.5396 .46119 m .54055 .46916 L .5347 .46297 L p .819 .348 .09 r
F P
0 g
s
.54297 .46621 m .53625 .45812 L p .53998 .46768 L .051 .378 .843 r
F P
0 g
s
.54055 .46916 m .54098 .46864 L p .53998 .46768 L .051 .378 .843 r
F P
0 g
s
.54098 .46864 m .54297 .46621 L p .53998 .46768 L .051 .378 .843 r
F P
0 g
s
.534 .45687 m .5347 .46297 L .52819 .45546 L p .752 .236 0 r
F P
0 g
s
.53625 .45812 m .52857 .44825 L p .53376 .46072 L .049 .357 .83 r
F P
0 g
s
.5347 .46297 m .53503 .46195 L p .53376 .46072 L .049 .357 .83 r
F P
0 g
s
.53503 .46195 m .53625 .45812 L p .53376 .46072 L .049 .357 .83 r
F P
0 g
s
.52819 .45546 m .52828 .45388 L p .52682 .45256 L .064 .368 .836 r
F P
0 g
s
.52828 .45388 m .52857 .44825 L p .52682 .45256 L .064 .368 .836 r
F P
0 g
s
.52083 .44716 m .52819 .45546 L p .52492 .44855 L .064 .368 .836 r
F P
0 g
s
.51958 .43727 m .52057 .4451 L p .52492 .44855 L .064 .368 .836 r
F P
0 g
s
.5132 .43925 m .51444 .44047 L .52094 .44567 L 0 .108 .574 r
F
.51251 .43867 m .51269 .43885 L p .5132 .43925 L F P
0 g
s
.51269 .43885 m .51444 .44047 L p .5132 .43925 L 0 .108 .574 r
F P
0 g
s
.51444 .44047 m .50686 .43517 L p .50729 .43475 L .744 .365 .334 r
F P
0 g
s
.51251 .43867 m .50328 .43064 L p .50481 .43199 L 0 .286 .741 r
F P
0 g
s
.50481 .43199 m .5136 .43973 L .51251 .43867 L 0 .286 .741 r
F
.51444 .44047 m .51425 .44029 L p .5136 .43973 L F P
0 g
s
.51425 .44029 m .51251 .43867 L p .5136 .43973 L 0 .286 .741 r
F P
0 g
s
.50328 .43064 m .50686 .43517 L .51444 .44047 L p 0 .286 .741 r
F P
0 g
s
.52083 .44716 m .51251 .43867 L p .52094 .44567 L 0 .108 .574 r
F P
0 g
s
.51949 .44475 m .51251 .43867 L .52083 .44716 L .1 .404 .857 r
F
.51514 .42706 m .51454 .43868 L p .50922 .43287 L .744 .365 .334 r
F P
0 g
s
.50915 .426 m .51251 .43867 L p .51949 .44475 L .1 .404 .857 r
F P
0 g
s
.5215 .44613 m .52145 .44622 L p .52094 .44567 L 0 .108 .574 r
F P
0 g
s
.52145 .44622 m .52083 .44716 L p .52094 .44567 L 0 .108 .574 r
F P
0 g
s
.52057 .4451 m .52083 .44716 L p .52492 .44855 L .064 .368 .836 r
F P
0 g
s
.49889 .43067 m .50686 .43517 L p .50571 .4342 L 0 .447 .862 r
F P
0 g
s
.4907 .42733 m .49437 .42028 L .50139 .42183 L p .623 .159 .131 r
F P
0 g
s
.49889 .43067 m .50139 .42183 L .50835 .42417 L p .699 .278 .244 r
F P
0 g
s
.49332 .42369 m .49889 .43067 L p .50571 .4342 L 0 .447 .862 r
F P
0 g
s
.4907 .42733 m .49889 .43067 L p .49742 .42954 L .187 .583 .941 r
F P
0 g
s
.48953 .39851 m .48744 .41967 L .48073 .42015 L p .557 .272 .438 r
F P
0 g
s
.47469 .42525 m .48073 .42015 L .48744 .41967 L p .333 0 0 r
F P
0 g
s
.48254 .42545 m .48744 .41967 L .49437 .42028 L p .504 .001 0 r
F P
0 g
s
.48294 .41839 m .4907 .42733 L p .49742 .42954 L .187 .583 .941 r
F P
0 g
s
.48254 .42545 m .4907 .42733 L p .48895 .42616 L .357 .688 .981 r
F P
0 g
s
.4744 .42174 m .47748 .40127 L .47192 .40366 L p .439 .171 .408 r
F P
0 g
s
.47192 .40366 m .46859 .42445 L .4744 .42174 L p .439 .171 .408 r
F P
0 g
s
.4744 .42174 m .47748 .40127 L .48337 .39955 L p .508 .227 .423 r
F P
0 g
s
.48337 .39955 m .48073 .42015 L .4744 .42174 L p .508 .227 .423 r
F P
0 g
s
.46741 .42681 m .4744 .42174 L .48073 .42015 L p .114 0 0 r
F P
0 g
s
.47255 .4152 m .48254 .42545 L p .48895 .42616 L .357 .688 .981 r
F P
0 g
s
.47469 .42525 m .48254 .42545 L p .48056 .42436 L .499 .762 .99 r
F P
0 g
s
.46859 .42445 m .47192 .40366 L .46676 .40666 L p .345 .099 .39 r
F P
0 g
s
.46741 .42681 m .4744 .42174 L .46859 .42445 L p 0 0 0 r
F P
0 g
s
.46258 .41443 m .47469 .42525 L p .48056 .42436 L .499 .762 .99 r
F P
0 g
s
.46741 .42681 m .47469 .42525 L p .47257 .42435 L .61 .809 .976 r
F P
0 g
s
.45349 .4162 m .46741 .42681 L p .47257 .42435 L .61 .809 .976 r
F P
0 g
s
.46589 .42565 m .46741 .42681 L .46096 .43011 L p .699 .835 .948 r
F P
0 g
s
.45121 .44125 m .45825 .43353 L p .45511 .43816 L .826 .919 .526 r
F P
0 g
s
.45825 .43353 m .4589 .43282 L .45511 .43816 L p .826 .919 .526 r
F P
0 g
s
.44805 .44853 m .45457 .43896 L p .45202 .44399 L .885 .889 .463 r
F P
0 g
s
.45457 .43896 m .45511 .43816 L .45202 .44399 L p .885 .889 .463 r
F P
0 g
s
.44598 .45648 m .45161 .44485 L p .44956 .45008 L .904 .842 .385 r
F P
0 g
s
.45161 .44485 m .45202 .44399 L .44956 .45008 L p .904 .842 .385 r
F P
0 g
s
.44485 .46471 m .44928 .45093 L p .44762 .45619 L .893 .783 .293 r
F P
0 g
s
.44928 .45093 m .44956 .45008 L .44762 .45619 L p .893 .783 .293 r
F P
0 g
s
.44603 .46119 m .44607 .46213 L .44762 .45619 L p 0 0 .358 r
F P
0 g
s
.48953 .39851 m .49198 .36905 L .49779 .3681 L p .58 .305 .465 r
F P
0 g
s
.49198 .36905 m .48953 .39851 L .48337 .39955 L p .548 .276 .456 r
F P
0 g
s
.5629 .37439 m .56378 .41114 L .55798 .41023 L p .78 .504 .519 r
F P
0 g
s
.55798 .41023 m .55731 .37316 L .5629 .37439 L p .78 .504 .519 r
F P
0 g
s
.63888 .54179 m .66191 .55048 L .67348 .54241 L p .66 .565 .737 r
F P
0 g
s
.67348 .54241 m .64758 .53433 L .63888 .54179 L p .66 .565 .737 r
F P
0 g
s
.62567 .46176 m .63735 .47288 L .63688 .46638 L p .196 .346 .789 r
F P
0 g
s
.44352 .50284 m .44099 .48119 L .43948 .48449 L p .009 0 .456 r
F P
0 g
s
.43948 .48449 m .44191 .50591 L .44352 .50284 L p .009 0 .456 r
F P
0 g
s
.67984 .62125 m .67206 .63558 L .67252 .62907 L p .945 .932 .584 r
F P
0 g
s
.63121 .49535 m .6487 .5019 L .65444 .4923 L p .595 .534 .757 r
F P
0 g
s
.65444 .4923 m .6343 .48766 L .63121 .49535 L p .595 .534 .757 r
F P
0 g
s
.50799 .69032 m .50618 .68592 L .51179 .69064 L p .655 .103 0 r
F P
0 g
s
.51179 .69064 m .51323 .69391 L .50799 .69032 L p .655 .103 0 r
F P
0 g
s
.49587 .39812 m .49779 .3681 L .50373 .36752 L p .608 .333 .474 r
F P
0 g
s
.49779 .3681 m .49587 .39812 L .48953 .39851 L p .58 .305 .465 r
F P
0 g
s
.55731 .37316 m .55798 .41023 L .55214 .40914 L p .767 .494 .521 r
F P
0 g
s
.55214 .40914 m .5516 .372 L .55731 .37316 L p .767 .494 .521 r
F P
0 g
s
.63518 .51968 m .65746 .52553 L .66781 .51553 L p .652 .559 .737 r
F P
0 g
s
.66781 .51553 m .6421 .51113 L .63518 .51968 L p .652 .559 .737 r
F P
0 g
s
.66777 .67446 m .6451 .67611 L .64088 .66515 L p .846 .768 .775 r
F P
0 g
s
.64088 .66515 m .66231 .66254 L .66777 .67446 L p .846 .768 .775 r
F P
0 g
s
.50233 .39832 m .50373 .36752 L .50975 .3673 L p .634 .358 .483 r
F P
0 g
s
.50373 .36752 m .50233 .39832 L .49587 .39812 L p .608 .333 .474 r
F P
0 g
s
.29371 .59891 m .30001 .57491 L .28409 .58359 L p .334 .11 .417 r
F P
0 g
s
.28409 .58359 m .27722 .60973 L .29371 .59891 L p .334 .11 .417 r
F P
0 g
s
.64758 .53433 m .67348 .54241 L .68671 .53283 L p .656 .557 .731 r
F P
0 g
s
.68671 .53283 m .65746 .52553 L .64758 .53433 L p .656 .557 .731 r
F P
0 g
s
.5516 .372 m .55214 .40914 L .54624 .40786 L p .754 .482 .521 r
F P
0 g
s
.54624 .40786 m .5458 .37092 L .5516 .372 L p .754 .482 .521 r
F P
0 g
s
.66191 .55048 m .6854 .56308 L .69952 .55496 L p .637 .53 .717 r
F P
0 g
s
.69952 .55496 m .67348 .54241 L .66191 .55048 L p .637 .53 .717 r
F P
0 g
s
.37855 .53371 m .40469 .52713 L .3955 .52803 L p .033 0 0 r
F P
0 g
s
.3955 .52803 m .36635 .53586 L .37855 .53371 L p .033 0 0 r
F P
0 g
s
.50274 .68824 m .50056 .68331 L .50618 .68592 L p .673 .139 0 r
F P
0 g
s
.50618 .68592 m .50799 .69032 L .50274 .68824 L p .673 .139 0 r
F P
0 g
s
.60636 .42035 m .61056 .44285 L .6052 .44158 L p .893 .565 .42 r
F P
0 g
s
.6052 .44158 m .60189 .41816 L .60636 .42035 L p .893 .565 .42 r
F P
0 g
s
.67423 .56987 m .68961 .58623 L .70214 .57989 L p .589 .47 .685 r
F P
0 g
s
.70214 .57989 m .6854 .56308 L .67423 .56987 L p .589 .47 .685 r
F P
0 g
s
.62564 .72953 m .60708 .7215 L .61027 .71373 L p .821 .82 .847 r
F P
0 g
s
.61027 .71373 m .62866 .71956 L .62564 .72953 L p .821 .82 .847 r
F P
0 g
s
.50882 .39904 m .50975 .3673 L .51581 .36738 L p .656 .381 .492 r
F P
0 g
s
.50975 .3673 m .50882 .39904 L .50233 .39832 L p .634 .358 .483 r
F P
0 g
s
.6525 .70176 m .62917 .69715 L .62735 .6859 L p .834 .765 .786 r
F P
0 g
s
.62735 .6859 m .64926 .68849 L .6525 .70176 L p .834 .765 .786 r
F P
0 g
s
.5458 .37092 m .54624 .40786 L .54026 .40639 L p .74 .469 .52 r
F P
0 g
s
.54026 .40639 m .53992 .36993 L .5458 .37092 L p .74 .469 .52 r
F P
0 g
s
.6343 .48766 m .65444 .4923 L .6588 .48272 L p .595 .558 .782 r
F P
0 g
s
.6588 .48272 m .63643 .48007 L .6343 .48766 L p .595 .558 .782 r
F P
0 g
s
.31697 .56752 m .33744 .54885 L .32225 .55384 L p .22 0 .11 r
F P
0 g
s
.32225 .55384 m .30001 .57491 L .31697 .56752 L p .22 0 .11 r
F P
0 g
s
.44443 .49878 m .44233 .47729 L .44099 .48119 L p 0 0 .388 r
F P
0 g
s
.44099 .48119 m .44352 .50284 L .44443 .49878 L p 0 0 .388 r
F P
0 g
s
.62446 .45649 m .63688 .46638 L .63491 .46085 L p .084 .338 .812 r
F P
0 g
s
.6421 .51113 m .66781 .51553 L .67784 .50454 L p .648 .566 .748 r
F P
0 g
s
.67784 .50454 m .6487 .5019 L .6421 .51113 L p .648 .566 .748 r
F P
0 g
s
.51529 .40016 m .51581 .36738 L .52189 .36772 L p .677 .403 .5 r
F P
0 g
s
.51581 .36738 m .51529 .40016 L .50882 .39904 L p .656 .381 .492 r
F P
0 g
s
.43413 .51943 m .43958 .50814 L .43661 .50971 L p .257 0 .226 r
F P
0 g
s
.43661 .50971 m .42954 .52058 L .43413 .51943 L p .257 0 .226 r
F P
0 g
s
.53992 .36993 m .54026 .40639 L .53419 .4048 L p .726 .455 .517 r
F P
0 g
s
.53419 .4048 m .53396 .36904 L .53992 .36993 L p .726 .455 .517 r
F P
0 g
s
.49724 .68775 m .49449 .68288 L .50056 .68331 L p .61 .124 .075 r
F P
0 g
s
.50056 .68331 m .50274 .68824 L .49724 .68775 L p .61 .124 .075 r
F P
0 g
s
.5217 .40158 m .52189 .36772 L .52794 .36829 L p .695 .422 .507 r
F P
0 g
s
.52189 .36772 m .5217 .40158 L .51529 .40016 L p .677 .403 .5 r
F P
0 g
s
.53396 .36904 m .53419 .4048 L .528 .40316 L p .711 .439 .512 r
F P
0 g
s
.528 .40316 m .52794 .36829 L .53396 .36904 L p .711 .439 .512 r
F P
0 g
s
.67484 .64382 m .65786 .65252 L .65542 .64452 L p .892 .838 .786 r
F P
0 g
s
.65542 .64452 m .67206 .63558 L .67484 .64382 L p .892 .838 .786 r
F P
0 g
s
.68104 .59197 m .68492 .60914 L .69376 .60397 L p .457 .303 .584 r
F P
0 g
s
.69376 .60397 m .68961 .58623 L .68104 .59197 L p .457 .303 .584 r
F P
0 g
s
.2896 .63335 m .27722 .60973 L .26329 .62167 L p .424 .309 .618 r
F P
0 g
s
.26329 .62167 m .27617 .64644 L .2896 .63335 L p .424 .309 .618 r
F P
0 g
s
.52794 .36829 m .528 .40316 L .5217 .40158 L p .695 .422 .507 r
F P
0 g
s
.3811 .7143 m .34359 .72057 L .35412 .72462 L p .534 .792 .992 r
F P
0 g
s
.35412 .72462 m .38919 .71737 L .3811 .7143 L p .534 .792 .992 r
F P
0 g
s
.49124 .68876 m .4876 .68452 L .49449 .68288 L p .519 .074 .131 r
F P
0 g
s
.49449 .68288 m .49724 .68775 L .49124 .68876 L p .519 .074 .131 r
F P
0 g
s
.65746 .52553 m .68671 .53283 L .70066 .52178 L p .649 .554 .733 r
F P
0 g
s
.70066 .52178 m .66781 .51553 L .65746 .52553 L p .649 .554 .733 r
F P
0 g
s
.41287 .52623 m .42954 .52058 L .42393 .52124 L p .163 0 0 r
F P
0 g
s
.42393 .52124 m .40469 .52713 L .41287 .52623 L p .163 0 0 r
F P
0 g
s
.48457 .69109 m .47961 .68796 L .4876 .68452 L p .432 .005 .126 r
F P
0 g
s
.4876 .68452 m .49124 .68876 L .48457 .69109 L p .432 .005 .126 r
F P
0 g
s
.47712 .69442 m .47036 .69275 L .47961 .68796 L p .351 0 .077 r
F P
0 g
s
.47961 .68796 m .48457 .69109 L .47712 .69442 L p .351 0 .077 r
F P
0 g
s
.67348 .54241 m .69952 .55496 L .71574 .54529 L p .631 .521 .71 r
F P
0 g
s
.71574 .54529 m .68671 .53283 L .67348 .54241 L p .631 .521 .71 r
F P
0 g
s
.60189 .41816 m .6052 .44158 L .59936 .44107 L p .868 .559 .463 r
F P
0 g
s
.59936 .44107 m .59703 .41644 L .60189 .41816 L p .868 .559 .463 r
F P
0 g
s
.56409 .73393 m .5593 .73546 L .5519 .73294 L p .504 0 0 r
F P
0 g
s
.54671 .72423 m .54465 .72955 L .53767 .72557 L p .751 .265 .084 r
F P
0 g
s
.46891 .69836 m .45985 .69837 L .47036 .69275 L p .271 0 0 r
F P
0 g
s
.47036 .69275 m .47712 .69442 L .46891 .69836 L p .271 0 0 r
F P
0 g
s
.46005 .70248 m .44826 .7042 L .45985 .69837 L p .184 0 0 r
F P
0 g
s
.45985 .69837 m .46891 .69836 L .46005 .70248 L p .184 0 0 r
F P
0 g
s
.35221 .54479 m .37855 .53371 L .36635 .53586 L p .091 0 0 r
F P
0 g
s
.36635 .53586 m .33744 .54885 L .35221 .54479 L p .091 0 0 r
F P
0 g
s
.6487 .5019 m .67784 .50454 L .68673 .49294 L p .643 .576 .764 r
F P
0 g
s
.68673 .49294 m .65444 .4923 L .6487 .5019 L p .643 .576 .764 r
F P
0 g
s
.63643 .48007 m .6588 .48272 L .66134 .47359 L p .593 .584 .812 r
F P
0 g
s
.66134 .47359 m .63735 .47288 L .63643 .48007 L p .593 .584 .812 r
F P
0 g
s
.53871 .71793 m .53767 .72557 L .53105 .7213 L p .801 .37 .224 r
F P
0 g
s
.57298 .73655 m .56668 .73688 L .5593 .73546 L p .281 0 0 r
F P
0 g
s
.44476 .49369 m .44356 .47279 L .44233 .47729 L p 0 0 .266 r
F P
0 g
s
.44233 .47729 m .44443 .49878 L .44476 .49369 L p 0 0 .266 r
F P
0 g
s
.6854 .56308 m .70214 .57989 L .71802 .57247 L p .596 .463 .67 r
F P
0 g
s
.71802 .57247 m .69952 .55496 L .6854 .56308 L p .596 .463 .67 r
F P
0 g
s
.67529 .62399 m .67252 .62907 L .67682 .62393 L p 0 0 0 r
F P
0 g
s
.65956 .63405 m .67682 .62393 L .67252 .62907 L p .749 .994 .858 r
F P
0 g
s
.66685 .63087 m .67833 .62388 L p .67682 .62393 L 0 0 0 r
F P
0 g
s
.67833 .62388 m .68519 .61969 L .67682 .62393 L p 0 0 0 r
F P
0 g
s
.68036 .61473 m .67529 .62399 L p .67682 .62393 L 0 0 0 r
F P
0 g
s
.45075 .70632 m .4359 .70964 L .44826 .7042 L p .081 0 0 r
F P
0 g
s
.44826 .7042 m .46005 .70248 L .45075 .70632 L p .081 0 0 r
F P
0 g
s
.33291 .69502 m .29233 .68959 L .29214 .70138 L p .53 .589 .858 r
F P
0 g
s
.29214 .70138 m .33272 .70541 L .33291 .69502 L p .53 .589 .858 r
F P
0 g
s
.52482 .71706 m .52475 .70475 L .53138 .71127 L p .821 .441 .333 r
F P
0 g
s
.43742 .51743 m .44191 .50591 L .43958 .50814 L p .061 0 .157 r
F P
0 g
s
.43958 .50814 m .43413 .51943 L .43742 .51743 L p .061 0 .157 r
F P
0 g
s
.66781 .51553 m .70066 .52178 L .71429 .50945 L p .64 .555 .743 r
F P
0 g
s
.71429 .50945 m .67784 .50454 L .66781 .51553 L p .64 .555 .743 r
F P
0 g
s
.62866 .71956 m .61027 .71373 L .61214 .70513 L p .844 .806 .813 r
F P
0 g
s
.61214 .70513 m .62975 .70857 L .62866 .71956 L p .844 .806 .813 r
F P
0 g
s
.5806 .73585 m .57385 .73703 L p .57527 .73695 L .28 .781 .857 r
F P
0 g
s
.58956 .73614 m .5806 .73585 L p .57527 .73695 L .28 .781 .857 r
F P
0 g
s
.58158 .73733 m .57385 .73703 L p .56803 .73692 L 0 .574 .72 r
F P
0 g
s
.58956 .73614 m .58147 .73587 L p .58676 .73331 L .542 .923 .918 r
F P
0 g
s
.58147 .73587 m .5806 .73585 L .58676 .73331 L p .542 .923 .918 r
F P
0 g
s
.58676 .73331 m .59662 .733 L .58956 .73614 L p .542 .923 .918 r
F P
0 g
s
.59662 .733 m .58766 .73329 L p .59218 .72952 L .738 .985 .903 r
F P
0 g
s
.58766 .73329 m .58676 .73331 L .59218 .72952 L p .738 .985 .903 r
F P
0 g
s
.59218 .72952 m .60251 .72804 L .59662 .733 L p .738 .985 .903 r
F P
0 g
s
.60251 .72804 m .59305 .7294 L p .59676 .72463 L .855 .987 .849 r
F P
0 g
s
.59305 .7294 m .59218 .72952 L .59676 .72463 L p .855 .987 .849 r
F P
0 g
s
.59676 .72463 m .60708 .7215 L .60251 .72804 L p .855 .987 .849 r
F P
0 g
s
.60708 .7215 m .59755 .72439 L p .60047 .71886 L .922 .965 .782 r
F P
0 g
s
.59755 .72439 m .59676 .72463 L .60047 .71886 L p .922 .965 .782 r
F P
0 g
s
.60047 .71886 m .61027 .71373 L .60708 .7215 L p .922 .965 .782 r
F P
0 g
s
.61027 .71373 m .60113 .71851 L p .60333 .71247 L .961 .934 .713 r
F P
0 g
s
.60113 .71851 m .60047 .71886 L .60333 .71247 L p .961 .934 .713 r
F P
0 g
s
.60333 .71247 m .61214 .70513 L .61027 .71373 L p .961 .934 .713 r
F P
0 g
s
.61214 .70513 m .60382 .71207 L p .60544 .70577 L .983 .901 .643 r
F P
0 g
s
.60382 .71207 m .60333 .71247 L .60544 .70577 L p .983 .901 .643 r
F P
0 g
s
.60544 .70577 m .61287 .69616 L .61214 .70513 L p .983 .901 .643 r
F P
0 g
s
.61287 .69616 m .60574 .70537 L p .60694 .69904 L .995 .868 .57 r
F P
0 g
s
.60574 .70537 m .60544 .70577 L .60694 .69904 L p .995 .868 .57 r
F P
0 g
s
.60694 .69904 m .61272 .68725 L .61287 .69616 L p .995 .868 .57 r
F P
0 g
s
.61272 .68725 m .60707 .69877 L p .60803 .69255 L .996 .836 .486 r
F P
0 g
s
.60707 .69877 m .60694 .69904 L .60803 .69255 L p .996 .836 .486 r
F P
0 g
s
.60803 .69255 m .61205 .67883 L .61272 .68725 L p .996 .836 .486 r
F P
0 g
s
.61205 .67883 m .60803 .69255 L .60891 .68656 L p .976 .795 .376 r
F P
0 g
s
.61205 .7147 m .60893 .68669 L p .60803 .69255 L 0 0 .387 r
F P
0 g
s
.60893 .68669 m .60891 .68656 L .60803 .69255 L p 0 0 .387 r
F P
0 g
s
.60984 .71944 m .60806 .69309 L p .60694 .69904 L 0 0 .342 r
F P
0 g
s
.60806 .69309 m .60803 .69255 L .60694 .69904 L p 0 0 .342 r
F P
0 g
s
.60736 .72439 m .60695 .69987 L p .60544 .70577 L 0 0 .307 r
F P
0 g
s
.60695 .69987 m .60694 .69904 L .60544 .70577 L p 0 0 .307 r
F P
0 g
s
.60451 .72941 m .6054 .70681 L p .60333 .71247 L 0 0 .285 r
F P
0 g
s
.6054 .70681 m .60544 .70577 L .60333 .71247 L p 0 0 .285 r
F P
0 g
s
.60122 .73433 m .60322 .71365 L p .60047 .71886 L 0 0 .278 r
F P
0 g
s
.60322 .71365 m .60333 .71247 L .60047 .71886 L p 0 0 .278 r
F P
0 g
s
.59743 .73898 m .60028 .72011 L p .59676 .72463 L .025 0 .285 r
F P
0 g
s
.60028 .72011 m .60047 .71886 L .59676 .72463 L p .025 0 .285 r
F P
0 g
s
.5931 .74321 m .59651 .72592 L p .59218 .72952 L .161 0 .303 r
F P
0 g
s
.59651 .72592 m .59676 .72463 L .59218 .72952 L p .161 0 .303 r
F P
0 g
s
.58822 .74685 m .59188 .73084 L p .58676 .73331 L .299 .03 .327 r
F P
0 g
s
.59188 .73084 m .59218 .72952 L .58676 .73331 L p .299 .03 .327 r
F P
0 g
s
.58283 .74978 m .58644 .73463 L p .5806 .73585 L .423 .126 .354 r
F P
0 g
s
.58644 .73463 m .58676 .73331 L .5806 .73585 L p .423 .126 .354 r
F P
0 g
s
.57385 .73703 m .5806 .73585 L p .57986 .73715 L .511 .2 .376 r
F P
0 g
s
.57077 .75322 m .57385 .73703 L p .57986 .73715 L .511 .2 .376 r
F P
0 g
s
.57385 .73703 m .56668 .73688 L p .56803 .73692 L 0 .574 .72 r
F P
0 g
s
.4359 .70964 m .45075 .70632 L .44133 .70946 L p 0 0 0 r
F P
0 g
s
.59703 .41644 m .59936 .44107 L .5932 .4412 L p .847 .555 .495 r
F P
0 g
s
.5932 .4412 m .59187 .4151 L .59703 .41644 L p .847 .555 .495 r
F P
0 g
s
.51896 .71315 m .51875 .69883 L .52475 .70475 L p .822 .484 .416 r
F P
0 g
s
.68961 .58623 m .69376 .60397 L .7067 .59864 L p .52 .341 .579 r
F P
0 g
s
.7067 .59864 m .70214 .57989 L .68961 .58623 L p .52 .341 .579 r
F P
0 g
s
.68671 .53283 m .71574 .54529 L .73292 .534 L p .62 .515 .712 r
F P
0 g
s
.73292 .534 m .70066 .52178 L .68671 .53283 L p .62 .515 .712 r
F P
0 g
s
.38938 .5318 m .41287 .52623 L .40469 .52713 L p .002 0 0 r
F P
0 g
s
.40469 .52713 m .37855 .53371 L .38938 .5318 L p .002 0 0 r
F P
0 g
s
.30581 .66336 m .27617 .64644 L .2664 .65996 L p .498 .455 .74 r
F P
0 g
s
.2664 .65996 m .29706 .67669 L .30581 .66336 L p .498 .455 .74 r
F P
0 g
s
.44476 .4677 m .44356 .47279 L p .44445 .48444 L 0 0 .108 r
F P
0 g
s
.44445 .48444 m .44464 .48684 L .44466 .48247 L 0 0 .108 r
F
.44445 .48444 m .44466 .48247 L .44476 .4677 L F
.4447 .48573 m .44476 .4677 L p .44464 .48684 L F P
0 g
s
.44469 .48758 m .4447 .48573 L p .44464 .48684 L 0 0 .108 r
F P
0 g
s
.44476 .4677 m .44469 .48758 L .44449 .48057 L p .764 .615 .049 r
F P
0 g
s
.44607 .46213 m .44476 .4677 L p .44453 .47866 L .764 .615 .049 r
F P
0 g
s
.44449 .48057 m .44488 .47609 L p .44453 .47866 L .764 .615 .049 r
F P
0 g
s
.44488 .47609 m .44607 .46213 L p .44453 .47866 L .764 .615 .049 r
F P
0 g
s
.44604 .46233 m .44487 .47607 L .44445 .47285 L .851 .711 .183 r
F
.44449 .48057 m .44445 .47285 L p .44487 .47607 L F P
0 g
s
.44601 .46279 m .44449 .48057 L p .44604 .46233 L .851 .711 .183 r
F P
0 g
s
.44607 .46213 m .44601 .46279 L p .44604 .46233 L .851 .711 .183 r
F P
0 g
s
.44445 .47285 m .44762 .45619 L .44607 .46213 L p .851 .711 .183 r
F P
0 g
s
.44734 .45754 m .44445 .47285 L .44742 .45679 L .893 .783 .293 r
F
.44732 .45775 m .4473 .45785 L p .44734 .45754 L F P
0 g
s
.4473 .45785 m .44445 .47285 L p .44734 .45754 L .893 .783 .293 r
F P
0 g
s
.44445 .47285 m .44485 .46471 L p .44742 .45679 L .893 .783 .293 r
F P
0 g
s
.44762 .45619 m .44732 .45775 L p .44742 .45679 L .893 .783 .293 r
F P
0 g
s
.44356 .47279 m .44476 .49369 L .44469 .48758 L p 0 0 .108 r
F P
0 g
s
.66231 .66254 m .64088 .66515 L .63747 .65596 L p .839 .771 .786 r
F P
0 g
s
.63747 .65596 m .65786 .65252 L .66231 .66254 L p .839 .771 .786 r
F P
0 g
s
.65444 .4923 m .68673 .49294 L .69373 .48119 L p .638 .591 .785 r
F P
0 g
s
.69373 .48119 m .6588 .48272 L .65444 .4923 L p .638 .591 .785 r
F P
0 g
s
.64926 .68849 m .62735 .6859 L .62484 .67536 L p .835 .753 .773 r
F P
0 g
s
.62484 .67536 m .6451 .67611 L .64926 .68849 L p .835 .753 .773 r
F P
0 g
s
.63735 .47288 m .66134 .47359 L .66176 .46533 L p .589 .616 .847 r
F P
0 g
s
.66176 .46533 m .63688 .46638 L .63735 .47288 L p .589 .616 .847 r
F P
0 g
s
.51337 .70983 m .51323 .69391 L .51875 .69883 L p .811 .507 .476 r
F P
0 g
s
.51875 .69883 m .51896 .71315 L .51337 .70983 L p .811 .507 .476 r
F P
0 g
s
.41944 .52488 m .43413 .51943 L .42954 .52058 L p .01 0 0 r
F P
0 g
s
.42954 .52058 m .41287 .52623 L .41944 .52488 L p .01 0 0 r
F P
0 g
s
.42324 .71411 m .43836 .71023 L p .43214 .71152 L .211 .733 .737 r
F P
0 g
s
.41083 .71712 m .42848 .71249 L p .42359 .71221 L .368 .828 .917 r
F P
0 g
s
.42848 .71249 m .43214 .71152 L .42359 .71221 L p .368 .828 .917 r
F P
0 g
s
.42359 .71221 m .39928 .71829 L .41083 .71712 L p .368 .828 .917 r
F P
0 g
s
.39928 .71829 m .42359 .71221 L .41608 .71132 L p .483 .839 .994 r
F P
0 g
s
.43152 .71488 m .41873 .71193 L p .42359 .71221 L .246 0 0 r
F P
0 g
s
.41873 .71193 m .41608 .71132 L .42359 .71221 L p .246 0 0 r
F P
0 g
s
.43729 .71618 m .4258 .71285 L p .43214 .71152 L .466 0 0 r
F P
0 g
s
.4258 .71285 m .42359 .71221 L .43214 .71152 L p .466 0 0 r
F P
0 g
s
.43836 .71023 m .44133 .70946 L .43214 .71152 L p .211 .733 .737 r
F P
0 g
s
.37546 .70911 m .33633 .71407 L .34359 .72057 L p .567 .734 .954 r
F P
0 g
s
.34359 .72057 m .3811 .7143 L .37546 .70911 L p .567 .734 .954 r
F P
0 g
s
.67206 .63558 m .65542 .64452 L .65581 .63846 L p .882 .917 .844 r
F P
0 g
s
.65581 .63846 m .67252 .62907 L .67206 .63558 L p .882 .917 .844 r
F P
0 g
s
.69952 .55496 m .71802 .57247 L .73629 .56362 L p .589 .454 .664 r
F P
0 g
s
.73629 .56362 m .71574 .54529 L .69952 .55496 L p .589 .454 .664 r
F P
0 g
s
.59187 .4151 m .5932 .4412 L .5869 .44178 L p .829 .552 .52 r
F P
0 g
s
.5869 .44178 m .58648 .41408 L .59187 .4151 L p .829 .552 .52 r
F P
0 g
s
.43928 .5143 m .44352 .50284 L .44191 .50591 L p 0 0 0 r
F P
0 g
s
.44191 .50591 m .43742 .51743 L .43928 .5143 L p 0 0 0 r
F P
0 g
s
.50796 .7073 m .50799 .69032 L .51323 .69391 L p .794 .515 .515 r
F P
0 g
s
.51323 .69391 m .51337 .70983 L .50796 .7073 L p .794 .515 .515 r
F P
0 g
s
.67784 .50454 m .71429 .50945 L .72652 .49622 L p .63 .561 .758 r
F P
0 g
s
.72652 .49622 m .68673 .49294 L .67784 .50454 L p .63 .561 .758 r
F P
0 g
s
.68492 .60914 m .67682 .62393 L .68519 .61969 L p .23 0 .237 r
F P
0 g
s
.68519 .61969 m .69376 .60397 L .68492 .60914 L p .23 0 .237 r
F P
0 g
s
.50258 .7057 m .50274 .68824 L .50799 .69032 L p .775 .513 .539 r
F P
0 g
s
.50799 .69032 m .50796 .7073 L .50258 .7057 L p .775 .513 .539 r
F P
0 g
s
.33348 .56132 m .35221 .54479 L .33744 .54885 L p .282 0 .145 r
F P
0 g
s
.33744 .54885 m .31697 .56752 L .33348 .56132 L p .282 0 .145 r
F P
0 g
s
.31126 .58943 m .31697 .56752 L .30001 .57491 L p .405 .172 .444 r
F P
0 g
s
.30001 .57491 m .29371 .59891 L .31126 .58943 L p .405 .172 .444 r
F P
0 g
s
.62975 .70857 m .61214 .70513 L .61287 .69616 L p .861 .792 .782 r
F P
0 g
s
.61287 .69616 m .62917 .69715 L .62975 .70857 L p .861 .792 .782 r
F P
0 g
s
.6588 .48272 m .69373 .48119 L .69818 .46983 L p .633 .612 .812 r
F P
0 g
s
.69818 .46983 m .66134 .47359 L .6588 .48272 L p .633 .612 .812 r
F P
0 g
s
.70066 .52178 m .73292 .534 L .74979 .52121 L p .606 .512 .721 r
F P
0 g
s
.74979 .52121 m .71429 .50945 L .70066 .52178 L p .606 .512 .721 r
F P
0 g
s
.4971 .70505 m .49724 .68775 L .50274 .68824 L p .756 .502 .549 r
F P
0 g
s
.50274 .68824 m .50258 .7057 L .4971 .70505 L p .756 .502 .549 r
F P
0 g
s
.63688 .46638 m .66176 .46533 L .65989 .45835 L p .58 .655 .888 r
F P
0 g
s
.65989 .45835 m .63491 .46085 L .63688 .46638 L p .58 .655 .888 r
F P
0 g
s
.58648 .41408 m .5869 .44178 L .58058 .4426 L p .815 .55 .538 r
F P
0 g
s
.58058 .4426 m .58093 .41328 L .58648 .41408 L p .815 .55 .538 r
F P
0 g
s
.36533 .54128 m .38938 .5318 L .37855 .53371 L p .062 0 0 r
F P
0 g
s
.37855 .53371 m .35221 .54479 L .36533 .54128 L p .062 0 0 r
F P
0 g
s
.70214 .57989 m .7067 .59864 L .72311 .59263 L p .535 .349 .576 r
F P
0 g
s
.72311 .59263 m .71802 .57247 L .70214 .57989 L p .535 .349 .576 r
F P
0 g
s
.43974 .5098 m .44443 .49878 L .44352 .50284 L p .927 .879 .457 r
F P
0 g
s
.44352 .50284 m .43928 .5143 L .43974 .5098 L p .927 .879 .457 r
F P
0 g
s
.49138 .70533 m .49124 .68876 L .49724 .68775 L p .738 .485 .548 r
F P
0 g
s
.49724 .68775 m .4971 .70505 L .49138 .70533 L p .738 .485 .548 r
F P
0 g
s
.42395 .52263 m .43742 .51743 L .43413 .51943 L p .415 .861 .794 r
F P
0 g
s
.43413 .51943 m .41944 .52488 L .42395 .52263 L p .415 .861 .794 r
F P
0 g
s
.41287 .52623 m .40528 .52803 L p .39799 .52962 L .198 .722 .719 r
F P
0 g
s
.40528 .52803 m .38938 .5318 L .39799 .52962 L p .198 .722 .719 r
F P
0 g
s
.37573 .5378 m .39799 .52962 L .38938 .5318 L p 0 0 0 r
F P
0 g
s
.38938 .5318 m .36533 .54128 L .3723 .53895 L p 0 0 0 r
F P
0 g
s
.36746 .54606 m .3781 .53748 L p .37573 .5378 L 0 0 0 r
F P
0 g
s
.37841 .53662 m .37509 .53788 L .37573 .5378 L 0 0 0 r
F
.38938 .5318 m .3723 .53895 L .37841 .53662 L F
.39799 .52962 m .37573 .5378 L .3827 .53377 L p .532 .923 .871 r
F P
0 g
s
.3781 .53748 m .3827 .53377 L .37573 .5378 L p 0 0 0 r
F P
0 g
s
.3723 .53895 m .37573 .5378 L p .37509 .53788 L 0 0 0 r
F P
0 g
s
.3827 .53377 m .38957 .53145 L p .39527 .53021 L .532 .923 .871 r
F P
0 g
s
.39799 .52962 m .3939 .53073 L .39527 .53021 L .532 .923 .871 r
F
.3939 .53073 m .3827 .53377 L .39527 .53021 L F
.38957 .53145 m .40381 .52662 L .39799 .52962 L p F P
0 g
s
.39799 .52962 m .41944 .52488 L .41287 .52623 L p .198 .722 .719 r
F P
0 g
s
.48534 .70641 m .48457 .69109 L .49124 .68876 L p .72 .462 .535 r
F P
0 g
s
.49124 .68876 m .49138 .70533 L .48534 .70641 L p .72 .462 .535 r
F P
0 g
s
.30543 .62121 m .29371 .59891 L .27722 .60973 L p .48 .341 .614 r
F P
0 g
s
.27722 .60973 m .2896 .63335 L .30543 .62121 L p .48 .341 .614 r
F P
0 g
s
.65786 .65252 m .63747 .65596 L .63565 .6487 L p .831 .795 .817 r
F P
0 g
s
.63565 .6487 m .65542 .64452 L .65786 .65252 L p .831 .795 .817 r
F P
0 g
s
.6451 .67611 m .62484 .67536 L .62225 .66598 L p .834 .748 .769 r
F P
0 g
s
.62225 .66598 m .64088 .66515 L .6451 .67611 L p .834 .748 .769 r
F P
0 g
s
.58093 .41328 m .58058 .4426 L .57435 .44344 L p .802 .547 .553 r
F P
0 g
s
.57435 .44344 m .57527 .41258 L .58093 .41328 L p .802 .547 .553 r
F P
0 g
s
.47893 .7081 m .47712 .69442 L .48457 .69109 L p .703 .432 .511 r
F P
0 g
s
.48457 .69109 m .48534 .70641 L .47893 .7081 L p .703 .432 .511 r
F P
0 g
s
.68673 .49294 m .72652 .49622 L .73631 .48258 L p .619 .572 .78 r
F P
0 g
s
.73631 .48258 m .69373 .48119 L .68673 .49294 L p .619 .572 .78 r
F P
0 g
s
.71574 .54529 m .73629 .56362 L .75571 .55316 L p .574 .444 .666 r
F P
0 g
s
.75571 .55316 m .73292 .534 L .71574 .54529 L p .574 .444 .666 r
F P
0 g
s
.33675 .68344 m .29706 .67669 L .29233 .68959 L p .559 .562 .813 r
F P
0 g
s
.29233 .68959 m .33291 .69502 L .33675 .68344 L p .559 .562 .813 r
F P
0 g
s
.67252 .62907 m .65581 .63846 L .65956 .63405 L p .749 .994 .858 r
F P
0 g
s
.47216 .71016 m .46891 .69836 L .47712 .69442 L p .686 .394 .473 r
F P
0 g
s
.47712 .69442 m .47893 .7081 L .47216 .71016 L p .686 .394 .473 r
F P
0 g
s
.43899 .50381 m .44476 .49369 L .44443 .49878 L p .995 .854 .582 r
F P
0 g
s
.44443 .49878 m .43974 .5098 L .43899 .50381 L p .995 .854 .582 r
F P
0 g
s
.41608 .71132 m .38919 .71737 L .39928 .71829 L p .483 .839 .994 r
F P
0 g
s
.63491 .46085 m .65989 .45835 L .65572 .45299 L p .564 .702 .934 r
F P
0 g
s
.65572 .45299 m .63146 .4565 L .63491 .46085 L p .564 .702 .934 r
F P
0 g
s
.37253 .70204 m .33272 .70541 L .33633 .71407 L p .587 .68 .905 r
F P
0 g
s
.33633 .71407 m .37546 .70911 L .37253 .70204 L p .587 .68 .905 r
F P
0 g
s
.66134 .47359 m .69818 .46983 L .69959 .45943 L p .628 .641 .844 r
F P
0 g
s
.69959 .45943 m .66176 .46533 L .66134 .47359 L p .628 .641 .844 r
F P
0 g
s
.69376 .60397 m .68519 .61969 L .69746 .61577 L p .396 .106 .351 r
F P
0 g
s
.69746 .61577 m .7067 .59864 L .69376 .60397 L p .396 .106 .351 r
F P
0 g
s
.62917 .69715 m .61287 .69616 L .61272 .68725 L p .873 .779 .755 r
F P
0 g
s
.61272 .68725 m .62735 .6859 L .62917 .69715 L p .873 .779 .755 r
F P
0 g
s
.57527 .41258 m .57435 .44344 L .56828 .44409 L p .792 .544 .563 r
F P
0 g
s
.56828 .44409 m .56954 .4119 L .57527 .41258 L p .792 .544 .563 r
F P
0 g
s
.4651 .7123 m .46005 .70248 L .46891 .69836 L p .668 .346 .419 r
F P
0 g
s
.46891 .69836 m .47216 .71016 L .4651 .7123 L p .668 .346 .419 r
F P
0 g
s
.42621 .51905 m .43928 .5143 L .43742 .51743 L p .782 .955 .927 r
F P
0 g
s
.43742 .51743 m .42395 .52263 L .42621 .51905 L p .782 .955 .927 r
F P
0 g
s
.71429 .50945 m .74979 .52121 L .76505 .50721 L p .59 .513 .737 r
F P
0 g
s
.76505 .50721 m .72652 .49622 L .71429 .50945 L p .59 .513 .737 r
F P
0 g
s
.53107 .7464 m .53105 .7213 L .53767 .72557 L p .732 .466 .526 r
F P
0 g
s
.53767 .72557 m .53754 .74868 L .53107 .7464 L p .732 .466 .526 r
F P
0 g
s
.53754 .74868 m .53767 .72557 L .54465 .72955 L p .716 .437 .503 r
F P
0 g
s
.54465 .72955 m .54415 .75071 L .53754 .74868 L p .716 .437 .503 r
F P
0 g
s
.54415 .75071 m .54465 .72955 L .5519 .73294 L p .693 .402 .478 r
F P
0 g
s
.52479 .74405 m .52482 .71706 L .53105 .7213 L p .742 .488 .546 r
F P
0 g
s
.53105 .7213 m .53107 .7464 L .52479 .74405 L p .742 .488 .546 r
F P
0 g
s
.51868 .74179 m .51896 .71315 L .52482 .71706 L p .75 .506 .562 r
F P
0 g
s
.52482 .71706 m .52479 .74405 L .51868 .74179 L p .75 .506 .562 r
F P
0 g
s
.5519 .73294 m .55086 .75232 L .54415 .75071 L p .693 .402 .478 r
F P
0 g
s
.55086 .75232 m .5519 .73294 L .5593 .73546 L p .663 .361 .451 r
F P
0 g
s
.71802 .57247 m .72311 .59263 L .74203 .58547 L p .529 .343 .573 r
F P
0 g
s
.74203 .58547 m .73629 .56362 L .71802 .57247 L p .529 .343 .573 r
F P
0 g
s
.31772 .65021 m .2896 .63335 L .27617 .64644 L p .537 .459 .715 r
F P
0 g
s
.27617 .64644 m .30581 .66336 L .31772 .65021 L p .537 .459 .715 r
F P
0 g
s
.45789 .71424 m .45075 .70632 L .46005 .70248 L p .648 .285 .342 r
F P
0 g
s
.46005 .70248 m .4651 .7123 L .45789 .71424 L p .648 .285 .342 r
F P
0 g
s
.40381 .52662 m .42395 .52263 L .41944 .52488 L p .543 .914 .95 r
F P
0 g
s
.41944 .52488 m .39799 .52962 L .40381 .52662 L p .543 .914 .95 r
F P
0 g
s
.48073 .42015 m .48337 .39955 L .48953 .39851 L p .557 .272 .438 r
F P
0 g
s
.44956 .45008 m .44485 .46471 L .44598 .45648 L p .904 .842 .385 r
F P
0 g
s
.56954 .4119 m .56828 .44409 L .56239 .44436 L p .783 .541 .57 r
F P
0 g
s
.56239 .44436 m .56378 .41114 L .56954 .4119 L p .783 .541 .57 r
F P
0 g
s
.51272 .73977 m .51337 .70983 L .51896 .71315 L p .754 .519 .575 r
F P
0 g
s
.51896 .71315 m .51868 .74179 L .51272 .73977 L p .754 .519 .575 r
F P
0 g
s
.43736 .49632 m .44469 .48758 L .44476 .49369 L p .972 .812 .625 r
F P
0 g
s
.44476 .49369 m .43899 .50381 L .43736 .49632 L p .972 .812 .625 r
F P
0 g
s
.5593 .73546 m .5576 .75335 L .55086 .75232 L p .663 .361 .451 r
F P
0 g
s
.5576 .75335 m .5593 .73546 L .56668 .73688 L p .622 .312 .424 r
F P
0 g
s
.60596 .45249 m .59936 .44107 L .6052 .44158 L p .753 .332 .251 r
F P
0 g
s
.50687 .73809 m .50796 .7073 L .51337 .70983 L p .758 .528 .585 r
F P
0 g
s
.51337 .70983 m .51272 .73977 L .50687 .73809 L p .758 .528 .585 r
F P
0 g
s
.34812 .556 m .36533 .54128 L .35221 .54479 L p .277 0 .12 r
F P
0 g
s
.35221 .54479 m .33348 .56132 L .34812 .556 L p .277 0 .12 r
F P
0 g
s
.64088 .66515 m .62225 .66598 L .6202 .65807 L p .832 .754 .778 r
F P
0 g
s
.6202 .65807 m .63747 .65596 L .64088 .66515 L p .832 .754 .778 r
F P
0 g
s
.65542 .64452 m .63565 .6487 L .63608 .64336 L p .814 .852 .877 r
F P
0 g
s
.63608 .64336 m .65581 .63846 L .65542 .64452 L p .814 .852 .877 r
F P
0 g
s
.56668 .73688 m .56427 .75368 L .5576 .75335 L p .622 .312 .424 r
F P
0 g
s
.56427 .75368 m .56668 .73688 L .57385 .73703 L p .572 .258 .398 r
F P
0 g
s
.48744 .41967 m .48953 .39851 L .49587 .39812 L p .6 .315 .455 r
F P
0 g
s
.69373 .48119 m .73631 .48258 L .74278 .46915 L p .608 .59 .808 r
F P
0 g
s
.74278 .46915 m .69818 .46983 L .69373 .48119 L p .608 .59 .808 r
F P
0 g
s
.50107 .73683 m .50258 .7057 L .50796 .7073 L p .76 .534 .591 r
F P
0 g
s
.50796 .7073 m .50687 .73809 L .50107 .73683 L p .76 .534 .591 r
F P
0 g
s
.56378 .41114 m .56239 .44436 L .55666 .44408 L p .775 .536 .574 r
F P
0 g
s
.55666 .44408 m .55798 .41023 L .56378 .41114 L p .775 .536 .574 r
F P
0 g
s
.63146 .4565 m .65572 .45299 L .6494 .44948 L p .532 .756 .979 r
F P
0 g
s
.6494 .44948 m .62662 .45348 L .63146 .4565 L p .532 .756 .979 r
F P
0 g
s
.42626 .51381 m .43974 .5098 L .43928 .5143 L p .848 .847 .842 r
F P
0 g
s
.43928 .5143 m .42621 .51905 L .42626 .51381 L p .848 .847 .842 r
F P
0 g
s
.4507 .71569 m .44133 .70946 L .45075 .70632 L p .62 .202 .228 r
F P
0 g
s
.45075 .70632 m .45789 .71424 L .4507 .71569 L p .62 .202 .228 r
F P
0 g
s
.40996 .70878 m .3811 .7143 L .38919 .71737 L p .548 .796 .99 r
F P
0 g
s
.38919 .71737 m .41608 .71132 L .40996 .70878 L p .548 .796 .99 r
F P
0 g
s
.66631 .6301 m .65956 .63405 L .66685 .63087 L p 0 0 0 r
F P
0 g
s
.63915 .63971 m .65956 .63405 L .65581 .63846 L p .737 .937 .952 r
F P
0 g
s
.65956 .63405 m .63915 .63971 L .6421 .63856 L p .426 .87 .847 r
F P
0 g
s
.6421 .63856 m .64501 .63743 L p .64863 .63659 L .426 .87 .847 r
F P
0 g
s
.64863 .63659 m .65956 .63405 L .6421 .63856 L .426 .87 .847 r
F
.64501 .63743 m .66685 .63087 L .65956 .63405 L p F P
0 g
s
.65353 .63606 m .66738 .63163 L p .66697 .63104 L 0 0 0 r
F P
0 g
s
.66446 .6318 m .66697 .63104 L .66685 .63087 L 0 0 0 r
F
.65353 .63606 m .66697 .63104 L .66446 .6318 L F
.66738 .63163 m .67752 .62839 L .66685 .63087 L p F P
0 g
s
.67682 .62393 m .66631 .6301 L p .66685 .63087 L 0 0 0 r
F P
0 g
s
.49528 .73602 m .4971 .70505 L .50258 .7057 L p .763 .538 .593 r
F P
0 g
s
.50258 .7057 m .50107 .73683 L .49528 .73602 L p .763 .538 .593 r
F P
0 g
s
.73292 .534 m .75571 .55316 L .77486 .54107 L p .553 .435 .673 r
F P
0 g
s
.77486 .54107 m .74979 .52121 L .73292 .534 L p .553 .435 .673 r
F P
0 g
s
.32832 .58132 m .33348 .56132 L .31697 .56752 L p .443 .204 .455 r
F P
0 g
s
.31697 .56752 m .31126 .58943 L .32832 .58132 L p .443 .204 .455 r
F P
0 g
s
.45202 .44399 m .44598 .45648 L .44805 .44853 L p .885 .889 .463 r
F P
0 g
s
.66176 .46533 m .69959 .45943 L .69771 .45052 L p .624 .678 .881 r
F P
0 g
s
.69771 .45052 m .65989 .45835 L .66176 .46533 L p .624 .678 .881 r
F P
0 g
s
.62735 .6859 m .61272 .68725 L .61205 .67883 L p .883 .771 .733 r
F P
0 g
s
.61205 .67883 m .62484 .67536 L .62735 .6859 L p .883 .771 .733 r
F P
0 g
s
.4353 .48747 m .44449 .48057 L .44469 .48758 L p .949 .794 .655 r
F P
0 g
s
.44469 .48758 m .43736 .49632 L .4353 .48747 L p .949 .794 .655 r
F P
0 g
s
.49437 .42028 m .49587 .39812 L .50233 .39832 L p .636 .354 .474 r
F P
0 g
s
.49587 .39812 m .49437 .42028 L .48744 .41967 L p .6 .315 .455 r
F P
0 g
s
.55798 .41023 m .55666 .44408 L .55104 .44318 L p .767 .53 .575 r
F P
0 g
s
.55104 .44318 m .55214 .40914 L .55798 .41023 L p .767 .53 .575 r
F P
0 g
s
.57385 .73703 m .57077 .75322 L .56427 .75368 L p .572 .258 .398 r
F P
0 g
s
.48944 .73564 m .49138 .70533 L .4971 .70505 L p .765 .54 .592 r
F P
0 g
s
.4971 .70505 m .49528 .73602 L .48944 .73564 L p .765 .54 .592 r
F P
0 g
s
.7067 .59864 m .69746 .61577 L .71304 .61161 L p .441 .159 .388 r
F P
0 g
s
.71304 .61161 m .72311 .59263 L .7067 .59864 L p .441 .159 .388 r
F P
0 g
s
.59936 .44107 m .60596 .45249 L .598 .4544 L p .753 .389 .365 r
F P
0 g
s
.598 .4544 m .5932 .4412 L .59936 .44107 L p .753 .389 .365 r
F P
0 g
s
.50139 .42183 m .50233 .39832 L .50882 .39904 L p .666 .389 .492 r
F P
0 g
s
.50233 .39832 m .50139 .42183 L .49437 .42028 L p .636 .354 .474 r
F P
0 g
s
.55214 .40914 m .55104 .44318 L .54545 .44161 L p .76 .522 .573 r
F P
0 g
s
.54545 .44161 m .54624 .40786 L .55214 .40914 L p .76 .522 .573 r
F P
0 g
s
.40655 .52229 m .42621 .51905 L .42395 .52263 L p .745 .894 .946 r
F P
0 g
s
.42395 .52263 m .40381 .52662 L .40655 .52229 L p .745 .894 .946 r
F P
0 g
s
.44376 .7164 m .43214 .71152 L .44133 .70946 L p .571 .08 .051 r
F P
0 g
s
.44133 .70946 m .4507 .71569 L .44376 .7164 L p .571 .08 .051 r
F P
0 g
s
.48351 .73563 m .48534 .70641 L .49138 .70533 L p .769 .54 .588 r
F P
0 g
s
.49138 .70533 m .48944 .73564 L .48351 .73563 L p .769 .54 .588 r
F P
0 g
s
.50835 .42417 m .50882 .39904 L .51529 .40016 L p .689 .42 .51 r
F P
0 g
s
.50882 .39904 m .50835 .42417 L .50139 .42183 L p .666 .389 .492 r
F P
0 g
s
.54624 .40786 m .54545 .44161 L .5398 .4394 L p .752 .512 .569 r
F P
0 g
s
.5398 .4394 m .54026 .40639 L .54624 .40786 L p .752 .512 .569 r
F P
0 g
s
.42439 .50671 m .43899 .50381 L .43974 .5098 L p .849 .778 .782 r
F P
0 g
s
.43974 .5098 m .42626 .51381 L .42439 .50671 L p .849 .778 .782 r
F P
0 g
s
.5806 .73585 m .57699 .75192 L .58283 .74978 L p .423 .126 .354 r
F P
0 g
s
.5806 .73585 m .57699 .75192 L .57077 .75322 L p .511 .2 .376 r
F P
0 g
s
.37242 .69342 m .33291 .69502 L .33272 .70541 L p .602 .638 .859 r
F P
0 g
s
.33272 .70541 m .37253 .70204 L .37242 .69342 L p .602 .638 .859 r
F P
0 g
s
.45511 .43816 m .44805 .44853 L .45121 .44125 L p .826 .919 .526 r
F P
0 g
s
.51514 .42706 m .51529 .40016 L .5217 .40158 L p .708 .446 .526 r
F P
0 g
s
.51529 .40016 m .51514 .42706 L .50835 .42417 L p .689 .42 .51 r
F P
0 g
s
.54026 .40639 m .5398 .4394 L .534 .43667 L p .744 .5 .562 r
F P
0 g
s
.534 .43667 m .53419 .4048 L .54026 .40639 L p .744 .5 .562 r
F P
0 g
s
.32223 .61038 m .31126 .58943 L .29371 .59891 L p .518 .364 .612 r
F P
0 g
s
.29371 .59891 m .30543 .62121 L .32223 .61038 L p .518 .364 .612 r
F P
0 g
s
.72652 .49622 m .76505 .50721 L .77741 .49251 L p .57 .519 .759 r
F P
0 g
s
.77741 .49251 m .73631 .48258 L .72652 .49622 L p .57 .519 .759 r
F P
0 g
s
.62662 .45348 m .6494 .44948 L .64124 .44795 L p .462 .8 .999 r
F P
0 g
s
.43329 .47751 m .44445 .47285 L .44449 .48057 L p .93 .792 .686 r
F P
0 g
s
.44449 .48057 m .4353 .48747 L .43329 .47751 L p .93 .792 .686 r
F P
0 g
s
.4775 .73588 m .47893 .7081 L .48534 .70641 L p .773 .538 .58 r
F P
0 g
s
.48534 .70641 m .48351 .73563 L .4775 .73588 L p .773 .538 .58 r
F P
0 g
s
.52169 .43028 m .5217 .40158 L .528 .40316 L p .722 .468 .541 r
F P
0 g
s
.5217 .40158 m .52169 .43028 L .51514 .42706 L p .708 .446 .526 r
F P
0 g
s
.53419 .4048 m .534 .43667 L .52798 .43356 L p .734 .486 .553 r
F P
0 g
s
.52798 .43356 m .528 .40316 L .53419 .4048 L p .734 .486 .553 r
F P
0 g
s
.528 .40316 m .52798 .43356 L .52169 .43028 L p .722 .468 .541 r
F P
0 g
s
.3438 .67127 m .30581 .66336 L .29706 .67669 L p .582 .545 .779 r
F P
0 g
s
.29706 .67669 m .33675 .68344 L .3438 .67127 L p .582 .545 .779 r
F P
0 g
s
.63747 .65596 m .6202 .65807 L .61927 .65181 L p .828 .781 .808 r
F P
0 g
s
.61927 .65181 m .63565 .6487 L .63747 .65596 L p .828 .781 .808 r
F P
0 g
s
.73629 .56362 m .74203 .58547 L .76217 .57686 L p .508 .328 .572 r
F P
0 g
s
.76217 .57686 m .75571 .55316 L .73629 .56362 L p .508 .328 .572 r
F P
0 g
s
.65581 .63846 m .63608 .64336 L .63915 .63971 L p .737 .937 .952 r
F P
0 g
s
.5932 .4412 m .598 .4544 L .58999 .45697 L p .751 .429 .439 r
F P
0 g
s
.58999 .45697 m .5869 .44178 L .5932 .4412 L p .751 .429 .439 r
F P
0 g
s
.62484 .67536 m .61205 .67883 L .61125 .67123 L p .894 .772 .719 r
F P
0 g
s
.61125 .67123 m .62225 .66598 L .62484 .67536 L p .894 .772 .719 r
F P
0 g
s
.58676 .73331 m .58283 .74978 L .58822 .74685 L p .299 .03 .327 r
F P
0 g
s
.40552 .70462 m .37546 .70911 L .3811 .7143 L p .581 .738 .951 r
F P
0 g
s
.3811 .7143 m .40996 .70878 L .40552 .70462 L p .581 .738 .951 r
F P
0 g
s
.47142 .73626 m .47216 .71016 L .47893 .7081 L p .779 .535 .568 r
F P
0 g
s
.47893 .7081 m .4775 .73588 L .47142 .73626 L p .779 .535 .568 r
F P
0 g
s
.69818 .46983 m .74278 .46915 L .74524 .4566 L p .597 .617 .843 r
F P
0 g
s
.74524 .4566 m .69959 .45943 L .69818 .46983 L p .597 .617 .843 r
F P
0 g
s
.43214 .71152 m .44376 .7164 L .43729 .71618 L p .466 0 0 r
F P
0 g
s
.65989 .45835 m .69771 .45052 L .69249 .4436 L p .618 .725 .923 r
F P
0 g
s
.69249 .4436 m .65572 .45299 L .65989 .45835 L p .618 .725 .923 r
F P
0 g
s
.4589 .43282 m .45121 .44125 L .45552 .435 L p .705 .912 .563 r
F P
0 g
s
.68519 .61969 m .66685 .63087 L .67752 .62839 L p .175 0 0 r
F P
0 g
s
.67752 .62839 m .69746 .61577 L .68519 .61969 L p .175 0 0 r
F P
0 g
s
.35972 .5511 m .37573 .5378 L .36533 .54128 L p .163 0 0 r
F P
0 g
s
.36533 .54128 m .34812 .556 L .35972 .5511 L p .163 0 0 r
F P
0 g
s
.42109 .49768 m .43736 .49632 L .43899 .50381 L p .845 .748 .756 r
F P
0 g
s
.43899 .50381 m .42439 .50671 L .42109 .49768 L p .845 .748 .756 r
F P
0 g
s
.40628 .51619 m .42626 .51381 L .42621 .51905 L p .799 .814 .864 r
F P
0 g
s
.42621 .51905 m .40655 .52229 L .40628 .51619 L p .799 .814 .864 r
F P
0 g
s
.43183 .46682 m .44485 .46471 L .44445 .47285 L p .914 .798 .719 r
F P
0 g
s
.44445 .47285 m .43329 .47751 L .43183 .46682 L p .914 .798 .719 r
F P
0 g
s
.46531 .73663 m .4651 .7123 L .47216 .71016 L p .786 .531 .552 r
F P
0 g
s
.47216 .71016 m .47142 .73626 L .46531 .73663 L p .786 .531 .552 r
F P
0 g
s
.5869 .44178 m .58999 .45697 L .58221 .45986 L p .75 .459 .489 r
F P
0 g
s
.58221 .45986 m .58058 .4426 L .5869 .44178 L p .75 .459 .489 r
F P
0 g
s
.62058 .45184 m .64124 .44795 L .63166 .44836 L p .322 .789 .934 r
F P
0 g
s
.59218 .72952 m .58822 .74685 L .5931 .74321 L p .161 0 .303 r
F P
0 g
s
.3317 .63782 m .30543 .62121 L .2896 .63335 L p .565 .465 .7 r
F P
0 g
s
.2896 .63335 m .31772 .65021 L .3317 .63782 L p .565 .465 .7 r
F P
0 g
s
.74979 .52121 m .77486 .54107 L .79227 .52757 L p .525 .427 .686 r
F P
0 g
s
.79227 .52757 m .76505 .50721 L .74979 .52121 L p .525 .427 .686 r
F P
0 g
s
.72311 .59263 m .71304 .61161 L .731 .60667 L p .439 .164 .398 r
F P
0 g
s
.731 .60667 m .74203 .58547 L .72311 .59263 L p .439 .164 .398 r
F P
0 g
s
.34343 .5744 m .34812 .556 L .33348 .56132 L p .45 .208 .455 r
F P
0 g
s
.33348 .56132 m .32832 .58132 L .34343 .5744 L p .45 .208 .455 r
F P
0 g
s
.63565 .6487 m .61927 .65181 L .6199 .64721 L p .814 .842 .871 r
F P
0 g
s
.6199 .64721 m .63608 .64336 L .63565 .6487 L p .814 .842 .871 r
F P
0 g
s
.38589 .52861 m .40655 .52229 L .40381 .52662 L p .78 .938 .932 r
F P
0 g
s
.40381 .52662 m .3827 .53377 L .38589 .52861 L p .78 .938 .932 r
F P
0 g
s
.62225 .66598 m .61125 .67123 L .61072 .6647 L p .909 .789 .715 r
F P
0 g
s
.61072 .6647 m .6202 .65807 L .62225 .66598 L p .909 .789 .715 r
F P
0 g
s
.45924 .73681 m .45789 .71424 L .4651 .7123 L p .796 .527 .53 r
F P
0 g
s
.4651 .7123 m .46531 .73663 L .45924 .73681 L p .796 .527 .53 r
F P
0 g
s
.41701 .48684 m .4353 .48747 L .43736 .49632 L p .841 .739 .75 r
F P
0 g
s
.43736 .49632 m .42109 .49768 L .41701 .48684 L p .841 .739 .75 r
F P
0 g
s
.43337 .73038 m .42727 .71402 L p .43152 .71488 L .9 .505 .258 r
F P
0 g
s
.42359 .71221 m .43577 .71574 L p .43152 .71488 L .246 0 0 r
F P
0 g
s
.41608 .71132 m .42989 .71451 L p .42668 .71245 L .049 .542 .885 r
F P
0 g
s
.42989 .71451 m .43152 .71488 L .42668 .71245 L p .049 .542 .885 r
F P
0 g
s
.42668 .71245 m .40996 .70878 L .41608 .71132 L p .049 .542 .885 r
F P
0 g
s
.40996 .70878 m .42501 .71208 L p .42291 .70889 L .261 .586 .946 r
F P
0 g
s
.42501 .71208 m .42668 .71245 L .42291 .70889 L p .261 .586 .946 r
F P
0 g
s
.42291 .70889 m .40552 .70462 L .40996 .70878 L p .261 .586 .946 r
F P
0 g
s
.40552 .70462 m .42128 .70849 L p .42034 .7043 L .371 .566 .912 r
F P
0 g
s
.42128 .70849 m .42291 .70889 L .42034 .7043 L p .371 .566 .912 r
F P
0 g
s
.42713 .72317 m .42087 .70578 L p .42291 .70889 L .854 .452 0 r
F P
0 g
s
.42087 .70578 m .42034 .7043 L .42291 .70889 L p .854 .452 0 r
F P
0 g
s
.42034 .7043 m .42621 .72063 L p .42515 .71866 L .739 .392 0 r
F P
0 g
s
.42621 .72063 m .42713 .72317 L .42515 .71866 L p .739 .392 0 r
F P
0 g
s
.42596 .74773 m .42412 .71674 L p .42515 .71866 L .958 .676 .238 r
F P
0 g
s
.42515 .71866 m .41943 .70025 L p .42034 .7043 L .739 .392 0 r
F P
0 g
s
.41898 .69881 m .42435 .71609 L p .42394 .7137 L 0 0 .272 r
F P
0 g
s
.42435 .71609 m .42515 .71866 L .42394 .7137 L p 0 0 .272 r
F P
0 g
s
.42394 .7137 m .4188 .69263 L .41898 .69881 L p 0 0 .272 r
F P
0 g
s
.42987 .7271 m .4235 .71042 L p .42668 .71245 L .903 .489 .131 r
F P
0 g
s
.4235 .71042 m .42291 .70889 L .42668 .71245 L p .903 .489 .131 r
F P
0 g
s
.42291 .70889 m .42987 .7271 L .42713 .72317 L p .854 .452 0 r
F P
0 g
s
.4188 .69263 m .42328 .71101 L p .42343 .70841 L 0 0 .313 r
F P
0 g
s
.42328 .71101 m .42394 .7137 L .42343 .70841 L p 0 0 .313 r
F P
0 g
s
.42394 .7137 m .42396 .71482 L .42353 .71137 L .921 .67 .179 r
F
.42396 .71482 m .42386 .71855 L .42353 .71137 L F
.42407 .72676 m .42353 .71137 L p .42426 .72714 L F P
0 g
s
.42383 .73902 m .42347 .73456 L p .42349 .7256 L .795 .628 .069 r
F P
0 g
s
.42353 .71137 m .42343 .70841 L .42394 .7137 L p .921 .67 .179 r
F P
0 g
s
.42343 .70841 m .42465 .74344 L .42383 .73902 L p .865 .654 .121 r
F P
0 g
s
.42343 .70841 m .42367 .72679 L .42358 .70588 L .865 .654 .121 r
F
.42383 .73902 m .42371 .72387 L p .42367 .72679 L F P
0 g
s
.42371 .72387 m .42358 .70588 L p .42367 .72679 L .865 .654 .121 r
F P
0 g
s
.42355 .70295 m .42371 .72387 L p .42349 .7256 L .795 .628 .069 r
F P
0 g
s
.42371 .72387 m .42373 .72608 L p .42367 .72595 L .795 .628 .069 r
F P
0 g
s
.42371 .72387 m .42367 .72595 L .42349 .7256 L .795 .628 .069 r
F
.42373 .72608 m .42383 .73902 L p .42349 .7256 L F P
0 g
s
.42358 .70588 m .42355 .70295 L .42343 .70841 L p .865 .654 .121 r
F P
0 g
s
.4242 .69746 m .42355 .70295 L p .4235 .7239 L .795 .628 .069 r
F P
0 g
s
.42347 .73456 m .42376 .71991 L p .4235 .7239 L .795 .628 .069 r
F P
0 g
s
.42376 .71991 m .4242 .69746 L p .4235 .7239 L .795 .628 .069 r
F P
0 g
s
.42387 .71328 m .42356 .73 L .42352 .73012 L .717 .595 .022 r
F
.42382 .71671 m .42356 .73 L p .42387 .71328 L F P
0 g
s
.42396 .71482 m .42426 .72714 L .42386 .71855 L .921 .67 .179 r
F
.42412 .71674 m .42394 .7137 L .42515 .71866 L p .958 .676 .238 r
F P
0 g
s
.42394 .7137 m .42596 .74773 L .42465 .74344 L p .921 .67 .179 r
F P
0 g
s
.42352 .73012 m .42394 .72578 L p .42478 .70417 L 0 0 .02 r
F P
0 g
s
.42525 .6921 m .42451 .70831 L p .42478 .70417 L 0 0 .02 r
F P
0 g
s
.42451 .70831 m .42352 .73012 L p .42478 .70417 L 0 0 .02 r
F P
0 g
s
.4242 .69746 m .42382 .71671 L p .42387 .71328 L .717 .595 .022 r
F P
0 g
s
.42356 .73 m .42347 .73456 L .42349 .73241 L p .717 .595 .022 r
F P
0 g
s
.42349 .73241 m .42352 .73012 L p .42356 .73 L .717 .595 .022 r
F P
0 g
s
.42465 .74344 m .42407 .72676 L p .42426 .72714 L .921 .67 .179 r
F P
0 g
s
.41943 .70025 m .41898 .69881 L .42034 .7043 L p .739 .392 0 r
F P
0 g
s
.42727 .71402 m .42668 .71245 L .43152 .71488 L p .9 .505 .258 r
F P
0 g
s
.43577 .71574 m .43729 .71618 L .43152 .71488 L p .246 0 0 r
F P
0 g
s
.4314 .45586 m .44598 .45648 L .44485 .46471 L p .897 .809 .754 r
F P
0 g
s
.44485 .46471 m .43183 .46682 L .4314 .45586 L p .897 .809 .754 r
F P
0 g
s
.58058 .4426 m .58221 .45986 L .57483 .46267 L p .75 .481 .525 r
F P
0 g
s
.57483 .46267 m .57435 .44344 L .58058 .4426 L p .75 .481 .525 r
F P
0 g
s
.40336 .508 m .42439 .50671 L .42626 .51381 L p .813 .766 .809 r
F P
0 g
s
.42626 .51381 m .40628 .51619 L .40336 .508 L p .813 .766 .809 r
F P
0 g
s
.51845 .78114 m .51868 .74179 L .52479 .74405 L p .722 .478 .557 r
F P
0 g
s
.52479 .74405 m .52475 .78227 L .51845 .78114 L p .722 .478 .557 r
F P
0 g
s
.52475 .78227 m .52479 .74405 L .53107 .7464 L p .709 .463 .55 r
F P
0 g
s
.59676 .72463 m .5931 .74321 L .59743 .73898 L p .025 0 .285 r
F P
0 g
s
.53107 .7464 m .53113 .78332 L .52475 .78227 L p .709 .463 .55 r
F P
0 g
s
.53113 .78332 m .53107 .7464 L .53754 .74868 L p .695 .446 .543 r
F P
0 g
s
.51222 .78001 m .51272 .73977 L .51868 .74179 L p .733 .491 .562 r
F P
0 g
s
.51868 .74179 m .51845 .78114 L .51222 .78001 L p .733 .491 .562 r
F P
0 g
s
.53754 .74868 m .53756 .78423 L .53113 .78332 L p .695 .446 .543 r
F P
0 g
s
.53756 .78423 m .53754 .74868 L .54415 .75071 L p .678 .427 .535 r
F P
0 g
s
.375 .68368 m .33675 .68344 L .33291 .69502 L p .614 .608 .821 r
F P
0 g
s
.33291 .69502 m .37242 .69342 L .375 .68368 L p .614 .608 .821 r
F P
0 g
s
.65572 .45299 m .69249 .4436 L .68417 .43903 L p .608 .782 .964 r
F P
0 g
s
.68417 .43903 m .6494 .44948 L .65572 .45299 L p .608 .782 .964 r
F P
0 g
s
.50607 .77892 m .50687 .73809 L .51272 .73977 L p .744 .503 .566 r
F P
0 g
s
.51272 .73977 m .51222 .78001 L .50607 .77892 L p .744 .503 .566 r
F P
0 g
s
.40293 .69897 m .37253 .70204 L .37546 .70911 L p .598 .686 .904 r
F P
0 g
s
.37546 .70911 m .40552 .70462 L .40293 .69897 L p .598 .686 .904 r
F P
0 g
s
.54415 .75071 m .54402 .78491 L .53756 .78423 L p .678 .427 .535 r
F P
0 g
s
.54402 .78491 m .54415 .75071 L .55086 .75232 L p .659 .406 .527 r
F P
0 g
s
.73631 .48258 m .77741 .49251 L .78576 .47772 L p .548 .532 .79 r
F P
0 g
s
.78576 .47772 m .74278 .46915 L .73631 .48258 L p .548 .532 .79 r
F P
0 g
s
.57435 .44344 m .57483 .46267 L .56797 .46503 L p .752 .499 .549 r
F P
0 g
s
.56797 .46503 m .56828 .44409 L .57435 .44344 L p .752 .499 .549 r
F P
0 g
s
.49998 .77792 m .50107 .73683 L .50687 .73809 L p .754 .513 .568 r
F P
0 g
s
.50687 .73809 m .50607 .77892 L .49998 .77792 L p .754 .513 .568 r
F P
0 g
s
.45331 .73666 m .4507 .71569 L .45789 .71424 L p .81 .522 .502 r
F P
0 g
s
.45789 .71424 m .45924 .73681 L .45331 .73666 L p .81 .522 .502 r
F P
0 g
s
.69746 .61577 m .67752 .62839 L .69105 .62607 L p .293 0 .06 r
F P
0 g
s
.69105 .62607 m .71304 .61161 L .69746 .61577 L p .293 0 .06 r
F P
0 g
s
.55086 .75232 m .55048 .78529 L .54402 .78491 L p .659 .406 .527 r
F P
0 g
s
.55048 .78529 m .55086 .75232 L .5576 .75335 L p .636 .383 .518 r
F P
0 g
s
.36694 .55651 m .36962 .54566 L p .36746 .54606 L 0 0 .096 r
F P
0 g
s
.37573 .5378 m .3653 .54646 L p .36746 .54606 L 0 0 0 r
F P
0 g
s
.3827 .53377 m .37289 .54168 L p .37095 .54026 L .808 .998 .789 r
F P
0 g
s
.37289 .54168 m .36746 .54606 L .37095 .54026 L p .808 .998 .789 r
F P
0 g
s
.36962 .54566 m .37095 .54026 L .36746 .54606 L p 0 0 .096 r
F P
0 g
s
.3653 .54646 m .35972 .5511 L .36746 .54606 L p 0 0 0 r
F P
0 g
s
.36336 .56253 m .36746 .54606 L .35972 .5511 L p .266 .039 .371 r
F P
0 g
s
.36746 .54606 m .36477 .55685 L p .36694 .55651 L 0 0 .096 r
F P
0 g
s
.36477 .55685 m .36336 .56253 L .36694 .55651 L p 0 0 .096 r
F P
0 g
s
.37465 .56837 m .36913 .55617 L p .36694 .55651 L 0 0 .553 r
F P
0 g
s
.37095 .54026 m .36809 .55184 L p .36619 .54967 L .954 .836 .405 r
F P
0 g
s
.36809 .55184 m .36694 .55651 L .36619 .54967 L p .954 .836 .405 r
F P
0 g
s
.36913 .55617 m .36619 .54967 L .36694 .55651 L p 0 0 .553 r
F P
0 g
s
.37034 .5616 m .36415 .54733 L p .36619 .54967 L .786 .393 0 r
F P
0 g
s
.36415 .54733 m .36161 .5415 L .36619 .54967 L p .786 .393 0 r
F P
0 g
s
.36619 .54967 m .36888 .53875 L p .37095 .54026 L .954 .836 .405 r
F P
0 g
s
.36888 .53875 m .37026 .53314 L .37095 .54026 L p .954 .836 .405 r
F P
0 g
s
.69959 .45943 m .74524 .4566 L .74332 .44562 L p .584 .654 .885 r
F P
0 g
s
.74332 .44562 m .69771 .45052 L .69959 .45943 L p .584 .654 .885 r
F P
0 g
s
.33853 .601 m .32832 .58132 L .31126 .58943 L p .541 .381 .614 r
F P
0 g
s
.31126 .58943 m .32223 .61038 L .33853 .601 L p .541 .381 .614 r
F P
0 g
s
.49396 .77701 m .49528 .73602 L .50107 .73683 L p .764 .522 .568 r
F P
0 g
s
.50107 .73683 m .49998 .77792 L .49396 .77701 L p .764 .522 .568 r
F P
0 g
s
.75571 .55316 m .76217 .57686 L .7821 .56666 L p .474 .305 .572 r
F P
0 g
s
.7821 .56666 m .77486 .54107 L .75571 .55316 L p .474 .305 .572 r
F P
0 g
s
.43237 .4452 m .44805 .44853 L .44598 .45648 L p .876 .822 .791 r
F P
0 g
s
.44598 .45648 m .4314 .45586 L .43237 .4452 L p .876 .822 .791 r
F P
0 g
s
.41287 .47448 m .43329 .47751 L .4353 .48747 L p .838 .741 .757 r
F P
0 g
s
.4353 .48747 m .41701 .48684 L .41287 .47448 L p .838 .741 .757 r
F P
0 g
s
.35338 .6591 m .31772 .65021 L .30581 .66336 L p .601 .536 .754 r
F P
0 g
s
.30581 .66336 m .3438 .67127 L .35338 .6591 L p .601 .536 .754 r
F P
0 g
s
.6202 .65807 m .61072 .6647 L .61081 .65941 L p .932 .839 .729 r
F P
0 g
s
.61081 .65941 m .61927 .65181 L .6202 .65807 L p .932 .839 .729 r
F P
0 g
s
.63608 .64336 m .6199 .64721 L .62237 .64414 L p .73 .934 .955 r
F P
0 g
s
.62237 .64414 m .63915 .63971 L .63608 .64336 L p .73 .934 .955 r
F P
0 g
s
.5576 .75335 m .5569 .78529 L .55048 .78529 L p .636 .383 .518 r
F P
0 g
s
.5569 .78529 m .5576 .75335 L .56427 .75368 L p .611 .359 .51 r
F P
0 g
s
.60047 .71886 m .59743 .73898 L .60122 .73433 L p 0 0 .278 r
F P
0 g
s
.56828 .44409 m .56797 .46503 L .56164 .46661 L p .755 .512 .565 r
F P
0 g
s
.56164 .46661 m .56239 .44436 L .56828 .44409 L p .755 .512 .565 r
F P
0 g
s
.48799 .77619 m .48944 .73564 L .49528 .73602 L p .774 .531 .568 r
F P
0 g
s
.49528 .73602 m .49396 .77701 L .48799 .77619 L p .774 .531 .568 r
F P
0 g
s
.38537 .52179 m .40628 .51619 L .40655 .52229 L p .833 .848 .858 r
F P
0 g
s
.40655 .52229 m .38589 .52861 L .38537 .52179 L p .833 .848 .858 r
F P
0 g
s
.39844 .4976 m .42109 .49768 L .42439 .50671 L p .82 .746 .782 r
F P
0 g
s
.42439 .50671 m .40336 .508 L .39844 .4976 L p .82 .746 .782 r
F P
0 g
s
.56427 .75368 m .56322 .78487 L .5569 .78529 L p .611 .359 .51 r
F P
0 g
s
.56322 .78487 m .56427 .75368 L .57077 .75322 L p .583 .333 .503 r
F P
0 g
s
.60891 .68656 m .61125 .67123 L .61205 .67883 L p .976 .795 .376 r
F P
0 g
s
.44764 .73604 m .44376 .7164 L .4507 .71569 L p .827 .517 .465 r
F P
0 g
s
.4507 .71569 m .45331 .73666 L .44764 .73604 L p .827 .517 .465 r
F P
0 g
s
.56239 .44436 m .56164 .46661 L .5558 .46713 L p .759 .522 .573 r
F P
0 g
s
.5558 .46713 m .55666 .44408 L .56239 .44436 L p .759 .522 .573 r
F P
0 g
s
.48209 .77543 m .48351 .73563 L .48944 .73564 L p .784 .538 .565 r
F P
0 g
s
.48944 .73564 m .48799 .77619 L .48209 .77543 L p .784 .538 .565 r
F P
0 g
s
.66685 .63087 m .64501 .63743 L .65353 .63606 L p 0 0 0 r
F P
0 g
s
.6494 .44948 m .68417 .43903 L .67317 .437 L p .588 .84 .992 r
F P
0 g
s
.67317 .437 m .64124 .44795 L .6494 .44948 L p .588 .84 .992 r
F P
0 g
s
.43502 .43539 m .45121 .44125 L .44805 .44853 L p .85 .834 .83 r
F P
0 g
s
.44805 .44853 m .43237 .4452 L .43502 .43539 L p .85 .834 .83 r
F P
0 g
s
.35539 .56831 m .35972 .5511 L .34812 .556 L p .413 .172 .436 r
F P
0 g
s
.34812 .556 m .34343 .5744 L .35539 .56831 L p .413 .172 .436 r
F P
0 g
s
.55666 .44408 m .5558 .46713 L .55029 .46643 L p .764 .527 .575 r
F P
0 g
s
.55029 .46643 m .55104 .44318 L .55666 .44408 L p .764 .527 .575 r
F P
0 g
s
.60333 .71247 m .60122 .73433 L .60451 .72941 L p 0 0 .285 r
F P
0 g
s
.57077 .75322 m .56939 .78397 L .56322 .78487 L p .583 .333 .503 r
F P
0 g
s
.56939 .78397 m .57077 .75322 L .57699 .75192 L p .551 .306 .497 r
F P
0 g
s
.61927 .65181 m .61081 .65941 L .61181 .65538 L p .941 .946 .758 r
F P
0 g
s
.61181 .65538 m .6199 .64721 L .61927 .65181 L p .941 .946 .758 r
F P
0 g
s
.47625 .77469 m .4775 .73588 L .48351 .73563 L p .795 .545 .56 r
F P
0 g
s
.48351 .73563 m .48209 .77543 L .47625 .77469 L p .795 .545 .56 r
F P
0 g
s
.74203 .58547 m .731 .60667 L .75014 .60058 L p .408 .138 .39 r
F P
0 g
s
.75014 .60058 m .76217 .57686 L .74203 .58547 L p .408 .138 .39 r
F P
0 g
s
.40943 .46105 m .43183 .46682 L .43329 .47751 L p .833 .75 .771 r
F P
0 g
s
.43329 .47751 m .41287 .47448 L .40943 .46105 L p .833 .75 .771 r
F P
0 g
s
.34648 .6266 m .32223 .61038 L .30543 .62121 L p .587 .473 .691 r
F P
0 g
s
.30543 .62121 m .3317 .63782 L .34648 .6266 L p .587 .473 .691 r
F P
0 g
s
.40226 .69208 m .37242 .69342 L .37253 .70204 L p .608 .643 .86 r
F P
0 g
s
.37253 .70204 m .40293 .69897 L .40226 .69208 L p .608 .643 .86 r
F P
0 g
s
.59948 .45864 m .58999 .45697 L .598 .4544 L p .307 0 0 r
F P
0 g
s
.55104 .44318 m .55029 .46643 L .54496 .46443 L p .769 .528 .569 r
F P
0 g
s
.54496 .46443 m .54545 .44161 L .55104 .44318 L p .769 .528 .569 r
F P
0 g
s
.76505 .50721 m .79227 .52757 L .80648 .51305 L p .489 .42 .705 r
F P
0 g
s
.80648 .51305 m .77741 .49251 L .76505 .50721 L p .489 .42 .705 r
F P
0 g
s
.63915 .63971 m .62237 .64414 L .6268 .64235 L p .374 .841 .831 r
F P
0 g
s
.6268 .64235 m .64501 .63743 L .63915 .63971 L p .374 .841 .831 r
F P
0 g
s
.61125 .67123 m .61065 .67515 L p .6107 .67504 L .896 .72 .212 r
F P
0 g
s
.60891 .68656 m .60981 .68123 L p .6107 .67504 L .896 .72 .212 r
F P
0 g
s
.61065 .67515 m .60891 .68656 L p .6107 .67504 L .896 .72 .212 r
F P
0 g
s
.60981 .68123 m .61072 .6647 L .61125 .67123 L p .896 .72 .212 r
F P
0 g
s
.61081 .65941 m .61072 .6647 L p .61089 .67464 L 0 0 .034 r
F P
0 g
s
.61092 .67669 m .61091 .67459 L p .61089 .67464 L 0 0 .034 r
F P
0 g
s
.61091 .67459 m .61081 .65941 L p .61089 .67464 L 0 0 .034 r
F P
0 g
s
.37095 .54026 m .38589 .52861 L .3827 .53377 L p .808 .998 .789 r
F P
0 g
s
.44235 .73483 m .43729 .71618 L .44376 .7164 L p .85 .514 .416 r
F P
0 g
s
.44376 .7164 m .44764 .73604 L .44235 .73483 L p .85 .514 .416 r
F P
0 g
s
.54545 .44161 m .54496 .46443 L .5396 .46119 L p .775 .524 .557 r
F P
0 g
s
.5396 .46119 m .5398 .4394 L .54545 .44161 L p .775 .524 .557 r
F P
0 g
s
.57699 .75192 m .57536 .78258 L .58108 .78071 L p .509 .273 .491 r
F P
0 g
s
.58108 .78071 m .58283 .74978 L .57699 .75192 L p .509 .273 .491 r
F P
0 g
s
.57699 .75192 m .57536 .78258 L .56939 .78397 L p .551 .306 .497 r
F P
0 g
s
.37994 .67332 m .3438 .67127 L .33675 .68344 L p .624 .586 .791 r
F P
0 g
s
.33675 .68344 m .375 .68368 L .37994 .67332 L p .624 .586 .791 r
F P
0 g
s
.39239 .48506 m .41701 .48684 L .42109 .49768 L p .825 .742 .772 r
F P
0 g
s
.42109 .49768 m .39844 .4976 L .39239 .48506 L p .825 .742 .772 r
F P
0 g
s
.47051 .77392 m .47142 .73626 L .4775 .73588 L p .806 .552 .554 r
F P
0 g
s
.4775 .73588 m .47625 .77469 L .47051 .77392 L p .806 .552 .554 r
F P
0 g
s
.38157 .5129 m .40336 .508 L .40628 .51619 L p .844 .793 .802 r
F P
0 g
s
.40628 .51619 m .38537 .52179 L .38157 .5129 L p .844 .793 .802 r
F P
0 g
s
.60544 .70577 m .60451 .72941 L .60736 .72439 L p 0 0 .307 r
F P
0 g
s
.69771 .45052 m .74332 .44562 L .73693 .43682 L p .569 .704 .933 r
F P
0 g
s
.73693 .43682 m .69249 .4436 L .69771 .45052 L p .569 .704 .933 r
F P
0 g
s
.43947 .42698 m .45552 .435 L .45121 .44125 L p .815 .842 .87 r
F P
0 g
s
.45121 .44125 m .43502 .43539 L .43947 .42698 L p .815 .842 .87 r
F P
0 g
s
.71304 .61161 m .69105 .62607 L .70665 .62337 L p .307 0 .099 r
F P
0 g
s
.70665 .62337 m .731 .60667 L .71304 .61161 L p .307 0 .099 r
F P
0 g
s
.58999 .45697 m .59948 .45864 L .58921 .46362 L p .423 0 .089 r
F P
0 g
s
.58921 .46362 m .58221 .45986 L .58999 .45697 L p .423 0 .089 r
F P
0 g
s
.74278 .46915 m .78576 .47772 L .78924 .46358 L p .52 .553 .83 r
F P
0 g
s
.78924 .46358 m .74524 .4566 L .74278 .46915 L p .52 .553 .83 r
F P
0 g
s
.6199 .64721 m .61181 .65538 L .6139 .65255 L p .639 .908 .603 r
F P
0 g
s
.6139 .65255 m .62237 .64414 L .6199 .64721 L p .639 .908 .603 r
F P
0 g
s
.35293 .59303 m .34343 .5744 L .32832 .58132 L p .549 .391 .619 r
F P
0 g
s
.32832 .58132 m .33853 .601 L .35293 .59303 L p .549 .391 .619 r
F P
0 g
s
.58283 .74978 m .58108 .78071 L .5865 .77836 L p .454 .231 .485 r
F P
0 g
s
.5865 .77836 m .58822 .74685 L .58283 .74978 L p .454 .231 .485 r
F P
0 g
s
.64124 .44795 m .67317 .437 L .66013 .4375 L p .549 .884 .988 r
F P
0 g
s
.66013 .4375 m .63166 .44836 L .64124 .44795 L p .549 .884 .988 r
F P
0 g
s
.46488 .77305 m .46531 .73663 L .47142 .73626 L p .819 .559 .545 r
F P
0 g
s
.47142 .73626 m .47051 .77392 L .46488 .77305 L p .819 .559 .545 r
F P
0 g
s
.61072 .6647 m .60981 .68123 L .61092 .67669 L p 0 0 .034 r
F P
0 g
s
.4074 .44716 m .4314 .45586 L .43183 .46682 L p .826 .761 .791 r
F P
0 g
s
.43183 .46682 m .40943 .46105 L .4074 .44716 L p .826 .761 .791 r
F P
0 g
s
.36458 .64746 m .3317 .63782 L .31772 .65021 L p .617 .533 .737 r
F P
0 g
s
.31772 .65021 m .35338 .6591 L .36458 .64746 L p .617 .533 .737 r
F P
0 g
s
.67752 .62839 m .65353 .63606 L .66428 .63512 L p .16 0 0 r
F P
0 g
s
.66428 .63512 m .69105 .62607 L .67752 .62839 L p .16 0 0 r
F P
0 g
s
.58221 .45986 m .58921 .46362 L .57977 .46846 L p .505 .11 .225 r
F P
0 g
s
.57977 .46846 m .57483 .46267 L .58221 .45986 L p .505 .11 .225 r
F P
0 g
s
.43756 .73296 m .43152 .71488 L .43729 .71618 L p .876 .511 .35 r
F P
0 g
s
.43729 .71618 m .44235 .73483 L .43756 .73296 L p .876 .511 .35 r
F P
0 g
s
.60694 .69904 m .60736 .72439 L .60984 .71944 L p 0 0 .342 r
F P
0 g
s
.44569 .42046 m .46096 .43011 L .45552 .435 L p .766 .844 .91 r
F P
0 g
s
.45552 .435 m .43947 .42698 L .44569 .42046 L p .766 .844 .91 r
F P
0 g
s
.35972 .5511 m .35539 .56831 L .36336 .56253 L p .266 .039 .371 r
F P
0 g
s
.64501 .63743 m .6268 .64235 L .63307 .6415 L p .038 0 0 r
F P
0 g
s
.63307 .6415 m .65353 .63606 L .64501 .63743 L p .038 0 0 r
F P
0 g
s
.58822 .74685 m .5865 .77836 L .59159 .77559 L p .395 .189 .478 r
F P
0 g
s
.59159 .77559 m .5931 .74321 L .58822 .74685 L p .395 .189 .478 r
F P
0 g
s
.77486 .54107 m .7821 .56666 L .80025 .55495 L p .423 .273 .572 r
F P
0 g
s
.80025 .55495 m .79227 .52757 L .77486 .54107 L p .423 .273 .572 r
F P
0 g
s
.42034 .7043 m .40293 .69897 L .40552 .70462 L p .371 .566 .912 r
F P
0 g
s
.40341 .68427 m .375 .68368 L .37242 .69342 L p .615 .61 .823 r
F P
0 g
s
.37242 .69342 m .40226 .69208 L .40341 .68427 L p .615 .61 .823 r
F P
0 g
s
.57483 .46267 m .57977 .46846 L .57133 .47259 L p .57 .209 .316 r
F P
0 g
s
.57133 .47259 m .56797 .46503 L .57483 .46267 L p .57 .209 .316 r
F P
0 g
s
.45942 .77201 m .45924 .73681 L .46531 .73663 L p .834 .566 .534 r
F P
0 g
s
.46531 .73663 m .46488 .77305 L .45942 .77201 L p .834 .566 .534 r
F P
0 g
s
.38616 .47064 m .41287 .47448 L .41701 .48684 L p .829 .748 .775 r
F P
0 g
s
.41701 .48684 m .39239 .48506 L .38616 .47064 L p .829 .748 .775 r
F P
0 g
s
.37026 .53314 m .38537 .52179 L .38589 .52861 L p .921 .909 .793 r
F P
0 g
s
.38589 .52861 m .37095 .54026 L .37026 .53314 L p .921 .909 .793 r
F P
0 g
s
.61081 .65941 m .61092 .67669 L .6124 .67297 L p 0 0 .285 r
F P
0 g
s
.6124 .67297 m .61181 .65538 L .61081 .65941 L p 0 0 .285 r
F P
0 g
s
.62237 .64414 m .6139 .65255 L .61714 .65075 L p .025 0 0 r
F P
0 g
s
.61714 .65075 m .6268 .64235 L .62237 .64414 L p .025 0 0 r
F P
0 g
s
.37528 .50172 m .39844 .4976 L .40336 .508 L p .849 .769 .773 r
F P
0 g
s
.40336 .508 m .38157 .5129 L .37528 .50172 L p .849 .769 .773 r
F P
0 g
s
.63166 .44836 m .66013 .4375 L .64579 .44033 L p .483 .892 .928 r
F P
0 g
s
.64579 .44033 m .62117 .45052 L .63166 .44836 L p .483 .892 .928 r
F P
0 g
s
.36078 .6168 m .33853 .601 L .32223 .61038 L p .602 .483 .689 r
F P
0 g
s
.32223 .61038 m .34648 .6266 L .36078 .6168 L p .602 .483 .689 r
F P
0 g
s
.56797 .46503 m .57133 .47259 L .56391 .47551 L p .627 .285 .372 r
F P
0 g
s
.56391 .47551 m .56164 .46661 L .56797 .46503 L p .627 .285 .372 r
F P
0 g
s
.60803 .69255 m .60984 .71944 L .61205 .7147 L p 0 0 .387 r
F P
0 g
s
.38673 .66282 m .35338 .6591 L .3438 .67127 L p .634 .572 .767 r
F P
0 g
s
.3438 .67127 m .37994 .67332 L .38673 .66282 L p .634 .572 .767 r
F P
0 g
s
.5931 .74321 m .59159 .77559 L .59632 .77245 L p .332 .146 .472 r
F P
0 g
s
.59632 .77245 m .59743 .73898 L .5931 .74321 L p .332 .146 .472 r
F P
0 g
s
.46096 .43011 m .44569 .42046 L .45349 .4162 L p .699 .835 .948 r
F P
0 g
s
.40735 .43351 m .43237 .4452 L .4314 .45586 L p .815 .773 .814 r
F P
0 g
s
.4314 .45586 m .4074 .44716 L .40735 .43351 L p .815 .773 .814 r
F P
0 g
s
.43152 .71488 m .43756 .73296 L .43337 .73038 L p .9 .505 .258 r
F P
0 g
s
.56164 .46661 m .56391 .47551 L .55739 .47681 L p .68 .343 .398 r
F P
0 g
s
.55739 .47681 m .5558 .46713 L .56164 .46661 L p .68 .343 .398 r
F P
0 g
s
.69249 .4436 m .73693 .43682 L .72635 .43071 L p .546 .763 .978 r
F P
0 g
s
.72635 .43071 m .68417 .43903 L .69249 .4436 L p .546 .763 .978 r
F P
0 g
s
.45416 .77073 m .45331 .73666 L .45924 .73681 L p .85 .574 .52 r
F P
0 g
s
.45924 .73681 m .45942 .77201 L .45416 .77073 L p .85 .574 .52 r
F P
0 g
s
.76217 .57686 m .75014 .60058 L .76908 .59306 L p .347 .084 .364 r
F P
0 g
s
.76908 .59306 m .7821 .56666 L .76217 .57686 L p .347 .084 .364 r
F P
0 g
s
.5558 .46713 m .55739 .47681 L .55155 .47624 L p .732 .385 .392 r
F P
0 g
s
.55155 .47624 m .55029 .46643 L .5558 .46713 L p .732 .385 .392 r
F P
0 g
s
.36432 .58622 m .35539 .56831 L .34343 .5744 L p .537 .392 .631 r
F P
0 g
s
.34343 .5744 m .35293 .59303 L .36432 .58622 L p .537 .392 .631 r
F P
0 g
s
.61181 .65538 m .6124 .67297 L .61434 .67006 L p .046 0 .418 r
F P
0 g
s
.61434 .67006 m .6139 .65255 L .61181 .65538 L p .046 0 .418 r
F P
0 g
s
.41898 .69881 m .40226 .69208 L .40293 .69897 L p .426 .533 .862 r
F P
0 g
s
.40293 .69897 m .42034 .7043 L .41898 .69881 L p .426 .533 .862 r
F P
0 g
s
.59743 .73898 m .59632 .77245 L .60068 .76902 L p .27 .106 .466 r
F P
0 g
s
.60068 .76902 m .60122 .73433 L .59743 .73898 L p .27 .106 .466 r
F P
0 g
s
.62117 .45052 m .64579 .44033 L .63094 .44506 L p .399 .854 .818 r
F P
0 g
s
.60891 .68656 m .61205 .7147 L .6141 .71028 L p 0 0 .435 r
F P
0 g
s
.6141 .71028 m .60981 .68123 L .60891 .68656 L p 0 0 .435 r
F P
0 g
s
.77741 .49251 m .80648 .51305 L .81622 .4981 L p .439 .414 .734 r
F P
0 g
s
.81622 .4981 m .78576 .47772 L .77741 .49251 L p .439 .414 .734 r
F P
0 g
s
.37641 .6368 m .34648 .6266 L .3317 .63782 L p .631 .534 .727 r
F P
0 g
s
.3317 .63782 m .36458 .64746 L .37641 .6368 L p .631 .534 .727 r
F P
0 g
s
.65353 .63606 m .63307 .6415 L .64087 .6412 L p .198 0 0 r
F P
0 g
s
.64087 .6412 m .66428 .63512 L .65353 .63606 L p .198 0 0 r
F P
0 g
s
.6268 .64235 m .61714 .65075 L .62146 .64977 L p .285 0 .059 r
F P
0 g
s
.62146 .64977 m .63307 .6415 L .6268 .64235 L p .285 0 .059 r
F P
0 g
s
.731 .60667 m .70665 .62337 L .72324 .61984 L p .262 0 .076 r
F P
0 g
s
.72324 .61984 m .75014 .60058 L .731 .60667 L p .262 0 .076 r
F P
0 g
s
.40618 .67588 m .37994 .67332 L .375 .68368 L p .62 .585 .793 r
F P
0 g
s
.375 .68368 m .40341 .68427 L .40618 .67588 L p .62 .585 .793 r
F P
0 g
s
.69105 .62607 m .66428 .63512 L .67662 .63413 L p .19 0 0 r
F P
0 g
s
.67662 .63413 m .70665 .62337 L .69105 .62607 L p .19 0 0 r
F P
0 g
s
.44917 .76915 m .44764 .73604 L .45331 .73666 L p .869 .584 .503 r
F P
0 g
s
.45331 .73666 m .45416 .77073 L .44917 .76915 L p .869 .584 .503 r
F P
0 g
s
.38079 .45485 m .40943 .46105 L .41287 .47448 L p .83 .76 .785 r
F P
0 g
s
.41287 .47448 m .38616 .47064 L .38079 .45485 L p .83 .76 .785 r
F P
0 g
s
.74524 .4566 m .78924 .46358 L .78732 .45087 L p .483 .586 .882 r
F P
0 g
s
.78732 .45087 m .74332 .44562 L .74524 .4566 L p .483 .586 .882 r
F P
0 g
s
.42668 .71245 m .43337 .73038 L .42987 .7271 L p .903 .489 .131 r
F P
0 g
s
.36588 .52421 m .38157 .5129 L .38537 .52179 L p .916 .826 .743 r
F P
0 g
s
.38537 .52179 m .37026 .53314 L .36588 .52421 L p .916 .826 .743 r
F P
0 g
s
.51886 .82314 m .51845 .78114 L .52475 .78227 L p .703 .426 .502 r
F P
0 g
s
.52475 .78227 m .52484 .82362 L .51886 .82314 L p .703 .426 .502 r
F P
0 g
s
.52484 .82362 m .52475 .78227 L .53113 .78332 L p .687 .411 .499 r
F P
0 g
s
.47469 .42525 m .46258 .41443 L .45349 .4162 L p .61 .809 .976 r
F P
0 g
s
.51292 .82253 m .51222 .78001 L .51845 .78114 L p .718 .44 .505 r
F P
0 g
s
.51845 .78114 m .51886 .82314 L .51292 .82253 L p .718 .44 .505 r
F P
0 g
s
.40972 .42084 m .43502 .43539 L .43237 .4452 L p .797 .784 .841 r
F P
0 g
s
.43237 .4452 m .40735 .43351 L .40972 .42084 L p .797 .784 .841 r
F P
0 g
s
.53113 .78332 m .53085 .82395 L .52484 .82362 L p .687 .411 .499 r
F P
0 g
s
.53085 .82395 m .53113 .78332 L .53756 .78423 L p .67 .394 .495 r
F P
0 g
s
.36752 .48824 m .39239 .48506 L .39844 .4976 L p .856 .766 .762 r
F P
0 g
s
.39844 .4976 m .37528 .50172 L .36752 .48824 L p .856 .766 .762 r
F P
0 g
s
.61028 .4541 m .63094 .44506 L .61633 .45111 L p .314 .787 .688 r
F P
0 g
s
.60122 .73433 m .60068 .76902 L .60468 .76537 L p .21 .07 .462 r
F P
0 g
s
.60468 .76537 m .60451 .72941 L .60122 .73433 L p .21 .07 .462 r
F P
0 g
s
.50703 .82182 m .50607 .77892 L .51222 .78001 L p .732 .454 .506 r
F P
0 g
s
.51222 .78001 m .51292 .82253 L .50703 .82182 L p .732 .454 .506 r
F P
0 g
s
.53756 .78423 m .53686 .82411 L .53085 .82395 L p .67 .394 .495 r
F P
0 g
s
.53686 .82411 m .53756 .78423 L .54402 .78491 L p .652 .377 .49 r
F P
0 g
s
.60981 .68123 m .6141 .71028 L .61605 .70626 L p 0 0 .479 r
F P
0 g
s
.61605 .70626 m .61092 .67669 L .60981 .68123 L p 0 0 .479 r
F P
0 g
s
.6139 .65255 m .61434 .67006 L .61677 .66788 L p .234 .079 .456 r
F P
0 g
s
.61677 .66788 m .61714 .65075 L .6139 .65255 L p .234 .079 .456 r
F P
0 g
s
.3734 .60849 m .35293 .59303 L .33853 .601 L p .609 .493 .696 r
F P
0 g
s
.33853 .601 m .36078 .6168 L .3734 .60849 L p .609 .493 .696 r
F P
0 g
s
.50122 .82102 m .49998 .77792 L .50607 .77892 L p .746 .466 .506 r
F P
0 g
s
.50607 .77892 m .50703 .82182 L .50122 .82102 L p .746 .466 .506 r
F P
0 g
s
.39473 .65266 m .36458 .64746 L .35338 .6591 L p .643 .564 .75 r
F P
0 g
s
.35338 .6591 m .38673 .66282 L .39473 .65266 L p .643 .564 .75 r
F P
0 g
s
.54402 .78491 m .54285 .82408 L .53686 .82411 L p .652 .377 .49 r
F P
0 g
s
.54285 .82408 m .54402 .78491 L .55048 .78529 L p .632 .358 .485 r
F P
0 g
s
.48254 .42545 m .47255 .4152 L .46258 .41443 L p .499 .762 .99 r
F P
0 g
s
.49549 .82014 m .49396 .77701 L .49998 .77792 L p .76 .478 .505 r
F P
0 g
s
.49998 .77792 m .50122 .82102 L .49549 .82014 L p .76 .478 .505 r
F P
0 g
s
.55048 .78529 m .5488 .82382 L .54285 .82408 L p .632 .358 .485 r
F P
0 g
s
.5488 .82382 m .55048 .78529 L .5569 .78529 L p .61 .338 .48 r
F P
0 g
s
.4188 .69263 m .40341 .68427 L .40226 .69208 L p .454 .499 .815 r
F P
0 g
s
.40226 .69208 m .41898 .69881 L .4188 .69263 L p .454 .499 .815 r
F P
0 g
s
.59948 .45864 m .61633 .45111 L .60258 .45777 L p 0 0 0 r
F P
0 g
s
.60258 .45777 m .58921 .46362 L .59948 .45864 L p 0 0 0 r
F P
0 g
s
.68417 .43903 m .72635 .43071 L .71217 .42757 L p .508 .82 1 r
F P
0 g
s
.71217 .42757 m .67317 .437 L .68417 .43903 L p .508 .82 1 r
F P
0 g
s
.44451 .76722 m .44235 .73483 L .44764 .73604 L p .89 .596 .483 r
F P
0 g
s
.44764 .73604 m .44917 .76915 L .44451 .76722 L p .89 .596 .483 r
F P
0 g
s
.4907 .42733 m .48294 .41839 L .47255 .4152 L p .357 .688 .981 r
F P
0 g
s
.37191 .58017 m .36336 .56253 L .35539 .56831 L p .48 .371 .652 r
F P
0 g
s
.35539 .56831 m .36432 .58622 L .37191 .58017 L p .48 .371 .652 r
F P
0 g
s
.60451 .72941 m .60468 .76537 L .60832 .76159 L p .158 .041 .459 r
F P
0 g
s
.60832 .76159 m .60736 .72439 L .60451 .72941 L p .158 .041 .459 r
F P
0 g
s
.48985 .81917 m .48799 .77619 L .49396 .77701 L p .774 .488 .503 r
F P
0 g
s
.49396 .77701 m .49549 .82014 L .48985 .81917 L p .774 .488 .503 r
F P
0 g
s
.5569 .78529 m .55467 .82331 L .5488 .82382 L p .61 .338 .48 r
F P
0 g
s
.55467 .82331 m .5569 .78529 L .56322 .78487 L p .587 .317 .474 r
F P
0 g
s
.49889 .43067 m .49332 .42369 L .48294 .41839 L p .187 .583 .941 r
F P
0 g
s
.41023 .6673 m .38673 .66282 L .37994 .67332 L p .624 .565 .768 r
F P
0 g
s
.37994 .67332 m .40618 .67588 L .41023 .6673 L p .624 .565 .768 r
F P
0 g
s
.50686 .43517 m .50328 .43064 L .49332 .42369 L p 0 .447 .862 r
F P
0 g
s
.63307 .6415 m .62146 .64977 L .62665 .64931 L p .355 0 .093 r
F P
0 g
s
.62665 .64931 m .64087 .6412 L .63307 .6415 L p .355 0 .093 r
F P
0 g
s
.58921 .46362 m .60258 .45777 L .59017 .46429 L p 0 0 0 r
F P
0 g
s
.59017 .46429 m .57977 .46846 L .58921 .46362 L p 0 0 0 r
F P
0 g
s
.61092 .67669 m .61605 .70626 L .61798 .70269 L p .047 .028 .51 r
F P
0 g
s
.61798 .70269 m .6124 .67297 L .61092 .67669 L p .047 .028 .51 r
F P
0 g
s
.38784 .62741 m .36078 .6168 L .34648 .6266 L p .641 .54 .724 r
F P
0 g
s
.34648 .6266 m .37641 .6368 L .38784 .62741 L p .641 .54 .724 r
F P
0 g
s
.79227 .52757 m .80025 .55495 L .81514 .54199 L p .346 .225 .569 r
F P
0 g
s
.81514 .54199 m .80648 .51305 L .79227 .52757 L p .346 .225 .569 r
F P
0 g
s
.57977 .46846 m .59017 .46429 L .57932 .4699 L p 0 0 0 r
F P
0 g
s
.57932 .4699 m .57133 .47259 L .57977 .46846 L p 0 0 0 r
F P
0 g
s
.48433 .81811 m .48209 .77543 L .48799 .77619 L p .787 .499 .499 r
F P
0 g
s
.48799 .77619 m .48985 .81917 L .48433 .81811 L p .787 .499 .499 r
F P
0 g
s
.4147 .40991 m .43947 .42698 L .43502 .43539 L p .773 .792 .869 r
F P
0 g
s
.43502 .43539 m .40972 .42084 L .4147 .40991 L p .773 .792 .869 r
F P
0 g
s
.61714 .65075 m .61677 .66788 L .61966 .66627 L p .325 .127 .451 r
F P
0 g
s
.61966 .66627 m .62146 .64977 L .61714 .65075 L p .325 .127 .451 r
F P
0 g
s
.56322 .78487 m .56044 .82254 L .55467 .82331 L p .587 .317 .474 r
F P
0 g
s
.56044 .82254 m .56322 .78487 L .56939 .78397 L p .562 .294 .468 r
F P
0 g
s
.66428 .63512 m .64087 .6412 L .64973 .64104 L p .215 0 0 r
F P
0 g
s
.64973 .64104 m .67662 .63413 L .66428 .63512 L p .215 0 0 r
F P
0 g
s
.57133 .47259 m .57932 .4699 L .57006 .47393 L p 0 0 0 r
F P
0 g
s
.57006 .47393 m .56391 .47551 L .57133 .47259 L p 0 0 0 r
F P
0 g
s
.37722 .43835 m .4074 .44716 L .40943 .46105 L p .828 .776 .803 r
F P
0 g
s
.40943 .46105 m .38079 .45485 L .37722 .43835 L p .828 .776 .803 r
F P
0 g
s
.56391 .47551 m .57006 .47393 L .56222 .47583 L p .141 .681 .695 r
F P
0 g
s
.56222 .47583 m .55739 .47681 L .56391 .47551 L p .141 .681 .695 r
F P
0 g
s
.44022 .76491 m .43756 .73296 L .44235 .73483 L p .913 .609 .458 r
F P
0 g
s
.44235 .73483 m .44451 .76722 L .44022 .76491 L p .913 .609 .458 r
F P
0 g
s
.60736 .72439 m .60832 .76159 L .61163 .75777 L p .115 .018 .457 r
F P
0 g
s
.61163 .75777 m .60984 .71944 L .60736 .72439 L p .115 .018 .457 r
F P
0 g
s
.40321 .64323 m .37641 .6368 L .36458 .64746 L p .651 .56 .739 r
F P
0 g
s
.36458 .64746 m .39473 .65266 L .40321 .64323 L p .651 .56 .739 r
F P
0 g
s
.47894 .81694 m .47625 .77469 L .48209 .77543 L p .802 .509 .494 r
F P
0 g
s
.48209 .77543 m .48433 .81811 L .47894 .81694 L p .802 .509 .494 r
F P
0 g
s
.35865 .51317 m .37528 .50172 L .38157 .5129 L p .912 .792 .714 r
F P
0 g
s
.38157 .5129 m .36588 .52421 L .35865 .51317 L p .912 .792 .714 r
F P
0 g
s
.41968 .686 m .40618 .67588 L .40341 .68427 L p .465 .465 .774 r
F P
0 g
s
.40341 .68427 m .4188 .69263 L .41968 .686 L p .465 .465 .774 r
F P
0 g
s
.38338 .60154 m .36432 .58622 L .35293 .59303 L p .604 .505 .715 r
F P
0 g
s
.35293 .59303 m .3734 .60849 L .38338 .60154 L p .604 .505 .715 r
F P
0 g
s
.56939 .78397 m .56609 .82149 L .56044 .82254 L p .562 .294 .468 r
F P
0 g
s
.56609 .82149 m .56939 .78397 L .57536 .78258 L p .534 .271 .462 r
F P
0 g
s
.55739 .47681 m .56222 .47583 L .55542 .47525 L p .127 .66 .863 r
F P
0 g
s
.55542 .47525 m .55155 .47624 L .55739 .47681 L p .127 .66 .863 r
F P
0 g
s
.6124 .67297 m .61798 .70269 L .61994 .69955 L p .12 .075 .528 r
F P
0 g
s
.61994 .69955 m .61434 .67006 L .6124 .67297 L p .12 .075 .528 r
F P
0 g
s
.35948 .47268 m .38616 .47064 L .39239 .48506 L p .863 .775 .763 r
F P
0 g
s
.39239 .48506 m .36752 .48824 L .35948 .47268 L p .863 .775 .763 r
F P
0 g
s
.70665 .62337 m .67662 .63413 L .68969 .63264 L p .133 0 0 r
F P
0 g
s
.68969 .63264 m .72324 .61984 L .70665 .62337 L p .133 0 0 r
F P
0 g
s
.55155 .47624 m .55542 .47525 L .54918 .47202 L p .097 .549 .91 r
F P
0 g
s
.54918 .47202 m .54605 .47366 L .55155 .47624 L p .097 .549 .91 r
F P
0 g
s
.67317 .437 m .71217 .42757 L .69522 .42747 L p .449 .851 .971 r
F P
0 g
s
.69522 .42747 m .66013 .4375 L .67317 .437 L p .449 .851 .971 r
F P
0 g
s
.41515 .65889 m .39473 .65266 L .38673 .66282 L p .626 .55 .748 r
F P
0 g
s
.38673 .66282 m .41023 .6673 L .41515 .65889 L p .626 .55 .748 r
F P
0 g
s
.7821 .56666 m .76908 .59306 L .78633 .58408 L p .245 0 .313 r
F P
0 g
s
.78633 .58408 m .80025 .55495 L .7821 .56666 L p .245 0 .313 r
F P
0 g
s
.74332 .44562 m .78732 .45087 L .77989 .44031 L p .429 .632 .94 r
F P
0 g
s
.77989 .44031 m .73693 .43682 L .74332 .44562 L p .429 .632 .94 r
F P
0 g
s
.57536 .78258 m .57157 .82016 L .57687 .81856 L p .5 .243 .456 r
F P
0 g
s
.57687 .81856 m .58108 .78071 L .57536 .78258 L p .5 .243 .456 r
F P
0 g
s
.57536 .78258 m .57157 .82016 L .56609 .82149 L p .534 .271 .462 r
F P
0 g
s
.47371 .81566 m .47051 .77392 L .47625 .77469 L p .816 .519 .487 r
F P
0 g
s
.47625 .77469 m .47894 .81694 L .47371 .81566 L p .816 .519 .487 r
F P
0 g
s
.37533 .5744 m .36694 .55651 L .36336 .56253 L p .296 .284 .675 r
F P
0 g
s
.36336 .56253 m .37191 .58017 L .37533 .5744 L p .296 .284 .675 r
F P
0 g
s
.39794 .61943 m .3734 .60849 L .36078 .6168 L p .647 .55 .731 r
F P
0 g
s
.36078 .6168 m .38784 .62741 L .39794 .61943 L p .647 .55 .731 r
F P
0 g
s
.54297 .46621 m .54055 .46916 L .54605 .47366 L p .068 .439 .876 r
F P
0 g
s
.60984 .71944 m .61163 .75777 L .61463 .75396 L p .084 .004 .457 r
F P
0 g
s
.61463 .75396 m .61205 .7147 L .60984 .71944 L p .084 .004 .457 r
F P
0 g
s
.75014 .60058 m .72324 .61984 L .73962 .61518 L p .159 0 0 r
F P
0 g
s
.73962 .61518 m .76908 .59306 L .75014 .60058 L p .159 0 0 r
F P
0 g
s
.42228 .4014 m .44569 .42046 L .43947 .42698 L p .738 .795 .898 r
F P
0 g
s
.43947 .42698 m .4147 .40991 L .42228 .4014 L p .738 .795 .898 r
F P
0 g
s
.78576 .47772 m .81622 .4981 L .82048 .48345 L p .365 .409 .773 r
F P
0 g
s
.82048 .48345 m .78924 .46358 L .78576 .47772 L p .365 .409 .773 r
F P
0 g
s
.62146 .64977 m .61966 .66627 L .62287 .66508 L p .359 .129 .423 r
F P
0 g
s
.62287 .66508 m .62665 .64931 L .62146 .64977 L p .359 .129 .423 r
F P
0 g
s
.43637 .7622 m .43337 .73038 L .43756 .73296 L p .936 .625 .427 r
F P
0 g
s
.43756 .73296 m .44022 .76491 L .43637 .7622 L p .936 .625 .427 r
F P
0 g
s
.64087 .6412 m .62665 .64931 L .63241 .64909 L p .348 0 .053 r
F P
0 g
s
.63241 .64909 m .64973 .64104 L .64087 .6412 L p .348 0 .053 r
F P
0 g
s
.41145 .63482 m .38784 .62741 L .37641 .6368 L p .657 .561 .736 r
F P
0 g
s
.37641 .6368 m .40321 .64323 L .41145 .63482 L p .657 .561 .736 r
F P
0 g
s
.42144 .67916 m .41023 .6673 L .40618 .67588 L p .463 .431 .737 r
F P
0 g
s
.40618 .67588 m .41968 .686 L .42144 .67916 L p .463 .431 .737 r
F P
0 g
s
.58108 .78071 m .57687 .81856 L .58195 .81668 L p .458 .208 .447 r
F P
0 g
s
.58195 .81668 m .5865 .77836 L .58108 .78071 L p .458 .208 .447 r
F P
0 g
s
.61434 .67006 m .61994 .69955 L .62193 .69683 L p .174 .104 .532 r
F P
0 g
s
.62193 .69683 m .61677 .66788 L .61434 .67006 L p .174 .104 .532 r
F P
0 g
s
.53625 .45812 m .5347 .46297 L .54055 .46916 L p .051 .378 .843 r
F P
0 g
s
.46865 .81424 m .46488 .77305 L .47051 .77392 L p .831 .529 .477 r
F P
0 g
s
.47051 .77392 m .47371 .81566 L .46865 .81424 L p .831 .529 .477 r
F P
0 g
s
.42049 .65096 m .40321 .64323 L .39473 .65266 L p .626 .537 .733 r
F P
0 g
s
.39473 .65266 m .41515 .65889 L .42049 .65096 L p .626 .537 .733 r
F P
0 g
s
.39006 .59567 m .37191 .58017 L .36432 .58622 L p .574 .515 .751 r
F P
0 g
s
.36432 .58622 m .38338 .60154 L .39006 .59567 L p .574 .515 .751 r
F P
0 g
s
.36161 .5415 m .36588 .52421 L .37026 .53314 L p .995 .792 .518 r
F P
0 g
s
.37026 .53314 m .36619 .54967 L .36161 .5415 L p .995 .792 .518 r
F P
0 g
s
.61205 .7147 m .61463 .75396 L .61735 .75024 L p .063 0 .459 r
F P
0 g
s
.61735 .75024 m .6141 .71028 L .61205 .7147 L p .063 0 .459 r
F P
0 g
s
.37627 .42197 m .40735 .43351 L .4074 .44716 L p .821 .793 .826 r
F P
0 g
s
.4074 .44716 m .37722 .43835 L .37627 .42197 L p .821 .793 .826 r
F P
0 g
s
.66013 .4375 m .69522 .42747 L .67653 .43018 L p .376 .84 .88 r
F P
0 g
s
.67653 .43018 m .64579 .44033 L .66013 .4375 L p .376 .84 .88 r
F P
0 g
s
.52857 .44825 m .52819 .45546 L .5347 .46297 L p .049 .357 .83 r
F P
0 g
s
.5865 .77836 m .58195 .81668 L .58679 .81455 L p .412 .172 .438 r
F P
0 g
s
.58679 .81455 m .59159 .77559 L .5865 .77836 L p .412 .172 .438 r
F P
0 g
s
.40595 .61282 m .38338 .60154 L .3734 .60849 L p .643 .564 .75 r
F P
0 g
s
.3734 .60849 m .39794 .61943 L .40595 .61282 L p .643 .564 .75 r
F P
0 g
s
.43219 .39583 m .45349 .4162 L .44569 .42046 L p .691 .789 .925 r
F P
0 g
s
.44569 .42046 m .42228 .4014 L .43219 .39583 L p .691 .789 .925 r
F P
0 g
s
.67662 .63413 m .64973 .64104 L .65904 .64066 L p .149 0 0 r
F P
0 g
s
.65904 .64066 m .68969 .63264 L .67662 .63413 L p .149 0 0 r
F P
0 g
s
.46378 .81267 m .45942 .77201 L .46488 .77305 L p .848 .539 .466 r
F P
0 g
s
.46488 .77305 m .46865 .81424 L .46378 .81267 L p .848 .539 .466 r
F P
0 g
s
.433 .7591 m .42987 .7271 L .43337 .73038 L p .957 .642 .39 r
F P
0 g
s
.43337 .73038 m .43637 .7622 L .433 .7591 L p .957 .642 .39 r
F P
0 g
s
.41879 .62761 m .39794 .61943 L .38784 .62741 L p .658 .567 .74 r
F P
0 g
s
.38784 .62741 m .41145 .63482 L .41879 .62761 L p .658 .567 .74 r
F P
0 g
s
.42385 .67237 m .41515 .65889 L .41023 .6673 L p .45 .392 .701 r
F P
0 g
s
.41023 .6673 m .42144 .67916 L .42385 .67237 L p .45 .392 .701 r
F P
0 g
s
.42578 .64376 m .41145 .63482 L .40321 .64323 L p .62 .524 .724 r
F P
0 g
s
.40321 .64323 m .42049 .65096 L .42578 .64376 L p .62 .524 .724 r
F P
0 g
s
.34972 .49992 m .36752 .48824 L .37528 .50172 L p .916 .786 .702 r
F P
0 g
s
.37528 .50172 m .35865 .51317 L .34972 .49992 L p .916 .786 .702 r
F P
0 g
s
.61677 .66788 m .62193 .69683 L .62392 .69445 L p .205 .114 .524 r
F P
0 g
s
.62392 .69445 m .61966 .66627 L .61677 .66788 L p .205 .114 .524 r
F P
0 g
s
.62665 .64931 m .62287 .66508 L .62624 .66411 L p .355 .096 .376 r
F P
0 g
s
.62624 .66411 m .63241 .64909 L .62665 .64931 L p .355 .096 .376 r
F P
0 g
s
.36694 .55651 m .37533 .5744 L .37465 .56837 L p 0 0 .553 r
F P
0 g
s
.59159 .77559 m .58679 .81455 L .59138 .8122 L p .363 .134 .427 r
F P
0 g
s
.59138 .8122 m .59632 .77245 L .59159 .77559 L p .363 .134 .427 r
F P
0 g
s
.6141 .71028 m .61735 .75024 L .6198 .74666 L p .051 0 .46 r
F P
0 g
s
.6198 .74666 m .61605 .70626 L .6141 .71028 L p .051 0 .46 r
F P
0 g
s
.42343 .70841 m .41968 .686 L .4188 .69263 L p 0 0 .313 r
F P
0 g
s
.35242 .4555 m .38079 .45485 L .38616 .47064 L p .868 .792 .774 r
F P
0 g
s
.38616 .47064 m .35948 .47268 L .35242 .4555 L p .868 .792 .774 r
F P
0 g
s
.64579 .44033 m .67653 .43018 L .65718 .43525 L p .311 .798 .76 r
F P
0 g
s
.65718 .43525 m .63094 .44506 L .64579 .44033 L p .311 .798 .76 r
F P
0 g
s
.45915 .81092 m .45416 .77073 L .45942 .77201 L p .865 .549 .452 r
F P
0 g
s
.45942 .77201 m .46378 .81267 L .45915 .81092 L p .865 .549 .452 r
F P
0 g
s
.42665 .66585 m .42049 .65096 L .41515 .65889 L p .422 .344 .664 r
F P
0 g
s
.41515 .65889 m .42385 .67237 L .42665 .66585 L p .422 .344 .664 r
F P
0 g
s
.43219 .39583 m .45349 .4162 L .46258 .41443 L p .626 .77 .949 r
F P
0 g
s
.42468 .62163 m .40595 .61282 L .39794 .61943 L p .651 .576 .758 r
F P
0 g
s
.39794 .61943 m .41879 .62761 L .42468 .62163 L p .651 .576 .758 r
F P
0 g
s
.43059 .63747 m .41879 .62761 L .41145 .63482 L p .607 .511 .72 r
F P
0 g
s
.41145 .63482 m .42578 .64376 L .43059 .63747 L p .607 .511 .72 r
F P
0 g
s
.64973 .64104 m .63241 .64909 L .63833 .6488 L p .286 0 0 r
F P
0 g
s
.63833 .6488 m .65904 .64066 L .64973 .64104 L p .286 0 0 r
F P
0 g
s
.39311 .5905 m .37533 .5744 L .37191 .58017 L p .479 .51 .811 r
F P
0 g
s
.37191 .58017 m .39006 .59567 L .39311 .5905 L p .479 .51 .811 r
F P
0 g
s
.52083 .44716 m .51958 .43727 L .50915 .426 L p .1 .404 .857 r
F P
0 g
s
.41137 .60744 m .39006 .59567 L .38338 .60154 L p .621 .582 .789 r
F P
0 g
s
.38338 .60154 m .40595 .61282 L .41137 .60744 L p .621 .582 .789 r
F P
0 g
s
.73693 .43682 m .77989 .44031 L .76725 .43252 L p .341 .679 .978 r
F P
0 g
s
.76725 .43252 m .72635 .43071 L .73693 .43682 L p .341 .679 .978 r
F P
0 g
s
.80648 .51305 m .81514 .54199 L .8254 .52828 L p .218 .148 .559 r
F P
0 g
s
.8254 .52828 m .81622 .4981 L .80648 .51305 L p .218 .148 .559 r
F P
0 g
s
.43013 .75562 m .42713 .72317 L .42987 .7271 L p .971 .658 .346 r
F P
0 g
s
.42987 .7271 m .433 .7591 L .43013 .75562 L p .971 .658 .346 r
F P
0 g
s
.63094 .44506 m .65718 .43525 L .63818 .44199 L p .275 .758 .658 r
F P
0 g
s
.63818 .44199 m .61633 .45111 L .63094 .44506 L p .275 .758 .658 r
F P
0 g
s
.59632 .77245 m .59138 .8122 L .59568 .80965 L p .31 .094 .415 r
F P
0 g
s
.59568 .80965 m .60068 .76902 L .59632 .77245 L p .31 .094 .415 r
F P
0 g
s
.72324 .61984 m .68969 .63264 L .70253 .63032 L p 0 0 0 r
F P
0 g
s
.70253 .63032 m .73962 .61518 L .72324 .61984 L p 0 0 0 r
F P
0 g
s
.61605 .70626 m .6198 .74666 L .62202 .74323 L p .043 0 .46 r
F P
0 g
s
.62202 .74323 m .61798 .70269 L .61605 .70626 L p .043 0 .46 r
F P
0 g
s
.42355 .70295 m .42144 .67916 L .41968 .686 L p 0 0 .313 r
F P
0 g
s
.41968 .686 m .42343 .70841 L .42355 .70295 L p 0 0 .313 r
F P
0 g
s
.51251 .43867 m .50915 .426 L .49733 .41529 L p .159 .461 .887 r
F P
0 g
s
.49733 .41529 m .50328 .43064 L .51251 .43867 L p .159 .461 .887 r
F P
0 g
s
.61633 .45111 m .63818 .44199 L .62041 .44957 L p 0 0 0 r
F P
0 g
s
.62041 .44957 m .60258 .45777 L .61633 .45111 L p 0 0 0 r
F P
0 g
s
.57914 .46825 m .57006 .47393 L .57932 .4699 L p .44 .874 .796 r
F P
0 g
s
.57006 .47393 m .57914 .46825 L .56949 .47045 L p .486 .89 .937 r
F P
0 g
s
.56949 .47045 m .56222 .47583 L .57006 .47393 L p .486 .89 .937 r
F P
0 g
s
.42958 .65979 m .42578 .64376 L .42049 .65096 L p .375 .283 .622 r
F P
0 g
s
.42049 .65096 m .42665 .66585 L .42958 .65979 L p .375 .283 .622 r
F P
0 g
s
.43458 .63215 m .42468 .62163 L .41879 .62761 L p .577 .493 .723 r
F P
0 g
s
.41879 .62761 m .43059 .63747 L .43458 .63215 L p .577 .493 .723 r
F P
0 g
s
.57932 .4699 m .59071 .46356 L .57914 .46825 L p .44 .874 .796 r
F P
0 g
s
.59071 .46356 m .58261 .46807 L p .59017 .46429 L .365 .81 .668 r
F P
0 g
s
.58238 .46831 m .59017 .46429 L p .58261 .46807 L .365 .81 .668 r
F P
0 g
s
.58867 .46569 m .57914 .46825 L .59071 .46356 L p 0 0 0 r
F P
0 g
s
.57914 .46825 m .58353 .46707 L p .5772 .46784 L .234 .751 .763 r
F P
0 g
s
.58353 .46707 m .58867 .46569 L .584 .46656 L p .234 .751 .763 r
F P
0 g
s
.584 .46656 m .5772 .46784 L p .58353 .46707 L .234 .751 .763 r
F P
0 g
s
.58261 .46807 m .57932 .4699 L .58238 .46831 L p .365 .81 .668 r
F P
0 g
s
.44399 .39353 m .46258 .41443 L .47255 .4152 L p .541 .733 .963 r
F P
0 g
s
.46258 .41443 m .44399 .39353 L .43219 .39583 L p .626 .77 .949 r
F P
0 g
s
.61966 .66627 m .62392 .69445 L .62585 .69233 L p .212 .103 .505 r
F P
0 g
s
.62585 .69233 m .62287 .66508 L .61966 .66627 L p .212 .103 .505 r
F P
0 g
s
.37854 .40663 m .40972 .42084 L .40735 .43351 L p .807 .81 .853 r
F P
0 g
s
.40735 .43351 m .37627 .42197 L .37854 .40663 L p .807 .81 .853 r
F P
0 g
s
.45476 .80897 m .44917 .76915 L .45416 .77073 L p .882 .56 .435 r
F P
0 g
s
.45416 .77073 m .45915 .81092 L .45476 .80897 L p .882 .56 .435 r
F P
0 g
s
.60253 .46094 m .58867 .46569 L p .58885 .4655 L 0 0 0 r
F P
0 g
s
.59751 .46058 m .59017 .46429 L .60087 .45867 L p 0 0 0 r
F P
0 g
s
.60448 .45706 m .59751 .46058 L p .60258 .45777 L 0 0 0 r
F P
0 g
s
.60087 .45867 m .60258 .45777 L p .59751 .46058 L 0 0 0 r
F P
0 g
s
.59017 .46429 m .60448 .45706 L .59071 .46356 L p .365 .81 .668 r
F P
0 g
s
.59071 .46356 m .59325 .463 L p .58885 .4655 L 0 0 0 r
F P
0 g
s
.59325 .463 m .60253 .46094 L p .58885 .4655 L 0 0 0 r
F P
0 g
s
.56222 .47583 m .56949 .47045 L .56128 .46973 L p .45 .8 .998 r
F P
0 g
s
.56128 .46973 m .55542 .47525 L .56222 .47583 L p .45 .8 .998 r
F P
0 g
s
.60258 .45777 m .62041 .44957 L .60448 .45706 L p 0 0 0 r
F P
0 g
s
.42877 .61683 m .41137 .60744 L .40595 .61282 L p .626 .59 .794 r
F P
0 g
s
.40595 .61282 m .42468 .62163 L .42877 .61683 L p .626 .59 .794 r
F P
0 g
s
.35408 .53162 m .35865 .51317 L .36588 .52421 L p .979 .756 .53 r
F P
0 g
s
.36588 .52421 m .36161 .5415 L .35408 .53162 L p .979 .756 .53 r
F P
0 g
s
.55542 .47525 m .56128 .46973 L .55386 .46588 L p .351 .65 .967 r
F P
0 g
s
.55386 .46588 m .54918 .47202 L .55542 .47525 L p .351 .65 .967 r
F P
0 g
s
.50328 .43064 m .49733 .41529 L .48438 .406 L p .24 .532 .92 r
F P
0 g
s
.48438 .406 m .49332 .42369 L .50328 .43064 L p .24 .532 .92 r
F P
0 g
s
.60068 .76902 m .59568 .80965 L .59971 .80693 L p .255 .054 .402 r
F P
0 g
s
.59971 .80693 m .60468 .76537 L .60068 .76902 L p .255 .054 .402 r
F P
0 g
s
.45708 .39461 m .47255 .4152 L .48294 .41839 L p .442 .677 .963 r
F P
0 g
s
.47255 .4152 m .45708 .39461 L .44399 .39353 L p .541 .733 .963 r
F P
0 g
s
.78924 .46358 m .82048 .48345 L .81863 .46987 L p .242 .4 .821 r
F P
0 g
s
.81863 .46987 m .78732 .45087 L .78924 .46358 L p .242 .4 .821 r
F P
0 g
s
.63241 .64909 m .62624 .66411 L .62953 .66316 L p .315 .025 .304 r
F P
0 g
s
.62953 .66316 m .63833 .6488 L .63241 .64909 L p .315 .025 .304 r
F P
0 g
s
.43242 .65433 m .43059 .63747 L .42578 .64376 L p .3 .2 .57 r
F P
0 g
s
.42578 .64376 m .42958 .65979 L .43242 .65433 L p .3 .2 .57 r
F P
0 g
s
.42778 .75181 m .42515 .71866 L .42713 .72317 L p .973 .671 .295 r
F P
0 g
s
.42713 .72317 m .43013 .75562 L .42778 .75181 L p .973 .671 .295 r
F P
0 g
s
.41394 .60302 m .39311 .5905 L .39006 .59567 L p .552 .599 .855 r
F P
0 g
s
.39006 .59567 m .41137 .60744 L .41394 .60302 L p .552 .599 .855 r
F P
0 g
s
.49332 .42369 m .48438 .406 L .47077 .3989 L p .338 .607 .948 r
F P
0 g
s
.47077 .3989 m .48294 .41839 L .49332 .42369 L p .338 .607 .948 r
F P
0 g
s
.43752 .62781 m .42877 .61683 L .42468 .62163 L p .517 .464 .737 r
F P
0 g
s
.42468 .62163 m .43458 .63215 L .43752 .62781 L p .517 .464 .737 r
F P
0 g
s
.76908 .59306 m .73962 .61518 L .75449 .60921 L p 0 0 0 r
F P
0 g
s
.75449 .60921 m .78633 .58408 L .76908 .59306 L p 0 0 0 r
F P
0 g
s
.48294 .41839 m .47077 .3989 L .45708 .39461 L p .442 .677 .963 r
F P
0 g
s
.80025 .55495 m .78633 .58408 L .80046 .57375 L p .064 0 .21 r
F P
0 g
s
.80046 .57375 m .81514 .54199 L .80025 .55495 L p .064 0 .21 r
F P
0 g
s
.4242 .69746 m .42385 .67237 L .42144 .67916 L p 0 0 .285 r
F P
0 g
s
.42144 .67916 m .42355 .70295 L .4242 .69746 L p 0 0 .285 r
F P
0 g
s
.61798 .70269 m .62202 .74323 L .62401 .73998 L p .035 0 .457 r
F P
0 g
s
.62401 .73998 m .61994 .69955 L .61798 .70269 L p .035 0 .457 r
F P
0 g
s
.54918 .47202 m .55386 .46588 L .54649 .45895 L p .245 .517 .91 r
F P
0 g
s
.54649 .45895 m .54297 .46621 L .54918 .47202 L p .245 .517 .91 r
F P
0 g
s
.45067 .80682 m .44451 .76722 L .44917 .76915 L p .9 .571 .414 r
F P
0 g
s
.44917 .76915 m .45476 .80897 L .45067 .80682 L p .9 .571 .414 r
F P
0 g
s
.36619 .54967 m .37299 .56469 L p .37034 .5616 L .786 .393 0 r
F P
0 g
s
.37299 .56469 m .37465 .56837 L .37034 .5616 L p .786 .393 0 r
F P
0 g
s
.38899 .58052 m .37034 .5616 L .37465 .56837 L p 0 .185 .699 r
F P
0 g
s
.36161 .5415 m .37034 .5616 L .36323 .55369 L p .899 .502 .079 r
F P
0 g
s
.37034 .5616 m .38751 .57902 L p .38296 .57488 L .556 .048 0 r
F P
0 g
s
.38751 .57902 m .38899 .58052 L .38296 .57488 L p .556 .048 0 r
F P
0 g
s
.38296 .57488 m .36743 .5582 L p .37034 .5616 L .556 .048 0 r
F P
0 g
s
.40662 .59207 m .38296 .57488 L .38899 .58052 L p 0 .224 .67 r
F P
0 g
s
.38296 .57488 m .40662 .59207 L .40104 .5881 L p .428 0 0 r
F P
0 g
s
.36743 .5582 m .36323 .55369 L .37034 .5616 L p .556 .048 0 r
F P
0 g
s
.36323 .55369 m .38296 .57488 L .37549 .5684 L p .648 .142 0 r
F P
0 g
s
.40104 .5881 m .37774 .57014 L p .38296 .57488 L .428 0 0 r
F P
0 g
s
.37774 .57014 m .37549 .5684 L .38296 .57488 L p .428 0 0 r
F P
0 g
s
.68969 .63264 m .65904 .64066 L .66808 .63973 L p .009 0 0 r
F P
0 g
s
.66808 .63973 m .70253 .63032 L .68969 .63264 L p .009 0 0 r
F P
0 g
s
.39262 .5856 m .37465 .56837 L .37533 .5744 L p .216 .432 .856 r
F P
0 g
s
.37533 .5744 m .39311 .5905 L .39262 .5856 L p .216 .432 .856 r
F P
0 g
s
.43089 .61304 m .41394 .60302 L .41137 .60744 L p .555 .604 .857 r
F P
0 g
s
.41137 .60744 m .42877 .61683 L .43089 .61304 L p .555 .604 .857 r
F P
0 g
s
.43496 .64955 m .43458 .63215 L .43059 .63747 L p .189 .088 .501 r
F P
0 g
s
.43059 .63747 m .43242 .65433 L .43496 .64955 L p .189 .088 .501 r
F P
0 g
s
.60468 .76537 m .59971 .80693 L .60343 .80409 L p .199 .012 .388 r
F P
0 g
s
.60343 .80409 m .60832 .76159 L .60468 .76537 L p .199 .012 .388 r
F P
0 g
s
.62287 .66508 m .62585 .69233 L .62764 .69035 L p .192 .071 .476 r
F P
0 g
s
.62764 .69035 m .62624 .66411 L .62287 .66508 L p .192 .071 .476 r
F P
0 g
s
.34042 .48458 m .35948 .47268 L .36752 .48824 L p .925 .798 .701 r
F P
0 g
s
.36752 .48824 m .34972 .49992 L .34042 .48458 L p .925 .798 .701 r
F P
0 g
s
.4393 .62437 m .43089 .61304 L .42877 .61683 L p .391 .41 .76 r
F P
0 g
s
.42877 .61683 m .43752 .62781 L .4393 .62437 L p .391 .41 .76 r
F P
0 g
s
.34751 .4374 m .37722 .43835 L .38079 .45485 L p .871 .816 .792 r
F P
0 g
s
.38079 .45485 m .35242 .4555 L .34751 .4374 L p .871 .816 .792 r
F P
0 g
s
.72635 .43071 m .76725 .43252 L .7501 .42789 L p .206 .688 .932 r
F P
0 g
s
.7501 .42789 m .71217 .42757 L .72635 .43071 L p .206 .688 .932 r
F P
0 g
s
.42525 .6921 m .42665 .66585 L .42385 .67237 L p 0 0 .242 r
F P
0 g
s
.42385 .67237 m .4242 .69746 L .42525 .6921 L p 0 0 .242 r
F P
0 g
s
.65904 .64066 m .63833 .6488 L .64395 .64819 L p .161 0 0 r
F P
0 g
s
.64395 .64819 m .66808 .63973 L .65904 .64066 L p .161 0 0 r
F P
0 g
s
.54297 .46621 m .54649 .45895 L .53843 .4493 L p .154 .424 .864 r
F P
0 g
s
.53843 .4493 m .53625 .45812 L .54297 .46621 L p .154 .424 .864 r
F P
0 g
s
.42515 .71866 m .42778 .75181 L .42596 .74773 L p .958 .676 .238 r
F P
0 g
s
.43707 .64548 m .43752 .62781 L .43458 .63215 L p .036 0 .413 r
F P
0 g
s
.43458 .63215 m .43496 .64955 L .43707 .64548 L p .036 0 .413 r
F P
0 g
s
.44687 .80446 m .44022 .76491 L .44451 .76722 L p .919 .583 .388 r
F P
0 g
s
.44451 .76722 m .45067 .80682 L .44687 .80446 L p .919 .583 .388 r
F P
0 g
s
.38433 .39325 m .4147 .40991 L .40972 .42084 L p .783 .824 .884 r
F P
0 g
s
.40972 .42084 m .37854 .40663 L .38433 .39325 L p .783 .824 .884 r
F P
0 g
s
.61994 .69955 m .62401 .73998 L .62576 .7369 L p .022 0 .448 r
F P
0 g
s
.62576 .7369 m .62193 .69683 L .61994 .69955 L p .022 0 .448 r
F P
0 g
s
.60832 .76159 m .60343 .80409 L .60685 .80114 L p .143 0 .372 r
F P
0 g
s
.60685 .80114 m .61163 .75777 L .60832 .76159 L p .143 0 .372 r
F P
0 g
s
.41375 .59922 m .39262 .5856 L .39311 .5905 L p .366 .578 .923 r
F P
0 g
s
.39311 .5905 m .41394 .60302 L .41375 .59922 L p .366 .578 .923 r
F P
0 g
s
.43108 .61002 m .41375 .59922 L .41394 .60302 L p .372 .583 .924 r
F P
0 g
s
.41394 .60302 m .43089 .61304 L .43108 .61002 L p .372 .583 .924 r
F P
0 g
s
.42658 .68697 m .42958 .65979 L .42665 .66585 L p 0 0 .192 r
F P
0 g
s
.42665 .66585 m .42525 .6921 L .42658 .68697 L p 0 0 .192 r
F P
0 g
s
.43996 .62169 m .43108 .61002 L .43089 .61304 L p .137 .297 .764 r
F P
0 g
s
.43089 .61304 m .4393 .62437 L .43996 .62169 L p .137 .297 .764 r
F P
0 g
s
.63833 .6488 m .62953 .66316 L .63248 .66205 L p .228 0 .189 r
F P
0 g
s
.63248 .66205 m .64395 .64819 L .63833 .6488 L p .228 0 .189 r
F P
0 g
s
.53625 .45812 m .53843 .4493 L .52907 .4375 L p .087 .371 .836 r
F P
0 g
s
.52907 .4375 m .52857 .44825 L .53625 .45812 L p .087 .371 .836 r
F P
0 g
s
.4387 .64209 m .4393 .62437 L .43752 .62781 L p 0 0 .31 r
F P
0 g
s
.43752 .62781 m .43707 .64548 L .4387 .64209 L p 0 0 .31 r
F P
0 g
s
.52034 .85723 m .51886 .82314 L .52484 .82362 L p .67 .325 .381 r
F P
0 g
s
.52484 .82362 m .52515 .85741 L .52034 .85723 L p .67 .325 .381 r
F P
0 g
s
.52515 .85741 m .52484 .82362 L .53085 .82395 L p .651 .308 .379 r
F P
0 g
s
.51555 .8569 m .51292 .82253 L .51886 .82314 L p .688 .341 .381 r
F P
0 g
s
.51886 .82314 m .52034 .85723 L .51555 .8569 L p .688 .341 .381 r
F P
0 g
s
.53085 .82395 m .52997 .85745 L .52515 .85741 L p .651 .308 .379 r
F P
0 g
s
.52997 .85745 m .53085 .82395 L .53686 .82411 L p .631 .29 .375 r
F P
0 g
s
.51081 .85645 m .50703 .82182 L .51292 .82253 L p .705 .355 .381 r
F P
0 g
s
.51292 .82253 m .51555 .8569 L .51081 .85645 L p .705 .355 .381 r
F P
0 g
s
.53686 .82411 m .53477 .85735 L .52997 .85745 L p .631 .29 .375 r
F P
0 g
s
.53477 .85735 m .53686 .82411 L .54285 .82408 L p .609 .27 .371 r
F P
0 g
s
.62624 .66411 m .62764 .69035 L .62917 .68843 L p .141 .012 .431 r
F P
0 g
s
.62917 .68843 m .62953 .66316 L .62624 .66411 L p .141 .012 .431 r
F P
0 g
s
.44342 .80188 m .43637 .7622 L .44022 .76491 L p .935 .594 .358 r
F P
0 g
s
.44022 .76491 m .44687 .80446 L .44342 .80188 L p .935 .594 .358 r
F P
0 g
s
.61163 .75777 m .60685 .80114 L .60997 .79813 L p .086 0 .355 r
F P
0 g
s
.60997 .79813 m .61463 .75396 L .61163 .75777 L p .086 0 .355 r
F P
0 g
s
.34476 .51986 m .34972 .49992 L .35865 .51317 L p .977 .75 .527 r
F P
0 g
s
.35865 .51317 m .35408 .53162 L .34476 .51986 L p .977 .75 .527 r
F P
0 g
s
.50612 .85586 m .50122 .82102 L .50703 .82182 L p .722 .369 .378 r
F P
0 g
s
.50703 .82182 m .51081 .85645 L .50612 .85586 L p .722 .369 .378 r
F P
0 g
s
.54285 .82408 m .53955 .85709 L .53477 .85735 L p .609 .27 .371 r
F P
0 g
s
.53955 .85709 m .54285 .82408 L .5488 .82382 L p .586 .249 .365 r
F P
0 g
s
.73962 .61518 m .70253 .63032 L .7141 .62693 L p 0 0 0 r
F P
0 g
s
.7141 .62693 m .75449 .60921 L .73962 .61518 L p 0 0 0 r
F P
0 g
s
.37465 .56837 m .39262 .5856 L .38899 .58052 L p 0 .185 .699 r
F P
0 g
s
.42809 .68218 m .43242 .65433 L .42958 .65979 L p 0 0 .142 r
F P
0 g
s
.42958 .65979 m .42658 .68697 L .42809 .68218 L p 0 0 .142 r
F P
0 g
s
.62193 .69683 m .62576 .7369 L .62725 .73396 L p 0 0 .433 r
F P
0 g
s
.62725 .73396 m .62392 .69445 L .62193 .69683 L p 0 0 .433 r
F P
0 g
s
.5488 .82382 m .54428 .85668 L .53955 .85709 L p .586 .249 .365 r
F P
0 g
s
.54428 .85668 m .5488 .82382 L .55467 .82331 L p .562 .227 .358 r
F P
0 g
s
.50151 .85515 m .49549 .82014 L .50122 .82102 L p .739 .381 .374 r
F P
0 g
s
.50122 .82102 m .50612 .85586 L .50151 .85515 L p .739 .381 .374 r
F P
0 g
s
.81622 .4981 m .8254 .52828 L .82998 .51443 L p 0 .003 .516 r
F P
0 g
s
.82998 .51443 m .82048 .48345 L .81622 .4981 L p 0 .003 .516 r
F P
0 g
s
.71217 .42757 m .7501 .42789 L .72951 .42657 L p .055 .621 .759 r
F P
0 g
s
.72951 .42657 m .69522 .42747 L .71217 .42757 L p .055 .621 .759 r
F P
0 g
s
.36323 .55369 m .35408 .53162 L .36161 .5415 L p .899 .502 .079 r
F P
0 g
s
.43996 .62169 m .4393 .62437 L p .43967 .63448 L 0 0 .219 r
F P
0 g
s
.43988 .63475 m .43996 .62169 L p .43967 .63448 L 0 0 .219 r
F P
0 g
s
.43108 .61002 m .43996 .62169 L .43966 .6196 L p 0 .119 .669 r
F P
0 g
s
.43996 .62169 m .43985 .63933 L .44062 .63709 L p 0 0 .17 r
F P
0 g
s
.43966 .6196 m .43996 .62169 L p .44059 .63632 L 0 0 .17 r
F P
0 g
s
.44062 .63709 m .44055 .63584 L p .44059 .63632 L 0 0 .17 r
F P
0 g
s
.44055 .63584 m .43966 .6196 L p .44059 .63632 L 0 0 .17 r
F P
0 g
s
.43966 .6196 m .44054 .63562 L p .44116 .63526 L 0 0 .182 r
F P
0 g
s
.43966 .6196 m .42959 .60753 L .43108 .61002 L p 0 .119 .669 r
F P
0 g
s
.42959 .60753 m .43966 .6196 L .43866 .6179 L p 0 0 .535 r
F P
0 g
s
.44116 .63526 m .43875 .61855 L p .43966 .6196 L 0 0 .182 r
F P
0 g
s
.43875 .61855 m .43866 .6179 L .43932 .61903 L p 0 0 .182 r
F P
0 g
s
.43932 .61903 m .43966 .6196 L p .43875 .61855 L 0 0 .182 r
F P
0 g
s
.41375 .59922 m .43108 .61002 L .42959 .60753 L p .027 .448 .872 r
F P
0 g
s
.42959 .60753 m .41111 .59568 L .41375 .59922 L p .027 .448 .872 r
F P
0 g
s
.41111 .59568 m .42959 .60753 L .42685 .60528 L p 0 .26 .693 r
F P
0 g
s
.43866 .6179 m .42685 .60528 L .42959 .60753 L p 0 0 .535 r
F P
0 g
s
.42685 .60528 m .40662 .59207 L .41111 .59568 L p 0 .26 .693 r
F P
0 g
s
.42685 .60528 m .43843 .61766 L p .43732 .6164 L 0 0 .495 r
F P
0 g
s
.43843 .61766 m .43866 .6179 L .43732 .6164 L p 0 0 .495 r
F P
0 g
s
.40662 .59207 m .4259 .60465 L p .42342 .60303 L 0 .168 .593 r
F P
0 g
s
.4259 .60465 m .42685 .60528 L .42342 .60303 L p 0 .168 .593 r
F P
0 g
s
.43732 .6164 m .42342 .60303 L .42685 .60528 L p 0 0 .495 r
F P
0 g
s
.42342 .60303 m .40104 .5881 L .40662 .59207 L p 0 .168 .593 r
F P
0 g
s
.42342 .60303 m .43632 .61544 L p .43606 .61494 L 0 .052 .552 r
F P
0 g
s
.43632 .61544 m .43732 .6164 L .43606 .61494 L p 0 .052 .552 r
F P
0 g
s
.43606 .61494 m .42059 .60118 L p .42342 .60303 L 0 .052 .552 r
F P
0 g
s
.44116 .63526 m .44167 .63369 L p .43956 .62262 L 0 0 .257 r
F P
0 g
s
.43866 .6179 m .43979 .62579 L p .43956 .62262 L 0 0 .257 r
F P
0 g
s
.43979 .62579 m .44116 .63526 L p .43956 .62262 L 0 0 .257 r
F P
0 g
s
.44167 .63369 m .43732 .6164 L .43866 .6179 L p 0 0 .257 r
F P
0 g
s
.44167 .63369 m .44237 .63228 L p .43851 .62013 L 0 0 .381 r
F P
0 g
s
.43732 .6164 m .43796 .61896 L p .43851 .62013 L 0 0 .381 r
F P
0 g
s
.43796 .61896 m .44167 .63369 L p .43851 .62013 L 0 0 .381 r
F P
0 g
s
.44237 .63228 m .43677 .61687 L p .43711 .61716 L 0 0 .381 r
F P
0 g
s
.43773 .61769 m .43851 .62013 L .43711 .61716 L 0 0 .381 r
F
.43851 .62013 m .44237 .63228 L .43711 .61716 L F
.43677 .61687 m .43606 .61494 L p .43773 .61769 L F P
0 g
s
.43606 .61494 m .44237 .63228 L .44351 .63089 L p 0 0 .528 r
F P
0 g
s
.40104 .5881 m .41893 .60004 L p .41992 .60059 L 0 .176 .607 r
F P
0 g
s
.41893 .60004 m .42342 .60303 L .41992 .60059 L p 0 .176 .607 r
F P
0 g
s
.41992 .60059 m .42342 .60303 L p .42068 .60124 L 0 .052 .552 r
F P
0 g
s
.42059 .60118 m .41992 .60059 L p .42068 .60124 L 0 .052 .552 r
F P
0 g
s
.4353 .61336 m .42098 .60118 L p .41992 .60059 L 0 .175 .668 r
F P
0 g
s
.42098 .60118 m .41703 .59782 L .41992 .60059 L p 0 .175 .668 r
F P
0 g
s
.41992 .60059 m .43606 .61494 L .4353 .61336 L p 0 .175 .668 r
F P
0 g
s
.43606 .61494 m .44241 .62855 L .43578 .61438 L 0 0 .528 r
F
.44351 .63089 m .44279 .62937 L p .44241 .62855 L F P
0 g
s
.44279 .62937 m .43578 .61438 L p .44241 .62855 L 0 0 .528 r
F P
0 g
s
.43578 .61438 m .4353 .61336 L .43606 .61494 L p 0 0 .528 r
F P
0 g
s
.43732 .6164 m .43773 .61769 L .43709 .61663 L 0 0 .381 r
F
.43732 .6164 m .43709 .61663 L .43614 .61506 L F
.43606 .61494 m .43732 .6164 L p .43614 .61506 L F P
0 g
s
.44054 .63562 m .44062 .63709 L .44091 .6361 L p 0 0 .182 r
F P
0 g
s
.44091 .6361 m .44116 .63526 L p .44054 .63562 L 0 0 .182 r
F P
0 g
s
.43985 .63933 m .43988 .63475 L p .43967 .63448 L 0 0 .219 r
F P
0 g
s
.4393 .62437 m .4387 .64209 L .43985 .63933 L p 0 0 .219 r
F P
0 g
s
.55467 .82331 m .54895 .8561 L .54428 .85668 L p .562 .227 .358 r
F P
0 g
s
.54895 .8561 m .55467 .82331 L .56044 .82254 L p .535 .202 .351 r
F P
0 g
s
.49699 .85432 m .48985 .81917 L .49549 .82014 L p .755 .393 .368 r
F P
0 g
s
.49549 .82014 m .50151 .85515 L .49699 .85432 L p .755 .393 .368 r
F P
0 g
s
.52857 .44825 m .52907 .4375 L .51794 .42436 L p .047 .354 .828 r
F P
0 g
s
.51794 .42436 m .51958 .43727 L .52857 .44825 L p .047 .354 .828 r
F P
0 g
s
.78732 .45087 m .81863 .46987 L .81051 .45817 L p .017 .365 .835 r
F P
0 g
s
.81051 .45817 m .77989 .44031 L .78732 .45087 L p .017 .365 .835 r
F P
0 g
s
.39364 .38269 m .42228 .4014 L .4147 .40991 L p .746 .832 .917 r
F P
0 g
s
.4147 .40991 m .38433 .39325 L .39364 .38269 L p .746 .832 .917 r
F P
0 g
s
.42968 .6778 m .43496 .64955 L .43242 .65433 L p 0 0 .099 r
F P
0 g
s
.43242 .65433 m .42809 .68218 L .42968 .6778 L p 0 0 .099 r
F P
0 g
s
.61463 .75396 m .60997 .79813 L .61278 .79508 L p .029 0 .336 r
F P
0 g
s
.61278 .79508 m .61735 .75024 L .61463 .75396 L p .029 0 .336 r
F P
0 g
s
.39262 .5856 m .41375 .59922 L .41111 .59568 L p .007 .431 .863 r
F P
0 g
s
.41111 .59568 m .38899 .58052 L .39262 .5856 L p .007 .431 .863 r
F P
0 g
s
.56044 .82254 m .55353 .85536 L .54895 .8561 L p .535 .202 .351 r
F P
0 g
s
.55353 .85536 m .56044 .82254 L .56609 .82149 L p .507 .176 .341 r
F P
0 g
s
.44032 .79909 m .433 .7591 L .43637 .7622 L p .949 .604 .32 r
F P
0 g
s
.43637 .7622 m .44342 .80188 L .44032 .79909 L p .949 .604 .32 r
F P
0 g
s
.49258 .85336 m .48433 .81811 L .48985 .81917 L p .771 .403 .36 r
F P
0 g
s
.48985 .81917 m .49699 .85432 L .49258 .85336 L p .771 .403 .36 r
F P
0 g
s
.66808 .63973 m .64756 .64693 L p .6488 .64705 L 0 0 0 r
F P
0 g
s
.64756 .64693 m .64395 .64819 L .6488 .64705 L p 0 0 0 r
F P
0 g
s
.63483 .66062 m .6488 .64705 L .64395 .64819 L p .063 0 0 r
F P
0 g
s
.63483 .66062 m .63631 .65876 L p .63646 .65896 L 0 0 0 r
F P
0 g
s
.63976 .65583 m .63483 .66062 L p .64104 .65433 L 0 0 0 r
F P
0 g
s
.64395 .64819 m .63248 .66205 L .63483 .66062 L p .063 0 0 r
F P
0 g
s
.63032 .68644 m .63248 .66205 L .62953 .66316 L p .044 0 .361 r
F P
0 g
s
.62937 .72839 m .62764 .69035 L .62585 .69233 L p 0 0 .369 r
F P
0 g
s
.62937 .72839 m .62991 .72567 L p .62933 .7166 L 0 0 .31 r
F P
0 g
s
.62764 .69035 m .62909 .72219 L p .62933 .7166 L 0 0 .31 r
F P
0 g
s
.62909 .72219 m .62937 .72839 L p .62933 .7166 L 0 0 .31 r
F P
0 g
s
.62991 .72567 m .62917 .68843 L .62764 .69035 L p 0 0 .31 r
F P
0 g
s
.62991 .72567 m .63003 .72294 L p .62968 .7088 L 0 0 .222 r
F P
0 g
s
.62917 .68843 m .62962 .71112 L p .62968 .7088 L 0 0 .222 r
F P
0 g
s
.62962 .71112 m .62991 .72567 L p .62968 .7088 L 0 0 .222 r
F P
0 g
s
.63003 .72294 m .63032 .68644 L .62917 .68843 L p 0 0 .222 r
F P
0 g
s
.62885 .71727 m .62962 .70433 L p .62991 .70001 L .743 .634 .072 r
F P
0 g
s
.63003 .72294 m .6297 .72015 L p .63006 .70066 L 0 0 .094 r
F P
0 g
s
.63032 .68644 m .63022 .69883 L p .63006 .70066 L 0 0 .094 r
F P
0 g
s
.63022 .69883 m .63003 .72294 L p .63006 .70066 L 0 0 .094 r
F P
0 g
s
.6297 .72015 m .63095 .68429 L .63032 .68644 L p 0 0 .094 r
F P
0 g
s
.62957 .70608 m .63024 .695 L .63018 .69637 L .743 .634 .072 r
F
.62885 .71727 m .62952 .7066 L .62957 .70608 L F
.62952 .7066 m .63024 .695 L .62957 .70608 L F
.6299 .70057 m .62991 .70001 L .63024 .695 L F
.62885 .71727 m .62991 .70001 L .6299 .70057 L F
.63018 .69637 m .63024 .695 L .63095 .68429 L F
.63032 .68644 m .63095 .68429 L p .63142 .67719 L 0 0 .245 r
F P
0 g
s
.62962 .70433 m .63096 .68191 L .63095 .68429 L p .743 .634 .072 r
F P
0 g
s
.63095 .68429 m .63146 .67688 L .63142 .67719 L 0 0 .245 r
F
.63248 .66205 m .63096 .67916 L p .63146 .67688 L F P
0 g
s
.63096 .67916 m .63032 .68644 L p .63146 .67688 L 0 0 .245 r
F P
0 g
s
.63095 .68429 m .63483 .66062 L .63248 .66205 L p 0 0 .245 r
F P
0 g
s
.63095 .68429 m .63096 .68191 L p .63167 .678 L 0 0 .046 r
F P
0 g
s
.63483 .66062 m .63103 .6838 L p .63167 .678 L 0 0 .046 r
F P
0 g
s
.63103 .6838 m .63095 .68429 L p .63167 .678 L 0 0 .046 r
F P
0 g
s
.63096 .68191 m .63631 .65876 L .63483 .66062 L p 0 0 .046 r
F P
0 g
s
.63592 .65349 m .63673 .65639 L p .63302 .66557 L .961 .886 .498 r
F P
0 g
s
.62953 .66316 m .62917 .68843 L .63032 .68644 L p .044 0 .361 r
F P
0 g
s
.6287 .67629 m .63351 .66109 L p .63302 .66557 L .961 .886 .498 r
F P
0 g
s
.63351 .66109 m .63592 .65349 L p .63302 .66557 L .961 .886 .498 r
F P
0 g
s
.63294 .6701 m .63613 .65851 L .63631 .65876 L .743 .755 .245 r
F
.63023 .67926 m .63333 .66836 L p .63294 .6701 L F P
0 g
s
.63333 .66836 m .63613 .65851 L p .63294 .6701 L .743 .755 .245 r
F P
0 g
s
.63613 .65851 m .63673 .65639 L .63631 .65876 L p .743 .755 .245 r
F P
0 g
s
.63631 .65876 m .64104 .65433 L .63646 .65896 L 0 0 0 r
F
.6488 .64705 m .63976 .65583 L p .64104 .65433 L F P
0 g
s
.63631 .65876 m .6501 .64718 L p .6488 .64705 L 0 0 0 r
F P
0 g
s
.6488 .64705 m .67612 .638 L .66808 .63973 L p 0 0 0 r
F P
0 g
s
.67612 .638 m .65326 .64557 L p .65243 .64523 L .323 .807 .772 r
F P
0 g
s
.65326 .64557 m .6488 .64705 L .65243 .64523 L p .323 .807 .772 r
F P
0 g
s
.65243 .64523 m .6488 .64705 L p .65 .64717 L 0 0 0 r
F P
0 g
s
.6501 .64718 m .65243 .64523 L p .65 .64717 L 0 0 0 r
F P
0 g
s
.64321 .65178 m .65167 .64491 L .65243 .64523 L .603 .931 .716 r
F
.65445 .64264 m .65243 .64523 L p .65167 .64491 L F P
0 g
s
.63673 .65639 m .64426 .65055 L p .64321 .65178 L .603 .931 .716 r
F P
0 g
s
.64426 .65055 m .65445 .64264 L p .64321 .65178 L .603 .931 .716 r
F P
0 g
s
.65243 .64523 m .65931 .64296 L p .67612 .638 L .323 .807 .772 r
F P
0 g
s
.69714 .63179 m .66808 .63973 L .67612 .638 L p .201 .718 .682 r
F P
0 g
s
.65931 .64296 m .68245 .63533 L .67612 .638 L p .323 .807 .772 r
F P
0 g
s
.70253 .63032 m .69714 .63179 L p .67612 .638 L .201 .718 .682 r
F P
0 g
s
.67612 .638 m .7141 .62693 L .70253 .63032 L p .201 .718 .682 r
F P
0 g
s
.34578 .41926 m .37627 .42197 L .37722 .43835 L p .868 .844 .819 r
F P
0 g
s
.37722 .43835 m .34751 .4374 L .34578 .41926 L p .868 .844 .819 r
F P
0 g
s
.62392 .69445 m .62725 .73396 L .62847 .73114 L p 0 0 .408 r
F P
0 g
s
.62847 .73114 m .62585 .69233 L .62392 .69445 L p 0 0 .408 r
F P
0 g
s
.56609 .82149 m .55801 .85446 L .55353 .85536 L p .507 .176 .341 r
F P
0 g
s
.55801 .85446 m .56609 .82149 L .57157 .82016 L p .475 .148 .331 r
F P
0 g
s
.4883 .85228 m .47894 .81694 L .48433 .81811 L p .787 .413 .349 r
F P
0 g
s
.48433 .81811 m .49258 .85336 L .4883 .85228 L p .787 .413 .349 r
F P
0 g
s
.33215 .46753 m .35242 .4555 L .35948 .47268 L p .936 .822 .708 r
F P
0 g
s
.35948 .47268 m .34042 .48458 L .33215 .46753 L p .936 .822 .708 r
F P
0 g
s
.78633 .58408 m .75449 .60921 L .7666 .60193 L p 0 0 0 r
F P
0 g
s
.7666 .60193 m .80046 .57375 L .78633 .58408 L p 0 0 0 r
F P
0 g
s
.43129 .67386 m .43707 .64548 L .43496 .64955 L p 0 0 .069 r
F P
0 g
s
.43496 .64955 m .42968 .6778 L .43129 .67386 L p 0 0 .069 r
F P
0 g
s
.81514 .54199 m .80046 .57375 L .81019 .56242 L p 0 0 0 r
F P
0 g
s
.81019 .56242 m .8254 .52828 L .81514 .54199 L p 0 0 0 r
F P
0 g
s
.69522 .42747 m .72951 .42657 L .70674 .42838 L p .05 0 0 r
F P
0 g
s
.70674 .42838 m .67653 .43018 L .69522 .42747 L p .05 0 0 r
F P
0 g
s
.5772 .46784 m .56949 .47045 L .57914 .46825 L p .234 .751 .763 r
F P
0 g
s
.56949 .47045 m .5772 .46784 L .56752 .4669 L p .237 .723 .927 r
F P
0 g
s
.56752 .4669 m .56128 .46973 L .56949 .47045 L p .237 .723 .927 r
F P
0 g
s
.51958 .43727 m .51794 .42436 L .50483 .41085 L p .039 .37 .838 r
F P
0 g
s
.50483 .41085 m .50915 .426 L .51958 .43727 L p .039 .37 .838 r
F P
0 g
s
.57157 .82016 m .56236 .8534 L .56658 .85218 L p .439 .115 .318 r
F P
0 g
s
.56658 .85218 m .57687 .81856 L .57157 .82016 L p .439 .115 .318 r
F P
0 g
s
.57157 .82016 m .56236 .8534 L .55801 .85446 L p .475 .148 .331 r
F P
0 g
s
.61735 .75024 m .61278 .79508 L .61527 .79202 L p 0 0 .314 r
F P
0 g
s
.61527 .79202 m .6198 .74666 L .61735 .75024 L p 0 0 .314 r
F P
0 g
s
.48416 .85108 m .47371 .81566 L .47894 .81694 L p .802 .422 .336 r
F P
0 g
s
.47894 .81694 m .4883 .85228 L .48416 .85108 L p .802 .422 .336 r
F P
0 g
s
.4376 .79611 m .43013 .75562 L .433 .7591 L p .956 .611 .276 r
F P
0 g
s
.433 .7591 m .44032 .79909 L .4376 .79611 L p .956 .611 .276 r
F P
0 g
s
.60253 .46094 m .59071 .46356 L .60448 .45706 L p 0 0 0 r
F P
0 g
s
.56128 .46973 m .56752 .4669 L .55881 .46261 L p .142 .565 .927 r
F P
0 g
s
.55881 .46261 m .55386 .46588 L .56128 .46973 L p .142 .565 .927 r
F P
0 g
s
.40613 .37564 m .43219 .39583 L .42228 .4014 L p .691 .828 .949 r
F P
0 g
s
.42228 .4014 m .39364 .38269 L .40613 .37564 L p .691 .828 .949 r
F P
0 g
s
.57687 .81856 m .56658 .85218 L .57063 .85081 L p .395 .076 .302 r
F P
0 g
s
.57063 .85081 m .58195 .81668 L .57687 .81856 L p .395 .076 .302 r
F P
0 g
s
.43288 .67038 m .4387 .64209 L .43707 .64548 L p 0 0 .058 r
F P
0 g
s
.43707 .64548 m .43129 .67386 L .43288 .67038 L p 0 0 .058 r
F P
0 g
s
.61912 .45434 m .60448 .45706 L .62041 .44957 L p .016 0 0 r
F P
0 g
s
.60448 .45706 m .61912 .45434 L .60253 .46094 L p 0 0 0 r
F P
0 g
s
.48017 .84975 m .46865 .81424 L .47371 .81566 L p .818 .43 .319 r
F P
0 g
s
.47371 .81566 m .48416 .85108 L .48017 .84975 L p .818 .43 .319 r
F P
0 g
s
.42352 .73012 m .42525 .6921 L .4242 .69746 L p .717 .595 .022 r
F P
0 g
s
.67653 .43018 m .70674 .42838 L .68315 .43287 L p .096 0 0 r
F P
0 g
s
.68315 .43287 m .65718 .43525 L .67653 .43018 L p .096 0 0 r
F P
0 g
s
.62585 .69233 m .62847 .73114 L .62937 .72839 L p 0 0 .369 r
F P
0 g
s
.55386 .46588 m .55881 .46261 L .55016 .45504 L p .015 .398 .852 r
F P
0 g
s
.55016 .45504 m .54649 .45895 L .55386 .46588 L p .015 .398 .852 r
F P
0 g
s
.63841 .4468 m .62041 .44957 L .63818 .44199 L p .068 0 0 r
F P
0 g
s
.62041 .44957 m .63841 .4468 L .61912 .45434 L p .016 0 0 r
F P
0 g
s
.6198 .74666 m .61527 .79202 L .61745 .78896 L p 0 0 .288 r
F P
0 g
s
.61745 .78896 m .62202 .74323 L .6198 .74666 L p 0 0 .288 r
F P
0 g
s
.38899 .58052 m .41111 .59568 L .40662 .59207 L p 0 .224 .67 r
F P
0 g
s
.50915 .426 m .50483 .41085 L .4898 .39802 L p .068 .417 .865 r
F P
0 g
s
.4898 .39802 m .49733 .41529 L .50915 .426 L p .068 .417 .865 r
F P
0 g
s
.58195 .81668 m .57063 .85081 L .57451 .84928 L p .346 .032 .283 r
F P
0 g
s
.57451 .84928 m .58679 .81455 L .58195 .81668 L p .346 .032 .283 r
F P
0 g
s
.65718 .43525 m .68315 .43287 L .66001 .43931 L p .097 0 0 r
F P
0 g
s
.66001 .43931 m .63818 .44199 L .65718 .43525 L p .097 0 0 r
F P
0 g
s
.43526 .79296 m .42778 .75181 L .43013 .75562 L p .953 .613 .222 r
F P
0 g
s
.43013 .75562 m .4376 .79611 L .43526 .79296 L p .953 .613 .222 r
F P
0 g
s
.63818 .44199 m .66001 .43931 L .63841 .4468 L p .068 0 0 r
F P
0 g
s
.47636 .8483 m .46378 .81267 L .46865 .81424 L p .833 .437 .298 r
F P
0 g
s
.46865 .81424 m .48017 .84975 L .47636 .8483 L p .833 .437 .298 r
F P
0 g
s
.33502 .50622 m .34042 .48458 L .34972 .49992 L p .985 .761 .517 r
F P
0 g
s
.34972 .49992 m .34476 .51986 L .33502 .50622 L p .985 .761 .517 r
F P
0 g
s
.43447 .66733 m .43985 .63933 L .4387 .64209 L p 0 0 .069 r
F P
0 g
s
.4387 .64209 m .43288 .67038 L .43447 .66733 L p 0 0 .069 r
F P
0 g
s
.42394 .72578 m .42658 .68697 L .42525 .6921 L p 0 0 .02 r
F P
0 g
s
.35442 .54439 m .34476 .51986 L .35408 .53162 L p .918 .53 .132 r
F P
0 g
s
.35408 .53162 m .36323 .55369 L .35442 .54439 L p .918 .53 .132 r
F P
0 g
s
.40613 .37564 m .43219 .39583 L .44399 .39353 L p .61 .806 .975 r
F P
0 g
s
.58679 .81455 m .57451 .84928 L .57821 .84763 L p .292 0 .261 r
F P
0 g
s
.57821 .84763 m .59138 .8122 L .58679 .81455 L p .292 0 .261 r
F P
0 g
s
.75449 .60921 m .7141 .62693 L .72341 .62238 L p .471 .89 .797 r
F P
0 g
s
.72341 .62238 m .7666 .60193 L .75449 .60921 L p .471 .89 .797 r
F P
0 g
s
.77989 .44031 m .81051 .45817 L .79643 .44901 L p 0 .24 .655 r
F P
0 g
s
.79643 .44901 m .76725 .43252 L .77989 .44031 L p 0 .24 .655 r
F P
0 g
s
.7141 .62693 m .67612 .638 L .68245 .63533 L p .43 .872 .874 r
F P
0 g
s
.49733 .41529 m .4898 .39802 L .47321 .38693 L p .136 .492 .904 r
F P
0 g
s
.47321 .38693 m .48438 .406 L .49733 .41529 L p .136 .492 .904 r
F P
0 g
s
.54649 .45895 m .55016 .45504 L .54068 .44452 L p 0 .272 .775 r
F P
0 g
s
.53843 .4493 m .54649 .45895 L p .54121 .44583 L 0 .272 .775 r
F P
0 g
s
.55284 .46027 m .54232 .44987 L p .54936 .45451 L .702 .219 0 r
F P
0 g
s
.55016 .45504 m .55053 .45575 L p .54936 .45451 L .702 .219 0 r
F P
0 g
s
.55053 .45575 m .55284 .46027 L p .54936 .45451 L .702 .219 0 r
F P
0 g
s
.54068 .44452 m .54045 .44502 L p .54121 .44583 L 0 .272 .775 r
F P
0 g
s
.54045 .44502 m .53843 .4493 L p .54121 .44583 L 0 .272 .775 r
F P
0 g
s
.62202 .74323 m .61745 .78896 L .6193 .78593 L p 0 0 .257 r
F P
0 g
s
.6193 .78593 m .62401 .73998 L .62202 .74323 L p 0 0 .257 r
F P
0 g
s
.47275 .84673 m .45915 .81092 L .46378 .81267 L p .847 .442 .274 r
F P
0 g
s
.46378 .81267 m .47636 .8483 L .47275 .84673 L p .847 .442 .274 r
F P
0 g
s
.34801 .40207 m .37854 .40663 L .37627 .42197 L p .855 .874 .853 r
F P
0 g
s
.37627 .42197 m .34578 .41926 L .34801 .40207 L p .855 .874 .853 r
F P
0 g
s
.43333 .78965 m .42596 .74773 L .42778 .75181 L p .934 .607 .16 r
F P
0 g
s
.42778 .75181 m .43526 .79296 L .43333 .78965 L p .934 .607 .16 r
F P
0 g
s
.68245 .63533 m .72341 .62238 L .7141 .62693 L p .43 .872 .874 r
F P
0 g
s
.82048 .48345 m .82998 .51443 L .82819 .50119 L p 0 0 .33 r
F P
0 g
s
.82819 .50119 m .81863 .46987 L .82048 .48345 L p 0 0 .33 r
F P
0 g
s
.59138 .8122 m .57821 .84763 L .5817 .84584 L p .232 0 .235 r
F P
0 g
s
.5817 .84584 m .59568 .80965 L .59138 .8122 L p .232 0 .235 r
F P
0 g
s
.4247 .72159 m .42809 .68218 L .42658 .68697 L p 0 0 .059 r
F P
0 g
s
.42658 .68697 m .42394 .72578 L .4247 .72159 L p 0 0 .059 r
F P
0 g
s
.4212 .37255 m .44399 .39353 L .45708 .39461 L p .497 .755 .988 r
F P
0 g
s
.44399 .39353 m .4212 .37255 L .40613 .37564 L p .61 .806 .975 r
F P
0 g
s
.43608 .66467 m .44062 .63709 L .43985 .63933 L p 0 0 .101 r
F P
0 g
s
.43985 .63933 m .43447 .66733 L .43608 .66467 L p 0 0 .101 r
F P
0 g
s
.48438 .406 m .47321 .38693 L .45568 .37853 L p .24 .584 .945 r
F P
0 g
s
.45568 .37853 m .47077 .3989 L .48438 .406 L p .24 .584 .945 r
F P
0 g
s
.46934 .84503 m .45476 .80897 L .45915 .81092 L p .86 .447 .243 r
F P
0 g
s
.45915 .81092 m .47275 .84673 L .46934 .84503 L p .86 .447 .243 r
F P
0 g
s
.32627 .44941 m .34751 .4374 L .35242 .4555 L p .946 .858 .722 r
F P
0 g
s
.35242 .4555 m .33215 .46753 L .32627 .44941 L p .946 .858 .722 r
F P
0 g
s
.43803 .37357 m .45708 .39461 L .47077 .3989 L p .367 .678 .977 r
F P
0 g
s
.45708 .39461 m .43803 .37357 L .4212 .37255 L p .497 .755 .988 r
F P
0 g
s
.47077 .3989 m .45568 .37853 L .43803 .37357 L p .367 .678 .977 r
F P
0 g
s
.62401 .73998 m .6193 .78593 L .62082 .78291 L p 0 0 .219 r
F P
0 g
s
.62082 .78291 m .62576 .7369 L .62401 .73998 L p 0 0 .219 r
F P
0 g
s
.59568 .80965 m .5817 .84584 L .58497 .84394 L p .166 0 .204 r
F P
0 g
s
.58497 .84394 m .59971 .80693 L .59568 .80965 L p .166 0 .204 r
F P
0 g
s
.43179 .78623 m .42465 .74344 L .42596 .74773 L p .895 .59 .089 r
F P
0 g
s
.42596 .74773 m .43333 .78965 L .43179 .78623 L p .895 .59 .089 r
F P
0 g
s
.42575 .7176 m .42968 .6778 L .42809 .68218 L p 0 0 .098 r
F P
0 g
s
.42809 .68218 m .4247 .72159 L .42575 .7176 L p 0 0 .098 r
F P
0 g
s
.53843 .4493 m .54068 .44452 L .52958 .43167 L p 0 .189 .714 r
F P
0 g
s
.52907 .4375 m .53843 .4493 L p .53051 .43352 L 0 .189 .714 r
F P
0 g
s
.54232 .44987 m .52995 .43721 L p .53942 .44366 L .754 .283 0 r
F P
0 g
s
.54068 .44452 m .54095 .4454 L p .53942 .44366 L .754 .283 0 r
F P
0 g
s
.54095 .4454 m .54232 .44987 L p .53942 .44366 L .754 .283 0 r
F P
0 g
s
.52958 .43167 m .52952 .43239 L p .53051 .43352 L 0 .189 .714 r
F P
0 g
s
.52952 .43239 m .52907 .4375 L p .53051 .43352 L 0 .189 .714 r
F P
0 g
s
.46615 .84321 m .45067 .80682 L .45476 .80897 L p .871 .449 .207 r
F P
0 g
s
.45476 .80897 m .46934 .84503 L .46615 .84321 L p .871 .449 .207 r
F P
0 g
s
.80046 .57375 m .7666 .60193 L .77484 .59352 L p .667 .952 .714 r
F P
0 g
s
.77484 .59352 m .81019 .56242 L .80046 .57375 L p .667 .952 .714 r
F P
0 g
s
.37549 .5684 m .35442 .54439 L .36323 .55369 L p .648 .142 0 r
F P
0 g
s
.4378 .66234 m .44116 .63526 L .44062 .63709 L p 0 0 .154 r
F P
0 g
s
.44062 .63709 m .43608 .66467 L .4378 .66234 L p 0 0 .154 r
F P
0 g
s
.59971 .80693 m .58497 .84394 L .58801 .84194 L p .094 0 .17 r
F P
0 g
s
.58801 .84194 m .60343 .80409 L .59971 .80693 L p .094 0 .17 r
F P
0 g
s
.68245 .63533 m .65243 .64523 L .65445 .64264 L p .548 .917 .946 r
F P
0 g
s
.65243 .64523 m .63631 .65876 L .63673 .65639 L p .603 .931 .716 r
F P
0 g
s
.8254 .52828 m .81019 .56242 L .81448 .55056 L p .76 .833 .373 r
F P
0 g
s
.81448 .55056 m .82998 .51443 L .8254 .52828 L p .76 .833 .373 r
F P
0 g
s
.62576 .7369 m .62082 .78291 L .62201 .77993 L p 0 0 .17 r
F P
0 g
s
.62201 .77993 m .62725 .73396 L .62576 .7369 L p 0 0 .17 r
F P
0 g
s
.76725 .43252 m .79643 .44901 L .7772 .44289 L p .515 0 0 r
F P
0 g
s
.7772 .44289 m .7501 .42789 L .76725 .43252 L p .515 0 0 r
F P
0 g
s
.42708 .71385 m .43129 .67386 L .42968 .6778 L p 0 0 .139 r
F P
0 g
s
.42968 .6778 m .42575 .7176 L .42708 .71385 L p 0 0 .139 r
F P
0 g
s
.43066 .78272 m .42521 .74786 L p .42465 .74344 L .834 .559 .012 r
F P
0 g
s
.42465 .74344 m .43179 .78623 L .43066 .78272 L p .834 .559 .012 r
F P
0 g
s
.42383 .73902 m .43066 .78272 L .42992 .77917 L p .749 .513 0 r
F P
0 g
s
.42347 .73456 m .42917 .77395 L p .42958 .7756 L 0 0 .142 r
F P
0 g
s
.42917 .77395 m .42992 .77917 L .42986 .77851 L p 0 0 .142 r
F P
0 g
s
.42986 .77851 m .42958 .7756 L p .42917 .77395 L 0 0 .142 r
F P
0 g
s
.42521 .74786 m .42383 .73902 L .42406 .74024 L p .834 .559 .012 r
F P
0 g
s
.42406 .74024 m .42465 .74344 L p .42521 .74786 L .834 .559 .012 r
F P
0 g
s
.4632 .84127 m .44687 .80446 L .45067 .80682 L p .878 .448 .163 r
F P
0 g
s
.45067 .80682 m .46615 .84321 L .4632 .84127 L p .878 .448 .163 r
F P
0 g
s
.72341 .62238 m .68245 .63533 L .68646 .63168 L p .597 .923 .968 r
F P
0 g
s
.65445 .64264 m .68646 .63168 L .68245 .63533 L p .548 .917 .946 r
F P
0 g
s
.60343 .80409 m .58801 .84194 L .59081 .83984 L p .015 0 .13 r
F P
0 g
s
.59081 .83984 m .60685 .80114 L .60343 .80409 L p .015 0 .13 r
F P
0 g
s
.3546 .38688 m .38433 .39325 L .37854 .40663 L p .826 .902 .893 r
F P
0 g
s
.37854 .40663 m .34801 .40207 L .3546 .38688 L p .826 .902 .893 r
F P
0 g
s
.63631 .65876 m .63096 .68191 L .63023 .67926 L p .743 .755 .245 r
F P
0 g
s
.32631 .49098 m .33215 .46753 L .34042 .48458 L p .996 .784 .498 r
F P
0 g
s
.34042 .48458 m .33502 .50622 L .32631 .49098 L p .996 .784 .498 r
F P
0 g
s
.52907 .4375 m .52958 .43167 L .51628 .41738 L p 0 .146 .672 r
F P
0 g
s
.51794 .42436 m .52907 .4375 L p .51766 .41956 L 0 .146 .672 r
F P
0 g
s
.52995 .43721 m .51509 .42316 L p .52779 .43062 L .79 .317 0 r
F P
0 g
s
.52958 .43167 m .52965 .43265 L p .52779 .43062 L .79 .317 0 r
F P
0 g
s
.52965 .43265 m .52995 .43721 L p .52779 .43062 L .79 .317 0 r
F P
0 g
s
.51628 .41738 m .51649 .41828 L p .51766 .41956 L 0 .146 .672 r
F P
0 g
s
.51649 .41828 m .51794 .42436 L p .51766 .41956 L 0 .146 .672 r
F P
0 g
s
.34521 .5336 m .33502 .50622 L .34476 .51986 L p .913 .532 .107 r
F P
0 g
s
.34476 .51986 m .35442 .54439 L .34521 .5336 L p .913 .532 .107 r
F P
0 g
s
.58282 .47336 m .5772 .46784 L .58867 .46569 L p .376 0 0 r
F P
0 g
s
.5772 .46784 m .58282 .47336 L .57206 .47219 L p .465 0 0 r
F P
0 g
s
.57206 .47219 m .56752 .4669 L .5772 .46784 L p .465 0 0 r
F P
0 g
s
.42867 .71036 m .43288 .67038 L .43129 .67386 L p 0 0 .181 r
F P
0 g
s
.43129 .67386 m .42708 .71385 L .42867 .71036 L p 0 0 .181 r
F P
0 g
s
.43971 .66026 m .44167 .63369 L .44116 .63526 L p 0 0 .225 r
F P
0 g
s
.44116 .63526 m .4378 .66234 L .43971 .66026 L p 0 0 .225 r
F P
0 g
s
.4605 .83922 m .44342 .80188 L .44687 .80446 L p .879 .442 .111 r
F P
0 g
s
.44687 .80446 m .4632 .84127 L .4605 .83922 L p .879 .442 .111 r
F P
0 g
s
.42992 .77917 m .42347 .73456 L .42383 .73902 L p .749 .513 0 r
F P
0 g
s
.5956 .47159 m .58867 .46569 L .60253 .46094 L p .348 0 .088 r
F P
0 g
s
.58867 .46569 m .5956 .47159 L .58282 .47336 L p .376 0 0 r
F P
0 g
s
.6233 .77402 m .62937 .72839 L .62847 .73114 L p 0 0 .028 r
F P
0 g
s
.62201 .77993 m .62284 .77697 L p .62442 .76157 L 0 0 .107 r
F P
0 g
s
.62284 .77697 m .62847 .73114 L .62725 .73396 L p 0 0 .107 r
F P
0 g
s
.62284 .77697 m .6233 .77402 L p .62625 .74959 L 0 0 .028 r
F P
0 g
s
.62847 .73114 m .6263 .74882 L p .62625 .74959 L 0 0 .028 r
F P
0 g
s
.6263 .74882 m .62284 .77697 L p .62625 .74959 L 0 0 .028 r
F P
0 g
s
.62937 .72839 m .62832 .73633 L p .62769 .74038 L 0 0 0 r
F P
0 g
s
.62832 .73633 m .6233 .77402 L p .62769 .74038 L 0 0 0 r
F P
0 g
s
.6233 .77402 m .62338 .77109 L p .62769 .74038 L 0 0 0 r
F P
0 g
s
.62611 .75163 m .62922 .73046 L .62769 .74038 L 0 0 0 r
F
.62338 .77109 m .62606 .75249 L p .62611 .75163 L F P
0 g
s
.62606 .75249 m .62922 .73046 L p .62611 .75163 L 0 0 0 r
F P
0 g
s
.62991 .72567 m .62937 .72839 L p .62769 .74038 L 0 0 0 r
F P
0 g
s
.62922 .73046 m .62991 .72567 L p .62769 .74038 L 0 0 0 r
F P
0 g
s
.62725 .73396 m .62321 .76942 L p .62442 .76157 L 0 0 .107 r
F P
0 g
s
.62321 .76942 m .62201 .77993 L p .62442 .76157 L 0 0 .107 r
F P
0 g
s
.7666 .60193 m .72341 .62238 L .7296 .61672 L p .666 .966 .925 r
F P
0 g
s
.7296 .61672 m .77484 .59352 L .7666 .60193 L p .666 .966 .925 r
F P
0 g
s
.68646 .63168 m .7296 .61672 L .72341 .62238 L p .597 .923 .968 r
F P
0 g
s
.56752 .4669 m .57206 .47219 L .56241 .46782 L p .572 0 0 r
F P
0 g
s
.56241 .46782 m .55881 .46261 L .56752 .4669 L p .572 0 0 r
F P
0 g
s
.60685 .80114 m .59081 .83984 L .59335 .83767 L p 0 0 .084 r
F P
0 g
s
.59335 .83767 m .60997 .79813 L .60685 .80114 L p 0 0 .084 r
F P
0 g
s
.81863 .46987 m .82819 .50119 L .81987 .48931 L p .897 .518 .067 r
F P
0 g
s
.81987 .48931 m .81051 .45817 L .81863 .46987 L p .897 .518 .067 r
F P
0 g
s
.61109 .4674 m .60253 .46094 L .61912 .45434 L p .359 0 .155 r
F P
0 g
s
.60253 .46094 m .61109 .4674 L .5956 .47159 L p .348 0 .088 r
F P
0 g
s
.68646 .63168 m .65445 .64264 L .65459 .63931 L p .658 .902 .981 r
F P
0 g
s
.65445 .64264 m .63673 .65639 L .63592 .65349 L p .798 .986 .892 r
F P
0 g
s
.63592 .65349 m .65459 .63931 L .65445 .64264 L p .798 .986 .892 r
F P
0 g
s
.7501 .42789 m .7772 .44289 L .75402 .44002 L p .55 .024 0 r
F P
0 g
s
.75402 .44002 m .72951 .42657 L .7501 .42789 L p .55 .024 0 r
F P
0 g
s
.45807 .83707 m .44032 .79909 L .44342 .80188 L p .871 .432 .05 r
F P
0 g
s
.44342 .80188 m .4605 .83922 L .45807 .83707 L p .871 .432 .05 r
F P
0 g
s
.43052 .70711 m .43447 .66733 L .43288 .67038 L p 0 0 .226 r
F P
0 g
s
.43288 .67038 m .42867 .71036 L .43052 .70711 L p 0 0 .226 r
F P
0 g
s
.42958 .7756 m .42352 .73012 L .42347 .73456 L p 0 0 .142 r
F P
0 g
s
.60997 .79813 m .59335 .83767 L .59564 .83543 L p 0 0 .033 r
F P
0 g
s
.59564 .83543 m .61278 .79508 L .60997 .79813 L p 0 0 .033 r
F P
0 g
s
.55881 .46261 m .56241 .46782 L .55284 .46027 L p .644 .121 0 r
F P
0 g
s
.55284 .46027 m .55016 .45504 L .55881 .46261 L p .644 .121 0 r
F P
0 g
s
.41992 .60059 m .39527 .58359 L .40104 .5881 L p 0 .176 .607 r
F P
0 g
s
.37549 .5684 m .40104 .5881 L .39527 .58359 L p 0 .111 .568 r
F P
0 g
s
.32395 .43106 m .34578 .41926 L .34751 .4374 L p .949 .903 .744 r
F P
0 g
s
.34751 .4374 m .32627 .44941 L .32395 .43106 L p .949 .903 .744 r
F P
0 g
s
.63095 .68429 m .6297 .72015 L .62885 .71727 L p .743 .634 .072 r
F P
0 g
s
.63673 .65639 m .63023 .67926 L .6287 .67629 L p .961 .886 .498 r
F P
0 g
s
.62968 .46155 m .61912 .45434 L .63841 .4468 L p .387 .007 .19 r
F P
0 g
s
.61912 .45434 m .62968 .46155 L .61109 .4674 L p .359 0 .155 r
F P
0 g
s
.44192 .65837 m .44237 .63228 L .44167 .63369 L p 0 0 .306 r
F P
0 g
s
.44167 .63369 m .43971 .66026 L .44192 .65837 L p 0 0 .306 r
F P
0 g
s
.51794 .42436 m .51628 .41738 L .5005 .4027 L p 0 .142 .654 r
F P
0 g
s
.50483 .41085 m .51794 .42436 L p .50232 .40496 L 0 .142 .654 r
F P
0 g
s
.51509 .42316 m .49739 .40877 L p .51398 .41633 L .805 .321 0 r
F P
0 g
s
.51628 .41738 m .51607 .41838 L p .51398 .41633 L .805 .321 0 r
F P
0 g
s
.51607 .41838 m .51509 .42316 L p .51398 .41633 L .805 .321 0 r
F P
0 g
s
.5005 .4027 m .50104 .4037 L p .50232 .40496 L 0 .142 .654 r
F P
0 g
s
.50104 .4037 m .50483 .41085 L p .50232 .40496 L 0 .142 .654 r
F P
0 g
s
.45591 .83482 m .4376 .79611 L .44032 .79909 L p .85 .413 0 r
F P
0 g
s
.44032 .79909 m .45807 .83707 L .45591 .83482 L p .85 .413 0 r
F P
0 g
s
.7296 .61672 m .68646 .63168 L .68768 .62712 L p .678 .895 .975 r
F P
0 g
s
.65459 .63931 m .68768 .62712 L .68646 .63168 L p .658 .902 .981 r
F P
0 g
s
.36559 .37469 m .39364 .38269 L .38433 .39325 L p .77 .921 .937 r
F P
0 g
s
.38433 .39325 m .3546 .38688 L .36559 .37469 L p .77 .921 .937 r
F P
0 g
s
.3677 .56092 m .34521 .5336 L .35442 .54439 L p .637 .144 0 r
F P
0 g
s
.35442 .54439 m .37549 .5684 L .3677 .56092 L p .637 .144 0 r
F P
0 g
s
.42962 .77206 m .42394 .72578 L .42352 .73012 L p 0 0 .212 r
F P
0 g
s
.42352 .73012 m .42958 .7756 L .42962 .77206 L p 0 0 .212 r
F P
0 g
s
.61278 .79508 m .59564 .83543 L .59765 .83313 L p 0 0 0 r
F P
0 g
s
.59765 .83313 m .61527 .79202 L .61278 .79508 L p 0 0 0 r
F P
0 g
s
.43263 .70412 m .43608 .66467 L .43447 .66733 L p 0 0 .272 r
F P
0 g
s
.43447 .66733 m .43052 .70711 L .43263 .70412 L p 0 0 .272 r
F P
0 g
s
.65136 .45494 m .63841 .4468 L .66001 .43931 L p .422 .037 .201 r
F P
0 g
s
.63841 .4468 m .65136 .45494 L .62968 .46155 L p .387 .007 .19 r
F P
0 g
s
.72951 .42657 m .75402 .44002 L .72835 .44032 L p .53 .061 .087 r
F P
0 g
s
.72835 .44032 m .70674 .42838 L .72951 .42657 L p .53 .061 .087 r
F P
0 g
s
.39527 .58359 m .3677 .56092 L .37549 .5684 L p 0 .111 .568 r
F P
0 g
s
.81019 .56242 m .77484 .59352 L .77834 .5843 L p .847 .991 .849 r
F P
0 g
s
.77834 .5843 m .81448 .55056 L .81019 .56242 L p .847 .991 .849 r
F P
0 g
s
.52296 .87314 m .52034 .85723 L .52515 .85741 L p .525 .026 .013 r
F P
0 g
s
.52515 .85741 m .52569 .87321 L .52296 .87314 L p .525 .026 .013 r
F P
0 g
s
.52569 .87321 m .52515 .85741 L .52997 .85745 L p .501 .006 .012 r
F P
0 g
s
.52997 .85745 m .52841 .87319 L .52569 .87321 L p .501 .006 .012 r
F P
0 g
s
.52841 .87319 m .52997 .85745 L .53477 .85735 L p .475 0 .008 r
F P
0 g
s
.52025 .87299 m .51555 .8569 L .52034 .85723 L p .547 .044 .011 r
F P
0 g
s
.52034 .85723 m .52296 .87314 L .52025 .87299 L p .547 .044 .011 r
F P
0 g
s
.39527 .58359 m .41992 .60059 L .41703 .59782 L p 0 .252 .696 r
F P
0 g
s
.53477 .85735 m .53113 .87309 L .52841 .87319 L p .475 0 .008 r
F P
0 g
s
.53113 .87309 m .53477 .85735 L .53955 .85709 L p .446 0 0 r
F P
0 g
s
.54232 .44987 m .54068 .44452 L .55016 .45504 L p .702 .219 0 r
F P
0 g
s
.68768 .62712 m .65459 .63931 L .65267 .63529 L p .695 .841 .953 r
F P
0 g
s
.65459 .63931 m .63592 .65349 L .63381 .65008 L p .825 .898 .893 r
F P
0 g
s
.63381 .65008 m .65267 .63529 L .65459 .63931 L p .825 .898 .893 r
F P
0 g
s
.51756 .87275 m .51081 .85645 L .51555 .8569 L p .567 .058 .005 r
F P
0 g
s
.51555 .8569 m .52025 .87299 L .51756 .87275 L p .567 .058 .005 r
F P
0 g
s
.63096 .68191 m .62885 .71727 L .62747 .71428 L p .906 .742 .244 r
F P
0 g
s
.62747 .71428 m .63023 .67926 L .63096 .68191 L p .906 .742 .244 r
F P
0 g
s
.53955 .85709 m .53384 .87291 L .53113 .87309 L p .446 0 0 r
F P
0 g
s
.53384 .87291 m .53955 .85709 L .54428 .85668 L p .414 0 0 r
F P
0 g
s
.82998 .51443 m .81448 .55056 L .81272 .53879 L p .982 .911 .622 r
F P
0 g
s
.81272 .53879 m .82819 .50119 L .82998 .51443 L p .982 .911 .622 r
F P
0 g
s
.63592 .65349 m .6287 .67629 L .62633 .67303 L p .99 .853 .61 r
F P
0 g
s
.62633 .67303 m .63381 .65008 L .63592 .65349 L p .99 .853 .61 r
F P
0 g
s
.67567 .44856 m .66001 .43931 L .68315 .43287 L p .459 .058 .191 r
F P
0 g
s
.66001 .43931 m .67567 .44856 L .65136 .45494 L p .422 .037 .201 r
F P
0 g
s
.51491 .87243 m .50612 .85586 L .51081 .85645 L p .584 .071 0 r
F P
0 g
s
.51081 .85645 m .51756 .87275 L .51491 .87243 L p .584 .071 0 r
F P
0 g
s
.45404 .83248 m .43526 .79296 L .4376 .79611 L p .811 .385 0 r
F P
0 g
s
.4376 .79611 m .45591 .83482 L .45404 .83248 L p .811 .385 0 r
F P
0 g
s
.54428 .85668 m .53651 .87264 L .53384 .87291 L p .414 0 0 r
F P
0 g
s
.53651 .87264 m .54428 .85668 L .54895 .8561 L p .379 0 0 r
F P
0 g
s
.70674 .42838 m .72835 .44032 L .70174 .44339 L p .496 .068 .157 r
F P
0 g
s
.70174 .44339 m .68315 .43287 L .70674 .42838 L p .496 .068 .157 r
F P
0 g
s
.5123 .87203 m .50151 .85515 L .50612 .85586 L p .6 .08 0 r
F P
0 g
s
.50612 .85586 m .51491 .87243 L .5123 .87203 L p .6 .08 0 r
F P
0 g
s
.61527 .79202 m .59765 .83313 L .59939 .83079 L p 0 0 0 r
F P
0 g
s
.59939 .83079 m .61745 .78896 L .61527 .79202 L p 0 0 0 r
F P
0 g
s
.43003 .76856 m .4247 .72159 L .42394 .72578 L p 0 0 .274 r
F P
0 g
s
.42394 .72578 m .42962 .77206 L .43003 .76856 L p 0 0 .274 r
F P
0 g
s
.68315 .43287 m .70174 .44339 L .67567 .44856 L p .459 .058 .191 r
F P
0 g
s
.54895 .8561 m .53914 .87228 L .53651 .87264 L p .379 0 0 r
F P
0 g
s
.53914 .87228 m .54895 .8561 L .55353 .85536 L p .341 0 0 r
F P
0 g
s
.44452 .65659 m .44351 .63089 L .44237 .63228 L p .037 0 .39 r
F P
0 g
s
.44237 .63228 m .44192 .65837 L .44452 .65659 L p .037 0 .39 r
F P
0 g
s
.50975 .87155 m .49699 .85432 L .50151 .85515 L p .613 .086 0 r
F P
0 g
s
.50151 .85515 m .5123 .87203 L .50975 .87155 L p .613 .086 0 r
F P
0 g
s
.43505 .70135 m .4378 .66234 L .43608 .66467 L p 0 0 .318 r
F P
0 g
s
.43608 .66467 m .43263 .70412 L .43505 .70135 L p 0 0 .318 r
F P
0 g
s
.50483 .41085 m .5005 .4027 L .48231 .3888 L p 0 .181 .663 r
F P
0 g
s
.4898 .39802 m .50483 .41085 L p .48445 .39089 L 0 .181 .663 r
F P
0 g
s
.49739 .40877 m .47692 .39523 L p .49781 .40185 L .794 .298 0 r
F P
0 g
s
.5005 .4027 m .50001 .40365 L p .49781 .40185 L .794 .298 0 r
F P
0 g
s
.50001 .40365 m .49739 .40877 L p .49781 .40185 L .794 .298 0 r
F P
0 g
s
.48231 .3888 m .48314 .38982 L p .48445 .39089 L 0 .181 .663 r
F P
0 g
s
.48314 .38982 m .4898 .39802 L p .48445 .39089 L 0 .181 .663 r
F P
0 g
s
.55353 .85536 m .54172 .87185 L .53914 .87228 L p .341 0 0 r
F P
0 g
s
.54172 .87185 m .55353 .85536 L .55801 .85446 L p .298 0 0 r
F P
0 g
s
.77484 .59352 m .7296 .61672 L .732 .61011 L p .753 .935 .946 r
F P
0 g
s
.68768 .62712 m .732 .61011 L .7296 .61672 L p .678 .895 .975 r
F P
0 g
s
.50726 .87099 m .49258 .85336 L .49699 .85432 L p .624 .089 0 r
F P
0 g
s
.49699 .85432 m .50975 .87155 L .50726 .87099 L p .624 .089 0 r
F P
0 g
s
.55801 .85446 m .54425 .87133 L .54172 .87185 L p .298 0 0 r
F P
0 g
s
.54425 .87133 m .55801 .85446 L .56236 .8534 L p .251 0 0 r
F P
0 g
s
.32004 .47462 m .32627 .44941 L .33215 .46753 L p .998 .811 .463 r
F P
0 g
s
.33215 .46753 m .32631 .49098 L .32004 .47462 L p .998 .811 .463 r
F P
0 g
s
.81051 .45817 m .81987 .48931 L .80533 .47948 L p .897 .52 .311 r
F P
0 g
s
.80533 .47948 m .79643 .44901 L .81051 .45817 L p .897 .52 .311 r
F P
0 g
s
.45246 .83006 m .43333 .78965 L .43526 .79296 L p .751 .345 0 r
F P
0 g
s
.43526 .79296 m .45404 .83248 L .45246 .83006 L p .751 .345 0 r
F P
0 g
s
.56786 .57596 m .56373 .5913 L .55736 .58982 L p .665 .536 .697 r
F P
0 g
s
.55736 .58982 m .56049 .57472 L .56786 .57596 L p .665 .536 .697 r
F P
0 g
s
.55752 .60771 m .55736 .58982 L .56373 .5913 L p .705 .449 .534 r
F P
0 g
s
.56049 .57472 m .55736 .58982 L .55154 .58873 L p .736 .605 .71 r
F P
0 g
s
.55736 .58982 m .55752 .60771 L .55172 .60659 L p .751 .484 .528 r
F P
0 g
s
.55172 .60659 m .55154 .58873 L .55736 .58982 L p .751 .484 .528 r
F P
0 g
s
.57576 .55816 m .56786 .57596 L .56049 .57472 L p .642 .598 .79 r
F P
0 g
s
.56049 .57472 m .56675 .55731 L .57576 .55816 L p .642 .598 .79 r
F P
0 g
s
.56675 .55731 m .56049 .57472 L .55403 .57359 L p .708 .672 .813 r
F P
0 g
s
.55154 .58873 m .55403 .57359 L .56049 .57472 L p .736 .605 .71 r
F P
0 g
s
.50485 .87036 m .4883 .85228 L .49258 .85336 L p .632 .089 0 r
F P
0 g
s
.49258 .85336 m .50726 .87099 L .50485 .87036 L p .632 .089 0 r
F P
0 g
s
.62991 .72567 m .62338 .77109 L .62307 .76815 L p .78 .711 .174 r
F P
0 g
s
.62307 .76815 m .63003 .72294 L .62991 .72567 L p .78 .711 .174 r
F P
0 g
s
.33698 .52148 m .32631 .49098 L .33502 .50622 L p .875 .506 .02 r
F P
0 g
s
.33502 .50622 m .34521 .5336 L .33698 .52148 L p .875 .506 .02 r
F P
0 g
s
.57647 .57743 m .57083 .59321 L .56373 .5913 L p .619 .496 .691 r
F P
0 g
s
.56373 .5913 m .56786 .57596 L .57647 .57743 L p .619 .496 .691 r
F P
0 g
s
.56357 .60931 m .56373 .5913 L .57083 .59321 L p .673 .431 .547 r
F P
0 g
s
.56373 .5913 m .56357 .60931 L .55752 .60771 L p .705 .449 .534 r
F P
0 g
s
.732 .61011 m .77834 .5843 L .77484 .59352 L p .753 .935 .946 r
F P
0 g
s
.61745 .78896 m .59939 .83079 L .60083 .82841 L p 0 0 0 r
F P
0 g
s
.60083 .82841 m .6193 .78593 L .61745 .78896 L p 0 0 0 r
F P
0 g
s
.44529 .62946 m .43544 .61159 L .4353 .61336 L p 0 .133 .66 r
F P
0 g
s
.4353 .61336 m .44351 .63089 L .44529 .62946 L p 0 .133 .66 r
F P
0 g
s
.41703 .59782 m .4353 .61336 L .43544 .61159 L p 0 .322 .794 r
F P
0 g
s
.38059 .36633 m .40613 .37564 L .39364 .38269 L p .673 .916 .975 r
F P
0 g
s
.39364 .38269 m .36559 .37469 L .38059 .36633 L p .673 .916 .975 r
F P
0 g
s
.63023 .67926 m .62747 .71428 L .62551 .71117 L p .985 .78 .38 r
F P
0 g
s
.62551 .71117 m .6287 .67629 L .63023 .67926 L p .985 .78 .38 r
F P
0 g
s
.55403 .57359 m .55907 .5561 L .56675 .55731 L p .708 .672 .813 r
F P
0 g
s
.55907 .5561 m .55403 .57359 L .54806 .57249 L p .783 .752 .825 r
F P
0 g
s
.55403 .57359 m .55154 .58873 L .546 .58797 L p .815 .686 .722 r
F P
0 g
s
.546 .58797 m .54806 .57249 L .55403 .57359 L p .815 .686 .722 r
F P
0 g
s
.55154 .58873 m .55172 .60659 L .54602 .60593 L p .802 .533 .531 r
F P
0 g
s
.54602 .60593 m .546 .58797 L .55154 .58873 L p .802 .533 .531 r
F P
0 g
s
.56236 .8534 m .5467 .87073 L .54907 .87006 L p .197 0 0 r
F P
0 g
s
.54907 .87006 m .56658 .85218 L .56236 .8534 L p .197 0 0 r
F P
0 g
s
.56236 .8534 m .5467 .87073 L .54425 .87133 L p .251 0 0 r
F P
0 g
s
.43081 .76515 m .42575 .7176 L .4247 .72159 L p 0 0 .328 r
F P
0 g
s
.4247 .72159 m .43003 .76856 L .43081 .76515 L p 0 0 .328 r
F P
0 g
s
.65267 .63529 m .63381 .65008 L .63039 .64623 L p .803 .802 .851 r
F P
0 g
s
.63381 .65008 m .62633 .67303 L .62313 .6695 L p .947 .775 .637 r
F P
0 g
s
.62313 .6695 m .63039 .64623 L .63381 .65008 L p .947 .775 .637 r
F P
0 g
s
.58654 .55886 m .57647 .57743 L .56786 .57596 L p .601 .551 .77 r
F P
0 g
s
.56786 .57596 m .57576 .55816 L .58654 .55886 L p .601 .551 .77 r
F P
0 g
s
.50252 .86965 m .48416 .85108 L .4883 .85228 L p .636 .086 0 r
F P
0 g
s
.4883 .85228 m .50485 .87036 L .50252 .86965 L p .636 .086 0 r
F P
0 g
s
.65267 .63529 m .68587 .62181 L .68768 .62712 L p .695 .841 .953 r
F P
0 g
s
.68587 .62181 m .65267 .63529 L .64871 .63071 L p .699 .778 .912 r
F P
0 g
s
.63039 .64623 m .64871 .63071 L .65267 .63529 L p .803 .802 .851 r
F P
0 g
s
.732 .61011 m .68768 .62712 L .68587 .62181 L p .705 .838 .946 r
F P
0 g
s
.5865 .57929 m .57878 .59563 L .57083 .59321 L p .597 .482 .694 r
F P
0 g
s
.57083 .59321 m .57647 .57743 L .5865 .57929 L p .597 .482 .694 r
F P
0 g
s
.56996 .6114 m .57083 .59321 L .57878 .59563 L p .655 .43 .566 r
F P
0 g
s
.57083 .59321 m .56996 .6114 L .56357 .60931 L p .673 .431 .547 r
F P
0 g
s
.43778 .69878 m .43971 .66026 L .4378 .66234 L p .053 0 .363 r
F P
0 g
s
.4378 .66234 m .43505 .70135 L .43778 .69878 L p .053 0 .363 r
F P
0 g
s
.41703 .59782 m .39024 .57845 L .39527 .58359 L p 0 .252 .696 r
F P
0 g
s
.3677 .56092 m .39527 .58359 L .39024 .57845 L p 0 .178 .656 r
F P
0 g
s
.56658 .85218 m .54907 .87006 L .55135 .86931 L p .134 0 0 r
F P
0 g
s
.55135 .86931 m .57063 .85081 L .56658 .85218 L p .134 0 0 r
F P
0 g
s
.52995 .43721 m .52958 .43167 L .54068 .44452 L p .754 .283 0 r
F P
0 g
s
.54806 .57249 m .546 .58797 L .54044 .5875 L p .874 .754 .727 r
F P
0 g
s
.546 .58797 m .54602 .60593 L .54028 .6057 L p .845 .584 .544 r
F P
0 g
s
.54028 .6057 m .54044 .5875 L .546 .58797 L p .845 .584 .544 r
F P
0 g
s
.50029 .86887 m .48017 .84975 L .48416 .85108 L p .635 .078 0 r
F P
0 g
s
.48416 .85108 m .50252 .86965 L .50029 .86887 L p .635 .078 0 r
F P
0 g
s
.3261 .41347 m .34801 .40207 L .34578 .41926 L p .933 .954 .77 r
F P
0 g
s
.34578 .41926 m .32395 .43106 L .3261 .41347 L p .933 .954 .77 r
F P
0 g
s
.54806 .57249 m .55211 .55438 L .55907 .5561 L p .783 .752 .825 r
F P
0 g
s
.55211 .55438 m .54806 .57249 L .54211 .57136 L p .842 .811 .82 r
F P
0 g
s
.54044 .5875 m .54211 .57136 L .54806 .57249 L p .874 .754 .727 r
F P
0 g
s
.43333 .78965 m .45246 .83006 L .45118 .82759 L p .67 .294 0 r
F P
0 g
s
.45118 .82759 m .43179 .78623 L .43333 .78965 L p .67 .294 0 r
F P
0 g
s
.58434 .4886 m .58282 .47336 L .5956 .47159 L p .623 .337 .462 r
F P
0 g
s
.58282 .47336 m .58434 .4886 L .57329 .48727 L p .726 .413 .448 r
F P
0 g
s
.57329 .48727 m .57206 .47219 L .58282 .47336 L p .726 .413 .448 r
F P
0 g
s
.59936 .55969 m .5865 .57929 L .57647 .57743 L p .584 .529 .76 r
F P
0 g
s
.57647 .57743 m .58654 .55886 L .59936 .55969 L p .584 .529 .76 r
F P
0 g
s
.4898 .39802 m .48231 .3888 L .46216 .37687 L p 0 .266 .704 r
F P
0 g
s
.47321 .38693 m .4898 .39802 L p .46441 .3786 L 0 .266 .704 r
F P
0 g
s
.47692 .39523 m .45419 .38372 L p .47947 .38829 L .757 .245 0 r
F P
0 g
s
.48231 .3888 m .4816 .38966 L p .47947 .38829 L .757 .245 0 r
F P
0 g
s
.4816 .38966 m .47692 .39523 L p .47947 .38829 L .757 .245 0 r
F P
0 g
s
.46216 .37687 m .46319 .3778 L p .46441 .3786 L 0 .266 .704 r
F P
0 g
s
.46319 .3778 m .47321 .38693 L p .46441 .3786 L 0 .266 .704 r
F P
0 g
s
.44763 .65485 m .44529 .62946 L .44351 .63089 L p .151 .042 .466 r
F P
0 g
s
.44351 .63089 m .44452 .65659 L .44763 .65485 L p .151 .042 .466 r
F P
0 g
s
.57063 .85081 m .55135 .86931 L .55353 .86848 L p .065 0 0 r
F P
0 g
s
.55353 .86848 m .57451 .84928 L .57063 .85081 L p .065 0 0 r
F P
0 g
s
.59792 .58168 m .58756 .59858 L .57878 .59563 L p .592 .488 .704 r
F P
0 g
s
.57878 .59563 m .5865 .57929 L .59792 .58168 L p .592 .488 .704 r
F P
0 g
s
.57674 .61399 m .57878 .59563 L .58756 .59858 L p .65 .443 .589 r
F P
0 g
s
.57878 .59563 m .57674 .61399 L .56996 .6114 L p .655 .43 .566 r
F P
0 g
s
.6193 .78593 m .60083 .82841 L .60138 .82729 L p 0 0 0 r
F P
0 g
s
.60624 .81616 m .6193 .78593 L .60138 .82729 L 0 0 0 r
F
.60199 .82601 m .62082 .78291 L .6193 .78593 L p F P
0 g
s
.60284 .82359 m .62201 .77993 L .62118 .78201 L p .686 .786 .313 r
F P
0 g
s
.62118 .78201 m .62082 .78291 L p .61724 .79102 L .686 .786 .313 r
F P
0 g
s
.60284 .82359 m .62118 .78201 L .61724 .79102 L .686 .786 .313 r
F
.60138 .82729 m .60199 .82601 L p .60624 .81616 L 0 0 0 r
F P
0 g
s
.59748 .48746 m .5956 .47159 L .61109 .4674 L p .567 .298 .468 r
F P
0 g
s
.5956 .47159 m .59748 .48746 L .58434 .4886 L p .623 .337 .462 r
F P
0 g
s
.43195 .76184 m .42708 .71385 L .42575 .7176 L p 0 0 .374 r
F P
0 g
s
.42575 .7176 m .43081 .76515 L .43195 .76184 L p 0 0 .374 r
F P
0 g
s
.57206 .47219 m .57329 .48727 L .56339 .48322 L p .843 .508 .418 r
F P
0 g
s
.56339 .48322 m .56241 .46782 L .57206 .47219 L p .843 .508 .418 r
F P
0 g
s
.63003 .72294 m .62307 .76815 L .62234 .76521 L p .887 .777 .282 r
F P
0 g
s
.62234 .76521 m .6297 .72015 L .63003 .72294 L p .887 .777 .282 r
F P
0 g
s
.49816 .86802 m .47636 .8483 L .48017 .84975 L p .63 .067 0 r
F P
0 g
s
.48017 .84975 m .50029 .86887 L .49816 .86802 L p .63 .067 0 r
F P
0 g
s
.64871 .63071 m .63039 .64623 L .62575 .64204 L p .773 .724 .807 r
F P
0 g
s
.63039 .64623 m .62313 .6695 L .61915 .66576 L p .896 .703 .633 r
F P
0 g
s
.61915 .66576 m .62575 .64204 L .63039 .64623 L p .896 .703 .633 r
F P
0 g
s
.6287 .67629 m .62551 .71117 L .62298 .70793 L p .995 .765 .464 r
F P
0 g
s
.62298 .70793 m .62633 .67303 L .6287 .67629 L p .995 .765 .464 r
F P
0 g
s
.57451 .84928 m .55353 .86848 L .55561 .86759 L p 0 0 0 r
F P
0 g
s
.55561 .86759 m .57821 .84763 L .57451 .84928 L p 0 0 0 r
F P
0 g
s
.43544 .61159 m .41539 .59466 L .41703 .59782 L p 0 .322 .794 r
F P
0 g
s
.39024 .57845 m .41703 .59782 L .41539 .59466 L p 0 .366 .809 r
F P
0 g
s
.54211 .57136 m .54044 .5875 L .53458 .58731 L p .903 .795 .73 r
F P
0 g
s
.54044 .5875 m .54028 .6057 L .53434 .60587 L p .874 .629 .565 r
F P
0 g
s
.53434 .60587 m .53458 .58731 L .54044 .5875 L p .874 .629 .565 r
F P
0 g
s
.38059 .36633 m .40613 .37564 L .4212 .37255 L p .512 .864 .99 r
F P
0 g
s
.64871 .63071 m .68097 .61599 L .68587 .62181 L p .699 .778 .912 r
F P
0 g
s
.68097 .61599 m .64871 .63071 L .64282 .62577 L p .69 .721 .873 r
F P
0 g
s
.62575 .64204 m .64282 .62577 L .64871 .63071 L p .773 .724 .807 r
F P
0 g
s
.61055 .58472 m .59703 .60209 L .58756 .59858 L p .599 .505 .719 r
F P
0 g
s
.58756 .59858 m .59792 .58168 L .61055 .58472 L p .599 .505 .719 r
F P
0 g
s
.5839 .61707 m .58756 .59858 L .59703 .60209 L p .654 .464 .615 r
F P
0 g
s
.58756 .59858 m .5839 .61707 L .57674 .61399 L p .65 .443 .589 r
F P
0 g
s
.49614 .86711 m .47275 .84673 L .47636 .8483 L p .618 .05 0 r
F P
0 g
s
.47636 .8483 m .49816 .86802 L .49614 .86711 L p .618 .05 0 r
F P
0 g
s
.58538 .53577 m .57576 .55816 L .56675 .55731 L p .652 .606 .791 r
F P
0 g
s
.56675 .55731 m .5745 .53548 L .58538 .53577 L p .652 .606 .791 r
F P
0 g
s
.5745 .53548 m .56675 .55731 L .55907 .5561 L p .71 .672 .811 r
F P
0 g
s
.45021 .82506 m .43066 .78272 L .43179 .78623 L p 0 0 .357 r
F P
0 g
s
.43179 .78623 m .45118 .82759 L .45021 .82506 L p 0 0 .357 r
F P
0 g
s
.44087 .69638 m .44192 .65837 L .43971 .66026 L p .135 0 .405 r
F P
0 g
s
.43971 .66026 m .43778 .69878 L .44087 .69638 L p .135 0 .405 r
F P
0 g
s
.61344 .48434 m .61109 .4674 L .62968 .46155 L p .55 .289 .473 r
F P
0 g
s
.61109 .4674 m .61344 .48434 L .59748 .48746 L p .567 .298 .468 r
F P
0 g
s
.61422 .56093 m .59792 .58168 L .5865 .57929 L p .584 .527 .757 r
F P
0 g
s
.5865 .57929 m .59936 .55969 L .61422 .56093 L p .584 .527 .757 r
F P
0 g
s
.55907 .5561 m .56533 .53417 L .5745 .53548 L p .71 .672 .811 r
F P
0 g
s
.56533 .53417 m .55907 .5561 L .55211 .55438 L p .779 .743 .82 r
F P
0 g
s
.54211 .57136 m .54519 .55211 L .55211 .55438 L p .842 .811 .82 r
F P
0 g
s
.54519 .55211 m .54211 .57136 L .5357 .57022 L p .874 .84 .809 r
F P
0 g
s
.53458 .58731 m .5357 .57022 L .54211 .57136 L p .903 .795 .73 r
F P
0 g
s
.57821 .84763 m .55561 .86759 L .55757 .86664 L p 0 0 0 r
F P
0 g
s
.55757 .86664 m .5817 .84584 L .57821 .84763 L p 0 0 0 r
F P
0 g
s
.62082 .78291 m .60199 .82601 L .60284 .82359 L p .686 .786 .313 r
F P
0 g
s
.47321 .38693 m .46216 .37687 L .4408 .36796 L p 0 .398 .778 r
F P
0 g
s
.45568 .37853 m .47321 .38693 L p .44294 .36921 L 0 .398 .778 r
F P
0 g
s
.44189 .36874 m .45568 .37853 L p .44294 .36921 L 0 .398 .778 r
F P
0 g
s
.45568 .37853 m .4408 .36796 L .4193 .36294 L p .05 .568 .873 r
F P
0 g
s
.43803 .37357 m .45568 .37853 L p .42106 .36369 L .05 .568 .873 r
F P
0 g
s
.4193 .36294 m .42028 .3635 L p .42106 .36369 L .05 .568 .873 r
F P
0 g
s
.42028 .3635 m .43803 .37357 L p .42106 .36369 L .05 .568 .873 r
F P
0 g
s
.39883 .36234 m .4212 .37255 L .43803 .37357 L p .286 .74 .956 r
F P
0 g
s
.4212 .37255 m .39883 .36234 L .38059 .36633 L p .512 .864 .99 r
F P
0 g
s
.43803 .37357 m .4193 .36294 L .39883 .36234 L p .286 .74 .956 r
F P
0 g
s
.43008 .37532 m .40579 .37091 L p .43858 .36815 L .57 .021 0 r
F P
0 g
s
.4408 .36796 m .44 .36851 L p .43858 .36815 L .57 .021 0 r
F P
0 g
s
.44 .36851 m .43008 .37532 L p .43858 .36815 L .57 .021 0 r
F P
0 g
s
.45419 .38372 m .43008 .37532 L p .45946 .37674 L .687 .157 0 r
F P
0 g
s
.46216 .37687 m .46132 .37758 L p .45946 .37674 L .687 .157 0 r
F P
0 g
s
.46132 .37758 m .45419 .38372 L p .45946 .37674 L .687 .157 0 r
F P
0 g
s
.4408 .36796 m .44189 .36874 L p .44294 .36921 L 0 .398 .778 r
F P
0 g
s
.39024 .57845 m .36077 .55246 L .3677 .56092 L p 0 .178 .656 r
F P
0 g
s
.34521 .5336 m .3677 .56092 L .36077 .55246 L p 0 0 .453 r
F P
0 g
s
.36077 .55246 m .33698 .52148 L .34521 .5336 L p 0 0 .453 r
F P
0 g
s
.59854 .53536 m .58654 .55886 L .57576 .55816 L p .615 .561 .771 r
F P
0 g
s
.57576 .55816 m .58538 .53577 L .59854 .53536 L p .615 .561 .771 r
F P
0 g
s
.43344 .75864 m .42867 .71036 L .42708 .71385 L p 0 0 .412 r
F P
0 g
s
.42708 .71385 m .43195 .76184 L .43344 .75864 L p 0 0 .412 r
F P
0 g
s
.64282 .62577 m .62575 .64204 L .62005 .63764 L p .746 .661 .767 r
F P
0 g
s
.62575 .64204 m .61915 .66576 L .61447 .66187 L p .852 .643 .619 r
F P
0 g
s
.61447 .66187 m .62005 .63764 L .62575 .64204 L p .852 .643 .619 r
F P
0 g
s
.56241 .46782 m .56339 .48322 L .55357 .47645 L p .917 .577 .382 r
F P
0 g
s
.55357 .47645 m .55284 .46027 L .56241 .46782 L p .917 .577 .382 r
F P
0 g
s
.44791 .6279 m .43682 .60957 L .43544 .61159 L p .154 .292 .753 r
F P
0 g
s
.43544 .61159 m .44529 .62946 L .44791 .6279 L p .154 .292 .753 r
F P
0 g
s
.41539 .59466 m .43544 .61159 L .43682 .60957 L p .094 .458 .886 r
F P
0 g
s
.49425 .86613 m .46934 .84503 L .47275 .84673 L p .597 .029 0 r
F P
0 g
s
.47275 .84673 m .49614 .86711 L .49425 .86613 L p .597 .029 0 r
F P
0 g
s
.79643 .44901 m .80533 .47948 L .78541 .47224 L p .816 .471 .405 r
F P
0 g
s
.78541 .47224 m .7772 .44289 L .79643 .44901 L p .816 .471 .405 r
F P
0 g
s
.81448 .55056 m .77834 .5843 L .77656 .57472 L p .871 .907 .853 r
F P
0 g
s
.77656 .57472 m .81272 .53879 L .81448 .55056 L p .871 .907 .853 r
F P
0 g
s
.62399 .5885 m .60693 .60614 L .59703 .60209 L p .611 .529 .738 r
F P
0 g
s
.59703 .60209 m .61055 .58472 L .62399 .5885 L p .611 .529 .738 r
F P
0 g
s
.59133 .6206 m .59703 .60209 L .60693 .60614 L p .665 .493 .642 r
F P
0 g
s
.59703 .60209 m .59133 .6206 L .5839 .61707 L p .654 .464 .615 r
F P
0 g
s
.82819 .50119 m .81272 .53879 L .80472 .52777 L p .945 .803 .672 r
F P
0 g
s
.80472 .52777 m .81987 .48931 L .82819 .50119 L p .945 .803 .672 r
F P
0 g
s
.68587 .62181 m .7302 .60286 L .732 .61011 L p .705 .838 .946 r
F P
0 g
s
.7302 .60286 m .68587 .62181 L .68097 .61599 L p .707 .78 .909 r
F P
0 g
s
.6297 .72015 m .62234 .76521 L .62119 .76226 L p .958 .814 .377 r
F P
0 g
s
.62119 .76226 m .62885 .71727 L .6297 .72015 L p .958 .814 .377 r
F P
0 g
s
.77834 .5843 m .732 .61011 L .7302 .60286 L p .772 .866 .918 r
F P
0 g
s
.56577 .63592 m .56357 .60931 L .56996 .6114 L p .727 .431 .478 r
F P
0 g
s
.56357 .60931 m .56577 .63592 L .55959 .6343 L p .738 .435 .468 r
F P
0 g
s
.55959 .6343 m .55752 .60771 L .56357 .60931 L p .738 .435 .468 r
F P
0 g
s
.62633 .67303 m .62298 .70793 L .61989 .7046 L p .972 .727 .509 r
F P
0 g
s
.61989 .7046 m .62313 .6695 L .62633 .67303 L p .972 .727 .509 r
F P
0 g
s
.5817 .84584 m .55757 .86664 L .5594 .86562 L p 0 0 0 r
F P
0 g
s
.5594 .86562 m .58497 .84394 L .5817 .84584 L p 0 0 0 r
F P
0 g
s
.55752 .60771 m .55959 .6343 L .55344 .63313 L p .753 .445 .464 r
F P
0 g
s
.55344 .63313 m .55172 .60659 L .55752 .60771 L p .753 .445 .464 r
F P
0 g
s
.57202 .638 m .56996 .6114 L .57674 .61399 L p .723 .436 .491 r
F P
0 g
s
.56996 .6114 m .57202 .638 L .56577 .63592 L p .727 .431 .478 r
F P
0 g
s
.45131 .65311 m .44791 .6279 L .44529 .62946 L p .258 .145 .528 r
F P
0 g
s
.44529 .62946 m .44763 .65485 L .45131 .65311 L p .258 .145 .528 r
F P
0 g
s
.64282 .62577 m .6732 .60992 L .68097 .61599 L p .69 .721 .873 r
F P
0 g
s
.6732 .60992 m .64282 .62577 L .6353 .62064 L p .676 .672 .839 r
F P
0 g
s
.62005 .63764 m .6353 .62064 L .64282 .62577 L p .746 .661 .767 r
F P
0 g
s
.5357 .57022 m .53458 .58731 L .52815 .58741 L p .91 .813 .739 r
F P
0 g
s
.53458 .58731 m .53434 .60587 L .52807 .60642 L p .887 .663 .593 r
F P
0 g
s
.52807 .60642 m .52815 .58741 L .53458 .58731 L p .887 .663 .593 r
F P
0 g
s
.44956 .82251 m .42992 .77917 L .43066 .78272 L p 0 0 .43 r
F P
0 g
s
.43066 .78272 m .45021 .82506 L .44956 .82251 L p 0 0 .43 r
F P
0 g
s
.51509 .42316 m .51628 .41738 L .52958 .43167 L p .79 .317 0 r
F P
0 g
s
.57835 .64051 m .57674 .61399 L .5839 .61707 L p .725 .448 .507 r
F P
0 g
s
.57674 .61399 m .57835 .64051 L .57202 .638 L p .723 .436 .491 r
F P
0 g
s
.55172 .60659 m .55344 .63313 L .54727 .63242 L p .77 .462 .465 r
F P
0 g
s
.54727 .63242 m .54602 .60593 L .55172 .60659 L p .77 .462 .465 r
F P
0 g
s
.55211 .55438 m .55709 .53163 L .56533 .53417 L p .779 .743 .82 r
F P
0 g
s
.55709 .53163 m .55211 .55438 L .54519 .55211 L p .835 .795 .813 r
F P
0 g
s
.6353 .62064 m .62005 .63764 L .6135 .63316 L p .721 .61 .732 r
F P
0 g
s
.62005 .63764 m .61447 .66187 L .60919 .65793 L p .816 .594 .601 r
F P
0 g
s
.60919 .65793 m .6135 .63316 L .62005 .63764 L p .816 .594 .601 r
F P
0 g
s
.49248 .8651 m .46615 .84321 L .46934 .84503 L p .568 .003 0 r
F P
0 g
s
.46934 .84503 m .49425 .86613 L .49248 .8651 L p .568 .003 0 r
F P
0 g
s
.63261 .47994 m .62968 .46155 L .65136 .45494 L p .557 .296 .476 r
F P
0 g
s
.62968 .46155 m .63261 .47994 L .61344 .48434 L p .55 .289 .473 r
F P
0 g
s
.63766 .59301 m .6169 .61066 L .60693 .60614 L p .626 .559 .759 r
F P
0 g
s
.60693 .60614 m .62399 .5885 L .63766 .59301 L p .626 .559 .759 r
F P
0 g
s
.59889 .62452 m .60693 .60614 L .6169 .61066 L p .68 .527 .67 r
F P
0 g
s
.60693 .60614 m .59889 .62452 L .59133 .6206 L p .665 .493 .642 r
F P
0 g
s
.63084 .56288 m .61055 .58472 L .59792 .58168 L p .594 .538 .762 r
F P
0 g
s
.59792 .58168 m .61422 .56093 L .63084 .56288 L p .594 .538 .762 r
F P
0 g
s
.58473 .64343 m .5839 .61707 L .59133 .6206 L p .732 .466 .525 r
F P
0 g
s
.5839 .61707 m .58473 .64343 L .57835 .64051 L p .725 .448 .507 r
F P
0 g
s
.61433 .53465 m .59936 .55969 L .58654 .55886 L p .601 .539 .757 r
F P
0 g
s
.58654 .55886 m .59854 .53536 L .61433 .53465 L p .601 .539 .757 r
F P
0 g
s
.44434 .69411 m .44452 .65659 L .44192 .65837 L p .212 .058 .443 r
F P
0 g
s
.44192 .65837 m .44087 .69638 L .44434 .69411 L p .212 .058 .443 r
F P
0 g
s
.62201 .77993 m .60284 .82359 L .60339 .82115 L p .781 .845 .389 r
F P
0 g
s
.60339 .82115 m .62284 .77697 L .62201 .77993 L p .781 .845 .389 r
F P
0 g
s
.58497 .84394 m .5594 .86562 L .56111 .86455 L p 0 0 0 r
F P
0 g
s
.56111 .86455 m .58801 .84194 L .58497 .84394 L p 0 0 0 r
F P
0 g
s
.43529 .75558 m .43052 .70711 L .42867 .71036 L p 0 0 .445 r
F P
0 g
s
.42867 .71036 m .43344 .75864 L .43529 .75558 L p 0 0 .445 r
F P
0 g
s
.6135 .63316 m .62651 .61555 L .6353 .62064 L p .721 .61 .732 r
F P
0 g
s
.62651 .61555 m .6135 .63316 L .60636 .62874 L p .699 .565 .7 r
F P
0 g
s
.6135 .63316 m .60919 .65793 L .60345 .65403 L p .787 .553 .582 r
F P
0 g
s
.60345 .65403 m .60636 .62874 L .6135 .63316 L p .787 .553 .582 r
F P
0 g
s
.6353 .62064 m .66298 .6039 L .6732 .60992 L p .676 .672 .839 r
F P
0 g
s
.66298 .6039 m .6353 .62064 L .62651 .61555 L p .66 .63 .809 r
F P
0 g
s
.54602 .60593 m .54727 .63242 L .54103 .63215 L p .786 .482 .473 r
F P
0 g
s
.54103 .63215 m .54028 .6057 L .54602 .60593 L p .786 .482 .473 r
F P
0 g
s
.5911 .6467 m .59133 .6206 L .59889 .62452 L p .745 .489 .544 r
F P
0 g
s
.59133 .6206 m .5911 .6467 L .58473 .64343 L p .732 .466 .525 r
F P
0 g
s
.6509 .59819 m .62651 .61555 L .6169 .61066 L p .643 .592 .782 r
F P
0 g
s
.6169 .61066 m .63766 .59301 L .6509 .59819 L p .643 .592 .782 r
F P
0 g
s
.60636 .62874 m .6169 .61066 L .62651 .61555 L p .699 .565 .7 r
F P
0 g
s
.6169 .61066 m .60636 .62874 L .59889 .62452 L p .68 .527 .67 r
F P
0 g
s
.59738 .65025 m .59889 .62452 L .60636 .62874 L p .763 .518 .563 r
F P
0 g
s
.59889 .62452 m .59738 .65025 L .5911 .6467 L p .745 .489 .544 r
F P
0 g
s
.60636 .62874 m .60345 .65403 L .59738 .65025 L p .763 .518 .563 r
F P
0 g
s
.62651 .61555 m .6509 .59819 L .66298 .6039 L p .66 .63 .809 r
F P
0 g
s
.49084 .86401 m .4632 .84127 L .46615 .84321 L p .527 0 0 r
F P
0 g
s
.46615 .84321 m .49248 .8651 L .49084 .86401 L p .527 0 0 r
F P
0 g
s
.7302 .60286 m .77656 .57472 L .77834 .5843 L p .772 .866 .918 r
F P
0 g
s
.62313 .6695 m .61989 .7046 L .61625 .70118 L p .938 .686 .53 r
F P
0 g
s
.61625 .70118 m .61915 .66576 L .62313 .6695 L p .938 .686 .53 r
F P
0 g
s
.5357 .57022 m .53764 .54936 L .54519 .55211 L p .874 .84 .809 r
F P
0 g
s
.53764 .54936 m .5357 .57022 L .52843 .56914 L p .885 .846 .801 r
F P
0 g
s
.52815 .58741 m .52843 .56914 L .5357 .57022 L p .91 .813 .739 r
F P
0 g
s
.62885 .71727 m .62119 .76226 L .61962 .75929 L p .993 .82 .451 r
F P
0 g
s
.61962 .75929 m .62747 .71428 L .62885 .71727 L p .993 .82 .451 r
F P
0 g
s
.44921 .81993 m .42958 .7756 L .42992 .77917 L p 0 0 .49 r
F P
0 g
s
.42992 .77917 m .44956 .82251 L .44921 .81993 L p 0 0 .49 r
F P
0 g
s
.58801 .84194 m .56111 .86455 L .56267 .86343 L p 0 0 0 r
F P
0 g
s
.56267 .86343 m .59081 .83984 L .58801 .84194 L p 0 0 0 r
F P
0 g
s
.54028 .6057 m .54103 .63215 L .53466 .63229 L p .798 .501 .487 r
F P
0 g
s
.53466 .63229 m .53434 .60587 L .54028 .6057 L p .798 .501 .487 r
F P
0 g
s
.31745 .45788 m .32395 .43106 L .32627 .44941 L p .959 .823 .391 r
F P
0 g
s
.32627 .44941 m .32004 .47462 L .31745 .45788 L p .959 .823 .391 r
F P
0 g
s
.55284 .46027 m .55357 .47645 L .54277 .46722 L p .943 .609 .364 r
F P
0 g
s
.54277 .46722 m .54232 .44987 L .55284 .46027 L p .943 .609 .364 r
F P
0 g
s
.5936 .5106 m .58538 .53577 L .5745 .53548 L p .667 .576 .743 r
F P
0 g
s
.5745 .53548 m .58117 .511 L .5936 .5106 L p .667 .576 .743 r
F P
0 g
s
.58117 .511 m .5745 .53548 L .56533 .53417 L p .728 .64 .76 r
F P
0 g
s
.655 .47507 m .65136 .45494 L .67567 .44856 L p .579 .313 .478 r
F P
0 g
s
.65136 .45494 m .655 .47507 L .63261 .47994 L p .557 .296 .476 r
F P
0 g
s
.58117 .511 m .58434 .4886 L .59748 .48746 L p .669 .503 .651 r
F P
0 g
s
.58434 .4886 m .58117 .511 L .57073 .50963 L p .743 .572 .662 r
F P
0 g
s
.57073 .50963 m .57329 .48727 L .58434 .4886 L p .743 .572 .662 r
F P
0 g
s
.41539 .59466 m .38685 .57271 L .39024 .57845 L p 0 .366 .809 r
F P
0 g
s
.36077 .55246 m .39024 .57845 L .38685 .57271 L p 0 .29 .771 r
F P
0 g
s
.52843 .56914 m .52815 .58741 L .521 .58779 L p .903 .818 .753 r
F P
0 g
s
.52815 .58741 m .52807 .60642 L .52138 .60732 L p .886 .684 .624 r
F P
0 g
s
.52138 .60732 m .521 .58779 L .52815 .58741 L p .886 .684 .624 r
F P
0 g
s
.33323 .39771 m .3546 .38688 L .34801 .40207 L p .868 .995 .791 r
F P
0 g
s
.34801 .40207 m .3261 .41347 L .33323 .39771 L p .868 .995 .791 r
F P
0 g
s
.68097 .61599 m .72414 .59532 L .7302 .60286 L p .707 .78 .909 r
F P
0 g
s
.72414 .59532 m .68097 .61599 L .6732 .60992 L p .696 .728 .875 r
F P
0 g
s
.62284 .77697 m .60339 .82115 L .60363 .81871 L p .86 .887 .458 r
F P
0 g
s
.60363 .81871 m .6233 .77402 L .62284 .77697 L p .86 .887 .458 r
F P
0 g
s
.64866 .56576 m .62399 .5885 L .61055 .58472 L p .609 .557 .771 r
F P
0 g
s
.61055 .58472 m .63084 .56288 L .64866 .56576 L p .609 .557 .771 r
F P
0 g
s
.48935 .86286 m .4605 .83922 L .4632 .84127 L p .476 0 0 r
F P
0 g
s
.4632 .84127 m .49084 .86401 L .48935 .86286 L p .476 0 0 r
F P
0 g
s
.56533 .53417 m .57073 .50963 L .58117 .511 L p .728 .64 .76 r
F P
0 g
s
.57073 .50963 m .56533 .53417 L .55709 .53163 L p .798 .708 .765 r
F P
0 g
s
.45561 .65133 m .45148 .62619 L .44791 .6279 L p .353 .234 .576 r
F P
0 g
s
.44791 .6279 m .45131 .65311 L .45561 .65133 L p .353 .234 .576 r
F P
0 g
s
.43682 .60957 m .44791 .6279 L .45148 .62619 L p .313 .413 .804 r
F P
0 g
s
.43748 .75265 m .43263 .70412 L .43052 .70711 L p .08 .013 .473 r
F P
0 g
s
.43052 .70711 m .43529 .75558 L .43748 .75265 L p .08 .013 .473 r
F P
0 g
s
.7772 .44289 m .78541 .47224 L .76136 .46786 L p .746 .428 .445 r
F P
0 g
s
.76136 .46786 m .75402 .44002 L .7772 .44289 L p .746 .428 .445 r
F P
0 g
s
.33105 .50834 m .32004 .47462 L .32631 .49098 L p .759 .423 0 r
F P
0 g
s
.32631 .49098 m .33698 .52148 L .33105 .50834 L p .759 .423 0 r
F P
0 g
s
.54519 .55211 m .54891 .52785 L .55709 .53163 L p .835 .795 .813 r
F P
0 g
s
.54891 .52785 m .54519 .55211 L .53764 .54936 L p .868 .819 .798 r
F P
0 g
s
.63274 .53414 m .61422 .56093 L .59936 .55969 L p .602 .535 .751 r
F P
0 g
s
.59936 .55969 m .61433 .53465 L .63274 .53414 L p .602 .535 .751 r
F P
0 g
s
.57329 .48727 m .57073 .50963 L .56136 .50625 L p .827 .648 .661 r
F P
0 g
s
.56136 .50625 m .56339 .48322 L .57329 .48727 L p .827 .648 .661 r
F P
0 g
s
.44823 .69195 m .44763 .65485 L .44452 .65659 L p .282 .12 .476 r
F P
0 g
s
.44452 .65659 m .44434 .69411 L .44823 .69195 L p .282 .12 .476 r
F P
0 g
s
.43682 .60957 m .41554 .59115 L .41539 .59466 L p .094 .458 .886 r
F P
0 g
s
.38685 .57271 m .41539 .59466 L .41554 .59115 L p .095 .48 .896 r
F P
0 g
s
.5936 .5106 m .59748 .48746 L .61344 .48434 L p .624 .459 .637 r
F P
0 g
s
.59748 .48746 m .5936 .5106 L .58117 .511 L p .669 .503 .651 r
F P
0 g
s
.60869 .50883 m .59854 .53536 L .58538 .53577 L p .63 .532 .725 r
F P
0 g
s
.58538 .53577 m .5936 .5106 L .60869 .50883 L p .63 .532 .725 r
F P
0 g
s
.59081 .83984 m .56267 .86343 L .56409 .86226 L p .466 .821 .549 r
F P
0 g
s
.56409 .86226 m .59335 .83767 L .59081 .83984 L p .466 .821 .549 r
F P
0 g
s
.45148 .62619 m .43967 .60731 L .43682 .60957 L p .313 .413 .804 r
F P
0 g
s
.41554 .59115 m .43682 .60957 L .43967 .60731 L p .28 .56 .931 r
F P
0 g
s
.61915 .66576 m .61625 .70118 L .6121 .69774 L p .904 .646 .539 r
F P
0 g
s
.6121 .69774 m .61447 .66187 L .61915 .66576 L p .904 .646 .539 r
F P
0 g
s
.53434 .60587 m .53466 .63229 L .52811 .63281 L p .804 .519 .506 r
F P
0 g
s
.52811 .63281 m .52807 .60642 L .53434 .60587 L p .804 .519 .506 r
F P
0 g
s
.44918 .81735 m .42962 .77206 L .42958 .7756 L p 0 0 .536 r
F P
0 g
s
.42958 .7756 m .44921 .81993 L .44918 .81735 L p 0 0 .536 r
F P
0 g
s
.62747 .71428 m .61962 .75929 L .61761 .75631 L p .999 .805 .503 r
F P
0 g
s
.61761 .75631 m .62551 .71117 L .62747 .71428 L p .999 .805 .503 r
F P
0 g
s
.48801 .86167 m .45807 .83707 L .4605 .83922 L p 0 .1 .58 r
F P
0 g
s
.4605 .83922 m .48935 .86286 L .48801 .86167 L p 0 .1 .58 r
F P
0 g
s
.68014 .47063 m .67567 .44856 L .70174 .44339 L p .609 .336 .478 r
F P
0 g
s
.67567 .44856 m .68014 .47063 L .655 .47507 L p .579 .313 .478 r
F P
0 g
s
.77656 .57472 m .7302 .60286 L .72414 .59532 L p .762 .796 .881 r
F P
0 g
s
.66688 .56974 m .63766 .59301 L .62399 .5885 L p .626 .581 .784 r
F P
0 g
s
.62399 .5885 m .64866 .56576 L .66688 .56974 L p .626 .581 .784 r
F P
0 g
s
.49739 .40877 m .5005 .4027 L .51628 .41738 L p .805 .321 0 r
F P
0 g
s
.59335 .83767 m .56409 .86226 L .56536 .86104 L p .555 .879 .605 r
F P
0 g
s
.56536 .86104 m .59564 .83543 L .59335 .83767 L p .555 .879 .605 r
F P
0 g
s
.6233 .77402 m .60363 .81871 L .60356 .81627 L p .92 .912 .518 r
F P
0 g
s
.60356 .81627 m .62338 .77109 L .6233 .77402 L p .92 .912 .518 r
F P
0 g
s
.55709 .53163 m .56136 .50625 L .57073 .50963 L p .798 .708 .765 r
F P
0 g
s
.56136 .50625 m .55709 .53163 L .54891 .52785 L p .855 .758 .755 r
F P
0 g
s
.61447 .66187 m .6121 .69774 L .6075 .69431 L p .873 .611 .54 r
F P
0 g
s
.6075 .69431 m .60919 .65793 L .61447 .66187 L p .873 .611 .54 r
F P
0 g
s
.6732 .60992 m .71408 .58789 L .72414 .59532 L p .696 .728 .875 r
F P
0 g
s
.71408 .58789 m .6732 .60992 L .66298 .6039 L p .681 .683 .846 r
F P
0 g
s
.44003 .74985 m .43505 .70135 L .43263 .70412 L p .153 .067 .496 r
F P
0 g
s
.43263 .70412 m .43748 .75265 L .44003 .74985 L p .153 .067 .496 r
F P
0 g
s
.60869 .50883 m .61344 .48434 L .63261 .47994 L p .608 .439 .628 r
F P
0 g
s
.61344 .48434 m .60869 .50883 L .5936 .5106 L p .624 .459 .637 r
F P
0 g
s
.75402 .44002 m .76136 .46786 L .73474 .46637 L p .691 .392 .464 r
F P
0 g
s
.73474 .46637 m .72835 .44032 L .75402 .44002 L p .691 .392 .464 r
F P
0 g
s
.62683 .50627 m .61433 .53465 L .59854 .53536 L p .615 .511 .712 r
F P
0 g
s
.59854 .53536 m .60869 .50883 L .62683 .50627 L p .615 .511 .712 r
F P
0 g
s
.52807 .60642 m .52811 .63281 L .52135 .63368 L p .804 .532 .527 r
F P
0 g
s
.52135 .63368 m .52138 .60732 L .52807 .60642 L p .804 .532 .527 r
F P
0 g
s
.56339 .48322 m .56136 .50625 L .55207 .50085 L p .89 .703 .643 r
F P
0 g
s
.55207 .50085 m .55357 .47645 L .56339 .48322 L p .89 .703 .643 r
F P
0 g
s
.52843 .56914 m .52889 .54628 L .53764 .54936 L p .885 .846 .801 r
F P
0 g
s
.52889 .54628 m .52843 .56914 L .52001 .56822 L p .881 .84 .8 r
F P
0 g
s
.521 .58779 m .52001 .56822 L .52843 .56914 L p .903 .818 .753 r
F P
0 g
s
.48682 .86044 m .45591 .83482 L .45807 .83707 L p 0 .139 .639 r
F P
0 g
s
.45807 .83707 m .48801 .86167 L .48682 .86044 L p 0 .139 .639 r
F P
0 g
s
.52001 .56822 m .521 .58779 L .51302 .5885 L p .886 .813 .771 r
F P
0 g
s
.521 .58779 m .52138 .60732 L .51424 .60854 L p .876 .695 .655 r
F P
0 g
s
.51424 .60854 m .51302 .5885 L .521 .58779 L p .876 .695 .655 r
F P
0 g
s
.81987 .48931 m .80472 .52777 L .79082 .51812 L p .872 .702 .668 r
F P
0 g
s
.79082 .51812 m .80533 .47948 L .81987 .48931 L p .872 .702 .668 r
F P
0 g
s
.45255 .68987 m .45131 .65311 L .44763 .65485 L p .345 .177 .504 r
F P
0 g
s
.44763 .65485 m .44823 .69195 L .45255 .68987 L p .345 .177 .504 r
F P
0 g
s
.44946 .81478 m .43003 .76856 L .42962 .77206 L p 0 .02 .571 r
F P
0 g
s
.42962 .77206 m .44918 .81735 L .44946 .81478 L p 0 .02 .571 r
F P
0 g
s
.46055 .64949 m .45605 .62431 L .45148 .62619 L p .434 .307 .608 r
F P
0 g
s
.45148 .62619 m .45561 .65133 L .46055 .64949 L p .434 .307 .608 r
F P
0 g
s
.43967 .60731 m .45148 .62619 L .45605 .62431 L p .438 .499 .825 r
F P
0 g
s
.70715 .46748 m .70174 .44339 L .72835 .44032 L p .646 .362 .474 r
F P
0 g
s
.70174 .44339 m .70715 .46748 L .68014 .47063 L p .609 .336 .478 r
F P
0 g
s
.60919 .65793 m .6075 .69431 L .60251 .69094 L p .846 .581 .537 r
F P
0 g
s
.60251 .69094 m .60345 .65403 L .60919 .65793 L p .846 .581 .537 r
F P
0 g
s
.68454 .57484 m .6509 .59819 L .63766 .59301 L p .645 .611 .801 r
F P
0 g
s
.63766 .59301 m .66688 .56974 L .68454 .57484 L p .645 .611 .801 r
F P
0 g
s
.65343 .53432 m .63084 .56288 L .61422 .56093 L p .613 .543 .751 r
F P
0 g
s
.61422 .56093 m .63274 .53414 L .65343 .53432 L p .613 .543 .751 r
F P
0 g
s
.59564 .83543 m .56536 .86104 L .56647 .85979 L p .636 .925 .656 r
F P
0 g
s
.56647 .85979 m .59765 .83313 L .59564 .83543 L p .636 .925 .656 r
F P
0 g
s
.81272 .53879 m .77656 .57472 L .76937 .5653 L p .842 .812 .821 r
F P
0 g
s
.76937 .5653 m .80472 .52777 L .81272 .53879 L p .842 .812 .821 r
F P
0 g
s
.72835 .44032 m .73474 .46637 L .70715 .46748 L p .646 .362 .474 r
F P
0 g
s
.66298 .6039 m .70061 .58096 L .71408 .58789 L p .681 .683 .846 r
F P
0 g
s
.70061 .58096 m .66298 .6039 L .6509 .59819 L p .663 .644 .821 r
F P
0 g
s
.62551 .71117 m .61761 .75631 L .61517 .75333 L p .987 .779 .536 r
F P
0 g
s
.61517 .75333 m .62298 .70793 L .62551 .71117 L p .987 .779 .536 r
F P
0 g
s
.6509 .59819 m .68454 .57484 L .70061 .58096 L p .663 .644 .821 r
F P
0 g
s
.54232 .44987 m .54277 .46722 L .53006 .45606 L p .947 .617 .368 r
F P
0 g
s
.53006 .45606 m .52995 .43721 L .54232 .44987 L p .947 .617 .368 r
F P
0 g
s
.38685 .57271 m .35587 .54317 L .36077 .55246 L p 0 .29 .771 r
F P
0 g
s
.33698 .52148 m .36077 .55246 L .35587 .54317 L p 0 .053 .604 r
F P
0 g
s
.62338 .77109 m .60356 .81627 L .60316 .81383 L p .959 .919 .567 r
F P
0 g
s
.60316 .81383 m .62307 .76815 L .62338 .77109 L p .959 .919 .567 r
F P
0 g
s
.60345 .65403 m .60251 .69094 L .59718 .6877 L p .824 .555 .532 r
F P
0 g
s
.59718 .6877 m .59738 .65025 L .60345 .65403 L p .824 .555 .532 r
F P
0 g
s
.48579 .85917 m .45404 .83248 L .45591 .83482 L p 0 .178 .689 r
F P
0 g
s
.45591 .83482 m .48682 .86044 L .48579 .85917 L p 0 .178 .689 r
F P
0 g
s
.53764 .54936 m .53993 .52295 L .54891 .52785 L p .868 .819 .798 r
F P
0 g
s
.53993 .52295 m .53764 .54936 L .52889 .54628 L p .88 .822 .786 r
F P
0 g
s
.52138 .60732 m .52135 .63368 L .51439 .63486 L p .797 .539 .549 r
F P
0 g
s
.51439 .63486 m .51424 .60854 L .52138 .60732 L p .797 .539 .549 r
F P
0 g
s
.44293 .74719 m .43778 .69878 L .43505 .70135 L p .219 .115 .516 r
F P
0 g
s
.43505 .70135 m .44003 .74985 L .44293 .74719 L p .219 .115 .516 r
F P
0 g
s
.54891 .52785 m .55207 .50085 L .56136 .50625 L p .855 .758 .755 r
F P
0 g
s
.45605 .62431 m .4441 .60484 L .43967 .60731 L p .438 .499 .825 r
F P
0 g
s
.41786 .58737 m .43967 .60731 L .4441 .60484 L p .426 .629 .939 r
F P
0 g
s
.43967 .60731 m .41786 .58737 L .41554 .59115 L p .28 .56 .931 r
F P
0 g
s
.35587 .54317 m .33105 .50834 L .33698 .52148 L p 0 .053 .604 r
F P
0 g
s
.63261 .47994 m .62683 .50627 L .60869 .50883 L p .608 .439 .628 r
F P
0 g
s
.59765 .83313 m .56647 .85979 L .56742 .85851 L p .707 .96 .7 r
F P
0 g
s
.56742 .85851 m .59939 .83079 L .59765 .83313 L p .707 .96 .7 r
F P
0 g
s
.59738 .65025 m .59718 .6877 L .59157 .68464 L p .806 .533 .526 r
F P
0 g
s
.59157 .68464 m .5911 .6467 L .59738 .65025 L p .806 .533 .526 r
F P
0 g
s
.72414 .59532 m .76937 .5653 L .77656 .57472 L p .762 .796 .881 r
F P
0 g
s
.45006 .81224 m .43081 .76515 L .43003 .76856 L p 0 .073 .597 r
F P
0 g
s
.43003 .76856 m .44946 .81478 L .45006 .81224 L p 0 .073 .597 r
F P
0 g
s
.62683 .50627 m .63261 .47994 L .655 .47507 L p .611 .438 .624 r
F P
0 g
s
.5911 .6467 m .59157 .68464 L .58575 .6818 L p .791 .515 .52 r
F P
0 g
s
.58575 .6818 m .58473 .64343 L .5911 .6467 L p .791 .515 .52 r
F P
0 g
s
.45731 .68785 m .45561 .65133 L .45131 .65311 L p .402 .227 .527 r
F P
0 g
s
.45131 .65311 m .45255 .68987 L .45731 .68785 L p .402 .227 .527 r
F P
0 g
s
.64801 .5036 m .63274 .53414 L .61433 .53465 L p .617 .507 .706 r
F P
0 g
s
.61433 .53465 m .62683 .50627 L .64801 .5036 L p .617 .507 .706 r
F P
0 g
s
.55207 .50085 m .54891 .52785 L .53993 .52295 L p .886 .78 .738 r
F P
0 g
s
.4661 .64759 m .4616 .62229 L .45605 .62431 L p .501 .366 .628 r
F P
0 g
s
.45605 .62431 m .46055 .64949 L .4661 .64759 L p .501 .366 .628 r
F P
0 g
s
.4441 .60484 m .45605 .62431 L .4616 .62229 L p .533 .559 .828 r
F P
0 g
s
.48493 .85787 m .45246 .83006 L .45404 .83248 L p 0 .215 .73 r
F P
0 g
s
.45404 .83248 m .48579 .85917 L .48493 .85787 L p 0 .215 .73 r
F P
0 g
s
.58473 .64343 m .58575 .6818 L .57976 .67924 L p .78 .501 .513 r
F P
0 g
s
.57976 .67924 m .57835 .64051 L .58473 .64343 L p .78 .501 .513 r
F P
0 g
s
.62298 .70793 m .61517 .75333 L .61231 .75035 L p .966 .747 .557 r
F P
0 g
s
.61231 .75035 m .61989 .7046 L .62298 .70793 L p .966 .747 .557 r
F P
0 g
s
.34539 .38484 m .36559 .37469 L .3546 .38688 L p .695 .974 .771 r
F P
0 g
s
.3546 .38688 m .33323 .39771 L .34539 .38484 L p .695 .974 .771 r
F P
0 g
s
.51302 .5885 m .51029 .56759 L .52001 .56822 L p .886 .813 .771 r
F P
0 g
s
.51029 .56759 m .51302 .5885 L .50427 .58955 L p .864 .803 .789 r
F P
0 g
s
.51302 .5885 m .51424 .60854 L .5067 .61004 L p .857 .699 .685 r
F P
0 g
s
.5067 .61004 m .50427 .58955 L .51302 .5885 L p .857 .699 .685 r
F P
0 g
s
.76937 .5653 m .72414 .59532 L .71408 .58789 L p .742 .737 .847 r
F P
0 g
s
.57835 .64051 m .57976 .67924 L .57364 .67699 L p .772 .49 .508 r
F P
0 g
s
.57364 .67699 m .57202 .638 L .57835 .64051 L p .772 .49 .508 r
F P
0 g
s
.38588 .56653 m .41554 .59115 L .41786 .58737 L p .279 .57 .936 r
F P
0 g
s
.41554 .59115 m .38588 .56653 L .38685 .57271 L p .095 .48 .896 r
F P
0 g
s
.51424 .60854 m .51439 .63486 L .50727 .6363 L p .783 .541 .57 r
F P
0 g
s
.50727 .6363 m .5067 .61004 L .51424 .60854 L p .783 .541 .57 r
F P
0 g
s
.67566 .53563 m .64866 .56576 L .63084 .56288 L p .63 .559 .756 r
F P
0 g
s
.63084 .56288 m .65343 .53432 L .67566 .53563 L p .63 .559 .756 r
F P
0 g
s
.57202 .638 m .57364 .67699 L .56741 .67508 L p .766 .483 .504 r
F P
0 g
s
.56741 .67508 m .56577 .63592 L .57202 .638 L p .766 .483 .504 r
F P
0 g
s
.62307 .76815 m .60316 .81383 L .60245 .8114 L p .98 .911 .603 r
F P
0 g
s
.60245 .8114 m .62234 .76521 L .62307 .76815 L p .98 .911 .603 r
F P
0 g
s
.59939 .83079 m .56742 .85851 L .5682 .8572 L p .767 .983 .735 r
F P
0 g
s
.5682 .8572 m .60083 .82841 L .59939 .83079 L p .767 .983 .735 r
F P
0 g
s
.55357 .47645 m .55207 .50085 L .54186 .49361 L p .921 .726 .623 r
F P
0 g
s
.54186 .49361 m .54277 .46722 L .55357 .47645 L p .921 .726 .623 r
F P
0 g
s
.56577 .63592 m .56741 .67508 L .56109 .67354 L p .763 .478 .502 r
F P
0 g
s
.56109 .67354 m .55959 .6343 L .56577 .63592 L p .763 .478 .502 r
F P
0 g
s
.47692 .39523 m .48231 .3888 L .5005 .4027 L p .794 .298 0 r
F P
0 g
s
.44618 .74467 m .44087 .69638 L .43778 .69878 L p .278 .16 .533 r
F P
0 g
s
.43778 .69878 m .44293 .74719 L .44618 .74467 L p .278 .16 .533 r
F P
0 g
s
.45096 .80973 m .43195 .76184 L .43081 .76515 L p .056 .121 .615 r
F P
0 g
s
.43081 .76515 m .45006 .81224 L .45096 .80973 L p .056 .121 .615 r
F P
0 g
s
.35587 .54317 m .38685 .57271 L .38588 .56653 L p .061 .408 .86 r
F P
0 g
s
.52001 .56822 m .5185 .54313 L .52889 .54628 L p .881 .84 .8 r
F P
0 g
s
.5185 .54313 m .52001 .56822 L .51029 .56759 L p .867 .826 .805 r
F P
0 g
s
.55959 .6343 m .56109 .67354 L .55469 .67237 L p .762 .477 .501 r
F P
0 g
s
.55469 .67237 m .55344 .63313 L .55959 .6343 L p .762 .477 .501 r
F P
0 g
s
.48424 .85654 m .45118 .82759 L .45246 .83006 L p 0 .249 .761 r
F P
0 g
s
.45246 .83006 m .48493 .85787 L .48424 .85654 L p 0 .249 .761 r
F P
0 g
s
.31949 .44164 m .3261 .41347 L .32395 .43106 L p .795 .757 .241 r
F P
0 g
s
.32395 .43106 m .31745 .45788 L .31949 .44164 L p .795 .757 .241 r
F P
0 g
s
.55344 .63313 m .55469 .67237 L .54819 .67159 L p .761 .477 .503 r
F P
0 g
s
.54819 .67159 m .54727 .63242 L .55344 .63313 L p .761 .477 .503 r
F P
0 g
s
.655 .47507 m .64801 .5036 L .62683 .50627 L p .611 .438 .624 r
F P
0 g
s
.4625 .68587 m .46055 .64949 L .45561 .65133 L p .452 .271 .544 r
F P
0 g
s
.45561 .65133 m .45731 .68785 L .4625 .68587 L p .452 .271 .544 r
F P
0 g
s
.4722 .64563 m .46804 .62016 L .4616 .62229 L p .557 .41 .638 r
F P
0 g
s
.4616 .62229 m .4661 .64759 L .4722 .64563 L p .557 .41 .638 r
F P
0 g
s
.45011 .60226 m .4616 .62229 L .46804 .62016 L p .605 .6 .82 r
F P
0 g
s
.4616 .62229 m .45011 .60226 L .4441 .60484 L p .533 .559 .828 r
F P
0 g
s
.61989 .7046 m .61231 .75035 L .60904 .7474 L p .942 .716 .568 r
F P
0 g
s
.60904 .7474 m .61625 .70118 L .61989 .7046 L p .942 .716 .568 r
F P
0 g
s
.80533 .47948 m .79082 .51812 L .77182 .51037 L p .809 .627 .656 r
F P
0 g
s
.77182 .51037 m .78541 .47224 L .80533 .47948 L p .809 .627 .656 r
F P
0 g
s
.60083 .82841 m .5682 .8572 L .56881 .85586 L p .816 .995 .762 r
F P
0 g
s
.56881 .85586 m .60199 .82601 L .60083 .82841 L p .816 .995 .762 r
F P
0 g
s
.50427 .58955 m .5067 .61004 L .49884 .61179 L p .833 .696 .712 r
F P
0 g
s
.5067 .61004 m .50727 .6363 L .50004 .63795 L p .763 .537 .59 r
F P
0 g
s
.50004 .63795 m .49884 .61179 L .5067 .61004 L p .763 .537 .59 r
F P
0 g
s
.64801 .5036 m .655 .47507 L .68014 .47063 L p .626 .449 .623 r
F P
0 g
s
.42257 .58347 m .4441 .60484 L .45011 .60226 L p .534 .674 .927 r
F P
0 g
s
.4441 .60484 m .42257 .58347 L .41786 .58737 L p .426 .629 .939 r
F P
0 g
s
.53993 .52295 m .54186 .49361 L .55207 .50085 L p .886 .78 .738 r
F P
0 g
s
.54727 .63242 m .54819 .67159 L .5416 .67117 L p .759 .478 .507 r
F P
0 g
s
.5416 .67117 m .54103 .63215 L .54727 .63242 L p .759 .478 .507 r
F P
0 g
s
.62234 .76521 m .60245 .8114 L .60141 .80899 L p .987 .893 .628 r
F P
0 g
s
.60141 .80899 m .62119 .76226 L .62234 .76521 L p .987 .893 .628 r
F P
0 g
s
.50427 .58955 m .49932 .5674 L .51029 .56759 L p .864 .803 .789 r
F P
0 g
s
.49932 .5674 m .50427 .58955 L .4949 .59095 L p .836 .791 .808 r
F P
0 g
s
.49884 .61179 m .4949 .59095 L .50427 .58955 L p .833 .696 .712 r
F P
0 g
s
.48371 .85519 m .45021 .82506 L .45118 .82759 L p 0 .279 .782 r
F P
0 g
s
.45118 .82759 m .48424 .85654 L .48371 .85519 L p 0 .279 .782 r
F P
0 g
s
.69842 .53841 m .66688 .56974 L .64866 .56576 L p .65 .583 .766 r
F P
0 g
s
.64866 .56576 m .67566 .53563 L .69842 .53841 L p .65 .583 .766 r
F P
0 g
s
.67183 .50151 m .65343 .53432 L .63274 .53414 L p .63 .516 .705 r
F P
0 g
s
.63274 .53414 m .64801 .5036 L .67183 .50151 L p .63 .516 .705 r
F P
0 g
s
.44979 .74227 m .44434 .69411 L .44087 .69638 L p .33 .2 .548 r
F P
0 g
s
.44087 .69638 m .44618 .74467 L .44979 .74227 L p .33 .2 .548 r
F P
0 g
s
.45218 .80727 m .43344 .75864 L .43195 .76184 L p .13 .162 .627 r
F P
0 g
s
.43195 .76184 m .45096 .80973 L .45218 .80727 L p .13 .162 .627 r
F P
0 g
s
.52569 .87321 m .52639 .86422 L .52296 .87314 L closepath p .379 .791 .979 r
F P
0 g
s
.52841 .87319 m .52639 .86422 L .52569 .87321 L closepath p .391 .801 .979 r
F P
0 g
s
.53113 .87309 m .52639 .86422 L .52841 .87319 L closepath p .404 .811 .98 r
F P
0 g
s
.52296 .87314 m .52639 .86422 L .52025 .87299 L closepath p .369 .782 .98 r
F P
0 g
s
.53384 .87291 m .52639 .86422 L .53113 .87309 L closepath p .418 .821 .98 r
F P
0 g
s
.71408 .58789 m .75709 .55656 L .76937 .5653 L p .742 .737 .847 r
F P
0 g
s
.75709 .55656 m .71408 .58789 L .70061 .58096 L p .719 .687 .819 r
F P
0 g
s
.52025 .87299 m .52639 .86422 L .51756 .87275 L closepath p .361 .773 .98 r
F P
0 g
s
.53651 .87264 m .52639 .86422 L .53384 .87291 L closepath p .435 .832 .981 r
F P
0 g
s
.54103 .63215 m .5416 .67117 L .53492 .67111 L p .756 .48 .513 r
F P
0 g
s
.53492 .67111 m .53466 .63229 L .54103 .63215 L p .756 .48 .513 r
F P
0 g
s
.51756 .87275 m .52639 .86422 L .51491 .87243 L closepath p .354 .764 .981 r
F P
0 g
s
.4949 .59095 m .49884 .61179 L .49083 .61374 L p .802 .688 .738 r
F P
0 g
s
.49884 .61179 m .50004 .63795 L .49281 .63976 L p .738 .527 .608 r
F P
0 g
s
.49281 .63976 m .49083 .61374 L .49884 .61179 L p .738 .527 .608 r
F P
0 g
s
.3286 .49473 m .31745 .45788 L .32004 .47462 L p 0 0 .353 r
F P
0 g
s
.32004 .47462 m .33105 .50834 L .3286 .49473 L p 0 0 .353 r
F P
0 g
s
.46804 .62016 m .45753 .59965 L .45011 .60226 L p .605 .6 .82 r
F P
0 g
s
.46609 .59713 m .4752 .61798 L .46804 .62016 L p .668 .632 .805 r
F P
0 g
s
.46804 .62016 m .45753 .59965 L .46609 .59713 L p .668 .632 .805 r
F P
0 g
s
.4722 .64563 m .46804 .62016 L .4752 .61798 L p .612 .451 .639 r
F P
0 g
s
.53914 .87228 m .52639 .86422 L .53651 .87264 L closepath p .452 .842 .982 r
F P
0 g
s
.80472 .52777 m .76937 .5653 L .75709 .55656 L p .803 .735 .789 r
F P
0 g
s
.75709 .55656 m .79082 .51812 L .80472 .52777 L p .803 .735 .789 r
F P
0 g
s
.52995 .43721 m .53006 .45606 L .51475 .44373 L p .938 .609 .385 r
F P
0 g
s
.51475 .44373 m .51509 .42316 L .52995 .43721 L p .938 .609 .385 r
F P
0 g
s
.51491 .87243 m .52639 .86422 L .5123 .87203 L closepath p .35 .756 .982 r
F P
0 g
s
.52889 .54628 m .52942 .5172 L .53993 .52295 L p .88 .822 .786 r
F P
0 g
s
.52942 .5172 m .52889 .54628 L .5185 .54313 L p .877 .811 .781 r
F P
0 g
s
.60199 .82601 m .56881 .85586 L .56925 .85451 L p .853 .997 .782 r
F P
0 g
s
.56925 .85451 m .60284 .82359 L .60199 .82601 L p .853 .997 .782 r
F P
0 g
s
.54172 .87185 m .52639 .86422 L .53914 .87228 L closepath p .47 .852 .983 r
F P
0 g
s
.61625 .70118 m .60904 .7474 L .60538 .74449 L p .917 .687 .574 r
F P
0 g
s
.60538 .74449 m .6121 .69774 L .61625 .70118 L p .917 .687 .574 r
F P
0 g
s
.46809 .68393 m .4661 .64759 L .46055 .64949 L p .496 .309 .556 r
F P
0 g
s
.46055 .64949 m .4625 .68587 L .46809 .68393 L p .496 .309 .556 r
F P
0 g
s
.5123 .87203 m .52639 .86422 L .50975 .87155 L closepath p .347 .749 .983 r
F P
0 g
s
.54425 .87133 m .52639 .86422 L .54172 .87185 L closepath p .489 .861 .984 r
F P
0 g
s
.50975 .87155 m .52639 .86422 L .50726 .87099 L closepath p .345 .741 .984 r
F P
0 g
s
.49083 .61374 m .48517 .59271 L .4949 .59095 L p .802 .688 .738 r
F P
0 g
s
.48517 .59271 m .49083 .61374 L .48287 .61582 L p .766 .675 .762 r
F P
0 g
s
.49083 .61374 m .49281 .63976 L .48567 .64167 L p .705 .51 .622 r
F P
0 g
s
.48567 .64167 m .48287 .61582 L .49083 .61374 L p .705 .51 .622 r
F P
0 g
s
.53466 .63229 m .53492 .67111 L .52814 .67139 L p .751 .48 .521 r
F P
0 g
s
.52814 .67139 m .52811 .63281 L .53466 .63229 L p .751 .48 .521 r
F P
0 g
s
.47544 .59478 m .48287 .61582 L .4752 .61798 L p .722 .657 .784 r
F P
0 g
s
.4752 .61798 m .46609 .59713 L .47544 .59478 L p .722 .657 .784 r
F P
0 g
s
.47876 .64364 m .4752 .61798 L .48287 .61582 L p .664 .485 .633 r
F P
0 g
s
.4752 .61798 m .47876 .64364 L .4722 .64563 L p .612 .451 .639 r
F P
0 g
s
.5467 .87073 m .52639 .86422 L .54425 .87133 L closepath p .509 .871 .985 r
F P
0 g
s
.48336 .85382 m .44956 .82251 L .45021 .82506 L p .032 .306 .796 r
F P
0 g
s
.45021 .82506 m .48371 .85519 L .48336 .85382 L p .032 .306 .796 r
F P
0 g
s
.50726 .87099 m .52639 .86422 L .50485 .87036 L closepath p .346 .734 .985 r
F P
0 g
s
.48287 .61582 m .47544 .59478 L .48517 .59271 L p .766 .675 .762 r
F P
0 g
s
.48287 .61582 m .48567 .64167 L .47876 .64364 L p .664 .485 .633 r
F P
0 g
s
.54186 .49361 m .53993 .52295 L .52942 .5172 L p .897 .781 .725 r
F P
0 g
s
.62119 .76226 m .60141 .80899 L .60006 .8066 L p .983 .869 .645 r
F P
0 g
s
.60006 .8066 m .61962 .75929 L .62119 .76226 L p .983 .869 .645 r
F P
0 g
s
.72045 .54285 m .68454 .57484 L .66688 .56974 L p .672 .611 .779 r
F P
0 g
s
.66688 .56974 m .69842 .53841 L .72045 .54285 L p .672 .611 .779 r
F P
0 g
s
.52639 .86422 m .54907 .87006 L .5467 .87073 L closepath p .529 .879 .986 r
F P
0 g
s
.67183 .50151 m .68014 .47063 L .70715 .46748 L p .65 .469 .625 r
F P
0 g
s
.68014 .47063 m .67183 .50151 L .64801 .5036 L p .626 .449 .623 r
F P
0 g
s
.42965 .57966 m .45011 .60226 L .45753 .59965 L p .615 .704 .908 r
F P
0 g
s
.45011 .60226 m .42965 .57966 L .42257 .58347 L p .534 .674 .927 r
F P
0 g
s
.50485 .87036 m .52639 .86422 L .50252 .86965 L closepath p .347 .728 .986 r
F P
0 g
s
.36216 .37573 m .38059 .36633 L .36559 .37469 L p .361 .804 .652 r
F P
0 g
s
.36559 .37469 m .34539 .38484 L .36216 .37573 L p .361 .804 .652 r
F P
0 g
s
.4537 .80487 m .43529 .75558 L .43344 .75864 L p .195 .2 .637 r
F P
0 g
s
.43344 .75864 m .45218 .80727 L .4537 .80487 L p .195 .2 .637 r
F P
0 g
s
.70061 .58096 m .74044 .54896 L .75709 .55656 L p .719 .687 .819 r
F P
0 g
s
.74044 .54896 m .70061 .58096 L .68454 .57484 L p .696 .646 .796 r
F P
0 g
s
.45419 .38372 m .46216 .37687 L .48231 .3888 L p .757 .245 0 r
F P
0 g
s
.45374 .73998 m .44823 .69195 L .44434 .69411 L p .377 .237 .56 r
F P
0 g
s
.44434 .69411 m .44979 .74227 L .45374 .73998 L p .377 .237 .56 r
F P
0 g
s
.4949 .59095 m .48731 .56778 L .49932 .5674 L p .836 .791 .808 r
F P
0 g
s
.48731 .56778 m .4949 .59095 L .48517 .59271 L p .804 .777 .827 r
F P
0 g
s
.52639 .86422 m .55135 .86931 L .54907 .87006 L closepath p .549 .886 .986 r
F P
0 g
s
.60284 .82359 m .56925 .85451 L .56952 .85315 L p .88 .992 .796 r
F P
0 g
s
.56952 .85315 m .60339 .82115 L .60284 .82359 L p .88 .992 .796 r
F P
0 g
s
.52811 .63281 m .52814 .67139 L .52129 .67198 L p .744 .479 .53 r
F P
0 g
s
.52129 .67198 m .52135 .63368 L .52811 .63281 L p .744 .479 .53 r
F P
0 g
s
.6121 .69774 m .60538 .74449 L .60135 .74166 L p .894 .66 .577 r
F P
0 g
s
.60135 .74166 m .6075 .69431 L .6121 .69774 L p .894 .66 .577 r
F P
0 g
s
.50252 .86965 m .52639 .86422 L .50029 .86887 L closepath p .351 .721 .986 r
F P
0 g
s
.68454 .57484 m .72045 .54285 L .74044 .54896 L p .696 .646 .796 r
F P
0 g
s
.78541 .47224 m .77182 .51037 L .74893 .50485 L p .758 .572 .645 r
F P
0 g
s
.74893 .50485 m .76136 .46786 L .78541 .47224 L p .758 .572 .645 r
F P
0 g
s
.47406 .68204 m .4722 .64563 L .4661 .64759 L p .534 .34 .564 r
F P
0 g
s
.4661 .64759 m .46809 .68393 L .47406 .68204 L p .534 .34 .564 r
F P
0 g
s
.54277 .46722 m .54186 .49361 L .52985 .48495 L p .927 .726 .611 r
F P
0 g
s
.52985 .48495 m .53006 .45606 L .54277 .46722 L p .927 .726 .611 r
F P
0 g
s
.51029 .56759 m .50626 .5402 L .5185 .54313 L p .867 .826 .805 r
F P
0 g
s
.50626 .5402 m .51029 .56759 L .49932 .5674 L p .847 .809 .813 r
F P
0 g
s
.38791 .56015 m .41786 .58737 L .42257 .58347 L p .424 .63 .94 r
F P
0 g
s
.41786 .58737 m .38791 .56015 L .38588 .56653 L p .279 .57 .936 r
F P
0 g
s
.52639 .86422 m .55353 .86848 L .55135 .86931 L closepath p .569 .893 .986 r
F P
0 g
s
.50029 .86887 m .52639 .86422 L .49816 .86802 L closepath p .355 .716 .986 r
F P
0 g
s
.48319 .85245 m .44921 .81993 L .44956 .82251 L p .096 .33 .804 r
F P
0 g
s
.44956 .82251 m .48336 .85382 L .48319 .85245 L p .096 .33 .804 r
F P
0 g
s
.52135 .63368 m .52129 .67198 L .51437 .67285 L p .733 .475 .539 r
F P
0 g
s
.51437 .67285 m .51439 .63486 L .52135 .63368 L p .733 .475 .539 r
F P
0 g
s
.69743 .50068 m .67566 .53563 L .65343 .53432 L p .649 .533 .709 r
F P
0 g
s
.65343 .53432 m .67183 .50151 L .69743 .50068 L p .649 .533 .709 r
F P
0 g
s
.52639 .86422 m .55561 .86759 L .55353 .86848 L closepath p .588 .898 .986 r
F P
0 g
s
.49816 .86802 m .52639 .86422 L .49614 .86711 L closepath p .361 .71 .986 r
F P
0 g
s
.38588 .56653 m .35401 .53339 L .35587 .54317 L p .061 .408 .86 r
F P
0 g
s
.33105 .50834 m .35587 .54317 L .35401 .53339 L p 0 .21 .736 r
F P
0 g
s
.61962 .75929 m .60006 .8066 L .59839 .80424 L p .972 .841 .655 r
F P
0 g
s
.59839 .80424 m .61761 .75631 L .61962 .75929 L p .972 .841 .655 r
F P
0 g
s
.45753 .59965 m .43889 .57613 L .42965 .57966 L p .615 .704 .908 r
F P
0 g
s
.44985 .57306 m .46609 .59713 L .45753 .59965 L p .677 .727 .887 r
F P
0 g
s
.45753 .59965 m .43889 .57613 L .44985 .57306 L p .677 .727 .887 r
F P
0 g
s
.60339 .82115 m .56952 .85315 L .56961 .85178 L p .898 .98 .804 r
F P
0 g
s
.56961 .85178 m .60363 .81871 L .60339 .82115 L p .898 .98 .804 r
F P
0 g
s
.52639 .86422 m .55757 .86664 L .55561 .86759 L closepath p .606 .903 .985 r
F P
0 g
s
.6075 .69431 m .60135 .74166 L .59699 .73892 L p .872 .636 .577 r
F P
0 g
s
.59699 .73892 m .60251 .69094 L .6075 .69431 L p .872 .636 .577 r
F P
0 g
s
.47406 .68204 m .4722 .64563 L .47876 .64364 L p .575 .372 .568 r
F P
0 g
s
.48517 .59271 m .47469 .56883 L .48731 .56778 L p .804 .777 .827 r
F P
0 g
s
.47469 .56883 m .48517 .59271 L .47544 .59478 L p .768 .762 .847 r
F P
0 g
s
.69743 .50068 m .70715 .46748 L .73474 .46637 L p .68 .495 .63 r
F P
0 g
s
.70715 .46748 m .69743 .50068 L .67183 .50151 L p .65 .469 .625 r
F P
0 g
s
.45553 .80254 m .43748 .75265 L .43529 .75558 L p .252 .233 .643 r
F P
0 g
s
.43529 .75558 m .4537 .80487 L .45553 .80254 L p .252 .233 .643 r
F P
0 g
s
.51439 .63486 m .51437 .67285 L .50742 .67397 L p .718 .468 .547 r
F P
0 g
s
.50742 .67397 m .50727 .6363 L .51439 .63486 L p .718 .468 .547 r
F P
0 g
s
.49614 .86711 m .52639 .86422 L .49425 .86613 L closepath p .368 .705 .985 r
F P
0 g
s
.45804 .73781 m .45255 .68987 L .44823 .69195 L p .419 .27 .57 r
F P
0 g
s
.44823 .69195 m .45374 .73998 L .45804 .73781 L p .419 .27 .57 r
F P
0 g
s
.52639 .86422 m .5594 .86562 L .55757 .86664 L closepath p .624 .906 .984 r
F P
0 g
s
.76136 .46786 m .74893 .50485 L .72362 .50167 L p .716 .529 .636 r
F P
0 g
s
.72362 .50167 m .73474 .46637 L .76136 .46786 L p .716 .529 .636 r
F P
0 g
s
.52942 .5172 m .52985 .48495 L .54186 .49361 L p .897 .781 .725 r
F P
0 g
s
.48319 .85107 m .44918 .81735 L .44921 .81993 L p .155 .351 .807 r
F P
0 g
s
.44921 .81993 m .48319 .85245 L .48319 .85107 L p .155 .351 .807 r
F P
0 g
s
.462 .5706 m .47544 .59478 L .46609 .59713 L p .727 .745 .867 r
F P
0 g
s
.46609 .59713 m .44985 .57306 L .462 .5706 L p .727 .745 .867 r
F P
0 g
s
.47544 .59478 m .462 .5706 L .47469 .56883 L p .768 .762 .847 r
F P
0 g
s
.48034 .6802 m .47876 .64364 L .48567 .64167 L p .615 .402 .569 r
F P
0 g
s
.47876 .64364 m .48034 .6802 L .47406 .68204 L p .575 .372 .568 r
F P
0 g
s
.50727 .6363 m .50742 .67397 L .50048 .6753 L p .699 .458 .555 r
F P
0 g
s
.50048 .6753 m .50004 .63795 L .50727 .6363 L p .699 .458 .555 r
F P
0 g
s
.49425 .86613 m .52639 .86422 L .49248 .8651 L closepath p .376 .699 .984 r
F P
0 g
s
.73474 .46637 m .72362 .50167 L .69743 .50068 L p .68 .495 .63 r
F P
0 g
s
.35401 .53339 m .3286 .49473 L .33105 .50834 L p 0 .21 .736 r
F P
0 g
s
.79082 .51812 m .75709 .55656 L .74044 .54896 L p .765 .675 .763 r
F P
0 g
s
.74044 .54896 m .77182 .51037 L .79082 .51812 L p .765 .675 .763 r
F P
0 g
s
.52639 .86422 m .56111 .86455 L .5594 .86562 L closepath p .641 .908 .982 r
F P
0 g
s
.60251 .69094 m .59699 .73892 L .59232 .73631 L p .853 .614 .576 r
F P
0 g
s
.59232 .73631 m .59718 .6877 L .60251 .69094 L p .853 .614 .576 r
F P
0 g
s
.50004 .63795 m .50048 .6753 L .49362 .67681 L p .676 .444 .562 r
F P
0 g
s
.49362 .67681 m .49281 .63976 L .50004 .63795 L p .676 .444 .562 r
F P
0 g
s
.35401 .53339 m .38588 .56653 L .38791 .56015 L p .256 .502 .898 r
F P
0 g
s
.48688 .67845 m .48567 .64167 L .49281 .63976 L p .648 .425 .567 r
F P
0 g
s
.48567 .64167 m .48688 .67845 L .48034 .6802 L p .615 .402 .569 r
F P
0 g
s
.60363 .81871 m .56961 .85178 L .56952 .85041 L p .909 .964 .807 r
F P
0 g
s
.56952 .85041 m .60356 .81627 L .60363 .81871 L p .909 .964 .807 r
F P
0 g
s
.49281 .63976 m .49362 .67681 L .48688 .67845 L p .648 .425 .567 r
F P
0 g
s
.49248 .8651 m .52639 .86422 L .49084 .86401 L closepath p .385 .695 .981 r
F P
0 g
s
.43008 .37532 m .4408 .36796 L .46216 .37687 L p .687 .157 0 r
F P
0 g
s
.61761 .75631 m .59839 .80424 L .59641 .80192 L p .957 .813 .66 r
F P
0 g
s
.59641 .80192 m .61517 .75333 L .61761 .75631 L p .957 .813 .66 r
F P
0 g
s
.36216 .37573 m .38059 .36633 L .39883 .36234 L p .051 0 0 r
F P
0 g
s
.52639 .86422 m .56267 .86343 L .56111 .86455 L closepath p .656 .909 .98 r
F P
0 g
s
.45765 .80029 m .44003 .74985 L .43748 .75265 L p .302 .263 .648 r
F P
0 g
s
.43748 .75265 m .45553 .80254 L .45765 .80029 L p .302 .263 .648 r
F P
0 g
s
.72362 .50167 m .69842 .53841 L .67566 .53563 L p .673 .558 .716 r
F P
0 g
s
.67566 .53563 m .69743 .50068 L .72362 .50167 L p .673 .558 .716 r
F P
0 g
s
.5185 .54313 m .51679 .51103 L .52942 .5172 L p .877 .811 .781 r
F P
0 g
s
.51679 .51103 m .5185 .54313 L .50626 .5402 L p .864 .794 .781 r
F P
0 g
s
.46267 .73576 m .45731 .68785 L .45255 .68987 L p .457 .299 .578 r
F P
0 g
s
.45255 .68987 m .45804 .73781 L .46267 .73576 L p .457 .299 .578 r
F P
0 g
s
.49084 .86401 m .52639 .86422 L .48935 .86286 L closepath p .394 .69 .979 r
F P
0 g
s
.48338 .8497 m .44946 .81478 L .44918 .81735 L p .207 .37 .806 r
F P
0 g
s
.44918 .81735 m .48319 .85107 L .48338 .8497 L p .207 .37 .806 r
F P
0 g
s
.59718 .6877 m .59232 .73631 L .58736 .73385 L p .836 .596 .575 r
F P
0 g
s
.58736 .73385 m .59157 .68464 L .59718 .6877 L p .836 .596 .575 r
F P
0 g
s
.51509 .42316 m .51475 .44373 L .49649 .43119 L p .919 .59 .404 r
F P
0 g
s
.49649 .43119 m .49739 .40877 L .51509 .42316 L p .919 .59 .404 r
F P
0 g
s
.52639 .86422 m .56409 .86226 L .56267 .86343 L closepath p .67 .908 .977 r
F P
0 g
s
.32671 .42688 m .33323 .39771 L .3261 .41347 L p 0 0 0 r
F P
0 g
s
.3261 .41347 m .31949 .44164 L .32671 .42688 L p 0 0 0 r
F P
0 g
s
.49932 .5674 m .49221 .53783 L .50626 .5402 L p .847 .809 .813 r
F P
0 g
s
.49221 .53783 m .49932 .5674 L .48731 .56778 L p .821 .791 .824 r
F P
0 g
s
.48935 .86286 m .52639 .86422 L .48801 .86167 L closepath p .404 .686 .976 r
F P
0 g
s
.60356 .81627 m .56952 .85041 L .56925 .84905 L p .914 .944 .808 r
F P
0 g
s
.56925 .84905 m .60316 .81383 L .60356 .81627 L p .914 .944 .808 r
F P
0 g
s
.39326 .55391 m .42257 .58347 L .42965 .57966 L p .533 .67 .925 r
F P
0 g
s
.42257 .58347 m .39326 .55391 L .38791 .56015 L p .424 .63 .94 r
F P
0 g
s
.59157 .68464 m .58736 .73385 L .58215 .73157 L p .822 .58 .573 r
F P
0 g
s
.58215 .73157 m .58575 .6818 L .59157 .68464 L p .822 .58 .573 r
F P
0 g
s
.52639 .86422 m .56536 .86104 L .56409 .86226 L closepath p .683 .907 .974 r
F P
0 g
s
.52985 .48495 m .52942 .5172 L .51679 .51103 L p .891 .768 .719 r
F P
0 g
s
.77182 .51037 m .74044 .54896 L .72045 .54285 L p .731 .627 .742 r
F P
0 g
s
.61517 .75333 m .59641 .80192 L .59412 .79965 L p .94 .785 .663 r
F P
0 g
s
.59412 .79965 m .61231 .75035 L .61517 .75333 L p .94 .785 .663 r
F P
0 g
s
.48801 .86167 m .52639 .86422 L .48682 .86044 L closepath p .415 .682 .972 r
F P
0 g
s
.46006 .79812 m .44293 .74719 L .44003 .74985 L p .346 .29 .651 r
F P
0 g
s
.44003 .74985 m .45765 .80029 L .46006 .79812 L p .346 .29 .651 r
F P
0 g
s
.74893 .50485 m .72045 .54285 L .69842 .53841 L p .701 .589 .727 r
F P
0 g
s
.69842 .53841 m .72362 .50167 L .74893 .50485 L p .701 .589 .727 r
F P
0 g
s
.40579 .37091 m .4193 .36294 L .4408 .36796 L p .57 .021 0 r
F P
0 g
s
.48373 .84833 m .45006 .81224 L .44946 .81478 L p .255 .386 .804 r
F P
0 g
s
.44946 .81478 m .48338 .8497 L .48373 .84833 L p .255 .386 .804 r
F P
0 g
s
.46762 .73381 m .4625 .68587 L .45731 .68785 L p .491 .326 .584 r
F P
0 g
s
.45731 .68785 m .46267 .73576 L .46762 .73381 L p .491 .326 .584 r
F P
0 g
s
.38269 .37099 m .39883 .36234 L .4193 .36294 L p .373 0 0 r
F P
0 g
s
.39883 .36234 m .38269 .37099 L .36216 .37573 L p .051 0 0 r
F P
0 g
s
.72045 .54285 m .74893 .50485 L .77182 .51037 L p .731 .627 .742 r
F P
0 g
s
.52639 .86422 m .56647 .85979 L .56536 .86104 L closepath p .695 .905 .97 r
F P
0 g
s
.58575 .6818 m .58215 .73157 L .57672 .7295 L p .808 .566 .572 r
F P
0 g
s
.57672 .7295 m .57976 .67924 L .58575 .6818 L p .808 .566 .572 r
F P
0 g
s
.48682 .86044 m .52639 .86422 L .48579 .85917 L closepath p .425 .678 .968 r
F P
0 g
s
.53006 .45606 m .52985 .48495 L .51539 .47548 L p .918 .713 .609 r
F P
0 g
s
.51539 .47548 m .51475 .44373 L .53006 .45606 L p .918 .713 .609 r
F P
0 g
s
.4193 .36294 m .40579 .37091 L .38269 .37099 L p .373 0 0 r
F P
0 g
s
.60316 .81383 m .56925 .84905 L .56881 .84769 L p .915 .923 .805 r
F P
0 g
s
.56881 .84769 m .60245 .8114 L .60316 .81383 L p .915 .923 .805 r
F P
0 g
s
.52639 .86422 m .56742 .85851 L .56647 .85979 L closepath p .706 .902 .966 r
F P
0 g
s
.57976 .67924 m .57672 .7295 L .5711 .72766 L p .797 .554 .57 r
F P
0 g
s
.5711 .72766 m .57364 .67699 L .57976 .67924 L p .797 .554 .57 r
F P
0 g
s
.33055 .48134 m .31949 .44164 L .31745 .45788 L p 0 0 .539 r
F P
0 g
s
.31745 .45788 m .3286 .49473 L .33055 .48134 L p 0 0 .539 r
F P
0 g
s
.48579 .85917 m .52639 .86422 L .48493 .85787 L closepath p .436 .674 .964 r
F P
0 g
s
.61231 .75035 m .59412 .79965 L .59154 .79744 L p .922 .759 .663 r
F P
0 g
s
.59154 .79744 m .60904 .7474 L .61231 .75035 L p .922 .759 .663 r
F P
0 g
s
.48427 .84697 m .45096 .80973 L .45006 .81224 L p .297 .401 .8 r
F P
0 g
s
.45006 .81224 m .48373 .84833 L .48427 .84697 L p .297 .401 .8 r
F P
0 g
s
.47286 .73197 m .46809 .68393 L .4625 .68587 L p .522 .35 .589 r
F P
0 g
s
.4625 .68587 m .46762 .73381 L .47286 .73197 L p .522 .35 .589 r
F P
0 g
s
.46276 .79604 m .44618 .74467 L .44293 .74719 L p .386 .314 .654 r
F P
0 g
s
.44293 .74719 m .46006 .79812 L .46276 .79604 L p .386 .314 .654 r
F P
0 g
s
.57364 .67699 m .5711 .72766 L .5653 .72607 L p .787 .544 .569 r
F P
0 g
s
.5653 .72607 m .56741 .67508 L .57364 .67699 L p .787 .544 .569 r
F P
0 g
s
.52639 .86422 m .5682 .8572 L .56742 .85851 L closepath p .715 .897 .962 r
F P
0 g
s
.48731 .56778 m .47667 .53636 L .49221 .53783 L p .821 .791 .824 r
F P
0 g
s
.47667 .53636 m .48731 .56778 L .47469 .56883 L p .791 .772 .836 r
F P
0 g
s
.48493 .85787 m .52639 .86422 L .48424 .85654 L closepath p .447 .671 .959 r
F P
0 g
s
.60245 .8114 m .56881 .84769 L .56819 .84636 L p .912 .901 .802 r
F P
0 g
s
.56819 .84636 m .60141 .80899 L .60245 .8114 L p .912 .901 .802 r
F P
0 g
s
.56741 .67508 m .5653 .72607 L .55935 .72474 L p .777 .535 .569 r
F P
0 g
s
.55935 .72474 m .56109 .67354 L .56741 .67508 L p .777 .535 .569 r
F P
0 g
s
.52639 .86422 m .56881 .85586 L .5682 .8572 L closepath p .723 .893 .957 r
F P
0 g
s
.40195 .54816 m .42965 .57966 L .43889 .57613 L p .615 .698 .903 r
F P
0 g
s
.42965 .57966 m .40195 .54816 L .39326 .55391 L p .533 .67 .925 r
F P
0 g
s
.51679 .51103 m .51539 .47548 L .52985 .48495 L p .891 .768 .719 r
F P
0 g
s
.47836 .73025 m .47406 .68204 L .46809 .68393 L p .549 .371 .592 r
F P
0 g
s
.46809 .68393 m .47286 .73197 L .47836 .73025 L p .549 .371 .592 r
F P
0 g
s
.48498 .84564 m .45218 .80727 L .45096 .80973 L p .335 .414 .795 r
F P
0 g
s
.45096 .80973 m .48427 .84697 L .48498 .84564 L p .335 .414 .795 r
F P
0 g
s
.56109 .67354 m .55935 .72474 L .55327 .72369 L p .768 .527 .569 r
F P
0 g
s
.55327 .72369 m .55469 .67237 L .56109 .67354 L p .768 .527 .569 r
F P
0 g
s
.48424 .85654 m .52639 .86422 L .48371 .85519 L closepath p .458 .668 .954 r
F P
0 g
s
.60904 .7474 m .59154 .79744 L .58868 .7953 L p .904 .735 .662 r
F P
0 g
s
.58868 .7953 m .60538 .74449 L .60904 .7474 L p .904 .735 .662 r
F P
0 g
s
.46573 .79405 m .44979 .74227 L .44618 .74467 L p .421 .337 .655 r
F P
0 g
s
.44618 .74467 m .46276 .79604 L .46573 .79405 L p .421 .337 .655 r
F P
0 g
s
.52639 .86422 m .56925 .85451 L .56881 .85586 L closepath p .73 .887 .952 r
F P
0 g
s
.55469 .67237 m .55327 .72369 L .54708 .72291 L p .76 .52 .57 r
F P
0 g
s
.54708 .72291 m .54819 .67159 L .55469 .67237 L p .76 .52 .57 r
F P
0 g
s
.50626 .5402 m .50178 .50497 L .51679 .51103 L p .864 .794 .781 r
F P
0 g
s
.50178 .50497 m .50626 .5402 L .49221 .53783 L p .844 .774 .785 r
F P
0 g
s
.60141 .80899 m .56819 .84636 L .56739 .84504 L p .906 .878 .797 r
F P
0 g
s
.56739 .84504 m .60006 .8066 L .60141 .80899 L p .906 .878 .797 r
F P
0 g
s
.38791 .56015 m .35593 .52359 L .35401 .53339 L p .256 .502 .898 r
F P
0 g
s
.3286 .49473 m .35401 .53339 L .35593 .52359 L p .155 .347 .803 r
F P
0 g
s
.35593 .52359 m .38791 .56015 L .39326 .55391 L p .41 .567 .899 r
F P
0 g
s
.48371 .85519 m .52639 .86422 L .48336 .85382 L closepath p .469 .666 .948 r
F P
0 g
s
.47836 .73025 m .47406 .68204 L .48034 .6802 L p .578 .392 .593 r
F P
0 g
s
.54819 .67159 m .54708 .72291 L .5408 .72241 L p .751 .513 .572 r
F P
0 g
s
.5408 .72241 m .5416 .67117 L .54819 .67159 L p .751 .513 .572 r
F P
0 g
s
.49739 .40877 m .49649 .43119 L .47534 .41948 L p .89 .562 .422 r
F P
0 g
s
.47534 .41948 m .47692 .39523 L .49739 .40877 L p .89 .562 .422 r
F P
0 g
s
.52639 .86422 m .56952 .85315 L .56925 .85451 L closepath p .737 .881 .947 r
F P
0 g
s
.48586 .84433 m .4537 .80487 L .45218 .80727 L p .37 .427 .79 r
F P
0 g
s
.45218 .80727 m .48498 .84564 L .48586 .84433 L p .37 .427 .79 r
F P
0 g
s
.60538 .74449 m .58868 .7953 L .58554 .79324 L p .887 .712 .66 r
F P
0 g
s
.58554 .79324 m .60135 .74166 L .60538 .74449 L p .887 .712 .66 r
F P
0 g
s
.47469 .56883 m .46022 .53604 L .47667 .53636 L p .791 .772 .836 r
F P
0 g
s
.46022 .53604 m .47469 .56883 L .462 .5706 L p .758 .755 .85 r
F P
0 g
s
.5416 .67117 m .5408 .72241 L .53445 .72219 L p .742 .507 .574 r
F P
0 g
s
.53445 .72219 m .53492 .67111 L .5416 .67117 L p .742 .507 .574 r
F P
0 g
s
.48336 .85382 m .52639 .86422 L .48319 .85245 L closepath p .479 .664 .943 r
F P
0 g
s
.48411 .72866 m .48034 .6802 L .48688 .67845 L p .606 .413 .594 r
F P
0 g
s
.48034 .6802 m .48411 .72866 L .47836 .73025 L p .578 .392 .593 r
F P
0 g
s
.46897 .79216 m .45374 .73998 L .44979 .74227 L p .453 .357 .657 r
F P
0 g
s
.44979 .74227 m .46573 .79405 L .46897 .79216 L p .453 .357 .657 r
F P
0 g
s
.43889 .57613 m .41366 .54326 L .40195 .54816 L p .615 .698 .903 r
F P
0 g
s
.42782 .5395 m .44985 .57306 L .43889 .57613 L p .674 .719 .883 r
F P
0 g
s
.43889 .57613 m .41366 .54326 L .42782 .5395 L p .674 .719 .883 r
F P
0 g
s
.52639 .86422 m .56961 .85178 L .56952 .85315 L closepath p .742 .875 .942 r
F P
0 g
s
.53492 .67111 m .53445 .72219 L .52804 .72222 L p .731 .5 .577 r
F P
0 g
s
.52804 .72222 m .52814 .67139 L .53492 .67111 L p .731 .5 .577 r
F P
0 g
s
.60006 .8066 m .56739 .84504 L .56643 .84374 L p .899 .856 .791 r
F P
0 g
s
.56643 .84374 m .59839 .80424 L .60006 .8066 L p .899 .856 .791 r
F P
0 g
s
.33919 .41458 m .34539 .38484 L .33323 .39771 L p .026 0 .219 r
F P
0 g
s
.33323 .39771 m .32671 .42688 L .33919 .41458 L p .026 0 .219 r
F P
0 g
s
.48319 .85245 m .52639 .86422 L .48319 .85107 L closepath p .49 .662 .938 r
F P
0 g
s
.52814 .67139 m .52804 .72222 L .52161 .72252 L p .719 .492 .58 r
F P
0 g
s
.52161 .72252 m .52129 .67198 L .52814 .67139 L p .719 .492 .58 r
F P
0 g
s
.51539 .47548 m .51679 .51103 L .50178 .50497 L p .876 .749 .719 r
F P
0 g
s
.49006 .7272 m .48688 .67845 L .49362 .67681 L p .631 .431 .593 r
F P
0 g
s
.48688 .67845 m .49006 .7272 L .48411 .72866 L p .606 .413 .594 r
F P
0 g
s
.35593 .52359 m .33055 .48134 L .3286 .49473 L p .155 .347 .803 r
F P
0 g
s
.48691 .84305 m .45553 .80254 L .4537 .80487 L p .401 .439 .784 r
F P
0 g
s
.4537 .80487 m .48586 .84433 L .48691 .84305 L p .401 .439 .784 r
F P
0 g
s
.52639 .86422 m .56952 .85041 L .56961 .85178 L closepath p .746 .868 .936 r
F P
0 g
s
.462 .5706 m .44364 .53707 L .46022 .53604 L p .758 .755 .85 r
F P
0 g
s
.44364 .53707 m .462 .5706 L .44985 .57306 L p .719 .737 .865 r
F P
0 g
s
.52129 .67198 m .52161 .72252 L .51517 .72305 L p .706 .483 .583 r
F P
0 g
s
.51517 .72305 m .51437 .67285 L .52129 .67198 L p .706 .483 .583 r
F P
0 g
s
.60135 .74166 m .58554 .79324 L .58215 .79128 L p .87 .692 .658 r
F P
0 g
s
.58215 .79128 m .59699 .73892 L .60135 .74166 L p .87 .692 .658 r
F P
0 g
s
.49618 .72589 m .49362 .67681 L .50048 .6753 L p .654 .447 .591 r
F P
0 g
s
.49362 .67681 m .49618 .72589 L .49006 .7272 L p .631 .431 .593 r
F P
0 g
s
.44985 .57306 m .42782 .5395 L .44364 .53707 L p .719 .737 .865 r
F P
0 g
s
.51437 .67285 m .51517 .72305 L .50877 .7238 L p .691 .473 .586 r
F P
0 g
s
.50877 .7238 m .50742 .67397 L .51437 .67285 L p .691 .473 .586 r
F P
0 g
s
.50242 .72475 m .50048 .6753 L .50742 .67397 L p .673 .461 .589 r
F P
0 g
s
.50048 .6753 m .50242 .72475 L .49618 .72589 L p .654 .447 .591 r
F P
0 g
s
.50742 .67397 m .50877 .7238 L .50242 .72475 L p .673 .461 .589 r
F P
0 g
s
.48319 .85107 m .52639 .86422 L .48338 .8497 L closepath p .5 .66 .933 r
F P
0 g
s
.47245 .79037 m .45804 .73781 L .45374 .73998 L p .482 .376 .657 r
F P
0 g
s
.45374 .73998 m .46897 .79216 L .47245 .79037 L p .482 .376 .657 r
F P
0 g
s
.59839 .80424 m .56643 .84374 L .5653 .84248 L p .89 .834 .785 r
F P
0 g
s
.5653 .84248 m .59641 .80192 L .59839 .80424 L p .89 .834 .785 r
F P
0 g
s
.52639 .86422 m .56925 .84905 L .56952 .85041 L closepath p .749 .86 .931 r
F P
0 g
s
.51475 .44373 m .51539 .47548 L .49813 .46596 L p .899 .691 .613 r
F P
0 g
s
.49813 .46596 m .49649 .43119 L .51475 .44373 L p .899 .691 .613 r
F P
0 g
s
.48338 .8497 m .52639 .86422 L .48373 .84833 L closepath p .51 .659 .927 r
F P
0 g
s
.48813 .84181 m .45765 .80029 L .45553 .80254 L p .429 .449 .779 r
F P
0 g
s
.45553 .80254 m .48691 .84305 L .48813 .84181 L p .429 .449 .779 r
F P
0 g
s
.59699 .73892 m .58215 .79128 L .57851 .78942 L p .855 .673 .656 r
F P
0 g
s
.57851 .78942 m .59232 .73631 L .59699 .73892 L p .855 .673 .656 r
F P
0 g
s
.52639 .86422 m .56881 .84769 L .56925 .84905 L closepath p .751 .853 .926 r
F P
0 g
s
.48373 .84833 m .52639 .86422 L .48427 .84697 L closepath p .52 .658 .922 r
F P
0 g
s
.47618 .7887 m .46267 .73576 L .45804 .73781 L p .509 .394 .658 r
F P
0 g
s
.45804 .73781 m .47245 .79037 L .47618 .7887 L p .509 .394 .658 r
F P
0 g
s
.59641 .80192 m .5653 .84248 L .564 .84126 L p .88 .814 .779 r
F P
0 g
s
.564 .84126 m .59412 .79965 L .59641 .80192 L p .88 .814 .779 r
F P
0 g
s
.52639 .86422 m .56819 .84636 L .56881 .84769 L closepath p .753 .845 .92 r
F P
0 g
s
.59232 .73631 m .57851 .78942 L .57465 .78769 L p .84 .656 .653 r
F P
0 g
s
.57465 .78769 m .58736 .73385 L .59232 .73631 L p .84 .656 .653 r
F P
0 g
s
.49221 .53783 m .48443 .4996 L .50178 .50497 L p .844 .774 .785 r
F P
0 g
s
.48443 .4996 m .49221 .53783 L .47667 .53636 L p .818 .753 .791 r
F P
0 g
s
.48951 .84061 m .46006 .79812 L .45765 .80029 L p .455 .46 .774 r
F P
0 g
s
.45765 .80029 m .48813 .84181 L .48951 .84061 L p .455 .46 .774 r
F P
0 g
s
.52639 .86422 m .56739 .84504 L .56819 .84636 L closepath p .753 .837 .915 r
F P
0 g
s
.52639 .86422 m .56643 .84374 L .56739 .84504 L closepath p .754 .829 .91 r
F P
0 g
s
.52639 .86422 m .5653 .84248 L .56643 .84374 L closepath p .753 .821 .905 r
F P
0 g
s
.52639 .86422 m .564 .84126 L .5653 .84248 L closepath p .752 .813 .9 r
F P
0 g
s
.52639 .86422 m .56255 .84007 L .564 .84126 L closepath p .75 .804 .896 r
F P
0 g
s
.52639 .86422 m .56094 .83894 L .56255 .84007 L closepath p .748 .797 .892 r
F P
0 g
s
.52639 .86422 m .55919 .83785 L .56094 .83894 L closepath p .746 .789 .888 r
F P
0 g
s
.52639 .86422 m .55729 .83682 L .55919 .83785 L closepath p .743 .781 .884 r
F P
0 g
s
.52639 .86422 m .55527 .83586 L .55729 .83682 L closepath p .74 .774 .88 r
F P
0 g
s
.52639 .86422 m .55313 .83496 L .55527 .83586 L closepath p .736 .767 .877 r
F P
0 g
s
.52639 .86422 m .55087 .83413 L .55313 .83496 L closepath p .733 .76 .874 r
F P
0 g
s
.52639 .86422 m .5485 .83337 L .55087 .83413 L closepath p .729 .753 .872 r
F P
0 g
s
.52639 .86422 m .54605 .8327 L .5485 .83337 L closepath p .724 .747 .87 r
F P
0 g
s
.52639 .86422 m .5435 .8321 L .54605 .8327 L closepath p .72 .74 .868 r
F P
0 g
s
.52639 .86422 m .54089 .83159 L .5435 .8321 L closepath p .715 .734 .866 r
F P
0 g
s
.52639 .86422 m .53821 .83117 L .54089 .83159 L closepath p .711 .728 .864 r
F P
0 g
s
.52639 .86422 m .53548 .83083 L .53821 .83117 L closepath p .706 .723 .863 r
F P
0 g
s
.52639 .86422 m .53272 .83058 L .53548 .83083 L closepath p .7 .718 .862 r
F P
0 g
s
.52639 .86422 m .52992 .83043 L .53272 .83058 L closepath p .695 .712 .862 r
F P
0 g
s
.52639 .86422 m .52711 .83036 L .52992 .83043 L closepath p .69 .707 .861 r
F P
0 g
s
.52639 .86422 m .5243 .83039 L .52711 .83036 L closepath p .684 .703 .861 r
F P
0 g
s
.52639 .86422 m .52149 .8305 L .5243 .83039 L closepath p .678 .698 .862 r
F P
0 g
s
.52639 .86422 m .51871 .83071 L .52149 .8305 L closepath p .672 .694 .862 r
F P
0 g
s
.52639 .86422 m .51596 .83101 L .51871 .83071 L closepath p .665 .69 .863 r
F P
0 g
s
.52639 .86422 m .51326 .83139 L .51596 .83101 L closepath p .659 .686 .864 r
F P
0 g
s
.52639 .86422 m .51061 .83186 L .51326 .83139 L closepath p .652 .682 .865 r
F P
0 g
s
.52639 .86422 m .50803 .83241 L .51061 .83186 L closepath p .645 .678 .867 r
F P
0 g
s
.52639 .86422 m .50552 .83305 L .50803 .83241 L closepath p .638 .675 .869 r
F P
0 g
s
.49455 .83731 m .52639 .86422 L .49651 .83632 L closepath p .6 .663 .883 r
F P
0 g
s
.49272 .83836 m .52639 .86422 L .49455 .83731 L closepath p .592 .661 .886 r
F P
0 g
s
.49104 .83946 m .52639 .86422 L .49272 .83836 L closepath p .583 .66 .89 r
F P
0 g
s
.48951 .84061 m .52639 .86422 L .49104 .83946 L closepath p .575 .658 .894 r
F P
0 g
s
.48813 .84181 m .52639 .86422 L .48951 .84061 L closepath p .566 .658 .898 r
F P
0 g
s
.48691 .84305 m .52639 .86422 L .48813 .84181 L closepath p .557 .657 .903 r
F P
0 g
s
.48586 .84433 m .52639 .86422 L .48691 .84305 L closepath p .548 .657 .907 r
F P
0 g
s
.48498 .84564 m .52639 .86422 L .48586 .84433 L closepath p .539 .657 .912 r
F P
0 g
s
.48427 .84697 m .52639 .86422 L .48498 .84564 L closepath p .53 .657 .917 r
F P
0 g
s
.50311 .83376 m .52639 .86422 L .50552 .83305 L closepath p .631 .672 .871 r
F P
0 g
s
.5008 .83454 m .52639 .86422 L .50311 .83376 L closepath p .623 .669 .874 r
F P
0 g
s
.49859 .8354 m .52639 .86422 L .5008 .83454 L closepath p .616 .667 .876 r
F P
0 g
s
.49651 .83632 m .52639 .86422 L .49859 .8354 L closepath p .608 .665 .879 r
F P
0 g
s
.50178 .50497 m .49813 .46596 L .51539 .47548 L p .876 .749 .719 r
F P
0 g
s
.47692 .39523 m .47534 .41948 L .45181 .4097 L p .851 .525 .435 r
F P
0 g
s
.45181 .4097 m .45419 .38372 L .47692 .39523 L p .851 .525 .435 r
F P
0 g
s
.36209 .51431 m .39326 .55391 L .40195 .54816 L p .523 .611 .882 r
F P
0 g
s
.39326 .55391 m .36209 .51431 L .35593 .52359 L p .41 .567 .899 r
F P
0 g
s
.59412 .79965 m .564 .84126 L .56255 .84007 L p .87 .794 .773 r
F P
0 g
s
.56255 .84007 m .59154 .79744 L .59412 .79965 L p .87 .794 .773 r
F P
0 g
s
.48013 .78713 m .46762 .73381 L .46267 .73576 L p .533 .41 .658 r
F P
0 g
s
.46267 .73576 m .47618 .7887 L .48013 .78713 L p .533 .41 .658 r
F P
0 g
s
.33741 .46896 m .32671 .42688 L .31949 .44164 L p .165 .184 .635 r
F P
0 g
s
.31949 .44164 m .33055 .48134 L .33741 .46896 L p .165 .184 .635 r
F P
0 g
s
.58736 .73385 m .57465 .78769 L .57058 .78609 L p .827 .641 .651 r
F P
0 g
s
.57058 .78609 m .58215 .73157 L .58736 .73385 L p .827 .641 .651 r
F P
0 g
s
.49104 .83946 m .46276 .79604 L .46006 .79812 L p .479 .47 .769 r
F P
0 g
s
.46006 .79812 m .48951 .84061 L .49104 .83946 L p .479 .47 .769 r
F P
0 g
s
.58215 .73157 m .57058 .78609 L .56632 .78463 L p .814 .627 .65 r
F P
0 g
s
.56632 .78463 m .57672 .7295 L .58215 .73157 L p .814 .627 .65 r
F P
0 g
s
.59154 .79744 m .56255 .84007 L .56094 .83894 L p .859 .775 .768 r
F P
0 g
s
.56094 .83894 m .58868 .7953 L .59154 .79744 L p .859 .775 .768 r
F P
0 g
s
.48429 .78569 m .47286 .73197 L .46762 .73381 L p .555 .425 .658 r
F P
0 g
s
.46762 .73381 m .48013 .78713 L .48429 .78569 L p .555 .425 .658 r
F P
0 g
s
.35649 .40557 m .36216 .37573 L .34539 .38484 L p .339 .066 .344 r
F P
0 g
s
.34539 .38484 m .33919 .41458 L .35649 .40557 L p .339 .066 .344 r
F P
0 g
s
.49272 .83836 m .46573 .79405 L .46276 .79604 L p .501 .479 .765 r
F P
0 g
s
.46276 .79604 m .49104 .83946 L .49272 .83836 L p .501 .479 .765 r
F P
0 g
s
.33055 .48134 m .35593 .52359 L .36209 .51431 L p .349 .445 .818 r
F P
0 g
s
.57672 .7295 m .56632 .78463 L .56189 .78332 L p .802 .614 .648 r
F P
0 g
s
.56189 .78332 m .5711 .72766 L .57672 .7295 L p .802 .614 .648 r
F P
0 g
s
.49813 .46596 m .50178 .50497 L .48443 .4996 L p .853 .726 .723 r
F P
0 g
s
.48864 .78436 m .47836 .73025 L .47286 .73197 L p .576 .439 .657 r
F P
0 g
s
.47286 .73197 m .48429 .78569 L .48864 .78436 L p .576 .439 .657 r
F P
0 g
s
.58868 .7953 m .56094 .83894 L .55919 .83785 L p .849 .758 .763 r
F P
0 g
s
.55919 .83785 m .58554 .79324 L .58868 .7953 L p .849 .758 .763 r
F P
0 g
s
.5711 .72766 m .56189 .78332 L .5573 .78218 L p .79 .603 .647 r
F P
0 g
s
.5573 .78218 m .5653 .72607 L .5711 .72766 L p .79 .603 .647 r
F P
0 g
s
.49455 .83731 m .46897 .79216 L .46573 .79405 L p .521 .488 .761 r
F P
0 g
s
.46573 .79405 m .49272 .83836 L .49455 .83731 L p .521 .488 .761 r
F P
0 g
s
.47667 .53636 m .46515 .49549 L .48443 .4996 L p .818 .753 .791 r
F P
0 g
s
.46515 .49549 m .47667 .53636 L .46022 .53604 L p .788 .732 .801 r
F P
0 g
s
.48864 .78436 m .47836 .73025 L .48411 .72866 L p .597 .453 .656 r
F P
0 g
s
.58554 .79324 m .55919 .83785 L .55729 .83682 L p .838 .742 .758 r
F P
0 g
s
.55729 .83682 m .58215 .79128 L .58554 .79324 L p .838 .742 .758 r
F P
0 g
s
.5653 .72607 m .5573 .78218 L .55258 .7812 L p .779 .592 .646 r
F P
0 g
s
.55258 .7812 m .55935 .72474 L .5653 .72607 L p .779 .592 .646 r
F P
0 g
s
.49649 .43119 m .49813 .46596 L .47814 .45722 L p .872 .665 .62 r
F P
0 g
s
.47814 .45722 m .47534 .41948 L .49649 .43119 L p .872 .665 .62 r
F P
0 g
s
.45419 .38372 m .45181 .4097 L .42683 .40282 L p .802 .478 .442 r
F P
0 g
s
.42683 .40282 m .43008 .37532 L .45419 .38372 L p .802 .478 .442 r
F P
0 g
s
.49651 .83632 m .47245 .79037 L .46897 .79216 L p .54 .497 .757 r
F P
0 g
s
.46897 .79216 m .49455 .83731 L .49651 .83632 L p .54 .497 .757 r
F P
0 g
s
.37252 .50615 m .40195 .54816 L .41366 .54326 L p .607 .644 .861 r
F P
0 g
s
.40195 .54816 m .37252 .50615 L .36209 .51431 L p .523 .611 .882 r
F P
0 g
s
.49315 .78317 m .48411 .72866 L .49006 .7272 L p .617 .467 .655 r
F P
0 g
s
.48411 .72866 m .49315 .78317 L .48864 .78436 L p .597 .453 .656 r
F P
0 g
s
.36209 .51431 m .33741 .46896 L .33055 .48134 L p .349 .445 .818 r
F P
0 g
s
.55935 .72474 m .55258 .7812 L .54775 .7804 L p .769 .582 .646 r
F P
0 g
s
.54775 .7804 m .55327 .72369 L .55935 .72474 L p .769 .582 .646 r
F P
0 g
s
.58215 .79128 m .55729 .83682 L .55527 .83586 L p .827 .727 .754 r
F P
0 g
s
.55527 .83586 m .57851 .78942 L .58215 .79128 L p .827 .727 .754 r
F P
0 g
s
.55327 .72369 m .54775 .7804 L .54282 .77978 L p .758 .572 .646 r
F P
0 g
s
.54282 .77978 m .54708 .72291 L .55327 .72369 L p .758 .572 .646 r
F P
0 g
s
.49782 .78212 m .49006 .7272 L .49618 .72589 L p .636 .48 .654 r
F P
0 g
s
.49006 .7272 m .49782 .78212 L .49315 .78317 L p .617 .467 .655 r
F P
0 g
s
.49859 .8354 m .47618 .7887 L .47245 .79037 L p .558 .506 .753 r
F P
0 g
s
.47245 .79037 m .49651 .83632 L .49859 .8354 L p .558 .506 .753 r
F P
0 g
s
.54708 .72291 m .54282 .77978 L .53783 .77935 L p .747 .563 .646 r
F P
0 g
s
.53783 .77935 m .5408 .72241 L .54708 .72291 L p .747 .563 .646 r
F P
0 g
s
.35649 .40557 m .36216 .37573 L .38269 .37099 L p .531 .231 .404 r
F P
0 g
s
.50261 .7812 m .49618 .72589 L .50242 .72475 L p .653 .492 .653 r
F P
0 g
s
.49618 .72589 m .50261 .7812 L .49782 .78212 L p .636 .48 .654 r
F P
0 g
s
.57851 .78942 m .55527 .83586 L .55313 .83496 L p .817 .712 .75 r
F P
0 g
s
.55313 .83496 m .57465 .78769 L .57851 .78942 L p .817 .712 .75 r
F P
0 g
s
.5408 .72241 m .53783 .77935 L .53278 .77909 L p .736 .553 .646 r
F P
0 g
s
.53278 .77909 m .53445 .72219 L .5408 .72241 L p .736 .553 .646 r
F P
0 g
s
.50751 .78044 m .50242 .72475 L .50877 .7238 L p .67 .504 .651 r
F P
0 g
s
.50242 .72475 m .50751 .78044 L .50261 .7812 L p .653 .492 .653 r
F P
0 g
s
.53445 .72219 m .53278 .77909 L .5277 .77901 L p .724 .544 .647 r
F P
0 g
s
.5277 .77901 m .52804 .72222 L .53445 .72219 L p .724 .544 .647 r
F P
0 g
s
.51249 .77983 m .50877 .7238 L .51517 .72305 L p .685 .514 .65 r
F P
0 g
s
.50877 .7238 m .51249 .77983 L .50751 .78044 L p .67 .504 .651 r
F P
0 g
s
.52804 .72222 m .5277 .77901 L .52261 .77912 L p .712 .535 .648 r
F P
0 g
s
.52261 .77912 m .52161 .72252 L .52804 .72222 L p .712 .535 .648 r
F P
0 g
s
.5008 .83454 m .48013 .78713 L .47618 .7887 L p .575 .514 .75 r
F P
0 g
s
.47618 .7887 m .49859 .8354 L .5008 .83454 L p .575 .514 .75 r
F P
0 g
s
.48443 .4996 m .47814 .45722 L .49813 .46596 L p .853 .726 .723 r
F P
0 g
s
.51753 .77939 m .51517 .72305 L .52161 .72252 L p .699 .525 .649 r
F P
0 g
s
.51517 .72305 m .51753 .77939 L .51249 .77983 L p .685 .514 .65 r
F P
0 g
s
.52161 .72252 m .52261 .77912 L .51753 .77939 L p .699 .525 .649 r
F P
0 g
s
.46022 .53604 m .44467 .49317 L .46515 .49549 L p .788 .732 .801 r
F P
0 g
s
.44467 .49317 m .46022 .53604 L .44364 .53707 L p .753 .711 .812 r
F P
0 g
s
.57465 .78769 m .55313 .83496 L .55087 .83413 L p .807 .699 .746 r
F P
0 g
s
.55087 .83413 m .57058 .78609 L .57465 .78769 L p .807 .699 .746 r
F P
0 g
s
.43008 .37532 m .42683 .40282 L .40165 .39959 L p .738 .419 .441 r
F P
0 g
s
.40165 .39959 m .40579 .37091 L .43008 .37532 L p .738 .419 .441 r
F P
0 g
s
.48013 .78713 m .5008 .83454 L .50311 .83376 L p .59 .523 .747 r
F P
0 g
s
.41366 .54326 m .38686 .49962 L .37252 .50615 L p .607 .644 .861 r
F P
0 g
s
.40437 .49516 m .42782 .5395 L .41366 .54326 L p .668 .669 .841 r
F P
0 g
s
.41366 .54326 m .38686 .49962 L .40437 .49516 L p .668 .669 .841 r
F P
0 g
s
.34924 .45839 m .33919 .41458 L .32671 .42688 L p .384 .323 .665 r
F P
0 g
s
.32671 .42688 m .33741 .46896 L .34924 .45839 L p .384 .323 .665 r
F P
0 g
s
.57058 .78609 m .55087 .83413 L .5485 .83337 L p .797 .687 .743 r
F P
0 g
s
.50311 .83376 m .48429 .78569 L .48013 .78713 L p .59 .523 .747 r
F P
0 g
s
.48429 .78569 m .50311 .83376 L .50552 .83305 L p .605 .531 .745 r
F P
0 g
s
.5485 .83337 m .56632 .78463 L .57058 .78609 L p .797 .687 .743 r
F P
0 g
s
.56632 .78463 m .5485 .83337 L .54605 .8327 L p .787 .675 .741 r
F P
0 g
s
.37773 .40048 m .38269 .37099 L .40579 .37091 L p .654 .341 .431 r
F P
0 g
s
.38269 .37099 m .37773 .40048 L .35649 .40557 L p .531 .231 .404 r
F P
0 g
s
.50552 .83305 m .48864 .78436 L .48429 .78569 L p .605 .531 .745 r
F P
0 g
s
.49315 .78317 m .50803 .83241 L .50552 .83305 L p .62 .539 .742 r
F P
0 g
s
.50552 .83305 m .48864 .78436 L .49315 .78317 L p .62 .539 .742 r
F P
0 g
s
.54605 .8327 m .56189 .78332 L .56632 .78463 L p .787 .675 .741 r
F P
0 g
s
.56189 .78332 m .54605 .8327 L .5435 .8321 L p .777 .664 .738 r
F P
0 g
s
.47814 .45722 m .48443 .4996 L .46515 .49549 L p .825 .702 .729 r
F P
0 g
s
.49782 .78212 m .51061 .83186 L .50803 .83241 L p .634 .548 .74 r
F P
0 g
s
.50803 .83241 m .49315 .78317 L .49782 .78212 L p .634 .548 .74 r
F P
0 g
s
.40579 .37091 m .40165 .39959 L .37773 .40048 L p .654 .341 .431 r
F P
0 g
s
.33741 .46896 m .36209 .51431 L .37252 .50615 L p .486 .511 .808 r
F P
0 g
s
.44364 .53707 m .42403 .49299 L .44467 .49317 L p .753 .711 .812 r
F P
0 g
s
.42403 .49299 m .44364 .53707 L .42782 .5395 L p .714 .69 .826 r
F P
0 g
s
.5435 .8321 m .5573 .78218 L .56189 .78332 L p .777 .664 .738 r
F P
0 g
s
.5573 .78218 m .5435 .8321 L .54089 .83159 L p .767 .654 .737 r
F P
0 g
s
.42782 .5395 m .40437 .49516 L .42403 .49299 L p .714 .69 .826 r
F P
0 g
s
.50261 .7812 m .51326 .83139 L .51061 .83186 L p .648 .556 .738 r
F P
0 g
s
.51061 .83186 m .49782 .78212 L .50261 .7812 L p .648 .556 .738 r
F P
0 g
s
.54089 .83159 m .55258 .7812 L .5573 .78218 L p .767 .654 .737 r
F P
0 g
s
.55258 .7812 m .54089 .83159 L .53821 .83117 L p .758 .644 .735 r
F P
0 g
s
.50751 .78044 m .51596 .83101 L .51326 .83139 L p .661 .565 .736 r
F P
0 g
s
.51326 .83139 m .50261 .7812 L .50751 .78044 L p .661 .565 .736 r
F P
0 g
s
.53821 .83117 m .54775 .7804 L .55258 .7812 L p .758 .644 .735 r
F P
0 g
s
.54775 .7804 m .53821 .83117 L .53548 .83083 L p .748 .634 .734 r
F P
0 g
s
.51249 .77983 m .51871 .83071 L .51596 .83101 L p .673 .573 .735 r
F P
0 g
s
.51596 .83101 m .50751 .78044 L .51249 .77983 L p .673 .573 .735 r
F P
0 g
s
.53548 .83083 m .54282 .77978 L .54775 .7804 L p .748 .634 .734 r
F P
0 g
s
.54282 .77978 m .53548 .83083 L .53272 .83058 L p .738 .625 .733 r
F P
0 g
s
.51753 .77939 m .52149 .8305 L .51871 .83071 L p .685 .582 .734 r
F P
0 g
s
.51871 .83071 m .51249 .77983 L .51753 .77939 L p .685 .582 .734 r
F P
0 g
s
.53272 .83058 m .53783 .77935 L .54282 .77978 L p .738 .625 .733 r
F P
0 g
s
.53783 .77935 m .53272 .83058 L .52992 .83043 L p .728 .616 .733 r
F P
0 g
s
.52261 .77912 m .5243 .83039 L .52149 .8305 L p .696 .59 .733 r
F P
0 g
s
.52149 .8305 m .51753 .77939 L .52261 .77912 L p .696 .59 .733 r
F P
0 g
s
.52992 .83043 m .53278 .77909 L .53783 .77935 L p .728 .616 .733 r
F P
0 g
s
.53278 .77909 m .52992 .83043 L .52711 .83036 L p .718 .607 .733 r
F P
0 g
s
.5277 .77901 m .52711 .83036 L .5243 .83039 L p .707 .599 .733 r
F P
0 g
s
.5243 .83039 m .52261 .77912 L .5277 .77901 L p .707 .599 .733 r
F P
0 g
s
.52711 .83036 m .5277 .77901 L .53278 .77909 L p .718 .607 .733 r
F P
0 g
s
.47534 .41948 m .47814 .45722 L .45589 .45013 L p .839 .636 .628 r
F P
0 g
s
.45589 .45013 m .45181 .4097 L .47534 .41948 L p .839 .636 .628 r
F P
0 g
s
.37252 .50615 m .34924 .45839 L .33741 .46896 L p .486 .511 .808 r
F P
0 g
s
.46515 .49549 m .45589 .45013 L .47814 .45722 L p .825 .702 .729 r
F P
0 g
s
.45589 .45013 m .46515 .49549 L .44467 .49317 L p .791 .677 .738 r
F P
0 g
s
.36565 .45034 m .35649 .40557 L .33919 .41458 L p .528 .415 .668 r
F P
0 g
s
.33919 .41458 m .34924 .45839 L .36565 .45034 L p .528 .415 .668 r
F P
0 g
s
.34924 .45839 m .37252 .50615 L .38686 .49962 L p .585 .559 .791 r
F P
0 g
s
.45181 .4097 m .45589 .45013 L .43226 .44544 L p .799 .604 .637 r
F P
0 g
s
.43226 .44544 m .42683 .40282 L .45181 .4097 L p .799 .604 .637 r
F P
0 g
s
.44467 .49317 m .43226 .44544 L .45589 .45013 L p .791 .677 .738 r
F P
0 g
s
.43226 .44544 m .44467 .49317 L .42403 .49299 L p .753 .651 .748 r
F P
0 g
s
.38686 .49962 m .36565 .45034 L .34924 .45839 L p .585 .559 .791 r
F P
0 g
s
.38577 .44537 m .40437 .49516 L .38686 .49962 L p .655 .594 .774 r
F P
0 g
s
.38686 .49962 m .36565 .45034 L .38577 .44537 L p .655 .594 .774 r
F P
0 g
s
.36565 .45034 m .35649 .40557 L .37773 .40048 L p .626 .479 .663 r
F P
0 g
s
.42683 .40282 m .43226 .44544 L .40843 .44375 L p .753 .568 .646 r
F P
0 g
s
.40843 .44375 m .40165 .39959 L .42683 .40282 L p .753 .568 .646 r
F P
0 g
s
.42403 .49299 m .40843 .44375 L .43226 .44544 L p .753 .651 .748 r
F P
0 g
s
.40843 .44375 m .42403 .49299 L .40437 .49516 L p .708 .623 .76 r
F P
0 g
s
.40437 .49516 m .38577 .44537 L .40843 .44375 L p .708 .623 .76 r
F P
0 g
s
.38577 .44537 m .37773 .40048 L .40165 .39959 L p .697 .527 .654 r
F P
0 g
s
.37773 .40048 m .38577 .44537 L .36565 .45034 L p .626 .479 .663 r
F P
0 g
s
.40165 .39959 m .40843 .44375 L .38577 .44537 L p .697 .527 .654 r
F P
0 g
s
.25 Mabswid
.67201 0 m
.92731 .41559 L
s
.92731 .41559 m
1 .94836 L
s
1 .94836 m
.70577 .58502 L
s
.70577 .58502 m
.67201 0 L
s
.08828 .24537 m
0 .80321 L
s
0 .80321 m
.70577 .58502 L
s
.70577 .58502 m
.67201 0 L
s
.67201 0 m
.08828 .24537 L
s
.08828 .24537 m
.67201 0 L
s
.18312 .20551 m
.18804 .21088 L
s
[(-0.01)] .17327 .19475 .91505 1 Mshowa
.36332 .12976 m
.36786 .13546 L
s
[(0)] .35423 .11836 .79742 1 Mshowa
.55738 .04818 m
.56148 .05421 L
s
[(0.01)] .54918 .03613 .6798 1 Mshowa
.125 Mabswid
.21812 .19079 m
.22103 .19406 L
s
.25363 .17587 m
.2565 .17917 L
s
.28966 .16072 m
.29248 .16406 L
s
.32622 .14535 m
.32899 .14873 L
s
.40097 .11393 m
.40365 .11739 L
s
.43919 .09786 m
.44182 .10136 L
s
.47799 .08156 m
.48056 .08509 L
s
.51738 .065 m
.5199 .06857 L
s
.14861 .22001 m
.1516 .2232 L
s
.11459 .23431 m
.11762 .23746 L
s
.598 .03111 m
.60039 .03477 L
s
.63925 .01377 m
.64159 .01747 L
s
.25 Mabswid
0 .80321 m
.40091 1.08568 L
s
.08573 .86361 m
.08667 .85638 L
s
[(-0.01)] .08385 .87807 .13011 -1 Mshowa
.22213 .95971 m
.22276 .95245 L
s
[(0)] .22086 .97424 .08736 -1 Mshowa
.34085 1.04337 m
.34123 1.03609 L
s
[(0.01)] .3401 1.05793 .05202 -1 Mshowa
.125 Mabswid
.11461 .88396 m
.11513 .87962 L
s
.14265 .90372 m
.14314 .89937 L
s
.1699 .92292 m
.17035 .91857 L
s
.19638 .94157 m
.19679 .93722 L
s
.24717 .97736 m
.24752 .973 L
s
.27154 .99453 m
.27185 .99017 L
s
.29526 1.01124 m
.29554 1.00688 L
s
.31835 1.02751 m
.31861 1.02315 L
s
.05597 .84265 m
.05658 .83832 L
s
.02531 .82104 m
.02596 .81672 L
s
.36278 1.05881 m
.36298 1.05444 L
s
.38415 1.07387 m
.38432 1.0695 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{265.25, 287.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 264.25}, {286.938, 0}} -> {-0.0325185, -0.0405773, \
0.00355188, 0.00355188}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics3D", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"],

Cell[BoxData["\<\"copper.pdf\"\>"], "Output"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{949, 621},
WindowMargins->{{6, Automatic}, {Automatic, 4}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 350, 8, 77, "Input"],
Cell[1684, 48, 72, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1793, 53, 76, 0, 73, "Section"],
Cell[CellGroupData[{
Cell[1894, 57, 691, 19, 77, "Input"],
Cell[2588, 78, 737, 26, 31, "Output"],
Cell[3328, 106, 2555, 86, 72, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5920, 197, 680, 19, 55, "Input"],
Cell[6603, 218, 9260, 251, 292, "Output"]
}, Open  ]],
Cell[15878, 472, 1339, 39, 64, "Input"],
Cell[CellGroupData[{
Cell[17242, 515, 229, 6, 27, "Input"],
Cell[17474, 523, 255, 8, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17766, 536, 234, 6, 27, "Input"],
Cell[18003, 544, 255, 8, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18295, 557, 218, 6, 27, "Input"],
Cell[18516, 565, 2574, 62, 184, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21139, 633, 113, 3, 72, "Section"],
Cell[CellGroupData[{
Cell[21277, 640, 1469, 44, 59, "Input"],
Cell[22749, 686, 872, 29, 27, "Output"],
Cell[23624, 717, 872, 29, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24533, 751, 180, 5, 27, "Input"],
Cell[24716, 758, 407, 14, 27, "Output"]
}, Open  ]],
Cell[25138, 775, 641, 19, 27, "Input"],
Cell[CellGroupData[{
Cell[25804, 798, 223, 6, 27, "Input"],
Cell[26030, 806, 447, 11, 130, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26514, 822, 28, 0, 27, "Input"],
Cell[26545, 824, 779, 26, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27361, 855, 177, 5, 27, "Input"],
Cell[27541, 862, 2229, 59, 184, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29807, 926, 66, 1, 43, "Input"],
Cell[29876, 929, 2809, 83, 91, "Output"]
}, Open  ]],
Cell[32700, 1015, 707, 20, 43, "Input"],
Cell[CellGroupData[{
Cell[33432, 1039, 181, 5, 27, "Input"],
Cell[33616, 1046, 447, 11, 130, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34100, 1062, 177, 5, 27, "Input"],
Cell[34280, 1069, 519, 11, 130, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34836, 1085, 177, 5, 27, "Input"],
Cell[35016, 1092, 2574, 62, 171, "Output"]
}, Open  ]],
Cell[37605, 1157, 4301, 109, 315, "Input"],
Cell[CellGroupData[{
Cell[41931, 1270, 184, 5, 27, "Input"],
Cell[42118, 1277, 1395, 55, 207, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43550, 1337, 188, 5, 27, "Input"],
Cell[43741, 1344, 414, 10, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44192, 1359, 169, 5, 27, "Input"],
Cell[44364, 1366, 1521, 55, 141, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45922, 1426, 168, 5, 27, "Input"],
Cell[46093, 1433, 2574, 62, 171, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[48716, 1501, 118, 3, 72, "Section"],
Cell[CellGroupData[{
Cell[48859, 1508, 218, 6, 27, "Input"],
Cell[49080, 1516, 2574, 62, 171, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51691, 1583, 235, 6, 27, "Input"],
Cell[51929, 1591, 450, 10, 117, "Output"]
}, Open  ]],
Cell[52394, 1604, 818, 19, 91, "Input"],
Cell[CellGroupData[{
Cell[53237, 1627, 161, 4, 27, "Input"],
Cell[53401, 1633, 1125, 37, 159, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54563, 1675, 139, 4, 27, "Input"],
Cell[54705, 1681, 1485, 55, 141, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[56239, 1742, 62, 0, 72, "Section"],
Cell[CellGroupData[{
Cell[56326, 1746, 703, 20, 43, "Input"],
Cell[57032, 1768, 238, 5, 20, "Message"],
Cell[57273, 1775, 243, 6, 20, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57553, 1786, 204, 6, 27, "Input"],
Cell[57760, 1794, 3943, 104, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61740, 1903, 99, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[61864, 1908, 204, 6, 27, "Input"],
Cell[62071, 1916, 3943, 104, 139, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[66063, 2026, 94, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[66182, 2031, 192, 5, 27, "Input"],
Cell[66377, 2038, 8201, 208, 267, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[74639, 2253, 37, 0, 72, "Section"],
Cell[CellGroupData[{
Cell[74701, 2257, 319, 6, 27, "Input"],
Cell[75023, 2265, 320, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75380, 2276, 587, 16, 43, "Input"],
Cell[75970, 2294, 389, 10, 27, "Output"],
Cell[76362, 2306, 389, 10, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76788, 2321, 142, 4, 27, "Input"],
Cell[76933, 2327, 382, 10, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77352, 2342, 661, 16, 59, "Input"],
Cell[78016, 2360, 689, 17, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78742, 2382, 140, 4, 27, "Input"],
Cell[78885, 2388, 366, 10, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79288, 2403, 914, 24, 43, "Input"],
Cell[80205, 2429, 786, 21, 69, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81028, 2455, 138, 4, 27, "Input"],
Cell[81169, 2461, 521, 16, 123, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81727, 2482, 336, 8, 27, "Input"],
Cell[82066, 2492, 557, 14, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82660, 2511, 141, 4, 27, "Input"],
Cell[82804, 2517, 366, 10, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83207, 2532, 808, 21, 43, "Input"],
Cell[84018, 2555, 784, 20, 69, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84839, 2580, 154, 4, 27, "Input"],
Cell[84996, 2586, 421, 12, 123, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85454, 2603, 816, 19, 43, "Input"],
Cell[86273, 2624, 821, 20, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87131, 2649, 135, 4, 27, "Input"],
Cell[87269, 2655, 366, 10, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87672, 2670, 1153, 30, 43, "Input"],
Cell[88828, 2702, 1018, 27, 69, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[89883, 2734, 134, 4, 27, "Input"],
Cell[90020, 2740, 531, 16, 137, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90588, 2761, 186, 4, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[90799, 2769, 175, 5, 27, "Input"],
Cell[90977, 2776, 14734, 427, 291, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[105772, 3210, 44, 0, 72, "Section"],
Cell[CellGroupData[{
Cell[105841, 3214, 345, 10, 27, "Input"],
Cell[106189, 3226, 245, 6, 20, "Message"],
Cell[106437, 3234, 290, 9, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106764, 3248, 234, 6, 27, "Input"],
Cell[107001, 3256, 1475, 45, 69, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108513, 3306, 1101, 27, 59, "Input"],
Cell[109617, 3335, 239, 6, 20, "Message"],
Cell[109859, 3343, 239, 6, 20, "Message"],
Cell[110101, 3351, 239, 6, 20, "Message"],
Cell[110343, 3359, 218, 5, 20, "Message"],
Cell[110564, 3366, 821, 20, 43, "Output"],
Cell[111388, 3388, 366, 10, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[111791, 3403, 215, 6, 27, "Input"],
Cell[112009, 3411, 2409, 76, 159, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114455, 3492, 757, 21, 27, "Input"],
Cell[115215, 3515, 615, 20, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115867, 3540, 227, 6, 27, "Input"],
Cell[116097, 3548, 366, 10, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116500, 3563, 1921, 64, 75, "Input"],
Cell[118424, 3629, 215, 6, 27, "Output"],
Cell[118642, 3637, 231, 6, 27, "Output"],
Cell[118876, 3645, 231, 6, 27, "Output"],
Cell[119110, 3653, 235, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119382, 3664, 184, 5, 27, "Input"],
Cell[119569, 3671, 2524, 72, 213, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[122130, 3748, 216, 6, 27, "Input"],
Cell[122349, 3756, 222, 7, 63, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[122608, 3768, 209, 6, 27, "Input"],
Cell[122820, 3776, 957, 31, 87, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123814, 3812, 215, 6, 27, "Input"],
Cell[124032, 3820, 2832, 81, 83, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126901, 3906, 315, 8, 27, "Input"],
Cell[127219, 3916, 939, 31, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128195, 3952, 181, 4, 27, "Input"],
Cell[128379, 3958, 939, 31, 29, "Output"]
}, Open  ]],
Cell[129333, 3992, 135, 3, 28, "Input"],
Cell[CellGroupData[{
Cell[129493, 3999, 241, 7, 27, "Input"],
Cell[129737, 4008, 30, 0, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[129804, 4013, 720, 20, 59, "Input"],
Cell[130527, 4035, 790608, 29883, 296, 762228, 29414, "GraphicsData", \
"PostScript", "Graphics"],
Cell[921138, 33920, 136, 4, 27, "Output"],
Cell[921277, 33926, 47, 0, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[921361, 33931, 710, 20, 59, "Input"],
Cell[922074, 33953, 756077, 29205, 296, 731305, 28796, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1678154, 63160, 136, 4, 27, "Output"],
Cell[1678293, 63166, 42, 0, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1678372, 63171, 722, 20, 59, "Input"],
Cell[1679097, 63193, 814896, 31318, 296, 799160, 31057, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2493996, 94513, 136, 4, 27, "Output"],
Cell[2494135, 94519, 48, 0, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2494220, 94524, 716, 20, 59, "Input"],
Cell[2494939, 94546, 814038, 31304, 296, 799160, 31057, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3308980, 125852, 136, 4, 27, "Output"],
Cell[3309119, 125858, 45, 0, 27, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
