(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     38976,       1271]
NotebookOptionsPosition[     35834,       1157]
NotebookOutlinePosition[     36165,       1172]
CellTagsIndexPosition[     36122,       1169]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["Bending of an anisotropic plate (Lehnitskii art. 16) ", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "Displacement.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "IntegrateStrain.m"}], "\[IndentingNewLine]"}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["From the stress field of the bending field to the \
displacement field",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   StyleBox[
    RowBox[{"sig", " ", "=", " ", 
     RowBox[{
      RowBox[{"12", " ", "/", " ", 
       RowBox[{"H", "^", "3"}]}], " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Mxx", " ", "z"}], ",", " ", 
          RowBox[{"Mxy", " ", "z"}], ",", " ", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Mxy", " ", "z"}], ",", " ", 
          RowBox[{"Myy", " ", "z"}], ",", " ", "0"}], " ", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]}]}],
    FontFamily->"Courier"], 
   StyleBox[" ",
    FontFamily->"Courier"], 
   StyleBox[")",
    FontFamily->"Courier"]}], 
  StyleBox[" ",
   FontFamily->"Courier"], "//", "  ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"12", " ", "Mxx", " ", "z"}], 
       SuperscriptBox["H", "3"]], 
      FractionBox[
       RowBox[{"12", " ", "Mxy", " ", "z"}], 
       SuperscriptBox["H", "3"]], "0"},
     {
      FractionBox[
       RowBox[{"12", " ", "Mxy", " ", "z"}], 
       SuperscriptBox["H", "3"]], 
      FractionBox[
       RowBox[{"12", " ", "Myy", " ", "z"}], 
       SuperscriptBox["H", "3"]], "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Div", "[", " ", "sig", " ", "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"normal", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"traction", " ", "=", " ", 
    RowBox[{"sig", " ", ".", " ", "normal"}]}], "\[IndentingNewLine]", 
   RowBox[{"Integrate", "[", " ", 
    RowBox[{
     RowBox[{"traction", "  ", "/.", " ", 
      RowBox[{"x", " ", "\[Rule]", " ", "Lx"}]}], " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "Ly"}], ",", " ", "Ly"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"z", ",", " ", 
       RowBox[{
        RowBox[{"-", "H"}], "/", "2"}], ",", " ", 
       RowBox[{"H", "/", "2"}]}], "}"}]}], "]"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{"Integrate", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Cross", "[", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", "z"}], "}"}], " ", ",", " ", 
        "traction"}], " ", "]"}], " ", "/.", " ", 
      RowBox[{"x", " ", "\[Rule]", " ", "Lx"}]}], " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "Ly"}], ",", " ", "Ly"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"z", ",", " ", 
       RowBox[{
        RowBox[{"-", "H"}], "/", "2"}], ",", " ", 
       RowBox[{"H", "/", "2"}]}], "}"}]}], "]"}]}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"12", " ", "Mxx", " ", "z"}], 
    SuperscriptBox["H", "3"]], ",", 
   FractionBox[
    RowBox[{"12", " ", "Mxy", " ", "z"}], 
    SuperscriptBox["H", "3"]], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", "Ly", " ", "Mxy"}], ",", 
   RowBox[{"2", " ", "Ly", " ", "Mxx"}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"C4", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C11", ",", "C16", ",", "C15"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C16", ",", "C12", ",", "C14"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C15", ",", "C14", ",", "C13"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C12", ",", "C26", ",", "C25"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C26", ",", "C22", ",", "C24"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C25", ",", "C24", ",", "C23"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C13", ",", "C36", ",", "C35"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C36", ",", "C23", ",", "C34"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C35", ",", "C34", ",", "C33"}], "}"}]}], "}"}]}], "}"}]}], 
    "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"eps", "=", 
      RowBox[{"DDot", "[", 
       RowBox[{"C4", ",", "sig"}], "]"}]}], " ", ")"}], "//", "MatrixForm"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", " ", 
    "MatrixForm"}]}], " "}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox[
        RowBox[{"12", " ", "C11", " ", "Mxx", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"24", " ", "C16", " ", "Mxy", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"12", " ", "C12", " ", "Myy", " ", "z"}], 
        SuperscriptBox["H", "3"]]}], 
      RowBox[{
       FractionBox[
        RowBox[{"12", " ", "C16", " ", "Mxx", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"24", " ", "C66", " ", "Mxy", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"12", " ", "C26", " ", "Myy", " ", "z"}], 
        SuperscriptBox["H", "3"]]}], 
      RowBox[{
       FractionBox[
        RowBox[{"12", " ", "C15", " ", "Mxx", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"24", " ", "C56", " ", "Mxy", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"12", " ", "C25", " ", "Myy", " ", "z"}], 
        SuperscriptBox["H", "3"]]}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{"12", " ", "C16", " ", "Mxx", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"24", " ", "C66", " ", "Mxy", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"12", " ", "C26", " ", "Myy", " ", "z"}], 
        SuperscriptBox["H", "3"]]}], 
      RowBox[{
       FractionBox[
        RowBox[{"12", " ", "C12", " ", "Mxx", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"24", " ", "C26", " ", "Mxy", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"12", " ", "C22", " ", "Myy", " ", "z"}], 
        SuperscriptBox["H", "3"]]}], 
      RowBox[{
       FractionBox[
        RowBox[{"12", " ", "C14", " ", "Mxx", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"24", " ", "C46", " ", "Mxy", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"12", " ", "C24", " ", "Myy", " ", "z"}], 
        SuperscriptBox["H", "3"]]}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{"12", " ", "C15", " ", "Mxx", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"24", " ", "C56", " ", "Mxy", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"12", " ", "C25", " ", "Myy", " ", "z"}], 
        SuperscriptBox["H", "3"]]}], 
      RowBox[{
       FractionBox[
        RowBox[{"12", " ", "C14", " ", "Mxx", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"24", " ", "C46", " ", "Mxy", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"12", " ", "C24", " ", "Myy", " ", "z"}], 
        SuperscriptBox["H", "3"]]}], 
      RowBox[{
       FractionBox[
        RowBox[{"12", " ", "C13", " ", "Mxx", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"24", " ", "C36", " ", "Mxy", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"12", " ", "C23", " ", "Myy", " ", "z"}], 
        SuperscriptBox["H", "3"]]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"IntegrateStrain", "[", "eps", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"12", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"C15", " ", "Mxx"}], "+", 
        RowBox[{"2", " ", "C56", " ", "Mxy"}], "+", 
        RowBox[{"C25", " ", "Myy"}]}], ")"}], " ", 
      SuperscriptBox["z", "2"]}], 
     SuperscriptBox["H", "3"]], "+", 
    RowBox[{"x", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"12", " ", "C11", " ", "Mxx", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"24", " ", "C16", " ", "Mxy", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"12", " ", "C12", " ", "Myy", " ", "z"}], 
        SuperscriptBox["H", "3"]]}], ")"}]}], "+", 
    RowBox[{"y", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"12", " ", "C16", " ", "Mxx", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"24", " ", "C66", " ", "Mxy", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"12", " ", "C26", " ", "Myy", " ", "z"}], 
        SuperscriptBox["H", "3"]]}], ")"}]}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"12", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"C14", " ", "Mxx"}], "+", 
        RowBox[{"2", " ", "C46", " ", "Mxy"}], "+", 
        RowBox[{"C24", " ", "Myy"}]}], ")"}], " ", 
      SuperscriptBox["z", "2"]}], 
     SuperscriptBox["H", "3"]], "+", 
    RowBox[{"y", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"12", " ", "C12", " ", "Mxx", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"24", " ", "C26", " ", "Mxy", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"12", " ", "C22", " ", "Myy", " ", "z"}], 
        SuperscriptBox["H", "3"]]}], ")"}]}], "+", 
    RowBox[{"x", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"12", " ", "C16", " ", "Mxx", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"24", " ", "C66", " ", "Mxy", " ", "z"}], 
        SuperscriptBox["H", "3"]], "+", 
       FractionBox[
        RowBox[{"12", " ", "C26", " ", "Myy", " ", "z"}], 
        SuperscriptBox["H", "3"]]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"C12", " ", "Mxx"}], "+", 
         RowBox[{"2", " ", "C26", " ", "Mxy"}], "+", 
         RowBox[{"C22", " ", "Myy"}]}], ")"}], " ", 
       SuperscriptBox["y", "2"]}], 
      SuperscriptBox["H", "3"]]}], "-", 
    FractionBox[
     RowBox[{"6", " ", "x", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"C11", " ", "Mxx", " ", "x"}], "+", 
        RowBox[{"C12", " ", "Myy", " ", "x"}], "+", 
        RowBox[{"4", " ", "C66", " ", "Mxy", " ", "y"}], "+", 
        RowBox[{"2", " ", "C26", " ", "Myy", " ", "y"}], "+", 
        RowBox[{"2", " ", "C16", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Mxy", " ", "x"}], "+", 
           RowBox[{"Mxx", " ", "y"}]}], ")"}]}]}], ")"}]}], 
     SuperscriptBox["H", "3"]], "+", 
    FractionBox[
     RowBox[{"6", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"C13", " ", "Mxx"}], "+", 
        RowBox[{"2", " ", "C36", " ", "Mxy"}], "+", 
        RowBox[{"C23", " ", "Myy"}]}], ")"}], " ", 
      SuperscriptBox["z", "2"]}], 
     SuperscriptBox["H", "3"]]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Deflection of the middle surface ",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"umiddle", " ", "=", " ", 
  RowBox[{"u", " ", "/.", " ", 
   RowBox[{"z", " ", "\[Rule]", " ", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"C12", " ", "Mxx"}], "+", 
         RowBox[{"2", " ", "C26", " ", "Mxy"}], "+", 
         RowBox[{"C22", " ", "Myy"}]}], ")"}], " ", 
       SuperscriptBox["y", "2"]}], 
      SuperscriptBox["H", "3"]]}], "-", 
    FractionBox[
     RowBox[{"6", " ", "x", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"C11", " ", "Mxx", " ", "x"}], "+", 
        RowBox[{"C12", " ", "Myy", " ", "x"}], "+", 
        RowBox[{"4", " ", "C66", " ", "Mxy", " ", "y"}], "+", 
        RowBox[{"2", " ", "C26", " ", "Myy", " ", "y"}], "+", 
        RowBox[{"2", " ", "C16", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Mxy", " ", "x"}], "+", 
           RowBox[{"Mxx", " ", "y"}]}], ")"}]}]}], ")"}]}], 
     SuperscriptBox["H", "3"]]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Orthogonality of normal segments",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}], " ", "-", " ", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "0"}], "}"}]}], "  ", ")"}], " ", ".", 
    "   ", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}], " ", "-", " ", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "0"}], "}"}]}], "  ", ")"}], " ", ".", 
    "   ", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1", ",", "0"}], "}"}]}]}], " "}]], "Input"],

Cell[BoxData["0"], "Output"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"tangentx", " ", "=", " ", 
  RowBox[{"D", "[", " ", 
   RowBox[{"umiddle", " ", ",", " ", "x"}], " ", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"tangenty", " ", "=", " ", 
  RowBox[{"D", "[", " ", 
   RowBox[{"umiddle", " ", ",", " ", "y"}], " ", "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"C11", " ", "Mxx"}], "+", 
         RowBox[{"2", " ", "C16", " ", "Mxy"}], "+", 
         RowBox[{"C12", " ", "Myy"}]}], ")"}], " ", "x"}], 
      SuperscriptBox["H", "3"]]}], "-", 
    FractionBox[
     RowBox[{"6", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"C11", " ", "Mxx", " ", "x"}], "+", 
        RowBox[{"C12", " ", "Myy", " ", "x"}], "+", 
        RowBox[{"4", " ", "C66", " ", "Mxy", " ", "y"}], "+", 
        RowBox[{"2", " ", "C26", " ", "Myy", " ", "y"}], "+", 
        RowBox[{"2", " ", "C16", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Mxy", " ", "x"}], "+", 
           RowBox[{"Mxx", " ", "y"}]}], ")"}]}]}], ")"}]}], 
     SuperscriptBox["H", "3"]]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "C16", " ", "Mxx"}], "+", 
         RowBox[{"4", " ", "C66", " ", "Mxy"}], "+", 
         RowBox[{"2", " ", "C26", " ", "Myy"}]}], ")"}], " ", "x"}], 
      SuperscriptBox["H", "3"]]}], "-", 
    FractionBox[
     RowBox[{"12", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"C12", " ", "Mxx"}], "+", 
        RowBox[{"2", " ", "C26", " ", "Mxy"}], "+", 
        RowBox[{"C22", " ", "Myy"}]}], ")"}], " ", "y"}], 
     SuperscriptBox["H", "3"]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"segment", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"u", " ", "-", "  ", "umiddle"}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["H", "3"]], 
    RowBox[{"12", " ", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C11", " ", "Mxx", " ", "x"}], "+", 
       RowBox[{"2", " ", "C16", " ", "Mxy", " ", "x"}], "+", 
       RowBox[{"C12", " ", "Myy", " ", "x"}], "+", 
       RowBox[{"C16", " ", "Mxx", " ", "y"}], "+", 
       RowBox[{"2", " ", "C66", " ", "Mxy", " ", "y"}], "+", 
       RowBox[{"C26", " ", "Myy", " ", "y"}], "+", 
       RowBox[{"C15", " ", "Mxx", " ", "z"}], "+", 
       RowBox[{"2", " ", "C56", " ", "Mxy", " ", "z"}], "+", 
       RowBox[{"C25", " ", "Myy", " ", "z"}]}], ")"}]}]}], ",", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["H", "3"]], 
    RowBox[{"12", " ", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C16", " ", "Mxx", " ", "x"}], "+", 
       RowBox[{"2", " ", "C66", " ", "Mxy", " ", "x"}], "+", 
       RowBox[{"C26", " ", "Myy", " ", "x"}], "+", 
       RowBox[{"C12", " ", "Mxx", " ", "y"}], "+", 
       RowBox[{"2", " ", "C26", " ", "Mxy", " ", "y"}], "+", 
       RowBox[{"C22", " ", "Myy", " ", "y"}], "+", 
       RowBox[{"C14", " ", "Mxx", " ", "z"}], "+", 
       RowBox[{"2", " ", "C46", " ", "Mxy", " ", "z"}], "+", 
       RowBox[{"C24", " ", "Myy", " ", "z"}]}], ")"}]}]}], ",", 
   FractionBox[
    RowBox[{"6", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C13", " ", "Mxx"}], "+", 
       RowBox[{"2", " ", "C36", " ", "Mxy"}], "+", 
       RowBox[{"C23", " ", "Myy"}]}], ")"}], " ", 
     SuperscriptBox["z", "2"]}], 
    SuperscriptBox["H", "3"]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", " ", 
  RowBox[{"tangentx", " ", ".", " ", "segment"}], " ", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", " ", 
  RowBox[{"tangenty", " ", ".", " ", "segment"}], " ", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    SuperscriptBox["H", "6"]], 
   RowBox[{"72", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C13", " ", "Mxx"}], "+", 
      RowBox[{"2", " ", "C36", " ", "Mxy"}], "+", 
      RowBox[{"C23", " ", "Myy"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C11", " ", "Mxx", " ", "x"}], "+", 
      RowBox[{"2", " ", "C16", " ", "Mxy", " ", "x"}], "+", 
      RowBox[{"C12", " ", "Myy", " ", "x"}], "+", 
      RowBox[{"C16", " ", "Mxx", " ", "y"}], "+", 
      RowBox[{"2", " ", "C66", " ", "Mxy", " ", "y"}], "+", 
      RowBox[{"C26", " ", "Myy", " ", "y"}]}], ")"}], " ", 
    SuperscriptBox["z", "2"]}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    SuperscriptBox["H", "6"]], 
   RowBox[{"72", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C13", " ", "Mxx"}], "+", 
      RowBox[{"2", " ", "C36", " ", "Mxy"}], "+", 
      RowBox[{"C23", " ", "Myy"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C16", " ", "Mxx", " ", "x"}], "+", 
      RowBox[{"2", " ", "C66", " ", "Mxy", " ", "x"}], "+", 
      RowBox[{"C26", " ", "Myy", " ", "x"}], "+", 
      RowBox[{"C12", " ", "Mxx", " ", "y"}], "+", 
      RowBox[{"2", " ", "C26", " ", "Mxy", " ", "y"}], "+", 
      RowBox[{"C22", " ", "Myy", " ", "y"}]}], ")"}], " ", 
    SuperscriptBox["z", "2"]}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"ggw", " ", "=", " ", 
    RowBox[{"Grad", "[", " ", 
     RowBox[{"Grad", "[", " ", 
      RowBox[{"umiddle", "[", 
       RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], " ", "]"}]}], " ", ")"}], "//",
   " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{"12", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"C11", " ", "Mxx"}], "+", 
           RowBox[{"2", " ", "C16", " ", "Mxy"}], "+", 
           RowBox[{"C12", " ", "Myy"}]}], ")"}]}], 
        SuperscriptBox["H", "3"]]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "C16", " ", "Mxx"}], "+", 
           RowBox[{"4", " ", "C66", " ", "Mxy"}], "+", 
           RowBox[{"2", " ", "C26", " ", "Myy"}]}], ")"}]}], 
        SuperscriptBox["H", "3"]]}], "0"},
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "C16", " ", "Mxx"}], "+", 
           RowBox[{"4", " ", "C66", " ", "Mxy"}], "+", 
           RowBox[{"2", " ", "C26", " ", "Myy"}]}], ")"}]}], 
        SuperscriptBox["H", "3"]]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"12", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"C12", " ", "Mxx"}], "+", 
           RowBox[{"2", " ", "C26", " ", "Mxy"}], "+", 
           RowBox[{"C22", " ", "Myy"}]}], ")"}]}], 
        SuperscriptBox["H", "3"]]}], "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solM", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"ggw", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", "==", " ", "wxx"}], ",",
        " ", 
       RowBox[{
        RowBox[{"ggw", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}], " ", "==", " ", "wxy"}], ",",
        " ", 
       RowBox[{
        RowBox[{"ggw", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}], " ", "==", " ", "wyy"}]}], 
      "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"Mxx", ",", " ", "Mxy", ",", " ", "Myy"}], "}"}]}], "]"}], "[", 
   
   RowBox[{"[", "1", "]"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Mxx", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["C26", "2"]}], " ", 
       SuperscriptBox["H", "3"], " ", "wxx"}], "+", 
      RowBox[{"C22", " ", "C66", " ", 
       SuperscriptBox["H", "3"], " ", "wxx"}], "-", 
      RowBox[{"C16", " ", "C22", " ", 
       SuperscriptBox["H", "3"], " ", "wxy"}], "+", 
      RowBox[{"C12", " ", "C26", " ", 
       SuperscriptBox["H", "3"], " ", "wxy"}], "+", 
      RowBox[{"C16", " ", "C26", " ", 
       SuperscriptBox["H", "3"], " ", "wyy"}], "-", 
      RowBox[{"C12", " ", "C66", " ", 
       SuperscriptBox["H", "3"], " ", "wyy"}]}], 
     RowBox[{"12", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["C16", "2"], " ", "C22"}], "-", 
        RowBox[{"2", " ", "C12", " ", "C16", " ", "C26"}], "+", 
        RowBox[{"C11", " ", 
         SuperscriptBox["C26", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["C12", "2"], " ", "C66"}], "-", 
        RowBox[{"C11", " ", "C22", " ", "C66"}]}], ")"}]}]]}], ",", 
   RowBox[{"Mxy", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"C16", " ", "C22", " ", 
        SuperscriptBox["H", "3"], " ", "wxx"}], "-", 
       RowBox[{"C12", " ", "C26", " ", 
        SuperscriptBox["H", "3"], " ", "wxx"}], "+", 
       RowBox[{
        SuperscriptBox["C12", "2"], " ", 
        SuperscriptBox["H", "3"], " ", "wxy"}], "-", 
       RowBox[{"C11", " ", "C22", " ", 
        SuperscriptBox["H", "3"], " ", "wxy"}], "-", 
       RowBox[{"C12", " ", "C16", " ", 
        SuperscriptBox["H", "3"], " ", "wyy"}], "+", 
       RowBox[{"C11", " ", "C26", " ", 
        SuperscriptBox["H", "3"], " ", "wyy"}]}], 
      RowBox[{"24", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["C16", "2"], " ", "C22"}], "-", 
         RowBox[{"2", " ", "C12", " ", "C16", " ", "C26"}], "+", 
         RowBox[{"C11", " ", 
          SuperscriptBox["C26", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["C12", "2"], " ", "C66"}], "-", 
         RowBox[{"C11", " ", "C22", " ", "C66"}]}], ")"}]}]]}]}], ",", 
   RowBox[{"Myy", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["H", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "C16"}], " ", "C26", " ", "wxx"}], "+", 
         RowBox[{"C12", " ", "C66", " ", "wxx"}], "-", 
         RowBox[{"C12", " ", "C16", " ", "wxy"}], "+", 
         RowBox[{"C11", " ", "C26", " ", "wxy"}], "+", 
         RowBox[{
          SuperscriptBox["C16", "2"], " ", "wyy"}], "-", 
         RowBox[{"C11", " ", "C66", " ", "wyy"}]}], ")"}]}], 
      RowBox[{"12", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["C16", "2"], " ", "C22"}], "-", 
         RowBox[{"2", " ", "C12", " ", "C16", " ", "C26"}], "+", 
         RowBox[{"C11", " ", 
          SuperscriptBox["C26", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["C12", "2"], " ", "C66"}], "-", 
         RowBox[{"C11", " ", "C22", " ", "C66"}]}], ")"}]}]]}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"solM", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"wxx", ",", "wxy", ",", "wyy"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["C26", "2"]}], " ", 
       SuperscriptBox["H", "3"]}], "+", 
      RowBox[{"C22", " ", "C66", " ", 
       SuperscriptBox["H", "3"]}]}], ")"}], " ", "wxx"}], 
   RowBox[{"12", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["C16", "2"], " ", "C22"}], "-", 
      RowBox[{"2", " ", "C12", " ", "C16", " ", "C26"}], "+", 
      RowBox[{"C11", " ", 
       SuperscriptBox["C26", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["C12", "2"], " ", "C66"}], "-", 
      RowBox[{"C11", " ", "C22", " ", "C66"}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "C16"}], " ", "C22", " ", 
       SuperscriptBox["H", "3"]}], "+", 
      RowBox[{"C12", " ", "C26", " ", 
       SuperscriptBox["H", "3"]}]}], ")"}], " ", "wxy"}], 
   RowBox[{"12", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["C16", "2"], " ", "C22"}], "-", 
      RowBox[{"2", " ", "C12", " ", "C16", " ", "C26"}], "+", 
      RowBox[{"C11", " ", 
       SuperscriptBox["C26", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["C12", "2"], " ", "C66"}], "-", 
      RowBox[{"C11", " ", "C22", " ", "C66"}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C16", " ", "C26", " ", 
       SuperscriptBox["H", "3"]}], "-", 
      RowBox[{"C12", " ", "C66", " ", 
       SuperscriptBox["H", "3"]}]}], ")"}], " ", "wyy"}], 
   RowBox[{"12", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["C16", "2"], " ", "C22"}], "-", 
      RowBox[{"2", " ", "C12", " ", "C16", " ", "C26"}], "+", 
      RowBox[{"C11", " ", 
       SuperscriptBox["C26", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["C12", "2"], " ", "C66"}], "-", 
      RowBox[{"C11", " ", "C22", " ", "C66"}]}], ")"}]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"12", " ", "/", " ", 
   RowBox[{"H", "^", "3"}]}], " ", 
  RowBox[{"Coefficient", "[", " ", 
   RowBox[{
    RowBox[{"solM", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", " ", "wxx"}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["C26", "2"]}], " ", 
    SuperscriptBox["H", "3"]}], "+", 
   RowBox[{"C22", " ", "C66", " ", 
    SuperscriptBox["H", "3"]}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["C16", "2"], " ", "C22"}], "-", 
     RowBox[{"2", " ", "C12", " ", "C16", " ", "C26"}], "+", 
     RowBox[{"C11", " ", 
      SuperscriptBox["C26", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["C12", "2"], " ", "C66"}], "-", 
     RowBox[{"C11", " ", "C22", " ", "C66"}]}], ")"}], " ", 
   SuperscriptBox["H", "3"]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"12", " ", "/", " ", 
   RowBox[{"H", "^", "3"}]}], " ", 
  RowBox[{"Coefficient", "[", " ", 
   RowBox[{
    RowBox[{"solM", "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "2"}], "]"}], "]"}], ",", " ", "wxy"}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["C12", "2"], " ", 
     SuperscriptBox["H", "3"]}], "-", 
    RowBox[{"C11", " ", "C22", " ", 
     SuperscriptBox["H", "3"]}]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["C16", "2"], " ", "C22"}], "-", 
      RowBox[{"2", " ", "C12", " ", "C16", " ", "C26"}], "+", 
      RowBox[{"C11", " ", 
       SuperscriptBox["C26", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["C12", "2"], " ", "C66"}], "-", 
      RowBox[{"C11", " ", "C22", " ", "C66"}]}], ")"}], " ", 
    SuperscriptBox["H", "3"]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"12", " ", "/", " ", 
   RowBox[{"H", "^", "3"}]}], " ", 
  RowBox[{"Coefficient", "[", " ", 
   RowBox[{
    RowBox[{"solM", "[", 
     RowBox[{"[", 
      RowBox[{"3", ",", "2"}], "]"}], "]"}], ",", " ", "wyy"}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["C16", "2"], "-", 
    RowBox[{"C11", " ", "C66"}]}], 
   RowBox[{
    RowBox[{
     SuperscriptBox["C16", "2"], " ", "C22"}], "-", 
    RowBox[{"2", " ", "C12", " ", "C16", " ", "C26"}], "+", 
    RowBox[{"C11", " ", 
     SuperscriptBox["C26", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["C12", "2"], " ", "C66"}], "-", 
    RowBox[{"C11", " ", "C22", " ", "C66"}]}]]}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{867, 821},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 96, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[1452, 43, 291, 8, 55, "Input"],
Cell[1746, 53, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1833, 56, 217, 3, 99, "Input"],
Cell[CellGroupData[{
Cell[2075, 63, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2187, 68, 137, 3, 32, "Input"],
Cell[2327, 73, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2460, 80, 132, 3, 32, "Input"],
Cell[2595, 85, 83, 2, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2727, 93, 136, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2888, 99, 818, 26, 32, "Input"],
Cell[3709, 127, 599, 20, 80, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4345, 152, 86, 2, 32, "Input"],
Cell[4434, 156, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4554, 163, 1362, 38, 99, "Input"],
Cell[5919, 203, 83, 2, 31, "Output"],
Cell[6005, 207, 255, 8, 47, "Output"],
Cell[6263, 217, 83, 2, 31, "Output"],
Cell[6349, 221, 177, 5, 31, "Output"]
}, Open  ]],
Cell[6541, 229, 3015, 85, 209, "Input"],
Cell[CellGroupData[{
Cell[9581, 318, 340, 11, 55, "Input"],
Cell[9924, 331, 3522, 98, 90, "Output"],
Cell[13449, 431, 219, 8, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13705, 444, 103, 2, 32, "Input"],
Cell[13811, 448, 3573, 104, 243, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17433, 558, 99, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[17557, 563, 139, 3, 32, "Input"],
Cell[17699, 568, 957, 27, 86, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18705, 601, 98, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[18828, 606, 698, 22, 55, "Input"],
Cell[19529, 630, 28, 0, 31, "Output"],
Cell[19560, 632, 28, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19625, 637, 295, 7, 55, "Input"],
Cell[19923, 646, 918, 26, 84, "Output"],
Cell[20844, 674, 676, 20, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21557, 699, 151, 3, 32, "Input"],
Cell[21711, 704, 1634, 41, 144, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23382, 750, 240, 5, 55, "Input"],
Cell[23625, 757, 703, 19, 69, "Output"],
Cell[24331, 778, 703, 19, 69, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25071, 802, 284, 8, 32, "Input"],
Cell[25358, 812, 1445, 44, 80, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26840, 861, 780, 25, 32, "Input"],
Cell[27623, 888, 3190, 85, 154, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30850, 978, 236, 7, 32, "Input"],
Cell[31089, 987, 1984, 61, 162, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33110, 1053, 276, 9, 32, "Input"],
Cell[33389, 1064, 629, 20, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34055, 1089, 276, 9, 32, "Input"],
Cell[34334, 1100, 654, 20, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35025, 1125, 276, 9, 32, "Input"],
Cell[35304, 1136, 461, 14, 49, "Output"]
}, Open  ]],
Cell[35780, 1153, 26, 0, 32, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

