(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     15916,        570]
NotebookOptionsPosition[     13817,        491]
NotebookOutlinePosition[     14149,        506]
CellTagsIndexPosition[     14106,        503]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["\<\
Shear of an anisotropic rectangular parallelipiped (Lehnitskii art. 13) \
\>", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "Displacement.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "IntegrateStrain.m"}], "\[IndentingNewLine]"}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["From the stress field of the bending field to the \
displacement field",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   StyleBox[
    RowBox[{"sig", " ", "=", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"sxy", ",", "0", ",", " ", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "sxy", ",", " ", "0"}], " ", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]}],
    FontFamily->"Courier"], 
   StyleBox[" ",
    FontFamily->"Courier"], 
   StyleBox[")",
    FontFamily->"Courier"]}], 
  StyleBox[" ",
   FontFamily->"Courier"], "//", "  ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"sxy", "0", "0"},
     {"0", "sxy", "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Div", "[", " ", "sig", " ", "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"normal", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"traction", " ", "=", " ", 
    RowBox[{"sig", " ", ".", " ", "normal"}]}], "\[IndentingNewLine]", 
   RowBox[{"Integrate", "[", " ", 
    RowBox[{
     RowBox[{"traction", "  ", "/.", " ", 
      RowBox[{"x", " ", "\[Rule]", " ", "Lx"}]}], " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "Ly"}], ",", " ", "Ly"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"z", ",", " ", 
       RowBox[{
        RowBox[{"-", "Lz"}], "/", "2"}], ",", " ", 
       RowBox[{"Lz", "/", "2"}]}], "}"}]}], "]"}], " ", "\[IndentingNewLine]",
    
   RowBox[{"Integrate", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Cross", "[", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", "z"}], "}"}], " ", ",", " ", 
        "traction"}], " ", "]"}], " ", "/.", " ", 
      RowBox[{"x", " ", "\[Rule]", " ", "Lx"}]}], " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "Ly"}], ",", " ", "Ly"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"z", ",", " ", 
       RowBox[{"-", "Lz"}], " ", ",", " ", "Lz"}], "}"}]}], "]"}]}], 
  " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"sxy", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", "Ly", " ", "Lz", " ", "sxy"}], ",", "0", ",", "0"}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"C4", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C11", ",", "C16", ",", "C15"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C16", ",", "C12", ",", "C14"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C15", ",", "C14", ",", "C13"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C12", ",", "C26", ",", "C25"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C26", ",", "C22", ",", "C24"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C25", ",", "C24", ",", "C23"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C13", ",", "C36", ",", "C35"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C36", ",", "C23", ",", "C34"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C35", ",", "C34", ",", "C33"}], "}"}]}], "}"}]}], "}"}]}], 
    "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"eps", "=", 
      RowBox[{"DDot", "[", 
       RowBox[{"C4", ",", "sig"}], "]"}]}], " ", ")"}], "//", "MatrixForm"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", " ", 
    "MatrixForm"}]}], " "}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"C11", " ", "sxy"}], "+", 
       RowBox[{"C12", " ", "sxy"}]}], 
      RowBox[{
       RowBox[{"C16", " ", "sxy"}], "+", 
       RowBox[{"C26", " ", "sxy"}]}], 
      RowBox[{
       RowBox[{"C15", " ", "sxy"}], "+", 
       RowBox[{"C25", " ", "sxy"}]}]},
     {
      RowBox[{
       RowBox[{"C16", " ", "sxy"}], "+", 
       RowBox[{"C26", " ", "sxy"}]}], 
      RowBox[{
       RowBox[{"C12", " ", "sxy"}], "+", 
       RowBox[{"C22", " ", "sxy"}]}], 
      RowBox[{
       RowBox[{"C14", " ", "sxy"}], "+", 
       RowBox[{"C24", " ", "sxy"}]}]},
     {
      RowBox[{
       RowBox[{"C15", " ", "sxy"}], "+", 
       RowBox[{"C25", " ", "sxy"}]}], 
      RowBox[{
       RowBox[{"C14", " ", "sxy"}], "+", 
       RowBox[{"C24", " ", "sxy"}]}], 
      RowBox[{
       RowBox[{"C13", " ", "sxy"}], "+", 
       RowBox[{"C23", " ", "sxy"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Transpose", "[", "eps", "]"}], " ", "-", " ", "eps"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"IntegrateStrain", "[", "eps", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C11", " ", "sxy"}], "+", 
       RowBox[{"C12", " ", "sxy"}]}], ")"}], " ", "x"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C16", " ", "sxy"}], "+", 
       RowBox[{"C26", " ", "sxy"}]}], ")"}], " ", "y"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C15", " ", "sxy"}], "+", 
       RowBox[{"C25", " ", "sxy"}]}], ")"}], " ", "z"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C16", " ", "sxy"}], "+", 
       RowBox[{"C26", " ", "sxy"}]}], ")"}], " ", "x"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C12", " ", "sxy"}], "+", 
       RowBox[{"C22", " ", "sxy"}]}], ")"}], " ", "y"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C14", " ", "sxy"}], "+", 
       RowBox[{"C24", " ", "sxy"}]}], ")"}], " ", "z"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C15", " ", "sxy"}], "+", 
       RowBox[{"C25", " ", "sxy"}]}], ")"}], " ", "x"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C14", " ", "sxy"}], "+", 
       RowBox[{"C24", " ", "sxy"}]}], ")"}], " ", "y"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C13", " ", "sxy"}], "+", 
       RowBox[{"C23", " ", "sxy"}]}], ")"}], " ", "z"}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Extension of the segment [0,LZ] ",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"u", " ", "/.", " ", 
     RowBox[{"x", " ", "\[Rule]", " ", "0"}]}], " ", "/.", " ", 
    RowBox[{"y", " ", "\[Rule]", " ", "0"}]}], " ", "/.", "  ", 
   RowBox[{"z", " ", "\[Rule]", " ", "Lz"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Lz", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C15", " ", "sxy"}], "+", 
      RowBox[{"C25", " ", "sxy"}]}], ")"}]}], ",", 
   RowBox[{"Lz", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C14", " ", "sxy"}], "+", 
      RowBox[{"C24", " ", "sxy"}]}], ")"}]}], ",", 
   RowBox[{"Lz", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C13", " ", "sxy"}], "+", 
      RowBox[{"C23", " ", "sxy"}]}], ")"}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["volume dilatation",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tr", "[", " ", "eps", " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"C11", " ", "sxy"}], "+", 
  RowBox[{"2", " ", "C12", " ", "sxy"}], "+", 
  RowBox[{"C13", " ", "sxy"}], "+", 
  RowBox[{"C22", " ", "sxy"}], "+", 
  RowBox[{"C23", " ", "sxy"}]}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{867, 821},
WindowMargins->{{Automatic, 22}, {Automatic, 0}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 123, 3, 101, "Section"],
Cell[CellGroupData[{
Cell[1479, 45, 291, 8, 55, "Input"],
Cell[1773, 55, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1860, 58, 217, 3, 99, "Input"],
Cell[CellGroupData[{
Cell[2102, 65, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2214, 70, 137, 3, 32, "Input"],
Cell[2354, 75, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2487, 82, 132, 3, 32, "Input"],
Cell[2622, 87, 83, 2, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2754, 95, 136, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2915, 101, 586, 19, 32, "Input"],
Cell[3504, 122, 223, 8, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3764, 135, 86, 2, 32, "Input"],
Cell[3853, 139, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3973, 146, 1317, 37, 99, "Input"],
Cell[5293, 185, 83, 2, 31, "Output"],
Cell[5379, 189, 85, 2, 31, "Output"],
Cell[5467, 193, 134, 4, 31, "Output"],
Cell[5604, 199, 83, 2, 31, "Output"]
}, Open  ]],
Cell[5702, 204, 3015, 85, 209, "Input"],
Cell[CellGroupData[{
Cell[8742, 293, 340, 11, 55, "Input"],
Cell[9085, 306, 1038, 35, 58, "Output"],
Cell[10126, 343, 219, 8, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10382, 356, 99, 2, 32, "Input"],
Cell[10484, 360, 260, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10781, 373, 103, 2, 32, "Input"],
Cell[10887, 377, 1463, 50, 72, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12399, 433, 98, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[12522, 438, 274, 7, 32, "Input"],
Cell[12799, 447, 497, 17, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13345, 470, 83, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[13453, 475, 67, 1, 32, "Input"],
Cell[13523, 478, 225, 6, 31, "Output"]
}, Open  ]],
Cell[13763, 487, 26, 0, 32, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

