(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     21825,        749]
NotebookOptionsPosition[     19636,        669]
NotebookOutlinePosition[     20079,        687]
CellTagsIndexPosition[     20036,        684]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["\<\
Extension of a bar with Cylindrical anisotropy (Lehnitskii art. 14)\
\>", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "Displacement.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "IntegrateStrain.m"}]}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Starting from the stress field",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"sig", "=", " ", 
    RowBox[{
     RowBox[{"-", "p"}], " ", 
     RowBox[{"IdentityMatrix", "[", "3", "]"}]}]}], " ", ")"}], "//", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "p"}], "0", "0"},
     {"0", 
      RowBox[{"-", "p"}], "0"},
     {"0", "0", 
      RowBox[{"-", "p"}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Div", "[", " ", "sig", " ", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"normal", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"nx", ",", " ", "ny", ",", " ", "nz"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"traction", " ", "=", " ", 
  RowBox[{
  "sig", " ", ".", " ", "normal", " "}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(normal\\)\\\" is similar to existing symbol \
\\\"\\!\\(Normal\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"nx", ",", "ny", ",", "nz"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "nx"}], " ", "p"}], ",", 
   RowBox[{
    RowBox[{"-", "ny"}], " ", "p"}], ",", 
   RowBox[{
    RowBox[{"-", "nz"}], " ", "p"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"C4", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C11", ",", "C16", ",", "C15"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C16", ",", "C12", ",", "C14"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C15", ",", "C14", ",", "C13"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C12", ",", "C26", ",", "C25"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C26", ",", "C22", ",", "C24"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C25", ",", "C24", ",", "C23"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C13", ",", "C36", ",", "C35"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C36", ",", "C23", ",", "C34"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C35", ",", "C34", ",", "C33"}], "}"}]}], "}"}]}], "}"}]}],
      "}"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"eps", "=", 
    RowBox[{"DDot", "[", 
     RowBox[{"C4", ",", "sig"}], "]"}]}], ")"}], "//", "MatrixForm"}], "\n", 
 RowBox[{
  RowBox[{"Inc", "[", "eps", "]"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "C11"}], " ", "p"}], "-", 
       RowBox[{"C12", " ", "p"}], "-", 
       RowBox[{"C13", " ", "p"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C16"}], " ", "p"}], "-", 
       RowBox[{"C26", " ", "p"}], "-", 
       RowBox[{"C36", " ", "p"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C15"}], " ", "p"}], "-", 
       RowBox[{"C25", " ", "p"}], "-", 
       RowBox[{"C35", " ", "p"}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "C16"}], " ", "p"}], "-", 
       RowBox[{"C26", " ", "p"}], "-", 
       RowBox[{"C36", " ", "p"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C12"}], " ", "p"}], "-", 
       RowBox[{"C22", " ", "p"}], "-", 
       RowBox[{"C23", " ", "p"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C14"}], " ", "p"}], "-", 
       RowBox[{"C24", " ", "p"}], "-", 
       RowBox[{"C34", " ", "p"}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "C15"}], " ", "p"}], "-", 
       RowBox[{"C25", " ", "p"}], "-", 
       RowBox[{"C35", " ", "p"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C14"}], " ", "p"}], "-", 
       RowBox[{"C24", " ", "p"}], "-", 
       RowBox[{"C34", " ", "p"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C13"}], " ", "p"}], "-", 
       RowBox[{"C23", " ", "p"}], "-", 
       RowBox[{"C33", " ", "p"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{
   RowBox[{"-", " ", 
    RowBox[{"Tr", "[", " ", "eps", " ", "]"}]}], " ", "/", " ", "p"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"C11", "+", 
  RowBox[{"2", " ", "C12"}], "+", 
  RowBox[{"2", " ", "C13"}], "+", "C22", "+", 
  RowBox[{"2", " ", "C23"}], "+", "C33"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"IntegrateStrain", "[", " ", "eps", " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C11"}], " ", "p"}], "-", 
       RowBox[{"C12", " ", "p"}], "-", 
       RowBox[{"C13", " ", "p"}]}], ")"}], " ", "x"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C16"}], " ", "p"}], "-", 
       RowBox[{"C26", " ", "p"}], "-", 
       RowBox[{"C36", " ", "p"}]}], ")"}], " ", "y"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C15"}], " ", "p"}], "-", 
       RowBox[{"C25", " ", "p"}], "-", 
       RowBox[{"C35", " ", "p"}]}], ")"}], " ", "z"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C16"}], " ", "p"}], "-", 
       RowBox[{"C26", " ", "p"}], "-", 
       RowBox[{"C36", " ", "p"}]}], ")"}], " ", "x"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C12"}], " ", "p"}], "-", 
       RowBox[{"C22", " ", "p"}], "-", 
       RowBox[{"C23", " ", "p"}]}], ")"}], " ", "y"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C14"}], " ", "p"}], "-", 
       RowBox[{"C24", " ", "p"}], "-", 
       RowBox[{"C34", " ", "p"}]}], ")"}], " ", "z"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C15"}], " ", "p"}], "-", 
       RowBox[{"C25", " ", "p"}], "-", 
       RowBox[{"C35", " ", "p"}]}], ")"}], " ", "x"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C14"}], " ", "p"}], "-", 
       RowBox[{"C24", " ", "p"}], "-", 
       RowBox[{"C34", " ", "p"}]}], ")"}], " ", "y"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C13"}], " ", "p"}], "-", 
       RowBox[{"C23", " ", "p"}], "-", 
       RowBox[{"C33", " ", "p"}]}], ")"}], " ", "z"}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Starting from uniform strain compression field",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eps", " ", "=", " ", 
  RowBox[{
   RowBox[{"-", " ", "ee"}], " ", 
   RowBox[{
   "IdentityMatrix", "[", " ", "3", " ", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Inc", "[", " ", "eps", " ", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "ee"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "ee"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", "ee"}]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"IntegrateStrain", "[", " ", "eps", " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "ee"}], " ", "x"}], ",", 
   RowBox[{
    RowBox[{"-", "ee"}], " ", "y"}], ",", 
   RowBox[{
    RowBox[{"-", "ee"}], " ", "z"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"S4", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"S11", ",", "S16", ",", "S15"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S16", ",", "S12", ",", "S14"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S15", ",", "S14", ",", "S13"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"S16", ",", "S66", ",", "S56"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S66", ",", "S26", ",", "S46"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S56", ",", "S46", ",", "S36"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"S15", ",", "S56", ",", "S55"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S56", ",", "S25", ",", "S45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S55", ",", "S45", ",", "S35"}], "}"}]}], "}"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"S16", ",", "S66", ",", "S56"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S66", ",", "S26", ",", "S46"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S56", ",", "S46", ",", "S36"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"S12", ",", "S26", ",", "S25"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S26", ",", "S22", ",", "S24"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S25", ",", "S24", ",", "S23"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"S14", ",", "S46", ",", "S45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S46", ",", "S24", ",", "S44"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S45", ",", "S44", ",", "S34"}], "}"}]}], "}"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"S15", ",", "S56", ",", "S55"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S56", ",", "S25", ",", "S45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S55", ",", "S45", ",", "S35"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"S14", ",", "S46", ",", "S45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S46", ",", "S24", ",", "S44"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S45", ",", "S44", ",", "S34"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"S13", ",", "S36", ",", "S35"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S36", ",", "S23", ",", "S34"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"S35", ",", "S34", ",", "S33"}], "}"}]}], "}"}]}], "}"}]}],
      "}"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"sig", "=", 
    RowBox[{"DDot", "[", 
     RowBox[{"S4", ",", " ", "eps"}], "]"}]}], ")"}], "//", 
  "MatrixForm"}], "\n", 
 RowBox[{
  RowBox[{"Div", "[", "sig", "]"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "ee"}], " ", "S11"}], "-", 
       RowBox[{"ee", " ", "S12"}], "-", 
       RowBox[{"ee", " ", "S13"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "ee"}], " ", "S16"}], "-", 
       RowBox[{"ee", " ", "S26"}], "-", 
       RowBox[{"ee", " ", "S36"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "ee"}], " ", "S15"}], "-", 
       RowBox[{"ee", " ", "S25"}], "-", 
       RowBox[{"ee", " ", "S35"}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "ee"}], " ", "S16"}], "-", 
       RowBox[{"ee", " ", "S26"}], "-", 
       RowBox[{"ee", " ", "S36"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "ee"}], " ", "S12"}], "-", 
       RowBox[{"ee", " ", "S22"}], "-", 
       RowBox[{"ee", " ", "S23"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "ee"}], " ", "S14"}], "-", 
       RowBox[{"ee", " ", "S24"}], "-", 
       RowBox[{"ee", " ", "S34"}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "ee"}], " ", "S15"}], "-", 
       RowBox[{"ee", " ", "S25"}], "-", 
       RowBox[{"ee", " ", "S35"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "ee"}], " ", "S14"}], "-", 
       RowBox[{"ee", " ", "S24"}], "-", 
       RowBox[{"ee", " ", "S34"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "ee"}], " ", "S13"}], "-", 
       RowBox[{"ee", " ", "S23"}], "-", 
       RowBox[{"ee", " ", "S33"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0"},
     {"0"},
     {"0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{0, 0, 0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", " ", "1", ",", " ", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"traction", " ", "=", " ", 
  RowBox[{
   RowBox[{"sig", " ", ".", " ", "normal"}], " "}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "ee"}], " ", "S16"}], "-", 
    RowBox[{"ee", " ", "S26"}], "-", 
    RowBox[{"ee", " ", "S36"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "ee"}], " ", "S12"}], "-", 
    RowBox[{"ee", " ", "S22"}], "-", 
    RowBox[{"ee", " ", "S23"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "ee"}], " ", "S14"}], "-", 
    RowBox[{"ee", " ", "S24"}], "-", 
    RowBox[{"ee", " ", "S34"}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{890, 793},
WindowMargins->{{Automatic, 1}, {Automatic, 10}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 118, 3, 101, "Section"],
Cell[CellGroupData[{
Cell[1474, 45, 291, 8, 55, "Input"],
Cell[1768, 55, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1855, 58, 189, 3, 77, "Input"],
Cell[CellGroupData[{
Cell[2069, 65, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2181, 70, 137, 3, 32, "Input"],
Cell[2321, 75, 96, 2, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2466, 83, 96, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2587, 88, 211, 7, 32, "Input"],
Cell[2801, 97, 285, 11, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3123, 113, 386, 10, 121, "Input"],
Cell[3512, 125, 83, 2, 31, "Output"],
Cell[3598, 129, 391, 8, 45, "Message"],
Cell[3992, 139, 86, 2, 31, "Output"],
Cell[4081, 143, 218, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4336, 156, 3409, 94, 297, "Input"],
Cell[7748, 252, 1578, 53, 76, "Output"],
Cell[9329, 307, 219, 8, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9585, 320, 169, 5, 27, "Input"],
Cell[9757, 327, 171, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9965, 336, 113, 2, 27, "Input"],
Cell[10081, 340, 2003, 68, 59, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12133, 414, 112, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[12270, 419, 236, 6, 43, "Input"],
Cell[12509, 427, 326, 11, 27, "Output"],
Cell[12838, 440, 260, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13135, 453, 113, 2, 27, "Input"],
Cell[13251, 457, 218, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13506, 470, 3417, 95, 171, "Input"],
Cell[16926, 567, 1605, 53, 76, "Output"],
Cell[18534, 622, 173, 7, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18744, 634, 263, 7, 43, "Input"],
Cell[19010, 643, 83, 2, 27, "Output"],
Cell[19096, 647, 500, 17, 27, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

