(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     60291,       1939]
NotebookOptionsPosition[     56463,       1804]
NotebookOutlinePosition[     56907,       1822]
CellTagsIndexPosition[     56864,       1819]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["Cylinder under pressure ", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "Displacement.m"}], "\[IndentingNewLine]"}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The general solution in cylindrical coordinate \
system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"u", "[", 
   RowBox[{"r_", ",", "t_", ",", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ur", "[", "r", "]"}], ",", "0", ",", 
    RowBox[{"uz", "[", "z", "]"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"Strain", "[", " ", 
     RowBox[{"u", " ", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]}], " ", ")"}], " ", "//",
   "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"Tr", "[", "eps", " ", "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", " ", "]"}]}], "+", " ", 
     RowBox[{"2", " ", "\[Mu]", " ", "eps"}]}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["ur", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"ur", "[", "r", "]"}], "r"], "0"},
     {"0", "0", 
      RowBox[{
       SuperscriptBox["uz", "\[Prime]",
        MultilineFunction->None], "[", "z", "]"}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{
         SuperscriptBox["ur", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"ur", "[", "r", "]"}], "r"], "+", 
          RowBox[{
           SuperscriptBox["ur", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "+", 
          RowBox[{
           SuperscriptBox["uz", "\[Prime]",
            MultilineFunction->None], "[", "z", "]"}]}], ")"}]}]}], "0", 
      "0"},
     {"0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"ur", "[", "r", "]"}], "r"], "+", 
          RowBox[{
           SuperscriptBox["ur", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "+", 
          RowBox[{
           SuperscriptBox["uz", "\[Prime]",
            MultilineFunction->None], "[", "z", "]"}]}], ")"}]}]}], "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{
         SuperscriptBox["uz", "\[Prime]",
          MultilineFunction->None], "[", "z", "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"ur", "[", "r", "]"}], "r"], "+", 
          RowBox[{
           SuperscriptBox["ur", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "+", 
          RowBox[{
           SuperscriptBox["uz", "\[Prime]",
            MultilineFunction->None], "[", "z", "]"}]}], ")"}]}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"divsig", " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Div", "[", " ", "sig", " ", "]"}], "]"}]}], " ", ")"}], " ", "//",
   " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"ur", "[", "r", "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["ur", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}], "+", 
             RowBox[{"r", " ", 
              RowBox[{
               SuperscriptBox["ur", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
         ")"}]}], 
       SuperscriptBox["r", "2"]]},
     {"0"},
     {
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["uz", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "z", "]"}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   r^(-2) (\[Lambda] + 2 \[Mu]) (-ur[r] + 
     r (Derivative[1][ur][r] + r Derivative[2][ur][r])), 
    0, (\[Lambda] + 2 \[Mu]) Derivative[2][uz][z]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"solur", " ", "=", " ", 
  RowBox[{
   RowBox[{"DSolve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"divsig", "[", 
       RowBox[{"[", "1", "]"}], "]"}], " ", "\[Equal]", " ", "0"}], ",", " ", 
     "ur", ",", " ", "r", " ", ",", " ", 
     StyleBox[
      RowBox[{"GeneratedParameters", "->", " ", "CR"}], "MR"]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"soluz", " ", "=", " ", 
  RowBox[{
   RowBox[{"DSolve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"divsig", "[", 
       RowBox[{"[", "3", "]"}], "]"}], " ", "\[Equal]", " ", "0"}], ",", " ", 
     "uz", ",", " ", "z", " ", ",", " ", 
     StyleBox[
      RowBox[{"GeneratedParameters", "->", " ", "CZ"}], "MR"]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"ur", "\[Rule]", 
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", "r", "}"}], ",", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["r", "2"]}], ")"}], " ", 
       RowBox[{"CR", "[", "1", "]"}]}], 
      RowBox[{"2", " ", "r"}]], "+", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["r", "2"]}], ")"}], " ", 
       RowBox[{"CR", "[", "2", "]"}]}], 
      RowBox[{"2", " ", "r"}]]}]}], "]"}]}]], "Output"],

Cell[BoxData[
 RowBox[{"uz", "\[Rule]", 
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", "z", "}"}], ",", 
    RowBox[{
     RowBox[{"CZ", "[", "1", "]"}], "+", 
     RowBox[{"z", " ", 
      RowBox[{"CZ", "[", "2", "]"}]}]}]}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"solur", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "2"}], "]"}], "]"}], " ", "/.", " ", 
   RowBox[{
    RowBox[{"CR", "[", "1", "]"}], " ", "\[Rule]", " ", 
    RowBox[{"(", 
     RowBox[{"A", " ", "+", " ", "B"}], ")"}]}]}], "/.", " ", 
  RowBox[{
   RowBox[{"CR", "[", "2", "]"}], " ", "\[Rule]", " ", 
   RowBox[{"\[ImaginaryI]", "  ", 
    RowBox[{"(", 
     RowBox[{"A", " ", "-", " ", "B"}], ")"}], "  "}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"A", "-", "B"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["r", "2"]}], ")"}]}], 
    RowBox[{"2", " ", "r"}]]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"A", "+", "B"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["r", "2"]}], ")"}]}], 
   RowBox[{"2", " ", "r"}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", "%", " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["A", "r"], "+", 
  RowBox[{"B", " ", "r"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"exp", " ", "=", " ", 
    RowBox[{"D", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", "r"}], " ", 
       RowBox[{"D", "[", " ", 
        RowBox[{
         RowBox[{"r", " ", 
          RowBox[{"ur", "[", "r", "]"}]}], ",", " ", "r"}], " ", "]"}]}], ",",
       " ", "r"}], " ", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", " ", "exp", " ", "]"}]}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"ur", "[", "r", "]"}], "+", 
     RowBox[{"r", " ", 
      RowBox[{
       SuperscriptBox["ur", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}], 
    SuperscriptBox["r", "2"]]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["ur", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], "+", 
    RowBox[{"r", " ", 
     RowBox[{
      SuperscriptBox["ur", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}]}], "r"]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"ur", "[", "r", "]"}], 
    SuperscriptBox["r", "2"]]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["ur", "\[Prime]",
     MultilineFunction->None], "[", "r", "]"}], "r"], "+", 
  RowBox[{
   SuperscriptBox["ur", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "r", "]"}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The cylinder under internal and external pressure: pi \
and pe and vertical pressure pz",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"u", " ", "[", 
     RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", "/.", " ", "solur"}], " ",
    "/.", "soluz"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["r", "2"]}], ")"}], " ", 
      RowBox[{"CR", "[", "1", "]"}]}], 
     RowBox[{"2", " ", "r"}]], "+", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["r", "2"]}], ")"}], " ", 
      RowBox[{"CR", "[", "2", "]"}]}], 
     RowBox[{"2", " ", "r"}]]}], ",", "0", ",", 
   RowBox[{
    RowBox[{"CZ", "[", "1", "]"}], "+", 
    RowBox[{"z", " ", 
     RowBox[{"CZ", "[", "2", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"Strain", "[", " ", "uu", " ", "]"}]}], " ", ")"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"Tr", "[", "eps", " ", "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", " ", "]"}]}], "+", " ", 
     RowBox[{"2", " ", "\[Mu]", " ", "eps"}]}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"CR", "[", "1", "]"}]}], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["r", "2"]}], ")"}], " ", 
           RowBox[{"CR", "[", "1", "]"}]}], 
          SuperscriptBox["r", "2"]], "+", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          RowBox[{"CR", "[", "2", "]"}]}], "-", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["r", "2"]}], ")"}], " ", 
           RowBox[{"CR", "[", "2", "]"}]}], 
          SuperscriptBox["r", "2"]]}], ")"}]}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["r", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "1", "]"}]}], 
         RowBox[{"2", " ", "r"}]], "+", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["r", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "2", "]"}]}], 
         RowBox[{"2", " ", "r"}]]}], "r"], "0"},
     {"0", "0", 
      RowBox[{"CZ", "[", "2", "]"}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"CR", "[", "1", "]"}]}], "-", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["r", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "1", "]"}]}], 
           SuperscriptBox["r", "2"]], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           RowBox[{"CR", "[", "2", "]"}]}], "-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["r", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "2", "]"}]}], 
           SuperscriptBox["r", "2"]]}], ")"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"CR", "[", "1", "]"}]}], "-", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["r", "2"]}], ")"}], " ", 
               RowBox[{"CR", "[", "1", "]"}]}], 
              SuperscriptBox["r", "2"]], "+", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              RowBox[{"CR", "[", "2", "]"}]}], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["r", "2"]}], ")"}], " ", 
               RowBox[{"CR", "[", "2", "]"}]}], 
              SuperscriptBox["r", "2"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["r", "2"]}], ")"}], " ", 
              RowBox[{"CR", "[", "1", "]"}]}], 
             RowBox[{"2", " ", "r"}]], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["r", "2"]}], ")"}], " ", 
              RowBox[{"CR", "[", "2", "]"}]}], 
             RowBox[{"2", " ", "r"}]]}], "r"], "+", 
          RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}], "0", "0"},
     {"0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["r", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "1", "]"}]}], 
            RowBox[{"2", " ", "r"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["r", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "2", "]"}]}], 
            RowBox[{"2", " ", "r"}]]}], ")"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"CR", "[", "1", "]"}]}], "-", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["r", "2"]}], ")"}], " ", 
               RowBox[{"CR", "[", "1", "]"}]}], 
              SuperscriptBox["r", "2"]], "+", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              RowBox[{"CR", "[", "2", "]"}]}], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["r", "2"]}], ")"}], " ", 
               RowBox[{"CR", "[", "2", "]"}]}], 
              SuperscriptBox["r", "2"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["r", "2"]}], ")"}], " ", 
              RowBox[{"CR", "[", "1", "]"}]}], 
             RowBox[{"2", " ", "r"}]], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["r", "2"]}], ")"}], " ", 
              RowBox[{"CR", "[", "2", "]"}]}], 
             RowBox[{"2", " ", "r"}]]}], "r"], "+", 
          RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}], "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{"CZ", "[", "2", "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"CR", "[", "1", "]"}]}], "-", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["r", "2"]}], ")"}], " ", 
               RowBox[{"CR", "[", "1", "]"}]}], 
              SuperscriptBox["r", "2"]], "+", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              RowBox[{"CR", "[", "2", "]"}]}], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["r", "2"]}], ")"}], " ", 
               RowBox[{"CR", "[", "2", "]"}]}], 
              SuperscriptBox["r", "2"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["r", "2"]}], ")"}], " ", 
              RowBox[{"CR", "[", "1", "]"}]}], 
             RowBox[{"2", " ", "r"}]], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["r", "2"]}], ")"}], " ", 
              RowBox[{"CR", "[", "2", "]"}]}], 
             RowBox[{"2", " ", "r"}]]}], "r"], "+", 
          RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["simetry condition on the vertical axis ",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqz0", " ", "=", " ", 
  RowBox[{"(", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"uu", "[", 
       RowBox[{"[", "3", "]"}], "]"}], " ", "/.", " ", 
      RowBox[{"z", " ", "\[Rule]", " ", "0"}]}], ")"}], " ", "\[Equal]", " ", 
    "0"}], ")"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CZ", "[", "1", "]"}], "\[Equal]", "0"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["condition for the vertical pressure",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ez", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"normal", " ", "=", " ", "ez"}], "\[IndentingNewLine]", 
 RowBox[{"eqv", " ", "=", " ", 
  RowBox[{"(", "  ", 
   RowBox[{"Thread", " ", "[", " ", 
    RowBox[{
     RowBox[{"sig", " ", ".", " ", "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"+", " ", "pz"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "1"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "1"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"2", " ", "\[Mu]", " ", 
      RowBox[{"CZ", "[", "2", "]"}]}], "+", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"CR", "[", "1", "]"}]}], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["r", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "1", "]"}]}], 
            SuperscriptBox["r", "2"]], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            RowBox[{"CR", "[", "2", "]"}]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["r", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "2", "]"}]}], 
            SuperscriptBox["r", "2"]]}], ")"}]}], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["r", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "1", "]"}]}], 
           RowBox[{"2", " ", "r"}]], "+", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["r", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "2", "]"}]}], 
           RowBox[{"2", " ", "r"}]]}], "r"], "+", 
        RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}], "\[Equal]", "pz"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["condition for the internal and external pressure",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"er", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"1", ",", "0", ",", "0"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", " ", 
  RowBox[{"-", " ", "er"}]}], "\[IndentingNewLine]", 
 RowBox[{"eqi", " ", "=", " ", 
  RowBox[{"(", " ", 
   RowBox[{"Thread", " ", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sig", " ", "/.", " ", 
        RowBox[{"r", " ", "\[Rule]", " ", "ri"}]}], ")"}], " ", ".", " ", 
      "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"-", " ", "pi"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[Mu]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"CR", "[", "1", "]"}]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["ri", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "1", "]"}]}], 
         SuperscriptBox["ri", "2"]], "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         RowBox[{"CR", "[", "2", "]"}]}], "-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["ri", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "2", "]"}]}], 
         SuperscriptBox["ri", "2"]]}], ")"}]}], "-", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"CR", "[", "1", "]"}]}], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["ri", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "1", "]"}]}], 
            SuperscriptBox["ri", "2"]], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            RowBox[{"CR", "[", "2", "]"}]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["ri", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "2", "]"}]}], 
            SuperscriptBox["ri", "2"]]}], ")"}]}], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["ri", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "1", "]"}]}], 
           RowBox[{"2", " ", "ri"}]], "+", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["ri", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "2", "]"}]}], 
           RowBox[{"2", " ", "ri"}]]}], "ri"], "+", 
        RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}], "\[Equal]", "pi"}], ",", 
   "True", ",", "True"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", "  ", "er"}], "\[IndentingNewLine]", 
 RowBox[{"eqe", " ", "=", " ", 
  RowBox[{"(", "  ", 
   RowBox[{"Thread", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sig", " ", "/.", " ", 
        RowBox[{"r", " ", "\[Rule]", " ", "re"}]}], ")"}], " ", ".", " ", 
      "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"+", " ", "pe"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"CR", "[", "1", "]"}]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["re", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "1", "]"}]}], 
         SuperscriptBox["re", "2"]], "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         RowBox[{"CR", "[", "2", "]"}]}], "-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["re", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "2", "]"}]}], 
         SuperscriptBox["re", "2"]]}], ")"}]}], "+", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"CR", "[", "1", "]"}]}], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["re", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "1", "]"}]}], 
            SuperscriptBox["re", "2"]], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            RowBox[{"CR", "[", "2", "]"}]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["re", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "2", "]"}]}], 
            SuperscriptBox["re", "2"]]}], ")"}]}], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["re", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "1", "]"}]}], 
           RowBox[{"2", " ", "re"}]], "+", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["re", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "2", "]"}]}], 
           RowBox[{"2", " ", "re"}]]}], "re"], "+", 
        RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}], "\[Equal]", "pe"}], ",", 
   "True", ",", "True"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"eqi", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
     RowBox[{"eqe", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "  ", "/.", " ", 
   RowBox[{
    RowBox[{"CZ", "[", "2", "]"}], " ", "\[Rule]", " ", "0"}]}], " ", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solve", "[", " ", 
  RowBox[{"%", ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"CR", "[", "1", "]"}], ",", " ", 
     RowBox[{"CR", "[", "2", "]"}]}], "}"}]}], " ", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"CR", "[", "1", "]"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["ri", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"CR", "[", "1", "]"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}]}], 
     SuperscriptBox["ri", "2"]], "\[Equal]", "pi"}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[Mu]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"CR", "[", "1", "]"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["re", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"CR", "[", "1", "]"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}]}], 
     SuperscriptBox["re", "2"]], "\[Equal]", "pe"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"CR", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", 
         SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
        RowBox[{"pi", " ", 
         SuperscriptBox["re", "2"], " ", 
         SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", "\[Mu]"}], "+", 
        RowBox[{"pi", " ", 
         SuperscriptBox["ri", "2"], " ", "\[Mu]"}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", 
         SuperscriptBox["ri", "2"], " ", "\[Mu]"}], "+", 
        RowBox[{"pi", " ", 
         SuperscriptBox["re", "2"], " ", 
         SuperscriptBox["ri", "2"], " ", "\[Mu]"}]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["re", "2"]}], "+", 
          SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]]}]}], ",", 
    RowBox[{
     RowBox[{"CR", "[", "2", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "+", "\[Mu]", "-", 
           FractionBox["\[Mu]", 
            SuperscriptBox["re", "2"]]}], ")"}]}], "-", 
        RowBox[{"pe", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Lambda]"}], "-", "\[Mu]", "+", 
           FractionBox["\[Mu]", 
            SuperscriptBox["ri", "2"]]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Lambda]", " ", "\[Mu]"}],
           
          SuperscriptBox["re", "2"]]}], "+", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Lambda]", " ", "\[Mu]"}], 
         
         SuperscriptBox["ri", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          SuperscriptBox["\[Mu]", "2"]}], 
         SuperscriptBox["re", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          SuperscriptBox["\[Mu]", "2"]}], 
         SuperscriptBox["ri", "2"]]}]]}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", " ", "/.", " ", "%"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["r", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"pe", " ", 
           SuperscriptBox["re", "2"], " ", 
           SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
          RowBox[{"pi", " ", 
           SuperscriptBox["re", "2"], " ", 
           SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
          RowBox[{"pe", " ", 
           SuperscriptBox["re", "2"], " ", "\[Mu]"}], "+", 
          RowBox[{"pi", " ", 
           SuperscriptBox["ri", "2"], " ", "\[Mu]"}], "+", 
          RowBox[{"pe", " ", 
           SuperscriptBox["re", "2"], " ", 
           SuperscriptBox["ri", "2"], " ", "\[Mu]"}], "+", 
          RowBox[{"pi", " ", 
           SuperscriptBox["re", "2"], " ", 
           SuperscriptBox["ri", "2"], " ", "\[Mu]"}]}], ")"}]}], 
       RowBox[{"4", " ", "r", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["re", "2"]}], "+", 
          SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]]}], "-", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["r", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"pi", " ", 
          RowBox[{"(", 
           RowBox[{"\[Lambda]", "+", "\[Mu]", "-", 
            FractionBox["\[Mu]", 
             SuperscriptBox["re", "2"]]}], ")"}]}], "-", 
         RowBox[{"pe", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Lambda]"}], "-", "\[Mu]", "+", 
            FractionBox["\[Mu]", 
             SuperscriptBox["ri", "2"]]}], ")"}]}]}], ")"}]}], 
      RowBox[{"2", " ", "r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
           "2", " ", "\[ImaginaryI]", " ", "\[Lambda]", " ", "\[Mu]"}], 
           SuperscriptBox["re", "2"]]}], "+", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Lambda]", " ", "\[Mu]"}],
           
          SuperscriptBox["ri", "2"]], "-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["\[Mu]", "2"]}], 
          SuperscriptBox["re", "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["\[Mu]", "2"]}], 
          SuperscriptBox["ri", "2"]]}], ")"}]}]]}], ",", "0", ",", 
    RowBox[{
     RowBox[{"CZ", "[", "1", "]"}], "+", 
     RowBox[{"z", " ", 
      RowBox[{"CZ", "[", "2", "]"}]}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"pi", " ", 
       SuperscriptBox["ri", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["r", "2"], " ", "\[Mu]"}], "+", 
         RowBox[{
          SuperscriptBox["re", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"pe", " ", 
       SuperscriptBox["re", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["r", "2"], " ", "\[Mu]"}], "+", 
         RowBox[{
          SuperscriptBox["ri", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]}], ")"}]}]}], 
     RowBox[{"2", " ", "r", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["re", "2"], "-", 
        SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]], ",", "0", ",", 
    RowBox[{
     RowBox[{"CZ", "[", "1", "]"}], "+", 
     RowBox[{"z", " ", 
      RowBox[{"CZ", "[", "2", "]"}]}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"eqv", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", 
      RowBox[{"eqi", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
      RowBox[{"eqe", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "}"}], " ", "]"}], 
   "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"pz", "\[Equal]", 
    RowBox[{
     RowBox[{"2", " ", "\[Mu]", " ", 
      RowBox[{"CZ", "[", "2", "]"}]}], "+", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CR", "[", "1", "]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"CR", "[", "2", "]"}]}], "+", 
        RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"CR", "[", "1", "]"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["ri", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"CR", "[", "1", "]"}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"CR", "[", "1", "]"}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"CR", "[", "2", "]"}]}], "+", 
            RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}], ")"}]}]}], 
     SuperscriptBox["ri", "2"]], "\[Equal]", "pi"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["re", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "1", "]"}]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["re", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], 
      SuperscriptBox["re", "2"]], "+", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CR", "[", "1", "]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"CR", "[", "2", "]"}]}], "+", 
        RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}], "\[Equal]", "pe"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"Solve", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"eqv", "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", 
        RowBox[{"eqi", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
        RowBox[{"eqe", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "}"}], " ", ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"CR", "[", "1", "]"}], ",", " ", 
        RowBox[{"CR", "[", "2", "]"}], ",", " ", 
        RowBox[{"CZ", "[", "2", "]"}]}], "}"}]}], " ", "]"}], " ", "]"}], "[",
    
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"CR", "[", "1", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"pz", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["re", "2"]}], "+", 
         SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Lambda]"}], "+", 
      RowBox[{"pi", " ", 
       SuperscriptBox["ri", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["re", "2"], " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["re", "2"]}], ")"}], " ", "\[Mu]"}]}], ")"}]}], 
      "+", 
      RowBox[{"pe", " ", 
       SuperscriptBox["re", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]"}]}], ")"}]}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["re", "2"], "-", 
        SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"CR", "[", "2", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"pz", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["re", "2"], "-", 
           SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Lambda]"}], "+", 
        RowBox[{"pi", " ", 
         SuperscriptBox["ri", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["re", "2"]}]}], ")"}], " ", "\[Lambda]"}], "+", 
           
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["re", "2"]}], ")"}], " ", "\[Mu]"}]}], ")"}]}], 
        "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["ri", "2"]}]}], ")"}], " ", "\[Lambda]"}], "+", 
           
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]"}]}], ")"}]}]}],
        ")"}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["re", "2"], "-", 
        SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"CZ", "[", "2", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "pe"}], " ", 
       SuperscriptBox["re", "2"], " ", "\[Lambda]"}], "-", 
      RowBox[{"pi", " ", 
       SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
      RowBox[{"pz", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["re", "2"], "-", 
         SuperscriptBox["ri", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["re", "2"], "-", 
        SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", " ", 
  RowBox[{"uu", " ", "/.", " ", "sol"}], " ", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"eps", " ", "/.", " ", "sol"}], " ", "]"}], " ", "//", " ", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"sig", " ", "/.", " ", "sol"}], " ", "]"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"pz", " ", 
      SuperscriptBox["r", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["re", "2"]}], "+", 
        SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Lambda]"}], "+", 
     RowBox[{"pi", " ", 
      SuperscriptBox["ri", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["re", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"pe", " ", 
      SuperscriptBox["re", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["ri", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}]}], 
    RowBox[{"2", " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["re", "2"], "-", 
       SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "\[Lambda]"}], "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], ",", "0", ",", 
   RowBox[{
    FractionBox[
     RowBox[{"z", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "pe"}], " ", 
         SuperscriptBox["re", "2"], " ", "\[Lambda]"}], "-", 
        RowBox[{"pi", " ", 
         SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
        RowBox[{"pz", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["re", "2"], "-", 
           SuperscriptBox["ri", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["re", "2"], "-", 
        SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
    RowBox[{"CZ", "[", "1", "]"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"pz", " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["re", "2"]}], "+", 
           SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Lambda]"}], "+", 
        RowBox[{"pi", " ", 
         SuperscriptBox["ri", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Lambda]", "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
           RowBox[{
            SuperscriptBox["re", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Lambda]", "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
           RowBox[{
            SuperscriptBox["ri", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{"pz", " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["re", "2"]}], "+", 
           SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Lambda]"}], "+", 
        RowBox[{"pi", " ", 
         SuperscriptBox["ri", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Lambda]", "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["re", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Lambda]", "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["ri", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "pe"}], " ", 
         SuperscriptBox["re", "2"], " ", "\[Lambda]"}], "-", 
        RowBox[{"pi", " ", 
         SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
        RowBox[{"pz", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["re", "2"], "-", 
           SuperscriptBox["ri", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "2"], "-", 
           SuperscriptBox["re", "2"]}], ")"}], " ", 
         SuperscriptBox["ri", "2"]}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "2"], "-", 
           SuperscriptBox["ri", "2"]}], ")"}]}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}]}]], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           SuperscriptBox["re", "2"]}], ")"}], " ", 
         SuperscriptBox["ri", "2"]}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           SuperscriptBox["ri", "2"]}], ")"}]}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}]}]], "0"},
     {"0", "0", "pz"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1170, 769},
WindowMargins->{{Automatic, 0}, {12, Automatic}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 67, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[1423, 43, 291, 8, 55, "Input"],
Cell[1717, 53, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1804, 56, 150, 2, 77, "Input"],
Cell[CellGroupData[{
Cell[1979, 62, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2091, 67, 139, 3, 32, "Input"],
Cell[2233, 72, 98, 2, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2380, 80, 121, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2526, 86, 844, 23, 77, "Input"],
Cell[3373, 111, 482, 16, 72, "Output"],
Cell[3858, 129, 1912, 56, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5807, 190, 221, 6, 32, "Input"],
Cell[6031, 198, 1260, 38, 74, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7328, 241, 869, 24, 55, "Input"],
Cell[8200, 267, 613, 20, 46, "Output"],
Cell[8816, 289, 257, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9110, 302, 478, 14, 27, "Input"],
Cell[9591, 318, 497, 19, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10125, 342, 71, 1, 27, "Input"],
Cell[10199, 345, 94, 3, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10330, 353, 446, 13, 43, "Input"],
Cell[10779, 368, 602, 20, 44, "Output"],
Cell[11384, 390, 369, 12, 43, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11802, 408, 153, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[11980, 414, 207, 6, 27, "Input"],
Cell[12190, 422, 651, 22, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12878, 449, 527, 14, 43, "Input"],
Cell[13408, 465, 1592, 49, 95, "Output"],
Cell[15003, 516, 6765, 186, 165, "Output"]
}, Open  ]],
Cell[21783, 705, 45, 0, 43, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21865, 710, 105, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[21995, 715, 302, 9, 27, "Input"],
Cell[22300, 726, 86, 2, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22435, 734, 101, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[22561, 739, 500, 14, 59, "Input"],
Cell[23064, 755, 83, 2, 27, "Output"],
Cell[23150, 759, 83, 2, 27, "Output"],
Cell[23236, 763, 1776, 51, 67, "Output"]
}, Open  ]],
Cell[25027, 817, 26, 0, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25090, 822, 114, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[25229, 827, 117, 3, 27, "Input"],
Cell[25349, 832, 83, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25469, 839, 495, 14, 43, "Input"],
Cell[25967, 855, 102, 3, 27, "Output"],
Cell[26072, 860, 2490, 72, 115, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28599, 937, 469, 13, 43, "Input"],
Cell[29071, 952, 83, 2, 27, "Output"],
Cell[29157, 956, 2468, 71, 115, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31662, 1032, 571, 17, 43, "Input"],
Cell[32236, 1051, 1336, 41, 47, "Output"],
Cell[33575, 1094, 2365, 66, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35977, 1165, 61, 1, 27, "Input"],
Cell[36041, 1168, 2845, 79, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38923, 1252, 61, 1, 27, "Input"],
Cell[38987, 1255, 1174, 36, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40198, 1296, 400, 12, 59, "Input"],
Cell[40601, 1310, 2207, 66, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42845, 1381, 691, 20, 27, "Input"],
Cell[43539, 1403, 3975, 121, 91, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47551, 1529, 424, 10, 59, "Input"],
Cell[47978, 1541, 2504, 77, 49, "Output"],
Cell[50485, 1620, 4443, 129, 105, "Output"],
Cell[54931, 1751, 1492, 48, 91, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

