(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     18709,        670]
NotebookOptionsPosition[     15910,        571]
NotebookOutlinePosition[     16354,        589]
CellTagsIndexPosition[     16311,        586]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["Heating of a double layer plate ", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "Displacement.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "IntegrateStrain.m"}], "\[IndentingNewLine]"}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The general solution of the heating of a plate \
(Integration of strain is easy due to the diagonal form of the strain)",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"sig", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "s"}], "}"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"eps", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", " ", "+", " ", "nu"}], ")"}], "/", " ", "EE"}], " ", 
    "sig"}], " ", "-", " ", 
   RowBox[{
    RowBox[{"nu", "/", " ", "EE"}], " ", 
    RowBox[{"Tr", "[", " ", "sig", " ", "]"}], " ", 
    RowBox[{"IdentityMatrix", "[", "3", "]"}]}], " ", "+", " ", 
   RowBox[{"alpha", " ", "tau", " ", 
    RowBox[{"IdentityMatrix", "[", "3", "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"sig", " ", "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{"eps", " ", "//", " ", 
  "MatrixForm"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "s"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"nu", " ", "s"}], "EE"]}], "+", 
      RowBox[{"alpha", " ", "tau"}]}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"nu", " ", "s"}], "EE"]}], "+", 
      RowBox[{"alpha", " ", "tau"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"nu", " ", "s"}], "EE"]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", "s"}], "EE"], "+", 
      RowBox[{"alpha", " ", "tau"}]}]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", "0"},
     {"0", "0", "s"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"nu", " ", "s"}], "EE"]}], "+", 
       RowBox[{"alpha", " ", "tau"}]}], "0", "0"},
     {"0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"nu", " ", "s"}], "EE"]}], "+", 
       RowBox[{"alpha", " ", "tau"}]}], "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"nu", " ", "s"}], "EE"]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", "s"}], "EE"], "+", 
       RowBox[{"alpha", " ", "tau"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "=", 
  RowBox[{"IntegrateStrain", "[", "eps", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"nu", " ", "s"}], "EE"]}], "+", 
      RowBox[{"alpha", " ", "tau"}]}], ")"}], " ", "x"}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"nu", " ", "s"}], "EE"]}], "+", 
      RowBox[{"alpha", " ", "tau"}]}], ")"}], " ", "y"}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox["s", "EE"], "+", 
      RowBox[{"alpha", " ", "tau"}]}], ")"}], " ", "z"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ssol", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", "[", 
         RowBox[{"[", "3", "]"}], "]"}], " ", "/.", " ", 
        RowBox[{"z", " ", "\[Rule]", " ", 
         RowBox[{"lz", "/", "2"}]}]}], " ", ")"}], "\[Equal]", " ", "0"}], 
     ",", " ", "s"}], " ", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"s", "\[Rule]", 
  RowBox[{
   RowBox[{"-", "alpha"}], " ", "EE", " ", "tau"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"[", "3", "]"}], "]"}], " ", "/.", " ", 
   RowBox[{"z", " ", "\[Rule]", " ", 
    RowBox[{
     RowBox[{"-", "lz"}], "/", "2"}]}]}], "  ", "/.", " ", "ssol", 
  " "}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"uf", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"u", " ", "/.", " ", "ssol"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"sigf", " ", "=", " ", 
    RowBox[{"sig", " ", "/.", " ", "ssol"}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"epsf", " ", "=", " ", 
    RowBox[{"eps", " ", "/.", " ", "ssol"}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"alpha", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", "tau", " ", "x"}], ",", 
   RowBox[{"alpha", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", "tau", " ", "y"}], ",", "0"}], 
  "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"-", "alpha"}], " ", "EE", " ", "tau"}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(epsf\\)\
\\\" is similar to existing symbol \\\"\\!\\(eps\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"alpha", " ", "tau"}], "+", 
       RowBox[{"alpha", " ", "nu", " ", "tau"}]}], "0", "0"},
     {"0", 
      RowBox[{
       RowBox[{"alpha", " ", "tau"}], "+", 
       RowBox[{"alpha", " ", "nu", " ", "tau"}]}], "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"alpha", " ", "tau"}], "+", 
       RowBox[{"alpha", " ", "nu", " ", "tau"}], "-", 
       RowBox[{"alpha", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", "tau"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Case of the heating of a doublelayer plate ",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"up", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"uf", " ", "/.", " ", 
     RowBox[{"alpha", " ", "\[Rule]", " ", "ap"}]}], " ", "/.", "  ", 
    RowBox[{"nu", " ", "\[Rule]", " ", "nup"}]}], "  ", "/.", " ", 
   RowBox[{
   "EE", " ", "\[Rule]", " ", "EEp", " "}]}]}], "\[IndentingNewLine]", 
 RowBox[{"epsp", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"epsf", " ", "/.", " ", 
     RowBox[{"alpha", " ", "\[Rule]", " ", "ap"}]}], " ", "/.", "  ", 
    RowBox[{"nu", " ", "\[Rule]", " ", "nup"}]}], "  ", "/.", " ", 
   RowBox[{"EE", " ", "\[Rule]", " ", "EEp"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigp", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"sigf", " ", "/.", " ", 
      RowBox[{"alpha", " ", "\[Rule]", " ", "ap"}]}], " ", "/.", "  ", 
     RowBox[{"nu", " ", "\[Rule]", " ", "nup"}]}], "  ", "/.", " ", 
    RowBox[{"EE", " ", "\[Rule]", " ", "EEp"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"um", " ", "=", " ", 
  RowBox[{"uf", " ", "/.", " ", 
   RowBox[{"alpha", " ", "\[Rule]", " ", "am"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"epsm", " ", "=", " ", 
  RowBox[{"epsf", " ", "/.", " ", 
   RowBox[{"alpha", " ", "\[Rule]", " ", "am"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"sigm", " ", "=", " ", 
  RowBox[{"sigf", " ", "/.", " ", 
   RowBox[{
   "alpha", " ", "\[Rule]", " ", "am"}]}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ap", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nup"}], ")"}], " ", "tau", " ", "x"}], ",", 
   RowBox[{"ap", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nup"}], ")"}], " ", "tau", " ", "y"}], ",", "0"}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"ap", " ", "tau"}], "+", 
      RowBox[{"ap", " ", "nup", " ", "tau"}]}], ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"ap", " ", "tau"}], "+", 
      RowBox[{"ap", " ", "nup", " ", "tau"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"ap", " ", "tau"}], "+", 
      RowBox[{"ap", " ", "nup", " ", "tau"}], "-", 
      RowBox[{"ap", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nup"}], ")"}], " ", "tau"}]}]}], "}"}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", "ap"}], " ", "EEp", " ", "tau"}]}], "}"}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"am", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", "tau", " ", "x"}], ",", 
   RowBox[{"am", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", "tau", " ", "y"}], ",", "0"}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"am", " ", "tau"}], "+", 
      RowBox[{"am", " ", "nu", " ", "tau"}]}], ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"am", " ", "tau"}], "+", 
      RowBox[{"am", " ", "nu", " ", "tau"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"am", " ", "tau"}], "+", 
      RowBox[{"am", " ", "nu", " ", "tau"}], "-", 
      RowBox[{"am", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", "tau"}]}]}], "}"}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", "am"}], " ", "EE", " ", "tau"}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Check interface condition at the doublelayer frontier \
",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"tractionp", " ", "=", 
  RowBox[{"sigp", " ", ".", " ", "normal"}]}], "\[IndentingNewLine]", 
 RowBox[{"tractionm", " ", "=", 
  RowBox[{"sigm", " ", ".", " ", 
   RowBox[{"(", 
    RowBox[{"-", " ", "normal"}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tractionp", "  ", "+", " ", "tractionm"}], " ", "\[Equal]", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0"}], "}"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"up", " ", "/.", " ", 
  RowBox[{"x", " ", "\[Rule]", " ", "0", " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"ap", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nup"}], ")"}], " ", "tau", " ", "y"}], ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"um", " ", "/.", " ", 
  RowBox[{"x", " ", "\[Rule]", " ", "0", " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"am", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", "tau", " ", "y"}], ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Change position of the interface at the doublelayer \
frontier ",
 FontFamily->"Courier"]], "Subsection"],

Cell[BoxData[""], "Input"],

Cell[BoxData[""], "Input"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1170, 769},
WindowMargins->{{Automatic, 35}, {9, Automatic}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 75, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[1431, 43, 291, 8, 55, "Input"],
Cell[1725, 53, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1812, 56, 217, 3, 99, "Input"],
Cell[CellGroupData[{
Cell[2054, 63, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2166, 68, 137, 3, 32, "Input"],
Cell[2306, 73, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2439, 80, 132, 3, 32, "Input"],
Cell[2574, 85, 83, 2, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2706, 93, 185, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2916, 99, 953, 26, 121, "Input"],
Cell[3872, 127, 260, 8, 31, "Output"],
Cell[4135, 137, 798, 27, 46, "Output"],
Cell[4936, 166, 219, 8, 58, "Output"],
Cell[5158, 176, 776, 27, 84, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5971, 208, 98, 2, 27, "Input"],
Cell[6072, 212, 591, 21, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6700, 238, 467, 14, 27, "Input"],
Cell[7170, 254, 115, 3, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7322, 262, 247, 8, 27, "Input"],
Cell[7572, 272, 28, 0, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7637, 277, 493, 13, 59, "Input"],
Cell[8133, 292, 290, 9, 27, "Output"],
Cell[8426, 303, 286, 10, 76, "Output"],
Cell[8715, 315, 386, 8, 20, "Message"],
Cell[9104, 325, 651, 20, 76, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9804, 351, 109, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[9938, 356, 1430, 34, 139, "Input"],
Cell[11371, 392, 286, 9, 27, "Output"],
Cell[11660, 403, 670, 22, 27, "Output"],
Cell[12333, 427, 326, 11, 27, "Output"],
Cell[12662, 440, 284, 9, 27, "Output"],
Cell[12949, 451, 666, 22, 27, "Output"],
Cell[13618, 475, 325, 11, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13992, 492, 122, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[14139, 498, 554, 13, 75, "Input"],
Cell[14696, 513, 83, 2, 27, "Output"],
Cell[14782, 517, 83, 2, 27, "Output"],
Cell[14868, 521, 83, 2, 27, "Output"],
Cell[14954, 525, 31, 0, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15022, 530, 105, 2, 27, "Input"],
Cell[15130, 534, 186, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15353, 545, 105, 2, 27, "Input"],
Cell[15461, 549, 185, 6, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15695, 561, 129, 2, 37, "Subsection"],
Cell[15827, 565, 26, 0, 27, "Input"],
Cell[15856, 567, 26, 0, 27, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

