(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    248005,       6978]
NotebookOptionsPosition[    243552,       6821]
NotebookOutlinePosition[    243996,       6839]
CellTagsIndexPosition[    243953,       6836]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["Thranserve isotropic Sphere under pressure ", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "Displacement.m"}], "\[IndentingNewLine]"}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Spherical", "[", 
  RowBox[{"r", ",", "t", ",", "p"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "t", ",", "p"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"C2", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "C11", ",", "C12", ",", "C13", ",", "C14", ",", "C15", ",", "C16"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "C12", ",", "C22", ",", "C23", ",", "C24", ",", "C25", ",", "C26"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "C13", ",", "C23", ",", "C33", ",", "C34", ",", "C35", ",", "C36"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "C14", ",", "C24", ",", "C34", ",", "C44", ",", "C45", ",", "C46"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "C15", ",", "C25", ",", "C35", ",", "C45", ",", "C55", ",", "C56"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "C16", ",", "C26", ",", "C36", ",", "C46", ",", "C56", ",", "C66"}], 
     "}"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"C4", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C11", ",", "C16", ",", "C15"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C16", ",", "C12", ",", "C14"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C15", ",", "C14", ",", "C13"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C12", ",", "C26", ",", "C25"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C26", ",", "C22", ",", "C24"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C25", ",", "C24", ",", "C23"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C13", ",", "C36", ",", "C35"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C36", ",", "C23", ",", "C34"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C35", ",", "C34", ",", "C33"}], "}"}]}], "}"}]}], "}"}]}], 
    "}"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "C11", ",", "C12", ",", "C13", ",", "C14", ",", "C15", ",", "C16"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "C12", ",", "C22", ",", "C23", ",", "C24", ",", "C25", ",", "C26"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "C13", ",", "C23", ",", "C33", ",", "C34", ",", "C35", ",", "C36"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "C14", ",", "C24", ",", "C34", ",", "C44", ",", "C45", ",", "C46"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "C15", ",", "C25", ",", "C35", ",", "C45", ",", "C55", ",", "C56"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "C16", ",", "C26", ",", "C36", ",", "C46", ",", "C56", ",", "C66"}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"transverseisotropic", "=", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"Thread", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "C14", ",", "C15", ",", "C16", ",", "C24", ",", "C25", ",", "C26", ",",
         "C34", ",", "C35", ",", "C36", ",", "C45", ",", "C46", ",", "C56"}], 
       "}"}], "\[Rule]", "0"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"C33", "\[Rule]", "C22"}], ",", 
      RowBox[{"C13", "\[Rule]", "C12"}], ",", 
      RowBox[{"C66", "\[Rule]", "C55"}], ",", 
      RowBox[{"C44", "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "-", "C12"}], ")"}], "/", "2"}]}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C4TI", " ", "=", " ", 
    RowBox[{"C4", "/.", "transverseisotropic"}]}], ")"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C2TI", " ", "=", " ", 
    RowBox[{"C2", "/.", "transverseisotropic"}]}], ")"}], "//", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"C14", "\[Rule]", "0"}], ",", 
   RowBox[{"C15", "\[Rule]", "0"}], ",", 
   RowBox[{"C16", "\[Rule]", "0"}], ",", 
   RowBox[{"C24", "\[Rule]", "0"}], ",", 
   RowBox[{"C25", "\[Rule]", "0"}], ",", 
   RowBox[{"C26", "\[Rule]", "0"}], ",", 
   RowBox[{"C34", "\[Rule]", "0"}], ",", 
   RowBox[{"C35", "\[Rule]", "0"}], ",", 
   RowBox[{"C36", "\[Rule]", "0"}], ",", 
   RowBox[{"C45", "\[Rule]", "0"}], ",", 
   RowBox[{"C46", "\[Rule]", "0"}], ",", 
   RowBox[{"C56", "\[Rule]", "0"}], ",", 
   RowBox[{"C33", "\[Rule]", "C22"}], ",", 
   RowBox[{"C13", "\[Rule]", "C12"}], ",", 
   RowBox[{"C66", "\[Rule]", "C55"}], ",", 
   RowBox[{"C44", "\[Rule]", 
    FractionBox[
     RowBox[{"C11", "-", "C12"}], "2"]}]}], "}"}]], "Output"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C11", "0", "0"},
         {"0", "C12", "0"},
         {"0", "0", "C12"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "C55", "0"},
         {"C55", "0", "0"},
         {"0", "0", "0"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "0", "C55"},
         {"0", "0", "0"},
         {"C55", "0", "0"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "C55", "0"},
         {"C55", "0", "0"},
         {"0", "0", "0"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C12", "0", "0"},
         {"0", "C22", "0"},
         {"0", "0", "C23"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "0", "0"},
         {"0", "0", 
          FractionBox[
           RowBox[{"C11", "-", "C12"}], "2"]},
         {"0", 
          FractionBox[
           RowBox[{"C11", "-", "C12"}], "2"], "0"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "0", "C55"},
         {"0", "0", "0"},
         {"C55", "0", "0"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "0", "0"},
         {"0", "0", 
          FractionBox[
           RowBox[{"C11", "-", "C12"}], "2"]},
         {"0", 
          FractionBox[
           RowBox[{"C11", "-", "C12"}], "2"], "0"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C12", "0", "0"},
         {"0", "C23", "0"},
         {"0", "0", "C22"}
        }], "\[NoBreak]", ")"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{{{{C11, 0, 0}, {0, C12, 0}, {0, 0, C12}}, {{0, C55, 0}, {
      C55, 0, 0}, {0, 0, 0}}, {{0, 0, C55}, {0, 0, 0}, {C55, 0, 0}}}, {{{
      0, C55, 0}, {C55, 0, 0}, {0, 0, 0}}, {{C12, 0, 0}, {0, C22, 0}, {
      0, 0, C23}}, {{0, 0, 0}, {0, 0, Rational[1, 2] (C11 - C12)}, {
      0, Rational[1, 2] (C11 - C12), 0}}}, {{{0, 0, C55}, {0, 0, 0}, {
      C55, 0, 0}}, {{0, 0, 0}, {0, 0, Rational[1, 2] (C11 - C12)}, {
      0, Rational[1, 2] (C11 - C12), 0}}, {{C12, 0, 0}, {0, C23, 0}, {
      0, 0, C22}}}}]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C11", "C12", "C12", "0", "0", "0"},
     {"C12", "C22", "C23", "0", "0", "0"},
     {"C12", "C23", "C22", "0", "0", "0"},
     {"0", "0", "0", 
      FractionBox[
       RowBox[{"C11", "-", "C12"}], "2"], "0", "0"},
     {"0", "0", "0", "0", "C55", "0"},
     {"0", "0", "0", "0", "0", "C55"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The thermal solution in the spherical coordinate \
system",
 FontFamily->"Courier"]], "Subsection"],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<\[Theta]\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"k", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"krr", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "ktt", ",", " ", "0"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0", ",", " ", "ktt"}], "}"}]}], "}"}]}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"krr", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "ktt", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "ktt"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Div", "[", " ", 
   RowBox[{"k", " ", 
    RowBox[{"Grad", "[", " ", 
     RowBox[{"\[Theta]", "[", "r", "]"}], "]"}]}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", "krr", " ", 
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
    RowBox[{"krr", " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}]}], ",", "0", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soltemperature", " ", "=", " ", 
  RowBox[{
   RowBox[{"DSolve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "1", "]"}], "]"}], " ", "\[Equal]", " ", "0"}], " ", ",", 
     " ", 
     RowBox[{"\[Theta]", "[", "r", "]"}], ",", " ", "r"}], " ", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", " ", "1"}], "]"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Theta]", "[", "r", "]"}], "\[Rule]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"C", "[", "1", "]"}], "r"]}], "+", 
   RowBox[{"C", "[", "2", "]"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The general solution in the spherical coordinate \
system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"u", "[", 
   RowBox[{"r_", ",", "t_", ",", "p_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ur", "[", "r", "]"}], ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"Strain", "[", " ", 
     RowBox[{"u", " ", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}]}], " ", ")"}], " ", "//",
   "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{"Simplify", "[", " ", 
     RowBox[{"DDot", "[", " ", 
      RowBox[{"C4TI", ",", " ", "eps"}], " ", "]"}], "    ", "]"}]}], " ", 
   ")"}], "//", " ", "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["ur", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"ur", "[", "r", "]"}], "r"], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{"ur", "[", "r", "]"}], "r"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "C12", " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
       RowBox[{"C11", " ", 
        RowBox[{
         SuperscriptBox["ur", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"C22", "+", "C23"}], ")"}], " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "+", 
        RowBox[{"C12", " ", "r", " ", 
         RowBox[{
          SuperscriptBox["ur", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], "r"], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"C22", "+", "C23"}], ")"}], " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "+", 
        RowBox[{"C12", " ", "r", " ", 
         RowBox[{
          SuperscriptBox["ur", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], "r"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"divsig", " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Div", "[", " ", "sig", " ", "]"}], "]"}]}], " ", ")"}], " ", "//",
   " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}], " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "+", 
        RowBox[{"C11", " ", "r", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox["ur", "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{"r", " ", 
            RowBox[{
             SuperscriptBox["ur", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
       SuperscriptBox["r", "2"]]},
     {"0"},
     {"0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   r^(-2) (2 (C12 - C22 - C23) ur[r] + 
     C11 r (2 Derivative[1][ur][r] + r Derivative[2][ur][r])), 0, 
    0}]]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Notations (Lihnitskii page 415) ",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solur", " ", "=", " ", 
   RowBox[{
    RowBox[{"DSolve", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"divsig", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", "\[Equal]", " ", "0"}], ",", " ",
       
      RowBox[{"ur", "[", "r", "]"}], ",", " ", "r", " ", ",", " ", 
      StyleBox[
       RowBox[{"GeneratedParameters", "->", " ", "AR"}], "MR"]}], "]"}], "[", 
    
    RowBox[{"[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ur", "[", "r", "]"}], "\[Rule]", 
  RowBox[{
   RowBox[{
    SuperscriptBox["r", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["C11"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
           RowBox[{
            SqrtBox["2"], " ", 
            RowBox[{"(", 
             RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
         FractionBox[
          SqrtBox[
           RowBox[{"C11", "-", 
            RowBox[{"8", " ", "C12"}], "+", 
            RowBox[{"8", " ", "C22"}], "+", 
            RowBox[{"8", " ", "C23"}]}]], 
          RowBox[{
           SqrtBox["2"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox["C11"]}]]], " ", 
    RowBox[{"AR", "[", "1", "]"}]}], "+", 
   RowBox[{
    SuperscriptBox["r", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["C11"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
           RowBox[{
            SqrtBox["2"], " ", 
            RowBox[{"(", 
             RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
         FractionBox[
          SqrtBox[
           RowBox[{"C11", "-", 
            RowBox[{"8", " ", "C12"}], "+", 
            RowBox[{"8", " ", "C22"}], "+", 
            RowBox[{"8", " ", "C23"}]}]], 
          RowBox[{
           SqrtBox["2"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox["C11"]}]]], " ", 
    RowBox[{"AR", "[", "2", "]"}]}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fur", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", " ", 
   RowBox[{"solur", ",", " ", 
    RowBox[{"Assumptions", " ", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"C12", "-", "C22", "-", "C23"}], "  ", ">", " ", "0"}], 
      "}"}]}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ur", "[", "r", "]"}], "\[Rule]", 
  RowBox[{
   SuperscriptBox["r", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       SqrtBox[
        FractionBox[
         RowBox[{"C11", "+", 
          RowBox[{"8", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}], 
         "C11"]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["r", 
       SqrtBox[
        FractionBox[
         RowBox[{"C11", "+", 
          RowBox[{"8", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}], 
         "C11"]]], " ", 
      RowBox[{"AR", "[", "1", "]"}]}], "+", 
     RowBox[{"AR", "[", "2", "]"}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"notation", " ", "=", " ", 
  RowBox[{
   SqrtBox[
    FractionBox[
     RowBox[{"C11", "+", 
      RowBox[{"8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}], "C11"]], 
   "\[Rule]", " ", "n", "  "}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SqrtBox[
   FractionBox[
    RowBox[{"C11", "+", 
     RowBox[{"8", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}], "C11"]], 
  "\[Rule]", "n"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fur", " ", "=", " ", 
  RowBox[{"Expand", "[", " ", 
   RowBox[{"fur", " ", "/.", " ", "notation"}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ur", "[", "r", "]"}], "\[Rule]", 
  RowBox[{
   SuperscriptBox["r", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", "n"}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["r", "n"], " ", 
      RowBox[{"AR", "[", "1", "]"}]}], "+", 
     RowBox[{"AR", "[", "2", "]"}]}], ")"}]}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The spherical thick shell under internal and external \
pressure: pi and pe",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", " ", "=", " ", 
  RowBox[{
   RowBox[{"u", " ", "[", 
    RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", "/.", " ", "fur", 
   " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["r", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "-", "n"}], ")"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["r", "n"], " ", 
       RowBox[{"AR", "[", "1", "]"}]}], "+", 
      RowBox[{"AR", "[", "2", "]"}]}], ")"}]}], ",", "0", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"Strain", "[", " ", "uu", " ", "]"}]}], " ", ")"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{"Simplify", "[", " ", 
     RowBox[{"DDot", "[", " ", 
      RowBox[{"C4TI", ",", " ", "eps"}], " ", "]"}], "    ", "]"}]}], " ", 
   ")"}], "//", " ", "MatrixForm"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "n", " ", 
          SuperscriptBox["r", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "n"}], ")"}]}], "+", "n"}]], " ", 
          RowBox[{"AR", "[", "1", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "-", "n"}], ")"}], " ", 
          SuperscriptBox["r", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "n"}], ")"}]}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["r", "n"], " ", 
             RowBox[{"AR", "[", "1", "]"}]}], "+", 
            RowBox[{"AR", "[", "2", "]"}]}], ")"}]}]}], ")"}]}], "0", "0"},
     {"0", 
      RowBox[{
       SuperscriptBox["r", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "-", "n"}], ")"}]}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["r", "n"], " ", 
          RowBox[{"AR", "[", "1", "]"}]}], "+", 
         RowBox[{"AR", "[", "2", "]"}]}], ")"}]}], "0"},
     {"0", "0", 
      RowBox[{
       SuperscriptBox["r", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "-", "n"}], ")"}]}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["r", "n"], " ", 
          RowBox[{"AR", "[", "1", "]"}]}], "+", 
         RowBox[{"AR", "[", "2", "]"}]}], ")"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["r", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         RowBox[{"(", 
          RowBox[{"3", "+", "n"}], ")"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", "C12", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["r", "n"], " ", 
             RowBox[{"AR", "[", "1", "]"}]}], "+", 
            RowBox[{"AR", "[", "2", "]"}]}], ")"}]}], "+", 
         RowBox[{"C11", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", 
             SuperscriptBox["r", "n"], " ", 
             RowBox[{"AR", "[", "1", "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", "n"}], ")"}], " ", 
             RowBox[{"AR", "[", "2", "]"}]}]}], ")"}]}]}], ")"}]}], "0", 
      "0"},
     {"0", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["r", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         RowBox[{"(", 
          RowBox[{"3", "+", "n"}], ")"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"C22", "+", "C23"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["r", "n"], " ", 
             RowBox[{"AR", "[", "1", "]"}]}], "+", 
            RowBox[{"AR", "[", "2", "]"}]}], ")"}]}], "+", 
         RowBox[{"C12", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", 
             SuperscriptBox["r", "n"], " ", 
             RowBox[{"AR", "[", "1", "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", "n"}], ")"}], " ", 
             RowBox[{"AR", "[", "2", "]"}]}]}], ")"}]}]}], ")"}]}], "0"},
     {"0", "0", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["r", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         RowBox[{"(", 
          RowBox[{"3", "+", "n"}], ")"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"C22", "+", "C23"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["r", "n"], " ", 
             RowBox[{"AR", "[", "1", "]"}]}], "+", 
            RowBox[{"AR", "[", "2", "]"}]}], ")"}]}], "+", 
         RowBox[{"C12", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", 
             SuperscriptBox["r", "n"], " ", 
             RowBox[{"AR", "[", "1", "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", "n"}], ")"}], " ", 
             RowBox[{"AR", "[", "2", "]"}]}]}], ")"}]}]}], ")"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["condition for the internal and external pressure",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"er", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"1", ",", "0", ",", "0"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", " ", 
  RowBox[{"-", " ", "er"}]}], "\[IndentingNewLine]", 
 RowBox[{"eqi", " ", "=", " ", 
  RowBox[{"(", " ", 
   RowBox[{"Thread", " ", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sig", " ", "/.", " ", 
        RowBox[{"r", " ", "\[Rule]", " ", "ri"}]}], ")"}], " ", ".", " ", 
      "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"-", " ", "pi"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     SuperscriptBox["ri", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", "n"}], ")"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "C12", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["ri", "n"], " ", 
           RowBox[{"AR", "[", "1", "]"}]}], "+", 
          RowBox[{"AR", "[", "2", "]"}]}], ")"}]}], "+", 
       RowBox[{"C11", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", 
           SuperscriptBox["ri", "n"], " ", 
           RowBox[{"AR", "[", "1", "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}], " ", 
           RowBox[{"AR", "[", "2", "]"}]}]}], ")"}]}]}], ")"}]}], "\[Equal]", 
    "pi"}], ",", "True", ",", "True"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", "  ", "er"}], "\[IndentingNewLine]", 
 RowBox[{"eqe", " ", "=", " ", 
  RowBox[{"(", "  ", 
   RowBox[{"Thread", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sig", " ", "/.", " ", 
        RowBox[{"r", " ", "\[Rule]", " ", "re"}]}], ")"}], " ", ".", " ", 
      "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"-", " ", "pe"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["re", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", "n"}], ")"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "C12", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["re", "n"], " ", 
           RowBox[{"AR", "[", "1", "]"}]}], "+", 
          RowBox[{"AR", "[", "2", "]"}]}], ")"}]}], "+", 
       RowBox[{"C11", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", 
           SuperscriptBox["re", "n"], " ", 
           RowBox[{"AR", "[", "1", "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}], " ", 
           RowBox[{"AR", "[", "2", "]"}]}]}], ")"}]}]}], ")"}]}], "\[Equal]", 
    
    RowBox[{"-", "pe"}]}], ",", "True", ",", "True"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"eqi", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
       RowBox[{"eqe", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}], " ", ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"AR", "[", "1", "]"}], ",", " ", 
       RowBox[{"AR", "[", "2", "]"}]}], "}"}]}], " ", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"AR", "[", "1", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["ri", 
        RowBox[{
         RowBox[{"-", "n"}], "/", "2"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "pe"}], " ", 
          SuperscriptBox["re", 
           RowBox[{
            FractionBox["3", "2"], "+", 
            FractionBox["n", "2"]}]], " ", 
          SuperscriptBox["ri", 
           RowBox[{"n", "/", "2"}]]}], "+", 
         RowBox[{"pi", " ", 
          SuperscriptBox["ri", 
           RowBox[{
            FractionBox["3", "2"], "+", "n"}]]}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "C11"}], "+", 
         RowBox[{"4", " ", "C12"}], "+", 
         RowBox[{"C11", " ", "n"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["re", "n"]}], "+", 
         SuperscriptBox["ri", "n"]}], ")"}]}]]}]}], ",", 
   RowBox[{
    RowBox[{"AR", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["re", 
        RowBox[{"n", "/", "2"}]], " ", 
       SuperscriptBox["ri", 
        RowBox[{"n", "/", "2"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"pi", " ", 
          SuperscriptBox["re", 
           RowBox[{"n", "/", "2"}]], " ", 
          SuperscriptBox["ri", 
           RowBox[{"3", "/", "2"}]]}], "-", 
         RowBox[{"pe", " ", 
          SuperscriptBox["re", 
           RowBox[{"3", "/", "2"}]], " ", 
          SuperscriptBox["ri", 
           RowBox[{"n", "/", "2"}]]}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "C11"}], "+", 
         RowBox[{"4", " ", "C12"}], "-", 
         RowBox[{"C11", " ", "n"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["re", "n"], "-", 
         SuperscriptBox["ri", "n"]}], ")"}]}]]}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["obtention of the isotropic formula",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ciso", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"C11", " ", "\[Rule]", " ", 
     RowBox[{"\[Lambda]", " ", "+", " ", 
      RowBox[{"2", " ", "\[Mu]"}]}]}], " ", ",", " ", 
    RowBox[{"C12", " ", "\[Rule]", " ", "\[Lambda]"}], "   ", ",", " ", 
    RowBox[{"C22", " ", "\[Rule]", " ", 
     RowBox[{"\[Lambda]", " ", "+", " ", 
      RowBox[{"2", " ", "\[Mu]"}]}]}], ",", " ", 
    RowBox[{"C23", " ", "\[Rule]", " ", "\[Lambda]"}]}], "  ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{"FullSimplify", "[", " ", 
   RowBox[{"notation", " ", "/.", " ", "ciso"}], "]"}], 
  " "}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"C11", "\[Rule]", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"2", " ", "\[Mu]"}]}]}], ",", 
   RowBox[{"C12", "\[Rule]", "\[Lambda]"}], ",", 
   RowBox[{"C22", "\[Rule]", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"2", " ", "\[Mu]"}]}]}], ",", 
   RowBox[{"C23", "\[Rule]", "\[Lambda]"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"3", "\[Rule]", "n"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"notation", " ", "/.", " ", "ciso"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SqrtBox[
   FractionBox[
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"2", " ", "\[Mu]"}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"(", 
       RowBox[{"\[Lambda]", "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"2", " ", "\[Mu]"}]}]]], "\[Rule]", "n"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{
   RowBox[{"sol", " ", "/.", " ", "ciso"}], " ", "/.", " ", 
   RowBox[{"n", " ", "\[Rule]", " ", "3"}]}], " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"AR", "[", "1", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "pe"}], " ", 
       SuperscriptBox["re", "3"]}], "+", 
      RowBox[{"pi", " ", 
       SuperscriptBox["ri", "3"]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["re", "3"], "-", 
        SuperscriptBox["ri", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"AR", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"pe", "-", "pi"}], ")"}], " ", 
       SuperscriptBox["re", "3"], " ", 
       SuperscriptBox["ri", "3"]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["re", "3"], "-", 
         SuperscriptBox["ri", "3"]}], ")"}], " ", "\[Mu]"}]]}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Alpha]", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"arr", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "att", ",", " ", "0"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0", ",", " ", "att"}], "}"}]}], "}"}]}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"arr", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "att", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "att"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"u", "[", 
   RowBox[{"r_", ",", "t_", ",", "p_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ur", "[", "r", "]"}], ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"Strain", "[", " ", 
     RowBox[{"u", " ", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}]}], " ", ")"}], " ", "//",
   "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{"Simplify", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"DDot", "[", " ", 
        RowBox[{"C4TI", ",", " ", "eps"}], " ", "]"}], " ", "+", " ", 
       RowBox[{"\[Alpha]", " ", 
        RowBox[{"\[Theta]", "[", "r", "]"}]}]}], "  ", "/.", " ", 
      "soltemperature"}], "  ", "]"}]}], " ", ")"}], "//", " ", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"divsig", " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Div", "[", " ", "sig", " ", "]"}], "]"}]}], " ", ")"}], " ", "//",
   " ", "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["ur", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"ur", "[", "r", "]"}], "r"], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{"ur", "[", "r", "]"}], "r"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "arr"}], " ", 
         RowBox[{"C", "[", "1", "]"}]}], "+", 
        RowBox[{"arr", " ", "r", " ", 
         RowBox[{"C", "[", "2", "]"}]}], "+", 
        RowBox[{"2", " ", "C12", " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "+", 
        RowBox[{"C11", " ", "r", " ", 
         RowBox[{
          SuperscriptBox["ur", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], "r"], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "att"}], " ", 
         RowBox[{"C", "[", "1", "]"}]}], "+", 
        RowBox[{"att", " ", "r", " ", 
         RowBox[{"C", "[", "2", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"C22", "+", "C23"}], ")"}], " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "+", 
        RowBox[{"C12", " ", "r", " ", 
         RowBox[{
          SuperscriptBox["ur", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], "r"], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "att"}], " ", 
         RowBox[{"C", "[", "1", "]"}]}], "+", 
        RowBox[{"att", " ", "r", " ", 
         RowBox[{"C", "[", "2", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"C22", "+", "C23"}], ")"}], " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "+", 
        RowBox[{"C12", " ", "r", " ", 
         RowBox[{
          SuperscriptBox["ur", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], "r"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "arr"}], " ", 
         RowBox[{"C", "[", "1", "]"}]}], "+", 
        RowBox[{"2", " ", "att", " ", 
         RowBox[{"C", "[", "1", "]"}]}], "+", 
        RowBox[{"2", " ", "arr", " ", "r", " ", 
         RowBox[{"C", "[", "2", "]"}]}], "-", 
        RowBox[{"2", " ", "att", " ", "r", " ", 
         RowBox[{"C", "[", "2", "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}], " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "+", 
        RowBox[{"2", " ", "C11", " ", "r", " ", 
         RowBox[{
          SuperscriptBox["ur", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], "+", 
        RowBox[{"C11", " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{
          SuperscriptBox["ur", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       SuperscriptBox["r", "2"]]},
     {"0"},
     {"0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   r^(-2) (-arr C[1] + 2 att C[1] + 2 arr r C[2] - 2 att r C[2] + 
     2 (C12 - C22 - C23) ur[r] + 2 C11 r Derivative[1][ur][r] + 
     C11 r^2 Derivative[2][ur][r]), 0, 0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"divsig", "[", 
     RowBox[{"[", "1", "]"}], "]"}], " ", "\[Equal]", " ", "0"}], " ", ",", 
   " ", 
   RowBox[{"ur", "[", "r", "]"}], ",", " ", "r"}], " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ur", "[", "r", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"16", " ", 
        SuperscriptBox["r", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], "-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            SqrtBox[
             RowBox[{"C11", "+", 
              RowBox[{"8", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]]}],
            
           RowBox[{"2", " ", 
            SqrtBox["C11"], " ", 
            SqrtBox[
             RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "arr", " ", 
           SuperscriptBox["C11", 
            RowBox[{"3", "/", "2"}]], " ", "C12", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "att", " ", 
           SuperscriptBox["C11", 
            RowBox[{"3", "/", "2"}]], " ", "C12", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C12", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C12", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "arr", " ", 
           SuperscriptBox["C11", 
            RowBox[{"3", "/", "2"}]], " ", "C22", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "att", " ", 
           SuperscriptBox["C11", 
            RowBox[{"3", "/", "2"}]], " ", "C22", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C22", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C22", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "arr", " ", 
           SuperscriptBox["C11", 
            RowBox[{"3", "/", "2"}]], " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "att", " ", 
           SuperscriptBox["C11", 
            RowBox[{"3", "/", "2"}]], " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", "C22", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", "C22", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C23", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C23", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"arr", " ", "C11", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"2", " ", "att", " ", "C11", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"arr", " ", "C12", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"2", " ", "att", " ", "C12", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"arr", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"2", " ", "att", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"arr", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", "C23", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"2", " ", "att", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", "C23", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "arr", " ", 
           SuperscriptBox["C11", 
            RowBox[{"3", "/", "2"}]], " ", "C12", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "att", " ", 
           SuperscriptBox["C11", 
            RowBox[{"3", "/", "2"}]], " ", "C12", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C12", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C12", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "arr", " ", 
           SuperscriptBox["C11", 
            RowBox[{"3", "/", "2"}]], " ", "C22", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "att", " ", 
           SuperscriptBox["C11", 
            RowBox[{"3", "/", "2"}]], " ", "C22", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C22", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C22", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "arr", " ", 
           SuperscriptBox["C11", 
            RowBox[{"3", "/", "2"}]], " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "att", " ", 
           SuperscriptBox["C11", 
            RowBox[{"3", "/", "2"}]], " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", "C22", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", "C22", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C23", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C23", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"arr", " ", "C11", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"2", " ", "att", " ", "C11", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"arr", " ", "C12", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"2", " ", "att", " ", "C12", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"arr", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"2", " ", "att", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"arr", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", "C23", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{"2", " ", "att", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", "C23", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "1", "]"}]}], "+", 
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C12", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C12", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C22", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C22", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", "C22", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", "C22", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C23", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C23", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"2", " ", "arr", " ", "C12", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"2", " ", "att", " ", "C12", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"2", " ", "arr", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"2", " ", "att", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"2", " ", "arr", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", "C23", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"2", " ", "att", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", "C23", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C12", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C12", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C22", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C22", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", "C12", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", "C22", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"12", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", "C22", " ", "C23", " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "arr", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C23", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"6", " ", "\[ImaginaryI]", " ", "att", " ", 
           SqrtBox["C11"], " ", 
           SuperscriptBox["C23", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"2", " ", "arr", " ", "C12", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"2", " ", "att", " ", "C12", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"2", " ", "arr", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"2", " ", "att", " ", "C22", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "-", 
          RowBox[{"2", " ", "arr", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", "C23", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}], "+", 
          RowBox[{"2", " ", "att", " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", "C23", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           SuperscriptBox["r", 
            RowBox[{"2", "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{"C11", "+", 
          RowBox[{"8", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], " ", 
        
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
               ")"}]}]}]]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
               ")"}]}]}]]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
               ")"}]}]}]]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[ImaginaryI]", " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
               ")"}]}]}]]}]}], ")"}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["r", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox["C11"], " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
             RowBox[{
              SqrtBox["2"], " ", 
              RowBox[{"(", 
               RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
           FractionBox[
            SqrtBox[
             RowBox[{"C11", "-", 
              RowBox[{"8", " ", "C12"}], "+", 
              RowBox[{"8", " ", "C22"}], "+", 
              RowBox[{"8", " ", "C23"}]}]], 
            RowBox[{
             SqrtBox["2"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
        RowBox[{
         SqrtBox["2"], " ", 
         SqrtBox["C11"]}]]], " ", 
      RowBox[{"C", "[", "3", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["r", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox["C11"], " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
             RowBox[{
              SqrtBox["2"], " ", 
              RowBox[{"(", 
               RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
           FractionBox[
            SqrtBox[
             RowBox[{"C11", "-", 
              RowBox[{"8", " ", "C12"}], "+", 
              RowBox[{"8", " ", "C22"}], "+", 
              RowBox[{"8", " ", "C23"}]}]], 
            RowBox[{
             SqrtBox["2"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
        RowBox[{
         SqrtBox["2"], " ", 
         SqrtBox["C11"]}]]], " ", 
      RowBox[{"C", "[", "4", "]"}]}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1143, 821},
WindowMargins->{{Automatic, 28}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 86, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[1442, 43, 291, 8, 55, "Input"],
Cell[1736, 53, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1823, 56, 150, 2, 77, "Input"],
Cell[CellGroupData[{
Cell[1998, 62, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2110, 67, 137, 3, 32, "Input"],
Cell[2250, 72, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2383, 79, 132, 3, 32, "Input"],
Cell[2518, 84, 335, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2890, 99, 3860, 112, 187, "Input"],
Cell[6753, 213, 779, 26, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7569, 244, 1043, 30, 99, "Input"],
Cell[8615, 276, 784, 20, 75, "Output"],
Cell[9402, 298, 2333, 67, 212, "Output"],
Cell[11738, 367, 454, 13, 136, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12241, 386, 123, 2, 37, "Subsection"],
Cell[12367, 390, 73, 1, 27, "Input"],
Cell[CellGroupData[{
Cell[12465, 395, 392, 11, 43, "Input"],
Cell[12860, 408, 266, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13163, 421, 179, 5, 27, "Input"],
Cell[13345, 428, 419, 13, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13801, 446, 400, 11, 27, "Input"],
Cell[14204, 459, 216, 7, 44, "Output"]
}, Open  ]],
Cell[14435, 469, 26, 0, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14498, 474, 123, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[14646, 480, 738, 21, 59, "Input"],
Cell[15387, 503, 439, 15, 92, "Output"],
Cell[15829, 520, 1157, 36, 100, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17023, 561, 221, 6, 27, "Input"],
Cell[17247, 569, 927, 28, 71, "Output"]
}, Open  ]],
Cell[18189, 600, 26, 0, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18252, 605, 98, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[18375, 610, 520, 16, 43, "Input"],
Cell[18898, 628, 2230, 71, 73, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21165, 704, 309, 8, 27, "Input"],
Cell[21477, 714, 884, 31, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22398, 750, 301, 10, 50, "Input"],
Cell[22702, 762, 243, 9, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22982, 776, 148, 3, 27, "Input"],
Cell[23133, 781, 426, 15, 35, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[23608, 802, 141, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[23774, 808, 174, 5, 27, "Input"],
Cell[23951, 815, 440, 16, 39, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24428, 836, 471, 12, 59, "Input"],
Cell[24902, 850, 2185, 70, 97, "Output"],
Cell[27090, 922, 3356, 103, 101, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30495, 1031, 114, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[30634, 1036, 117, 3, 27, "Input"],
Cell[30754, 1041, 83, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30874, 1048, 495, 14, 43, "Input"],
Cell[31372, 1064, 102, 3, 27, "Output"],
Cell[31477, 1069, 1091, 35, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32605, 1109, 469, 13, 43, "Input"],
Cell[33077, 1124, 83, 2, 27, "Output"],
Cell[33163, 1128, 1089, 35, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34289, 1168, 504, 15, 27, "Input"],
Cell[34796, 1185, 2049, 66, 62, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36894, 1257, 100, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[37019, 1262, 671, 16, 59, "Input"],
Cell[37693, 1280, 363, 10, 27, "Output"],
Cell[38059, 1292, 56, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38152, 1298, 70, 1, 27, "Input"],
Cell[38225, 1301, 348, 11, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38610, 1317, 189, 4, 27, "Input"],
Cell[38802, 1323, 1016, 35, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39855, 1363, 399, 11, 43, "Input"],
Cell[40257, 1376, 266, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40560, 1389, 1132, 32, 75, "Input"],
Cell[41695, 1423, 439, 15, 92, "Output"],
Cell[42137, 1440, 1732, 51, 100, "Output"],
Cell[43872, 1493, 1315, 35, 86, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45224, 1533, 253, 7, 27, "Input"],
Cell[45480, 1542, 198032, 5274, 7554, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

