(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    437979,      12041]
NotebookOptionsPosition[    431689,      11834]
NotebookOutlinePosition[    432369,      11860]
CellTagsIndexPosition[    432281,      11855]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["Sphere under pressure ", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "Displacement.m"}], "\[IndentingNewLine]"}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Spherical", "[", 
  RowBox[{"r", ",", "t", ",", "p"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "t", ",", "p"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"C2", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "C11", ",", "C12", ",", "C13", ",", "C14", ",", "C15", ",", "C16"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "C12", ",", "C22", ",", "C23", ",", "C24", ",", "C25", ",", "C26"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "C13", ",", "C23", ",", "C33", ",", "C34", ",", "C35", ",", "C36"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "C14", ",", "C24", ",", "C34", ",", "C44", ",", "C45", ",", "C46"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "C15", ",", "C25", ",", "C35", ",", "C45", ",", "C55", ",", "C56"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "C16", ",", "C26", ",", "C36", ",", "C46", ",", "C56", ",", "C66"}], 
     "}"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"C4", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C11", ",", "C16", ",", "C15"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C16", ",", "C12", ",", "C14"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C15", ",", "C14", ",", "C13"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C12", ",", "C26", ",", "C25"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C26", ",", "C22", ",", "C24"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C25", ",", "C24", ",", "C23"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"C13", ",", "C36", ",", "C35"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C36", ",", "C23", ",", "C34"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"C35", ",", "C34", ",", "C33"}], "}"}]}], "}"}]}], "}"}]}], 
    "}"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "C11", ",", "C12", ",", "C13", ",", "C14", ",", "C15", ",", "C16"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "C12", ",", "C22", ",", "C23", ",", "C24", ",", "C25", ",", "C26"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "C13", ",", "C23", ",", "C33", ",", "C34", ",", "C35", ",", "C36"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "C14", ",", "C24", ",", "C34", ",", "C44", ",", "C45", ",", "C46"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "C15", ",", "C25", ",", "C35", ",", "C45", ",", "C55", ",", "C56"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "C16", ",", "C26", ",", "C36", ",", "C46", ",", "C56", ",", "C66"}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"transverseisotropic", "=", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"Thread", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "C14", ",", "C15", ",", "C16", ",", "C24", ",", "C25", ",", "C26", ",",
         "C34", ",", "C35", ",", "C36", ",", "C45", ",", "C46", ",", "C56"}], 
       "}"}], "\[Rule]", "0"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"C33", "\[Rule]", "C22"}], ",", 
      RowBox[{"C13", "\[Rule]", "C12"}], ",", 
      RowBox[{"C66", "\[Rule]", "C55"}], ",", 
      RowBox[{"C44", "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"C11", "-", "C12"}], ")"}], "/", "2"}]}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C4TI", " ", "=", " ", 
    RowBox[{"C4", "/.", "transverseisotropic"}]}], ")"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"C2TI", " ", "=", " ", 
    RowBox[{"C2", "/.", "transverseisotropic"}]}], ")"}], "//", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"C14", "\[Rule]", "0"}], ",", 
   RowBox[{"C15", "\[Rule]", "0"}], ",", 
   RowBox[{"C16", "\[Rule]", "0"}], ",", 
   RowBox[{"C24", "\[Rule]", "0"}], ",", 
   RowBox[{"C25", "\[Rule]", "0"}], ",", 
   RowBox[{"C26", "\[Rule]", "0"}], ",", 
   RowBox[{"C34", "\[Rule]", "0"}], ",", 
   RowBox[{"C35", "\[Rule]", "0"}], ",", 
   RowBox[{"C36", "\[Rule]", "0"}], ",", 
   RowBox[{"C45", "\[Rule]", "0"}], ",", 
   RowBox[{"C46", "\[Rule]", "0"}], ",", 
   RowBox[{"C56", "\[Rule]", "0"}], ",", 
   RowBox[{"C33", "\[Rule]", "C22"}], ",", 
   RowBox[{"C13", "\[Rule]", "C12"}], ",", 
   RowBox[{"C66", "\[Rule]", "C55"}], ",", 
   RowBox[{"C44", "\[Rule]", 
    FractionBox[
     RowBox[{"C11", "-", "C12"}], "2"]}]}], "}"}]], "Output"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C11", "0", "0"},
         {"0", "C12", "0"},
         {"0", "0", "C12"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "C55", "0"},
         {"C55", "0", "0"},
         {"0", "0", "0"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "0", "C55"},
         {"0", "0", "0"},
         {"C55", "0", "0"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "C55", "0"},
         {"C55", "0", "0"},
         {"0", "0", "0"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C12", "0", "0"},
         {"0", "C22", "0"},
         {"0", "0", "C23"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "0", "0"},
         {"0", "0", 
          FractionBox[
           RowBox[{"C11", "-", "C12"}], "2"]},
         {"0", 
          FractionBox[
           RowBox[{"C11", "-", "C12"}], "2"], "0"}
        }], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "0", "C55"},
         {"0", "0", "0"},
         {"C55", "0", "0"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"0", "0", "0"},
         {"0", "0", 
          FractionBox[
           RowBox[{"C11", "-", "C12"}], "2"]},
         {"0", 
          FractionBox[
           RowBox[{"C11", "-", "C12"}], "2"], "0"}
        }], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"C12", "0", "0"},
         {"0", "C23", "0"},
         {"0", "0", "C22"}
        }], "\[NoBreak]", ")"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{{{{C11, 0, 0}, {0, C12, 0}, {0, 0, C12}}, {{0, C55, 0}, {
      C55, 0, 0}, {0, 0, 0}}, {{0, 0, C55}, {0, 0, 0}, {C55, 0, 0}}}, {{{
      0, C55, 0}, {C55, 0, 0}, {0, 0, 0}}, {{C12, 0, 0}, {0, C22, 0}, {
      0, 0, C23}}, {{0, 0, 0}, {0, 0, Rational[1, 2] (C11 - C12)}, {
      0, Rational[1, 2] (C11 - C12), 0}}}, {{{0, 0, C55}, {0, 0, 0}, {
      C55, 0, 0}}, {{0, 0, 0}, {0, 0, Rational[1, 2] (C11 - C12)}, {
      0, Rational[1, 2] (C11 - C12), 0}}, {{C12, 0, 0}, {0, C23, 0}, {
      0, 0, C22}}}}]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"C11", "C12", "C12", "0", "0", "0"},
     {"C12", "C22", "C23", "0", "0", "0"},
     {"C12", "C23", "C22", "0", "0", "0"},
     {"0", "0", "0", 
      FractionBox[
       RowBox[{"C11", "-", "C12"}], "2"], "0", "0"},
     {"0", "0", "0", "0", "C55", "0"},
     {"0", "0", "0", "0", "0", "C55"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "DDot"}]], "Input"],

Cell[CellGroupData[{

Cell["Global`DDot", "Print",
 CellTags->"Info3356455612-8622876"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"DDot", "[", 
          RowBox[{"T4_", ",", "t2_"}], "]"}], ":=", 
         RowBox[{"GTr", "[", 
          RowBox[{
           RowBox[{"GDot", "[", 
            RowBox[{"T4", ",", "t2", ",", "1", ",", "1"}], "]"}], ",", "1", 
           ",", "4"}], "]"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition["DDot"],
  Editable->False]], "Print",
 CellTags->"Info3356455612-8622876"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Transient heat equation in cylindrical coordinate \
system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Div", "[", " ", 
   RowBox[{"k", " ", 
    RowBox[{"Grad", "[", " ", 
     RowBox[{"T", "[", 
      RowBox[{"r", ",", "time"}], "]"}], "]"}]}], "]"}], " ", "==", " ", 
  RowBox[{"D", "[", " ", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"r", ",", "time"}], "]"}], ",", " ", "time"}], "]"}], 
  " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "k", " ", 
     RowBox[{
      SuperscriptBox["T", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"r", ",", "time"}], "]"}]}], "r"], "+", 
   RowBox[{"k", " ", 
    RowBox[{
     SuperscriptBox["T", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"r", ",", "time"}], "]"}]}]}], "\[Equal]", 
  RowBox[{
   SuperscriptBox["T", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"r", ",", "time"}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LaplaceTransform", "[", 
  RowBox[{
   RowBox[{"Div", "[", " ", 
    RowBox[{"k", " ", 
     RowBox[{"Grad", "[", " ", 
      RowBox[{"T", "[", 
       RowBox[{"r", ",", "time"}], "]"}], "]"}]}], "]"}], ",", " ", "time", 
   ",", " ", "s"}], " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", "k", " ", 
    RowBox[{"LaplaceTransform", "[", 
     RowBox[{
      RowBox[{
       SuperscriptBox["T", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"r", ",", "time"}], "]"}], ",", "time", ",", "s"}], "]"}]}], 
   "r"], "+", 
  RowBox[{"k", " ", 
   RowBox[{"LaplaceTransform", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox["T", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"r", ",", "time"}], "]"}], ",", "time", ",", "s"}], 
    "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LaplaceTransform", "[", 
  RowBox[{
   RowBox[{"D", "[", " ", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"r", ",", "time"}], "]"}], ",", " ", "time"}], "]"}], ",", " ", 
   "time", ",", " ", "s"}], " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"s", " ", 
   RowBox[{"LaplaceTransform", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"r", ",", "time"}], "]"}], ",", "time", ",", "s"}], "]"}]}], 
  "-", 
  RowBox[{"T", "[", 
   RowBox[{"r", ",", "0"}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Div", "[", " ", 
   RowBox[{"k", " ", 
    RowBox[{"Grad", "[", " ", 
     RowBox[{"LT", "[", "r", "]"}], " ", "]"}]}], "]"}], " ", "==", " ", 
  RowBox[{"s", " ", 
   RowBox[{"LT", "[", "r", "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "k", " ", 
     RowBox[{
      SuperscriptBox["LT", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
   RowBox[{"k", " ", 
    RowBox[{
     SuperscriptBox["LT", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}]}], "\[Equal]", 
  RowBox[{"s", " ", 
   RowBox[{"LT", "[", "r", "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solLT", " ", "=", " ", 
  RowBox[{
   RowBox[{"DSolve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Div", "[", " ", 
       RowBox[{"k", " ", 
        RowBox[{"Grad", "[", " ", 
         RowBox[{"LT", "[", "r", "]"}], " ", "]"}]}], "]"}], " ", "==", " ", 
      RowBox[{"s", " ", 
       RowBox[{"LT", "[", "r", "]"}]}]}], ",", " ", 
     RowBox[{"LT", "[", "r", "]"}], ",", " ", "r"}], " ", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LT", "[", "r", "]"}], "\[Rule]", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "r"}], " ", 
       SqrtBox[
        FractionBox["s", "k"]]}]], " ", 
     RowBox[{"C", "[", "1", "]"}]}], "r"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"r", " ", 
       SqrtBox[
        FractionBox["s", "k"]]}]], " ", 
     RowBox[{"C", "[", "2", "]"}]}], 
    RowBox[{"2", " ", "r", " ", 
     SqrtBox[
      FractionBox["s", "k"]]}]]}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The general solution in cylindrical coordinate \
system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Lu", "[", 
   RowBox[{"r_", ",", "t_", ",", "p_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Lur", "[", "r", "]"}], ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"Leps", " ", "=", " ", 
    RowBox[{"Strain", "[", " ", 
     RowBox[{"Lu", " ", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}]}], " ", ")"}], " ", "//",
   "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"Lsig", " ", "=", " ", 
    RowBox[{"Simplify", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"DDot", "[", " ", 
        RowBox[{"C4TI", ",", " ", "Leps"}], " ", "]"}], "   ", "-", " ", 
       RowBox[{"alpha", " ", 
        RowBox[{"LT", "[", "r", "]"}], " ", 
        RowBox[{"IdentityMatrix", "[", "3", "]"}]}]}], "  ", "/.", " ", 
      "solLT"}], " ", "]"}]}], " ", ")"}], "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(Leps\\)\
\\\" is similar to existing symbols \\!\\({eps, Less}\\). \\!\\(\\*ButtonBox[\
\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["Lur", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"Lur", "[", "r", "]"}], "r"], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{"Lur", "[", "r", "]"}], "r"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(Lsig\\)\
\\\" is similar to existing symbol \\\"\\!\\(sig\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"alpha", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "r"}], " ", 
            SqrtBox[
             FractionBox["s", "k"]]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"C", "[", "1", "]"}]}], "+", 
            FractionBox[
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"2", " ", "r", " ", 
                SqrtBox[
                 FractionBox["s", "k"]]}]], " ", 
              RowBox[{"C", "[", "2", "]"}]}], 
             SqrtBox[
              FractionBox["s", "k"]]]}], ")"}]}], 
         RowBox[{"2", " ", "r"}]]}], "+", 
       FractionBox[
        RowBox[{"2", " ", "C12", " ", 
         RowBox[{"Lur", "[", "r", "]"}]}], "r"], "+", 
       RowBox[{"C11", " ", 
        RowBox[{
         SuperscriptBox["Lur", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], "0", "0"},
     {"0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"alpha", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "r"}], " ", 
            SqrtBox[
             FractionBox["s", "k"]]}]], " ", 
          RowBox[{"C", "[", "1", "]"}]}], "r"]}], "-", 
       FractionBox[
        RowBox[{"alpha", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"r", " ", 
           SqrtBox[
            FractionBox["s", "k"]]}]], " ", 
         RowBox[{"C", "[", "2", "]"}]}], 
        RowBox[{"2", " ", "r", " ", 
         SqrtBox[
          FractionBox["s", "k"]]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"C22", "+", "C23"}], ")"}], " ", 
         RowBox[{"Lur", "[", "r", "]"}]}], "r"], "+", 
       RowBox[{"C12", " ", 
        RowBox[{
         SuperscriptBox["Lur", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"alpha", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "r"}], " ", 
            SqrtBox[
             FractionBox["s", "k"]]}]], " ", 
          RowBox[{"C", "[", "1", "]"}]}], "r"]}], "-", 
       FractionBox[
        RowBox[{"alpha", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"r", " ", 
           SqrtBox[
            FractionBox["s", "k"]]}]], " ", 
         RowBox[{"C", "[", "2", "]"}]}], 
        RowBox[{"2", " ", "r", " ", 
         SqrtBox[
          FractionBox["s", "k"]]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"C22", "+", "C23"}], ")"}], " ", 
         RowBox[{"Lur", "[", "r", "]"}]}], "r"], "+", 
       RowBox[{"C12", " ", 
        RowBox[{
         SuperscriptBox["Lur", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"divsig", " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Div", "[", " ", "Lsig", " ", "]"}], "]"}]}], " ", ")"}], " ", "//",
   " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", "alpha", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "r"}], " ", 
           SqrtBox[
            FractionBox["s", "k"]]}]], " ", "s", " ", 
         RowBox[{"C", "[", "1", "]"}]}], "+", 
        RowBox[{"2", " ", "alpha", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "r"}], " ", 
           SqrtBox[
            FractionBox["s", "k"]]}]], " ", "r", " ", "s", " ", 
         SqrtBox[
          FractionBox["s", "k"]], " ", 
         RowBox[{"C", "[", "1", "]"}]}], "-", 
        RowBox[{"alpha", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"r", " ", 
           SqrtBox[
            FractionBox["s", "k"]]}]], " ", "r", " ", "s", " ", 
         RowBox[{"C", "[", "2", "]"}]}], "+", 
        RowBox[{"alpha", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"r", " ", 
           SqrtBox[
            FractionBox["s", "k"]]}]], " ", "k", " ", 
         SqrtBox[
          FractionBox["s", "k"]], " ", 
         RowBox[{"C", "[", "2", "]"}]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}], " ", "s", " ", 
         RowBox[{"Lur", "[", "r", "]"}]}], "+", 
        RowBox[{"4", " ", "C11", " ", "r", " ", "s", " ", 
         RowBox[{
          SuperscriptBox["Lur", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], "+", 
        RowBox[{"2", " ", "C11", " ", 
         SuperscriptBox["r", "2"], " ", "s", " ", 
         RowBox[{
          SuperscriptBox["Lur", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", "s"}]]},
     {"0"},
     {"0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   Rational[1, 2] r^(-2) 
    s^(-1) (2 alpha E^(-r (k^(-1) s)^Rational[1, 2]) s C[1] + 
     2 alpha E^(-r (k^(-1) s)^Rational[1, 2]) r s (k^(-1) s)^Rational[1, 2] 
      C[1] - alpha E^(r (k^(-1) s)^Rational[1, 2]) r s C[2] + 
     alpha E^(r (k^(-1) s)^Rational[1, 2]) k (k^(-1) s)^Rational[1, 2] C[2] + 
     4 (C12 - C22 - C23) s Lur[r] + 4 C11 r s Derivative[1][Lur][r] + 
     2 C11 r^2 s Derivative[2][Lur][r]), 0, 0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solur", " ", "=", " ", 
   RowBox[{
    RowBox[{"DSolve", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"divsig", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", "\[Equal]", " ", "0"}], ",", " ",
       "Lur", ",", " ", "r", " ", ",", " ", 
      StyleBox[
       RowBox[{"GeneratedParameters", "->", " ", "LSR"}], "MR"]}], "]"}], "[",
     
    RowBox[{"[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Lur", "\[Rule]", 
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", "r", "}"}], ",", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["r", 
          RowBox[{
           FractionBox["1", "2"], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             SqrtBox[
              RowBox[{"C11", "+", 
               RowBox[{"8", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                 ")"}]}]}]]}], 
            RowBox[{"2", " ", 
             SqrtBox["C11"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "r"}], " ", 
            SqrtBox[
             FractionBox["s", "k"]]}], ")"}], 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "2"]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             SqrtBox[
              RowBox[{"C11", "+", 
               RowBox[{"8", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                 ")"}]}]}]]}], 
            RowBox[{"2", " ", 
             SqrtBox["C11"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"r", " ", 
            SqrtBox[
             FractionBox["s", "k"]]}], ")"}], 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "2"]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             SqrtBox[
              RowBox[{"C11", "+", 
               RowBox[{"8", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                 ")"}]}]}]]}], 
            RowBox[{"2", " ", 
             SqrtBox["C11"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "alpha"}], " ", 
            SqrtBox[
             RowBox[{"-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
               "2"]}]], " ", "k", " ", 
            SuperscriptBox["r", 
             RowBox[{"1", "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", 
            SqrtBox[
             FractionBox["s", "k"]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "r"}], " ", 
               SqrtBox[
                FractionBox["s", "k"]]}], ")"}], 
             RowBox[{
              FractionBox["1", "2"], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"r", " ", 
               SqrtBox[
                FractionBox["s", "k"]]}], ")"}], 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{"2", " ", 
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], " ", 
            RowBox[{"C", "[", "2", "]"}], " ", 
            RowBox[{"Gamma", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "2"], "-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{"2", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ",", 
              RowBox[{
               RowBox[{"-", "r"}], " ", 
               SqrtBox[
                FractionBox["s", "k"]]}]}], "]"}]}], "+", 
           RowBox[{"2", " ", "alpha", " ", 
            SqrtBox[
             RowBox[{"-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
               "2"]}]], " ", 
            SuperscriptBox["r", 
             RowBox[{"1", "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", "s", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "r"}], " ", 
               SqrtBox[
                FractionBox["s", "k"]]}], ")"}], 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{"2", " ", 
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"r", " ", 
               SqrtBox[
                FractionBox["s", "k"]]}], ")"}], 
             RowBox[{
              FractionBox["1", "2"], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
            RowBox[{"C", "[", "1", "]"}], " ", 
            RowBox[{"Gamma", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "2"], "-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{"2", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ",", 
              RowBox[{"r", " ", 
               SqrtBox[
                FractionBox["s", "k"]]}]}], "]"}]}], "-", 
           RowBox[{"alpha", " ", 
            SqrtBox[
             RowBox[{"-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
               "2"]}]], " ", "k", " ", 
            SuperscriptBox["r", 
             RowBox[{"1", "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", 
            SqrtBox[
             FractionBox["s", "k"]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "r"}], " ", 
               SqrtBox[
                FractionBox["s", "k"]]}], ")"}], 
             RowBox[{
              FractionBox["1", "2"], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"r", " ", 
               SqrtBox[
                FractionBox["s", "k"]]}], ")"}], 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{"2", " ", 
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], " ", 
            RowBox[{"C", "[", "2", "]"}], " ", 
            RowBox[{"Gamma", "[", 
             RowBox[{
              RowBox[{
               FractionBox["3", "2"], "-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{"2", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ",", 
              RowBox[{
               RowBox[{"-", "r"}], " ", 
               SqrtBox[
                FractionBox["s", "k"]]}]}], "]"}]}], "+", 
           RowBox[{"2", " ", "alpha", " ", 
            SqrtBox[
             RowBox[{"-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
               "2"]}]], " ", 
            SuperscriptBox["r", 
             RowBox[{"1", "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", "s", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "r"}], " ", 
               SqrtBox[
                FractionBox["s", "k"]]}], ")"}], 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{"2", " ", 
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"r", " ", 
               SqrtBox[
                FractionBox["s", "k"]]}], ")"}], 
             RowBox[{
              FractionBox["1", "2"], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
            RowBox[{"C", "[", "1", "]"}], " ", 
            RowBox[{"Gamma", "[", 
             RowBox[{
              RowBox[{
               FractionBox["3", "2"], "-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{"2", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ",", 
              RowBox[{"r", " ", 
               SqrtBox[
                FractionBox["s", "k"]]}]}], "]"}]}], "+", 
           RowBox[{"alpha", " ", 
            SqrtBox[
             RowBox[{"-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
               "2"]}]], " ", "k", " ", 
            SuperscriptBox["r", 
             RowBox[{
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", 
            SqrtBox[
             RowBox[{"-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["r", "2"], " ", "s"}], "k"]}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"r", " ", 
               SqrtBox[
                FractionBox["s", "k"]]}], ")"}], 
             RowBox[{
              FractionBox["1", "2"], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{"2", " ", 
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
            RowBox[{"C", "[", "2", "]"}], " ", 
            RowBox[{"Gamma", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "2"], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{"2", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ",", 
              RowBox[{
               RowBox[{"-", "r"}], " ", 
               SqrtBox[
                FractionBox["s", "k"]]}]}], "]"}]}], "+", 
           RowBox[{"2", " ", "alpha", " ", 
            SqrtBox[
             RowBox[{"-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
               "2"]}]], " ", "k", " ", 
            SuperscriptBox["r", 
             RowBox[{
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", 
            SqrtBox[
             FractionBox["s", "k"]], " ", 
            SqrtBox[
             RowBox[{"-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["r", "2"], " ", "s"}], "k"]}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "r"}], " ", 
               SqrtBox[
                FractionBox["s", "k"]]}], ")"}], 
             RowBox[{
              FractionBox["1", "2"], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{"2", " ", 
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
            RowBox[{"C", "[", "1", "]"}], " ", 
            RowBox[{"Gamma", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "2"], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{"2", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ",", 
              RowBox[{"r", " ", 
               SqrtBox[
                FractionBox["s", "k"]]}]}], "]"}]}], "+", 
           RowBox[{"alpha", " ", 
            SqrtBox[
             RowBox[{"-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
               "2"]}]], " ", "k", " ", 
            SuperscriptBox["r", 
             RowBox[{
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", 
            SqrtBox[
             RowBox[{"-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["r", "2"], " ", "s"}], "k"]}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"r", " ", 
               SqrtBox[
                FractionBox["s", "k"]]}], ")"}], 
             RowBox[{
              FractionBox["1", "2"], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{"2", " ", 
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
            RowBox[{"C", "[", "2", "]"}], " ", 
            RowBox[{"Gamma", "[", 
             RowBox[{
              RowBox[{
               FractionBox["3", "2"], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{"2", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ",", 
              RowBox[{
               RowBox[{"-", "r"}], " ", 
               SqrtBox[
                FractionBox["s", "k"]]}]}], "]"}]}], "+", 
           RowBox[{"2", " ", "alpha", " ", 
            SqrtBox[
             RowBox[{"-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
               "2"]}]], " ", "k", " ", 
            SuperscriptBox["r", 
             RowBox[{
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", 
            SqrtBox[
             FractionBox["s", "k"]], " ", 
            SqrtBox[
             RowBox[{"-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["r", "2"], " ", "s"}], "k"]}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "r"}], " ", 
               SqrtBox[
                FractionBox["s", "k"]]}], ")"}], 
             RowBox[{
              FractionBox["1", "2"], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{"2", " ", 
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
            RowBox[{"C", "[", "1", "]"}], " ", 
            RowBox[{"Gamma", "[", 
             RowBox[{
              RowBox[{
               FractionBox["3", "2"], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{"2", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ",", 
              RowBox[{"r", " ", 
               SqrtBox[
                FractionBox["s", "k"]]}]}], "]"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SqrtBox["C11"], " ", 
         RowBox[{"(", 
          RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}], " ", 
         SqrtBox[
          RowBox[{"C11", "+", 
           RowBox[{"8", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], " ",
          "k", " ", 
         SqrtBox[
          FractionBox["s", "k"]], " ", 
         SqrtBox[
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["r", "2"], " ", "s"}], "k"]}]]}], ")"}]}]}], "+", 
     
     RowBox[{
      SuperscriptBox["r", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox["C11"], " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
             RowBox[{
              SqrtBox["2"], " ", 
              RowBox[{"(", 
               RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
           FractionBox[
            SqrtBox[
             RowBox[{"C11", "-", 
              RowBox[{"8", " ", "C12"}], "+", 
              RowBox[{"8", " ", "C22"}], "+", 
              RowBox[{"8", " ", "C23"}]}]], 
            RowBox[{
             SqrtBox["2"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
        RowBox[{
         SqrtBox["2"], " ", 
         SqrtBox["C11"]}]]], " ", 
      RowBox[{"LSR", "[", "1", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["r", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox["C11"], " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
             RowBox[{
              SqrtBox["2"], " ", 
              RowBox[{"(", 
               RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
           FractionBox[
            SqrtBox[
             RowBox[{"C11", "-", 
              RowBox[{"8", " ", "C12"}], "+", 
              RowBox[{"8", " ", "C22"}], "+", 
              RowBox[{"8", " ", "C23"}]}]], 
            RowBox[{
             SqrtBox["2"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
        RowBox[{
         SqrtBox["2"], " ", 
         SqrtBox["C11"]}]]], " ", 
      RowBox[{"LSR", "[", "2", "]"}]}]}]}], "]"}]}]], "Output"]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input"]
}, Open  ]],

Cell[TextData[StyleBox["Temperature Solutions",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The spherical thick shell under internal and external \
pressure: pi and pe",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", " ", "=", " ", 
  RowBox[{
   RowBox[{"u", " ", "[", 
    RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", "/.", " ", "solur", 
   " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["r", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["C11"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
            RowBox[{
             SqrtBox["2"], " ", 
             RowBox[{"(", 
              RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
          FractionBox[
           SqrtBox[
            RowBox[{"C11", "-", 
             RowBox[{"8", " ", "C12"}], "+", 
             RowBox[{"8", " ", "C22"}], "+", 
             RowBox[{"8", " ", "C23"}]}]], 
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox[
             RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
       RowBox[{
        SqrtBox["2"], " ", 
        SqrtBox["C11"]}]]], " ", 
     RowBox[{"CR", "[", "1", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["r", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["C11"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
            RowBox[{
             SqrtBox["2"], " ", 
             RowBox[{"(", 
              RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
          FractionBox[
           SqrtBox[
            RowBox[{"C11", "-", 
             RowBox[{"8", " ", "C12"}], "+", 
             RowBox[{"8", " ", "C22"}], "+", 
             RowBox[{"8", " ", "C23"}]}]], 
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox[
             RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
       RowBox[{
        SqrtBox["2"], " ", 
        SqrtBox["C11"]}]]], " ", 
     RowBox[{"CR", "[", "2", "]"}]}]}], ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"Strain", "[", " ", "uu", " ", "]"}]}], " ", ")"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"Tr", "[", "eps", " ", "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", " ", "]"}]}], "+", " ", 
     RowBox[{"2", " ", "\[Mu]", " ", "eps"}]}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                RowBox[{"(", 
                 RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
             FractionBox[
              SqrtBox[
               RowBox[{"C11", "-", 
                RowBox[{"8", " ", "C12"}], "+", 
                RowBox[{"8", " ", "C22"}], "+", 
                RowBox[{"8", " ", "C23"}]}]], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
           SuperscriptBox["r", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"CR", "[", "1", "]"}]}], 
          RowBox[{
           SqrtBox["2"], " ", 
           SqrtBox["C11"]}]], "+", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                RowBox[{"(", 
                 RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
             FractionBox[
              SqrtBox[
               RowBox[{"C11", "-", 
                RowBox[{"8", " ", "C12"}], "+", 
                RowBox[{"8", " ", "C22"}], "+", 
                RowBox[{"8", " ", "C23"}]}]], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
           SuperscriptBox["r", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", 
           RowBox[{"CR", "[", "2", "]"}]}], 
          RowBox[{
           SqrtBox["2"], " ", 
           SqrtBox["C11"]}]]}], ")"}]}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["r", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
              FractionBox[
               SqrtBox[
                RowBox[{"C11", "-", 
                 RowBox[{"8", " ", "C12"}], "+", 
                 RowBox[{"8", " ", "C22"}], "+", 
                 RowBox[{"8", " ", "C23"}]}]], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox["C11"]}]]], " ", 
         RowBox[{"CR", "[", "1", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["r", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
              FractionBox[
               SqrtBox[
                RowBox[{"C11", "-", 
                 RowBox[{"8", " ", "C12"}], "+", 
                 RowBox[{"8", " ", "C22"}], "+", 
                 RowBox[{"8", " ", "C23"}]}]], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox["C11"]}]]], " ", 
         RowBox[{"CR", "[", "2", "]"}]}]}], "r"], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["r", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
              FractionBox[
               SqrtBox[
                RowBox[{"C11", "-", 
                 RowBox[{"8", " ", "C12"}], "+", 
                 RowBox[{"8", " ", "C22"}], "+", 
                 RowBox[{"8", " ", "C23"}]}]], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox["C11"]}]]], " ", 
         RowBox[{"CR", "[", "1", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["r", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
              FractionBox[
               SqrtBox[
                RowBox[{"C11", "-", 
                 RowBox[{"8", " ", "C12"}], "+", 
                 RowBox[{"8", " ", "C22"}], "+", 
                 RowBox[{"8", " ", "C23"}]}]], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox["C11"]}]]], " ", 
         RowBox[{"CR", "[", "2", "]"}]}]}], "r"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
              FractionBox[
               SqrtBox[
                RowBox[{"C11", "-", 
                 RowBox[{"8", " ", "C12"}], "+", 
                 RowBox[{"8", " ", "C22"}], "+", 
                 RowBox[{"8", " ", "C23"}]}]], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
            SuperscriptBox["r", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", 
            RowBox[{"CR", "[", "1", "]"}]}], 
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox["C11"]}]], "+", 
          FractionBox[
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
              FractionBox[
               SqrtBox[
                RowBox[{"C11", "-", 
                 RowBox[{"8", " ", "C12"}], "+", 
                 RowBox[{"8", " ", "C22"}], "+", 
                 RowBox[{"8", " ", "C23"}]}]], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
            SuperscriptBox["r", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", 
            RowBox[{"CR", "[", "2", "]"}]}], 
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox["C11"]}]]}], ")"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["r", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox["C11"]}]]], " ", 
               RowBox[{"CR", "[", "1", "]"}]}], "+", 
              RowBox[{
               SuperscriptBox["r", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox["C11"]}]]], " ", 
               RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], "r"], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["r", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", 
               RowBox[{"CR", "[", "1", "]"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]], "+", 
             FractionBox[
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["r", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", 
               RowBox[{"CR", "[", "2", "]"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}], ")"}]}]}], ")"}]}]}], "0", "0"},
     {"0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]], " ", 
            RowBox[{"CR", "[", "1", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["r", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]], " ", 
            RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["r", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox["C11"]}]]], " ", 
               RowBox[{"CR", "[", "1", "]"}]}], "+", 
              RowBox[{
               SuperscriptBox["r", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox["C11"]}]]], " ", 
               RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], "r"], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["r", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", 
               RowBox[{"CR", "[", "1", "]"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]], "+", 
             FractionBox[
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["r", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", 
               RowBox[{"CR", "[", "2", "]"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}], ")"}]}]}], ")"}]}]}], "0"},
     {"0", "0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]], " ", 
            RowBox[{"CR", "[", "1", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["r", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]], " ", 
            RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["r", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox["C11"]}]]], " ", 
               RowBox[{"CR", "[", "1", "]"}]}], "+", 
              RowBox[{
               SuperscriptBox["r", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox["C11"]}]]], " ", 
               RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], "r"], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["r", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", 
               RowBox[{"CR", "[", "1", "]"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]], "+", 
             FractionBox[
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["r", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", 
               RowBox[{"CR", "[", "2", "]"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}], ")"}]}]}], ")"}]}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["condition for the internal and external pressure",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"er", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"1", ",", "0", ",", "0"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", " ", 
  RowBox[{"-", " ", "er"}]}], "\[IndentingNewLine]", 
 RowBox[{"eqi", " ", "=", " ", 
  RowBox[{"(", " ", 
   RowBox[{"Thread", " ", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sig", " ", "/.", " ", 
        RowBox[{"r", " ", "\[Rule]", " ", "ri"}]}], ")"}], " ", ".", " ", 
      "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"-", " ", "pi"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(normal\\)\\\" is similar to existing symbol \
\\\"\\!\\(Normal\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[Mu]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               RowBox[{"(", 
                RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
            FractionBox[
             SqrtBox[
              RowBox[{"C11", "-", 
               RowBox[{"8", " ", "C12"}], "+", 
               RowBox[{"8", " ", "C22"}], "+", 
               RowBox[{"8", " ", "C23"}]}]], 
             RowBox[{
              SqrtBox["2"], " ", 
              SqrtBox[
               RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
          SuperscriptBox["ri", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                
                FractionBox[
                 SqrtBox[
                  RowBox[{"C11", "-", 
                   RowBox[{"8", " ", "C12"}], "+", 
                   RowBox[{"8", " ", "C22"}], "+", 
                   RowBox[{"8", " ", "C23"}]}]], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
             RowBox[{
              SqrtBox["2"], " ", 
              SqrtBox["C11"]}]]}]], " ", 
          RowBox[{"CR", "[", "1", "]"}]}], 
         SqrtBox["C11"]], "+", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               RowBox[{"(", 
                RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
            FractionBox[
             SqrtBox[
              RowBox[{"C11", "-", 
               RowBox[{"8", " ", "C12"}], "+", 
               RowBox[{"8", " ", "C22"}], "+", 
               RowBox[{"8", " ", "C23"}]}]], 
             RowBox[{
              SqrtBox["2"], " ", 
              SqrtBox[
               RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
          SuperscriptBox["ri", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                
                FractionBox[
                 SqrtBox[
                  RowBox[{"C11", "-", 
                   RowBox[{"8", " ", "C12"}], "+", 
                   RowBox[{"8", " ", "C22"}], "+", 
                   RowBox[{"8", " ", "C23"}]}]], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
             RowBox[{
              SqrtBox["2"], " ", 
              SqrtBox["C11"]}]]}]], " ", 
          RowBox[{"CR", "[", "2", "]"}]}], 
         SqrtBox["C11"]]}], ")"}]}], "-", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["ri", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]], " ", 
             RowBox[{"CR", "[", "1", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["ri", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]], " ", 
             RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], "ri"], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["2"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["ri", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", 
             RowBox[{"CR", "[", "1", "]"}]}], 
            SqrtBox["C11"]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["2"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["ri", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", 
             RowBox[{"CR", "[", "2", "]"}]}], 
            SqrtBox["C11"]]}], ")"}]}]}], ")"}]}]}], "\[Equal]", "pi"}], ",", 
   "True", ",", "True"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", "  ", "er"}], "\[IndentingNewLine]", 
 RowBox[{"eqe", " ", "=", " ", 
  RowBox[{"(", "  ", 
   RowBox[{"Thread", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sig", " ", "/.", " ", 
        RowBox[{"r", " ", "\[Rule]", " ", "re"}]}], ")"}], " ", ".", " ", 
      "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"-", " ", "pe"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               RowBox[{"(", 
                RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
            FractionBox[
             SqrtBox[
              RowBox[{"C11", "-", 
               RowBox[{"8", " ", "C12"}], "+", 
               RowBox[{"8", " ", "C22"}], "+", 
               RowBox[{"8", " ", "C23"}]}]], 
             RowBox[{
              SqrtBox["2"], " ", 
              SqrtBox[
               RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
          SuperscriptBox["re", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                
                FractionBox[
                 SqrtBox[
                  RowBox[{"C11", "-", 
                   RowBox[{"8", " ", "C12"}], "+", 
                   RowBox[{"8", " ", "C22"}], "+", 
                   RowBox[{"8", " ", "C23"}]}]], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
             RowBox[{
              SqrtBox["2"], " ", 
              SqrtBox["C11"]}]]}]], " ", 
          RowBox[{"CR", "[", "1", "]"}]}], 
         SqrtBox["C11"]], "+", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               RowBox[{"(", 
                RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
            FractionBox[
             SqrtBox[
              RowBox[{"C11", "-", 
               RowBox[{"8", " ", "C12"}], "+", 
               RowBox[{"8", " ", "C22"}], "+", 
               RowBox[{"8", " ", "C23"}]}]], 
             RowBox[{
              SqrtBox["2"], " ", 
              SqrtBox[
               RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
          SuperscriptBox["re", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                
                FractionBox[
                 SqrtBox[
                  RowBox[{"C11", "-", 
                   RowBox[{"8", " ", "C12"}], "+", 
                   RowBox[{"8", " ", "C22"}], "+", 
                   RowBox[{"8", " ", "C23"}]}]], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
             RowBox[{
              SqrtBox["2"], " ", 
              SqrtBox["C11"]}]]}]], " ", 
          RowBox[{"CR", "[", "2", "]"}]}], 
         SqrtBox["C11"]]}], ")"}]}], "+", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["re", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]], " ", 
             RowBox[{"CR", "[", "1", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["re", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]], " ", 
             RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], "re"], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["2"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["re", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", 
             RowBox[{"CR", "[", "1", "]"}]}], 
            SqrtBox["C11"]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["2"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["re", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", 
             RowBox[{"CR", "[", "2", "]"}]}], 
            SqrtBox["C11"]]}], ")"}]}]}], ")"}]}]}], "\[Equal]", 
    RowBox[{"-", "pe"}]}], ",", "True", ",", "True"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"eqi", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
       RowBox[{"eqe", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}], " ", ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CR", "[", "1", "]"}], ",", " ", 
       RowBox[{"CR", "[", "2", "]"}]}], "}"}]}], " ", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"CR", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"pi", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["ri", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
            RowBox[{
             SqrtBox["2"], " ", 
             SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], "-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               RowBox[{"(", 
                RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
            FractionBox[
             SqrtBox[
              RowBox[{"C11", "-", 
               RowBox[{"8", " ", "C12"}], "+", 
               RowBox[{"8", " ", "C22"}], "+", 
               RowBox[{"8", " ", "C23"}]}]], 
             RowBox[{
              SqrtBox["2"], " ", 
              SqrtBox[
               RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
          SuperscriptBox["ri", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                
                FractionBox[
                 SqrtBox[
                  RowBox[{"C11", "-", 
                   RowBox[{"8", " ", "C12"}], "+", 
                   RowBox[{"8", " ", "C22"}], "+", 
                   RowBox[{"8", " ", "C23"}]}]], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
             RowBox[{
              SqrtBox["2"], " ", 
              SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], 
         RowBox[{
          SqrtBox["2"], " ", 
          SqrtBox["C11"]}]], "-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               RowBox[{"(", 
                RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
            FractionBox[
             SqrtBox[
              RowBox[{"C11", "-", 
               RowBox[{"8", " ", "C12"}], "+", 
               RowBox[{"8", " ", "C22"}], "+", 
               RowBox[{"8", " ", "C23"}]}]], 
             RowBox[{
              SqrtBox["2"], " ", 
              SqrtBox[
               RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
          SuperscriptBox["ri", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                
                FractionBox[
                 SqrtBox[
                  RowBox[{"C11", "-", 
                   RowBox[{"8", " ", "C12"}], "+", 
                   RowBox[{"8", " ", "C22"}], "+", 
                   RowBox[{"8", " ", "C23"}]}]], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
             RowBox[{
              SqrtBox["2"], " ", 
              SqrtBox["C11"]}]]}]], " ", "\[Mu]"}], 
         SqrtBox["C11"]]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["ri", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], "-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
              FractionBox[
               SqrtBox[
                RowBox[{"C11", "-", 
                 RowBox[{"8", " ", "C12"}], "+", 
                 RowBox[{"8", " ", "C22"}], "+", 
                 RowBox[{"8", " ", "C23"}]}]], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
            SuperscriptBox["ri", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], 
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox["C11"]}]], "-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["2"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
              FractionBox[
               SqrtBox[
                RowBox[{"C11", "-", 
                 RowBox[{"8", " ", "C12"}], "+", 
                 RowBox[{"8", " ", "C22"}], "+", 
                 RowBox[{"8", " ", "C23"}]}]], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
            SuperscriptBox["ri", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", "\[Mu]"}], 
           SqrtBox["C11"]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"pi", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["re", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["re", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox["2"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["re", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", "\[Mu]"}], 
              SqrtBox["C11"]]}], ")"}]}], "+", 
          RowBox[{"pe", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              SuperscriptBox["ri", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["ri", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox["2"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["ri", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", "\[Mu]"}], 
              SqrtBox["C11"]]}], ")"}]}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["ri", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], "-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
              FractionBox[
               SqrtBox[
                RowBox[{"C11", "-", 
                 RowBox[{"8", " ", "C12"}], "+", 
                 RowBox[{"8", " ", "C22"}], "+", 
                 RowBox[{"8", " ", "C23"}]}]], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
            SuperscriptBox["ri", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], 
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox["C11"]}]], "-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["2"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
              FractionBox[
               SqrtBox[
                RowBox[{"C11", "-", 
                 RowBox[{"8", " ", "C12"}], "+", 
                 RowBox[{"8", " ", "C22"}], "+", 
                 RowBox[{"8", " ", "C23"}]}]], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
            SuperscriptBox["ri", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", "\[Mu]"}], 
           SqrtBox["C11"]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["re", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["re", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox["2"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["re", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", "\[Mu]"}], 
              SqrtBox["C11"]]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              SuperscriptBox["ri", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["ri", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox["2"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["ri", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", "\[Mu]"}], 
              SqrtBox["C11"]]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["re", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["re", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox["2"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["re", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", "\[Mu]"}], 
              SqrtBox["C11"]]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              SuperscriptBox["ri", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["ri", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], 
              RowBox[{
               SqrtBox["2"], " ", 
               SqrtBox["C11"]}]], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox["2"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ",
                
               SuperscriptBox["ri", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                    
                    FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SqrtBox["C11"]}]]}]], " ", "\[Mu]"}], 
              SqrtBox["C11"]]}], ")"}]}]}], ")"}]}], ")"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"CR", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["re", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["re", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], 
            RowBox[{
             SqrtBox["2"], " ", 
             SqrtBox["C11"]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["2"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["re", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", "\[Mu]"}], 
            SqrtBox["C11"]]}], ")"}]}], "+", 
        RowBox[{"pe", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["ri", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["ri", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], 
            RowBox[{
             SqrtBox["2"], " ", 
             SqrtBox["C11"]}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["2"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["ri", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", "\[Mu]"}], 
            SqrtBox["C11"]]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["re", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["re", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], 
            RowBox[{
             SqrtBox["2"], " ", 
             SqrtBox["C11"]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["2"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["re", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", "\[Mu]"}], 
            SqrtBox["C11"]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["ri", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["ri", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], 
            RowBox[{
             SqrtBox["2"], " ", 
             SqrtBox["C11"]}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["2"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["ri", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", "\[Mu]"}], 
            SqrtBox["C11"]]}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["re", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["re", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], 
            RowBox[{
             SqrtBox["2"], " ", 
             SqrtBox["C11"]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["2"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["re", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "-", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", "\[Mu]"}], 
            SqrtBox["C11"]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["ri", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                  
                  FractionBox[
                   SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                   RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
               RowBox[{
                SqrtBox["2"], " ", 
                SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["ri", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", "\[Lambda]"}], 
            RowBox[{
             SqrtBox["2"], " ", 
             SqrtBox["C11"]}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox["2"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                 RowBox[{
                  SqrtBox["2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
               FractionBox[
                SqrtBox[
                 RowBox[{"C11", "-", 
                  RowBox[{"8", " ", "C12"}], "+", 
                  RowBox[{"8", " ", "C22"}], "+", 
                  RowBox[{"8", " ", "C23"}]}]], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}], " ", 
             SuperscriptBox["ri", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", 
                    SqrtBox["C11"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]]}], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}]}]]}], "+", 
                   
                   FractionBox[
                    SqrtBox[
                    RowBox[{"C11", "-", 
                    RowBox[{"8", " ", "C12"}], "+", 
                    RowBox[{"8", " ", "C22"}], "+", 
                    RowBox[{"8", " ", "C23"}]}]], 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}], ")"}]}], 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SqrtBox["C11"]}]]}]], " ", "\[Mu]"}], 
            SqrtBox["C11"]]}], ")"}]}]}], ")"}]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"uf", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"uu", " ", "/.", " ", "sol"}], " ", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"epsf", " ", "=", " ", 
  RowBox[{
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"eps", " ", "/.", " ", "sol"}], " ", "]"}], " ", "//", " ", 
   "MatrixForm"}]}], "\[IndentingNewLine]", 
 RowBox[{"sigf", " ", "=", " ", 
  RowBox[{
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"sig", " ", "/.", " ", "sol"}], " ", "]"}], " ", "//", " ", 
   "MatrixForm"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], "-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
          SqrtBox[
           RowBox[{"C11", "+", 
            RowBox[{"8", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]]}], 
         RowBox[{"2", " ", 
          SqrtBox["C11"], " ", 
          SqrtBox[
           RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "C11"}], " ", 
         RowBox[{"(", 
          RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "pi"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
              SuperscriptBox["re", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], " ", 
            
            SuperscriptBox["ri", 
             RowBox[{
              FractionBox["3", "2"], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{"2", " ", 
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "+", 
           RowBox[{"pe", " ", 
            SuperscriptBox["re", 
             RowBox[{
              FractionBox["3", "2"], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{"2", " ", 
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
              SuperscriptBox["ri", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}], 
          ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "-", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["C11"], " ", 
         SqrtBox[
          RowBox[{"-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], "2"]}]], 
         " ", 
         SqrtBox[
          RowBox[{"C11", "+", 
           RowBox[{"8", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], " ",
          
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "pi"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "+", 
              SuperscriptBox["re", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], " ", 
            
            SuperscriptBox["ri", 
             RowBox[{
              FractionBox["3", "2"], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{"2", " ", 
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "+", 
           RowBox[{"pe", " ", 
            SuperscriptBox["re", 
             RowBox[{
              FractionBox["3", "2"], "+", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{"2", " ", 
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "+", 
              SuperscriptBox["ri", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                 SqrtBox[
                  RowBox[{"C11", "+", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                RowBox[{
                 SqrtBox["C11"], " ", 
                 SqrtBox[
                  RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}], 
          ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["re", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]]}], 
          
          RowBox[{
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
        SuperscriptBox["ri", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]]}], 
          
          RowBox[{
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SqrtBox["C11"], " ", 
         SqrtBox[
          RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "-", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
        RowBox[{
         SqrtBox[
          RowBox[{
           RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
         SqrtBox[
          RowBox[{"C11", "+", 
           RowBox[{"8", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], " ",
          
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["C11"], " ", 
         SqrtBox[
          RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "-", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
        RowBox[{
         SqrtBox[
          RowBox[{
           RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
         SqrtBox[
          RowBox[{"C11", "+", 
           RowBox[{"8", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], " ",
          
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], ")"}]}], ",", 
   "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(epsf\\)\
\\\" is similar to existing symbol \\\"\\!\\(eps\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["r", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3", "2"]}], "-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            SqrtBox[
             RowBox[{"C11", "+", 
              RowBox[{"8", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]]}],
            
           RowBox[{"2", " ", 
            SqrtBox["C11"], " ", 
            SqrtBox[
             RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"C11", " ", 
           RowBox[{"(", 
            RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "pi"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["re", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], 
              " ", 
              SuperscriptBox["ri", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "+", 
             RowBox[{"pe", " ", 
              SuperscriptBox["re", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["ri", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}],
             ")"}], " ", "\[Lambda]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "pi"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "+", 
                SuperscriptBox["re", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], 
              " ", 
              SuperscriptBox["ri", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "+", 
             RowBox[{"pe", " ", 
              SuperscriptBox["re", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "+", 
                SuperscriptBox["ri", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}],
             ")"}], " ", "\[Lambda]"}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], "2"], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "pi"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["re", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], 
              " ", 
              SuperscriptBox["ri", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "+", 
             RowBox[{"pe", " ", 
              SuperscriptBox["re", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["ri", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}],
             ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             SqrtBox[
              RowBox[{"C11", "+", 
               RowBox[{"8", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                 ")"}]}]}]]}], 
            RowBox[{
             SqrtBox["C11"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
          SuperscriptBox["ri", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             SqrtBox[
              RowBox[{"C11", "+", 
               RowBox[{"8", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                 ")"}]}]}]]}], 
            RowBox[{
             SqrtBox["C11"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "-", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "-", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}]], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["r", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3", "2"]}], "-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            SqrtBox[
             RowBox[{"C11", "+", 
              RowBox[{"8", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]]}],
            
           RowBox[{"2", " ", 
            SqrtBox["C11"], " ", 
            SqrtBox[
             RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "C11"}], " ", 
           RowBox[{"(", 
            RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "pi"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["re", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], 
              " ", 
              SuperscriptBox["ri", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "+", 
             RowBox[{"pe", " ", 
              SuperscriptBox["re", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["ri", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}],
             ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "-", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "pi"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "+", 
                SuperscriptBox["re", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], 
              " ", 
              SuperscriptBox["ri", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "+", 
             RowBox[{"pe", " ", 
              SuperscriptBox["re", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "+", 
                SuperscriptBox["ri", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}],
             ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             SqrtBox[
              RowBox[{"C11", "+", 
               RowBox[{"8", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                 ")"}]}]}]]}], 
            RowBox[{
             SqrtBox["C11"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
          SuperscriptBox["ri", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             SqrtBox[
              RowBox[{"C11", "+", 
               RowBox[{"8", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                 ")"}]}]}]]}], 
            RowBox[{
             SqrtBox["C11"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "-", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "-", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}]], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["r", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3", "2"]}], "-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            SqrtBox[
             RowBox[{"C11", "+", 
              RowBox[{"8", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]]}],
            
           RowBox[{"2", " ", 
            SqrtBox["C11"], " ", 
            SqrtBox[
             RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "C11"}], " ", 
           RowBox[{"(", 
            RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "pi"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["re", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], 
              " ", 
              SuperscriptBox["ri", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "+", 
             RowBox[{"pe", " ", 
              SuperscriptBox["re", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["ri", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}],
             ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "-", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "pi"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "+", 
                SuperscriptBox["re", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], 
              " ", 
              SuperscriptBox["ri", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "+", 
             RowBox[{"pe", " ", 
              SuperscriptBox["re", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "+", 
                SuperscriptBox["ri", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}],
             ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             SqrtBox[
              RowBox[{"C11", "+", 
               RowBox[{"8", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                 ")"}]}]}]]}], 
            RowBox[{
             SqrtBox["C11"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
          SuperscriptBox["ri", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             SqrtBox[
              RowBox[{"C11", "+", 
               RowBox[{"8", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                 ")"}]}]}]]}], 
            RowBox[{
             SqrtBox["C11"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "-", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "-", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}]]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(sigf\\)\
\\\" is similar to existing symbol \\\"\\!\\(sig\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        SuperscriptBox["r", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3", "2"]}], "-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            SqrtBox[
             RowBox[{"C11", "+", 
              RowBox[{"8", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]]}],
            
           RowBox[{"2", " ", 
            SqrtBox["C11"], " ", 
            SqrtBox[
             RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"pi", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
             SuperscriptBox["re", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], " ", 
           SuperscriptBox["ri", 
            RowBox[{
             FractionBox["3", "2"], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{"2", " ", 
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "-", 
          RowBox[{"pe", " ", 
           SuperscriptBox["re", 
            RowBox[{
             FractionBox["3", "2"], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
               SqrtBox[
                RowBox[{"C11", "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                   ")"}]}]}]]}], 
              RowBox[{"2", " ", 
               SqrtBox["C11"], " ", 
               SqrtBox[
                RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
             SuperscriptBox["ri", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                SqrtBox[
                 RowBox[{"C11", "+", 
                  RowBox[{"8", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
               RowBox[{
                SqrtBox["C11"], " ", 
                SqrtBox[
                 RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}], 
         ")"}]}], 
       RowBox[{
        SuperscriptBox["re", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]]}], 
          
          RowBox[{
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
        SuperscriptBox["ri", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]]}], 
          
          RowBox[{
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}]], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["r", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3", "2"]}], "-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            SqrtBox[
             RowBox[{"C11", "+", 
              RowBox[{"8", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]]}],
            
           RowBox[{"2", " ", 
            SqrtBox["C11"], " ", 
            SqrtBox[
             RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], "2"], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "pi"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["re", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], 
              " ", 
              SuperscriptBox["ri", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "+", 
             RowBox[{"pe", " ", 
              SuperscriptBox["re", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["ri", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}],
             ")"}], " ", "\[Lambda]", " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "pi"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "+", 
                SuperscriptBox["re", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], 
              " ", 
              SuperscriptBox["ri", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "+", 
             RowBox[{"pe", " ", 
              SuperscriptBox["re", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "+", 
                SuperscriptBox["ri", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}],
             ")"}], " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
          RowBox[{"C11", " ", 
           RowBox[{"(", 
            RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "pi"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["re", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], 
              " ", 
              SuperscriptBox["ri", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "+", 
             RowBox[{"pe", " ", 
              SuperscriptBox["re", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["ri", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}],
             ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["\[Lambda]", "2"]}], "+", 
             RowBox[{"\[Lambda]", " ", "\[Mu]"}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[Mu]", "2"]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             SqrtBox[
              RowBox[{"C11", "+", 
               RowBox[{"8", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                 ")"}]}]}]]}], 
            RowBox[{
             SqrtBox["C11"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
          SuperscriptBox["ri", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             SqrtBox[
              RowBox[{"C11", "+", 
               RowBox[{"8", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                 ")"}]}]}]]}], 
            RowBox[{
             SqrtBox["C11"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "-", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "-", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}]], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["r", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3", "2"]}], "-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
            SqrtBox[
             RowBox[{"C11", "+", 
              RowBox[{"8", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]]}],
            
           RowBox[{"2", " ", 
            SqrtBox["C11"], " ", 
            SqrtBox[
             RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], "2"], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "pi"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["re", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], 
              " ", 
              SuperscriptBox["ri", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "+", 
             RowBox[{"pe", " ", 
              SuperscriptBox["re", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["ri", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}],
             ")"}], " ", "\[Lambda]", " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}], 
              "2"]}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "pi"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "+", 
                SuperscriptBox["re", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], 
              " ", 
              SuperscriptBox["ri", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "+", 
             RowBox[{"pe", " ", 
              SuperscriptBox["re", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "+", 
                SuperscriptBox["ri", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}],
             ")"}], " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
          RowBox[{"C11", " ", 
           RowBox[{"(", 
            RowBox[{"C12", "-", "C22", "-", "C23"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "pi"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["re", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], 
              " ", 
              SuperscriptBox["ri", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]]}], "+", 
             RowBox[{"pe", " ", 
              SuperscriptBox["re", 
               RowBox[{
                FractionBox["3", "2"], "+", 
                FractionBox[
                 RowBox[{"\[ImaginaryI]", " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                  SqrtBox[
                   RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                 RowBox[{"2", " ", 
                  SqrtBox["C11"], " ", 
                  SqrtBox[
                   RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["r", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
                SuperscriptBox["ri", 
                 FractionBox[
                  RowBox[{"\[ImaginaryI]", " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
                   SqrtBox[
                    RowBox[{"C11", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                    ")"}]}]}]]}], 
                  RowBox[{
                   SqrtBox["C11"], " ", 
                   SqrtBox[
                    RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}]}]}],
             ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["\[Lambda]", "2"]}], "+", 
             RowBox[{"\[Lambda]", " ", "\[Mu]"}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[Mu]", "2"]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             SqrtBox[
              RowBox[{"C11", "+", 
               RowBox[{"8", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                 ")"}]}]}]]}], 
            RowBox[{
             SqrtBox["C11"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]], "-", 
          SuperscriptBox["ri", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
             SqrtBox[
              RowBox[{"C11", "+", 
               RowBox[{"8", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], 
                 ")"}]}]}]]}], 
            RowBox[{
             SqrtBox["C11"], " ", 
             SqrtBox[
              RowBox[{"C12", "-", "C22", "-", "C23"}]]}]]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "-", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["C11"], " ", 
           SqrtBox[
            RowBox[{"C12", "-", "C22", "-", "C23"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "-", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}]], " ", 
           SqrtBox[
            RowBox[{"C11", "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C12"}], "+", "C22", "+", "C23"}], ")"}]}]}]], 
           " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}]]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The underground cavity under internal pressure: pi",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", " ", 
  RowBox[{
   RowBox[{"uf", " ", "/.", " ", 
    RowBox[{"pe", " ", "\[Rule]", " ", "0"}]}], "  ", ",", " ", 
   RowBox[{"re", " ", "\[Rule]", " ", "Infinity"}]}], " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"pi", " ", 
     SuperscriptBox["ri", "3"]}], 
    RowBox[{"4", " ", 
     SuperscriptBox["r", "2"], " ", "\[Mu]"}]], ",", "0", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Series", "[", " ", 
   RowBox[{
    RowBox[{"epsf", "  ", "/.", " ", 
     RowBox[{"pe", " ", "\[Rule]", " ", "0"}]}], "   ", ",", " ", 
    RowBox[{"{", 
     RowBox[{"re", " ", ",", "Infinity", ",", "1"}], "}"}]}], " ", "]"}], " ",
   "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Series", "[", " ", 
   RowBox[{
    RowBox[{"sigf", "  ", "/.", " ", 
     RowBox[{"pe", " ", "\[Rule]", " ", "0"}]}], "  ", ",", " ", 
    RowBox[{"{", 
     RowBox[{"re", ",", "Infinity", ",", " ", "1"}], "}"}]}], " ", "]"}], " ",
   "//", " ", "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       InterpretationBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"pi", " ", 
            SuperscriptBox["ri", "3"]}], 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", "\[Mu]"}], ")"}]}]]}], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", 
            FractionBox["1", "re"], "]"}], "2"],
          SeriesData[re, 
           DirectedInfinity[1], {}, 0, 2, 1],
          Editable->False]}],
        SeriesData[re, 
         DirectedInfinity[1], {Rational[-1, 2] pi r^(-3) ri^3/\[Mu]}, 0, 2, 
         1],
        Editable->False], "0", "0"},
      {"0", 
       InterpretationBox[
        RowBox[{
         FractionBox[
          RowBox[{"pi", " ", 
           SuperscriptBox["ri", "3"]}], 
          RowBox[{"4", " ", 
           SuperscriptBox["r", "3"], " ", "\[Mu]"}]], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", 
            FractionBox["1", "re"], "]"}], "2"],
          SeriesData[re, 
           DirectedInfinity[1], {}, 0, 2, 1],
          Editable->False]}],
        SeriesData[re, 
         DirectedInfinity[1], {Rational[1, 4] pi r^(-3) ri^3/\[Mu]}, 0, 2, 1],
        
        Editable->False], "0"},
      {"0", "0", 
       InterpretationBox[
        RowBox[{
         FractionBox[
          RowBox[{"pi", " ", 
           SuperscriptBox["ri", "3"]}], 
          RowBox[{"4", " ", 
           SuperscriptBox["r", "3"], " ", "\[Mu]"}]], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", 
            FractionBox["1", "re"], "]"}], "2"],
          SeriesData[re, 
           DirectedInfinity[1], {}, 0, 2, 1],
          Editable->False]}],
        SeriesData[re, 
         DirectedInfinity[1], {Rational[1, 4] pi r^(-3) ri^3/\[Mu]}, 0, 2, 1],
        
        Editable->False]}
     }], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       InterpretationBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"pi", " ", 
            SuperscriptBox["ri", "3"]}], 
           SuperscriptBox["r", "3"]]}], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", 
            FractionBox["1", "re"], "]"}], "2"],
          SeriesData[re, 
           DirectedInfinity[1], {}, 0, 2, 1],
          Editable->False]}],
        SeriesData[re, 
         DirectedInfinity[1], {-pi r^(-3) ri^3}, 0, 2, 1],
        Editable->False], "0", "0"},
      {"0", 
       InterpretationBox[
        RowBox[{
         FractionBox[
          RowBox[{"pi", " ", 
           SuperscriptBox["ri", "3"]}], 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"]}]], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", 
            FractionBox["1", "re"], "]"}], "2"],
          SeriesData[re, 
           DirectedInfinity[1], {}, 0, 2, 1],
          Editable->False]}],
        SeriesData[re, 
         DirectedInfinity[1], {Rational[1, 2] pi r^(-3) ri^3}, 0, 2, 1],
        Editable->False], "0"},
      {"0", "0", 
       InterpretationBox[
        RowBox[{
         FractionBox[
          RowBox[{"pi", " ", 
           SuperscriptBox["ri", "3"]}], 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"]}]], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", 
            FractionBox["1", "re"], "]"}], "2"],
          SeriesData[re, 
           DirectedInfinity[1], {}, 0, 2, 1],
          Editable->False]}],
        SeriesData[re, 
         DirectedInfinity[1], {Rational[1, 2] pi r^(-3) ri^3}, 0, 2, 1],
        Editable->False]}
     }], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Series", "[", " ", 
   RowBox[{"epsf", "    ", ",", " ", 
    RowBox[{"{", 
     RowBox[{"re", " ", ",", "Infinity", ",", "1"}], "}"}]}], " ", "]"}], " ",
   "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Series", "[", " ", 
   RowBox[{"sigf", "    ", ",", " ", 
    RowBox[{"{", 
     RowBox[{"re", ",", "Infinity", ",", " ", "1"}], "}"}]}], " ", "]"}], " ",
   "//", " ", "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       InterpretationBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"pe", " ", 
             SuperscriptBox["ri", "3"]}], 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "3"], " ", "\[Mu]"}]], "-", 
           FractionBox[
            RowBox[{"pi", " ", 
             SuperscriptBox["ri", "3"]}], 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "3"], " ", "\[Mu]"}]], "-", 
           FractionBox["pe", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "+", 
             RowBox[{"2", " ", "\[Mu]"}]}]]}], ")"}], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", 
            FractionBox["1", "re"], "]"}], "2"],
          SeriesData[re, 
           DirectedInfinity[1], {}, 0, 2, 1],
          Editable->False]}],
        SeriesData[re, 
         DirectedInfinity[1], {
         Rational[1, 2] pe r^(-3) ri^3/\[Mu] + 
          Rational[-1, 2] pi r^(-3) ri^3/\[Mu] - pe/(3 \[Lambda] + 2 \[Mu])}, 
         0, 2, 1],
        Editable->False], "0", "0"},
      {"0", 
       InterpretationBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"pe", " ", 
              SuperscriptBox["ri", "3"]}], 
             RowBox[{"4", " ", 
              SuperscriptBox["r", "3"], " ", "\[Mu]"}]]}], "+", 
           FractionBox[
            RowBox[{"pi", " ", 
             SuperscriptBox["ri", "3"]}], 
            RowBox[{"4", " ", 
             SuperscriptBox["r", "3"], " ", "\[Mu]"}]], "-", 
           FractionBox["pe", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "+", 
             RowBox[{"2", " ", "\[Mu]"}]}]]}], ")"}], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", 
            FractionBox["1", "re"], "]"}], "2"],
          SeriesData[re, 
           DirectedInfinity[1], {}, 0, 2, 1],
          Editable->False]}],
        SeriesData[re, 
         DirectedInfinity[1], {
         Rational[-1, 4] pe r^(-3) ri^3/\[Mu] + 
          Rational[1, 4] pi r^(-3) ri^3/\[Mu] - pe/(3 \[Lambda] + 2 \[Mu])}, 
         0, 2, 1],
        Editable->False], "0"},
      {"0", "0", 
       InterpretationBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"pe", " ", 
              SuperscriptBox["ri", "3"]}], 
             RowBox[{"4", " ", 
              SuperscriptBox["r", "3"], " ", "\[Mu]"}]]}], "+", 
           FractionBox[
            RowBox[{"pi", " ", 
             SuperscriptBox["ri", "3"]}], 
            RowBox[{"4", " ", 
             SuperscriptBox["r", "3"], " ", "\[Mu]"}]], "-", 
           FractionBox["pe", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "+", 
             RowBox[{"2", " ", "\[Mu]"}]}]]}], ")"}], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", 
            FractionBox["1", "re"], "]"}], "2"],
          SeriesData[re, 
           DirectedInfinity[1], {}, 0, 2, 1],
          Editable->False]}],
        SeriesData[re, 
         DirectedInfinity[1], {
         Rational[-1, 4] pe r^(-3) ri^3/\[Mu] + 
          Rational[1, 4] pi r^(-3) ri^3/\[Mu] - pe/(3 \[Lambda] + 2 \[Mu])}, 
         0, 2, 1],
        Editable->False]}
     }], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       InterpretationBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "pe"}], "+", 
           FractionBox[
            RowBox[{"pe", " ", 
             SuperscriptBox["ri", "3"]}], 
            SuperscriptBox["r", "3"]], "-", 
           FractionBox[
            RowBox[{"pi", " ", 
             SuperscriptBox["ri", "3"]}], 
            SuperscriptBox["r", "3"]]}], ")"}], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", 
            FractionBox["1", "re"], "]"}], "2"],
          SeriesData[re, 
           DirectedInfinity[1], {}, 0, 2, 1],
          Editable->False]}],
        SeriesData[re, 
         DirectedInfinity[1], {-pe + pe r^(-3) ri^3 - pi r^(-3) ri^3}, 0, 2, 
         1],
        Editable->False], "0", "0"},
      {"0", 
       InterpretationBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "pe"}], "-", 
           FractionBox[
            RowBox[{"pe", " ", 
             SuperscriptBox["ri", "3"]}], 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "3"]}]], "+", 
           FractionBox[
            RowBox[{"pi", " ", 
             SuperscriptBox["ri", "3"]}], 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "3"]}]]}], ")"}], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", 
            FractionBox["1", "re"], "]"}], "2"],
          SeriesData[re, 
           DirectedInfinity[1], {}, 0, 2, 1],
          Editable->False]}],
        SeriesData[re, 
         DirectedInfinity[
         1], {-pe + Rational[-1, 2] pe r^(-3) ri^3 + 
          Rational[1, 2] pi r^(-3) ri^3}, 0, 2, 1],
        Editable->False], "0"},
      {"0", "0", 
       InterpretationBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "pe"}], "-", 
           FractionBox[
            RowBox[{"pe", " ", 
             SuperscriptBox["ri", "3"]}], 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "3"]}]], "+", 
           FractionBox[
            RowBox[{"pi", " ", 
             SuperscriptBox["ri", "3"]}], 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "3"]}]]}], ")"}], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", 
            FractionBox["1", "re"], "]"}], "2"],
          SeriesData[re, 
           DirectedInfinity[1], {}, 0, 2, 1],
          Editable->False]}],
        SeriesData[re, 
         DirectedInfinity[
         1], {-pe + Rational[-1, 2] pe r^(-3) ri^3 + 
          Rational[1, 2] pi r^(-3) ri^3}, 0, 2, 1],
        Editable->False]}
     }], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The spherical thin shell under internal and external \
pressure: pi and pe",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"r2eta", " ", "=", " ", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"ri", " ", "\[Rule]", " ", 
       RowBox[{"R", 
        RowBox[{"(", " ", 
         RowBox[{"1", " ", "-", " ", 
          RowBox[{"eta", "/", "2"}]}], ")"}]}]}], " ", ",", " ", 
      RowBox[{"re", " ", "\[Rule]", " ", 
       RowBox[{"R", " ", 
        RowBox[{"(", " ", 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{"eta", "/", "2"}]}], " ", ")"}]}]}], " ", ",", " ", 
      RowBox[{"r", " ", "\[Rule]", "  ", 
       RowBox[{"R", 
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", "delta"}], ")"}]}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"delta2r", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"delta", " ", "\[Rule]", "  ", 
       RowBox[{
        RowBox[{"r", " ", "/", " ", "R"}], " ", "-", "1"}]}], ",", " ", 
      RowBox[{"eta", " ", "\[Rule]", " ", 
       RowBox[{"ee", " ", "/", " ", "R"}]}]}], " ", "}"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ri", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox["eta", "2"]}], ")"}], " ", "R"}]}], ",", 
   RowBox[{"re", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox["eta", "2"]}], ")"}], " ", "R"}]}], ",", 
   RowBox[{"r", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "delta"}], ")"}], " ", "R"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"delta", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     FractionBox["r", "R"]}]}], ",", 
   RowBox[{"eta", "\[Rule]", 
    FractionBox["ee", "R"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Series", "[", " ", 
    RowBox[{
     RowBox[{"uf", "  ", "/.", " ", "r2eta"}], " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"eta", ",", "  ", "0", ",", " ", "1"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"delta", ",", " ", "0", ",", "1"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Normal", "[", "%", "]"}], "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"suf", " ", "=", " ", 
      RowBox[{"Normal", "[", 
       RowBox[{"Series", "[", " ", 
        RowBox[{"%", " ", ",", " ", 
         RowBox[{"{", 
          RowBox[{"eta", ",", " ", "0", ",", "0"}], "}"}]}], "]"}], "]"}]}], 
     " ", ")"}], "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"ruf", " ", "=", " ", 
      RowBox[{"Simplify", "[", " ", 
       RowBox[{"suf", " ", "/.", " ", "delta2r"}], " ", "]"}]}], ")"}], " ", "//",
     " ", "MatrixForm"}]}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox[
      InterpretationBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"pe", " ", "R"}], 
            RowBox[{"12", " ", "\[Mu]"}]]}], "+", 
          FractionBox[
           RowBox[{"pi", " ", "R"}], 
           RowBox[{"12", " ", "\[Mu]"}]], "-", 
          FractionBox[
           RowBox[{"pe", " ", "R"}], 
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{"pi", " ", "R"}], 
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ")"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"pe", " ", "R"}], 
            RowBox[{"6", " ", "\[Mu]"}]], "-", 
           FractionBox[
            RowBox[{"pi", " ", "R"}], 
            RowBox[{"6", " ", "\[Mu]"}]], "-", 
           FractionBox[
            RowBox[{"pe", " ", "R"}], 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[Lambda]"}], "+", 
               RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{"pi", " ", "R"}], 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[Lambda]"}], "+", 
               RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ")"}], " ", 
         "delta"}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", "delta", "]"}], "2"],
         SeriesData[delta, 0, {}, 0, 2, 1],
         Editable->False]}],
       SeriesData[
       delta, 0, {
        Rational[-1, 12] pe R/\[Mu] + Rational[1, 12] pi R/\[Mu] + 
         Rational[-1, 3] pe R/(3 \[Lambda] + 2 \[Mu]) + 
         Rational[1, 3] pi R/(3 \[Lambda] + 2 \[Mu]), 
         Rational[1, 6] pe R/\[Mu] + Rational[-1, 6] pi R/\[Mu] + 
         Rational[-1, 3] pe R/(3 \[Lambda] + 2 \[Mu]) + 
         Rational[1, 3] pi R/(3 \[Lambda] + 2 \[Mu])}, 0, 2, 1],
       Editable->False], "eta"], "+", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"pe", " ", "R"}], 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[Lambda]"}], "+", 
               RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], "-", 
          FractionBox[
           RowBox[{"pi", " ", "R"}], 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ")"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"pe", " ", "R"}], 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", "\[Lambda]"}], "+", 
                RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], "-", 
           FractionBox[
            RowBox[{"pi", " ", "R"}], 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[Lambda]"}], "+", 
               RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ")"}], " ", 
         "delta"}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", "delta", "]"}], "2"],
         SeriesData[delta, 0, {}, 0, 2, 1],
         Editable->False]}],
       SeriesData[
       delta, 0, {
        Rational[-1, 2] pe R/(3 \[Lambda] + 2 \[Mu]) + 
         Rational[-1, 2] pi R/(3 \[Lambda] + 2 \[Mu]), 
         Rational[-1, 2] pe R/(3 \[Lambda] + 2 \[Mu]) + 
         Rational[-1, 2] pi R/(3 \[Lambda] + 2 \[Mu])}, 0, 2, 1],
       Editable->False], ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"5", " ", "pe", " ", "R"}], 
            RowBox[{"72", " ", "\[Mu]"}]], "-", 
           FractionBox[
            RowBox[{"5", " ", "pi", " ", "R"}], 
            RowBox[{"72", " ", "\[Mu]"}]], "-", 
           FractionBox[
            RowBox[{"2", " ", "pe", " ", "R"}], 
            RowBox[{"9", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[Lambda]"}], "+", 
               RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{"2", " ", "pi", " ", "R"}], 
            RowBox[{"9", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[Lambda]"}], "+", 
               RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"5", " ", "pe", " ", "R"}], 
              RowBox[{"36", " ", "\[Mu]"}]]}], "+", 
            FractionBox[
             RowBox[{"5", " ", "pi", " ", "R"}], 
             RowBox[{"36", " ", "\[Mu]"}]], "-", 
            FractionBox[
             RowBox[{"2", " ", "pe", " ", "R"}], 
             RowBox[{"9", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", "\[Lambda]"}], "+", 
                RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
            FractionBox[
             RowBox[{"2", " ", "pi", " ", "R"}], 
             RowBox[{"9", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", "\[Lambda]"}], "+", 
                RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ")"}], " ", 
          "delta"}], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", "delta", "]"}], "2"],
          SeriesData[delta, 0, {}, 0, 2, 1],
          Editable->False]}],
        SeriesData[
        delta, 0, {
         Rational[5, 72] pe R/\[Mu] + Rational[-5, 72] pi R/\[Mu] + 
          Rational[-2, 9] pe R/(3 \[Lambda] + 2 \[Mu]) + 
          Rational[2, 9] pi R/(3 \[Lambda] + 2 \[Mu]), 
          Rational[-5, 36] pe R/\[Mu] + Rational[5, 36] pi R/\[Mu] + 
          Rational[-2, 9] pe R/(3 \[Lambda] + 2 \[Mu]) + 
          Rational[2, 9] pi R/(3 \[Lambda] + 2 \[Mu])}, 0, 2, 1],
        Editable->False], ")"}], " ", "eta"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "eta", "]"}], "2"],
      SeriesData[eta, 0, {}, -1, 2, 1],
      Editable->False]}],
    SeriesData[eta, 0, {
      SeriesData[
      delta, 0, {
       Rational[-1, 12] pe R/\[Mu] + Rational[1, 12] pi R/\[Mu] + 
        Rational[-1, 3] pe R/(3 \[Lambda] + 2 \[Mu]) + 
        Rational[1, 3] pi R/(3 \[Lambda] + 2 \[Mu]), 
        Rational[1, 6] pe R/\[Mu] + Rational[-1, 6] pi R/\[Mu] + 
        Rational[-1, 3] pe R/(3 \[Lambda] + 2 \[Mu]) + 
        Rational[1, 3] pi R/(3 \[Lambda] + 2 \[Mu])}, 0, 2, 1], 
      SeriesData[
      delta, 0, {
       Rational[-1, 2] pe R/(3 \[Lambda] + 2 \[Mu]) + 
        Rational[-1, 2] pi R/(3 \[Lambda] + 2 \[Mu]), 
        Rational[-1, 2] pe R/(3 \[Lambda] + 2 \[Mu]) + 
        Rational[-1, 2] pi R/(3 \[Lambda] + 2 \[Mu])}, 0, 2, 1], 
      SeriesData[
      delta, 0, {
       Rational[5, 72] pe R/\[Mu] + Rational[-5, 72] pi R/\[Mu] + 
        Rational[-2, 9] pe R/(3 \[Lambda] + 2 \[Mu]) + 
        Rational[2, 9] pi R/(3 \[Lambda] + 2 \[Mu]), 
        Rational[-5, 36] pe R/\[Mu] + Rational[5, 36] pi R/\[Mu] + 
        Rational[-2, 9] pe R/(3 \[Lambda] + 2 \[Mu]) + 
        Rational[2, 9] pi R/(3 \[Lambda] + 2 \[Mu])}, 0, 2, 1]}, -1, 2, 1],
    Editable->False], ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"24", " ", "eta", " ", "\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], 
     RowBox[{"(", 
      RowBox[{"R", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"pi", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", " ", "delta"}]}], ")"}]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "6"}], "+", 
               RowBox[{"5", " ", 
                SuperscriptBox["eta", "2"]}]}], ")"}], " ", "\[Lambda]"}], 
            "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"6", "-", 
               RowBox[{"6", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "delta"}], ")"}], " ", "eta"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"6", " ", "delta"}]}], ")"}], " ", 
                SuperscriptBox["eta", "2"]}]}], ")"}], " ", "\[Mu]"}]}], 
           ")"}]}], "+", 
         RowBox[{"pe", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"2", " ", "delta"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "6"}], "+", 
               RowBox[{"5", " ", 
                SuperscriptBox["eta", "2"]}]}], ")"}], " ", "\[Lambda]"}], 
            "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"6", "+", 
               RowBox[{"6", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "delta"}], ")"}], " ", "eta"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"6", " ", "delta"}]}], ")"}], " ", 
                SuperscriptBox["eta", "2"]}]}], ")"}], " ", "\[Mu]"}]}], 
           ")"}]}]}], ")"}]}], ")"}]}]}], ",", "0", ",", "0"}], 
  "}"}]], "Output"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox[
        RowBox[{"R", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "6"}], " ", "pe", " ", "\[Lambda]"}], "+", 
           RowBox[{"12", " ", "delta", " ", "pe", " ", "\[Lambda]"}], "+", 
           RowBox[{"6", " ", "pi", " ", "\[Lambda]"}], "-", 
           RowBox[{"12", " ", "delta", " ", "pi", " ", "\[Lambda]"}], "-", 
           RowBox[{"12", " ", "pe", " ", "\[Mu]"}], "+", 
           RowBox[{"12", " ", "pi", " ", "\[Mu]"}]}], ")"}]}], 
        RowBox[{"24", " ", "eta", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{"R", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "12"}], " ", "pe", " ", "\[Mu]"}], "-", 
           RowBox[{"12", " ", "delta", " ", "pe", " ", "\[Mu]"}], "-", 
           RowBox[{"12", " ", "pi", " ", "\[Mu]"}], "-", 
           RowBox[{"12", " ", "delta", " ", "pi", " ", "\[Mu]"}]}], ")"}]}], 
        RowBox[{"24", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}]},
     {"0"},
     {"0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   Rational[1, 24] eta^(-1) 
     R \[Mu]^(-1) (3 \[Lambda] + 2 \[Mu])^(-1) ((-6) pe \[Lambda] + 
      12 delta pe \[Lambda] + 6 pi \[Lambda] - 12 delta pi \[Lambda] - 12 
      pe \[Mu] + 12 pi \[Mu]) + 
    Rational[1, 24] 
     R \[Mu]^(-1) (3 \[Lambda] + 2 \[Mu])^(-1) ((-12) pe \[Mu] - 12 delta 
      pe \[Mu] - 12 pi \[Mu] - 12 delta pi \[Mu]), 0, 0}]]], "Output"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", "pe", " ", "r", " ", "R", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "pi", " ", "r", " ", "R", " ", "\[Lambda]"}], "-", 
        RowBox[{"3", " ", "pe", " ", 
         SuperscriptBox["R", "2"], " ", "\[Lambda]"}], "+", 
        RowBox[{"3", " ", "pi", " ", 
         SuperscriptBox["R", "2"], " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "ee", " ", "pe", " ", "r", " ", "\[Mu]"}], "-", 
        RowBox[{"2", " ", "ee", " ", "pi", " ", "r", " ", "\[Mu]"}], "-", 
        RowBox[{"2", " ", "pe", " ", 
         SuperscriptBox["R", "2"], " ", "\[Mu]"}], "+", 
        RowBox[{"2", " ", "pi", " ", 
         SuperscriptBox["R", "2"], " ", "\[Mu]"}]}], 
       RowBox[{
        RowBox[{"12", " ", "ee", " ", "\[Lambda]", " ", "\[Mu]"}], "+", 
        RowBox[{"8", " ", "ee", " ", 
         SuperscriptBox["\[Mu]", "2"]}]}]]},
     {"0"},
     {"0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{(2 pe r R \[Lambda] - 2 pi r R \[Lambda] - 3 pe R^2 \[Lambda] + 
     3 pi R^2 \[Lambda] - 2 ee pe r \[Mu] - 2 ee pi r \[Mu] - 2 pe R^2 \[Mu] + 
     2 pi R^2 \[Mu])/(12 ee \[Lambda] \[Mu] + 8 ee \[Mu]^2), 0, 
    0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Series", "[", " ", 
  RowBox[{
   RowBox[{"epsf", "  ", "/.", "  ", "r2eta"}], " ", ",", " ", 
   RowBox[{"{", 
    RowBox[{"eta", ",", "  ", "0", ",", " ", "1"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"delta", ",", " ", "0", ",", "1"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"Normal", "[", "%", "]"}], "]"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"seps", " ", "=", " ", 
    RowBox[{"Normal", "[", " ", 
     RowBox[{"Series", "[", 
      RowBox[{"%", ",", " ", 
       RowBox[{"{", 
        RowBox[{"eta", ",", " ", "0", ",", " ", "0"}], "}"}]}], "]"}], 
     "]"}]}], " ", ")"}], "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"reps", " ", "=", " ", 
     RowBox[{"Simplify", "[", " ", 
      RowBox[{"seps", " ", "/.", " ", "delta2r"}], " ", "]"}]}], " ", ")"}], 
   " ", "//", " ", "MatrixForm"}], " "}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      InterpretationBox[
       RowBox[{
        FractionBox[
         InterpretationBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             FractionBox["pe", 
              RowBox[{"6", " ", "\[Mu]"}]], "-", 
             FractionBox["pi", 
              RowBox[{"6", " ", "\[Mu]"}]], "-", 
             FractionBox["pe", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "\[Lambda]"}], "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
             FractionBox["pi", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "\[Lambda]"}], "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["pe", 
                RowBox[{"2", " ", "\[Mu]"}]]}], "+", 
              FractionBox["pi", 
               RowBox[{"2", " ", "\[Mu]"}]]}], ")"}], " ", "delta"}], "+", 
           InterpretationBox[
            SuperscriptBox[
             RowBox[{"O", "[", "delta", "]"}], "2"],
            SeriesData[delta, 0, {}, 0, 2, 1],
            Editable->False]}],
          SeriesData[
          delta, 0, {
           Rational[1, 6] pe/\[Mu] + Rational[-1, 6] pi/\[Mu] + 
            Rational[-1, 3] pe/(3 \[Lambda] + 2 \[Mu]) + 
            Rational[1, 3] pi/(3 \[Lambda] + 2 \[Mu]), 
            Rational[-1, 2] pe/\[Mu] + Rational[1, 2] pi/\[Mu]}, 0, 2, 1],
          Editable->False], "eta"], "+", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["pe", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[Lambda]"}], "+", 
               RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], "-", 
          FractionBox["pi", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ")"}], "+", 
        RowBox[{
         RowBox[{"(", 
          InterpretationBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"5", " ", "pe"}], 
                RowBox[{"36", " ", "\[Mu]"}]]}], "+", 
              FractionBox[
               RowBox[{"5", " ", "pi"}], 
               RowBox[{"36", " ", "\[Mu]"}]], "-", 
              FractionBox[
               RowBox[{"2", " ", "pe"}], 
               RowBox[{"9", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", "\[Lambda]"}], "+", 
                  RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
              FractionBox[
               RowBox[{"2", " ", "pi"}], 
               RowBox[{"9", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", "\[Lambda]"}], "+", 
                  RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ")"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               FractionBox[
                RowBox[{"5", " ", "pe"}], 
                RowBox[{"12", " ", "\[Mu]"}]], "-", 
               FractionBox[
                RowBox[{"5", " ", "pi"}], 
                RowBox[{"12", " ", "\[Mu]"}]]}], ")"}], " ", "delta"}], "+", 
            InterpretationBox[
             SuperscriptBox[
              RowBox[{"O", "[", "delta", "]"}], "2"],
             SeriesData[delta, 0, {}, 0, 2, 1],
             Editable->False]}],
           SeriesData[
           delta, 0, {
            Rational[-5, 36] pe/\[Mu] + Rational[5, 36] pi/\[Mu] + 
             Rational[-2, 9] pe/(3 \[Lambda] + 2 \[Mu]) + 
             Rational[2, 9] pi/(3 \[Lambda] + 2 \[Mu]), 
             Rational[5, 12] pe/\[Mu] + Rational[-5, 12] pi/\[Mu]}, 0, 2, 1],
           Editable->False], ")"}], " ", "eta"}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", "eta", "]"}], "2"],
         SeriesData[eta, 0, {}, -1, 2, 1],
         Editable->False]}],
       SeriesData[eta, 0, {
         SeriesData[
         delta, 0, {
          Rational[1, 6] pe/\[Mu] + Rational[-1, 6] pi/\[Mu] + 
           Rational[-1, 3] pe/(3 \[Lambda] + 2 \[Mu]) + 
           Rational[1, 3] pi/(3 \[Lambda] + 2 \[Mu]), 
           Rational[-1, 2] pe/\[Mu] + Rational[1, 2] pi/\[Mu]}, 0, 2, 1], 
         Rational[-1, 2] pe/(3 \[Lambda] + 2 \[Mu]) + 
         Rational[-1, 2] pi/(3 \[Lambda] + 2 \[Mu]), 
         SeriesData[
         delta, 0, {
          Rational[-5, 36] pe/\[Mu] + Rational[5, 36] pi/\[Mu] + 
           Rational[-2, 9] pe/(3 \[Lambda] + 2 \[Mu]) + 
           Rational[2, 9] pi/(3 \[Lambda] + 2 \[Mu]), 
           Rational[5, 12] pe/\[Mu] + Rational[-5, 12] pi/\[Mu]}, 0, 2, 
          1]}, -1, 2, 1],
       Editable->False], "0", "0"},
     {"0", 
      InterpretationBox[
       RowBox[{
        FractionBox[
         InterpretationBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["pe", 
               RowBox[{"12", " ", "\[Mu]"}]]}], "+", 
             FractionBox["pi", 
              RowBox[{"12", " ", "\[Mu]"}]], "-", 
             FractionBox["pe", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "\[Lambda]"}], "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
             FractionBox["pi", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "\[Lambda]"}], "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              FractionBox["pe", 
               RowBox[{"4", " ", "\[Mu]"}]], "-", 
              FractionBox["pi", 
               RowBox[{"4", " ", "\[Mu]"}]]}], ")"}], " ", "delta"}], "+", 
           InterpretationBox[
            SuperscriptBox[
             RowBox[{"O", "[", "delta", "]"}], "2"],
            SeriesData[delta, 0, {}, 0, 2, 1],
            Editable->False]}],
          SeriesData[
          delta, 0, {
           Rational[-1, 12] pe/\[Mu] + Rational[1, 12] pi/\[Mu] + 
            Rational[-1, 3] pe/(3 \[Lambda] + 2 \[Mu]) + 
            Rational[1, 3] pi/(3 \[Lambda] + 2 \[Mu]), 
            Rational[1, 4] pe/\[Mu] + Rational[-1, 4] pi/\[Mu]}, 0, 2, 1],
          Editable->False], "eta"], "+", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["pe", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[Lambda]"}], "+", 
               RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], "-", 
          FractionBox["pi", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ")"}], "+", 
        RowBox[{
         RowBox[{"(", 
          InterpretationBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{"5", " ", "pe"}], 
               RowBox[{"72", " ", "\[Mu]"}]], "-", 
              FractionBox[
               RowBox[{"5", " ", "pi"}], 
               RowBox[{"72", " ", "\[Mu]"}]], "-", 
              FractionBox[
               RowBox[{"2", " ", "pe"}], 
               RowBox[{"9", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", "\[Lambda]"}], "+", 
                  RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
              FractionBox[
               RowBox[{"2", " ", "pi"}], 
               RowBox[{"9", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", "\[Lambda]"}], "+", 
                  RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ")"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"5", " ", "pe"}], 
                 RowBox[{"24", " ", "\[Mu]"}]]}], "+", 
               FractionBox[
                RowBox[{"5", " ", "pi"}], 
                RowBox[{"24", " ", "\[Mu]"}]]}], ")"}], " ", "delta"}], "+", 
            InterpretationBox[
             SuperscriptBox[
              RowBox[{"O", "[", "delta", "]"}], "2"],
             SeriesData[delta, 0, {}, 0, 2, 1],
             Editable->False]}],
           SeriesData[
           delta, 0, {
            Rational[5, 72] pe/\[Mu] + Rational[-5, 72] pi/\[Mu] + 
             Rational[-2, 9] pe/(3 \[Lambda] + 2 \[Mu]) + 
             Rational[2, 9] pi/(3 \[Lambda] + 2 \[Mu]), 
             Rational[-5, 24] pe/\[Mu] + Rational[5, 24] pi/\[Mu]}, 0, 2, 1],
           Editable->False], ")"}], " ", "eta"}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", "eta", "]"}], "2"],
         SeriesData[eta, 0, {}, -1, 2, 1],
         Editable->False]}],
       SeriesData[eta, 0, {
         SeriesData[
         delta, 0, {
          Rational[-1, 12] pe/\[Mu] + Rational[1, 12] pi/\[Mu] + 
           Rational[-1, 3] pe/(3 \[Lambda] + 2 \[Mu]) + 
           Rational[1, 3] pi/(3 \[Lambda] + 2 \[Mu]), Rational[1, 4] pe/\[Mu] + 
           Rational[-1, 4] pi/\[Mu]}, 0, 2, 1], 
         Rational[-1, 2] pe/(3 \[Lambda] + 2 \[Mu]) + 
         Rational[-1, 2] pi/(3 \[Lambda] + 2 \[Mu]), 
         SeriesData[
         delta, 0, {
          Rational[5, 72] pe/\[Mu] + Rational[-5, 72] pi/\[Mu] + 
           Rational[-2, 9] pe/(3 \[Lambda] + 2 \[Mu]) + 
           Rational[2, 9] pi/(3 \[Lambda] + 2 \[Mu]), 
           Rational[-5, 24] pe/\[Mu] + Rational[5, 24] pi/\[Mu]}, 0, 2, 
          1]}, -1, 2, 1],
       Editable->False], "0"},
     {"0", "0", 
      InterpretationBox[
       RowBox[{
        FractionBox[
         InterpretationBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["pe", 
               RowBox[{"12", " ", "\[Mu]"}]]}], "+", 
             FractionBox["pi", 
              RowBox[{"12", " ", "\[Mu]"}]], "-", 
             FractionBox["pe", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "\[Lambda]"}], "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
             FractionBox["pi", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "\[Lambda]"}], "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              FractionBox["pe", 
               RowBox[{"4", " ", "\[Mu]"}]], "-", 
              FractionBox["pi", 
               RowBox[{"4", " ", "\[Mu]"}]]}], ")"}], " ", "delta"}], "+", 
           InterpretationBox[
            SuperscriptBox[
             RowBox[{"O", "[", "delta", "]"}], "2"],
            SeriesData[delta, 0, {}, 0, 2, 1],
            Editable->False]}],
          SeriesData[
          delta, 0, {
           Rational[-1, 12] pe/\[Mu] + Rational[1, 12] pi/\[Mu] + 
            Rational[-1, 3] pe/(3 \[Lambda] + 2 \[Mu]) + 
            Rational[1, 3] pi/(3 \[Lambda] + 2 \[Mu]), 
            Rational[1, 4] pe/\[Mu] + Rational[-1, 4] pi/\[Mu]}, 0, 2, 1],
          Editable->False], "eta"], "+", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["pe", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[Lambda]"}], "+", 
               RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], "-", 
          FractionBox["pi", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ")"}], "+", 
        RowBox[{
         RowBox[{"(", 
          InterpretationBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{"5", " ", "pe"}], 
               RowBox[{"72", " ", "\[Mu]"}]], "-", 
              FractionBox[
               RowBox[{"5", " ", "pi"}], 
               RowBox[{"72", " ", "\[Mu]"}]], "-", 
              FractionBox[
               RowBox[{"2", " ", "pe"}], 
               RowBox[{"9", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", "\[Lambda]"}], "+", 
                  RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
              FractionBox[
               RowBox[{"2", " ", "pi"}], 
               RowBox[{"9", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", "\[Lambda]"}], "+", 
                  RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ")"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"5", " ", "pe"}], 
                 RowBox[{"24", " ", "\[Mu]"}]]}], "+", 
               FractionBox[
                RowBox[{"5", " ", "pi"}], 
                RowBox[{"24", " ", "\[Mu]"}]]}], ")"}], " ", "delta"}], "+", 
            InterpretationBox[
             SuperscriptBox[
              RowBox[{"O", "[", "delta", "]"}], "2"],
             SeriesData[delta, 0, {}, 0, 2, 1],
             Editable->False]}],
           SeriesData[
           delta, 0, {
            Rational[5, 72] pe/\[Mu] + Rational[-5, 72] pi/\[Mu] + 
             Rational[-2, 9] pe/(3 \[Lambda] + 2 \[Mu]) + 
             Rational[2, 9] pi/(3 \[Lambda] + 2 \[Mu]), 
             Rational[-5, 24] pe/\[Mu] + Rational[5, 24] pi/\[Mu]}, 0, 2, 1],
           Editable->False], ")"}], " ", "eta"}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", "eta", "]"}], "2"],
         SeriesData[eta, 0, {}, -1, 2, 1],
         Editable->False]}],
       SeriesData[eta, 0, {
         SeriesData[
         delta, 0, {
          Rational[-1, 12] pe/\[Mu] + Rational[1, 12] pi/\[Mu] + 
           Rational[-1, 3] pe/(3 \[Lambda] + 2 \[Mu]) + 
           Rational[1, 3] pi/(3 \[Lambda] + 2 \[Mu]), Rational[1, 4] pe/\[Mu] + 
           Rational[-1, 4] pi/\[Mu]}, 0, 2, 1], 
         Rational[-1, 2] pe/(3 \[Lambda] + 2 \[Mu]) + 
         Rational[-1, 2] pi/(3 \[Lambda] + 2 \[Mu]), 
         SeriesData[
         delta, 0, {
          Rational[5, 72] pe/\[Mu] + Rational[-5, 72] pi/\[Mu] + 
           Rational[-2, 9] pe/(3 \[Lambda] + 2 \[Mu]) + 
           Rational[2, 9] pi/(3 \[Lambda] + 2 \[Mu]), 
           Rational[-5, 24] pe/\[Mu] + Rational[5, 24] pi/\[Mu]}, 0, 2, 
          1]}, -1, 2, 1],
       Editable->False]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"12", " ", "eta", " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"3", " ", "delta"}]}], ")"}]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "6"}], "+", 
              RowBox[{"5", " ", 
               SuperscriptBox["eta", "2"]}]}], ")"}], " ", "\[Lambda]"}], "+",
            
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "eta"}], ")"}], " ", "eta"}], "+", 
              RowBox[{"delta", " ", 
               RowBox[{"(", 
                RowBox[{"6", "-", 
                 RowBox[{"5", " ", 
                  SuperscriptBox["eta", "2"]}]}], ")"}]}]}], ")"}], " ", 
            "\[Mu]"}]}], ")"}]}], "+", 
        RowBox[{"pe", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"3", " ", "delta"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "6"}], "+", 
              RowBox[{"5", " ", 
               SuperscriptBox["eta", "2"]}]}], ")"}], " ", "\[Lambda]"}], "+",
            
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", "eta", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "eta"}], ")"}]}], "+", 
              RowBox[{"delta", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "6"}], "+", 
                 RowBox[{"5", " ", 
                  SuperscriptBox["eta", "2"]}]}], ")"}]}]}], ")"}], " ", 
            "\[Mu]"}]}], ")"}]}]}], ")"}]}], ",", "0", ",", "0"}], "}"}], ",",
    
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"24", " ", "eta", " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"3", " ", "delta"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "6"}], "+", 
              RowBox[{"5", " ", 
               SuperscriptBox["eta", "2"]}]}], ")"}], " ", "\[Lambda]"}], "+",
            
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"6", "-", 
              RowBox[{"6", " ", "delta"}], "-", 
              RowBox[{"6", " ", "eta"}], "+", 
              SuperscriptBox["eta", "2"], "+", 
              RowBox[{"5", " ", "delta", " ", 
               SuperscriptBox["eta", "2"]}]}], ")"}], " ", "\[Mu]"}]}], 
          ")"}]}], "-", 
        RowBox[{"pe", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"3", " ", "delta"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "6"}], "+", 
              RowBox[{"5", " ", 
               SuperscriptBox["eta", "2"]}]}], ")"}], " ", "\[Lambda]"}], "+",
            
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"6", "-", 
              RowBox[{"6", " ", "delta"}], "+", 
              RowBox[{"6", " ", "eta"}], "+", 
              SuperscriptBox["eta", "2"], "+", 
              RowBox[{"5", " ", "delta", " ", 
               SuperscriptBox["eta", "2"]}]}], ")"}], " ", "\[Mu]"}]}], 
          ")"}]}]}], ")"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"24", " ", "eta", " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"3", " ", "delta"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "6"}], "+", 
              RowBox[{"5", " ", 
               SuperscriptBox["eta", "2"]}]}], ")"}], " ", "\[Lambda]"}], "+",
            
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"6", "-", 
              RowBox[{"6", " ", "delta"}], "-", 
              RowBox[{"6", " ", "eta"}], "+", 
              SuperscriptBox["eta", "2"], "+", 
              RowBox[{"5", " ", "delta", " ", 
               SuperscriptBox["eta", "2"]}]}], ")"}], " ", "\[Mu]"}]}], 
          ")"}]}], "-", 
        RowBox[{"pe", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"3", " ", "delta"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "6"}], "+", 
              RowBox[{"5", " ", 
               SuperscriptBox["eta", "2"]}]}], ")"}], " ", "\[Lambda]"}], "+",
            
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"6", "-", 
              RowBox[{"6", " ", "delta"}], "+", 
              RowBox[{"6", " ", "eta"}], "+", 
              SuperscriptBox["eta", "2"], "+", 
              RowBox[{"5", " ", "delta", " ", 
               SuperscriptBox["eta", "2"]}]}], ")"}], " ", "\[Mu]"}]}], 
          ")"}]}]}], ")"}]}]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "6"}], " ", "pe", " ", "\[Mu]"}], "-", 
         RowBox[{"6", " ", "pi", " ", "\[Mu]"}]}], 
        RowBox[{"12", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"6", " ", "pe", " ", "\[Lambda]"}], "-", 
         RowBox[{"18", " ", "delta", " ", "pe", " ", "\[Lambda]"}], "-", 
         RowBox[{"6", " ", "pi", " ", "\[Lambda]"}], "+", 
         RowBox[{"18", " ", "delta", " ", "pi", " ", "\[Lambda]"}], "-", 
         RowBox[{"12", " ", "delta", " ", "pe", " ", "\[Mu]"}], "+", 
         RowBox[{"12", " ", "delta", " ", "pi", " ", "\[Mu]"}]}], 
        RowBox[{"12", " ", "eta", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], "0", "0"},
     {"0", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", "pe", " ", "\[Mu]"}], "-", 
         RowBox[{"12", " ", "pi", " ", "\[Mu]"}]}], 
        RowBox[{"24", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "6"}], " ", "pe", " ", "\[Lambda]"}], "+", 
         RowBox[{"18", " ", "delta", " ", "pe", " ", "\[Lambda]"}], "+", 
         RowBox[{"6", " ", "pi", " ", "\[Lambda]"}], "-", 
         RowBox[{"18", " ", "delta", " ", "pi", " ", "\[Lambda]"}], "-", 
         RowBox[{"12", " ", "pe", " ", "\[Mu]"}], "+", 
         RowBox[{"12", " ", "delta", " ", "pe", " ", "\[Mu]"}], "+", 
         RowBox[{"12", " ", "pi", " ", "\[Mu]"}], "-", 
         RowBox[{"12", " ", "delta", " ", "pi", " ", "\[Mu]"}]}], 
        RowBox[{"24", " ", "eta", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], "0"},
     {"0", "0", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", "pe", " ", "\[Mu]"}], "-", 
         RowBox[{"12", " ", "pi", " ", "\[Mu]"}]}], 
        RowBox[{"24", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "6"}], " ", "pe", " ", "\[Lambda]"}], "+", 
         RowBox[{"18", " ", "delta", " ", "pe", " ", "\[Lambda]"}], "+", 
         RowBox[{"6", " ", "pi", " ", "\[Lambda]"}], "-", 
         RowBox[{"18", " ", "delta", " ", "pi", " ", "\[Lambda]"}], "-", 
         RowBox[{"12", " ", "pe", " ", "\[Mu]"}], "+", 
         RowBox[{"12", " ", "delta", " ", "pe", " ", "\[Mu]"}], "+", 
         RowBox[{"12", " ", "pi", " ", "\[Mu]"}], "-", 
         RowBox[{"12", " ", "delta", " ", "pi", " ", "\[Mu]"}]}], 
        RowBox[{"24", " ", "eta", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"3", " ", "pe", " ", "r", " ", "\[Lambda]"}], "-", 
        RowBox[{"3", " ", "pi", " ", "r", " ", "\[Lambda]"}], "-", 
        RowBox[{"4", " ", "pe", " ", "R", " ", "\[Lambda]"}], "+", 
        RowBox[{"4", " ", "pi", " ", "R", " ", "\[Lambda]"}], "+", 
        RowBox[{"ee", " ", "pe", " ", "\[Mu]"}], "+", 
        RowBox[{"ee", " ", "pi", " ", "\[Mu]"}], "+", 
        RowBox[{"2", " ", "pe", " ", "r", " ", "\[Mu]"}], "-", 
        RowBox[{"2", " ", "pi", " ", "r", " ", "\[Mu]"}], "-", 
        RowBox[{"2", " ", "pe", " ", "R", " ", "\[Mu]"}], "+", 
        RowBox[{"2", " ", "pi", " ", "R", " ", "\[Mu]"}]}], 
       RowBox[{
        RowBox[{
         RowBox[{"-", "6"}], " ", "ee", " ", "\[Lambda]", " ", "\[Mu]"}], "-",
         
        RowBox[{"4", " ", "ee", " ", 
         SuperscriptBox["\[Mu]", "2"]}]}]], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "ee", " ", "\[Mu]"}], "+", 
           RowBox[{"4", " ", "R", " ", 
            RowBox[{"(", 
             RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}], "-", 
           RowBox[{"r", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"pe", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"r", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"ee", " ", "\[Mu]"}], "+", 
              RowBox[{"2", " ", "R", " ", 
               RowBox[{"(", 
                RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}], 
       RowBox[{"4", " ", "ee", " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "ee", " ", "\[Mu]"}], "+", 
           RowBox[{"4", " ", "R", " ", 
            RowBox[{"(", 
             RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}], "-", 
           RowBox[{"r", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"pe", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"r", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"ee", " ", "\[Mu]"}], "+", 
              RowBox[{"2", " ", "R", " ", 
               RowBox[{"(", 
                RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}], 
       RowBox[{"4", " ", "ee", " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Series", "[", "  ", 
  RowBox[{
   RowBox[{"sigf", " ", "/.", " ", "r2eta"}], "  ", ",", "  ", 
   RowBox[{"{", 
    RowBox[{"eta", ",", "  ", "0", ",", " ", "1"}], "}"}], ",", "  ", 
   RowBox[{"{", 
    RowBox[{"delta", ",", " ", "0", ",", "1"}], "}"}]}], " ", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Expand", "[", " ", 
  RowBox[{"Normal", "[", "%", "]"}], " ", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"ssig", " ", "=", " ", 
    RowBox[{"Normal", "[", 
     RowBox[{"Series", "[", 
      RowBox[{"%", ",", " ", 
       RowBox[{"{", 
        RowBox[{"eta", ",", " ", "0", ",", " ", "0"}], "}"}]}], "]"}], 
     "]"}]}], ")"}], " ", "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"rsig", " ", "=", " ", 
     RowBox[{"Simplify", "[", " ", 
      RowBox[{"ssig", " ", "/.", " ", "delta2r"}], " ", "]"}]}], " ", ")"}], "//",
    " ", "MatrixForm"}], " "}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      InterpretationBox[
       RowBox[{
        FractionBox[
         InterpretationBox[
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "pe"}], "+", "pi"}], ")"}], " ", "delta"}], "+", 
           InterpretationBox[
            SuperscriptBox[
             RowBox[{"O", "[", "delta", "]"}], "2"],
            SeriesData[delta, 0, {}, 1, 2, 1],
            Editable->False]}],
          SeriesData[delta, 0, {-pe + pi}, 1, 2, 1],
          Editable->False], "eta"], "+", 
        RowBox[{"(", 
         InterpretationBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["pe", "2"]}], "-", 
             FractionBox["pi", "2"]}], ")"}], "+", 
           InterpretationBox[
            SuperscriptBox[
             RowBox[{"O", "[", "delta", "]"}], "2"],
            SeriesData[delta, 0, {}, 0, 2, 1],
            Editable->False]}],
          SeriesData[
          delta, 0, {Rational[-1, 2] pe + Rational[-1, 2] pi}, 0, 2, 1],
          Editable->False], ")"}], "+", 
        RowBox[{
         RowBox[{"(", 
          InterpretationBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["pe", "2"]}], "+", 
              FractionBox["pi", "2"]}], ")"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               FractionBox[
                RowBox[{"5", " ", "pe"}], "6"], "-", 
               FractionBox[
                RowBox[{"5", " ", "pi"}], "6"]}], ")"}], " ", "delta"}], "+", 
            
            InterpretationBox[
             SuperscriptBox[
              RowBox[{"O", "[", "delta", "]"}], "2"],
             SeriesData[delta, 0, {}, 0, 2, 1],
             Editable->False]}],
           SeriesData[
           delta, 0, {
            Rational[-1, 2] pe + Rational[1, 2] pi, Rational[5, 6] pe + 
             Rational[-5, 6] pi}, 0, 2, 1],
           Editable->False], ")"}], " ", "eta"}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", "eta", "]"}], "2"],
         SeriesData[eta, 0, {}, -1, 2, 1],
         Editable->False]}],
       SeriesData[eta, 0, {
         SeriesData[delta, 0, {-pe + pi}, 1, 2, 1], 
         SeriesData[
         delta, 0, {Rational[-1, 2] pe + Rational[-1, 2] pi}, 0, 2, 1], 
         SeriesData[
         delta, 0, {
          Rational[-1, 2] pe + Rational[1, 2] pi, Rational[5, 6] pe + 
           Rational[-5, 6] pi}, 0, 2, 1]}, -1, 2, 1],
       Editable->False], "0", "0"},
     {"0", 
      InterpretationBox[
       RowBox[{
        FractionBox[
         InterpretationBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["pe", "2"]}], "+", 
             FractionBox["pi", "2"]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              FractionBox["pe", "2"], "-", 
              FractionBox["pi", "2"]}], ")"}], " ", "delta"}], "+", 
           InterpretationBox[
            SuperscriptBox[
             RowBox[{"O", "[", "delta", "]"}], "2"],
            SeriesData[delta, 0, {}, 0, 2, 1],
            Editable->False]}],
          SeriesData[
          delta, 0, {
           Rational[-1, 2] pe + Rational[1, 2] pi, Rational[1, 2] pe + 
            Rational[-1, 2] pi}, 0, 2, 1],
          Editable->False], "eta"], "+", 
        RowBox[{"(", 
         InterpretationBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["pe", "2"]}], "-", 
             FractionBox["pi", "2"]}], ")"}], "+", 
           InterpretationBox[
            SuperscriptBox[
             RowBox[{"O", "[", "delta", "]"}], "2"],
            SeriesData[delta, 0, {}, 0, 2, 1],
            Editable->False]}],
          SeriesData[
          delta, 0, {Rational[-1, 2] pe + Rational[-1, 2] pi}, 0, 2, 1],
          Editable->False], ")"}], "+", 
        RowBox[{
         RowBox[{"(", 
          InterpretationBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["pe", "12"]}], "+", 
              FractionBox["pi", "12"]}], ")"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"5", " ", "pe"}], "12"]}], "+", 
               FractionBox[
                RowBox[{"5", " ", "pi"}], "12"]}], ")"}], " ", "delta"}], "+",
             
            InterpretationBox[
             SuperscriptBox[
              RowBox[{"O", "[", "delta", "]"}], "2"],
             SeriesData[delta, 0, {}, 0, 2, 1],
             Editable->False]}],
           SeriesData[
           delta, 0, {
            Rational[-1, 12] pe + Rational[1, 12] pi, Rational[-5, 12] pe + 
             Rational[5, 12] pi}, 0, 2, 1],
           Editable->False], ")"}], " ", "eta"}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", "eta", "]"}], "2"],
         SeriesData[eta, 0, {}, -1, 2, 1],
         Editable->False]}],
       SeriesData[eta, 0, {
         SeriesData[
         delta, 0, {
          Rational[-1, 2] pe + Rational[1, 2] pi, Rational[1, 2] pe + 
           Rational[-1, 2] pi}, 0, 2, 1], 
         SeriesData[
         delta, 0, {Rational[-1, 2] pe + Rational[-1, 2] pi}, 0, 2, 1], 
         SeriesData[
         delta, 0, {
          Rational[-1, 12] pe + Rational[1, 12] pi, Rational[-5, 12] pe + 
           Rational[5, 12] pi}, 0, 2, 1]}, -1, 2, 1],
       Editable->False], "0"},
     {"0", "0", 
      InterpretationBox[
       RowBox[{
        FractionBox[
         InterpretationBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["pe", "2"]}], "+", 
             FractionBox["pi", "2"]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              FractionBox["pe", "2"], "-", 
              FractionBox["pi", "2"]}], ")"}], " ", "delta"}], "+", 
           InterpretationBox[
            SuperscriptBox[
             RowBox[{"O", "[", "delta", "]"}], "2"],
            SeriesData[delta, 0, {}, 0, 2, 1],
            Editable->False]}],
          SeriesData[
          delta, 0, {
           Rational[-1, 2] pe + Rational[1, 2] pi, Rational[1, 2] pe + 
            Rational[-1, 2] pi}, 0, 2, 1],
          Editable->False], "eta"], "+", 
        RowBox[{"(", 
         InterpretationBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["pe", "2"]}], "-", 
             FractionBox["pi", "2"]}], ")"}], "+", 
           InterpretationBox[
            SuperscriptBox[
             RowBox[{"O", "[", "delta", "]"}], "2"],
            SeriesData[delta, 0, {}, 0, 2, 1],
            Editable->False]}],
          SeriesData[
          delta, 0, {Rational[-1, 2] pe + Rational[-1, 2] pi}, 0, 2, 1],
          Editable->False], ")"}], "+", 
        RowBox[{
         RowBox[{"(", 
          InterpretationBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["pe", "12"]}], "+", 
              FractionBox["pi", "12"]}], ")"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"5", " ", "pe"}], "12"]}], "+", 
               FractionBox[
                RowBox[{"5", " ", "pi"}], "12"]}], ")"}], " ", "delta"}], "+",
             
            InterpretationBox[
             SuperscriptBox[
              RowBox[{"O", "[", "delta", "]"}], "2"],
             SeriesData[delta, 0, {}, 0, 2, 1],
             Editable->False]}],
           SeriesData[
           delta, 0, {
            Rational[-1, 12] pe + Rational[1, 12] pi, Rational[-5, 12] pe + 
             Rational[5, 12] pi}, 0, 2, 1],
           Editable->False], ")"}], " ", "eta"}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", "eta", "]"}], "2"],
         SeriesData[eta, 0, {}, -1, 2, 1],
         Editable->False]}],
       SeriesData[eta, 0, {
         SeriesData[
         delta, 0, {
          Rational[-1, 2] pe + Rational[1, 2] pi, Rational[1, 2] pe + 
           Rational[-1, 2] pi}, 0, 2, 1], 
         SeriesData[
         delta, 0, {Rational[-1, 2] pe + Rational[-1, 2] pi}, 0, 2, 1], 
         SeriesData[
         delta, 0, {
          Rational[-1, 12] pe + Rational[1, 12] pi, Rational[-5, 12] pe + 
           Rational[5, 12] pi}, 0, 2, 1]}, -1, 2, 1],
       Editable->False]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["pe", "2"]}], "-", 
      FractionBox[
       RowBox[{"delta", " ", "pe"}], "eta"], "-", 
      FractionBox[
       RowBox[{"eta", " ", "pe"}], "2"], "+", 
      FractionBox[
       RowBox[{"5", " ", "delta", " ", "eta", " ", "pe"}], "6"], "-", 
      FractionBox["pi", "2"], "+", 
      FractionBox[
       RowBox[{"delta", " ", "pi"}], "eta"], "+", 
      FractionBox[
       RowBox[{"eta", " ", "pi"}], "2"], "-", 
      FractionBox[
       RowBox[{"5", " ", "delta", " ", "eta", " ", "pi"}], "6"]}], ",", "0", 
     ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["pe", "2"]}], "-", 
      FractionBox["pe", 
       RowBox[{"2", " ", "eta"}]], "+", 
      FractionBox[
       RowBox[{"delta", " ", "pe"}], 
       RowBox[{"2", " ", "eta"}]], "-", 
      FractionBox[
       RowBox[{"eta", " ", "pe"}], "12"], "-", 
      FractionBox[
       RowBox[{"5", " ", "delta", " ", "eta", " ", "pe"}], "12"], "-", 
      FractionBox["pi", "2"], "+", 
      FractionBox["pi", 
       RowBox[{"2", " ", "eta"}]], "-", 
      FractionBox[
       RowBox[{"delta", " ", "pi"}], 
       RowBox[{"2", " ", "eta"}]], "+", 
      FractionBox[
       RowBox[{"eta", " ", "pi"}], "12"], "+", 
      FractionBox[
       RowBox[{"5", " ", "delta", " ", "eta", " ", "pi"}], "12"]}], ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["pe", "2"]}], "-", 
      FractionBox["pe", 
       RowBox[{"2", " ", "eta"}]], "+", 
      FractionBox[
       RowBox[{"delta", " ", "pe"}], 
       RowBox[{"2", " ", "eta"}]], "-", 
      FractionBox[
       RowBox[{"eta", " ", "pe"}], "12"], "-", 
      FractionBox[
       RowBox[{"5", " ", "delta", " ", "eta", " ", "pe"}], "12"], "-", 
      FractionBox["pi", "2"], "+", 
      FractionBox["pi", 
       RowBox[{"2", " ", "eta"}]], "-", 
      FractionBox[
       RowBox[{"delta", " ", "pi"}], 
       RowBox[{"2", " ", "eta"}]], "+", 
      FractionBox[
       RowBox[{"eta", " ", "pi"}], "12"], "+", 
      FractionBox[
       RowBox[{"5", " ", "delta", " ", "eta", " ", "pi"}], "12"]}]}], "}"}]}],
   "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox["pe", "2"]}], "-", 
       FractionBox["pi", "2"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "delta"}], " ", "pe"}], "+", 
         RowBox[{"delta", " ", "pi"}]}], "eta"]}], "0", "0"},
     {"0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["pe", "2"]}], "-", 
       FractionBox["pi", "2"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["pe", "2"]}], "+", 
         FractionBox[
          RowBox[{"delta", " ", "pe"}], "2"], "+", 
         FractionBox["pi", "2"], "-", 
         FractionBox[
          RowBox[{"delta", " ", "pi"}], "2"]}], "eta"]}], "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["pe", "2"]}], "-", 
       FractionBox["pi", "2"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["pe", "2"]}], "+", 
         FractionBox[
          RowBox[{"delta", " ", "pe"}], "2"], "+", 
         FractionBox["pi", "2"], "-", 
         FractionBox[
          RowBox[{"delta", " ", "pi"}], "2"]}], "eta"]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"ee", " ", 
          RowBox[{"(", 
           RowBox[{"pe", "+", "pi"}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"pe", "-", "pi"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"r", "-", "R"}], ")"}]}]}], 
        RowBox[{"2", " ", "ee"}]]}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "ee"}], " ", 
         RowBox[{"(", 
          RowBox[{"pe", "+", "pi"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"pe", "-", "pi"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", "R"}]}], ")"}]}]}], 
       RowBox[{"2", " ", "ee"}]], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "ee"}], " ", 
         RowBox[{"(", 
          RowBox[{"pe", "+", "pi"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"pe", "-", "pi"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", "R"}]}], ")"}]}]}], 
       RowBox[{"2", " ", "ee"}]]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", " ", 
  RowBox[{
   RowBox[{"Strain", "[", " ", "ruf", " ", "]"}], " ", "-", " ", "reps"}], 
  " ", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", " ", 
  RowBox[{
   RowBox[{"%", " ", "/.", " ", "r2eta"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"delta", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"pe", "-", "pi"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", "R"}], ")"}]}], 
      RowBox[{"2", " ", "ee", " ", "\[Mu]"}]], ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"pe", "-", "pi"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"r", "-", "R"}], ")"}], "2"]}], 
       RowBox[{"4", " ", "ee", " ", "r", " ", "\[Mu]"}]]}], ",", "0"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"pe", "-", "pi"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"r", "-", "R"}], ")"}], "2"]}], 
       RowBox[{"4", " ", "ee", " ", "r", " ", "\[Mu]"}]]}]}], "}"}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"pe", "-", "pi"}], ")"}], " ", "R", " ", "delta"}], 
        RowBox[{"2", " ", "ee", " ", "\[Mu]"}]], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", "delta", "]"}], "2"],
        SeriesData[delta, 0, {}, 1, 2, 1],
        Editable->False]}],
      SeriesData[
      delta, 0, {Rational[1, 2] ee^(-1) (pe - pi) R/\[Mu]}, 1, 2, 1],
      Editable->False], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "delta", "]"}], "2"],
      SeriesData[delta, 0, {}, 2, 2, 1],
      Editable->False], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "delta", "]"}], "2"],
      SeriesData[delta, 0, {}, 2, 2, 1],
      Editable->False]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{
   RowBox[{"\[Lambda]", " ", 
    RowBox[{"Tr", "[", "reps", "]"}], " ", 
    RowBox[{"IdentityMatrix", "[", "3", "]"}]}], " ", "+", " ", 
   RowBox[{"2", " ", "\[Mu]", " ", "reps"}], " ", "-", " ", "rsig"}], "  ", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"Div", "[", " ", "rsig", " ", "]"}], " ", "]"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", " ", 
  RowBox[{
   RowBox[{"%", " ", "/.", " ", "r2eta"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"delta", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"pe", "-", "pi"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"r", "-", "R"}], ")"}]}], 
     RowBox[{"ee", " ", "r"}]]}], ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", "pe"}], "ee"]}], "+", 
        FractionBox[
         RowBox[{"4", " ", "pi"}], "ee"]}], ")"}], " ", "delta"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "delta", "]"}], "2"],
      SeriesData[delta, 0, {}, 1, 2, 1],
      Editable->False]}],
    SeriesData[delta, 0, {(-4) ee^(-1) pe + 4 ee^(-1) pi}, 1, 2, 1],
    Editable->False], ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1137, 821},
WindowMargins->{{Automatic, 11}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3356455612-8622876"->{
  Cell[12280, 390, 65, 1, 23, "Print",
   CellTags->"Info3356455612-8622876"],
  Cell[12348, 393, 951, 27, 23, "Print",
   CellTags->"Info3356455612-8622876"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3356455612-8622876", 432097, 11847}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 65, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[1421, 43, 291, 8, 55, "Input"],
Cell[1715, 53, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1802, 56, 150, 2, 77, "Input"],
Cell[CellGroupData[{
Cell[1977, 62, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2089, 67, 137, 3, 32, "Input"],
Cell[2229, 72, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2362, 79, 132, 3, 32, "Input"],
Cell[2497, 84, 335, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2869, 99, 3860, 112, 187, "Input"],
Cell[6732, 213, 779, 26, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7548, 244, 1043, 30, 99, "Input"],
Cell[8594, 276, 784, 20, 75, "Output"],
Cell[9381, 298, 2333, 67, 212, "Output"],
Cell[11717, 367, 454, 13, 136, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12208, 385, 47, 1, 27, "Input"],
Cell[CellGroupData[{
Cell[12280, 390, 65, 1, 23, "Print",
 CellTags->"Info3356455612-8622876"],
Cell[12348, 393, 951, 27, 23, "Print",
 CellTags->"Info3356455612-8622876"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13360, 427, 124, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[13509, 433, 350, 11, 27, "Input"],
Cell[13862, 446, 777, 29, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14676, 480, 287, 8, 27, "Input"],
Cell[14966, 490, 743, 26, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15746, 521, 252, 7, 27, "Input"],
Cell[16001, 530, 271, 9, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16309, 544, 247, 7, 27, "Input"],
Cell[16559, 553, 417, 13, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17013, 571, 514, 14, 27, "Input"],
Cell[17530, 587, 586, 21, 73, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18165, 614, 121, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[18311, 620, 956, 27, 59, "Input"],
Cell[19270, 649, 383, 7, 20, "Message"],
Cell[19656, 658, 442, 15, 92, "Output"],
Cell[20101, 675, 386, 8, 20, "Message"],
Cell[20490, 685, 3141, 96, 234, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23668, 786, 222, 6, 27, "Input"],
Cell[23893, 794, 2384, 61, 112, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26314, 860, 490, 15, 43, "Input"],
Cell[26807, 877, 39991, 1082, 1664, "Output"]
}, Open  ]],
Cell[66813, 1962, 45, 0, 43, "Input"]
}, Open  ]],
Cell[66873, 1965, 87, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[66985, 1970, 141, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[67151, 1976, 176, 5, 27, "Input"],
Cell[67330, 1983, 2297, 71, 77, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69664, 2059, 527, 14, 43, "Input"],
Cell[70194, 2075, 10377, 286, 305, "Output"],
Cell[80574, 2363, 37080, 953, 653, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[117703, 3322, 114, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[117842, 3327, 117, 3, 27, "Input"],
Cell[117962, 3332, 83, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118082, 3339, 495, 14, 43, "Input"],
Cell[118580, 3355, 391, 8, 20, "Message"],
Cell[118974, 3365, 102, 3, 27, "Output"],
Cell[119079, 3370, 13325, 354, 1158, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[132441, 3729, 469, 13, 43, "Input"],
Cell[132913, 3744, 83, 2, 27, "Output"],
Cell[132999, 3748, 13319, 353, 1158, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[146355, 4106, 504, 15, 27, "Input"],
Cell[146862, 4123, 101203, 2598, 7252, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[248102, 6726, 541, 14, 59, "Input"],
Cell[248646, 6742, 13373, 375, 631, "Output"],
Cell[262022, 7119, 386, 8, 20, "Message"],
Cell[262411, 7129, 46541, 1239, 444, "Output"],
Cell[308955, 8370, 386, 8, 20, "Message"],
Cell[309344, 8380, 44335, 1182, 414, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[353728, 9568, 116, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[353869, 9573, 228, 5, 27, "Input"],
Cell[354100, 9580, 228, 8, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[354365, 9593, 618, 16, 43, "Input"],
Cell[354986, 9611, 2162, 68, 101, "Output"],
Cell[357151, 9681, 1967, 62, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[359155, 9748, 461, 12, 43, "Input"],
Cell[359619, 9762, 3626, 106, 101, "Output"],
Cell[363248, 9870, 2885, 89, 95, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[366182, 9965, 140, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[366347, 9971, 1034, 28, 59, "Input"],
Cell[367384, 10001, 469, 16, 43, "Output"],
Cell[367856, 10019, 233, 8, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[368126, 10032, 1019, 27, 75, "Input"],
Cell[369148, 10061, 7994, 213, 133, "Output"],
Cell[377145, 10276, 2341, 68, 72, "Output"],
Cell[379489, 10346, 1823, 45, 73, "Output"],
Cell[381315, 10393, 1274, 28, 75, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[382626, 10426, 1015, 27, 91, "Input"],
Cell[383644, 10455, 15171, 392, 125, "Output"],
Cell[398818, 10849, 6324, 184, 200, "Output"],
Cell[405145, 11035, 3538, 86, 106, "Output"],
Cell[408686, 11123, 3627, 98, 106, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[412350, 11226, 1001, 26, 91, "Input"],
Cell[413354, 11254, 8917, 253, 120, "Output"],
Cell[422274, 11509, 2318, 71, 116, "Output"],
Cell[424595, 11582, 1295, 43, 118, "Output"],
Cell[425893, 11627, 1360, 46, 100, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[427290, 11678, 363, 9, 43, "Input"],
Cell[427656, 11689, 1038, 36, 48, "Output"],
Cell[428697, 11727, 1071, 33, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[429805, 11765, 291, 7, 27, "Input"],
Cell[430099, 11774, 260, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[430396, 11787, 343, 9, 43, "Input"],
Cell[430742, 11798, 300, 10, 44, "Output"],
Cell[431045, 11810, 604, 19, 44, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

