(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     47455,       1595]
NotebookOptionsPosition[     43884,       1473]
NotebookOutlinePosition[     44220,       1488]
CellTagsIndexPosition[     44177,       1485]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["Sphere under pressure ", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "Displacement.m"}], "\[IndentingNewLine]"}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Spherical", "[", 
  RowBox[{"r", ",", "t", ",", "p"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "t", ",", "p"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The general solution in cylindrical coordinate \
system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"u", "[", 
   RowBox[{"r_", ",", "t_", ",", "p_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ur", "[", "r", "]"}], ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"Strain", "[", " ", 
     RowBox[{"u", " ", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}]}], " ", ")"}], " ", "//",
   "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"Tr", "[", "eps", " ", "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", " ", "]"}]}], "+", " ", 
     RowBox[{"2", " ", "\[Mu]", " ", "eps"}]}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["ur", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"ur", "[", "r", "]"}], "r"], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{"ur", "[", "r", "]"}], "r"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{
         SuperscriptBox["ur", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
          RowBox[{
           SuperscriptBox["ur", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}], "0", 
      "0"},
     {"0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
          RowBox[{
           SuperscriptBox["ur", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}], "0"},
     {"0", "0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
          RowBox[{
           SuperscriptBox["ur", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"divsig", " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Div", "[", " ", "sig", " ", "]"}], "]"}]}], " ", ")"}], " ", "//",
   " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{"ur", "[", "r", "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{
               SuperscriptBox["ur", "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{
               SuperscriptBox["ur", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
         ")"}]}], 
       SuperscriptBox["r", "2"]]},
     {"0"},
     {"0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   r^(-2) (\[Lambda] + 2 \[Mu]) ((-2) ur[r] + 
     r (2 Derivative[1][ur][r] + r Derivative[2][ur][r])), 0, 0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solur", " ", "=", " ", 
   RowBox[{
    RowBox[{"DSolve", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"divsig", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", "\[Equal]", " ", "0"}], ",", " ",
       "ur", ",", " ", "r"}], " ", "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"ur", "\[Rule]", 
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", "r", "}"}], ",", 
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{"C", "[", "1", "]"}]}], "+", 
     FractionBox[
      RowBox[{"C", "[", "2", "]"}], 
      SuperscriptBox["r", "2"]]}]}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Simplify", "[", " ", 
    RowBox[{
     RowBox[{"divsig", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", "/", " ", 
     RowBox[{"(", 
      RowBox[{"\[Lambda]", "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"exp", " ", "=", " ", 
    RowBox[{"D", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"r", "^", "2"}]}], " ", 
       RowBox[{"D", "[", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"r", "^", "2"}], " ", 
          RowBox[{"ur", "[", "r", "]"}]}], ",", " ", "r"}], " ", "]"}]}], ",",
       " ", "r"}], " ", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", " ", "exp", " ", "]"}]}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"ur", "[", "r", "]"}]}], 
    SuperscriptBox["r", "2"]]}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox["ur", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
  RowBox[{
   SuperscriptBox["ur", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "r", "]"}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(exp\\)\\\" is similar to existing symbol \\\"\\!\\(Exp\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "r", " ", 
        RowBox[{"ur", "[", "r", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{
         SuperscriptBox["ur", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
    SuperscriptBox["r", "3"]]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"ur", "[", "r", "]"}]}], "+", 
    RowBox[{"4", " ", "r", " ", 
     RowBox[{
      SuperscriptBox["ur", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     RowBox[{
      SuperscriptBox["ur", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}]}], 
   SuperscriptBox["r", "2"]]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"ur", "[", "r", "]"}]}], 
    SuperscriptBox["r", "2"]]}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox["ur", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
  RowBox[{
   SuperscriptBox["ur", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "r", "]"}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The spherical thick shell under internal and external \
pressure: pi and pe",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", " ", "=", " ", 
  RowBox[{
   RowBox[{"u", " ", "[", 
    RowBox[{"r", ",", "t", ",", "p"}], "]"}], " ", "/.", " ", "solur", 
   " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"C", "[", "1", "]"}]}], "+", 
    FractionBox[
     RowBox[{"C", "[", "2", "]"}], 
     SuperscriptBox["r", "2"]]}], ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"Strain", "[", " ", "uu", " ", "]"}]}], " ", ")"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"Tr", "[", "eps", " ", "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", " ", "]"}]}], "+", " ", 
     RowBox[{"2", " ", "\[Mu]", " ", "eps"}]}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"C", "[", "1", "]"}]}], "-", 
         FractionBox[
          RowBox[{"4", " ", 
           RowBox[{"C", "[", "2", "]"}]}], 
          SuperscriptBox["r", "3"]]}], ")"}]}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{"r", " ", 
         RowBox[{"C", "[", "1", "]"}]}], "+", 
        FractionBox[
         RowBox[{"C", "[", "2", "]"}], 
         SuperscriptBox["r", "2"]]}], "r"], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{"r", " ", 
         RowBox[{"C", "[", "1", "]"}]}], "+", 
        FractionBox[
         RowBox[{"C", "[", "2", "]"}], 
         SuperscriptBox["r", "2"]]}], "r"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          FractionBox[
           RowBox[{"4", " ", 
            RowBox[{"C", "[", "2", "]"}]}], 
           SuperscriptBox["r", "3"]]}], ")"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"C", "[", "1", "]"}]}], "-", 
             FractionBox[
              RowBox[{"4", " ", 
               RowBox[{"C", "[", "2", "]"}]}], 
              SuperscriptBox["r", "3"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"r", " ", 
               RowBox[{"C", "[", "1", "]"}]}], "+", 
              FractionBox[
               RowBox[{"C", "[", "2", "]"}], 
               SuperscriptBox["r", "2"]]}], ")"}]}], "r"]}], ")"}]}]}], "0", 
      "0"},
     {"0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"r", " ", 
            RowBox[{"C", "[", "1", "]"}]}], "+", 
           FractionBox[
            RowBox[{"C", "[", "2", "]"}], 
            SuperscriptBox["r", "2"]]}], ")"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"C", "[", "1", "]"}]}], "-", 
             FractionBox[
              RowBox[{"4", " ", 
               RowBox[{"C", "[", "2", "]"}]}], 
              SuperscriptBox["r", "3"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"r", " ", 
               RowBox[{"C", "[", "1", "]"}]}], "+", 
              FractionBox[
               RowBox[{"C", "[", "2", "]"}], 
               SuperscriptBox["r", "2"]]}], ")"}]}], "r"]}], ")"}]}]}], "0"},
     {"0", "0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"r", " ", 
            RowBox[{"C", "[", "1", "]"}]}], "+", 
           FractionBox[
            RowBox[{"C", "[", "2", "]"}], 
            SuperscriptBox["r", "2"]]}], ")"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"C", "[", "1", "]"}]}], "-", 
             FractionBox[
              RowBox[{"4", " ", 
               RowBox[{"C", "[", "2", "]"}]}], 
              SuperscriptBox["r", "3"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"r", " ", 
               RowBox[{"C", "[", "1", "]"}]}], "+", 
              FractionBox[
               RowBox[{"C", "[", "2", "]"}], 
               SuperscriptBox["r", "2"]]}], ")"}]}], "r"]}], ")"}]}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Collect", "[", " ", 
  RowBox[{"eps", ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], ",", " ", 
     RowBox[{"C", "[", "2", "]"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", " ", 
  RowBox[{"sig", ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], ",", " ", 
     RowBox[{"C", "[", "2", "]"}]}], "}"}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"C", "[", "2", "]"}]}], 
       SuperscriptBox["r", "3"]]}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], "+", 
      FractionBox[
       RowBox[{"C", "[", "2", "]"}], 
       SuperscriptBox["r", "3"]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], "+", 
      FractionBox[
       RowBox[{"C", "[", "2", "]"}], 
       SuperscriptBox["r", "3"]]}]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
       RowBox[{"C", "[", "1", "]"}]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[Mu]", " ", 
        RowBox[{"C", "[", "2", "]"}]}], 
       SuperscriptBox["r", "3"]]}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
       RowBox[{"C", "[", "1", "]"}]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{"C", "[", "2", "]"}]}], 
       SuperscriptBox["r", "3"]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
       RowBox[{"C", "[", "1", "]"}]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{"C", "[", "2", "]"}]}], 
       SuperscriptBox["r", "3"]]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", " ", 
  RowBox[{"eps", ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], ",", " ", 
     RowBox[{"C", "[", "2", "]"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"C", "[", "2", "]"}]}], 
       SuperscriptBox["r", "3"]]}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], "+", 
      FractionBox[
       RowBox[{"C", "[", "2", "]"}], 
       SuperscriptBox["r", "3"]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], "+", 
      FractionBox[
       RowBox[{"C", "[", "2", "]"}], 
       SuperscriptBox["r", "3"]]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["condition for the internal and external pressure",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"er", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"1", ",", "0", ",", "0"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", " ", 
  RowBox[{"-", " ", "er"}]}], "\[IndentingNewLine]", 
 RowBox[{"eqi", " ", "=", " ", 
  RowBox[{"(", " ", 
   RowBox[{"Thread", " ", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sig", " ", "/.", " ", 
        RowBox[{"r", " ", "\[Rule]", " ", "ri"}]}], ")"}], " ", ".", " ", 
      "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"-", " ", "pi"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"normal", " ", "=", "  ", "er"}], "\[IndentingNewLine]", 
 RowBox[{"eqe", " ", "=", " ", 
  RowBox[{"(", "  ", 
   RowBox[{"Thread", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sig", " ", "/.", " ", 
        RowBox[{"r", " ", "\[Rule]", " ", "re"}]}], ")"}], " ", ".", " ", 
      "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"-", " ", "pe"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"eqi", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
       RowBox[{"eqe", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}], " ", ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"C", "[", "1", "]"}], ",", " ", 
       RowBox[{"C", "[", "2", "]"}]}], "}"}]}], " ", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(normal\\)\\\" is similar to existing symbol \
\\\"\\!\\(Normal\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[Mu]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"C", "[", "1", "]"}]}], "-", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"C", "[", "2", "]"}]}], 
         SuperscriptBox["ri", "3"]]}], ")"}]}], "-", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"C", "[", "1", "]"}]}], "-", 
           FractionBox[
            RowBox[{"4", " ", 
             RowBox[{"C", "[", "2", "]"}]}], 
            SuperscriptBox["ri", "3"]]}], ")"}]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ri", " ", 
             RowBox[{"C", "[", "1", "]"}]}], "+", 
            FractionBox[
             RowBox[{"C", "[", "2", "]"}], 
             SuperscriptBox["ri", "2"]]}], ")"}]}], "ri"]}], ")"}]}]}], 
    "\[Equal]", "pi"}], ",", "True", ",", "True"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"C", "[", "1", "]"}]}], "-", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"C", "[", "2", "]"}]}], 
         SuperscriptBox["re", "3"]]}], ")"}]}], "+", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"C", "[", "1", "]"}]}], "-", 
           FractionBox[
            RowBox[{"4", " ", 
             RowBox[{"C", "[", "2", "]"}]}], 
            SuperscriptBox["re", "3"]]}], ")"}]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"re", " ", 
             RowBox[{"C", "[", "1", "]"}]}], "+", 
            FractionBox[
             RowBox[{"C", "[", "2", "]"}], 
             SuperscriptBox["re", "2"]]}], ")"}]}], "re"]}], ")"}]}]}], 
    "\[Equal]", 
    RowBox[{"-", "pe"}]}], ",", "True", ",", "True"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"pe", " ", 
        SuperscriptBox["re", "3"]}], "-", 
       RowBox[{"pi", " ", 
        SuperscriptBox["ri", "3"]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["re", "3"], "-", 
         SuperscriptBox["ri", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}]}], ",", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"pe", "-", "pi"}], ")"}], " ", 
       SuperscriptBox["re", "3"], " ", 
       SuperscriptBox["ri", "3"]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["re", "3"], "-", 
         SuperscriptBox["ri", "3"]}], ")"}], " ", "\[Mu]"}]]}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"uf", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"uu", " ", "/.", " ", "sol"}], " ", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"epsf", " ", "=", " ", 
  RowBox[{
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"eps", " ", "/.", " ", "sol"}], " ", "]"}], " ", "//", " ", 
   "MatrixForm"}]}], "\[IndentingNewLine]", 
 RowBox[{"sigf", " ", "=", " ", 
  RowBox[{
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"sig", " ", "/.", " ", "sol"}], " ", "]"}], " ", "//", " ", 
   "MatrixForm"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"pe", "-", "pi"}], ")"}], " ", 
        SuperscriptBox["re", "3"], " ", 
        SuperscriptBox["ri", "3"]}], "\[Mu]"], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"pe", " ", 
           SuperscriptBox["re", "3"]}], "-", 
          RowBox[{"pi", " ", 
           SuperscriptBox["ri", "3"]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}]]}], 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["re", "3"], "-", 
        SuperscriptBox["ri", "3"]}], ")"}]}]]}], ",", "0", ",", "0"}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(epsf\\)\
\\\" is similar to existing symbol \\\"\\!\\(eps\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"pe", "-", "pi"}], ")"}], " ", 
          SuperscriptBox["re", "3"], " ", 
          SuperscriptBox["ri", "3"]}], 
         RowBox[{
          SuperscriptBox["r", "3"], " ", "\[Mu]"}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "pe", " ", 
           SuperscriptBox["re", "3"]}], "+", 
          RowBox[{"2", " ", "pi", " ", 
           SuperscriptBox["ri", "3"]}]}], 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}]]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "3"], "-", 
          SuperscriptBox["ri", "3"]}], ")"}]}]], "0", "0"},
     {"0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"pe", "-", "pi"}], ")"}], " ", 
           SuperscriptBox["re", "3"], " ", 
           SuperscriptBox["ri", "3"]}], "\[Mu]"], "+", 
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox["r", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"pe", " ", 
              SuperscriptBox["re", "3"]}], "-", 
             RowBox[{"pi", " ", 
              SuperscriptBox["ri", "3"]}]}], ")"}]}], 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}]]}], 
        RowBox[{"4", " ", 
         SuperscriptBox["r", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["re", "3"], "-", 
           SuperscriptBox["ri", "3"]}], ")"}]}]]}], "0"},
     {"0", "0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"pe", "-", "pi"}], ")"}], " ", 
           SuperscriptBox["re", "3"], " ", 
           SuperscriptBox["ri", "3"]}], "\[Mu]"], "+", 
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox["r", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"pe", " ", 
              SuperscriptBox["re", "3"]}], "-", 
             RowBox[{"pi", " ", 
              SuperscriptBox["ri", "3"]}]}], ")"}]}], 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}]]}], 
        RowBox[{"4", " ", 
         SuperscriptBox["r", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["re", "3"], "-", 
           SuperscriptBox["ri", "3"]}], ")"}]}]]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(sigf\\)\
\\\" is similar to existing symbol \\\"\\!\\(sig\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "3"], "-", 
           SuperscriptBox["re", "3"]}], ")"}], " ", 
         SuperscriptBox["ri", "3"]}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["r", "3"]}], "+", 
           SuperscriptBox["ri", "3"]}], ")"}]}]}], 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "3"], "-", 
          SuperscriptBox["ri", "3"]}], ")"}]}]], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["r", "3"]}], "+", 
           SuperscriptBox["re", "3"]}], ")"}], " ", 
         SuperscriptBox["ri", "3"]}], "-", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["r", "3"]}], "+", 
           SuperscriptBox["ri", "3"]}], ")"}]}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "3"], "-", 
          SuperscriptBox["ri", "3"]}], ")"}]}]], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["r", "3"]}], "+", 
           SuperscriptBox["re", "3"]}], ")"}], " ", 
         SuperscriptBox["ri", "3"]}], "-", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["r", "3"]}], "+", 
           SuperscriptBox["ri", "3"]}], ")"}]}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "3"], "-", 
          SuperscriptBox["ri", "3"]}], ")"}]}]]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The spherical thin shell under internal and external \
pressure: pi and pe",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"r2series", " ", "=", " ", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"ri", " ", "\[Rule]", " ", 
       RowBox[{"R", 
        RowBox[{"(", " ", 
         RowBox[{"1", " ", "-", " ", 
          RowBox[{"eta", "/", "2"}]}], ")"}]}]}], " ", ",", " ", 
      RowBox[{"re", " ", "\[Rule]", " ", 
       RowBox[{"R", " ", 
        RowBox[{"(", " ", 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{"eta", "/", "2"}]}], " ", ")"}]}]}], " ", ",", " ", 
      RowBox[{"r", " ", "\[Rule]", "  ", 
       RowBox[{"R", 
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", "delta"}], ")"}]}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"series2r", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"delta", " ", "\[Rule]", "  ", 
       RowBox[{
        RowBox[{"r", " ", "/", " ", "R"}], " ", "-", "1"}]}], ",", " ", 
      RowBox[{"eta", " ", "\[Rule]", " ", 
       RowBox[{"ee", " ", "/", " ", "R"}]}]}], " ", "}"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ri", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox["eta", "2"]}], ")"}], " ", "R"}]}], ",", 
   RowBox[{"re", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox["eta", "2"]}], ")"}], " ", "R"}]}], ",", 
   RowBox[{"r", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "delta"}], ")"}], " ", "R"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"delta", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     FractionBox["r", "R"]}]}], ",", 
   RowBox[{"eta", "\[Rule]", 
    FractionBox["ee", "R"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Normal", "[", 
   RowBox[{"Series", "[", "  ", 
    RowBox[{
     RowBox[{"sigf", " ", "/.", " ", "r2series"}], "  ", ",", "  ", 
     RowBox[{"{", 
      RowBox[{"eta", ",", "  ", "0", ",", " ", "1"}], "}"}], ",", "  ", 
     RowBox[{"{", 
      RowBox[{"delta", ",", " ", "0", ",", "1"}], "}"}]}], " ", "]"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"ssig", " ", "=", " ", 
    RowBox[{"Normal", "[", 
     RowBox[{"Series", "[", 
      RowBox[{"%", ",", " ", 
       RowBox[{"{", 
        RowBox[{"eta", ",", " ", "0", ",", " ", "0"}], "}"}]}], "]"}], 
     "]"}]}], ")"}], " ", "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"rsig", " ", "=", " ", 
     RowBox[{"Simplify", "[", " ", 
      RowBox[{"ssig", " ", "/.", " ", "series2r"}], " ", "]"}]}], " ", ")"}], 
   "//", " ", "MatrixForm"}], " "}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox["pe", "2"]}], "+", 
       RowBox[{"eta", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["pe", "2"]}], "+", 
          FractionBox["pi", "2"]}], ")"}]}], "-", 
       FractionBox["pi", "2"], "+", 
       RowBox[{"delta", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"eta", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"5", " ", "pe"}], "6"], "-", 
             FractionBox[
              RowBox[{"5", " ", "pi"}], "6"]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"-", "pe"}], "+", "pi"}], "eta"]}], ")"}]}]}], "0", "0"},
     {"0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["pe", "2"]}], "+", 
       RowBox[{"delta", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["pe", "2"], "-", 
            FractionBox["pi", "2"]}], "eta"], "+", 
          RowBox[{"eta", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"5", " ", "pe"}], "12"]}], "+", 
             FractionBox[
              RowBox[{"5", " ", "pi"}], "12"]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"eta", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["pe", "12"]}], "+", 
          FractionBox["pi", "12"]}], ")"}]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["pe", "2"]}], "+", 
         FractionBox["pi", "2"]}], "eta"], "-", 
       FractionBox["pi", "2"]}], "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["pe", "2"]}], "+", 
       RowBox[{"delta", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            FractionBox["pe", "2"], "-", 
            FractionBox["pi", "2"]}], "eta"], "+", 
          RowBox[{"eta", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"5", " ", "pe"}], "12"]}], "+", 
             FractionBox[
              RowBox[{"5", " ", "pi"}], "12"]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"eta", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["pe", "12"]}], "+", 
          FractionBox["pi", "12"]}], ")"}]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["pe", "2"]}], "+", 
         FractionBox["pi", "2"]}], "eta"], "-", 
       FractionBox["pi", "2"]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(ssig\\)\
\\\" is similar to existing symbol \\\"\\!\\(sig\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox["pe", "2"]}], "-", 
       FractionBox["pi", "2"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "delta"}], " ", "pe"}], "+", 
         RowBox[{"delta", " ", "pi"}]}], "eta"]}], "0", "0"},
     {"0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["pe", "2"]}], "-", 
       FractionBox["pi", "2"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["pe", "2"]}], "+", 
         FractionBox[
          RowBox[{"delta", " ", "pe"}], "2"], "+", 
         FractionBox["pi", "2"], "-", 
         FractionBox[
          RowBox[{"delta", " ", "pi"}], "2"]}], "eta"]}], "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["pe", "2"]}], "-", 
       FractionBox["pi", "2"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["pe", "2"]}], "+", 
         FractionBox[
          RowBox[{"delta", " ", "pe"}], "2"], "+", 
         FractionBox["pi", "2"], "-", 
         FractionBox[
          RowBox[{"delta", " ", "pi"}], "2"]}], "eta"]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(rsig\\)\
\\\" is similar to existing symbols \\!\\({sig, ssig}\\). \\!\\(\\*ButtonBox[\
\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"ee", " ", 
          RowBox[{"(", 
           RowBox[{"pe", "+", "pi"}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"pe", "-", "pi"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"r", "-", "R"}], ")"}]}]}], 
        RowBox[{"2", " ", "ee"}]]}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "ee"}], " ", 
         RowBox[{"(", 
          RowBox[{"pe", "+", "pi"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"pe", "-", "pi"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", "R"}]}], ")"}]}]}], 
       RowBox[{"2", " ", "ee"}]], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "ee"}], " ", 
         RowBox[{"(", 
          RowBox[{"pe", "+", "pi"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"pe", "-", "pi"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", "R"}]}], ")"}]}]}], 
       RowBox[{"2", " ", "ee"}]]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"Div", "[", " ", "rsig", " ", "]"}], " ", "]"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", " ", 
  RowBox[{
   RowBox[{"%", " ", "/.", " ", "r2eta"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"delta", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"pe", "-", "pi"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"r", "-", "R"}], ")"}]}], 
     RowBox[{"ee", " ", "r"}]]}], ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ReplaceAll", "::", "\<\"reps\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"\\!\\({r2eta}\\) is neither a list of replacement rules \
nor a valid dispatch table, and so cannot be used for replacing. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"ReplaceAll::reps\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"pe", "-", "pi"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", "R"}], ")"}]}], 
      RowBox[{"ee", " ", "r"}]]}], ",", "0", ",", "0"}], "}"}], "/.", 
  "\[InvisibleSpace]", "r2eta"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1070, 821},
WindowMargins->{{116, Automatic}, {Automatic, 103}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 65, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[1421, 43, 291, 8, 55, "Input"],
Cell[1715, 53, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1802, 56, 150, 2, 77, "Input"],
Cell[CellGroupData[{
Cell[1977, 62, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2089, 67, 137, 3, 32, "Input"],
Cell[2229, 72, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2362, 79, 132, 3, 32, "Input"],
Cell[2497, 84, 335, 10, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2881, 100, 121, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[3027, 106, 817, 23, 77, "Input"],
Cell[3847, 131, 439, 15, 80, "Output"],
Cell[4289, 148, 1594, 49, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5920, 202, 221, 6, 32, "Input"],
Cell[6144, 210, 1050, 32, 72, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7231, 247, 392, 12, 55, "Input"],
Cell[7626, 261, 308, 10, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7971, 276, 766, 22, 77, "Input"],
Cell[8740, 300, 422, 14, 47, "Output"],
Cell[9165, 316, 385, 8, 24, "Message"],
Cell[9553, 326, 863, 28, 52, "Output"],
Cell[10419, 356, 422, 14, 47, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10890, 376, 141, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[11056, 382, 176, 5, 32, "Input"],
Cell[11235, 389, 244, 8, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11516, 402, 527, 14, 55, "Input"],
Cell[12046, 418, 943, 32, 114, "Output"],
Cell[12992, 452, 3464, 105, 154, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16493, 562, 425, 12, 55, "Input"],
Cell[16921, 576, 724, 24, 47, "Output"],
Cell[17648, 602, 1295, 41, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18980, 648, 211, 6, 32, "Input"],
Cell[19194, 656, 724, 24, 47, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19967, 686, 114, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[20106, 691, 117, 3, 32, "Input"],
Cell[20226, 696, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20346, 703, 1466, 42, 121, "Input"],
Cell[21815, 747, 391, 8, 24, "Message"],
Cell[22209, 757, 102, 3, 31, "Output"],
Cell[22314, 762, 1161, 37, 63, "Output"],
Cell[23478, 801, 83, 2, 31, "Output"],
Cell[23564, 805, 1159, 37, 63, "Output"],
Cell[24726, 844, 1026, 35, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25789, 884, 541, 14, 77, "Input"],
Cell[26333, 900, 907, 30, 69, "Output"],
Cell[27243, 932, 386, 8, 24, "Message"],
Cell[27632, 942, 2833, 87, 164, "Output"],
Cell[30468, 1031, 386, 8, 24, "Message"],
Cell[30857, 1041, 2307, 73, 132, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[33213, 1120, 140, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[33378, 1126, 1038, 28, 77, "Input"],
Cell[34419, 1156, 469, 16, 46, "Output"],
Cell[34891, 1174, 233, 8, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35161, 1187, 984, 26, 121, "Input"],
Cell[36148, 1215, 2816, 91, 124, "Output"],
Cell[38967, 1308, 386, 8, 24, "Message"],
Cell[39356, 1318, 1295, 43, 108, "Output"],
Cell[40654, 1363, 383, 7, 24, "Message"],
Cell[41040, 1372, 1360, 46, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42437, 1423, 343, 9, 55, "Input"],
Cell[42783, 1434, 300, 10, 47, "Output"],
Cell[43086, 1446, 394, 8, 45, "Message"],
Cell[43483, 1456, 361, 12, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

