(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     40434,       1269]
NotebookOptionsPosition[     38060,       1184]
NotebookOutlinePosition[     38504,       1202]
CellTagsIndexPosition[     38461,       1199]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["Free expanding sphere under a temperature gradient ", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "Displacement.m"}], "\[IndentingNewLine]"}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Spherical", "[", 
  RowBox[{"r", ",", "t", ",", "p"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "t", ",", "p"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Computation of the temperature field ",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"dsolT", " ", "=", 
  RowBox[{
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"Div", "[", 
        RowBox[{"k", " ", 
         RowBox[{"Grad", "[", 
          RowBox[{"T", "[", "r", "]"}], "]"}]}], "]"}], "\[Equal]", " ", 
       "0"}], "}"}], ",", " ", 
     RowBox[{"T", "[", "r", "]"}], ",", " ", "r"}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CT", " ", "=", " ", 
   RowBox[{
    RowBox[{"Solve", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"T", "[", "r", "]"}], " ", "/.", " ", "dsolT"}], " ", "/.",
            " ", 
           RowBox[{"r", " ", "\[Rule]", " ", "ri"}]}], ")"}], " ", "\[Equal]",
          " ", "Ti"}], " ", ",", "  ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"T", "[", "r", "]"}], " ", "/.", " ", "dsolT"}], " ", "/.",
            " ", 
           RowBox[{"r", " ", "\[Rule]", " ", "re"}]}], ")"}], " ", "\[Equal]",
          " ", "Te"}]}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"C", "[", "1", "]"}], ",", " ", 
        RowBox[{"C", "[", "2", "]"}]}], "}"}]}], " ", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], " "}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"T", "[", "r", "]"}], "\[Rule]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"C", "[", "1", "]"}], "r"]}], "+", 
   RowBox[{"C", "[", "2", "]"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"re", " ", "ri", " ", "Te"}], "-", 
       RowBox[{"re", " ", "ri", " ", "Ti"}]}], 
      RowBox[{
       RowBox[{"-", "re"}], "+", "ri"}]]}]}], ",", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "re"}], " ", "Te"}], "+", 
       RowBox[{"ri", " ", "Ti"}]}], 
      RowBox[{"re", "-", "ri"}]]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"\[Theta]", "[", "r_", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"dsolT", "[", 
     RowBox[{"[", "2", "]"}], "]"}], " ", "/.", " ", "CT"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "re"}], " ", "Te"}], "+", 
     RowBox[{"ri", " ", "Ti"}]}], 
    RowBox[{"re", "-", "ri"}]]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"re", " ", "ri", " ", "Te"}], "-", 
    RowBox[{"re", " ", "ri", " ", "Ti"}]}], 
   RowBox[{"r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "re"}], "+", "ri"}], ")"}]}]]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Computation of the displacement field ",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"u", "[", 
   RowBox[{"r_", ",", "t_", ",", "p_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ur", "[", "r", "]"}], ",", "0", ",", "0"}], "}"}]}], "\n", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"Strain", "[", " ", 
     RowBox[{"u", " ", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}]}], " ", ")"}], " ", "//",
   "MatrixForm"}], "\n", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"Tr", "[", "eps", " ", "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", " ", "]"}]}], "+", " ", 
     RowBox[{"2", " ", "\[Mu]", " ", "eps"}], " ", "-", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Lambda]", " ", "+", " ", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", "\[Alpha]", " ", 
      RowBox[{"\[Theta]", "[", "r", "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", "]"}]}]}]}], " ", ")"}], " ", "//", 
  " ", "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["ur", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"ur", "[", "r", "]"}], "r"], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{"ur", "[", "r", "]"}], "r"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "re"}], " ", "Te"}], "+", 
              RowBox[{"ri", " ", "Ti"}]}], 
             RowBox[{"re", "-", "ri"}]]}], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"re", " ", "ri", " ", "Te"}], "-", 
             RowBox[{"re", " ", "ri", " ", "Ti"}]}], 
            RowBox[{"r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "re"}], "+", "ri"}], ")"}]}]]}], ")"}]}], " ", 
        "\[Alpha]", " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{
         SuperscriptBox["ur", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
          RowBox[{
           SuperscriptBox["ur", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}], "0", 
      "0"},
     {"0", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "re"}], " ", "Te"}], "+", 
              RowBox[{"ri", " ", "Ti"}]}], 
             RowBox[{"re", "-", "ri"}]]}], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"re", " ", "ri", " ", "Te"}], "-", 
             RowBox[{"re", " ", "ri", " ", "Ti"}]}], 
            RowBox[{"r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "re"}], "+", "ri"}], ")"}]}]]}], ")"}]}], " ", 
        "\[Alpha]", " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
          RowBox[{
           SuperscriptBox["ur", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}], "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "re"}], " ", "Te"}], "+", 
              RowBox[{"ri", " ", "Ti"}]}], 
             RowBox[{"re", "-", "ri"}]]}], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"re", " ", "ri", " ", "Te"}], "-", 
             RowBox[{"re", " ", "ri", " ", "Ti"}]}], 
            RowBox[{"r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "re"}], "+", "ri"}], ")"}]}]]}], ")"}]}], " ", 
        "\[Alpha]", " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
          RowBox[{
           SuperscriptBox["ur", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"divsig", " ", "=", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"Div", "[", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"sig", " ", "/.", "  ", 
       RowBox[{
        RowBox[{"\[Theta]", "[", "r", "]"}], " ", "->", " ", 
        RowBox[{"dsolT", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}], " ", "/.", " ", "CT"}], " ", 
     ")"}], "  ", "]"}], " ", "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Lambda]", "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "re"}], " ", "ri", " ", "Te", " ", "\[Alpha]"}], "+", 
       RowBox[{"re", " ", "ri", " ", "Ti", " ", "\[Alpha]"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"re", "-", "ri"}], ")"}], " ", 
        RowBox[{"ur", "[", "r", "]"}]}], "+", 
       RowBox[{"2", " ", "r", " ", 
        RowBox[{"(", 
         RowBox[{"re", "-", "ri"}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["ur", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", "re", " ", 
        RowBox[{
         SuperscriptBox["ur", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", "ri", " ", 
        RowBox[{
         SuperscriptBox["ur", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"re", "-", "ri"}], ")"}]}]], ",", "0", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solu", " ", "=", " ", 
  RowBox[{
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"divsig", "[", 
       RowBox[{"[", "1", "]"}], "]"}], " ", "==", " ", "0"}], ",", " ", 
     RowBox[{"ur", "[", "r", "]"}], ",", " ", "r", " ", ",", " ", 
     RowBox[{"GeneratedParameters", " ", "\[Rule]", " ", "B"}]}], "]"}], "[", 
   
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ur", "[", "r", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"re", " ", "ri", " ", "Te", " ", "\[Alpha]"}], "-", 
       RowBox[{"re", " ", "ri", " ", "Ti", " ", "\[Alpha]"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"re", "-", "ri"}], ")"}]}]]}], "+", 
    RowBox[{"r", " ", 
     RowBox[{"B", "[", "1", "]"}]}], "+", 
    FractionBox[
     RowBox[{"B", "[", "2", "]"}], 
     SuperscriptBox["r", "2"]]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Computation displacement boundary conditions ",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"uu", " ", "=", " ", 
  RowBox[{
   RowBox[{"u", " ", "[", 
    RowBox[{"r", ",", "t", ",", "p"}], "]"}], " ", "/.", " ", "solu", 
   " "}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"Strain", "[", " ", "uu", "]"}]}], "  ", ")"}], " ", "//", 
  "MatrixForm"}], "\n", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"Tr", "[", "eps", " ", "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", " ", "]"}]}], "+", " ", 
     RowBox[{"2", " ", "\[Mu]", " ", "eps"}], " ", "-", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Lambda]", " ", "+", " ", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", "\[Alpha]", " ", 
      RowBox[{"\[Theta]", "[", "r", "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", "]"}]}]}]}], " ", ")"}], " ", "//", 
  " ", "MatrixForm"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"re", " ", "ri", " ", "Te", " ", "\[Alpha]"}], "-", 
       RowBox[{"re", " ", "ri", " ", "Ti", " ", "\[Alpha]"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"re", "-", "ri"}], ")"}]}]]}], "+", 
    RowBox[{"r", " ", 
     RowBox[{"B", "[", "1", "]"}]}], "+", 
    FractionBox[
     RowBox[{"B", "[", "2", "]"}], 
     SuperscriptBox["r", "2"]]}], ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"B", "[", "1", "]"}]}], "-", 
         FractionBox[
          RowBox[{"4", " ", 
           RowBox[{"B", "[", "2", "]"}]}], 
          SuperscriptBox["r", "3"]]}], ")"}]}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"re", " ", "ri", " ", "Te", " ", "\[Alpha]"}], "-", 
           RowBox[{"re", " ", "ri", " ", "Ti", " ", "\[Alpha]"}]}], 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"re", "-", "ri"}], ")"}]}]]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{"B", "[", "1", "]"}]}], "+", 
        FractionBox[
         RowBox[{"B", "[", "2", "]"}], 
         SuperscriptBox["r", "2"]]}], "r"], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"re", " ", "ri", " ", "Te", " ", "\[Alpha]"}], "-", 
           RowBox[{"re", " ", "ri", " ", "Ti", " ", "\[Alpha]"}]}], 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"re", "-", "ri"}], ")"}]}]]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{"B", "[", "1", "]"}]}], "+", 
        FractionBox[
         RowBox[{"B", "[", "2", "]"}], 
         SuperscriptBox["r", "2"]]}], "r"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "re"}], " ", "Te"}], "+", 
              RowBox[{"ri", " ", "Ti"}]}], 
             RowBox[{"re", "-", "ri"}]]}], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"re", " ", "ri", " ", "Te"}], "-", 
             RowBox[{"re", " ", "ri", " ", "Ti"}]}], 
            RowBox[{"r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "re"}], "+", "ri"}], ")"}]}]]}], ")"}]}], " ", 
        "\[Alpha]", " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"B", "[", "1", "]"}]}], "-", 
          FractionBox[
           RowBox[{"4", " ", 
            RowBox[{"B", "[", "2", "]"}]}], 
           SuperscriptBox["r", "3"]]}], ")"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"B", "[", "1", "]"}]}], "-", 
             FractionBox[
              RowBox[{"4", " ", 
               RowBox[{"B", "[", "2", "]"}]}], 
              SuperscriptBox["r", "3"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{
                 RowBox[{"re", " ", "ri", " ", "Te", " ", "\[Alpha]"}], "-", 
                 RowBox[{"re", " ", "ri", " ", "Ti", " ", "\[Alpha]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{"re", "-", "ri"}], ")"}]}]]}], "+", 
              RowBox[{"r", " ", 
               RowBox[{"B", "[", "1", "]"}]}], "+", 
              FractionBox[
               RowBox[{"B", "[", "2", "]"}], 
               SuperscriptBox["r", "2"]]}], ")"}]}], "r"]}], ")"}]}]}], "0", 
      "0"},
     {"0", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "re"}], " ", "Te"}], "+", 
              RowBox[{"ri", " ", "Ti"}]}], 
             RowBox[{"re", "-", "ri"}]]}], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"re", " ", "ri", " ", "Te"}], "-", 
             RowBox[{"re", " ", "ri", " ", "Ti"}]}], 
            RowBox[{"r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "re"}], "+", "ri"}], ")"}]}]]}], ")"}]}], " ", 
        "\[Alpha]", " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{"re", " ", "ri", " ", "Te", " ", "\[Alpha]"}], "-", 
              RowBox[{"re", " ", "ri", " ", "Ti", " ", "\[Alpha]"}]}], 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{"re", "-", "ri"}], ")"}]}]]}], "+", 
           RowBox[{"r", " ", 
            RowBox[{"B", "[", "1", "]"}]}], "+", 
           FractionBox[
            RowBox[{"B", "[", "2", "]"}], 
            SuperscriptBox["r", "2"]]}], ")"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"B", "[", "1", "]"}]}], "-", 
             FractionBox[
              RowBox[{"4", " ", 
               RowBox[{"B", "[", "2", "]"}]}], 
              SuperscriptBox["r", "3"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{
                 RowBox[{"re", " ", "ri", " ", "Te", " ", "\[Alpha]"}], "-", 
                 RowBox[{"re", " ", "ri", " ", "Ti", " ", "\[Alpha]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{"re", "-", "ri"}], ")"}]}]]}], "+", 
              RowBox[{"r", " ", 
               RowBox[{"B", "[", "1", "]"}]}], "+", 
              FractionBox[
               RowBox[{"B", "[", "2", "]"}], 
               SuperscriptBox["r", "2"]]}], ")"}]}], "r"]}], ")"}]}]}], "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "re"}], " ", "Te"}], "+", 
              RowBox[{"ri", " ", "Ti"}]}], 
             RowBox[{"re", "-", "ri"}]]}], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"re", " ", "ri", " ", "Te"}], "-", 
             RowBox[{"re", " ", "ri", " ", "Ti"}]}], 
            RowBox[{"r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "re"}], "+", "ri"}], ")"}]}]]}], ")"}]}], " ", 
        "\[Alpha]", " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{"re", " ", "ri", " ", "Te", " ", "\[Alpha]"}], "-", 
              RowBox[{"re", " ", "ri", " ", "Ti", " ", "\[Alpha]"}]}], 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{"re", "-", "ri"}], ")"}]}]]}], "+", 
           RowBox[{"r", " ", 
            RowBox[{"B", "[", "1", "]"}]}], "+", 
           FractionBox[
            RowBox[{"B", "[", "2", "]"}], 
            SuperscriptBox["r", "2"]]}], ")"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"B", "[", "1", "]"}]}], "-", 
             FractionBox[
              RowBox[{"4", " ", 
               RowBox[{"B", "[", "2", "]"}]}], 
              SuperscriptBox["r", "3"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{
                 RowBox[{"re", " ", "ri", " ", "Te", " ", "\[Alpha]"}], "-", 
                 RowBox[{"re", " ", "ri", " ", "Ti", " ", "\[Alpha]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{"re", "-", "ri"}], ")"}]}]]}], "+", 
              RowBox[{"r", " ", 
               RowBox[{"B", "[", "1", "]"}]}], "+", 
              FractionBox[
               RowBox[{"B", "[", "2", "]"}], 
               SuperscriptBox["r", "2"]]}], ")"}]}], "r"]}], ")"}]}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"sig", " ", "=", "  ", 
     RowBox[{"Simplify", "[", "sig", " ", "]"}]}], ")"}], " ", "//", " ", 
   "MatrixForm"}]}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["r", "2"], " ", "re", " ", "ri", " ", 
         RowBox[{"(", 
          RowBox[{"Te", "-", "Ti"}], ")"}], " ", "\[Alpha]", " ", "\[Mu]"}], 
        "+", 
        RowBox[{
         SuperscriptBox["r", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ri", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Ti", " ", "\[Alpha]", " ", 
               RowBox[{"(", 
                RowBox[{"\[Lambda]", "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "\[Lambda]"}], "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
               RowBox[{"B", "[", "1", "]"}]}]}], ")"}]}], "+", 
           RowBox[{"re", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Te"}], " ", "\[Alpha]", " ", 
               RowBox[{"(", 
                RowBox[{"\[Lambda]", "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "\[Lambda]"}], "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
               RowBox[{"B", "[", "1", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "re"}], "+", "ri"}], ")"}], " ", "\[Mu]", " ", 
         RowBox[{"B", "[", "2", "]"}]}]}], 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"re", "-", "ri"}], ")"}]}]], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "2"], " ", "re", " ", "ri", " ", 
         RowBox[{"(", 
          RowBox[{"Te", "-", "Ti"}], ")"}], " ", "\[Alpha]", " ", "\[Mu]"}], 
        "+", 
        RowBox[{
         SuperscriptBox["r", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ri", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Ti", " ", "\[Alpha]", " ", 
               RowBox[{"(", 
                RowBox[{"\[Lambda]", "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "\[Lambda]"}], "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
               RowBox[{"B", "[", "1", "]"}]}]}], ")"}]}], "+", 
           RowBox[{"re", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Te"}], " ", "\[Alpha]", " ", 
               RowBox[{"(", 
                RowBox[{"\[Lambda]", "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "\[Lambda]"}], "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
               RowBox[{"B", "[", "1", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"re", "-", "ri"}], ")"}], " ", "\[Mu]", " ", 
         RowBox[{"B", "[", "2", "]"}]}]}], 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"re", "-", "ri"}], ")"}]}]], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "2"], " ", "re", " ", "ri", " ", 
         RowBox[{"(", 
          RowBox[{"Te", "-", "Ti"}], ")"}], " ", "\[Alpha]", " ", "\[Mu]"}], 
        "+", 
        RowBox[{
         SuperscriptBox["r", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ri", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Ti", " ", "\[Alpha]", " ", 
               RowBox[{"(", 
                RowBox[{"\[Lambda]", "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "\[Lambda]"}], "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
               RowBox[{"B", "[", "1", "]"}]}]}], ")"}]}], "+", 
           RowBox[{"re", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "Te"}], " ", "\[Alpha]", " ", 
               RowBox[{"(", 
                RowBox[{"\[Lambda]", "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "\[Lambda]"}], "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
               RowBox[{"B", "[", "1", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"re", "-", "ri"}], ")"}], " ", "\[Mu]", " ", 
         RowBox[{"B", "[", "2", "]"}]}]}], 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"re", "-", "ri"}], ")"}]}]]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", " ", 
  RowBox[{"-", " ", "er"}]}], "\[IndentingNewLine]", 
 RowBox[{"eqi", " ", "=", " ", 
  RowBox[{"(", " ", 
   RowBox[{"Thread", " ", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sig", " ", "/.", " ", 
        RowBox[{"r", " ", "\[Rule]", " ", "ri"}]}], ")"}], " ", ".", " ", 
      "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"-", " ", "0"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"normal", " ", "=", "  ", "er"}], "\[IndentingNewLine]", 
 RowBox[{"eqe", " ", "=", " ", 
  RowBox[{"(", "  ", 
   RowBox[{"Thread", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sig", " ", "/.", " ", 
        RowBox[{"r", " ", "\[Rule]", " ", "re"}]}], ")"}], " ", ".", " ", 
      "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"-", " ", "0"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"eqi", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
       RowBox[{"eqe", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}], " ", ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"B", "[", "1", "]"}], ",", " ", 
       RowBox[{"B", "[", "2", "]"}]}], "}"}]}], " ", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "re", " ", 
        SuperscriptBox["ri", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"Te", "-", "Ti"}], ")"}], " ", "\[Alpha]", " ", "\[Mu]"}], 
       "+", 
       RowBox[{
        SuperscriptBox["ri", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"ri", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Ti", " ", "\[Alpha]", " ", 
              RowBox[{"(", 
               RowBox[{"\[Lambda]", "+", 
                RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", "\[Lambda]"}], "+", 
                RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
              RowBox[{"B", "[", "1", "]"}]}]}], ")"}]}], "+", 
          RowBox[{"re", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "Te"}], " ", "\[Alpha]", " ", 
              RowBox[{"(", 
               RowBox[{"\[Lambda]", "+", 
                RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", "\[Lambda]"}], "+", 
                RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
              RowBox[{"B", "[", "1", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "re"}], "+", "ri"}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"B", "[", "2", "]"}]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"re", "-", "ri"}], ")"}], " ", 
       SuperscriptBox["ri", "3"]}]]}], "\[Equal]", "0"}], ",", "True", ",", 
   "True"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["re", "3"], " ", "ri", " ", 
       RowBox[{"(", 
        RowBox[{"Te", "-", "Ti"}], ")"}], " ", "\[Alpha]", " ", "\[Mu]"}], 
      "+", 
      RowBox[{
       SuperscriptBox["re", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"ri", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Ti", " ", "\[Alpha]", " ", 
             RowBox[{"(", 
              RowBox[{"\[Lambda]", "+", 
               RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[Lambda]"}], "+", 
               RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
             RowBox[{"B", "[", "1", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"re", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "Te"}], " ", "\[Alpha]", " ", 
             RowBox[{"(", 
              RowBox[{"\[Lambda]", "+", 
               RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[Lambda]"}], "+", 
               RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
             RowBox[{"B", "[", "1", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "re"}], "+", "ri"}], ")"}], " ", "\[Mu]", " ", 
       RowBox[{"B", "[", "2", "]"}]}]}], 
     RowBox[{
      SuperscriptBox["re", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"re", "-", "ri"}], ")"}]}]], "\[Equal]", "0"}], ",", "True", 
   ",", "True"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"B", "[", "1", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["re", "3"]}], " ", "Te", " ", "\[Alpha]", " ", 
        "\[Lambda]"}], "-", 
       RowBox[{
        SuperscriptBox["re", "2"], " ", "ri", " ", "Te", " ", "\[Alpha]", " ",
         "\[Lambda]"}], "-", 
       RowBox[{"re", " ", 
        SuperscriptBox["ri", "2"], " ", "Te", " ", "\[Alpha]", " ", 
        "\[Lambda]"}], "+", 
       RowBox[{
        SuperscriptBox["re", "2"], " ", "ri", " ", "Ti", " ", "\[Alpha]", " ",
         "\[Lambda]"}], "+", 
       RowBox[{"re", " ", 
        SuperscriptBox["ri", "2"], " ", "Ti", " ", "\[Alpha]", " ", 
        "\[Lambda]"}], "+", 
       RowBox[{
        SuperscriptBox["ri", "3"], " ", "Ti", " ", "\[Alpha]", " ", 
        "\[Lambda]"}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["re", "3"], " ", "Te", " ", "\[Alpha]", " ", "\[Mu]"}],
        "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["ri", "3"], " ", "Ti", " ", "\[Alpha]", " ", 
        "\[Mu]"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"re", "-", "ri"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["re", "2"], "+", 
         RowBox[{"re", " ", "ri"}], "+", 
         SuperscriptBox["ri", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}]}], ",", 
   RowBox[{
    RowBox[{"B", "[", "2", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["re", "3"], " ", 
      SuperscriptBox["ri", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Te", " ", "\[Alpha]"}], "-", 
        RowBox[{"Ti", " ", "\[Alpha]"}]}], ")"}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["re", "3"], "-", 
        SuperscriptBox["ri", "3"]}], ")"}]}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1058, 821},
WindowMargins->{{Automatic, 82}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 94, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[1450, 43, 291, 8, 55, "Input"],
Cell[1744, 53, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1831, 56, 150, 2, 77, "Input"],
Cell[CellGroupData[{
Cell[2006, 62, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2118, 67, 137, 3, 32, "Input"],
Cell[2258, 72, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2391, 79, 132, 3, 32, "Input"],
Cell[2526, 84, 335, 10, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2910, 100, 103, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[3038, 105, 1438, 42, 77, "Input"],
Cell[4479, 149, 209, 7, 46, "Output"],
Cell[4691, 158, 582, 20, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5310, 183, 228, 6, 55, "Input"],
Cell[5541, 191, 440, 16, 50, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6030, 213, 104, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[6159, 218, 1043, 28, 59, "Input"],
Cell[7205, 248, 439, 15, 79, "Output"],
Cell[7647, 265, 3922, 118, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11606, 388, 414, 11, 27, "Input"],
Cell[12023, 401, 1287, 37, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13347, 443, 411, 11, 27, "Input"],
Cell[13761, 456, 553, 17, 46, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14363, 479, 111, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[14499, 484, 951, 25, 59, "Input"],
Cell[15453, 511, 527, 16, 46, "Output"],
Cell[15983, 529, 1573, 48, 109, "Output"],
Cell[17559, 579, 7559, 214, 147, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25155, 798, 198, 6, 27, "Input"],
Cell[25356, 806, 5344, 147, 101, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30737, 958, 1464, 42, 91, "Input"],
Cell[32204, 1002, 102, 3, 27, "Output"],
Cell[32309, 1007, 1822, 52, 49, "Output"],
Cell[34134, 1061, 83, 2, 27, "Output"],
Cell[34220, 1065, 1755, 51, 48, "Output"],
Cell[35978, 1118, 2013, 59, 49, "Output"]
}, Open  ]],
Cell[38006, 1180, 26, 0, 27, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

