(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    104304,       3482]
NotebookOptionsPosition[     97960,       3264]
NotebookOutlinePosition[     98799,       3291]
CellTagsIndexPosition[     98756,       3288]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["The Saint Venant Solution ", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", 
   "\"\</local/constant/Oxford/Tex/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/Oxford/Tex/ElasticaBook/Packages\"\>"], \
"Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]"}]], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigma", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sxx", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", " ", 
      RowBox[{"sxy", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", " ", 
      RowBox[{"sxz", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sxy", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", " ", "0", ",", " ", 
      "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sxz", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", " ", "0", ",", " ", 
      "0"}], "}"}]}], "}"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"div", " ", ":=", " ", 
    RowBox[{"Thread", "[", " ", 
     RowBox[{
      RowBox[{"Div", "[", " ", 
       RowBox[{"sigma", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], " ", "\[Equal]", " ",
       
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], " ", "]"}]}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"div", " ", "//", " ", "MatrixForm"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(div\\)\\\" is similar to existing symbol \\\"\\!\\(Div\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["sxz", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{
         SuperscriptBox["sxy", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{
         SuperscriptBox["sxx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["sxy", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["sxz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], "\[Equal]", "0"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   Derivative[0, 0, 1][sxz][x, y, z] + Derivative[0, 1, 0][sxy][x, y, z] + 
     Derivative[1, 0, 0][sxx][x, y, z] == 0, 
    Derivative[1, 0, 0][sxy][x, y, z] == 0, Derivative[1, 0, 0][sxz][x, y, z] == 
    0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sxy", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "=", " ", 
  RowBox[{"sxy", "[", 
   RowBox[{"y", ",", "z"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"sxy", "[", 
  RowBox[{"y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sxz", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "=", " ", 
  RowBox[{"sxz", "[", 
   RowBox[{"y", ",", "z"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"sxz", "[", 
  RowBox[{"y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Thread", "[", " ", 
    RowBox[{
     RowBox[{"Div", "[", " ", 
      RowBox[{"sigma", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], " ", "\[Equal]", " ", 
     
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], " ", "]"}], " ", ")"}], " ",
   "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["sxz", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}], "+", 
        RowBox[{
         SuperscriptBox["sxy", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}], "+", 
        RowBox[{
         SuperscriptBox["sxx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "\[Equal]", "0"}]},
     {"True"},
     {"True"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   Derivative[0, 1][sxz][y, z] + Derivative[1, 0][sxy][y, z] + 
     Derivative[1, 0, 0][sxx][x, y, z] == 0, True, True}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"eps", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", " ", "+", " ", "nu"}], ")"}], " ", 
    RowBox[{"sigma", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], " ", "-", " ", 
   RowBox[{"nu", "  ", 
    RowBox[{"Tr", "[", " ", 
     RowBox[{"sigma", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], " ", 
    RowBox[{"IdentityMatrix", "[", "3", "]"}], 
    " "}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eps", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "  ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "nu"}], " ", 
        RowBox[{"sxx", "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"sxx", "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       RowBox[{"sxy", "[", 
        RowBox[{"y", ",", "z"}], "]"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       RowBox[{"sxz", "[", 
        RowBox[{"y", ",", "z"}], "]"}]}]},
     {
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       RowBox[{"sxy", "[", 
        RowBox[{"y", ",", "z"}], "]"}]}], 
      RowBox[{
       RowBox[{"-", "nu"}], " ", 
       RowBox[{"sxx", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "0"},
     {
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       RowBox[{"sxz", "[", 
        RowBox[{"y", ",", "z"}], "]"}]}], "0", 
      RowBox[{
       RowBox[{"-", "nu"}], " ", 
       RowBox[{"sxx", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"inc", " ", ":=", " ", 
   RowBox[{"Thread", "[", " ", 
    RowBox[{
     RowBox[{"Flatten", "[", " ", 
      RowBox[{"Inc", "[", " ", 
       RowBox[{"eps", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], " ", "]"}], " ", 
     "\[Equal]", " ", 
     RowBox[{"Array", "[", 
      RowBox[{
       RowBox[{"0", " ", "&"}], ",", " ", "9"}], "]"}]}], "]"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"inc", "  ", "//", " ", "MatrixForm"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(inc\\)\\\" is similar to existing symbol \\\"\\!\\(Inc\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "nu"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["sxx", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
          RowBox[{
           SuperscriptBox["sxx", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], ")"}]}], "\[Equal]", 
       "0"}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}]}], " ", 
         RowBox[{
          SuperscriptBox["sxy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sxz", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}], "+", 
        RowBox[{"nu", " ", 
         RowBox[{
          SuperscriptBox["sxx", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sxy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sxz", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}], "+", 
        RowBox[{"nu", " ", 
         RowBox[{
          SuperscriptBox["sxx", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}]}], " ", 
         RowBox[{
          SuperscriptBox["sxy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sxz", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}], "+", 
        RowBox[{"nu", " ", 
         RowBox[{
          SuperscriptBox["sxx", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["sxx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}], "-", 
        RowBox[{"nu", " ", 
         RowBox[{
          SuperscriptBox["sxx", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         SuperscriptBox["sxx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sxy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sxz", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}], "+", 
        RowBox[{"nu", " ", 
         RowBox[{
          SuperscriptBox["sxx", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         SuperscriptBox["sxx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["sxx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}], "-", 
        RowBox[{"nu", " ", 
         RowBox[{
          SuperscriptBox["sxx", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "\[Equal]", "0"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{-
     nu (Derivative[0, 0, 2][sxx][x, y, z] + 
      Derivative[0, 2, 0][sxx][x, y, z]) == 
    0, -(1 + nu) Derivative[0, 2][sxy][y, z] + (1 + nu) 
      Derivative[1, 1][sxz][y, z] + nu Derivative[1, 1, 0][sxx][x, y, z] == 
    0, (1 + nu) Derivative[1, 1][sxy][y, z] - (1 + nu) 
     Derivative[2, 0][sxz][y, z] + nu Derivative[1, 0, 1][sxx][x, y, z] == 
    0, -(1 + nu) Derivative[0, 2][sxy][y, z] + (1 + nu) 
      Derivative[1, 1][sxz][y, z] + nu Derivative[1, 1, 0][sxx][x, y, z] == 0,
     Derivative[0, 0, 2][sxx][x, y, z] - nu Derivative[2, 0, 0][sxx][x, y, z] == 
    0, -Derivative[0, 1, 1][sxx][x, y, z] == 
    0, (1 + nu) Derivative[1, 1][sxy][y, z] - (1 + nu) 
     Derivative[2, 0][sxz][y, z] + nu Derivative[1, 0, 1][sxx][x, y, z] == 
    0, -Derivative[0, 1, 1][sxx][x, y, z] == 0, 
    Derivative[0, 2, 0][sxx][x, y, z] - nu Derivative[2, 0, 0][sxx][x, y, z] == 
    0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"sxx", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"a1", " ", "x", " ", "y"}], " ", "+", " ", 
    RowBox[{"a2", " ", "x", " ", "z"}], " ", "+", " ", 
    RowBox[{"a3", " ", "x"}], " ", "+", " ", 
    RowBox[{"a4", " ", "y"}], " ", "+", " ", 
    RowBox[{"a5", " ", "z"}], " ", "+", " ", "a6"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"a6", "+", 
  RowBox[{"a3", " ", "x"}], "+", 
  RowBox[{"a4", " ", "y"}], "+", 
  RowBox[{"a1", " ", "x", " ", "y"}], "+", 
  RowBox[{"a5", " ", "z"}], "+", 
  RowBox[{"a2", " ", "x", " ", "z"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"inc", "  ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"True"},
     {
      RowBox[{
       RowBox[{
        RowBox[{"a1", " ", "nu"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sxy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sxz", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"a2", " ", "nu"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sxy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sxz", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"a1", " ", "nu"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sxy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sxz", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], "\[Equal]", "0"}]},
     {"True"},
     {"True"},
     {
      RowBox[{
       RowBox[{
        RowBox[{"a2", " ", "nu"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sxy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sxz", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], "\[Equal]", "0"}]},
     {"True"},
     {"True"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   True, a1 nu - (1 + nu) 
     Derivative[0, 2][sxy][y, z] + (1 + nu) Derivative[1, 1][sxz][y, z] == 0, 
    a2 nu + (1 + nu) Derivative[1, 1][sxy][y, z] - (1 + nu) 
     Derivative[2, 0][sxz][y, z] == 0, 
    a1 nu - (1 + nu) 
     Derivative[0, 2][sxy][y, z] + (1 + nu) Derivative[1, 1][sxz][y, z] == 0, 
    True, True, 
    a2 nu + (1 + nu) Derivative[1, 1][sxy][y, z] - (1 + nu) 
     Derivative[2, 0][sxz][y, z] == 0, True, True}]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Laplacian equations for sxy[y,z] and syz[y,z]",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq1", " ", "=", " ", 
  RowBox[{"div", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"a3", "+", 
  RowBox[{"a1", " ", "y"}], "+", 
  RowBox[{"a2", " ", "z"}], "+", 
  RowBox[{
   SuperscriptBox["sxz", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"y", ",", "z"}], "]"}], "+", 
  RowBox[{
   SuperscriptBox["sxy", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"1", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"y", ",", "z"}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{"Solve", "[", " ", 
   RowBox[{
    RowBox[{"D", "[", " ", 
     RowBox[{
      RowBox[{"div", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", "y"}], " ", "]"}], ",", " ", 
    
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sxz", "[", 
       RowBox[{"y", ",", "z"}], "]"}], ",", "y", ",", "z"}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["sxz", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"y", ",", "z"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "a1"}], "-", 
     RowBox[{
      SuperscriptBox["sxy", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq2", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{"inc", "[", 
     RowBox[{"[", "2", "]"}], "]"}], " ", "/.", " ", 
    RowBox[{"sol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a1", "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["sxy", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"y", ",", "z"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["sxy", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"y", ",", "z"}], "]"}]}]}], "\[Equal]", "0"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{"Solve", "[", " ", 
   RowBox[{
    RowBox[{"D", "[", " ", 
     RowBox[{
      RowBox[{"div", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", "z"}], " ", "]"}], ",", " ", 
    
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sxy", "[", 
       RowBox[{"y", ",", "z"}], "]"}], ",", "y", ",", "z"}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["sxy", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"y", ",", "z"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "a2"}], "-", 
     RowBox[{
      SuperscriptBox["sxz", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{"D", "[", " ", 
     RowBox[{
      RowBox[{"inc", "[", 
       RowBox[{"[", 
        RowBox[{"3", ",", "1"}], "]"}], "]"}], " ", ",", " ", "y"}], "]"}], 
    " ", "-", " ", 
    RowBox[{"D", "[", " ", 
     RowBox[{
      RowBox[{"inc", "[", 
       RowBox[{"[", 
        RowBox[{"3", ",", "1"}], "]"}], "]"}], " ", ",", " ", "z"}], "]"}]}], 
   " ", "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "+", "nu"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      SuperscriptBox["sxy", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["sxy", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"y", ",", "z"}], "]"}], "+", 
    RowBox[{
     SuperscriptBox["sxz", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"y", ",", "z"}], "]"}], "-", 
    RowBox[{
     SuperscriptBox["sxz", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"3", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"y", ",", "z"}], "]"}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq3", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{"inc", "[", 
     RowBox[{"[", "3", "]"}], "]"}], " ", "/.", " ", 
    RowBox[{"sol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2", "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["sxz", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"y", ",", "z"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["sxz", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"y", ",", "z"}], "]"}]}]}], "\[Equal]", "0"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Integration of strains to displacements",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"strain", " ", "=", " ", 
    RowBox[{"Simplify", "[", " ", 
     RowBox[{"eps", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]}], ")"}], " ", "//", 
  " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"a6", "+", 
       RowBox[{"a3", " ", "x"}], "+", 
       RowBox[{"a4", " ", "y"}], "+", 
       RowBox[{"a1", " ", "x", " ", "y"}], "+", 
       RowBox[{"a5", " ", "z"}], "+", 
       RowBox[{"a2", " ", "x", " ", "z"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       RowBox[{"sxy", "[", 
        RowBox[{"y", ",", "z"}], "]"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       RowBox[{"sxz", "[", 
        RowBox[{"y", ",", "z"}], "]"}]}]},
     {
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       RowBox[{"sxy", "[", 
        RowBox[{"y", ",", "z"}], "]"}]}], 
      RowBox[{
       RowBox[{"-", "nu"}], " ", 
       RowBox[{"(", 
        RowBox[{"a6", "+", 
         RowBox[{"a3", " ", "x"}], "+", 
         RowBox[{"a4", " ", "y"}], "+", 
         RowBox[{"a1", " ", "x", " ", "y"}], "+", 
         RowBox[{"a5", " ", "z"}], "+", 
         RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], "0"},
     {
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       RowBox[{"sxz", "[", 
        RowBox[{"y", ",", "z"}], "]"}]}], "0", 
      RowBox[{
       RowBox[{"-", "nu"}], " ", 
       RowBox[{"(", 
        RowBox[{"a6", "+", 
         RowBox[{"a3", " ", "x"}], "+", 
         RowBox[{"a4", " ", "y"}], "+", 
         RowBox[{"a1", " ", "x", " ", "y"}], "+", 
         RowBox[{"a5", " ", "z"}], "+", 
         RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pp", " ", "=", " ", 
  RowBox[{"Coordinates", "[", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"u", " ", ":=", " ", 
   RowBox[{"Map", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Integrate", "[", " ", 
        RowBox[{
         RowBox[{"strain", "[", 
          RowBox[{"[", 
           RowBox[{"#", ",", "#"}], "]"}], "]"}], " ", ",", " ", 
         RowBox[{"pp", "[", 
          RowBox[{"[", "#", "]"}], "]"}]}], " ", "]"}], "  ", "+", " ", 
       RowBox[{
        RowBox[{"ToExpression", "[", 
         RowBox[{"\"\<K\>\"", "<>", 
          RowBox[{"ToString", "[", 
           RowBox[{"pp", "[", 
            RowBox[{"[", "#", "]"}], "]"}], "]"}]}], " ", "]"}], " ", "@@", 
        " ", 
        RowBox[{"Drop", "[", 
         RowBox[{"pp", ",", " ", 
          RowBox[{"{", "#", "}"}]}], "]"}]}]}], " ", "&"}], " ", ",", " ", 
     RowBox[{"Range", "[", "3", "]"}]}], "]"}]}], 
  " "}], "\[IndentingNewLine]", "u"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"a6", " ", "x"}], "+", 
    FractionBox[
     RowBox[{"a3", " ", 
      SuperscriptBox["x", "2"]}], "2"], "+", 
    RowBox[{"a4", " ", "x", " ", "y"}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "a1", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"a5", " ", "x", " ", "z"}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "a2", " ", 
     SuperscriptBox["x", "2"], " ", "z"}], "+", 
    RowBox[{"Kx", "[", 
     RowBox[{"y", ",", "z"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", "nu", " ", "y", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "a6"}], "+", 
       RowBox[{"2", " ", "a3", " ", "x"}], "+", 
       RowBox[{"a4", " ", "y"}], "+", 
       RowBox[{"a1", " ", "x", " ", "y"}], "+", 
       RowBox[{"2", " ", "a5", " ", "z"}], "+", 
       RowBox[{"2", " ", "a2", " ", "x", " ", "z"}]}], ")"}]}], "+", 
    RowBox[{"Ky", "[", 
     RowBox[{"x", ",", "z"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", "nu", " ", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "a6"}], "+", 
       RowBox[{"2", " ", "a3", " ", "x"}], "+", 
       RowBox[{"2", " ", "a4", " ", "y"}], "+", 
       RowBox[{"2", " ", "a1", " ", "x", " ", "y"}], "+", 
       RowBox[{"a5", " ", "z"}], "+", 
       RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], "+", 
    RowBox[{"Kz", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"epsyz", " ", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", " ", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", " ", "y"}], " ", "]"}], " ", "+", 
   " ", 
   RowBox[{"D", "[", " ", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", " ", "z"}], " ", 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", "nu", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "a5"}], "+", 
     RowBox[{"2", " ", "a2", " ", "x"}]}], ")"}], " ", "y"}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "nu", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "a4"}], "+", 
     RowBox[{"2", " ", "a1", " ", "x"}]}], ")"}], " ", "z"}], "+", 
  RowBox[{
   SuperscriptBox["Ky", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "z"}], "]"}], "+", 
  RowBox[{
   SuperscriptBox["Kz", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "y"}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sky", " ", "=", " ", 
   RowBox[{"DSolve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{"epsyz", ",", " ", "z"}], "]"}], " ", "\[Equal]", " ", "0"}], 
     " ", ",", " ", 
     RowBox[{"Ky", "[", 
      RowBox[{"x", ",", "z"}], "]"}], ",", "z"}], "]"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ky", "[", 
   RowBox[{"x", ",", "z"}], "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"sky", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}], " ", "/.", " ", 
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], " ", "\[Rule]", " ", 
     RowBox[{"Ky", "[", "x", "]"}]}]}], " ", "/.", " ", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], " ", "\[Rule]", 
    RowBox[{"-", "  ", 
     RowBox[{"K", "[", "x", "]"}]}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Ky", "[", 
     RowBox[{"x", ",", "z"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", "a4", " ", "nu", " ", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", "a1", " ", "nu", " ", "x", " ", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{"C", "[", "1", "]"}], "+", 
     RowBox[{"z", " ", 
      RowBox[{"C", "[", "2", "]"}]}]}]}], "}"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "a4", " ", "nu", " ", 
   SuperscriptBox["z", "2"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "a1", " ", "nu", " ", "x", " ", 
   SuperscriptBox["z", "2"]}], "-", 
  RowBox[{"z", " ", 
   RowBox[{"K", "[", "x", "]"}]}], "+", 
  RowBox[{"Ky", "[", "x", "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"skz", " ", "=", " ", 
   RowBox[{"DSolve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{"epsyz", ",", " ", "y"}], "]"}], " ", "\[Equal]", " ", "0"}], 
     " ", ",", " ", 
     RowBox[{"Kz", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", "y"}], "]"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Kz", "[", 
   RowBox[{"x", ",", "y"}], "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"skz", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}], " ", "/.", " ", 
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], " ", "\[Rule]", " ", 
     RowBox[{"Kz", "[", "x", "]"}]}]}], " ", "/.", " ", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], " ", "\[Rule]", "  ", 
    RowBox[{"K", "[", "x", "]"}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Kz", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", "a5", " ", "nu", " ", 
      SuperscriptBox["y", "2"]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", "a2", " ", "nu", " ", "x", " ", 
      SuperscriptBox["y", "2"]}], "+", 
     RowBox[{"C", "[", "1", "]"}], "+", 
     RowBox[{"y", " ", 
      RowBox[{"C", "[", "2", "]"}]}]}]}], "}"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "a5", " ", "nu", " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "a2", " ", "nu", " ", "x", " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{"y", " ", 
   RowBox[{"K", "[", "x", "]"}]}], "+", 
  RowBox[{"Kz", "[", "x", "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["u"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"a6", " ", "x"}], "+", 
    FractionBox[
     RowBox[{"a3", " ", 
      SuperscriptBox["x", "2"]}], "2"], "+", 
    RowBox[{"a4", " ", "x", " ", "y"}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "a1", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"a5", " ", "x", " ", "z"}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "a2", " ", 
     SuperscriptBox["x", "2"], " ", "z"}], "+", 
    RowBox[{"Kx", "[", 
     RowBox[{"y", ",", "z"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", "a4", " ", "nu", " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "a1", " ", "nu", " ", "x", " ", 
     SuperscriptBox["z", "2"]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "nu", " ", "y", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "a6"}], "+", 
       RowBox[{"2", " ", "a3", " ", "x"}], "+", 
       RowBox[{"a4", " ", "y"}], "+", 
       RowBox[{"a1", " ", "x", " ", "y"}], "+", 
       RowBox[{"2", " ", "a5", " ", "z"}], "+", 
       RowBox[{"2", " ", "a2", " ", "x", " ", "z"}]}], ")"}]}], "-", 
    RowBox[{"z", " ", 
     RowBox[{"K", "[", "x", "]"}]}], "+", 
    RowBox[{"Ky", "[", "x", "]"}]}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", "a5", " ", "nu", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "a2", " ", "nu", " ", "x", " ", 
     SuperscriptBox["y", "2"]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "nu", " ", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "a6"}], "+", 
       RowBox[{"2", " ", "a3", " ", "x"}], "+", 
       RowBox[{"2", " ", "a4", " ", "y"}], "+", 
       RowBox[{"2", " ", "a1", " ", "x", " ", "y"}], "+", 
       RowBox[{"a5", " ", "z"}], "+", 
       RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], "+", 
    RowBox[{"y", " ", 
     RowBox[{"K", "[", "x", "]"}]}], "+", 
    RowBox[{"Kz", "[", "x", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"strain", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{"1", "/", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Grad", "[", "u", "]"}], "]"}]}], " ", ")"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a6", "+", 
      RowBox[{"a3", " ", "x"}], "+", 
      RowBox[{"a4", " ", "y"}], "+", 
      RowBox[{"a1", " ", "x", " ", "y"}], "+", 
      RowBox[{"a5", " ", "z"}], "+", 
      RowBox[{"a2", " ", "x", " ", "z"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a4", " ", "x"}], "+", 
        FractionBox[
         RowBox[{"a1", " ", 
          SuperscriptBox["x", "2"]}], "2"], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", "a1", " ", "nu", " ", 
         SuperscriptBox["z", "2"]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", "nu", " ", "y", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a3"}], "+", 
           RowBox[{"a1", " ", "y"}], "+", 
           RowBox[{"2", " ", "a2", " ", "z"}]}], ")"}]}], "-", 
        RowBox[{"z", " ", 
         RowBox[{
          SuperscriptBox["K", "\[Prime]",
           MultilineFunction->None], "[", "x", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["Ky", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}], "+", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a5", " ", "x"}], "+", 
        FractionBox[
         RowBox[{"a2", " ", 
          SuperscriptBox["x", "2"]}], "2"], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", "a2", " ", "nu", " ", 
         SuperscriptBox["y", "2"]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", "nu", " ", "z", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a3"}], "+", 
           RowBox[{"2", " ", "a1", " ", "y"}], "+", 
           RowBox[{"a2", " ", "z"}]}], ")"}]}], "+", 
        RowBox[{"y", " ", 
         RowBox[{
          SuperscriptBox["K", "\[Prime]",
           MultilineFunction->None], "[", "x", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["Kz", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}], "+", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a4", " ", "x"}], "+", 
        FractionBox[
         RowBox[{"a1", " ", 
          SuperscriptBox["x", "2"]}], "2"], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", "a1", " ", "nu", " ", 
         SuperscriptBox["z", "2"]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", "nu", " ", "y", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a3"}], "+", 
           RowBox[{"a1", " ", "y"}], "+", 
           RowBox[{"2", " ", "a2", " ", "z"}]}], ")"}]}], "-", 
        RowBox[{"z", " ", 
         RowBox[{
          SuperscriptBox["K", "\[Prime]",
           MultilineFunction->None], "[", "x", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["Ky", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}], "+", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "nu"}], " ", 
      RowBox[{"(", 
       RowBox[{"a6", "+", 
        RowBox[{"a3", " ", "x"}], "+", 
        RowBox[{"a4", " ", "y"}], "+", 
        RowBox[{"a1", " ", "x", " ", "y"}], "+", 
        RowBox[{"a5", " ", "z"}], "+", 
        RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], ",", "0"}], "}"}], ",",
    
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a5", " ", "x"}], "+", 
        FractionBox[
         RowBox[{"a2", " ", 
          SuperscriptBox["x", "2"]}], "2"], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", "a2", " ", "nu", " ", 
         SuperscriptBox["y", "2"]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", "nu", " ", "z", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a3"}], "+", 
           RowBox[{"2", " ", "a1", " ", "y"}], "+", 
           RowBox[{"a2", " ", "z"}]}], ")"}]}], "+", 
        RowBox[{"y", " ", 
         RowBox[{
          SuperscriptBox["K", "\[Prime]",
           MultilineFunction->None], "[", "x", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["Kz", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}], "+", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}], ")"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"-", "nu"}], " ", 
      RowBox[{"(", 
       RowBox[{"a6", "+", 
        RowBox[{"a3", " ", "x"}], "+", 
        RowBox[{"a4", " ", "y"}], "+", 
        RowBox[{"a1", " ", "x", " ", "y"}], "+", 
        RowBox[{"a5", " ", "z"}], "+", 
        RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sig", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"nu", " ", "/", 
       RowBox[{"(", 
        RowBox[{"1", " ", "+", " ", "nu"}], ")"}]}], " ", "/", " ", 
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", 
        RowBox[{"2", " ", "nu"}]}], ")"}]}], " ", 
     RowBox[{"Tr", "[", " ", "strain", " ", "]"}], " ", 
     RowBox[{"IdentityMatrix", "[", " ", "3", " ", "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"1", " ", "/", " ", 
      RowBox[{"(", 
       RowBox[{"1", " ", "+", " ", "nu"}], ")"}]}], " ", "strain"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a6", "+", 
      RowBox[{"a3", " ", "x"}], "+", 
      RowBox[{"a4", " ", "y"}], "+", 
      RowBox[{"a1", " ", "x", " ", "y"}], "+", 
      RowBox[{"a5", " ", "z"}], "+", 
      RowBox[{"a2", " ", "x", " ", "z"}]}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"a4", " ", "x"}], "+", 
       FractionBox[
        RowBox[{"a1", " ", 
         SuperscriptBox["x", "2"]}], "2"], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "a1", " ", "nu", " ", 
        SuperscriptBox["z", "2"]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "nu", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a3"}], "+", 
          RowBox[{"a1", " ", "y"}], "+", 
          RowBox[{"2", " ", "a2", " ", "z"}]}], ")"}]}], "-", 
       RowBox[{"z", " ", 
        RowBox[{
         SuperscriptBox["K", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["Ky", "\[Prime]",
         MultilineFunction->None], "[", "x", "]"}], "+", 
       RowBox[{
        SuperscriptBox["Kx", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"y", ",", "z"}], "]"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"a5", " ", "x"}], "+", 
       FractionBox[
        RowBox[{"a2", " ", 
         SuperscriptBox["x", "2"]}], "2"], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "a2", " ", "nu", " ", 
        SuperscriptBox["y", "2"]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "nu", " ", "z", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a3"}], "+", 
          RowBox[{"2", " ", "a1", " ", "y"}], "+", 
          RowBox[{"a2", " ", "z"}]}], ")"}]}], "+", 
       RowBox[{"y", " ", 
        RowBox[{
         SuperscriptBox["K", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["Kz", "\[Prime]",
         MultilineFunction->None], "[", "x", "]"}], "+", 
       RowBox[{
        SuperscriptBox["Kx", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"y", ",", "z"}], "]"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"a4", " ", "x"}], "+", 
       FractionBox[
        RowBox[{"a1", " ", 
         SuperscriptBox["x", "2"]}], "2"], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "a1", " ", "nu", " ", 
        SuperscriptBox["z", "2"]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "nu", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a3"}], "+", 
          RowBox[{"a1", " ", "y"}], "+", 
          RowBox[{"2", " ", "a2", " ", "z"}]}], ")"}]}], "-", 
       RowBox[{"z", " ", 
        RowBox[{
         SuperscriptBox["K", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["Ky", "\[Prime]",
         MultilineFunction->None], "[", "x", "]"}], "+", 
       RowBox[{
        SuperscriptBox["Kx", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"y", ",", "z"}], "]"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}]}]], ",", "0", ",", "0"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"a5", " ", "x"}], "+", 
       FractionBox[
        RowBox[{"a2", " ", 
         SuperscriptBox["x", "2"]}], "2"], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "a2", " ", "nu", " ", 
        SuperscriptBox["y", "2"]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "nu", " ", "z", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a3"}], "+", 
          RowBox[{"2", " ", "a1", " ", "y"}], "+", 
          RowBox[{"a2", " ", "z"}]}], ")"}]}], "+", 
       RowBox[{"y", " ", 
        RowBox[{
         SuperscriptBox["K", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["Kz", "\[Prime]",
         MultilineFunction->None], "[", "x", "]"}], "+", 
       RowBox[{
        SuperscriptBox["Kx", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"y", ",", "z"}], "]"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}]}]], ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"newdiv", " ", ":=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Div", "[", "sig", "]"}], "]"}]}], " "}], "\[IndentingNewLine]", 
 RowBox[{"newdiv", " ", "//", "  ", "MatrixForm"}]}], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", "a3"}], "+", 
        RowBox[{"2", " ", "a1", " ", "y"}], "+", 
        RowBox[{"2", " ", "a2", " ", "z"}], "+", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}], "+", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}], 
       RowBox[{"2", "+", 
        RowBox[{"2", " ", "nu"}]}]]},
     {
      FractionBox[
       RowBox[{"a4", "+", 
        RowBox[{"a1", " ", "x"}], "-", 
        RowBox[{"z", " ", 
         RowBox[{
          SuperscriptBox["K", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "x", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["Ky", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], 
       RowBox[{"2", "+", 
        RowBox[{"2", " ", "nu"}]}]]},
     {
      FractionBox[
       RowBox[{"a5", "+", 
        RowBox[{"a2", " ", "x"}], "+", 
        RowBox[{"y", " ", 
         RowBox[{
          SuperscriptBox["K", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "x", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["Kz", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], 
       RowBox[{"2", "+", 
        RowBox[{"2", " ", "nu"}]}]]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{(2 + 2 nu)^(-1) (2 a3 + 2 a1 y + 2 a2 z + 
     Derivative[0, 2][Kx][y, z] + 
     Derivative[2, 0][Kx][y, z]), (2 + 2 nu)^(-1) (a4 + a1 x - z 
     Derivative[2][K][x] + Derivative[2][Ky][x]), (2 + 2 nu)^(-1) (a5 + a2 x + 
     y Derivative[2][K][x] + Derivative[2][Kz][x])}]]], "Output"]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"K", "[", "x", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"c", " ", "x"}], " ", "+", " ", "rx", " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"rx", "+", 
  RowBox[{"c", " ", "x"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"newdiv", " ", "=", " ", 
  RowBox[{"newdiv", " ", "/.", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"K", "''"}], "[", "x", "]"}], " ", "\[Rule]", " ", 
    "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", "a3"}], "+", 
     RowBox[{"2", " ", "a1", " ", "y"}], "+", 
     RowBox[{"2", " ", "a2", " ", "z"}], "+", 
     RowBox[{
      SuperscriptBox["Kx", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["Kx", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}]}], 
    RowBox[{"2", "+", 
     RowBox[{"2", " ", "nu"}]}]], ",", 
   FractionBox[
    RowBox[{"a4", "+", 
     RowBox[{"a1", " ", "x"}], "+", 
     RowBox[{
      SuperscriptBox["Ky", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "x", "]"}]}], 
    RowBox[{"2", "+", 
     RowBox[{"2", " ", "nu"}]}]], ",", 
   FractionBox[
    RowBox[{"a5", "+", 
     RowBox[{"a2", " ", "x"}], "+", 
     RowBox[{
      SuperscriptBox["Kz", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "x", "]"}]}], 
    RowBox[{"2", "+", 
     RowBox[{"2", " ", "nu"}]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DSolve", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"newdiv", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "==", "0"}], "  ", ",", " ", 
   RowBox[{
    RowBox[{"Ky", "''"}], "[", "x", "]"}], ",", " ", "x"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ky", "[", "x", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}], " ", "/.", " ", 
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], " ", "\[Rule]", " ", 
     RowBox[{"-", " ", "ly"}]}]}], "  ", "/.", " ", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], " ", "\[Rule]", " ", 
    RowBox[{
     RowBox[{"-", " ", "ry"}], "  "}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Ky", "[", "x", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"a4", " ", 
        SuperscriptBox["x", "2"]}], "2"]}], "-", 
     FractionBox[
      RowBox[{"a1", " ", 
       SuperscriptBox["x", "3"]}], "6"], "+", 
     RowBox[{"C", "[", "1", "]"}], "+", 
     RowBox[{"x", " ", 
      RowBox[{"C", "[", "2", "]"}]}]}]}], "}"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "ly"}], "-", 
  RowBox[{"ry", " ", "x"}], "-", 
  FractionBox[
   RowBox[{"a4", " ", 
    SuperscriptBox["x", "2"]}], "2"], "-", 
  FractionBox[
   RowBox[{"a1", " ", 
    SuperscriptBox["x", "3"]}], "6"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DSolve", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"newdiv", "[", 
     RowBox[{"[", "3", "]"}], "]"}], " ", "==", "0"}], ",", " ", 
   RowBox[{
    RowBox[{"Kz", "''"}], "[", "x", "]"}], ",", " ", "x"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Kz", "[", "x", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}], " ", "/.", " ", 
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], " ", "\[Rule]", " ", 
     RowBox[{"-", " ", "lz"}]}]}], " ", "/.", " ", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], " ", "\[Rule]", " ", 
    RowBox[{
     RowBox[{"-", " ", "rz"}], "  "}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Kz", "[", "x", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"a5", " ", 
        SuperscriptBox["x", "2"]}], "2"]}], "-", 
     FractionBox[
      RowBox[{"a2", " ", 
       SuperscriptBox["x", "3"]}], "6"], "+", 
     RowBox[{"C", "[", "1", "]"}], "+", 
     RowBox[{"x", " ", 
      RowBox[{"C", "[", "2", "]"}]}]}]}], "}"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "lz"}], "-", 
  RowBox[{"rz", " ", "x"}], "-", 
  FractionBox[
   RowBox[{"a5", " ", 
    SuperscriptBox["x", "2"]}], "2"], "-", 
  FractionBox[
   RowBox[{"a2", " ", 
    SuperscriptBox["x", "3"]}], "6"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", " ", "u", " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", "x", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "a6"}], "+", 
       RowBox[{"a3", " ", "x"}], "+", 
       RowBox[{"2", " ", "a4", " ", "y"}], "+", 
       RowBox[{"a1", " ", "x", " ", "y"}], "+", 
       RowBox[{"2", " ", "a5", " ", "z"}], "+", 
       RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], "+", 
    RowBox[{"Kx", "[", 
     RowBox[{"y", ",", "z"}], "]"}]}], ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", "ly"}], "-", 
      RowBox[{"6", " ", "ry", " ", "x"}], "-", 
      RowBox[{"3", " ", "a4", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"a1", " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{"rx", "+", 
         RowBox[{"c", " ", "x"}]}], ")"}], " ", "z"}], "+", 
      RowBox[{"3", " ", "a4", " ", "nu", " ", 
       SuperscriptBox["z", "2"]}], "+", 
      RowBox[{"3", " ", "a1", " ", "nu", " ", "x", " ", 
       SuperscriptBox["z", "2"]}], "-", 
      RowBox[{"3", " ", "nu", " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a6"}], "+", 
         RowBox[{"2", " ", "a3", " ", "x"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a4", "+", 
            RowBox[{"a1", " ", "x"}]}], ")"}], " ", "y"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"a5", "+", 
            RowBox[{"a2", " ", "x"}]}], ")"}], " ", "z"}]}], ")"}]}]}], 
     ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", "lz"}], "-", 
      RowBox[{"6", " ", "rz", " ", "x"}], "-", 
      RowBox[{"3", " ", "a5", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"a2", " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{"rx", "+", 
         RowBox[{"c", " ", "x"}]}], ")"}], " ", "y"}], "+", 
      RowBox[{"3", " ", "a5", " ", "nu", " ", 
       SuperscriptBox["y", "2"]}], "+", 
      RowBox[{"3", " ", "a2", " ", "nu", " ", "x", " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"3", " ", "nu", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"a6", "+", 
            RowBox[{"a3", " ", "x"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"a4", "+", 
               RowBox[{"a1", " ", "x"}]}], ")"}], " ", "y"}]}], ")"}]}], "+", 
         
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a5", "+", 
            RowBox[{"a2", " ", "x"}]}], ")"}], " ", "z"}]}], ")"}]}]}], 
     ")"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", "  ", "=", " ", 
  RowBox[{"u", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Kx", "[", 
     RowBox[{"y", ",", "z"}], "]"}], " ", "->", " ", 
    RowBox[{
     RowBox[{"phi", "[", 
      RowBox[{"y", ",", "z"}], "]"}], " ", "-", " ", 
     RowBox[{"rz", "  ", "z"}], " ", "+", " ", 
     RowBox[{"ry", " ", "y"}]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"a6", " ", "x"}], "+", 
    FractionBox[
     RowBox[{"a3", " ", 
      SuperscriptBox["x", "2"]}], "2"], "+", 
    RowBox[{"ry", " ", "y"}], "+", 
    RowBox[{"a4", " ", "x", " ", "y"}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "a1", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "-", 
    RowBox[{"rz", " ", "z"}], "+", 
    RowBox[{"a5", " ", "x", " ", "z"}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "a2", " ", 
     SuperscriptBox["x", "2"], " ", "z"}], "+", 
    RowBox[{"phi", "[", 
     RowBox[{"y", ",", "z"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "ly"}], "-", 
    RowBox[{"ry", " ", "x"}], "-", 
    FractionBox[
     RowBox[{"a4", " ", 
      SuperscriptBox["x", "2"]}], "2"], "-", 
    FractionBox[
     RowBox[{"a1", " ", 
      SuperscriptBox["x", "3"]}], "6"], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"rx", "+", 
       RowBox[{"c", " ", "x"}]}], ")"}], " ", "z"}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "a4", " ", "nu", " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "a1", " ", "nu", " ", "x", " ", 
     SuperscriptBox["z", "2"]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "nu", " ", "y", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "a6"}], "+", 
       RowBox[{"2", " ", "a3", " ", "x"}], "+", 
       RowBox[{"a4", " ", "y"}], "+", 
       RowBox[{"a1", " ", "x", " ", "y"}], "+", 
       RowBox[{"2", " ", "a5", " ", "z"}], "+", 
       RowBox[{"2", " ", "a2", " ", "x", " ", "z"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", "lz"}], "-", 
    RowBox[{"rz", " ", "x"}], "-", 
    FractionBox[
     RowBox[{"a5", " ", 
      SuperscriptBox["x", "2"]}], "2"], "-", 
    FractionBox[
     RowBox[{"a2", " ", 
      SuperscriptBox["x", "3"]}], "6"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"rx", "+", 
       RowBox[{"c", " ", "x"}]}], ")"}], " ", "y"}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "a5", " ", "nu", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "a2", " ", "nu", " ", "x", " ", 
     SuperscriptBox["y", "2"]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "nu", " ", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "a6"}], "+", 
       RowBox[{"2", " ", "a3", " ", "x"}], "+", 
       RowBox[{"2", " ", "a4", " ", "y"}], "+", 
       RowBox[{"2", " ", "a1", " ", "x", " ", "y"}], "+", 
       RowBox[{"a5", " ", "z"}], "+", 
       RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", " ", "u", "  ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "ry", " ", "y"}], "-", 
       RowBox[{"2", " ", "rz", " ", "z"}], "+", 
       RowBox[{"x", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a6"}], "+", 
          RowBox[{"a3", " ", "x"}], "+", 
          RowBox[{"2", " ", "a4", " ", "y"}], "+", 
          RowBox[{"a1", " ", "x", " ", "y"}], "+", 
          RowBox[{"2", " ", "a5", " ", "z"}], "+", 
          RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"phi", "[", 
     RowBox[{"y", ",", "z"}], "]"}]}], ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", "ly"}], "-", 
      RowBox[{"6", " ", "ry", " ", "x"}], "-", 
      RowBox[{"3", " ", "a4", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"a1", " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{"rx", "+", 
         RowBox[{"c", " ", "x"}]}], ")"}], " ", "z"}], "+", 
      RowBox[{"3", " ", "a4", " ", "nu", " ", 
       SuperscriptBox["z", "2"]}], "+", 
      RowBox[{"3", " ", "a1", " ", "nu", " ", "x", " ", 
       SuperscriptBox["z", "2"]}], "-", 
      RowBox[{"3", " ", "nu", " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a6"}], "+", 
         RowBox[{"2", " ", "a3", " ", "x"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a4", "+", 
            RowBox[{"a1", " ", "x"}]}], ")"}], " ", "y"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"a5", "+", 
            RowBox[{"a2", " ", "x"}]}], ")"}], " ", "z"}]}], ")"}]}]}], 
     ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", "lz"}], "-", 
      RowBox[{"6", " ", "rz", " ", "x"}], "-", 
      RowBox[{"3", " ", "a5", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"a2", " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{"rx", "+", 
         RowBox[{"c", " ", "x"}]}], ")"}], " ", "y"}], "+", 
      RowBox[{"3", " ", "a5", " ", "nu", " ", 
       SuperscriptBox["y", "2"]}], "+", 
      RowBox[{"3", " ", "a2", " ", "nu", " ", "x", " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"3", " ", "nu", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"a6", "+", 
            RowBox[{"a3", " ", "x"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"a4", "+", 
               RowBox[{"a1", " ", "x"}]}], ")"}], " ", "y"}]}], ")"}]}], "+", 
         
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a5", "+", 
            RowBox[{"a2", " ", "x"}]}], ")"}], " ", "z"}]}], ")"}]}]}], 
     ")"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"strain", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", " ", 
   RowBox[{
    RowBox[{"1", "/", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Grad", "[", "u", "]"}], "]"}]}], " ", ")"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a6", "+", 
      RowBox[{"a4", " ", "y"}], "+", 
      RowBox[{"a5", " ", "z"}], "+", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{"a3", "+", 
         RowBox[{"a1", " ", "y"}], "+", 
         RowBox[{"a2", " ", "z"}]}], ")"}]}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "nu"}], " ", "y", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a3"}], "+", 
           RowBox[{"a1", " ", "y"}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"c", "+", 
           RowBox[{"a2", " ", "nu", " ", "y"}]}], ")"}], " ", "z"}], "+", 
        RowBox[{"a1", " ", "nu", " ", 
         SuperscriptBox["z", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", "rz"}], "+", 
        RowBox[{"2", " ", "c", " ", "y"}], "+", 
        RowBox[{"nu", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"a3", "+", 
              RowBox[{"a1", " ", "y"}]}], ")"}], " ", "z"}], "+", 
           RowBox[{"a2", " ", 
            RowBox[{"(", 
             RowBox[{"y", "-", "z"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "nu"}], " ", "y", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a3"}], "+", 
           RowBox[{"a1", " ", "y"}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"c", "+", 
           RowBox[{"a2", " ", "nu", " ", "y"}]}], ")"}], " ", "z"}], "+", 
        RowBox[{"a1", " ", "nu", " ", 
         SuperscriptBox["z", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "nu"}], " ", 
      RowBox[{"(", 
       RowBox[{"a6", "+", 
        RowBox[{"a4", " ", "y"}], "+", 
        RowBox[{"a5", " ", "z"}], "+", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{"a3", "+", 
           RowBox[{"a1", " ", "y"}], "+", 
           RowBox[{"a2", " ", "z"}]}], ")"}]}]}], ")"}]}], ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", "rz"}], "+", 
        RowBox[{"2", " ", "c", " ", "y"}], "+", 
        RowBox[{"nu", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"a3", "+", 
              RowBox[{"a1", " ", "y"}]}], ")"}], " ", "z"}], "+", 
           RowBox[{"a2", " ", 
            RowBox[{"(", 
             RowBox[{"y", "-", "z"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], ")"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"-", "nu"}], " ", 
      RowBox[{"(", 
       RowBox[{"a6", "+", 
        RowBox[{"a4", " ", "y"}], "+", 
        RowBox[{"a5", " ", "z"}], "+", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{"a3", "+", 
           RowBox[{"a1", " ", "y"}], "+", 
           RowBox[{"a2", " ", "z"}]}], ")"}]}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{"FullSimplify", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"nu", " ", "/", 
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", "nu"}], ")"}]}], " ", "/", " ", 
        RowBox[{"(", 
         RowBox[{"1", " ", "-", " ", 
          RowBox[{"2", " ", "nu"}]}], ")"}]}], " ", 
       RowBox[{"Tr", "[", " ", "strain", " ", "]"}], " ", 
       RowBox[{"IdentityMatrix", "[", " ", "3", " ", "]"}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"1", " ", "/", " ", 
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", "nu"}], ")"}]}], " ", "strain"}]}], 
     "]"}]}], " ", ")"}], " ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"a6", "+", 
       RowBox[{"a4", " ", "y"}], "+", 
       RowBox[{"a5", " ", "z"}], "+", 
       RowBox[{"x", " ", 
        RowBox[{"(", 
         RowBox[{"a3", "+", 
          RowBox[{"a1", " ", "y"}], "+", 
          RowBox[{"a2", " ", "z"}]}], ")"}]}]}], 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "nu"}], " ", "y", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a3"}], "+", 
           RowBox[{"a1", " ", "y"}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"c", "+", 
           RowBox[{"a2", " ", "nu", " ", "y"}]}], ")"}], " ", "z"}], "+", 
        RowBox[{"a1", " ", "nu", " ", 
         SuperscriptBox["z", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]], 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", "rz"}], "+", 
        RowBox[{"2", " ", "c", " ", "y"}], "+", 
        RowBox[{"nu", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"a3", "+", 
              RowBox[{"a1", " ", "y"}]}], ")"}], " ", "z"}], "+", 
           RowBox[{"a2", " ", 
            RowBox[{"(", 
             RowBox[{"y", "-", "z"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]]},
     {
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "nu"}], " ", "y", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a3"}], "+", 
           RowBox[{"a1", " ", "y"}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"c", "+", 
           RowBox[{"a2", " ", "nu", " ", "y"}]}], ")"}], " ", "z"}], "+", 
        RowBox[{"a1", " ", "nu", " ", 
         SuperscriptBox["z", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]], "0", "0"},
     {
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", "rz"}], "+", 
        RowBox[{"2", " ", "c", " ", "y"}], "+", 
        RowBox[{"nu", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"a3", "+", 
              RowBox[{"a1", " ", "y"}]}], ")"}], " ", "z"}], "+", 
           RowBox[{"a2", " ", 
            RowBox[{"(", 
             RowBox[{"y", "-", "z"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]], "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"Div", "[", "sig", "]"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", "a3"}], "+", 
     RowBox[{"2", " ", "a1", " ", "y"}], "+", 
     RowBox[{"2", " ", "a2", " ", "z"}], "+", 
     RowBox[{
      SuperscriptBox["phi", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["phi", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}]}], 
    RowBox[{"2", "+", 
     RowBox[{"2", " ", "nu"}]}]], ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"traction", " ", "=", " ", 
    RowBox[{"sig", " ", ".", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", " ", "0", ",", "0"}], "}"}]}]}], " ", ")"}], " ", "//",
   " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"a6", "+", 
       RowBox[{"a4", " ", "y"}], "+", 
       RowBox[{"a5", " ", "z"}], "+", 
       RowBox[{"x", " ", 
        RowBox[{"(", 
         RowBox[{"a3", "+", 
          RowBox[{"a1", " ", "y"}], "+", 
          RowBox[{"a2", " ", "z"}]}], ")"}]}]}]},
     {
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "nu"}], " ", "y", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a3"}], "+", 
           RowBox[{"a1", " ", "y"}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"c", "+", 
           RowBox[{"a2", " ", "nu", " ", "y"}]}], ")"}], " ", "z"}], "+", 
        RowBox[{"a1", " ", "nu", " ", 
         SuperscriptBox["z", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]]},
     {
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", "rz"}], "+", 
        RowBox[{"2", " ", "c", " ", "y"}], "+", 
        RowBox[{"nu", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"a3", "+", 
              RowBox[{"a1", " ", "y"}]}], ")"}], " ", "z"}], "+", 
           RowBox[{"a2", " ", 
            RowBox[{"(", 
             RowBox[{"y", "-", "z"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   a6 + a4 y + a5 z + x (a3 + a1 y + a2 z), 
    Rational[1, 4] (1 + nu)^(-1) (-nu y (2 a3 + a1 y) - 2 (c + a2 nu y) z + 
     a1 nu z^2 + 2 Derivative[1, 0][phi][y, z]), 
    Rational[1, 4] (1 + nu)^(-1) ((-4) rz + 2 c y + 
     nu ((-2) (a3 + a1 y) z + a2 (y - z) (y + z)) + 
     2 Derivative[0, 1][phi][y, z])}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"traction", "  ", "/.", " ", 
    RowBox[{"x", " ", "\[Rule]", " ", "0"}]}], "  ", ")"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a6", "+", 
    RowBox[{"a4", " ", "y"}], "+", 
    RowBox[{"a5", " ", "z"}]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "nu"}], " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a3"}], "+", 
        RowBox[{"a1", " ", "y"}]}], ")"}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"c", "+", 
        RowBox[{"a2", " ", "nu", " ", "y"}]}], ")"}], " ", "z"}], "+", 
     RowBox[{"a1", " ", "nu", " ", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["phi", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}]}]}], 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "rz"}], "+", 
     RowBox[{"2", " ", "c", " ", "y"}], "+", 
     RowBox[{"nu", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"(", 
          RowBox[{"a3", "+", 
           RowBox[{"a1", " ", "y"}]}], ")"}], " ", "z"}], "+", 
        RowBox[{"a2", " ", 
         RowBox[{"(", 
          RowBox[{"y", "-", "z"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["phi", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}]}]}], 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"traction", "  ", "/.", " ", 
    RowBox[{"x", " ", "\[Rule]", " ", "L"}]}], "  ", ")"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a6", "+", 
    RowBox[{"a4", " ", "y"}], "+", 
    RowBox[{"a5", " ", "z"}], "+", 
    RowBox[{"L", " ", 
     RowBox[{"(", 
      RowBox[{"a3", "+", 
       RowBox[{"a1", " ", "y"}], "+", 
       RowBox[{"a2", " ", "z"}]}], ")"}]}]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "nu"}], " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a3"}], "+", 
        RowBox[{"a1", " ", "y"}]}], ")"}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"c", "+", 
        RowBox[{"a2", " ", "nu", " ", "y"}]}], ")"}], " ", "z"}], "+", 
     RowBox[{"a1", " ", "nu", " ", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["phi", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}]}]}], 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "rz"}], "+", 
     RowBox[{"2", " ", "c", " ", "y"}], "+", 
     RowBox[{"nu", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"(", 
          RowBox[{"a3", "+", 
           RowBox[{"a1", " ", "y"}]}], ")"}], " ", "z"}], "+", 
        RowBox[{"a2", " ", 
         RowBox[{"(", 
          RowBox[{"y", "-", "z"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["phi", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}]}]}], 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sig", " ", "/.", " ", 
  RowBox[{"a3", " ", "\[Rule]", " ", "0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a6", "+", 
      RowBox[{"a4", " ", "y"}], "+", 
      RowBox[{"a5", " ", "z"}], "+", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a1", " ", "y"}], "+", 
         RowBox[{"a2", " ", "z"}]}], ")"}]}]}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "a1"}], " ", "nu", " ", 
        SuperscriptBox["y", "2"]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"c", "+", 
          RowBox[{"a2", " ", "nu", " ", "y"}]}], ")"}], " ", "z"}], "+", 
       RowBox[{"a1", " ", "nu", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["phi", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "rz"}], "+", 
       RowBox[{"2", " ", "c", " ", "y"}], "+", 
       RowBox[{"nu", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "a1", " ", "y", " ", "z"}], "+", 
          RowBox[{"a2", " ", 
           RowBox[{"(", 
            RowBox[{"y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["phi", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "a1"}], " ", "nu", " ", 
        SuperscriptBox["y", "2"]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"c", "+", 
          RowBox[{"a2", " ", "nu", " ", "y"}]}], ")"}], " ", "z"}], "+", 
       RowBox[{"a1", " ", "nu", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["phi", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}]}]], ",", "0", ",", "0"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "rz"}], "+", 
       RowBox[{"2", " ", "c", " ", "y"}], "+", 
       RowBox[{"nu", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "a1", " ", "y", " ", "z"}], "+", 
          RowBox[{"a2", " ", 
           RowBox[{"(", 
            RowBox[{"y", "-", "z"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["phi", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}]}]], ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"traction", " ", "=", " ", 
    RowBox[{
     RowBox[{"sig", " ", ".", " ", 
      RowBox[{"{", 
       RowBox[{"1", ",", " ", "0", ",", "0"}], "}"}]}], "  ", "/.", " ", 
     RowBox[{"a3", " ", "\[Rule]", " ", "0"}]}]}], ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"a6", "+", 
       RowBox[{"a4", " ", "y"}], "+", 
       RowBox[{"a5", " ", "z"}], "+", 
       RowBox[{"x", " ", 
        RowBox[{"(", 
         RowBox[{"a3", "+", 
          RowBox[{"a1", " ", "y"}], "+", 
          RowBox[{"a2", " ", "z"}]}], ")"}]}]}]},
     {
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "nu"}], " ", "y", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a3"}], "+", 
           RowBox[{"a1", " ", "y"}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"c", "+", 
           RowBox[{"a2", " ", "nu", " ", "y"}]}], ")"}], " ", "z"}], "+", 
        RowBox[{"a1", " ", "nu", " ", 
         SuperscriptBox["z", "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]]},
     {
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", "rz"}], "+", 
        RowBox[{"2", " ", "c", " ", "y"}], "+", 
        RowBox[{"nu", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{"a3", "+", 
              RowBox[{"a1", " ", "y"}]}], ")"}], " ", "z"}], "+", 
           RowBox[{"a2", " ", 
            RowBox[{"(", 
             RowBox[{"y", "-", "z"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   a6 + a4 y + a5 z + x (a3 + a1 y + a2 z), 
    Rational[1, 4] (1 + nu)^(-1) (-nu y (2 a3 + a1 y) - 2 (c + a2 nu y) z + 
     a1 nu z^2 + 2 Derivative[1, 0][phi][y, z]), 
    Rational[1, 4] (1 + nu)^(-1) ((-4) rz + 2 c y + 
     nu ((-2) (a3 + a1 y) z + a2 (y - z) (y + z)) + 
     2 Derivative[0, 1][phi][y, z])}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"traction", "  ", "/.", " ", 
     RowBox[{"x", " ", "\[Rule]", " ", "0"}]}], "  ", "/.", " ", 
    RowBox[{"a3", " ", "\[Rule]", " ", "0"}]}], " ", ")"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a6", "+", 
    RowBox[{"a4", " ", "y"}], "+", 
    RowBox[{"a5", " ", "z"}]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "a1"}], " ", "nu", " ", 
      SuperscriptBox["y", "2"]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"c", "+", 
        RowBox[{"a2", " ", "nu", " ", "y"}]}], ")"}], " ", "z"}], "+", 
     RowBox[{"a1", " ", "nu", " ", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["phi", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}]}]}], 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "rz"}], "+", 
     RowBox[{"2", " ", "c", " ", "y"}], "+", 
     RowBox[{"nu", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "a1", " ", "y", " ", "z"}], "+", 
        RowBox[{"a2", " ", 
         RowBox[{"(", 
          RowBox[{"y", "-", "z"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["phi", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}]}]}], 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"traction", "  ", "/.", " ", 
     RowBox[{"x", " ", "\[Rule]", " ", "L"}]}], "  ", "/.", " ", 
    RowBox[{"a3", " ", "\[Rule]", " ", "0"}]}], " ", ")"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a6", "+", 
    RowBox[{"a4", " ", "y"}], "+", 
    RowBox[{"a5", " ", "z"}], "+", 
    RowBox[{"L", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a1", " ", "y"}], "+", 
       RowBox[{"a2", " ", "z"}]}], ")"}]}]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "a1"}], " ", "nu", " ", 
      SuperscriptBox["y", "2"]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"c", "+", 
        RowBox[{"a2", " ", "nu", " ", "y"}]}], ")"}], " ", "z"}], "+", 
     RowBox[{"a1", " ", "nu", " ", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["phi", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}]}]}], 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "rz"}], "+", 
     RowBox[{"2", " ", "c", " ", "y"}], "+", 
     RowBox[{"nu", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "a1", " ", "y", " ", "z"}], "+", 
        RowBox[{"a2", " ", 
         RowBox[{"(", 
          RowBox[{"y", "-", "z"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["phi", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}]}]}], 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
PrintingStyleEnvironment->"Condensed",
WindowSize->{1192, 821},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{612, 792},
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "local", 
   "constant", "Oxford", "Tex", "ElasticaBook", 
   "C04_CompleteElasticityProblem", "NB"}, "st_venant.nb.ps", 
  CharacterEncoding -> "iso8859-1"]},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 69, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[1425, 43, 306, 9, 55, "Input"],
Cell[1734, 54, 85, 1, 31, "Output"]
}, Open  ]],
Cell[1834, 58, 97, 2, 55, "Input"],
Cell[CellGroupData[{
Cell[1956, 64, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2068, 69, 137, 3, 32, "Input"],
Cell[2208, 74, 96, 2, 31, "Output"]
}, Open  ]],
Cell[2319, 79, 773, 23, 32, "Input"],
Cell[CellGroupData[{
Cell[3117, 106, 470, 13, 77, "Input"],
Cell[3590, 121, 385, 8, 24, "Message"],
Cell[3978, 131, 1795, 55, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5810, 191, 177, 5, 32, "Input"],
Cell[5990, 198, 80, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6107, 205, 177, 5, 32, "Input"],
Cell[6287, 212, 80, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6404, 219, 367, 11, 32, "Input"],
Cell[6774, 232, 1101, 35, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7912, 272, 650, 19, 55, "Input"],
Cell[8565, 293, 1385, 46, 60, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9987, 344, 500, 14, 43, "Input"],
Cell[10490, 360, 385, 8, 20, "Message"],
Cell[10878, 370, 7934, 242, 189, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18849, 617, 426, 10, 43, "Input"],
Cell[19278, 629, 231, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19546, 640, 72, 1, 27, "Input"],
Cell[19621, 643, 3805, 122, 179, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[23475, 771, 111, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[23611, 776, 140, 4, 27, "Input"],
Cell[23754, 782, 511, 19, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24302, 806, 397, 13, 27, "Input"],
Cell[24702, 821, 572, 21, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25311, 847, 252, 7, 27, "Input"],
Cell[25566, 856, 657, 24, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26260, 885, 397, 13, 27, "Input"],
Cell[26660, 900, 572, 21, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27269, 926, 456, 15, 27, "Input"],
Cell[27728, 943, 1021, 38, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28786, 986, 252, 7, 27, "Input"],
Cell[29041, 995, 657, 24, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29747, 1025, 105, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[29877, 1030, 246, 7, 27, "Input"],
Cell[30126, 1039, 1696, 52, 63, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31859, 1096, 93, 2, 27, "Input"],
Cell[31955, 1100, 83, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32075, 1107, 896, 25, 43, "Input"],
Cell[32974, 1134, 1564, 45, 82, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34575, 1184, 359, 12, 27, "Input"],
Cell[34937, 1198, 828, 30, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35802, 1233, 848, 26, 43, "Input"],
Cell[36653, 1261, 506, 15, 44, "Output"],
Cell[37162, 1278, 345, 10, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37544, 1293, 827, 25, 43, "Input"],
Cell[38374, 1320, 506, 15, 44, "Output"],
Cell[38883, 1337, 345, 10, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39265, 1352, 27, 0, 27, "Input"],
Cell[39295, 1354, 2052, 57, 82, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41384, 1416, 334, 10, 27, "Input"],
Cell[41721, 1428, 5640, 166, 186, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47398, 1599, 639, 18, 27, "Input"],
Cell[48040, 1619, 5014, 152, 205, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53091, 1776, 231, 5, 43, "Input"],
Cell[53325, 1783, 2017, 58, 89, "Output"]
}, Open  ]],
Cell[55357, 1844, 45, 0, 43, "Input"],
Cell[CellGroupData[{
Cell[55427, 1848, 150, 4, 27, "Input"],
Cell[55580, 1854, 74, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55691, 1861, 200, 6, 27, "Input"],
Cell[55894, 1869, 1229, 41, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57160, 1915, 724, 22, 43, "Input"],
Cell[57887, 1939, 454, 15, 46, "Output"],
Cell[58344, 1956, 257, 9, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58638, 1970, 722, 22, 43, "Input"],
Cell[59363, 1994, 454, 15, 46, "Output"],
Cell[59820, 2011, 257, 9, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60114, 2025, 75, 1, 27, "Input"],
Cell[60192, 2028, 2850, 84, 116, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63079, 2117, 356, 10, 27, "Input"],
Cell[63438, 2129, 2631, 77, 122, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66106, 2211, 76, 1, 27, "Input"],
Cell[66185, 2214, 3034, 89, 116, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69256, 2308, 338, 10, 27, "Input"],
Cell[69597, 2320, 4727, 148, 152, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74361, 2473, 749, 20, 27, "Input"],
Cell[75113, 2495, 4123, 128, 101, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79273, 2628, 112, 3, 27, "Input"],
Cell[79388, 2633, 743, 25, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80168, 2663, 246, 7, 27, "Input"],
Cell[80417, 2672, 2566, 77, 89, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83020, 2754, 157, 4, 27, "Input"],
Cell[83180, 2760, 1820, 61, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85037, 2826, 157, 4, 27, "Input"],
Cell[85197, 2832, 1977, 66, 89, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87211, 2903, 102, 2, 27, "Input"],
Cell[87316, 2907, 3676, 118, 89, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91029, 3030, 324, 9, 27, "Input"],
Cell[91356, 3041, 2566, 77, 89, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93959, 3123, 236, 6, 27, "Input"],
Cell[94198, 3131, 1650, 55, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[95885, 3191, 236, 6, 27, "Input"],
Cell[96124, 3199, 1796, 60, 48, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

