(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    120627,       4015]
NotebookOptionsPosition[    112926,       3758]
NotebookOutlinePosition[    113774,       3785]
CellTagsIndexPosition[    113731,       3782]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["\<\
The Saint Venant Solution - with young modulus in the computation\
\>", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", 
   "\"\</local/constant/Oxford/Tex/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/Oxford/Tex/ElasticaBook/Packages\"\>"], \
"Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]"}]], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sigma", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sxx", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", " ", 
      RowBox[{"sxy", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", " ", 
      RowBox[{"sxz", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sxy", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", " ", "0", ",", " ", 
      "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sxz", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", " ", "0", ",", " ", 
      "0"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigma", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"sxx", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], 
      RowBox[{"sxy", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], 
      RowBox[{"sxz", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]},
     {
      RowBox[{"sxy", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], "0", "0"},
     {
      RowBox[{"sxz", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"div", " ", ":=", " ", 
    RowBox[{"Thread", "[", " ", 
     RowBox[{
      RowBox[{"Div", "[", " ", 
       RowBox[{"sigma", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], " ", "\[Equal]", " ",
       
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], " ", "]"}]}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"div", " ", "//", " ", "MatrixForm"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(div\\)\\\" is similar to existing symbol \\\"\\!\\(Div\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["sxz", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{
         SuperscriptBox["sxy", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{
         SuperscriptBox["sxx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["sxy", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["sxz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], "\[Equal]", "0"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   Derivative[0, 0, 1][sxz][x, y, z] + Derivative[0, 1, 0][sxy][x, y, z] + 
     Derivative[1, 0, 0][sxx][x, y, z] == 0, 
    Derivative[1, 0, 0][sxy][x, y, z] == 0, Derivative[1, 0, 0][sxz][x, y, z] == 
    0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sxy", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "=", " ", 
  RowBox[{"sxy", "[", 
   RowBox[{"y", ",", "z"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"sxy", "[", 
  RowBox[{"y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sxz", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "=", " ", 
  RowBox[{"sxz", "[", 
   RowBox[{"y", ",", "z"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"sxz", "[", 
  RowBox[{"y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Thread", "[", " ", 
    RowBox[{
     RowBox[{"Div", "[", " ", 
      RowBox[{"sigma", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], " ", "\[Equal]", " ", 
     
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], " ", "]"}], " ", ")"}], " ",
   "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["sxz", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}], "+", 
        RowBox[{
         SuperscriptBox["sxy", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}], "+", 
        RowBox[{
         SuperscriptBox["sxx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "\[Equal]", "0"}]},
     {"True"},
     {"True"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   Derivative[0, 1][sxz][y, z] + Derivative[1, 0][sxy][y, z] + 
     Derivative[1, 0, 0][sxx][x, y, z] == 0, True, True}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"eps", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", " ", "+", " ", "nu"}], ")"}], " ", "/", " ", "EE"}], " ", 
    RowBox[{"sigma", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], " ", "-", " ", 
   RowBox[{
    RowBox[{"nu", "  ", "/", " ", "EE"}], " ", 
    RowBox[{"Tr", "[", " ", 
     RowBox[{"sigma", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], " ", 
    RowBox[{"IdentityMatrix", "[", "3", "]"}], 
    " "}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eps", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "  ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"nu", " ", 
          RowBox[{"sxx", "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "EE"]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{"sxx", "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "EE"]}], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"sxy", "[", 
         RowBox[{"y", ",", "z"}], "]"}]}], "EE"], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"sxz", "[", 
         RowBox[{"y", ",", "z"}], "]"}]}], "EE"]},
     {
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"sxy", "[", 
         RowBox[{"y", ",", "z"}], "]"}]}], "EE"], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"nu", " ", 
         RowBox[{"sxx", "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "EE"]}], "0"},
     {
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"sxz", "[", 
         RowBox[{"y", ",", "z"}], "]"}]}], "EE"], "0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"nu", " ", 
         RowBox[{"sxx", "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "EE"]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"inc", " ", ":=", " ", 
    RowBox[{"Thread", "[", " ", 
     RowBox[{
      RowBox[{"Flatten", "[", " ", 
       RowBox[{"Inc", "[", " ", 
        RowBox[{"eps", "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], " ", "]"}], " ", 
      "\[Equal]", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{"0", " ", "&"}], ",", " ", "9"}], "]"}]}], "]"}]}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"inc", "  ", "//", " ", "MatrixForm"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(inc\\)\\\" is similar to existing symbol \\\"\\!\\(Inc\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"nu", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["sxx", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
            RowBox[{
             SuperscriptBox["sxx", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], ")"}]}], "EE"]}], 
       "\[Equal]", "0"}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "+", "nu"}], ")"}]}], " ", 
          RowBox[{
           SuperscriptBox["sxy", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["sxz", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}], "+", 
         RowBox[{"nu", " ", 
          RowBox[{
           SuperscriptBox["sxx", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "EE"], "\[Equal]", 
       "0"}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["sxy", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["sxz", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}], "+", 
         RowBox[{"nu", " ", 
          RowBox[{
           SuperscriptBox["sxx", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "EE"], "\[Equal]", 
       "0"}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "+", "nu"}], ")"}]}], " ", 
          RowBox[{
           SuperscriptBox["sxy", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["sxz", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}], "+", 
         RowBox[{"nu", " ", 
          RowBox[{
           SuperscriptBox["sxx", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "EE"], "\[Equal]", 
       "0"}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["sxx", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}], "-", 
         RowBox[{"nu", " ", 
          RowBox[{
           SuperscriptBox["sxx", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "EE"], "\[Equal]", 
       "0"}]},
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["sxx", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}], "EE"]}], "\[Equal]", 
       "0"}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["sxy", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["sxz", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}], "+", 
         RowBox[{"nu", " ", 
          RowBox[{
           SuperscriptBox["sxx", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "EE"], "\[Equal]", 
       "0"}]},
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["sxx", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}], "EE"]}], "\[Equal]", 
       "0"}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["sxx", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}], "-", 
         RowBox[{"nu", " ", 
          RowBox[{
           SuperscriptBox["sxx", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}], "EE"], "\[Equal]", 
       "0"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{-EE^(-1) 
     nu (Derivative[0, 0, 2][sxx][x, y, z] + 
      Derivative[0, 2, 0][sxx][x, y, z]) == 0, 
    EE^(-1) (-(1 + nu) Derivative[0, 2][sxy][y, z] + (1 + nu) 
       Derivative[1, 1][sxz][y, z] + nu Derivative[1, 1, 0][sxx][x, y, z]) == 
    0, EE^(-1) ((1 + nu) Derivative[1, 1][sxy][y, z] - (1 + nu) 
      Derivative[2, 0][sxz][y, z] + nu Derivative[1, 0, 1][sxx][x, y, z]) == 
    0, EE^(-1) (-(1 + nu) Derivative[0, 2][sxy][y, z] + (1 + nu) 
       Derivative[1, 1][sxz][y, z] + nu Derivative[1, 1, 0][sxx][x, y, z]) == 
    0, EE^(-1) (Derivative[0, 0, 2][sxx][x, y, z] - nu 
      Derivative[2, 0, 0][sxx][x, y, z]) == 
    0, -EE^(-1) Derivative[0, 1, 1][sxx][x, y, z] == 0, 
    EE^(-1) ((1 + nu) Derivative[1, 1][sxy][y, z] - (1 + nu) 
      Derivative[2, 0][sxz][y, z] + nu Derivative[1, 0, 1][sxx][x, y, z]) == 
    0, -EE^(-1) Derivative[0, 1, 1][sxx][x, y, z] == 0, 
    EE^(-1) (Derivative[0, 2, 0][sxx][x, y, z] - nu 
      Derivative[2, 0, 0][sxx][x, y, z]) == 0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"sxx", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"a1", " ", "x", " ", "y"}], " ", "+", " ", 
    RowBox[{"a2", " ", "x", " ", "z"}], " ", "+", " ", 
    RowBox[{"a3", " ", "x"}], " ", "+", " ", 
    RowBox[{"a4", " ", "y"}], " ", "+", " ", 
    RowBox[{"a5", " ", "z"}], " ", "+", " ", "a6"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"a6", "+", 
  RowBox[{"a3", " ", "x"}], "+", 
  RowBox[{"a4", " ", "y"}], "+", 
  RowBox[{"a1", " ", "x", " ", "y"}], "+", 
  RowBox[{"a5", " ", "z"}], "+", 
  RowBox[{"a2", " ", "x", " ", "z"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{"traction", " ", "=", " ", 
    RowBox[{
     RowBox[{"sigma", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", ".", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", " ", "0", ",", "0"}], "}"}]}]}], " ", ")"}], " ", "//",
   " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"traction", "  ", "/.", " ", 
    RowBox[{"x", " ", "\[Rule]", " ", "0"}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"traction", "  ", "/.", " ", 
    RowBox[{"x", " ", "\[Rule]", " ", "L"}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"a6", "+", 
       RowBox[{"a3", " ", "x"}], "+", 
       RowBox[{"a4", " ", "y"}], "+", 
       RowBox[{"a1", " ", "x", " ", "y"}], "+", 
       RowBox[{"a5", " ", "z"}], "+", 
       RowBox[{"a2", " ", "x", " ", "z"}]}]},
     {
      RowBox[{"sxy", "[", 
       RowBox[{"y", ",", "z"}], "]"}]},
     {
      RowBox[{"sxz", "[", 
       RowBox[{"y", ",", "z"}], "]"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{a6 + a3 x + a4 y + a1 x y + a5 z + a2 x z, 
    sxy[y, z], 
    sxz[y, z]}]]], "Output"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"a6", "+", 
       RowBox[{"a4", " ", "y"}], "+", 
       RowBox[{"a5", " ", "z"}]}]},
     {
      RowBox[{"sxy", "[", 
       RowBox[{"y", ",", "z"}], "]"}]},
     {
      RowBox[{"sxz", "[", 
       RowBox[{"y", ",", "z"}], "]"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{a6 + a4 y + a5 z, 
    sxy[y, z], 
    sxz[y, z]}]]], "Output"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"a6", "+", 
       RowBox[{"a3", " ", "L"}], "+", 
       RowBox[{"a4", " ", "y"}], "+", 
       RowBox[{"a1", " ", "L", " ", "y"}], "+", 
       RowBox[{"a5", " ", "z"}], "+", 
       RowBox[{"a2", " ", "L", " ", "z"}]}]},
     {
      RowBox[{"sxy", "[", 
       RowBox[{"y", ",", "z"}], "]"}]},
     {
      RowBox[{"sxz", "[", 
       RowBox[{"y", ",", "z"}], "]"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{a6 + a3 L + a4 y + a1 L y + a5 z + a2 L z, 
    sxy[y, z], 
    sxz[y, z]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3", " ", "=", " ", "0", " "}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"inc", "  ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"True"},
     {
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"a1", " ", "nu"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["sxy", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["sxz", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}]}], "EE"], "\[Equal]", "0"}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"a2", " ", "nu"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["sxy", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["sxz", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}]}], "EE"], "\[Equal]", "0"}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"a1", " ", "nu"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["sxy", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["sxz", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}]}], "EE"], "\[Equal]", "0"}]},
     {"True"},
     {"True"},
     {
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"a2", " ", "nu"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["sxy", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["sxz", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"y", ",", "z"}], "]"}]}]}], "EE"], "\[Equal]", "0"}]},
     {"True"},
     {"True"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   True, EE^(-1) (a1 nu - (1 + nu) 
      Derivative[0, 2][sxy][y, z] + (1 + nu) Derivative[1, 1][sxz][y, z]) == 
    0, EE^(-1) (a2 nu + (1 + nu) Derivative[1, 1][sxy][y, z] - (1 + nu) 
      Derivative[2, 0][sxz][y, z]) == 0, 
    EE^(-1) (a1 nu - (1 + nu) 
      Derivative[0, 2][sxy][y, z] + (1 + nu) Derivative[1, 1][sxz][y, z]) == 
    0, True, True, 
    EE^(-1) (a2 nu + (1 + nu) Derivative[1, 1][sxy][y, z] - (1 + nu) 
      Derivative[2, 0][sxz][y, z]) == 0, True, True}]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Laplacian equations for sxy[y,z] and syz[y,z]",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq1", " ", "=", " ", 
  RowBox[{"div", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a1", " ", "y"}], "+", 
  RowBox[{"a2", " ", "z"}], "+", 
  RowBox[{
   SuperscriptBox["sxz", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"y", ",", "z"}], "]"}], "+", 
  RowBox[{
   SuperscriptBox["sxy", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"1", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"y", ",", "z"}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{"Solve", "[", " ", 
   RowBox[{
    RowBox[{"D", "[", " ", 
     RowBox[{
      RowBox[{"div", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", "y"}], " ", "]"}], ",", " ", 
    
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sxz", "[", 
       RowBox[{"y", ",", "z"}], "]"}], ",", "y", ",", "z"}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["sxz", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"y", ",", "z"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "a1"}], "-", 
     RowBox[{
      SuperscriptBox["sxy", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq2", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{"inc", "[", 
     RowBox[{"[", "2", "]"}], "]"}], " ", "/.", " ", 
    RowBox[{"sol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"a1", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["sxy", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["sxy", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}]}]}], "EE"], "\[Equal]", "0"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{"Solve", "[", " ", 
   RowBox[{
    RowBox[{"D", "[", " ", 
     RowBox[{
      RowBox[{"div", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", "z"}], " ", "]"}], ",", " ", 
    
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sxy", "[", 
       RowBox[{"y", ",", "z"}], "]"}], ",", "y", ",", "z"}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["sxy", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"y", ",", "z"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "a2"}], "-", 
     RowBox[{
      SuperscriptBox["sxz", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{"D", "[", " ", 
     RowBox[{
      RowBox[{"inc", "[", 
       RowBox[{"[", 
        RowBox[{"3", ",", "1"}], "]"}], "]"}], " ", ",", " ", "y"}], "]"}], 
    " ", "-", " ", 
    RowBox[{"D", "[", " ", 
     RowBox[{
      RowBox[{"inc", "[", 
       RowBox[{"[", 
        RowBox[{"3", ",", "1"}], "]"}], "]"}], " ", ",", " ", "z"}], "]"}]}], 
   " ", "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["sxy", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}], "-", 
      RowBox[{
       SuperscriptBox["sxy", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}], "-", 
      RowBox[{
       SuperscriptBox["sxz", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}], "+", 
      RowBox[{
       SuperscriptBox["sxz", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"3", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}]}], ")"}]}], "EE"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq3", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{"inc", "[", 
     RowBox[{"[", "3", "]"}], "]"}], " ", "/.", " ", 
    RowBox[{"sol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"a2", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["sxz", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["sxz", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}]}]}], "EE"], "\[Equal]", "0"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Integration of strains to displacements",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"strain", " ", "=", " ", 
    RowBox[{"Simplify", "[", " ", 
     RowBox[{"eps", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]}], ")"}], " ", "//", 
  " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"a6", "+", 
        RowBox[{"a4", " ", "y"}], "+", 
        RowBox[{"a1", " ", "x", " ", "y"}], "+", 
        RowBox[{"a5", " ", "z"}], "+", 
        RowBox[{"a2", " ", "x", " ", "z"}]}], "EE"], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"sxy", "[", 
         RowBox[{"y", ",", "z"}], "]"}]}], "EE"], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"sxz", "[", 
         RowBox[{"y", ",", "z"}], "]"}]}], "EE"]},
     {
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"sxy", "[", 
         RowBox[{"y", ",", "z"}], "]"}]}], "EE"], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"nu", " ", 
         RowBox[{"(", 
          RowBox[{"a6", "+", 
           RowBox[{"a4", " ", "y"}], "+", 
           RowBox[{"a1", " ", "x", " ", "y"}], "+", 
           RowBox[{"a5", " ", "z"}], "+", 
           RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], "EE"]}], "0"},
     {
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"sxz", "[", 
         RowBox[{"y", ",", "z"}], "]"}]}], "EE"], "0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"nu", " ", 
         RowBox[{"(", 
          RowBox[{"a6", "+", 
           RowBox[{"a4", " ", "y"}], "+", 
           RowBox[{"a1", " ", "x", " ", "y"}], "+", 
           RowBox[{"a5", " ", "z"}], "+", 
           RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], "EE"]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pp", " ", "=", " ", 
  RowBox[{"Coordinates", "[", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"u", " ", ":=", " ", 
   RowBox[{"Map", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Integrate", "[", " ", 
        RowBox[{
         RowBox[{"strain", "[", 
          RowBox[{"[", 
           RowBox[{"#", ",", "#"}], "]"}], "]"}], " ", ",", " ", 
         RowBox[{"pp", "[", 
          RowBox[{"[", "#", "]"}], "]"}]}], " ", "]"}], "  ", "+", " ", 
       RowBox[{
        RowBox[{"If", "[", " ", 
         RowBox[{
          RowBox[{"#", " ", "\[Equal]", " ", "1"}], ",", " ", 
          RowBox[{"1", " ", "/", " ", "EE"}], ",", " ", 
          RowBox[{
           RowBox[{"-", " ", "nu"}], " ", "/", " ", "EE"}]}], "]"}], " ", 
        RowBox[{
         RowBox[{"ToExpression", "[", 
          RowBox[{"\"\<K\>\"", "<>", 
           RowBox[{"ToString", "[", 
            RowBox[{"pp", "[", 
             RowBox[{"[", "#", "]"}], "]"}], "]"}]}], " ", "]"}], " ", "@@", 
         " ", 
         RowBox[{"Drop", "[", 
          RowBox[{"pp", ",", " ", 
           RowBox[{"{", "#", "}"}]}], "]"}]}]}]}], " ", "&"}], " ", ",", " ", 
     
     RowBox[{"Range", "[", "3", "]"}]}], "]"}]}], 
  " "}], "\[IndentingNewLine]", "u"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"x", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a6"}], "+", 
        RowBox[{"2", " ", "a4", " ", "y"}], "+", 
        RowBox[{"a1", " ", "x", " ", "y"}], "+", 
        RowBox[{"2", " ", "a5", " ", "z"}], "+", 
        RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], 
     RowBox[{"2", " ", "EE"}]], "+", 
    FractionBox[
     RowBox[{"Kx", "[", 
      RowBox[{"y", ",", "z"}], "]"}], "EE"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"nu", " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a6"}], "+", 
         RowBox[{"a4", " ", "y"}], "+", 
         RowBox[{"a1", " ", "x", " ", "y"}], "+", 
         RowBox[{"2", " ", "a5", " ", "z"}], "+", 
         RowBox[{"2", " ", "a2", " ", "x", " ", "z"}]}], ")"}]}], 
      RowBox[{"2", " ", "EE"}]]}], "-", 
    FractionBox[
     RowBox[{"nu", " ", 
      RowBox[{"Ky", "[", 
       RowBox[{"x", ",", "z"}], "]"}]}], "EE"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"nu", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a6"}], "+", 
         RowBox[{"2", " ", "a4", " ", "y"}], "+", 
         RowBox[{"2", " ", "a1", " ", "x", " ", "y"}], "+", 
         RowBox[{"a5", " ", "z"}], "+", 
         RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], 
      RowBox[{"2", " ", "EE"}]]}], "-", 
    FractionBox[
     RowBox[{"nu", " ", 
      RowBox[{"Kz", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "EE"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"epsyz", " ", "=", " ", 
  RowBox[{
   RowBox[{"D", "[", " ", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", " ", "y"}], " ", "]"}], " ", "+", 
   " ", 
   RowBox[{"D", "[", " ", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", " ", "z"}], " ", 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"nu", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "a5"}], "+", 
       RowBox[{"2", " ", "a2", " ", "x"}]}], ")"}], " ", "y"}], 
    RowBox[{"2", " ", "EE"}]]}], "-", 
  FractionBox[
   RowBox[{"nu", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "a4"}], "+", 
      RowBox[{"2", " ", "a1", " ", "x"}]}], ")"}], " ", "z"}], 
   RowBox[{"2", " ", "EE"}]], "-", 
  FractionBox[
   RowBox[{"nu", " ", 
    RowBox[{
     SuperscriptBox["Ky", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x", ",", "z"}], "]"}]}], "EE"], "-", 
  FractionBox[
   RowBox[{"nu", " ", 
    RowBox[{
     SuperscriptBox["Kz", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x", ",", "y"}], "]"}]}], "EE"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sky", " ", "=", " ", 
   RowBox[{"DSolve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{"epsyz", ",", " ", "z"}], "]"}], " ", "\[Equal]", " ", "0"}], 
     " ", ",", " ", 
     RowBox[{"Ky", "[", 
      RowBox[{"x", ",", "z"}], "]"}], ",", "z"}], "]"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ky", "[", 
   RowBox[{"x", ",", "z"}], "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"sky", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}], " ", "/.", " ", 
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], " ", "\[Rule]", " ", 
     RowBox[{"Ky", "[", "x", "]"}]}]}], " ", "/.", " ", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], " ", "\[Rule]", 
    RowBox[{"-", "  ", 
     RowBox[{"K", "[", "x", "]"}]}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Ky", "[", 
     RowBox[{"x", ",", "z"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"a4", " ", 
        SuperscriptBox["z", "2"]}], "2"]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", "a1", " ", "x", " ", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{"C", "[", "1", "]"}], "+", 
     RowBox[{"z", " ", 
      RowBox[{"C", "[", "2", "]"}]}]}]}], "}"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"a4", " ", 
     SuperscriptBox["z", "2"]}], "2"]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "a1", " ", "x", " ", 
   SuperscriptBox["z", "2"]}], "-", 
  RowBox[{"z", " ", 
   RowBox[{"K", "[", "x", "]"}]}], "+", 
  RowBox[{"Ky", "[", "x", "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"skz", " ", "=", " ", 
   RowBox[{"DSolve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{"epsyz", ",", " ", "y"}], "]"}], " ", "\[Equal]", " ", "0"}], 
     " ", ",", " ", 
     RowBox[{"Kz", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", "y"}], "]"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Kz", "[", 
   RowBox[{"x", ",", "y"}], "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"skz", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}], " ", "/.", " ", 
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], " ", "\[Rule]", " ", 
     RowBox[{"Kz", "[", "x", "]"}]}]}], " ", "/.", " ", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], " ", "\[Rule]", "  ", 
    RowBox[{"K", "[", "x", "]"}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Kz", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"a5", " ", 
        SuperscriptBox["y", "2"]}], "2"]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", "a2", " ", "x", " ", 
      SuperscriptBox["y", "2"]}], "+", 
     RowBox[{"C", "[", "1", "]"}], "+", 
     RowBox[{"y", " ", 
      RowBox[{"C", "[", "2", "]"}]}]}]}], "}"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"a5", " ", 
     SuperscriptBox["y", "2"]}], "2"]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "a2", " ", "x", " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{"y", " ", 
   RowBox[{"K", "[", "x", "]"}]}], "+", 
  RowBox[{"Kz", "[", "x", "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["u"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"x", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a6"}], "+", 
        RowBox[{"2", " ", "a4", " ", "y"}], "+", 
        RowBox[{"a1", " ", "x", " ", "y"}], "+", 
        RowBox[{"2", " ", "a5", " ", "z"}], "+", 
        RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], 
     RowBox[{"2", " ", "EE"}]], "+", 
    FractionBox[
     RowBox[{"Kx", "[", 
      RowBox[{"y", ",", "z"}], "]"}], "EE"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"nu", " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a6"}], "+", 
         RowBox[{"a4", " ", "y"}], "+", 
         RowBox[{"a1", " ", "x", " ", "y"}], "+", 
         RowBox[{"2", " ", "a5", " ", "z"}], "+", 
         RowBox[{"2", " ", "a2", " ", "x", " ", "z"}]}], ")"}]}], 
      RowBox[{"2", " ", "EE"}]]}], "-", 
    FractionBox[
     RowBox[{"nu", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"a4", " ", 
           SuperscriptBox["z", "2"]}], "2"]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", "a1", " ", "x", " ", 
         SuperscriptBox["z", "2"]}], "-", 
        RowBox[{"z", " ", 
         RowBox[{"K", "[", "x", "]"}]}], "+", 
        RowBox[{"Ky", "[", "x", "]"}]}], ")"}]}], "EE"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"nu", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a6"}], "+", 
         RowBox[{"2", " ", "a4", " ", "y"}], "+", 
         RowBox[{"2", " ", "a1", " ", "x", " ", "y"}], "+", 
         RowBox[{"a5", " ", "z"}], "+", 
         RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], 
      RowBox[{"2", " ", "EE"}]]}], "-", 
    FractionBox[
     RowBox[{"nu", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"a5", " ", 
           SuperscriptBox["y", "2"]}], "2"]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", "a2", " ", "x", " ", 
         SuperscriptBox["y", "2"]}], "+", 
        RowBox[{"y", " ", 
         RowBox[{"K", "[", "x", "]"}]}], "+", 
        RowBox[{"Kz", "[", "x", "]"}]}], ")"}]}], "EE"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"strain", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{"1", "/", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Grad", "[", "u", "]"}], "]"}]}], " ", ")"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"a6", "+", 
       RowBox[{"a4", " ", "y"}], "+", 
       RowBox[{"a1", " ", "x", " ", "y"}], "+", 
       RowBox[{"a5", " ", "z"}], "+", 
       RowBox[{"a2", " ", "x", " ", "z"}]}], "EE"], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "a4", " ", "x"}], "+", 
       RowBox[{"a1", " ", 
        SuperscriptBox["x", "2"]}], "-", 
       RowBox[{"a1", " ", "nu", " ", 
        SuperscriptBox["y", "2"]}], "-", 
       RowBox[{"2", " ", "a2", " ", "nu", " ", "y", " ", "z"}], "+", 
       RowBox[{"a1", " ", "nu", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"2", " ", "nu", " ", "z", " ", 
        RowBox[{
         SuperscriptBox["K", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "-", 
       RowBox[{"2", " ", "nu", " ", 
        RowBox[{
         SuperscriptBox["Ky", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", " ", "EE"}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "a5", " ", "x"}], "+", 
       RowBox[{"a2", " ", 
        SuperscriptBox["x", "2"]}], "+", 
       RowBox[{"a2", " ", "nu", " ", 
        SuperscriptBox["y", "2"]}], "-", 
       RowBox[{"2", " ", "a1", " ", "nu", " ", "y", " ", "z"}], "-", 
       RowBox[{"a2", " ", "nu", " ", 
        SuperscriptBox["z", "2"]}], "-", 
       RowBox[{"2", " ", "nu", " ", "y", " ", 
        RowBox[{
         SuperscriptBox["K", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "-", 
       RowBox[{"2", " ", "nu", " ", 
        RowBox[{
         SuperscriptBox["Kz", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", " ", "EE"}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "a4", " ", "x"}], "+", 
       RowBox[{"a1", " ", 
        SuperscriptBox["x", "2"]}], "-", 
       RowBox[{"a1", " ", "nu", " ", 
        SuperscriptBox["y", "2"]}], "-", 
       RowBox[{"2", " ", "a2", " ", "nu", " ", "y", " ", "z"}], "+", 
       RowBox[{"a1", " ", "nu", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"2", " ", "nu", " ", "z", " ", 
        RowBox[{
         SuperscriptBox["K", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "-", 
       RowBox[{"2", " ", "nu", " ", 
        RowBox[{
         SuperscriptBox["Ky", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", " ", "EE"}]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"nu", " ", 
        RowBox[{"(", 
         RowBox[{"a6", "+", 
          RowBox[{"a4", " ", "y"}], "+", 
          RowBox[{"a1", " ", "x", " ", "y"}], "+", 
          RowBox[{"a5", " ", "z"}], "+", 
          RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], "EE"]}], ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "a5", " ", "x"}], "+", 
       RowBox[{"a2", " ", 
        SuperscriptBox["x", "2"]}], "+", 
       RowBox[{"a2", " ", "nu", " ", 
        SuperscriptBox["y", "2"]}], "-", 
       RowBox[{"2", " ", "a1", " ", "nu", " ", "y", " ", "z"}], "-", 
       RowBox[{"a2", " ", "nu", " ", 
        SuperscriptBox["z", "2"]}], "-", 
       RowBox[{"2", " ", "nu", " ", "y", " ", 
        RowBox[{
         SuperscriptBox["K", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "-", 
       RowBox[{"2", " ", "nu", " ", 
        RowBox[{
         SuperscriptBox["Kz", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", " ", "EE"}]], ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"nu", " ", 
        RowBox[{"(", 
         RowBox[{"a6", "+", 
          RowBox[{"a4", " ", "y"}], "+", 
          RowBox[{"a1", " ", "x", " ", "y"}], "+", 
          RowBox[{"a5", " ", "z"}], "+", 
          RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], "EE"]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sig", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{"EE", " ", 
     RowBox[{
      RowBox[{"nu", " ", "/", 
       RowBox[{"(", 
        RowBox[{"1", " ", "+", " ", "nu"}], ")"}]}], " ", "/", " ", 
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", 
        RowBox[{"2", " ", "nu"}]}], ")"}]}], " ", 
     RowBox[{"Tr", "[", " ", "strain", " ", "]"}], " ", 
     RowBox[{"IdentityMatrix", "[", " ", "3", " ", "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"EE", " ", "/", " ", 
      RowBox[{"(", 
       RowBox[{"1", " ", "+", " ", "nu"}], ")"}]}], " ", "strain"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a6", "+", 
      RowBox[{"a4", " ", "y"}], "+", 
      RowBox[{"a1", " ", "x", " ", "y"}], "+", 
      RowBox[{"a5", " ", "z"}], "+", 
      RowBox[{"a2", " ", "x", " ", "z"}]}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "a4", " ", "x"}], "+", 
       RowBox[{"a1", " ", 
        SuperscriptBox["x", "2"]}], "-", 
       RowBox[{"a1", " ", "nu", " ", 
        SuperscriptBox["y", "2"]}], "-", 
       RowBox[{"2", " ", "a2", " ", "nu", " ", "y", " ", "z"}], "+", 
       RowBox[{"a1", " ", "nu", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"2", " ", "nu", " ", "z", " ", 
        RowBox[{
         SuperscriptBox["K", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "-", 
       RowBox[{"2", " ", "nu", " ", 
        RowBox[{
         SuperscriptBox["Ky", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", "+", 
       RowBox[{"4", " ", "nu"}]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "a5", " ", "x"}], "+", 
       RowBox[{"a2", " ", 
        SuperscriptBox["x", "2"]}], "+", 
       RowBox[{"a2", " ", "nu", " ", 
        SuperscriptBox["y", "2"]}], "-", 
       RowBox[{"2", " ", "a1", " ", "nu", " ", "y", " ", "z"}], "-", 
       RowBox[{"a2", " ", "nu", " ", 
        SuperscriptBox["z", "2"]}], "-", 
       RowBox[{"2", " ", "nu", " ", "y", " ", 
        RowBox[{
         SuperscriptBox["K", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "-", 
       RowBox[{"2", " ", "nu", " ", 
        RowBox[{
         SuperscriptBox["Kz", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", "+", 
       RowBox[{"4", " ", "nu"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "a4", " ", "x"}], "+", 
       RowBox[{"a1", " ", 
        SuperscriptBox["x", "2"]}], "-", 
       RowBox[{"a1", " ", "nu", " ", 
        SuperscriptBox["y", "2"]}], "-", 
       RowBox[{"2", " ", "a2", " ", "nu", " ", "y", " ", "z"}], "+", 
       RowBox[{"a1", " ", "nu", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"2", " ", "nu", " ", "z", " ", 
        RowBox[{
         SuperscriptBox["K", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "-", 
       RowBox[{"2", " ", "nu", " ", 
        RowBox[{
         SuperscriptBox["Ky", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", "+", 
       RowBox[{"4", " ", "nu"}]}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "a5", " ", "x"}], "+", 
       RowBox[{"a2", " ", 
        SuperscriptBox["x", "2"]}], "+", 
       RowBox[{"a2", " ", "nu", " ", 
        SuperscriptBox["y", "2"]}], "-", 
       RowBox[{"2", " ", "a1", " ", "nu", " ", "y", " ", "z"}], "-", 
       RowBox[{"a2", " ", "nu", " ", 
        SuperscriptBox["z", "2"]}], "-", 
       RowBox[{"2", " ", "nu", " ", "y", " ", 
        RowBox[{
         SuperscriptBox["K", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "-", 
       RowBox[{"2", " ", "nu", " ", 
        RowBox[{
         SuperscriptBox["Kz", "\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", "+", 
       RowBox[{"4", " ", "nu"}]}]], ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"newdiv", " ", ":=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Div", "[", "sig", "]"}], "]"}]}], 
  " "}], "\[IndentingNewLine]", "newdiv", "\[IndentingNewLine]", 
 RowBox[{"newdiv", " ", "//", "  ", "MatrixForm"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", "a1", " ", "y"}], "+", 
     RowBox[{"2", " ", "a2", " ", "z"}], "+", 
     RowBox[{
      SuperscriptBox["Kx", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["Kx", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}]}], 
    RowBox[{"2", "+", 
     RowBox[{"2", " ", "nu"}]}]], ",", 
   FractionBox[
    RowBox[{"a4", "+", 
     RowBox[{"a1", " ", "x"}], "+", 
     RowBox[{"nu", " ", "z", " ", 
      RowBox[{
       SuperscriptBox["K", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "x", "]"}]}], "-", 
     RowBox[{"nu", " ", 
      RowBox[{
       SuperscriptBox["Ky", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "x", "]"}]}]}], 
    RowBox[{"2", "+", 
     RowBox[{"2", " ", "nu"}]}]], ",", 
   FractionBox[
    RowBox[{"a5", "+", 
     RowBox[{"a2", " ", "x"}], "-", 
     RowBox[{"nu", " ", "y", " ", 
      RowBox[{
       SuperscriptBox["K", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "x", "]"}]}], "-", 
     RowBox[{"nu", " ", 
      RowBox[{
       SuperscriptBox["Kz", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "x", "]"}]}]}], 
    RowBox[{"2", "+", 
     RowBox[{"2", " ", "nu"}]}]]}], "}"}]], "Output"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", "a1", " ", "y"}], "+", 
        RowBox[{"2", " ", "a2", " ", "z"}], "+", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}], "+", 
        RowBox[{
         SuperscriptBox["Kx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}], 
       RowBox[{"2", "+", 
        RowBox[{"2", " ", "nu"}]}]]},
     {
      FractionBox[
       RowBox[{"a4", "+", 
        RowBox[{"a1", " ", "x"}], "+", 
        RowBox[{"nu", " ", "z", " ", 
         RowBox[{
          SuperscriptBox["K", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "x", "]"}]}], "-", 
        RowBox[{"nu", " ", 
         RowBox[{
          SuperscriptBox["Ky", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "x", "]"}]}]}], 
       RowBox[{"2", "+", 
        RowBox[{"2", " ", "nu"}]}]]},
     {
      FractionBox[
       RowBox[{"a5", "+", 
        RowBox[{"a2", " ", "x"}], "-", 
        RowBox[{"nu", " ", "y", " ", 
         RowBox[{
          SuperscriptBox["K", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "x", "]"}]}], "-", 
        RowBox[{"nu", " ", 
         RowBox[{
          SuperscriptBox["Kz", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "x", "]"}]}]}], 
       RowBox[{"2", "+", 
        RowBox[{"2", " ", "nu"}]}]]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{(2 + 2 nu)^(-1) (2 a1 y + 2 a2 z + Derivative[0, 2][Kx][y, z] + 
     Derivative[2, 0][Kx][y, z]), (2 + 2 nu)^(-1) (a4 + a1 x + 
     nu z Derivative[2][K][x] - nu Derivative[2][Ky][x]), (2 + 2 nu)^(-1) (a5 + 
     a2 x - nu y Derivative[2][K][x] - nu Derivative[2][Kz][x])}]]], "Output"]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"K", "[", "x", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"c", " ", "x"}], " ", "-", " ", 
   RowBox[{
    RowBox[{"EE", " ", "/", " ", "nu"}], " ", "rx", " "}]}]}]], "Input"],

Cell[BoxData[""], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"newdiv", " ", "=", " ", 
  RowBox[{"newdiv", " ", "/.", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"K", "''"}], "[", "x", "]"}], " ", "\[Rule]", " ", 
    "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", "a1", " ", "y"}], "+", 
     RowBox[{"2", " ", "a2", " ", "z"}], "+", 
     RowBox[{
      SuperscriptBox["Kx", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["Kx", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}]}], 
    RowBox[{"2", "+", 
     RowBox[{"2", " ", "nu"}]}]], ",", 
   FractionBox[
    RowBox[{"a4", "+", 
     RowBox[{"a1", " ", "x"}], "-", 
     RowBox[{"nu", " ", 
      RowBox[{
       SuperscriptBox["Ky", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "x", "]"}]}]}], 
    RowBox[{"2", "+", 
     RowBox[{"2", " ", "nu"}]}]], ",", 
   FractionBox[
    RowBox[{"a5", "+", 
     RowBox[{"a2", " ", "x"}], "-", 
     RowBox[{"nu", " ", 
      RowBox[{
       SuperscriptBox["Kz", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "x", "]"}]}]}], 
    RowBox[{"2", "+", 
     RowBox[{"2", " ", "nu"}]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DSolve", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"newdiv", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "==", "0"}], "  ", ",", " ", 
   RowBox[{
    RowBox[{"Ky", "''"}], "[", "x", "]"}], ",", " ", "x"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ky", "[", "x", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}], " ", "/.", " ", 
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], " ", "\[Rule]", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", " ", "EE"}], "  ", "/", " ", "nu"}], " ", "ly"}]}]}], 
   "   ", "/.", " ", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], " ", "\[Rule]", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", "EE"}], " ", "/", " ", "nu"}], " ", "rz", 
     " "}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Ky", "[", "x", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"a4", " ", 
       SuperscriptBox["x", "2"]}], 
      RowBox[{"2", " ", "nu"}]], "+", 
     FractionBox[
      RowBox[{"a1", " ", 
       SuperscriptBox["x", "3"]}], 
      RowBox[{"6", " ", "nu"}]], "+", 
     RowBox[{"C", "[", "1", "]"}], "+", 
     RowBox[{"x", " ", 
      RowBox[{"C", "[", "2", "]"}]}]}]}], "}"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"EE", " ", "ly"}], "nu"]}], "-", 
  FractionBox[
   RowBox[{"EE", " ", "rz", " ", "x"}], "nu"], "+", 
  FractionBox[
   RowBox[{"a4", " ", 
    SuperscriptBox["x", "2"]}], 
   RowBox[{"2", " ", "nu"}]], "+", 
  FractionBox[
   RowBox[{"a1", " ", 
    SuperscriptBox["x", "3"]}], 
   RowBox[{"6", " ", "nu"}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DSolve", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"newdiv", "[", 
     RowBox[{"[", "3", "]"}], "]"}], " ", "==", "0"}], ",", " ", 
   RowBox[{
    RowBox[{"Kz", "''"}], "[", "x", "]"}], ",", " ", "x"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Kz", "[", "x", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}], " ", "/.", " ", 
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], " ", "\[Rule]", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", " ", "EE"}], "  ", "/", "nu"}], " ", "lz"}]}]}], " ", "/.",
    " ", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], " ", "\[Rule]", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"+", " ", "EE"}], " ", "/", " ", "nu"}], "  ", "ry", 
     "  "}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Kz", "[", "x", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"a5", " ", 
       SuperscriptBox["x", "2"]}], 
      RowBox[{"2", " ", "nu"}]], "+", 
     FractionBox[
      RowBox[{"a2", " ", 
       SuperscriptBox["x", "3"]}], 
      RowBox[{"6", " ", "nu"}]], "+", 
     RowBox[{"C", "[", "1", "]"}], "+", 
     RowBox[{"x", " ", 
      RowBox[{"C", "[", "2", "]"}]}]}]}], "}"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"EE", " ", "lz"}], "nu"]}], "+", 
  FractionBox[
   RowBox[{"EE", " ", "ry", " ", "x"}], "nu"], "+", 
  FractionBox[
   RowBox[{"a5", " ", 
    SuperscriptBox["x", "2"]}], 
   RowBox[{"2", " ", "nu"}]], "+", 
  FractionBox[
   RowBox[{"a2", " ", 
    SuperscriptBox["x", "3"]}], 
   RowBox[{"6", " ", "nu"}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", " ", "u", " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"x", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a6"}], "+", 
        RowBox[{"2", " ", "a4", " ", "y"}], "+", 
        RowBox[{"a1", " ", "x", " ", "y"}], "+", 
        RowBox[{"2", " ", "a5", " ", "z"}], "+", 
        RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Kx", "[", 
       RowBox[{"y", ",", "z"}], "]"}]}]}], 
    RowBox[{"2", " ", "EE"}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", "a6", " ", "nu", " ", "y"}], "-", 
     RowBox[{"a1", " ", "x", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        RowBox[{"3", " ", "nu", " ", 
         SuperscriptBox["y", "2"]}]}], ")"}]}], "+", 
     RowBox[{"6", " ", "nu", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", " ", "x"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a5", "+", 
           RowBox[{"a2", " ", "x"}]}], ")"}], " ", "y"}]}], ")"}], " ", "z"}],
      "+", 
     RowBox[{"3", " ", "a1", " ", "nu", " ", "x", " ", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{"6", " ", "EE", " ", 
      RowBox[{"(", 
       RowBox[{"ly", "+", 
        RowBox[{"rz", " ", "x"}], "-", 
        RowBox[{"rx", " ", "z"}]}], ")"}]}], "-", 
     RowBox[{"3", " ", "a4", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        RowBox[{"nu", " ", 
         RowBox[{"(", 
          RowBox[{"y", "-", "z"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}]}], 
    RowBox[{"6", " ", "EE"}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"3", " ", "a5", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"a2", " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"6", " ", "c", " ", "nu", " ", "x", " ", "y"}], "-", 
      RowBox[{"3", " ", "a5", " ", "nu", " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"3", " ", "a2", " ", "nu", " ", "x", " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"6", " ", "EE", " ", 
       RowBox[{"(", 
        RowBox[{"lz", "-", 
         RowBox[{"ry", " ", "x"}], "+", 
         RowBox[{"rx", " ", "y"}]}], ")"}]}], "+", 
      RowBox[{"6", " ", "nu", " ", 
       RowBox[{"(", 
        RowBox[{"a6", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a4", "+", 
            RowBox[{"a1", " ", "x"}]}], ")"}], " ", "y"}]}], ")"}], " ", 
       "z"}], "+", 
      RowBox[{"3", " ", "nu", " ", 
       RowBox[{"(", 
        RowBox[{"a5", "+", 
         RowBox[{"a2", " ", "x"}]}], ")"}], " ", 
       SuperscriptBox["z", "2"]}]}], 
     RowBox[{"6", " ", "EE"}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", "  ", "=", " ", 
  RowBox[{"u", " ", "/.", " ", 
   RowBox[{
    RowBox[{"Kx", "[", 
     RowBox[{"y", ",", "z"}], "]"}], " ", "->", " ", 
    RowBox[{
     RowBox[{"phi", "[", 
      RowBox[{"y", ",", "z"}], "]"}], " ", "+", " ", 
     RowBox[{"EE", " ", "ry", "  ", "z"}], " ", "-", " ", 
     RowBox[{"EE", " ", "rz", " ", "y"}]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"x", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a6"}], "+", 
        RowBox[{"2", " ", "a4", " ", "y"}], "+", 
        RowBox[{"a1", " ", "x", " ", "y"}], "+", 
        RowBox[{"2", " ", "a5", " ", "z"}], "+", 
        RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], 
     RowBox[{"2", " ", "EE"}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "EE"}], " ", "rz", " ", "y"}], "+", 
      RowBox[{"EE", " ", "ry", " ", "z"}], "+", 
      RowBox[{"phi", "[", 
       RowBox[{"y", ",", "z"}], "]"}]}], "EE"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"nu", " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a6"}], "+", 
         RowBox[{"a4", " ", "y"}], "+", 
         RowBox[{"a1", " ", "x", " ", "y"}], "+", 
         RowBox[{"2", " ", "a5", " ", "z"}], "+", 
         RowBox[{"2", " ", "a2", " ", "x", " ", "z"}]}], ")"}]}], 
      RowBox[{"2", " ", "EE"}]]}], "-", 
    FractionBox[
     RowBox[{"nu", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"EE", " ", "ly"}], "nu"]}], "-", 
        FractionBox[
         RowBox[{"EE", " ", "rz", " ", "x"}], "nu"], "+", 
        FractionBox[
         RowBox[{"a4", " ", 
          SuperscriptBox["x", "2"]}], 
         RowBox[{"2", " ", "nu"}]], "+", 
        FractionBox[
         RowBox[{"a1", " ", 
          SuperscriptBox["x", "3"]}], 
         RowBox[{"6", " ", "nu"}]], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"EE", " ", "rx"}], "nu"]}], "+", 
           RowBox[{"c", " ", "x"}]}], ")"}], " ", "z"}], "-", 
        FractionBox[
         RowBox[{"a4", " ", 
          SuperscriptBox["z", "2"]}], "2"], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", "a1", " ", "x", " ", 
         SuperscriptBox["z", "2"]}]}], ")"}]}], "EE"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"nu", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"EE", " ", "lz"}], "nu"]}], "+", 
         FractionBox[
          RowBox[{"EE", " ", "ry", " ", "x"}], "nu"], "+", 
         FractionBox[
          RowBox[{"a5", " ", 
           SuperscriptBox["x", "2"]}], 
          RowBox[{"2", " ", "nu"}]], "+", 
         FractionBox[
          RowBox[{"a2", " ", 
           SuperscriptBox["x", "3"]}], 
          RowBox[{"6", " ", "nu"}]], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"EE", " ", "rx"}], "nu"]}], "+", 
            RowBox[{"c", " ", "x"}]}], ")"}], " ", "y"}], "-", 
         FractionBox[
          RowBox[{"a5", " ", 
           SuperscriptBox["y", "2"]}], "2"], "-", 
         RowBox[{
          FractionBox["1", "2"], " ", "a2", " ", "x", " ", 
          SuperscriptBox["y", "2"]}]}], ")"}]}], "EE"]}], "-", 
    FractionBox[
     RowBox[{"nu", " ", "z", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a6"}], "+", 
        RowBox[{"2", " ", "a4", " ", "y"}], "+", 
        RowBox[{"2", " ", "a1", " ", "x", " ", "y"}], "+", 
        RowBox[{"a5", " ", "z"}], "+", 
        RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], 
     RowBox[{"2", " ", "EE"}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", " ", "u", "  ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"x", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a6"}], "+", 
        RowBox[{"2", " ", "a4", " ", "y"}], "+", 
        RowBox[{"a1", " ", "x", " ", "y"}], "+", 
        RowBox[{"2", " ", "a5", " ", "z"}], "+", 
        RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "EE"}], " ", "rz", " ", "y"}], "+", 
        RowBox[{"EE", " ", "ry", " ", "z"}], "+", 
        RowBox[{"phi", "[", 
         RowBox[{"y", ",", "z"}], "]"}]}], ")"}]}]}], 
    RowBox[{"2", " ", "EE"}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", "a6", " ", "nu", " ", "y"}], "-", 
     RowBox[{"a1", " ", "x", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        RowBox[{"3", " ", "nu", " ", 
         SuperscriptBox["y", "2"]}]}], ")"}]}], "+", 
     RowBox[{"6", " ", "nu", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"c", " ", "x"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a5", "+", 
           RowBox[{"a2", " ", "x"}]}], ")"}], " ", "y"}]}], ")"}], " ", "z"}],
      "+", 
     RowBox[{"3", " ", "a1", " ", "nu", " ", "x", " ", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{"6", " ", "EE", " ", 
      RowBox[{"(", 
       RowBox[{"ly", "+", 
        RowBox[{"rz", " ", "x"}], "-", 
        RowBox[{"rx", " ", "z"}]}], ")"}]}], "-", 
     RowBox[{"3", " ", "a4", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        RowBox[{"nu", " ", 
         RowBox[{"(", 
          RowBox[{"y", "-", "z"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}]}], 
    RowBox[{"6", " ", "EE"}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"3", " ", "a5", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"a2", " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"6", " ", "c", " ", "nu", " ", "x", " ", "y"}], "-", 
      RowBox[{"3", " ", "a5", " ", "nu", " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"3", " ", "a2", " ", "nu", " ", "x", " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"6", " ", "EE", " ", 
       RowBox[{"(", 
        RowBox[{"lz", "-", 
         RowBox[{"ry", " ", "x"}], "+", 
         RowBox[{"rx", " ", "y"}]}], ")"}]}], "+", 
      RowBox[{"6", " ", "nu", " ", 
       RowBox[{"(", 
        RowBox[{"a6", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a4", "+", 
            RowBox[{"a1", " ", "x"}]}], ")"}], " ", "y"}]}], ")"}], " ", 
       "z"}], "+", 
      RowBox[{"3", " ", "nu", " ", 
       RowBox[{"(", 
        RowBox[{"a5", "+", 
         RowBox[{"a2", " ", "x"}]}], ")"}], " ", 
       SuperscriptBox["z", "2"]}]}], 
     RowBox[{"6", " ", "EE"}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"strain", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", " ", 
   RowBox[{
    RowBox[{"1", "/", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Grad", "[", "u", "]"}], "]"}]}], " ", ")"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"a6", "+", 
       RowBox[{"a4", " ", "y"}], "+", 
       RowBox[{"a1", " ", "x", " ", "y"}], "+", 
       RowBox[{"a5", " ", "z"}], "+", 
       RowBox[{"a2", " ", "x", " ", "z"}]}], "EE"], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"nu", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"c", "-", 
             RowBox[{"a2", " ", "y"}]}], ")"}], " ", "z"}], "+", 
          RowBox[{"a1", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["y", "2"]}], "+", 
             SuperscriptBox["z", "2"]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["phi", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", " ", "EE"}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "nu"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "c", " ", "y"}], "-", 
          RowBox[{"a2", " ", 
           SuperscriptBox["y", "2"]}], "+", 
          RowBox[{"2", " ", "a1", " ", "y", " ", "z"}], "+", 
          RowBox[{"a2", " ", 
           SuperscriptBox["z", "2"]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["phi", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", " ", "EE"}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"nu", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"c", "-", 
             RowBox[{"a2", " ", "y"}]}], ")"}], " ", "z"}], "+", 
          RowBox[{"a1", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["y", "2"]}], "+", 
             SuperscriptBox["z", "2"]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["phi", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", " ", "EE"}]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"nu", " ", 
        RowBox[{"(", 
         RowBox[{"a6", "+", 
          RowBox[{"a4", " ", "y"}], "+", 
          RowBox[{"a1", " ", "x", " ", "y"}], "+", 
          RowBox[{"a5", " ", "z"}], "+", 
          RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], "EE"]}], ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "nu"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "c", " ", "y"}], "-", 
          RowBox[{"a2", " ", 
           SuperscriptBox["y", "2"]}], "+", 
          RowBox[{"2", " ", "a1", " ", "y", " ", "z"}], "+", 
          RowBox[{"a2", " ", 
           SuperscriptBox["z", "2"]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["phi", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"y", ",", "z"}], "]"}]}]}], 
      RowBox[{"4", " ", "EE"}]], ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"nu", " ", 
        RowBox[{"(", 
         RowBox[{"a6", "+", 
          RowBox[{"a4", " ", "y"}], "+", 
          RowBox[{"a1", " ", "x", " ", "y"}], "+", 
          RowBox[{"a5", " ", "z"}], "+", 
          RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], "EE"]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{"FullSimplify", "[", " ", 
     RowBox[{
      RowBox[{"EE", "  ", 
       RowBox[{
        RowBox[{"nu", " ", "/", 
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", "nu"}], ")"}]}], " ", "/", " ", 
        RowBox[{"(", 
         RowBox[{"1", " ", "-", " ", 
          RowBox[{"2", " ", "nu"}]}], ")"}]}], " ", 
       RowBox[{"Tr", "[", " ", "strain", " ", "]"}], " ", 
       RowBox[{"IdentityMatrix", "[", " ", "3", " ", "]"}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"EE", " ", "/", " ", 
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", "nu"}], ")"}]}], " ", "strain"}]}], 
     "]"}]}], " ", ")"}], " ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"a6", "+", 
       RowBox[{"a4", " ", "y"}], "+", 
       RowBox[{"a1", " ", "x", " ", "y"}], "+", 
       RowBox[{"a5", " ", "z"}], "+", 
       RowBox[{"a2", " ", "x", " ", "z"}]}], 
      FractionBox[
       RowBox[{
        RowBox[{"nu", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"c", "-", 
              RowBox[{"a2", " ", "y"}]}], ")"}], " ", "z"}], "+", 
           RowBox[{"a1", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["y", "2"]}], "+", 
              SuperscriptBox["z", "2"]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]], 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "nu"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "c", " ", "y"}], "-", 
           RowBox[{"a2", " ", 
            SuperscriptBox["y", "2"]}], "+", 
           RowBox[{"2", " ", "a1", " ", "y", " ", "z"}], "+", 
           RowBox[{"a2", " ", 
            SuperscriptBox["z", "2"]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]]},
     {
      FractionBox[
       RowBox[{
        RowBox[{"nu", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"c", "-", 
              RowBox[{"a2", " ", "y"}]}], ")"}], " ", "z"}], "+", 
           RowBox[{"a1", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["y", "2"]}], "+", 
              SuperscriptBox["z", "2"]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]], "0", "0"},
     {
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "nu"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "c", " ", "y"}], "-", 
           RowBox[{"a2", " ", 
            SuperscriptBox["y", "2"]}], "+", 
           RowBox[{"2", " ", "a1", " ", "y", " ", "z"}], "+", 
           RowBox[{"a2", " ", 
            SuperscriptBox["z", "2"]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]], "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"Div", "[", "sig", "]"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", "a1", " ", "y"}], "+", 
     RowBox[{"2", " ", "a2", " ", "z"}], "+", 
     RowBox[{
      SuperscriptBox["phi", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["phi", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"y", ",", "z"}], "]"}]}], 
    RowBox[{"2", "+", 
     RowBox[{"2", " ", "nu"}]}]], ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"traction", " ", "=", " ", 
    RowBox[{"sig", " ", ".", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", " ", "0", ",", "0"}], "}"}]}]}], " ", ")"}], " ", "//",
   " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"a6", "+", 
       RowBox[{"a4", " ", "y"}], "+", 
       RowBox[{"a1", " ", "x", " ", "y"}], "+", 
       RowBox[{"a5", " ", "z"}], "+", 
       RowBox[{"a2", " ", "x", " ", "z"}]}]},
     {
      FractionBox[
       RowBox[{
        RowBox[{"nu", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"c", "-", 
              RowBox[{"a2", " ", "y"}]}], ")"}], " ", "z"}], "+", 
           RowBox[{"a1", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["y", "2"]}], "+", 
              SuperscriptBox["z", "2"]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]]},
     {
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "nu"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "c", " ", "y"}], "-", 
           RowBox[{"a2", " ", 
            SuperscriptBox["y", "2"]}], "+", 
           RowBox[{"2", " ", "a1", " ", "y", " ", "z"}], "+", 
           RowBox[{"a2", " ", 
            SuperscriptBox["z", "2"]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["phi", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"y", ",", "z"}], "]"}]}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   a6 + a4 y + a1 x y + a5 z + a2 x z, 
    Rational[1, 4] (1 + nu)^(-1) (nu (2 (c - a2 y) z + a1 (-y^2 + z^2)) + 
     2 Derivative[1, 0][phi][y, z]), 
    Rational[1, 4] (1 + nu)^(-1) (-nu (2 c y - a2 y^2 + 2 a1 y z + a2 z^2) + 
     2 Derivative[0, 1][phi][y, z])}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["traction"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a6", "+", 
    RowBox[{"a4", " ", "y"}], "+", 
    RowBox[{"a1", " ", "x", " ", "y"}], "+", 
    RowBox[{"a5", " ", "z"}], "+", 
    RowBox[{"a2", " ", "x", " ", "z"}]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"nu", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"c", "-", 
           RowBox[{"a2", " ", "y"}]}], ")"}], " ", "z"}], "+", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["y", "2"]}], "+", 
           SuperscriptBox["z", "2"]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["phi", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}]}]}], 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "nu"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "c", " ", "y"}], "-", 
        RowBox[{"a2", " ", 
         SuperscriptBox["y", "2"]}], "+", 
        RowBox[{"2", " ", "a1", " ", "y", " ", "z"}], "+", 
        RowBox[{"a2", " ", 
         SuperscriptBox["z", "2"]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["phi", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}]}]}], 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"traction", "  ", "/.", " ", 
    RowBox[{"x", " ", "\[Rule]", " ", "0"}]}], "  ", ")"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a6", "+", 
    RowBox[{"a4", " ", "y"}], "+", 
    RowBox[{"a5", " ", "z"}]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"nu", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"c", "-", 
           RowBox[{"a2", " ", "y"}]}], ")"}], " ", "z"}], "+", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["y", "2"]}], "+", 
           SuperscriptBox["z", "2"]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["phi", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}]}]}], 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "nu"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "c", " ", "y"}], "-", 
        RowBox[{"a2", " ", 
         SuperscriptBox["y", "2"]}], "+", 
        RowBox[{"2", " ", "a1", " ", "y", " ", "z"}], "+", 
        RowBox[{"a2", " ", 
         SuperscriptBox["z", "2"]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["phi", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}]}]}], 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"traction", "  ", "/.", " ", 
    RowBox[{"x", " ", "\[Rule]", " ", "L"}]}], "  ", ")"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a6", "+", 
    RowBox[{"a4", " ", "y"}], "+", 
    RowBox[{"a1", " ", "L", " ", "y"}], "+", 
    RowBox[{"a5", " ", "z"}], "+", 
    RowBox[{"a2", " ", "L", " ", "z"}]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"nu", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"c", "-", 
           RowBox[{"a2", " ", "y"}]}], ")"}], " ", "z"}], "+", 
        RowBox[{"a1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["y", "2"]}], "+", 
           SuperscriptBox["z", "2"]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["phi", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}]}]}], 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "nu"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "c", " ", "y"}], "-", 
        RowBox[{"a2", " ", 
         SuperscriptBox["y", "2"]}], "+", 
        RowBox[{"2", " ", "a1", " ", "y", " ", "z"}], "+", 
        RowBox[{"a2", " ", 
         SuperscriptBox["z", "2"]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["phi", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"y", ",", "z"}], "]"}]}]}], 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"traction", " ", "=", " ", 
    RowBox[{"sig", " ", ".", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", 
       RowBox[{"Cos", "[", "t", "]"}], ",", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], "}"}]}]}], " ", ")"}], " ", "//", 
  " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"Sin", "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "nu"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "c", " ", "y"}], "-", 
              RowBox[{"a2", " ", 
               SuperscriptBox["y", "2"]}], "+", 
              RowBox[{"2", " ", "a1", " ", "y", " ", "z"}], "+", 
              RowBox[{"a2", " ", 
               SuperscriptBox["z", "2"]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox["phi", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"y", ",", "z"}], "]"}]}]}], ")"}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"nu", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{"c", "-", 
                 RowBox[{"a2", " ", "y"}]}], ")"}], " ", "z"}], "+", 
              RowBox[{"a1", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["y", "2"]}], "+", 
                 SuperscriptBox["z", "2"]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox["phi", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"y", ",", "z"}], "]"}]}]}], ")"}]}], 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}]}]]}]},
     {"0"},
     {"0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   Rational[1, 4] (1 + nu)^(-1) 
     Sin[t] (-nu (2 c y - a2 y^2 + 2 a1 y z + a2 z^2) + 
      2 Derivative[0, 1][phi][y, z]) + 
    Rational[1, 4] (1 + nu)^(-1) 
     Cos[t] (nu (2 (c - a2 y) z + a1 (-y^2 + z^2)) + 
      2 Derivative[1, 0][phi][y, z]), 0, 0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"u", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"a1", ",", "a2", ",", "a4", ",", "c", ",", "a5", ",", "6"}], 
     "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", "*", " ", "EE"}], "]"}], ",", " ", 
   
   RowBox[{"{", 
    RowBox[{"a1", ",", "a2", ",", "a4", ",", "c", ",", "a5", ",", "6"}], 
    "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"TeXForm", "[", "%", "]"}]}], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"EE", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "rz", " ", "y"}], "+", 
      RowBox[{"2", " ", "ry", " ", "z"}]}], ")"}]}], "+", 
   RowBox[{"x", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "a6"}], "+", 
      RowBox[{"2", " ", "a4", " ", "y"}], "+", 
      RowBox[{"a1", " ", "x", " ", "y"}], "+", 
      RowBox[{"2", " ", "a5", " ", "z"}], "+", 
      RowBox[{"a2", " ", "x", " ", "z"}]}], ")"}]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"phi", "[", 
     RowBox[{"y", ",", "z"}], "]"}]}]}], 
  RowBox[{"2", " ", "EE"}]]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a6", " ", "x"}], "+", 
  RowBox[{"a4", " ", "x", " ", "y"}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "a1", " ", 
   SuperscriptBox["x", "2"], " ", "y"}], "+", 
  RowBox[{"a5", " ", "x", " ", "z"}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "a2", " ", 
   SuperscriptBox["x", "2"], " ", "z"}], "+", 
  RowBox[{"EE", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "rz"}], " ", "y"}], "+", 
     RowBox[{"ry", " ", "z"}]}], ")"}]}], "+", 
  RowBox[{"phi", "[", 
   RowBox[{"y", ",", "z"}], "]"}]}]], "Output"],

Cell["\<\
\\Mvariable{a6}\\,x + \\Muserfunction{a4}\\,x\\,y + \
\\frac{\\Muserfunction{a1}\\,x^2\\,y}{2} + \\Mvariable{a5}\\,x\\,z + 
  \\frac{\\Mvariable{a2}\\,x^2\\,z}{2} + \\Mvariable{EE}\\,
   \\left( -\\left( \\Mvariable{rz}\\,y \\right)  + \\Mvariable{ry}\\,z \
\\right)  + \\phi(y,z)\
\>", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"u", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"a1", ",", "a2", ",", "a4", ",", "c", ",", "a5", ",", "6"}], 
     "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"[", "2", "]"}], "]"}], " ", "*", " ", "EE"}], "]"}], ",", " ", 
   
   RowBox[{"{", 
    RowBox[{"a1", ",", "a2", ",", "a4", ",", "c", ",", "a5", ",", "6"}], 
    "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"TeXForm", "[", "%", "]"}]}], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "6"}], " ", "a6", " ", "nu", " ", "y"}], "-", 
   RowBox[{"a1", " ", "x", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      RowBox[{"3", " ", "nu", " ", 
       SuperscriptBox["y", "2"]}]}], ")"}]}], "+", 
   RowBox[{"6", " ", "nu", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", " ", "x"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a5", "+", 
         RowBox[{"a2", " ", "x"}]}], ")"}], " ", "y"}]}], ")"}], " ", "z"}], 
   "+", 
   RowBox[{"3", " ", "a1", " ", "nu", " ", "x", " ", 
    SuperscriptBox["z", "2"]}], "+", 
   RowBox[{"6", " ", "EE", " ", 
    RowBox[{"(", 
     RowBox[{"ly", "+", 
      RowBox[{"rz", " ", "x"}], "-", 
      RowBox[{"rx", " ", "z"}]}], ")"}]}], "-", 
   RowBox[{"3", " ", "a4", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      RowBox[{"nu", " ", 
       RowBox[{"(", 
        RowBox[{"y", "-", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}]}], 
  RowBox[{"6", " ", "EE"}]]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c", " ", "nu", " ", "x", " ", "z"}], "-", 
  RowBox[{"a5", " ", "nu", " ", "y", " ", "z"}], "-", 
  RowBox[{"a2", " ", "nu", " ", "x", " ", "y", " ", "z"}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", "a1", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "x"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        RowBox[{"3", " ", "nu", " ", 
         SuperscriptBox["y", "2"]}]}], ")"}]}], "+", 
     RowBox[{"3", " ", "nu", " ", "x", " ", 
      SuperscriptBox["z", "2"]}]}], ")"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "a4", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["x", "2"], "+", 
     RowBox[{"nu", " ", 
      RowBox[{"(", 
       RowBox[{"y", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", "a6", " ", "nu", " ", "y"}], "+", 
     RowBox[{"6", " ", "EE", " ", 
      RowBox[{"(", 
       RowBox[{"ly", "+", 
        RowBox[{"rz", " ", "x"}], "-", 
        RowBox[{"rx", " ", "z"}]}], ")"}]}]}], ")"}]}]}]], "Output"],

Cell["\<\
c\\,\\nu\\,x\\,z - \\Mvariable{a5}\\,\\nu\\,y\\,z - \
\\Mvariable{a2}\\,\\nu\\,x\\,y\\,z + 
  \\frac{\\Mvariable{a1}\\,\\left( -\\left( x\\,\\left( x^2 + 3\\,\\nu\\,y^2 \
\\right)  \\right)  + 3\\,\\nu\\,x\\,z^2 \\right) }{6} - 
  \\frac{\\Mvariable{a4}\\,\\left( x^2 + \\nu\\,\\left( y - z \\right) \
\\,\\left( y + z \\right)  \\right) }{2} + 
  \\frac{-6\\,\\Mvariable{a6}\\,\\nu\\,y + 6\\,\\Mvariable{EE}\\,
      \\left( \\Mvariable{ly} + \\Mvariable{rz}\\,x - \\Mvariable{rx}\\,z \
\\right) }{6}\
\>", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"u", "[", 
     RowBox[{"[", "3", "]"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"a1", ",", "a2", ",", "a4", ",", "c", ",", "a5", ",", "6"}], 
     "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"[", "3", "]"}], "]"}], " ", "*", " ", "EE"}], "]"}], ",", " ", 
   
   RowBox[{"{", 
    RowBox[{"a1", ",", "a2", ",", "a4", ",", "c", ",", "a5", ",", "6"}], 
    "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"TeXForm", "[", "%", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"3", " ", "a5", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"a2", " ", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{"6", " ", "c", " ", "nu", " ", "x", " ", "y"}], "-", 
    RowBox[{"3", " ", "a5", " ", "nu", " ", 
     SuperscriptBox["y", "2"]}], "-", 
    RowBox[{"3", " ", "a2", " ", "nu", " ", "x", " ", 
     SuperscriptBox["y", "2"]}], "-", 
    RowBox[{"6", " ", "EE", " ", 
     RowBox[{"(", 
      RowBox[{"lz", "-", 
       RowBox[{"ry", " ", "x"}], "+", 
       RowBox[{"rx", " ", "y"}]}], ")"}]}], "+", 
    RowBox[{"6", " ", "nu", " ", 
     RowBox[{"(", 
      RowBox[{"a6", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a4", "+", 
          RowBox[{"a1", " ", "x"}]}], ")"}], " ", "y"}]}], ")"}], " ", "z"}], 
    "+", 
    RowBox[{"3", " ", "nu", " ", 
     RowBox[{"(", 
      RowBox[{"a5", "+", 
       RowBox[{"a2", " ", "x"}]}], ")"}], " ", 
     SuperscriptBox["z", "2"]}]}], 
   RowBox[{"6", " ", "EE"}]]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "c"}], " ", "nu", " ", "x", " ", "y"}], "-", 
  RowBox[{"a4", " ", "nu", " ", "y", " ", "z"}], "-", 
  RowBox[{"a1", " ", "nu", " ", "x", " ", "y", " ", "z"}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"6", " ", "EE", " ", 
      RowBox[{"(", 
       RowBox[{"lz", "-", 
        RowBox[{"ry", " ", "x"}], "+", 
        RowBox[{"rx", " ", "y"}]}], ")"}]}], "-", 
     RowBox[{"6", " ", "a6", " ", "nu", " ", "z"}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", "a5", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"3", " ", "nu", " ", 
      SuperscriptBox["y", "2"]}], "-", 
     RowBox[{"3", " ", "nu", " ", 
      SuperscriptBox["z", "2"]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", "a2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"3", " ", "nu", " ", "x", " ", 
      SuperscriptBox["y", "2"]}], "-", 
     RowBox[{"3", " ", "nu", " ", "x", " ", 
      SuperscriptBox["z", "2"]}]}], ")"}]}]}]], "Output"],

Cell["\<\
-\\left( c\\,\\nu\\,x\\,y \\right)  - \\Mvariable{a4}\\,\\nu\\,y\\,z - \
\\Mvariable{a1}\\,\\nu\\,x\\,y\\,z + 
  \\frac{6\\,\\Mvariable{EE}\\,\\left( \\Mvariable{lz} - \\Mvariable{ry}\\,x \
+ \\Mvariable{rx}\\,y \\right)  - 
     6\\,\\Mvariable{a6}\\,\\nu\\,z}{6} + \\frac{\\Mvariable{a5}\\,\\left( -3\
\\,x^2 + 3\\,\\nu\\,y^2 - 3\\,\\nu\\,z^2 \\right) }{6} + 
  \\frac{\\Mvariable{a2}\\,\\left( -x^3 + 3\\,\\nu\\,x\\,y^2 - \
3\\,\\nu\\,x\\,z^2 \\right) }{6}\
\>", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"sig", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"a1", ",", "a2", ",", "a4", ",", "c", ",", "a5", ",", "6"}], 
     "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"TeXForm", "[", "%", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"a6", "+", 
  RowBox[{"a4", " ", "y"}], "+", 
  RowBox[{"a1", " ", "x", " ", "y"}], "+", 
  RowBox[{"a5", " ", "z"}], "+", 
  RowBox[{"a2", " ", "x", " ", "z"}]}]], "Output"],

Cell["\<\
\\Mvariable{a6} + \\Mvariable{a4}\\,y + \\Mvariable{a1}\\,x\\,y + \
\\Mvariable{a5}\\,z + \\Mvariable{a2}\\,x\\,z\
\>", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"sig", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"a1", ",", "a2", ",", "a4", ",", "c", ",", "a5", ",", "6"}], 
     "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{"sig", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], " ", "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "a2", ",", "a4", ",", "c", ",", "a5", ",", "6"}], 
    "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"TeXForm", "[", "%%", "]"}]}], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"nu", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"c", "-", 
         RowBox[{"a2", " ", "y"}]}], ")"}], " ", "z"}], "+", 
      RowBox[{"a1", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["y", "2"]}], "+", 
         SuperscriptBox["z", "2"]}], ")"}]}]}], ")"}]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox["phi", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"y", ",", "z"}], "]"}]}]}], 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "nu"}], ")"}]}]]], "Output"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"c", " ", "nu", " ", "z"}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"a2", " ", "nu", " ", "y", " ", "z"}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"a1", " ", "nu", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["y", "2"]}], "+", 
      SuperscriptBox["z", "2"]}], ")"}]}], 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["phi", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"y", ",", "z"}], "]"}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}]}]]}]], "Output"],

Cell["\<\
\\frac{\\nu\\,\\left( 2\\,\\left( c - \\Mvariable{a2}\\,y \\right) \\,z + \
\\Mvariable{a1}\\,\\left( -y^2 + z^2 \\right)  \\right)  + 
    2\\,\\phi^{(1,0)}(y,z)}{4\\,\\left( 1 + \\nu \\right) }\
\>", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"sig", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "3"}], "]"}], "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"a1", ",", "a2", ",", "a4", ",", "c", ",", "a5", ",", "6"}], 
       "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{"sig", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "3"}], "]"}], "]"}], " ", "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"a1", ",", "a2", ",", "a4", ",", "c", ",", "a5", ",", "6"}], 
      "}"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"TeXForm", "[", "%%", "]"}]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "nu"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "c", " ", "y"}], "-", 
      RowBox[{"a2", " ", 
       SuperscriptBox["y", "2"]}], "+", 
      RowBox[{"2", " ", "a1", " ", "y", " ", "z"}], "+", 
      RowBox[{"a2", " ", 
       SuperscriptBox["z", "2"]}]}], ")"}]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox["phi", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"y", ",", "z"}], "]"}]}]}], 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "nu"}], ")"}]}]]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"c", " ", "nu", " ", "y"}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]]}], "-", 
  FractionBox[
   RowBox[{"a1", " ", "nu", " ", "y", " ", "z"}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"a2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"nu", " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"nu", " ", 
       SuperscriptBox["z", "2"]}]}], ")"}]}], 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["phi", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"y", ",", "z"}], "]"}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}]}]]}]], "Output"],

Cell["\<\
\\frac{-\\left( \\nu\\,\\left( 2\\,c\\,y - \\Mvariable{a2}\\,y^2 + \
2\\,\\Mvariable{a1}\\,y\\,z + \\Mvariable{a2}\\,z^2 \\right)  \\right)
        + 2\\,\\phi^{(0,1)}(y,z)}{4\\,\\left( 1 + \\nu \\right) }\
\>", "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
PrintingStyleEnvironment->"Condensed",
WindowSize->{986, 821},
WindowMargins->{{30, Automatic}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Landscape",
"PaperSize"->{597.562, 842.375},
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "local", 
   "constant", "Oxford", "Tex", "ElasticaBook", 
   "C04_CompleteElasticityProblem", "NB"}, "st_venant.nb.ps", 
  CharacterEncoding -> "iso8859-1"]},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 116, 3, 73, "Section"],
Cell[CellGroupData[{
Cell[1472, 45, 306, 9, 55, "Input"],
Cell[1781, 56, 85, 1, 31, "Output"]
}, Open  ]],
Cell[1881, 60, 97, 2, 55, "Input"],
Cell[CellGroupData[{
Cell[2003, 66, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2115, 71, 137, 3, 32, "Input"],
Cell[2255, 76, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2388, 83, 914, 27, 55, "Input"],
Cell[3305, 112, 579, 18, 60, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3921, 135, 470, 13, 77, "Input"],
Cell[4394, 150, 385, 8, 24, "Message"],
Cell[4782, 160, 1795, 55, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6614, 220, 177, 5, 32, "Input"],
Cell[6794, 227, 80, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6911, 234, 177, 5, 32, "Input"],
Cell[7091, 241, 80, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7208, 248, 367, 11, 32, "Input"],
Cell[7578, 261, 1101, 35, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8716, 301, 724, 21, 43, "Input"],
Cell[9443, 324, 1638, 54, 100, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11118, 383, 548, 15, 59, "Input"],
Cell[11669, 400, 385, 8, 20, "Message"],
Cell[12057, 410, 8560, 260, 284, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20654, 675, 426, 10, 43, "Input"],
Cell[21083, 687, 231, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21351, 698, 688, 19, 59, "Input"],
Cell[22042, 719, 596, 19, 76, "Output"],
Cell[22641, 740, 434, 16, 76, "Output"],
Cell[23078, 758, 596, 19, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23711, 782, 65, 1, 27, "Input"],
Cell[23779, 785, 28, 0, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23844, 790, 72, 1, 27, "Input"],
Cell[23919, 793, 4053, 126, 228, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[28021, 925, 111, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[28157, 930, 140, 4, 27, "Input"],
Cell[28300, 936, 500, 19, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28837, 960, 397, 13, 27, "Input"],
Cell[29237, 975, 572, 21, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29846, 1001, 252, 7, 27, "Input"],
Cell[30101, 1010, 702, 25, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30840, 1040, 397, 13, 27, "Input"],
Cell[31240, 1055, 572, 21, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31849, 1081, 456, 15, 27, "Input"],
Cell[32308, 1098, 1106, 39, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33451, 1142, 252, 7, 27, "Input"],
Cell[33706, 1151, 702, 25, 46, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[34457, 1182, 105, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[34587, 1187, 246, 7, 27, "Input"],
Cell[34836, 1196, 1810, 56, 100, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36683, 1257, 93, 2, 27, "Input"],
Cell[36779, 1261, 83, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36899, 1268, 1195, 33, 91, "Input"],
Cell[38097, 1303, 1597, 48, 80, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39731, 1356, 359, 12, 27, "Input"],
Cell[40093, 1370, 997, 36, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41127, 1411, 848, 26, 43, "Input"],
Cell[41978, 1439, 499, 16, 46, "Output"],
Cell[42480, 1457, 335, 11, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42852, 1473, 827, 25, 43, "Input"],
Cell[43682, 1500, 499, 16, 46, "Output"],
Cell[44184, 1518, 335, 11, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44556, 1534, 27, 0, 27, "Input"],
Cell[44586, 1536, 2275, 68, 140, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46898, 1609, 334, 10, 27, "Input"],
Cell[47235, 1621, 5139, 146, 160, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52411, 1772, 651, 18, 27, "Input"],
Cell[53065, 1792, 4588, 130, 160, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57690, 1927, 267, 6, 59, "Input"],
Cell[57960, 1935, 1564, 50, 46, "Output"],
Cell[59527, 1987, 2064, 58, 102, "Output"]
}, Open  ]],
Cell[61606, 2048, 45, 0, 43, "Input"],
Cell[61654, 2050, 212, 6, 27, "Input"],
Cell[61869, 2058, 26, 0, 27, "Input"],
Cell[CellGroupData[{
Cell[61920, 2062, 200, 6, 27, "Input"],
Cell[62123, 2070, 1252, 42, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63412, 2117, 851, 27, 43, "Input"],
Cell[64266, 2146, 486, 16, 46, "Output"],
Cell[64755, 2164, 390, 14, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65182, 2183, 845, 27, 43, "Input"],
Cell[66030, 2212, 486, 16, 46, "Output"],
Cell[66519, 2230, 390, 14, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66946, 2249, 75, 1, 27, "Input"],
Cell[67024, 2252, 2793, 83, 120, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69854, 2340, 378, 10, 27, "Input"],
Cell[70235, 2352, 3473, 104, 140, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73745, 2461, 76, 1, 27, "Input"],
Cell[73824, 2464, 2970, 88, 120, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76831, 2557, 338, 10, 27, "Input"],
Cell[77172, 2569, 4061, 128, 158, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81270, 2702, 762, 20, 43, "Input"],
Cell[82035, 2724, 3689, 115, 118, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85761, 2844, 112, 3, 27, "Input"],
Cell[85876, 2849, 706, 24, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86619, 2878, 246, 7, 27, "Input"],
Cell[86868, 2887, 2265, 68, 104, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[89170, 2960, 34, 0, 27, "Input"],
Cell[89207, 2962, 1747, 58, 89, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90991, 3025, 157, 4, 27, "Input"],
Cell[91151, 3031, 1655, 56, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92843, 3092, 157, 4, 27, "Input"],
Cell[93003, 3098, 1747, 58, 89, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[94787, 3161, 321, 9, 27, "Input"],
Cell[95111, 3172, 2421, 71, 90, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97569, 3248, 673, 19, 59, "Input"],
Cell[98245, 3269, 647, 20, 44, "Output"],
Cell[98895, 3291, 577, 18, 44, "Output"],
Cell[99475, 3311, 306, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99818, 3322, 673, 19, 59, "Input"],
Cell[100494, 3343, 1126, 36, 46, "Output"],
Cell[101623, 3381, 1224, 38, 44, "Output"],
Cell[102850, 3421, 527, 10, 100, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103414, 3436, 673, 19, 59, "Input"],
Cell[104090, 3457, 1044, 31, 46, "Output"],
Cell[105137, 3490, 1193, 36, 44, "Output"],
Cell[106333, 3528, 485, 9, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106855, 3542, 377, 10, 43, "Input"],
Cell[107235, 3554, 197, 5, 27, "Output"],
Cell[107435, 3561, 139, 3, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107611, 3569, 695, 19, 59, "Input"],
Cell[108309, 3590, 749, 27, 48, "Output"],
Cell[109061, 3619, 904, 33, 48, "Output"],
Cell[109968, 3654, 221, 4, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[110226, 3663, 779, 21, 75, "Input"],
Cell[111008, 3686, 690, 24, 48, "Output"],
Cell[111701, 3712, 951, 35, 48, "Output"],
Cell[112655, 3749, 231, 4, 55, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

