(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     31930,       1099]
NotebookOptionsPosition[     29008,        999]
NotebookOutlinePosition[     29451,       1017]
CellTagsIndexPosition[     29408,       1014]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{"Torsion", " ", "of", " ", "bar"}], " ", "-", " ", 
     RowBox[{"general", " ", "setting", " "}]}]}], "Subtitle"], 
  TraditionalForm]], "Input",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
    "]"}], "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\n", 
 RowBox[{"<<", "Displacement.m"}], "\n"}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SetCoordinates", "[", 
   RowBox[{"Cartesian", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell["notation a = \[Alpha] / L", "Subsection"],

Cell[CellGroupData[{

Cell["circular cross section", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"a", " ", 
   RowBox[{"Cross", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0", ",", " ", "z"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "y", ",", "0"}], "}"}]}], "]"}], 
   " "}]}], "\[IndentingNewLine]", 
 RowBox[{"eps", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", " ", 
   RowBox[{
    RowBox[{"1", "/", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}]}], " ", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"eps", " ", "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{"sig", " ", "=", " ", 
  RowBox[{
   RowBox[{"lambda", " ", 
    RowBox[{"Tr", "[", " ", "eps", " ", "]"}], " ", 
    RowBox[{"IdentityMatrix", "[", "3", "]"}]}], " ", "+", " ", 
   RowBox[{"2", " ", "mu", " ", "eps", " "}]}]}], "\[IndentingNewLine]", 
 RowBox[{"sig", " ", "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{"Div", "[", " ", "sig", " ", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "a"}], " ", "y", " ", "z"}], ",", 
   RowBox[{"a", " ", "x", " ", "z"}], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"a", " ", "y"}], "2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"a", " ", "x"}], "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"a", " ", "y"}], "2"]}], ",", 
     FractionBox[
      RowBox[{"a", " ", "x"}], "2"], ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"a", " ", "y"}], "2"]}]},
     {"0", "0", 
      FractionBox[
       RowBox[{"a", " ", "x"}], "2"]},
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{"a", " ", "y"}], "2"]}], 
      FractionBox[
       RowBox[{"a", " ", "x"}], "2"], "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(lambda\\)\\\" is similar to existing symbol \
\\\"\\!\\(Llambda\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", "a"}], " ", "mu", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"a", " ", "mu", " ", "x"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], " ", "mu", " ", "y"}], ",", 
     RowBox[{"a", " ", "mu", " ", "x"}], ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      RowBox[{
       RowBox[{"-", "a"}], " ", "mu", " ", "y"}]},
     {"0", "0", 
      RowBox[{"a", " ", "mu", " ", "x"}]},
     {
      RowBox[{
       RowBox[{"-", "a"}], " ", "mu", " ", "y"}], 
      RowBox[{"a", " ", "mu", " ", "x"}], "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lattraction", " ", "=", " ", 
  RowBox[{
   RowBox[{"sig", " ", ".", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", "y", ",", " ", "0"}], "}"}]}], " ", "/", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"x", "^", "2"}], " ", "+", " ", 
     RowBox[{"y", "^", "2"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"endtraction", " ", "=", " ", 
  RowBox[{"sig", " ", ".", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "a"}], " ", "mu", " ", "y"}], ",", 
   RowBox[{"a", " ", "mu", " ", "x"}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"endtraction", " ", "r"}], " ", "/.", " ", 
     RowBox[{"x", " ", "\[Rule]", " ", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]}], " ", "/.", " ", 
    RowBox[{"y", " ", "\[Rule]", " ", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0", ",", " ", "R"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", " ", "0", ",", " ", 
     RowBox[{"2", " ", "Pi"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Cross", "[", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", " ", "0"}], "}"}], " ", ",", " ", 
        "endtraction"}], "]"}], "  ", "r"}], " ", "/.", " ", 
     RowBox[{"x", " ", "\[Rule]", " ", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]}], " ", "/.", " ", 
    RowBox[{"y", " ", "\[Rule]", " ", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0", ",", " ", "R"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", " ", "0", ",", " ", 
     RowBox[{"2", " ", "Pi"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    FractionBox["1", "2"], " ", "a", " ", "mu", " ", "\[Pi]", " ", 
    SuperscriptBox["R", "4"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pt", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"r", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
      RowBox[{
       RowBox[{"r", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", "z"}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"tangent", " ", "=", " ", 
    RowBox[{"D", "[", " ", 
     RowBox[{"pt", " ", ",", " ", "\[Theta]"}], " ", "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"normal", " ", "=", " ", 
    RowBox[{"Cross", "[", " ", 
     RowBox[{"tangent", ",", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}]}]}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
    RowBox[{"r", "[", "\[Theta]", "]"}]}], ",", 
   RowBox[{
    RowBox[{"r", "[", "\[Theta]", "]"}], " ", 
    RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", "z"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"r", "[", "\[Theta]", "]"}]}], " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{
      SuperscriptBox["r", "\[Prime]",
       MultilineFunction->None], "[", "\[Theta]", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"r", "[", "\[Theta]", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{
      SuperscriptBox["r", "\[Prime]",
       MultilineFunction->None], "[", "\[Theta]", "]"}]}]}], ",", "0"}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(normal\\)\\\" is similar to existing symbol \
\\\"\\!\\(Normal\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"r", "[", "\[Theta]", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{
      SuperscriptBox["r", "\[Prime]",
       MultilineFunction->None], "[", "\[Theta]", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
    RowBox[{
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{
      SuperscriptBox["r", "\[Prime]",
       MultilineFunction->None], "[", "\[Theta]", "]"}]}]}], ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{"surfacesig", " ", "=", 
    RowBox[{"sig", " ", "/.", " ", 
     RowBox[{"Thread", "[", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", " ", ",", " ", "y", ",", " ", "z"}], "}"}], " ", 
       "\[Rule]", "  ", "pt"}], " ", "]"}]}]}], ")"}], " ", "//", " ", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{"lattraction", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", " ", 
   RowBox[{"surfacesig", ".", " ", "normal"}], " ", "]"}]}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      RowBox[{
       RowBox[{"-", "a"}], " ", "mu", " ", 
       RowBox[{"r", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]},
     {"0", "0", 
      RowBox[{"a", " ", "mu", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"r", "[", "\[Theta]", "]"}]}]},
     {
      RowBox[{
       RowBox[{"-", "a"}], " ", "mu", " ", 
       RowBox[{"r", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
      RowBox[{"a", " ", "mu", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"r", "[", "\[Theta]", "]"}]}], "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"-", "a"}], " ", "mu", " ", 
    RowBox[{"r", "[", "\[Theta]", "]"}], " ", 
    RowBox[{
     SuperscriptBox["r", "\[Prime]",
      MultilineFunction->None], "[", "\[Theta]", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"lattraction", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "0"}], ",", " ", 
   RowBox[{"r", "[", "\[Theta]", "]"}], ",", "\[Theta]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", "[", "\[Theta]", "]"}], "\[Rule]", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", "[", "\[Theta]", "]"}], "\[Rule]", 
     RowBox[{"C", "[", "1", "]"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cross", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "0", ",", " ", "z"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", " ", "y", ",", "0"}], "}"}]}], "]"}], " ", "+", " ",
      
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0", ",", " ", 
       RowBox[{"\[Phi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "}"}]}], ")"}], 
   " "}]}], "\[IndentingNewLine]", 
 RowBox[{"eps", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", " ", 
   RowBox[{
    RowBox[{"1", "/", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}]}], " ", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"eps", " ", "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{"sig", " ", "=", " ", 
  RowBox[{
   RowBox[{"lambda", " ", 
    RowBox[{"Tr", "[", " ", "eps", " ", "]"}], " ", 
    RowBox[{"IdentityMatrix", "[", "3", "]"}]}], " ", "+", " ", 
   RowBox[{"2", " ", "mu", " ", "eps", " "}]}]}], "\[IndentingNewLine]", 
 RowBox[{"sig", " ", "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Div", "[", " ", "sig", " ", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "a"}], " ", "y", " ", "z"}], ",", 
   RowBox[{"a", " ", "x", " ", "z"}], ",", 
   RowBox[{"a", " ", 
    RowBox[{"\[Phi]", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      FractionBox["1", "2"], " ", "a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "y"}], "+", 
        RowBox[{
         SuperscriptBox["\[Phi]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      FractionBox["1", "2"], " ", "a", " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{
         SuperscriptBox["\[Phi]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", "a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "y"}], "+", 
        RowBox[{
         SuperscriptBox["\[Phi]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", "a", " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{
         SuperscriptBox["\[Phi]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], ",", "0"}], "}"}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      RowBox[{
       FractionBox["1", "2"], " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "y"}], "+", 
         RowBox[{
          SuperscriptBox["\[Phi]", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]},
     {"0", "0", 
      RowBox[{
       FractionBox["1", "2"], " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{
          SuperscriptBox["\[Phi]", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]},
     {
      RowBox[{
       FractionBox["1", "2"], " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "y"}], "+", 
         RowBox[{
          SuperscriptBox["\[Phi]", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], 
      RowBox[{
       FractionBox["1", "2"], " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{
          SuperscriptBox["\[Phi]", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"a", " ", "mu", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "y"}], "+", 
        RowBox[{
         SuperscriptBox["\[Phi]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"a", " ", "mu", " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{
         SuperscriptBox["\[Phi]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", "mu", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "y"}], "+", 
        RowBox[{
         SuperscriptBox["\[Phi]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], ",", 
     RowBox[{"a", " ", "mu", " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{
         SuperscriptBox["\[Phi]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], ",", "0"}], "}"}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      RowBox[{"a", " ", "mu", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "y"}], "+", 
         RowBox[{
          SuperscriptBox["\[Phi]", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]},
     {"0", "0", 
      RowBox[{"a", " ", "mu", " ", 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{
          SuperscriptBox["\[Phi]", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]},
     {
      RowBox[{"a", " ", "mu", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "y"}], "+", 
         RowBox[{
          SuperscriptBox["\[Phi]", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], 
      RowBox[{"a", " ", "mu", " ", 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{
          SuperscriptBox["\[Phi]", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"a", " ", "mu", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "+", 
    RowBox[{"a", " ", "mu", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "y"}], "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"traction", " ", "=", " ", 
  RowBox[{
   RowBox[{"sig", " ", ".", " ", 
    RowBox[{"{", 
     RowBox[{"nx", " ", ",", " ", "ny", " ", ",", " ", "0"}], "}"}]}], 
   "  "}]}], "\[IndentingNewLine]", 
 RowBox[{"traction", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"sig", " ", ".", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", ",", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", ",", " ", "0"}], "}"}]}], 
    " ", "/.", " ", 
    RowBox[{"x", " ", "\[Rule]", " ", 
     RowBox[{"r", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]}], " ", "/.", " ", 
   RowBox[{"y", " ", "\[Rule]", "  ", 
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " "}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"a", " ", "mu", " ", "ny", " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{
        SuperscriptBox["\[Phi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"a", " ", "mu", " ", "nx", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "y"}], "+", 
       RowBox[{
        SuperscriptBox["\[Phi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"a", " ", "mu", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"r", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[Phi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"r", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
         RowBox[{"r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], "]"}]}], ")"}]}], "+", 
    RowBox[{"a", " ", "mu", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "r"}], " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[Phi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"r", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
         RowBox[{"r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], "]"}]}], ")"}]}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"traction", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"traction", "[", 
      RowBox[{"[", "3", "]"}], "]"}], " ", "/", " ", "a"}], " ", "/", " ", 
    "mu"}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"torsion", " ", "=", " ", 
   RowBox[{"sig", " ", ".", " ", 
    RowBox[{"{", 
     RowBox[{"0", " ", ",", " ", "0", " ", ",", " ", "1"}], "}"}]}]}], "  ", 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", " ", "mu", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "y"}], "+", 
      RowBox[{
       SuperscriptBox["\[Phi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], ",", 
   RowBox[{"a", " ", "mu", " ", 
    RowBox[{"(", 
     RowBox[{"x", "+", 
      RowBox[{
       SuperscriptBox["\[Phi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", " ", "y", ",", " ", "0"}], "}"}], ",", " ", 
    "torsion"}], "]"}], "\t"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"a", " ", "mu", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"a", " ", "mu", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"a", " ", "mu", " ", "x", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "-", 
    RowBox[{"a", " ", "mu", " ", "y", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "y"}], "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{952, 821},
WindowMargins->{{Automatic, 52}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[1309, 36, 246, 8, 46, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1580, 48, 320, 9, 77, "Input"],
Cell[1903, 59, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1990, 62, 111, 2, 77, "Input"],
Cell[CellGroupData[{
Cell[2126, 68, 178, 5, 55, "Input"],
Cell[2307, 75, 96, 2, 31, "Output"]
}, Open  ]],
Cell[2418, 80, 47, 0, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2490, 84, 44, 0, 31, "Subsection"],
Cell[CellGroupData[{
Cell[2559, 88, 1103, 28, 143, "Input"],
Cell[3665, 118, 171, 5, 31, "Output"],
Cell[3839, 125, 510, 18, 44, "Output"],
Cell[4352, 145, 479, 18, 82, "Output"],
Cell[4834, 165, 392, 8, 24, "Message"],
Cell[5229, 175, 452, 14, 31, "Output"],
Cell[5684, 191, 417, 14, 58, "Output"],
Cell[6104, 207, 83, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6224, 214, 328, 9, 27, "Input"],
Cell[6555, 225, 83, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6675, 232, 163, 4, 27, "Input"],
Cell[6841, 238, 173, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7051, 248, 603, 16, 27, "Input"],
Cell[7657, 266, 83, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7777, 273, 766, 21, 27, "Input"],
Cell[8546, 296, 191, 5, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8774, 306, 739, 21, 59, "Input"],
Cell[9516, 329, 283, 8, 27, "Output"],
Cell[9802, 339, 702, 22, 27, "Output"],
Cell[10507, 363, 391, 8, 20, "Message"],
Cell[10901, 373, 680, 21, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11618, 399, 516, 13, 43, "Input"],
Cell[12137, 414, 785, 22, 63, "Output"],
Cell[12925, 438, 287, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13249, 451, 237, 6, 27, "Input"],
Cell[13489, 459, 290, 9, 27, "Output"]
}, Open  ]],
Cell[13794, 471, 26, 0, 27, "Input"],
Cell[CellGroupData[{
Cell[13845, 475, 1382, 37, 139, "Input"],
Cell[15230, 514, 256, 8, 27, "Output"],
Cell[15489, 524, 1743, 59, 44, "Output"],
Cell[17235, 585, 1749, 58, 83, "Output"],
Cell[18987, 645, 1647, 55, 29, "Output"],
Cell[20637, 702, 1649, 54, 69, "Output"],
Cell[22289, 758, 615, 21, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22941, 784, 774, 21, 43, "Input"],
Cell[23718, 807, 798, 26, 29, "Output"],
Cell[24519, 835, 1322, 41, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25878, 881, 250, 7, 27, "Input"],
Cell[26131, 890, 844, 29, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27012, 924, 227, 6, 43, "Input"],
Cell[27242, 932, 729, 25, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28008, 962, 188, 6, 27, "Input"],
Cell[28199, 970, 781, 25, 29, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

