(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     82026,       2625]
NotebookOptionsPosition[     77147,       2459]
NotebookOutlinePosition[     77591,       2477]
CellTagsIndexPosition[     77548,       2474]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["Tube autofrettage", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "Displacement.m"}], "\[IndentingNewLine]"}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The general solution in cylindrical coordinate \
system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"u", "[", 
   RowBox[{"r_", ",", "t_", ",", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ur", "[", "r", "]"}], ",", "0", ",", 
    RowBox[{"uz", "[", "z", "]"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"Strain", "[", " ", 
     RowBox[{"u", " ", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]}], " ", ")"}], " ", "//",
   "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"Tr", "[", "eps", " ", "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", " ", "]"}]}], "+", " ", 
     RowBox[{"2", " ", "\[Mu]", " ", "eps"}]}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["ur", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"ur", "[", "r", "]"}], "r"], "0"},
     {"0", "0", 
      RowBox[{
       SuperscriptBox["uz", "\[Prime]",
        MultilineFunction->None], "[", "z", "]"}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{
         SuperscriptBox["ur", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"ur", "[", "r", "]"}], "r"], "+", 
          RowBox[{
           SuperscriptBox["ur", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "+", 
          RowBox[{
           SuperscriptBox["uz", "\[Prime]",
            MultilineFunction->None], "[", "z", "]"}]}], ")"}]}]}], "0", 
      "0"},
     {"0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"ur", "[", "r", "]"}], "r"], "+", 
          RowBox[{
           SuperscriptBox["ur", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "+", 
          RowBox[{
           SuperscriptBox["uz", "\[Prime]",
            MultilineFunction->None], "[", "z", "]"}]}], ")"}]}]}], "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{
         SuperscriptBox["uz", "\[Prime]",
          MultilineFunction->None], "[", "z", "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"ur", "[", "r", "]"}], "r"], "+", 
          RowBox[{
           SuperscriptBox["ur", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "+", 
          RowBox[{
           SuperscriptBox["uz", "\[Prime]",
            MultilineFunction->None], "[", "z", "]"}]}], ")"}]}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"divsig", " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Div", "[", " ", "sig", " ", "]"}], "]"}]}], " ", ")"}], " ", "//",
   " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"ur", "[", "r", "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["ur", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}], "+", 
             RowBox[{"r", " ", 
              RowBox[{
               SuperscriptBox["ur", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
         ")"}]}], 
       SuperscriptBox["r", "2"]]},
     {"0"},
     {
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["uz", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "z", "]"}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   r^(-2) (\[Lambda] + 2 \[Mu]) (-ur[r] + 
     r (Derivative[1][ur][r] + r Derivative[2][ur][r])), 
    0, (\[Lambda] + 2 \[Mu]) Derivative[2][uz][z]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"solur", " ", "=", " ", 
  RowBox[{
   RowBox[{"DSolve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"divsig", "[", 
       RowBox[{"[", "1", "]"}], "]"}], " ", "\[Equal]", " ", "0"}], ",", " ", 
     "ur", ",", " ", "r", " ", ",", " ", 
     StyleBox[
      RowBox[{"GeneratedParameters", "->", " ", "CR"}], "MR"]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"soluz", " ", "=", " ", 
  RowBox[{
   RowBox[{"DSolve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"divsig", "[", 
       RowBox[{"[", "3", "]"}], "]"}], " ", "\[Equal]", " ", "0"}], ",", " ", 
     "uz", ",", " ", "z", " ", ",", " ", 
     StyleBox[
      RowBox[{"GeneratedParameters", "->", " ", "CZ"}], "MR"]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"ur", "\[Rule]", 
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", "r", "}"}], ",", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["r", "2"]}], ")"}], " ", 
       RowBox[{"CR", "[", "1", "]"}]}], 
      RowBox[{"2", " ", "r"}]], "+", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["r", "2"]}], ")"}], " ", 
       RowBox[{"CR", "[", "2", "]"}]}], 
      RowBox[{"2", " ", "r"}]]}]}], "]"}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(soluz\\)\\\" is similar to existing symbol \\\"\\!\\(solur\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 RowBox[{"uz", "\[Rule]", 
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", "z", "}"}], ",", 
    RowBox[{
     RowBox[{"CZ", "[", "1", "]"}], "+", 
     RowBox[{"z", " ", 
      RowBox[{"CZ", "[", "2", "]"}]}]}]}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"solur", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "2"}], "]"}], "]"}], " ", "/.", " ", 
   RowBox[{
    RowBox[{"CR", "[", "1", "]"}], " ", "\[Rule]", " ", 
    RowBox[{"(", 
     RowBox[{"A", " ", "+", " ", "B"}], ")"}]}]}], "/.", " ", 
  RowBox[{
   RowBox[{"CR", "[", "2", "]"}], " ", "\[Rule]", " ", 
   RowBox[{"\[ImaginaryI]", "  ", 
    RowBox[{"(", 
     RowBox[{"A", " ", "-", " ", "B"}], ")"}], "  "}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"A", "-", "B"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["r", "2"]}], ")"}]}], 
    RowBox[{"2", " ", "r"}]]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"A", "+", "B"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["r", "2"]}], ")"}]}], 
   RowBox[{"2", " ", "r"}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", "%", " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["A", "r"], "+", 
  RowBox[{"B", " ", "r"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"exp", " ", "=", " ", 
    RowBox[{"D", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", "r"}], " ", 
       RowBox[{"D", "[", " ", 
        RowBox[{
         RowBox[{"r", " ", 
          RowBox[{"ur", "[", "r", "]"}]}], ",", " ", "r"}], " ", "]"}]}], ",",
       " ", "r"}], " ", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", " ", "exp", " ", "]"}]}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(exp\\)\\\" is similar to existing symbol \\\"\\!\\(Exp\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"ur", "[", "r", "]"}], "+", 
     RowBox[{"r", " ", 
      RowBox[{
       SuperscriptBox["ur", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}], 
    SuperscriptBox["r", "2"]]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["ur", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], "+", 
    RowBox[{"r", " ", 
     RowBox[{
      SuperscriptBox["ur", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}]}], "r"]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"ur", "[", "r", "]"}], 
    SuperscriptBox["r", "2"]]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["ur", "\[Prime]",
     MultilineFunction->None], "[", "r", "]"}], "r"], "+", 
  RowBox[{
   SuperscriptBox["ur", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "r", "]"}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The cylinder under internal and external pressure: pi \
and pe and vertical pressure pz",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"u", " ", "[", 
     RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", "/.", " ", "solur"}], " ",
    "/.", "soluz"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["r", "2"]}], ")"}], " ", 
      RowBox[{"CR", "[", "1", "]"}]}], 
     RowBox[{"2", " ", "r"}]], "+", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["r", "2"]}], ")"}], " ", 
      RowBox[{"CR", "[", "2", "]"}]}], 
     RowBox[{"2", " ", "r"}]]}], ",", "0", ",", 
   RowBox[{
    RowBox[{"CZ", "[", "1", "]"}], "+", 
    RowBox[{"z", " ", 
     RowBox[{"CZ", "[", "2", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"Strain", "[", " ", "uu", " ", "]"}]}], " ", ")"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"Tr", "[", "eps", " ", "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", " ", "]"}]}], "+", " ", 
     RowBox[{"2", " ", "\[Mu]", " ", "eps"}]}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"CR", "[", "1", "]"}]}], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["r", "2"]}], ")"}], " ", 
           RowBox[{"CR", "[", "1", "]"}]}], 
          SuperscriptBox["r", "2"]], "+", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          RowBox[{"CR", "[", "2", "]"}]}], "-", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["r", "2"]}], ")"}], " ", 
           RowBox[{"CR", "[", "2", "]"}]}], 
          SuperscriptBox["r", "2"]]}], ")"}]}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["r", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "1", "]"}]}], 
         RowBox[{"2", " ", "r"}]], "+", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["r", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "2", "]"}]}], 
         RowBox[{"2", " ", "r"}]]}], "r"], "0"},
     {"0", "0", 
      RowBox[{"CZ", "[", "2", "]"}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"CR", "[", "1", "]"}]}], "-", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["r", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "1", "]"}]}], 
           SuperscriptBox["r", "2"]], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           RowBox[{"CR", "[", "2", "]"}]}], "-", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["r", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "2", "]"}]}], 
           SuperscriptBox["r", "2"]]}], ")"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"CR", "[", "1", "]"}]}], "-", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["r", "2"]}], ")"}], " ", 
               RowBox[{"CR", "[", "1", "]"}]}], 
              SuperscriptBox["r", "2"]], "+", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              RowBox[{"CR", "[", "2", "]"}]}], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["r", "2"]}], ")"}], " ", 
               RowBox[{"CR", "[", "2", "]"}]}], 
              SuperscriptBox["r", "2"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["r", "2"]}], ")"}], " ", 
              RowBox[{"CR", "[", "1", "]"}]}], 
             RowBox[{"2", " ", "r"}]], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["r", "2"]}], ")"}], " ", 
              RowBox[{"CR", "[", "2", "]"}]}], 
             RowBox[{"2", " ", "r"}]]}], "r"], "+", 
          RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}], "0", "0"},
     {"0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["r", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "1", "]"}]}], 
            RowBox[{"2", " ", "r"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["r", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "2", "]"}]}], 
            RowBox[{"2", " ", "r"}]]}], ")"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"CR", "[", "1", "]"}]}], "-", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["r", "2"]}], ")"}], " ", 
               RowBox[{"CR", "[", "1", "]"}]}], 
              SuperscriptBox["r", "2"]], "+", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              RowBox[{"CR", "[", "2", "]"}]}], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["r", "2"]}], ")"}], " ", 
               RowBox[{"CR", "[", "2", "]"}]}], 
              SuperscriptBox["r", "2"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["r", "2"]}], ")"}], " ", 
              RowBox[{"CR", "[", "1", "]"}]}], 
             RowBox[{"2", " ", "r"}]], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["r", "2"]}], ")"}], " ", 
              RowBox[{"CR", "[", "2", "]"}]}], 
             RowBox[{"2", " ", "r"}]]}], "r"], "+", 
          RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}], "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{"CZ", "[", "2", "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"CR", "[", "1", "]"}]}], "-", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["r", "2"]}], ")"}], " ", 
               RowBox[{"CR", "[", "1", "]"}]}], 
              SuperscriptBox["r", "2"]], "+", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              RowBox[{"CR", "[", "2", "]"}]}], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["r", "2"]}], ")"}], " ", 
               RowBox[{"CR", "[", "2", "]"}]}], 
              SuperscriptBox["r", "2"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["r", "2"]}], ")"}], " ", 
              RowBox[{"CR", "[", "1", "]"}]}], 
             RowBox[{"2", " ", "r"}]], "+", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["r", "2"]}], ")"}], " ", 
              RowBox[{"CR", "[", "2", "]"}]}], 
             RowBox[{"2", " ", "r"}]]}], "r"], "+", 
          RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["simetry condition on the vertical axis ",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqz0", " ", "=", " ", 
  RowBox[{"(", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"uu", "[", 
       RowBox[{"[", "3", "]"}], "]"}], " ", "/.", " ", 
      RowBox[{"z", " ", "\[Rule]", " ", "0"}]}], ")"}], " ", "\[Equal]", " ", 
    "0"}], ")"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CZ", "[", "1", "]"}], "\[Equal]", "0"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["condition for the vertical pressure",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ez", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"normal", " ", "=", " ", "ez"}], "\[IndentingNewLine]", 
 RowBox[{"eqv", " ", "=", " ", 
  RowBox[{"(", "  ", 
   RowBox[{"Thread", " ", "[", " ", 
    RowBox[{
     RowBox[{"sig", " ", ".", " ", "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"+", " ", "pz"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "1"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(normal\\)\\\" is similar to existing symbol \
\\\"\\!\\(Normal\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "1"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"2", " ", "\[Mu]", " ", 
      RowBox[{"CZ", "[", "2", "]"}]}], "+", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"CR", "[", "1", "]"}]}], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["r", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "1", "]"}]}], 
            SuperscriptBox["r", "2"]], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            RowBox[{"CR", "[", "2", "]"}]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["r", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "2", "]"}]}], 
            SuperscriptBox["r", "2"]]}], ")"}]}], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["r", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "1", "]"}]}], 
           RowBox[{"2", " ", "r"}]], "+", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["r", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "2", "]"}]}], 
           RowBox[{"2", " ", "r"}]]}], "r"], "+", 
        RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}], "\[Equal]", "pz"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["condition for the internal and external pressure",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"er", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"1", ",", "0", ",", "0"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", " ", 
  RowBox[{"-", " ", "er"}]}], "\[IndentingNewLine]", 
 RowBox[{"eqi", " ", "=", " ", 
  RowBox[{"(", " ", 
   RowBox[{"Thread", " ", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sig", " ", "/.", " ", 
        RowBox[{"r", " ", "\[Rule]", " ", "ri"}]}], ")"}], " ", ".", " ", 
      "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"-", " ", "pi"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[Mu]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"CR", "[", "1", "]"}]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["ri", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "1", "]"}]}], 
         SuperscriptBox["ri", "2"]], "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         RowBox[{"CR", "[", "2", "]"}]}], "-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["ri", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "2", "]"}]}], 
         SuperscriptBox["ri", "2"]]}], ")"}]}], "-", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"CR", "[", "1", "]"}]}], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["ri", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "1", "]"}]}], 
            SuperscriptBox["ri", "2"]], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            RowBox[{"CR", "[", "2", "]"}]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["ri", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "2", "]"}]}], 
            SuperscriptBox["ri", "2"]]}], ")"}]}], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["ri", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "1", "]"}]}], 
           RowBox[{"2", " ", "ri"}]], "+", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["ri", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "2", "]"}]}], 
           RowBox[{"2", " ", "ri"}]]}], "ri"], "+", 
        RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}], "\[Equal]", "pi"}], ",", 
   "True", ",", "True"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", "  ", "er"}], "\[IndentingNewLine]", 
 RowBox[{"eqe", " ", "=", " ", 
  RowBox[{"(", "  ", 
   RowBox[{"Thread", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sig", " ", "/.", " ", 
        RowBox[{"r", " ", "\[Rule]", " ", "re"}]}], ")"}], " ", ".", " ", 
      "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"+", " ", "pe"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"CR", "[", "1", "]"}]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["re", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "1", "]"}]}], 
         SuperscriptBox["re", "2"]], "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         RowBox[{"CR", "[", "2", "]"}]}], "-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["re", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "2", "]"}]}], 
         SuperscriptBox["re", "2"]]}], ")"}]}], "+", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"CR", "[", "1", "]"}]}], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["re", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "1", "]"}]}], 
            SuperscriptBox["re", "2"]], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            RowBox[{"CR", "[", "2", "]"}]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["re", "2"]}], ")"}], " ", 
             RowBox[{"CR", "[", "2", "]"}]}], 
            SuperscriptBox["re", "2"]]}], ")"}]}], "+", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["re", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "1", "]"}]}], 
           RowBox[{"2", " ", "re"}]], "+", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["re", "2"]}], ")"}], " ", 
            RowBox[{"CR", "[", "2", "]"}]}], 
           RowBox[{"2", " ", "re"}]]}], "re"], "+", 
        RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}], "\[Equal]", "pe"}], ",", 
   "True", ",", "True"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"eqi", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
     RowBox[{"eqe", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "  ", "/.", " ", 
   RowBox[{
    RowBox[{"CZ", "[", "2", "]"}], " ", "\[Rule]", " ", "0"}]}], " ", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solve", "[", " ", 
  RowBox[{"%", ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"CR", "[", "1", "]"}], ",", " ", 
     RowBox[{"CR", "[", "2", "]"}]}], "}"}]}], " ", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"CR", "[", "1", "]"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["ri", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"CR", "[", "1", "]"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}]}], 
     SuperscriptBox["ri", "2"]], "\[Equal]", "pi"}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[Mu]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"CR", "[", "1", "]"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["re", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"CR", "[", "1", "]"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}]}], 
     SuperscriptBox["re", "2"]], "\[Equal]", "pe"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"CR", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", 
         SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
        RowBox[{"pi", " ", 
         SuperscriptBox["re", "2"], " ", 
         SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", "\[Mu]"}], "+", 
        RowBox[{"pi", " ", 
         SuperscriptBox["ri", "2"], " ", "\[Mu]"}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", 
         SuperscriptBox["ri", "2"], " ", "\[Mu]"}], "+", 
        RowBox[{"pi", " ", 
         SuperscriptBox["re", "2"], " ", 
         SuperscriptBox["ri", "2"], " ", "\[Mu]"}]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["re", "2"]}], "+", 
          SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]]}]}], ",", 
    RowBox[{
     RowBox[{"CR", "[", "2", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "+", "\[Mu]", "-", 
           FractionBox["\[Mu]", 
            SuperscriptBox["re", "2"]]}], ")"}]}], "-", 
        RowBox[{"pe", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Lambda]"}], "-", "\[Mu]", "+", 
           FractionBox["\[Mu]", 
            SuperscriptBox["ri", "2"]]}], ")"}]}]}], 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Lambda]", " ", "\[Mu]"}],
           
          SuperscriptBox["re", "2"]]}], "+", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Lambda]", " ", "\[Mu]"}], 
         
         SuperscriptBox["ri", "2"]], "-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          SuperscriptBox["\[Mu]", "2"]}], 
         SuperscriptBox["re", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          SuperscriptBox["\[Mu]", "2"]}], 
         SuperscriptBox["ri", "2"]]}]]}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", " ", "/.", " ", "%"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["r", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"pe", " ", 
           SuperscriptBox["re", "2"], " ", 
           SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
          RowBox[{"pi", " ", 
           SuperscriptBox["re", "2"], " ", 
           SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
          RowBox[{"pe", " ", 
           SuperscriptBox["re", "2"], " ", "\[Mu]"}], "+", 
          RowBox[{"pi", " ", 
           SuperscriptBox["ri", "2"], " ", "\[Mu]"}], "+", 
          RowBox[{"pe", " ", 
           SuperscriptBox["re", "2"], " ", 
           SuperscriptBox["ri", "2"], " ", "\[Mu]"}], "+", 
          RowBox[{"pi", " ", 
           SuperscriptBox["re", "2"], " ", 
           SuperscriptBox["ri", "2"], " ", "\[Mu]"}]}], ")"}]}], 
       RowBox[{"4", " ", "r", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["re", "2"]}], "+", 
          SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]]}], "-", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["r", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"pi", " ", 
          RowBox[{"(", 
           RowBox[{"\[Lambda]", "+", "\[Mu]", "-", 
            FractionBox["\[Mu]", 
             SuperscriptBox["re", "2"]]}], ")"}]}], "-", 
         RowBox[{"pe", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Lambda]"}], "-", "\[Mu]", "+", 
            FractionBox["\[Mu]", 
             SuperscriptBox["ri", "2"]]}], ")"}]}]}], ")"}]}], 
      RowBox[{"2", " ", "r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
           "2", " ", "\[ImaginaryI]", " ", "\[Lambda]", " ", "\[Mu]"}], 
           SuperscriptBox["re", "2"]]}], "+", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Lambda]", " ", "\[Mu]"}],
           
          SuperscriptBox["ri", "2"]], "-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["\[Mu]", "2"]}], 
          SuperscriptBox["re", "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["\[Mu]", "2"]}], 
          SuperscriptBox["ri", "2"]]}], ")"}]}]]}], ",", "0", ",", 
    RowBox[{
     RowBox[{"CZ", "[", "1", "]"}], "+", 
     RowBox[{"z", " ", 
      RowBox[{"CZ", "[", "2", "]"}]}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"pi", " ", 
       SuperscriptBox["ri", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["r", "2"], " ", "\[Mu]"}], "+", 
         RowBox[{
          SuperscriptBox["re", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"pe", " ", 
       SuperscriptBox["re", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["r", "2"], " ", "\[Mu]"}], "+", 
         RowBox[{
          SuperscriptBox["ri", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]}], ")"}]}]}], 
     RowBox[{"2", " ", "r", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["re", "2"], "-", 
        SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]], ",", "0", ",", 
    RowBox[{
     RowBox[{"CZ", "[", "1", "]"}], "+", 
     RowBox[{"z", " ", 
      RowBox[{"CZ", "[", "2", "]"}]}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"eqv", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", 
      RowBox[{"eqi", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
      RowBox[{"eqe", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "}"}], " ", "]"}], 
   "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"pz", "\[Equal]", 
    RowBox[{
     RowBox[{"2", " ", "\[Mu]", " ", 
      RowBox[{"CZ", "[", "2", "]"}]}], "+", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CR", "[", "1", "]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"CR", "[", "2", "]"}]}], "+", 
        RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"CR", "[", "1", "]"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["ri", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"CR", "[", "1", "]"}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"CR", "[", "1", "]"}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"CR", "[", "2", "]"}]}], "+", 
            RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}], ")"}]}]}], 
     SuperscriptBox["ri", "2"]], "\[Equal]", "pi"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["re", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "1", "]"}]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["re", "2"]}], ")"}], " ", 
          RowBox[{"CR", "[", "2", "]"}]}]}], ")"}]}], 
      SuperscriptBox["re", "2"]], "+", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CR", "[", "1", "]"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"CR", "[", "2", "]"}]}], "+", 
        RowBox[{"CZ", "[", "2", "]"}]}], ")"}]}]}], "\[Equal]", "pe"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"Solve", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"eqv", "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", 
        RowBox[{"eqi", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
        RowBox[{"eqe", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "}"}], " ", ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"CR", "[", "1", "]"}], ",", " ", 
        RowBox[{"CR", "[", "2", "]"}], ",", " ", 
        RowBox[{"CZ", "[", "2", "]"}]}], "}"}]}], " ", "]"}], " ", "]"}], "[",
    
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"CR", "[", "1", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"pz", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["re", "2"]}], "+", 
         SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Lambda]"}], "+", 
      RowBox[{"pi", " ", 
       SuperscriptBox["ri", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["re", "2"], " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["re", "2"]}], ")"}], " ", "\[Mu]"}]}], ")"}]}], 
      "+", 
      RowBox[{"pe", " ", 
       SuperscriptBox["re", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]"}]}], ")"}]}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["re", "2"], "-", 
        SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"CR", "[", "2", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"pz", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["re", "2"], "-", 
           SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Lambda]"}], "+", 
        RowBox[{"pi", " ", 
         SuperscriptBox["ri", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["re", "2"]}]}], ")"}], " ", "\[Lambda]"}], "+", 
           
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["re", "2"]}], ")"}], " ", "\[Mu]"}]}], ")"}]}], 
        "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["ri", "2"]}]}], ")"}], " ", "\[Lambda]"}], "+", 
           
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]"}]}], ")"}]}]}],
        ")"}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["re", "2"], "-", 
        SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{"CZ", "[", "2", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "pe"}], " ", 
       SuperscriptBox["re", "2"], " ", "\[Lambda]"}], "-", 
      RowBox[{"pi", " ", 
       SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
      RowBox[{"pz", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["re", "2"], "-", 
         SuperscriptBox["ri", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["re", "2"], "-", 
        SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", " ", 
  RowBox[{"uu", " ", "/.", " ", "sol"}], " ", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"eps", " ", "/.", " ", "sol"}], " ", "]"}], " ", "//", " ", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"sig", " ", "/.", " ", "sol"}], " ", "]"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"pz", " ", 
      SuperscriptBox["r", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["re", "2"]}], "+", 
        SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Lambda]"}], "+", 
     RowBox[{"pi", " ", 
      SuperscriptBox["ri", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["re", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"pe", " ", 
      SuperscriptBox["re", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["ri", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}]}], 
    RowBox[{"2", " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["re", "2"], "-", 
       SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "\[Lambda]"}], "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], ",", "0", ",", 
   RowBox[{
    FractionBox[
     RowBox[{"z", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "pe"}], " ", 
         SuperscriptBox["re", "2"], " ", "\[Lambda]"}], "-", 
        RowBox[{"pi", " ", 
         SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
        RowBox[{"pz", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["re", "2"], "-", 
           SuperscriptBox["ri", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["re", "2"], "-", 
        SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
    RowBox[{"CZ", "[", "1", "]"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"pz", " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["re", "2"]}], "+", 
           SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Lambda]"}], "+", 
        RowBox[{"pi", " ", 
         SuperscriptBox["ri", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Lambda]", "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
           RowBox[{
            SuperscriptBox["re", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Lambda]", "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
           RowBox[{
            SuperscriptBox["ri", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{"pz", " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["re", "2"]}], "+", 
           SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Lambda]"}], "+", 
        RowBox[{"pi", " ", 
         SuperscriptBox["ri", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Lambda]", "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["re", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Lambda]", "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["ri", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Lambda]"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "pe"}], " ", 
         SuperscriptBox["re", "2"], " ", "\[Lambda]"}], "-", 
        RowBox[{"pi", " ", 
         SuperscriptBox["ri", "2"], " ", "\[Lambda]"}], "+", 
        RowBox[{"pz", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["re", "2"], "-", 
           SuperscriptBox["ri", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "2"], "-", 
           SuperscriptBox["re", "2"]}], ")"}], " ", 
         SuperscriptBox["ri", "2"]}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "2"], "-", 
           SuperscriptBox["ri", "2"]}], ")"}]}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}]}]], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           SuperscriptBox["re", "2"]}], ")"}], " ", 
         SuperscriptBox["ri", "2"]}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           SuperscriptBox["ri", "2"]}], ")"}]}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}]}]], "0"},
     {"0", "0", "pz"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"tubeinner", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"pz", " ", "\[Rule]", " ", "0"}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"tubeouter", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"pz", " ", "\[Rule]", " ", "0"}], ",", " ", 
    RowBox[{"ri", " ", "\[Rule]", " ", "RI"}], ",", " ", 
    RowBox[{"re", " ", "\[Rule]", " ", "RE"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"autofinner", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"pi", " ", "\[Rule]", " ", "0"}], ",", " ", 
    RowBox[{"pe", " ", "\[Rule]", " ", "p0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"autofouter", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"pi", " ", "\[Rule]", " ", "p0"}], ",", " ", 
    RowBox[{"pe", " ", "\[Rule]", " ", "0"}]}], "}"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"pz", "\[Rule]", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"pz", "\[Rule]", "0"}], ",", 
   RowBox[{"ri", "\[Rule]", "RI"}], ",", 
   RowBox[{"re", "\[Rule]", "RE"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"pi", "\[Rule]", "0"}], ",", 
   RowBox[{"pe", "\[Rule]", "p0"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"pi", "\[Rule]", "p0"}], ",", 
   RowBox[{"pe", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{"uinner", " ", "=", " ", 
    RowBox[{"Simplify", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"uu", "  ", "/.", " ", "sol"}], "  ", "/.", " ", "tubeinner"}],
       " ", "/.", " ", "autofinner"}], " ", "]"}]}], " ", ")"}], "//", " ", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"epsinner", " ", "=", " ", 
    RowBox[{"Simplify", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"eps", " ", "/.", " ", "sol"}], "  ", "/.", " ", "tubeinner"}],
       " ", "/.", " ", "autofinner"}], " ", "]"}]}], " ", ")"}], "//", " ", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"siginner", " ", "=", " ", 
    RowBox[{"Simplify", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"sig", " ", "/.", " ", "sol"}], "  ", "/.", " ", "tubeinner"}],
       " ", "/.", " ", "autofinner"}], " ", "]"}]}], " ", ")"}], "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"p0", " ", 
        SuperscriptBox["re", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["ri", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"2", " ", "r", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]},
     {"0"},
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"p0", " ", 
          SuperscriptBox["re", "2"], " ", "z", " ", "\[Lambda]"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["re", "2"], "-", 
            SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "\[Lambda]"}], "+", 
            RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], "+", 
       RowBox[{"CZ", "[", "1", "]"}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   Rational[1, 2] p0 r^(-1) 
    re^2 (re^2 - ri^2)^(-1) \[Mu]^(-1) (3 \[Lambda] + 2 \[Mu])^(-1) (
     r^2 (\[Lambda] + 2 \[Mu]) + ri^2 (3 \[Lambda] + 2 \[Mu])), 
    0, -p0 re^2 (re^2 - ri^2)^(-1) z \[Lambda] \[Mu]^(-1)/(3 \[Lambda] + 
     2 \[Mu]) + CZ[1]}]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"p0", " ", 
        SuperscriptBox["re", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["ri", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"p0", " ", 
        SuperscriptBox["re", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["ri", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "0"},
     {"0", "0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"p0", " ", 
         SuperscriptBox["re", "2"], " ", "\[Lambda]"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["re", "2"], "-", 
           SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"p0", " ", 
        SuperscriptBox["re", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}]}]], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"p0", " ", 
        SuperscriptBox["re", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["ri", "2"]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "2"], "-", 
          SuperscriptBox["ri", "2"]}], ")"}]}]], "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{"uouter", " ", "=", " ", 
    RowBox[{"Simplify", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"uu", "  ", "/.", " ", "sol"}], "  ", "/.", " ", "tubeouter"}],
       " ", "/.", " ", "autofouter"}], " ", "]"}]}], ")"}], " ", "//", " ", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"epsouter", " ", "=", " ", 
    RowBox[{"Simplify", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"eps", " ", "/.", " ", "sol"}], "  ", "/.", " ", "tubeouter"}],
       " ", "/.", " ", "autofouter"}], " ", "]"}]}], ")"}], " ", "//", " ", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"sigouter", " ", "=", " ", 
    RowBox[{"Simplify", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"sig", " ", "/.", " ", "sol"}], "  ", "/.", " ", "tubeouter"}],
       " ", "/.", " ", "autofouter"}], " ", "]"}]}], ")"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"p0", " ", 
        SuperscriptBox["RI", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["RE", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"2", " ", "r", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["RE", "2"], "-", 
          SuperscriptBox["RI", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]},
     {"0"},
     {
      RowBox[{
       FractionBox[
        RowBox[{"p0", " ", 
         SuperscriptBox["RI", "2"], " ", "z", " ", "\[Lambda]"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["RE", "2"]}], "+", 
           SuperscriptBox["RI", "2"]}], ")"}], " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
       RowBox[{"CZ", "[", "1", "]"}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   Rational[1, 2] p0 r^(-1) 
    RI^2 (RE^2 - RI^2)^(-1) \[Mu]^(-1) (3 \[Lambda] + 2 \[Mu])^(-1) (
     r^2 (\[Lambda] + 2 \[Mu]) + RE^2 (3 \[Lambda] + 2 \[Mu])), 0, 
    p0 RI^2 (-RE^2 + RI^2)^(-1) z \[Lambda] \[Mu]^(-1)/(3 \[Lambda] + 
     2 \[Mu]) + CZ[1]}]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"p0", " ", 
        SuperscriptBox["RI", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["RE", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["RE", "2"], "-", 
          SuperscriptBox["RI", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"p0", " ", 
        SuperscriptBox["RI", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Lambda]", "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["RE", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Lambda]"}], "+", 
             RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["RE", "2"], "-", 
          SuperscriptBox["RI", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{"p0", " ", 
        SuperscriptBox["RI", "2"], " ", "\[Lambda]"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["RE", "2"]}], "+", 
          SuperscriptBox["RI", "2"]}], ")"}], " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"p0", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "-", 
          SuperscriptBox["RE", "2"]}], ")"}], " ", 
        SuperscriptBox["RI", "2"]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["RE", "2"], "-", 
          SuperscriptBox["RI", "2"]}], ")"}]}]], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"p0", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["RE", "2"]}], ")"}], " ", 
        SuperscriptBox["RI", "2"]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["RE", "2"], "-", 
          SuperscriptBox["RI", "2"]}], ")"}]}]], "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{"uouter", "\[IndentingNewLine]", " ", "uinner"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"p0", " ", 
     SuperscriptBox["RI", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["RE", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], 
    RowBox[{"2", " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["RE", "2"], "-", 
       SuperscriptBox["RI", "2"]}], ")"}], " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "\[Lambda]"}], "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], ",", "0", ",", 
   RowBox[{
    FractionBox[
     RowBox[{"p0", " ", 
      SuperscriptBox["RI", "2"], " ", "z", " ", "\[Lambda]"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["RE", "2"]}], "+", 
        SuperscriptBox["RI", "2"]}], ")"}], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
    RowBox[{"CZ", "[", "1", "]"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"p0", " ", 
     SuperscriptBox["re", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["ri", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], 
    RowBox[{"2", " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["re", "2"], "-", 
       SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "\[Lambda]"}], "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], ",", "0", ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"p0", " ", 
       SuperscriptBox["re", "2"], " ", "z", " ", "\[Lambda]"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["re", "2"], "-", 
         SuperscriptBox["ri", "2"]}], ")"}], " ", "\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], "+", 
    RowBox[{"CZ", "[", "1", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"p0sol", " ", "=", " ", 
   RowBox[{"Simplify", "[", " ", 
    RowBox[{
     RowBox[{"Solve", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"RI", " ", "+", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"uouter", "[", 
               RowBox[{"[", "1", "]"}], "]"}], " ", "RI"}], " ", "+", " ", 
             RowBox[{"uouter", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "\[Equal]", " ", 
            RowBox[{"re", " ", "+", 
             RowBox[{"ruinner", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}]}], " ", "/.", " ", 
           RowBox[{"r", " ", "\[Rule]", " ", "RE"}]}], ")"}]}], " ", 
        "\[Equal]", " ", 
        RowBox[{"re", " ", "+", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"uinner", "[", 
            RowBox[{"[", "1", "]"}], "]"}], " ", "/.", " ", 
           RowBox[{"r", " ", "\[Rule]", " ", "re"}]}], ")"}]}]}], ",", " ", 
       "p0"}], " ", "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"p0", "\[Rule]", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["re", "2"], "-", 
      SuperscriptBox["ri", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"re", "-", "RI"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["RE", "2"]}], "+", 
      SuperscriptBox["RI", "2"]}], ")"}], " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", "\[Lambda]"}], "+", 
      RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], 
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", 
     SuperscriptBox["re", "2"], " ", "RE", " ", 
     SuperscriptBox["RI", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}], "+", 
    RowBox[{"4", " ", "RE", " ", 
     SuperscriptBox["ri", "2"], " ", 
     SuperscriptBox["RI", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["re", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["RE", "2"], "-", 
       SuperscriptBox["RI", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Lambda]", "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
    RowBox[{"re", " ", 
     SuperscriptBox["ri", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["RE", "2"], "-", 
       SuperscriptBox["RI", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "\[Lambda]"}], "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}]]}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1170, 769},
WindowMargins->{{Automatic, 29}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 60, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[1416, 43, 291, 8, 55, "Input"],
Cell[1710, 53, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1797, 56, 150, 2, 77, "Input"],
Cell[CellGroupData[{
Cell[1972, 62, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2084, 67, 139, 3, 32, "Input"],
Cell[2226, 72, 98, 2, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2373, 80, 121, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2519, 86, 844, 23, 77, "Input"],
Cell[3366, 111, 482, 16, 72, "Output"],
Cell[3851, 129, 1912, 56, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5800, 190, 221, 6, 32, "Input"],
Cell[6024, 198, 1260, 38, 74, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7321, 241, 869, 24, 55, "Input"],
Cell[8193, 267, 613, 20, 46, "Output"],
Cell[8809, 289, 389, 8, 20, "Message"],
Cell[9201, 299, 257, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9495, 312, 478, 14, 27, "Input"],
Cell[9976, 328, 497, 19, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10510, 352, 71, 1, 27, "Input"],
Cell[10584, 355, 94, 3, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10715, 363, 446, 13, 43, "Input"],
Cell[11164, 378, 385, 8, 20, "Message"],
Cell[11552, 388, 602, 20, 44, "Output"],
Cell[12157, 410, 369, 12, 43, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12575, 428, 153, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[12753, 434, 207, 6, 27, "Input"],
Cell[12963, 442, 651, 22, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13651, 469, 527, 14, 43, "Input"],
Cell[14181, 485, 1592, 49, 108, "Output"],
Cell[15776, 536, 6765, 186, 178, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22590, 728, 105, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[22720, 733, 302, 9, 27, "Input"],
Cell[23025, 744, 86, 2, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[23160, 752, 101, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[23286, 757, 500, 14, 59, "Input"],
Cell[23789, 773, 83, 2, 27, "Output"],
Cell[23875, 777, 391, 8, 20, "Message"],
Cell[24269, 787, 83, 2, 27, "Output"],
Cell[24355, 791, 1776, 51, 67, "Output"]
}, Open  ]],
Cell[26146, 845, 26, 0, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26209, 850, 114, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[26348, 855, 117, 3, 27, "Input"],
Cell[26468, 860, 83, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26588, 867, 495, 14, 43, "Input"],
Cell[27086, 883, 102, 3, 27, "Output"],
Cell[27191, 888, 2490, 72, 115, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29718, 965, 469, 13, 43, "Input"],
Cell[30190, 980, 83, 2, 27, "Output"],
Cell[30276, 984, 2468, 71, 115, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32781, 1060, 571, 17, 43, "Input"],
Cell[33355, 1079, 1336, 41, 47, "Output"],
Cell[34694, 1122, 2365, 66, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37096, 1193, 61, 1, 27, "Input"],
Cell[37160, 1196, 2845, 79, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40042, 1280, 61, 1, 27, "Input"],
Cell[40106, 1283, 1174, 36, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41317, 1324, 400, 12, 59, "Input"],
Cell[41720, 1338, 2207, 66, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43964, 1409, 691, 20, 27, "Input"],
Cell[44658, 1431, 3975, 121, 91, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48670, 1557, 424, 10, 59, "Input"],
Cell[49097, 1569, 2504, 77, 49, "Output"],
Cell[51604, 1648, 4443, 129, 118, "Output"],
Cell[56050, 1779, 1492, 48, 104, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57579, 1832, 816, 21, 75, "Input"],
Cell[58398, 1855, 80, 2, 27, "Output"],
Cell[58481, 1859, 178, 5, 27, "Output"],
Cell[58662, 1866, 136, 4, 27, "Output"],
Cell[58801, 1872, 136, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58974, 1881, 980, 27, 59, "Input"],
Cell[59957, 1910, 1806, 52, 102, "Output"],
Cell[61766, 1964, 2434, 73, 116, "Output"],
Cell[64203, 2039, 1023, 34, 104, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65263, 2078, 980, 27, 59, "Input"],
Cell[66246, 2107, 1799, 52, 102, "Output"],
Cell[68048, 2161, 2427, 73, 116, "Output"],
Cell[70478, 2236, 1023, 34, 104, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71538, 2275, 101, 2, 43, "Input"],
Cell[71642, 2279, 1336, 42, 48, "Output"],
Cell[72981, 2323, 1343, 42, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74361, 2370, 1161, 31, 43, "Input"],
Cell[75525, 2403, 1553, 49, 49, "Output"]
}, Open  ]],
Cell[77093, 2455, 26, 0, 27, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

