(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     47957,       1607]
NotebookOptionsPosition[     44063,       1470]
NotebookOutlinePosition[     44507,       1488]
CellTagsIndexPosition[     44464,       1485]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["\<\
Underground reservoir under pressure and temperature loadings \
\>", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "Displacement.m"}], "\[IndentingNewLine]"}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Spherical", "[", 
  RowBox[{"r", ",", "t", ",", "p"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "t", ",", "p"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The general solution of the heat equation in \
spherical coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Div", "[", " ", 
   RowBox[{"k", " ", 
    RowBox[{"Grad", " ", "[", " ", 
     RowBox[{"\[Theta]", "[", "r", "]"}], " ", "]"}]}], " ", "]"}], " ", 
  "\[Equal]", " ", "0"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "k", " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
   RowBox[{"k", " ", 
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}]}], "\[Equal]", 
  "0"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"heatsol", " ", "=", 
  RowBox[{
   RowBox[{"DSolve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Div", "[", " ", 
       RowBox[{"k", " ", 
        RowBox[{"Grad", " ", "[", " ", 
         RowBox[{"\[Theta]", "[", "r", "]"}], " ", "]"}]}], " ", "]"}], " ", 
      "\[Equal]", " ", "0"}], ",", " ", "\[Theta]", " ", ",", " ", "r"}], " ",
     "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"\[Theta]", "\[Rule]", 
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", "r", "}"}], ",", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"C", "[", "1", "]"}], "r"]}], "+", 
     RowBox[{"C", "[", "2", "]"}]}]}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"heatbc", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Limit", "[", " ", 
         RowBox[{
          RowBox[{"heatsol", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "2"}], "]"}], "]"}], ",", " ", 
          RowBox[{"r", " ", "\[Rule]", " ", "Infinity"}]}], " ", "]"}], " ", 
        "\[Equal]", "Tinfinity"}], ",", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"heatsol", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "2"}], "]"}], "]"}], " ", "/.", " ", 
          RowBox[{"r", " ", "\[Rule]", " ", "R"}]}], ")"}], " ", "\[Equal]", 
        " ", 
        RowBox[{"DT", " ", "+", " ", "Tinfinity"}]}]}], "}"}], " ", ",", " ", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"C", "[", "1", "]"}], ",", 
       RowBox[{"C", "[", "2", "]"}]}], "}"}]}], " ", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "  "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "DT"}], " ", "R"}]}], ",", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], "\[Rule]", "Tinfinity"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Theta]", "[", "r", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Theta]", "[", "r", "]"}], " ", "/.", " ", "heatsol"}], " ", "/.",
     " ", "heatbc"}], " ", "/.", " ", 
   RowBox[{"Tinfinity", " ", "\[Rule]", " ", "0"}]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"DT", " ", "R"}], "r"]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"r", "^", "2"}], " ", 
    RowBox[{"\[Theta]", "[", "r", "]"}]}], " ", ",", " ", 
   RowBox[{"{", 
    RowBox[{"r", ",", " ", "R", ",", " ", "RR"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "DT", " ", "R", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["R", "2"]}], "+", 
    SuperscriptBox["RR", "2"]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The general solution elastic solution in the \
spherical coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"u", "[", 
   RowBox[{"r_", ",", "t_", ",", "p_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ur", "[", "r", "]"}], ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"Strain", "[", " ", 
     RowBox[{"u", " ", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}]}], " ", ")"}], " ", "//",
   "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{
     RowBox[{"p0", " ", 
      RowBox[{"IdentityMatrix", "[", "3", "]"}]}], " ", "+", " ", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"Tr", "[", "eps", " ", "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", " ", "]"}]}], "+", " ", 
     RowBox[{"2", " ", "\[Mu]", " ", "eps"}], " ", "-", " ", 
     RowBox[{"k", " ", 
      RowBox[{"\[Theta]", "[", "r", "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", "]"}]}]}]}], " ", ")"}], " ", "//", 
  " ", "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["ur", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"ur", "[", "r", "]"}], "r"], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{"ur", "[", "r", "]"}], "r"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"p0", "-", 
       FractionBox[
        RowBox[{"DT", " ", "k", " ", "R"}], "r"], "+", 
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{
         SuperscriptBox["ur", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
          RowBox[{
           SuperscriptBox["ur", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}], "0", 
      "0"},
     {"0", 
      RowBox[{"p0", "-", 
       FractionBox[
        RowBox[{"DT", " ", "k", " ", "R"}], "r"], "+", 
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
          RowBox[{
           SuperscriptBox["ur", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}], "0"},
     {"0", "0", 
      RowBox[{"p0", "-", 
       FractionBox[
        RowBox[{"DT", " ", "k", " ", "R"}], "r"], "+", 
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"ur", "[", "r", "]"}]}], "r"], "+", 
          RowBox[{
           SuperscriptBox["ur", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"divsig", " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Div", "[", " ", "sig", " ", "]"}], "]"}]}], " ", ")"}], " ", "//",
   " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"DT", " ", "k", " ", "R"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
         RowBox[{"ur", "[", "r", "]"}]}], "+", 
        RowBox[{"2", " ", "r", " ", 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["ur", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", "\[Lambda]", " ", 
         RowBox[{
          SuperscriptBox["ur", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["r", "2"], " ", "\[Mu]", " ", 
         RowBox[{
          SuperscriptBox["ur", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       SuperscriptBox["r", "2"]]},
     {"0"},
     {"0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   r^(-2) (DT k R - 2 (\[Lambda] + 2 \[Mu]) ur[r] + 
     2 r (\[Lambda] + 2 \[Mu]) Derivative[1][ur][r] + 
     r^2 \[Lambda] Derivative[2][ur][r] + 2 r^2 \[Mu] Derivative[2][ur][r]), 
    0, 0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solur", " ", "=", " ", 
   RowBox[{
    RowBox[{"DSolve", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"divsig", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", "\[Equal]", " ", "0"}], ",", " ",
       "ur", ",", " ", "r"}], " ", "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"ur", "\[Rule]", 
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", "r", "}"}], ",", 
    RowBox[{
     FractionBox[
      RowBox[{"DT", " ", "k", " ", "R"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
     RowBox[{"r", " ", 
      RowBox[{"C", "[", "1", "]"}]}], "+", 
     FractionBox[
      RowBox[{"C", "[", "2", "]"}], 
      SuperscriptBox["r", "2"]]}]}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", " ", 
  RowBox[{
   RowBox[{"solur", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "2"}], "]"}], "]"}], " ", ",", " ", 
   RowBox[{"r", " ", "\[Rule]", " ", "Infinity"}]}], "]"}]], "Input"],

Cell[BoxData["$Aborted"], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "\[Lambda]", " ", 
     RowBox[{"ur", "[", "r", "]"}]}], 
    SuperscriptBox["r", "2"]]}], "-", 
  FractionBox[
   RowBox[{"4", " ", "\[Mu]", " ", 
    RowBox[{"ur", "[", "r", "]"}]}], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   RowBox[{"2", " ", "\[Lambda]", " ", 
    RowBox[{
     SuperscriptBox["ur", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
  FractionBox[
   RowBox[{"4", " ", "\[Mu]", " ", 
    RowBox[{
     SuperscriptBox["ur", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], "r"], "-", 
  RowBox[{"k", " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}], "+", 
  RowBox[{"\[Lambda]", " ", 
   RowBox[{
    SuperscriptBox["ur", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}], "+", 
  RowBox[{"2", " ", "\[Mu]", " ", 
   RowBox[{
    SuperscriptBox["ur", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "\[Lambda]", " ", 
     RowBox[{"ur", "[", "r", "]"}]}], 
    SuperscriptBox["r", "2"]]}], "-", 
  FractionBox[
   RowBox[{"4", " ", "\[Mu]", " ", 
    RowBox[{"ur", "[", "r", "]"}]}], 
   SuperscriptBox["r", "2"]], "+", 
  FractionBox[
   RowBox[{"2", " ", "\[Lambda]", " ", 
    RowBox[{
     SuperscriptBox["ur", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
  FractionBox[
   RowBox[{"4", " ", "\[Mu]", " ", 
    RowBox[{
     SuperscriptBox["ur", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
  RowBox[{"\[Lambda]", " ", 
   RowBox[{
    SuperscriptBox["ur", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}], "+", 
  RowBox[{"2", " ", "\[Mu]", " ", 
   RowBox[{
    SuperscriptBox["ur", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}]}]], "Output"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"ur", "[", "r", "]"}]}], "+", 
     RowBox[{"r", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["ur", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["ur", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], ")"}]}], 
  
  SuperscriptBox["r", "2"]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"exp", " ", "-", 
     RowBox[{"k", " ", 
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}], "]"}], " ", "===", " ",
    
   RowBox[{"Simplify", "[", 
    RowBox[{"divsig", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "^", "2"}], " ", 
     RowBox[{"ur", "[", "r", "]"}]}], ",", " ", "r"}], " ", "]"}], " ", "=", 
  " ", 
  RowBox[{
   RowBox[{"k", "/", 
    RowBox[{"(", 
     RowBox[{"\[Lambda]", "+", 
      RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], " ", 
   RowBox[{"\[Theta]", "[", "rr", "]"}], " ", 
   RowBox[{
    RowBox[{"r", "^", "2"}], "  "}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The spherical thick shell under internal and external \
pressure: pi and pe",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", " ", "=", " ", 
  RowBox[{
   RowBox[{"u", " ", "[", 
    RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", "/.", " ", "solur", 
   " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"DT", " ", "k", " ", "R"}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"\[Lambda]", "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
    RowBox[{"r", " ", 
     RowBox[{"C", "[", "1", "]"}]}], "+", 
    FractionBox[
     RowBox[{"C", "[", "2", "]"}], 
     SuperscriptBox["r", "2"]]}], ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"Strain", "[", " ", "uu", " ", "]"}]}], " ", ")"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"Tr", "[", "eps", " ", "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", " ", "]"}]}], "+", " ", 
     RowBox[{"2", " ", "\[Mu]", " ", "eps"}]}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"C", "[", "1", "]"}]}], "-", 
         FractionBox[
          RowBox[{"4", " ", 
           RowBox[{"C", "[", "2", "]"}]}], 
          SuperscriptBox["r", "3"]]}], ")"}]}], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"DT", " ", "k", " ", "R"}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"\[Lambda]", "+", 
            RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
        RowBox[{"r", " ", 
         RowBox[{"C", "[", "1", "]"}]}], "+", 
        FractionBox[
         RowBox[{"C", "[", "2", "]"}], 
         SuperscriptBox["r", "2"]]}], "r"], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"DT", " ", "k", " ", "R"}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"\[Lambda]", "+", 
            RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
        RowBox[{"r", " ", 
         RowBox[{"C", "[", "1", "]"}]}], "+", 
        FractionBox[
         RowBox[{"C", "[", "2", "]"}], 
         SuperscriptBox["r", "2"]]}], "r"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          FractionBox[
           RowBox[{"4", " ", 
            RowBox[{"C", "[", "2", "]"}]}], 
           SuperscriptBox["r", "3"]]}], ")"}]}], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"C", "[", "1", "]"}]}], "-", 
             FractionBox[
              RowBox[{"4", " ", 
               RowBox[{"C", "[", "2", "]"}]}], 
              SuperscriptBox["r", "3"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{"DT", " ", "k", " ", "R"}], 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"\[Lambda]", "+", 
                  RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
              RowBox[{"r", " ", 
               RowBox[{"C", "[", "1", "]"}]}], "+", 
              FractionBox[
               RowBox[{"C", "[", "2", "]"}], 
               SuperscriptBox["r", "2"]]}], ")"}]}], "r"]}], ")"}]}]}], "0", 
      "0"},
     {"0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"DT", " ", "k", " ", "R"}], 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"\[Lambda]", "+", 
               RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
           RowBox[{"r", " ", 
            RowBox[{"C", "[", "1", "]"}]}], "+", 
           FractionBox[
            RowBox[{"C", "[", "2", "]"}], 
            SuperscriptBox["r", "2"]]}], ")"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"C", "[", "1", "]"}]}], "-", 
             FractionBox[
              RowBox[{"4", " ", 
               RowBox[{"C", "[", "2", "]"}]}], 
              SuperscriptBox["r", "3"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{"DT", " ", "k", " ", "R"}], 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"\[Lambda]", "+", 
                  RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
              RowBox[{"r", " ", 
               RowBox[{"C", "[", "1", "]"}]}], "+", 
              FractionBox[
               RowBox[{"C", "[", "2", "]"}], 
               SuperscriptBox["r", "2"]]}], ")"}]}], "r"]}], ")"}]}]}], "0"},
     {"0", "0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"DT", " ", "k", " ", "R"}], 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"\[Lambda]", "+", 
               RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
           RowBox[{"r", " ", 
            RowBox[{"C", "[", "1", "]"}]}], "+", 
           FractionBox[
            RowBox[{"C", "[", "2", "]"}], 
            SuperscriptBox["r", "2"]]}], ")"}]}], "r"], "+", 
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"C", "[", "1", "]"}]}], "-", 
             FractionBox[
              RowBox[{"4", " ", 
               RowBox[{"C", "[", "2", "]"}]}], 
              SuperscriptBox["r", "3"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{"DT", " ", "k", " ", "R"}], 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"\[Lambda]", "+", 
                  RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
              RowBox[{"r", " ", 
               RowBox[{"C", "[", "1", "]"}]}], "+", 
              FractionBox[
               RowBox[{"C", "[", "2", "]"}], 
               SuperscriptBox["r", "2"]]}], ")"}]}], "r"]}], ")"}]}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["condition for the internal and external pressure",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"er", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"1", ",", "0", ",", "0"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", " ", 
  RowBox[{"-", " ", "er"}]}], "\[IndentingNewLine]", 
 RowBox[{"eqi", " ", "=", " ", 
  RowBox[{"(", " ", 
   RowBox[{"Thread", " ", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sig", " ", "/.", " ", 
        RowBox[{"r", " ", "\[Rule]", " ", "R"}]}], ")"}], " ", ".", " ", 
      "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"-", " ", "pi"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(normal\\)\\\" is similar to existing symbol \
\\\"\\!\\(Normal\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[Mu]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"C", "[", "1", "]"}]}], "-", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"C", "[", "2", "]"}]}], 
         SuperscriptBox["R", "3"]]}], ")"}]}], "-", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"C", "[", "1", "]"}]}], "-", 
           FractionBox[
            RowBox[{"4", " ", 
             RowBox[{"C", "[", "2", "]"}]}], 
            SuperscriptBox["R", "3"]]}], ")"}]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"DT", " ", "k", " ", "R"}], 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{"\[Lambda]", "+", 
                RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], "+", 
            RowBox[{"R", " ", 
             RowBox[{"C", "[", "1", "]"}]}], "+", 
            FractionBox[
             RowBox[{"C", "[", "2", "]"}], 
             SuperscriptBox["R", "2"]]}], ")"}]}], "R"]}], ")"}]}]}], 
    "\[Equal]", "pi"}], ",", "True", ",", "True"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", "  ", "er"}], "\[IndentingNewLine]", 
 RowBox[{"eqe", " ", "=", " ", 
  RowBox[{"(", "  ", 
   RowBox[{"Thread", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sig", " ", "/.", " ", 
        RowBox[{"r", " ", "\[Rule]", " ", "re"}]}], ")"}], " ", ".", " ", 
      "normal"}], " ", "==", " ", 
     RowBox[{
      RowBox[{"+", " ", "pe"}], " ", "normal"}]}], " ", "]"}], " ", 
   ")"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"CR", "[", "1", "]"}]}], "-", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"CR", "[", "2", "]"}]}], 
         SuperscriptBox["re", "3"]]}], ")"}]}], "+", 
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"CR", "[", "1", "]"}]}], "-", 
           FractionBox[
            RowBox[{"4", " ", 
             RowBox[{"CR", "[", "2", "]"}]}], 
            SuperscriptBox["re", "3"]]}], ")"}]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"re", " ", 
             RowBox[{"CR", "[", "1", "]"}]}], "+", 
            FractionBox[
             RowBox[{"CR", "[", "2", "]"}], 
             SuperscriptBox["re", "2"]]}], ")"}]}], "re"]}], ")"}]}]}], 
    "\[Equal]", "pe"}], ",", "True", ",", "True"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"eqi", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
       RowBox[{"eqe", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}], " ", ",", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CR", "[", "1", "]"}], ",", " ", 
       RowBox[{"CR", "[", "2", "]"}]}], "}"}]}], " ", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"CR", "[", "1", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "pe"}], " ", 
        SuperscriptBox["re", "3"]}], "-", 
       RowBox[{"pi", " ", 
        SuperscriptBox["ri", "3"]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["re", "3"], "-", 
         SuperscriptBox["ri", "3"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}]}], ",", 
   RowBox[{
    RowBox[{"CR", "[", "2", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"pe", "+", "pi"}], ")"}], " ", 
      SuperscriptBox["re", "3"], " ", 
      SuperscriptBox["ri", "3"]}], 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["re", "3"], "-", 
        SuperscriptBox["ri", "3"]}], ")"}], " ", "\[Mu]"}]]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"uf", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"uu", " ", "/.", " ", "sol"}], " ", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"epsf", " ", "=", " ", 
  RowBox[{
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"eps", " ", "/.", " ", "sol"}], " ", "]"}], " ", "//", " ", 
   "MatrixForm"}]}], "\[IndentingNewLine]", 
 RowBox[{"sigf", " ", "=", " ", 
  RowBox[{
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"sig", " ", "/.", " ", "sol"}], " ", "]"}], " ", "//", " ", 
   "MatrixForm"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"pe", "+", "pi"}], ")"}], " ", 
       SuperscriptBox["re", "3"], " ", 
       SuperscriptBox["ri", "3"]}], "\[Mu]"], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["r", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"pe", " ", 
          SuperscriptBox["re", "3"]}], "+", 
         RowBox[{"pi", " ", 
          SuperscriptBox["ri", "3"]}]}], ")"}]}], 
      RowBox[{
       RowBox[{"3", " ", "\[Lambda]"}], "+", 
       RowBox[{"2", " ", "\[Mu]"}]}]]}], 
    RowBox[{"4", " ", 
     SuperscriptBox["r", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["re", "3"], "-", 
       SuperscriptBox["ri", "3"]}], ")"}]}]], ",", "0", ",", "0"}], 
  "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"pe", "+", "pi"}], ")"}], " ", 
           SuperscriptBox["re", "3"], " ", 
           SuperscriptBox["ri", "3"]}], 
          RowBox[{
           SuperscriptBox["r", "3"], " ", "\[Mu]"}]]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"pe", " ", 
             SuperscriptBox["re", "3"]}], "+", 
            RowBox[{"pi", " ", 
             SuperscriptBox["ri", "3"]}]}], ")"}]}], 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}]]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "3"], "-", 
          SuperscriptBox["ri", "3"]}], ")"}]}]], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"pe", "+", "pi"}], ")"}], " ", 
          SuperscriptBox["re", "3"], " ", 
          SuperscriptBox["ri", "3"]}], "\[Mu]"], "+", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["r", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"pe", " ", 
             SuperscriptBox["re", "3"]}], "+", 
            RowBox[{"pi", " ", 
             SuperscriptBox["ri", "3"]}]}], ")"}]}], 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}]]}], 
       RowBox[{"4", " ", 
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "3"], "-", 
          SuperscriptBox["ri", "3"]}], ")"}]}]], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"pe", "+", "pi"}], ")"}], " ", 
          SuperscriptBox["re", "3"], " ", 
          SuperscriptBox["ri", "3"]}], "\[Mu]"], "+", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["r", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"pe", " ", 
             SuperscriptBox["re", "3"]}], "+", 
            RowBox[{"pi", " ", 
             SuperscriptBox["ri", "3"]}]}], ")"}]}], 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], "+", 
          RowBox[{"2", " ", "\[Mu]"}]}]]}], 
       RowBox[{"4", " ", 
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "3"], "-", 
          SuperscriptBox["ri", "3"]}], ")"}]}]]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "3"], "-", 
           SuperscriptBox["re", "3"]}], ")"}], " ", 
         SuperscriptBox["ri", "3"]}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "3"], "-", 
           SuperscriptBox["ri", "3"]}], ")"}]}]}], 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "3"], "-", 
          SuperscriptBox["ri", "3"]}], ")"}]}]], "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["r", "3"]}], "+", 
           SuperscriptBox["re", "3"]}], ")"}], " ", 
         SuperscriptBox["ri", "3"]}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["r", "3"]}], "+", 
           SuperscriptBox["ri", "3"]}], ")"}]}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "3"], "-", 
          SuperscriptBox["ri", "3"]}], ")"}]}]], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{"pi", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["r", "3"]}], "+", 
           SuperscriptBox["re", "3"]}], ")"}], " ", 
         SuperscriptBox["ri", "3"]}], "+", 
        RowBox[{"pe", " ", 
         SuperscriptBox["re", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["r", "3"]}], "+", 
           SuperscriptBox["ri", "3"]}], ")"}]}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["re", "3"], "-", 
          SuperscriptBox["ri", "3"]}], ")"}]}]]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", " ", 
  RowBox[{"uf", "   ", ",", " ", 
   RowBox[{"re", " ", "\[Rule]", " ", "Infinity"}]}], " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"pi", " ", 
      SuperscriptBox["ri", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
     RowBox[{"pe", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox["r", "3"], " ", "\[Mu]"}], "+", 
        RowBox[{
         SuperscriptBox["ri", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Lambda]"}], "+", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}]}], 
    RowBox[{"4", " ", 
     SuperscriptBox["r", "2"], " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "\[Lambda]"}], "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]], ",", "0", ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", " ", "[", "  ", 
  RowBox[{"Limit", "[", " ", 
   RowBox[{"epsf", "   ", ",", " ", 
    RowBox[{"re", " ", "\[Rule]", " ", "Infinity"}]}], " ", "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", " ", 
  RowBox[{"Limit", "[", " ", 
   RowBox[{"sigf", "   ", ",", " ", 
    RowBox[{"re", " ", "\[Rule]", " ", "Infinity"}]}], " ", "]"}], 
  "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"pe", "+", "pi"}], ")"}], " ", 
             SuperscriptBox["re", "3"], " ", 
             SuperscriptBox["ri", "3"]}], 
            RowBox[{
             SuperscriptBox["r", "3"], " ", "\[Mu]"}]]}], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"pe", " ", 
               SuperscriptBox["re", "3"]}], "+", 
              RowBox[{"pi", " ", 
               SuperscriptBox["ri", "3"]}]}], ")"}]}], 
           RowBox[{
            RowBox[{"3", " ", "\[Lambda]"}], "+", 
            RowBox[{"2", " ", "\[Mu]"}]}]]}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["re", "3"], "-", 
            SuperscriptBox["ri", "3"]}], ")"}]}]], "0", "0"},
       {"0", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"pe", "+", "pi"}], ")"}], " ", 
            SuperscriptBox["re", "3"], " ", 
            SuperscriptBox["ri", "3"]}], "\[Mu]"], "+", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["r", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"pe", " ", 
               SuperscriptBox["re", "3"]}], "+", 
              RowBox[{"pi", " ", 
               SuperscriptBox["ri", "3"]}]}], ")"}]}], 
           RowBox[{
            RowBox[{"3", " ", "\[Lambda]"}], "+", 
            RowBox[{"2", " ", "\[Mu]"}]}]]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["r", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["re", "3"], "-", 
            SuperscriptBox["ri", "3"]}], ")"}]}]], "0"},
       {"0", "0", 
        FractionBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"pe", "+", "pi"}], ")"}], " ", 
            SuperscriptBox["re", "3"], " ", 
            SuperscriptBox["ri", "3"]}], "\[Mu]"], "+", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["r", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"pe", " ", 
               SuperscriptBox["re", "3"]}], "+", 
              RowBox[{"pi", " ", 
               SuperscriptBox["ri", "3"]}]}], ")"}]}], 
           RowBox[{
            RowBox[{"3", " ", "\[Lambda]"}], "+", 
            RowBox[{"2", " ", "\[Mu]"}]}]]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["r", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["re", "3"], "-", 
            SuperscriptBox["ri", "3"]}], ")"}]}]]}
      }], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   RowBox[{"re", "\[Rule]", "\[Infinity]"}]}], "]"}]], "Output"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox[
         RowBox[{
          RowBox[{"pi", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "3"], "-", 
             SuperscriptBox["re", "3"]}], ")"}], " ", 
           SuperscriptBox["ri", "3"]}], "+", 
          RowBox[{"pe", " ", 
           SuperscriptBox["re", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "3"], "-", 
             SuperscriptBox["ri", "3"]}], ")"}]}]}], 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["re", "3"], "-", 
            SuperscriptBox["ri", "3"]}], ")"}]}]], "0", "0"},
       {"0", 
        FractionBox[
         RowBox[{
          RowBox[{"pi", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["r", "3"]}], "+", 
             SuperscriptBox["re", "3"]}], ")"}], " ", 
           SuperscriptBox["ri", "3"]}], "+", 
          RowBox[{"pe", " ", 
           SuperscriptBox["re", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["r", "3"]}], "+", 
             SuperscriptBox["ri", "3"]}], ")"}]}]}], 
         RowBox[{"2", " ", 
          SuperscriptBox["r", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["re", "3"], "-", 
            SuperscriptBox["ri", "3"]}], ")"}]}]], "0"},
       {"0", "0", 
        FractionBox[
         RowBox[{
          RowBox[{"pi", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["r", "3"]}], "+", 
             SuperscriptBox["re", "3"]}], ")"}], " ", 
           SuperscriptBox["ri", "3"]}], "+", 
          RowBox[{"pe", " ", 
           SuperscriptBox["re", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["r", "3"]}], "+", 
             SuperscriptBox["ri", "3"]}], ")"}]}]}], 
         RowBox[{"2", " ", 
          SuperscriptBox["r", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["re", "3"], "-", 
            SuperscriptBox["ri", "3"]}], ")"}]}]]}
      }], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   RowBox[{"re", "\[Rule]", "\[Infinity]"}]}], "]"}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1170, 769},
WindowMargins->{{49, Automatic}, {Automatic, 8}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 113, 3, 73, "Section"],
Cell[CellGroupData[{
Cell[1469, 45, 291, 8, 55, "Input"],
Cell[1763, 55, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1850, 58, 150, 2, 77, "Input"],
Cell[CellGroupData[{
Cell[2025, 64, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2137, 69, 137, 3, 32, "Input"],
Cell[2277, 74, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2410, 81, 132, 3, 32, "Input"],
Cell[2545, 86, 335, 10, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2929, 102, 140, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[3094, 108, 219, 6, 32, "Input"],
Cell[3316, 116, 379, 12, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3732, 133, 464, 13, 32, "Input"],
Cell[4199, 148, 282, 9, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4518, 162, 1038, 29, 55, "Input"],
Cell[5559, 193, 248, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5844, 206, 301, 8, 32, "Input"],
Cell[6148, 216, 72, 2, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6257, 223, 256, 7, 32, "Input"],
Cell[6516, 232, 213, 7, 44, "Output"]
}, Open  ]],
Cell[6744, 242, 26, 0, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6807, 247, 140, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[6972, 253, 1049, 28, 59, "Input"],
Cell[8024, 283, 439, 15, 92, "Output"],
Cell[8466, 300, 1855, 55, 100, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10358, 360, 221, 6, 27, "Input"],
Cell[10582, 368, 1358, 37, 86, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11977, 410, 392, 12, 43, "Input"],
Cell[12372, 424, 506, 16, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12915, 445, 227, 6, 27, "Input"],
Cell[13145, 453, 35, 0, 27, "Output"],
Cell[13183, 455, 1062, 32, 44, "Output"],
Cell[14248, 489, 930, 28, 44, "Output"],
Cell[15181, 519, 684, 23, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15902, 547, 408, 13, 43, "Input"],
Cell[16313, 562, 31, 0, 27, "Output"]
}, Open  ]],
Cell[16359, 565, 441, 15, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16837, 585, 141, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[17003, 591, 176, 5, 27, "Input"],
Cell[17182, 598, 436, 14, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17655, 617, 527, 14, 43, "Input"],
Cell[18185, 633, 1375, 44, 109, "Output"],
Cell[19563, 679, 4688, 135, 147, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24300, 820, 114, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[24439, 825, 117, 3, 27, "Input"],
Cell[24559, 830, 83, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24679, 837, 494, 14, 43, "Input"],
Cell[25176, 853, 391, 8, 20, "Message"],
Cell[25570, 863, 102, 3, 27, "Output"],
Cell[25675, 868, 1396, 43, 64, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27108, 916, 469, 13, 43, "Input"],
Cell[27580, 931, 83, 2, 27, "Output"],
Cell[27666, 935, 1145, 36, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28848, 976, 504, 15, 27, "Input"],
Cell[29355, 993, 1021, 35, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30413, 1033, 541, 14, 59, "Input"],
Cell[30957, 1049, 862, 29, 60, "Output"],
Cell[31822, 1080, 2793, 87, 139, "Output"],
Cell[34618, 1169, 2279, 72, 105, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36934, 1246, 152, 3, 27, "Input"],
Cell[37089, 1251, 875, 28, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38001, 1284, 407, 10, 43, "Input"],
Cell[38411, 1296, 3062, 90, 139, "Output"],
Cell[41476, 1388, 2518, 75, 105, "Output"]
}, Open  ]],
Cell[44009, 1466, 26, 0, 27, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

