(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     16838,        566]
NotebookOptionsPosition[     15111,        508]
NotebookOutlinePosition[     15913,        534]
CellTagsIndexPosition[     15870,        531]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "MyPackageDir", "]"}]], "Input"],

Cell[BoxData["\<\"C:\\\\A1\\\\AMK06\\\\elastica\\\\ElasticaBook.AC\\\\\
Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", " ", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Displacement.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "IntegrateStrain.m"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", " ", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", " ", "\[Theta]", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "\[Theta]", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"AiryStress", "[", "Airy_", "]"}], ":=", 
  RowBox[{"Inc", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "Airy"}], "}"}]}], "}"}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rulefun", "=", 
   RowBox[{
    RowBox[{"Rule", "[", 
     RowBox[{"#1", ",", "#2"}], "]"}], "&"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"norigid", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{"rulefun", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"R", "[", "i", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"T", "[", "i", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"R", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"R", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"R", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"T", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"T", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"T", "[", "3", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IC", "=", 
  RowBox[{"IsotropicComplianceK", "[", "K", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"1", "+", "K"}], "4"], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "K"}], ")"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "K"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox["1", "2"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "2"], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         FractionBox["1", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "2"], ",", "0", ",", "0"}], "}"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox["1", "2"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "2"], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "K"}], ")"}]}], ",", "0", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox[
          RowBox[{"1", "+", "K"}], "4"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "K"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         FractionBox["1", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox["1", "2"], ",", "0"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         FractionBox["1", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "2"], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         FractionBox["1", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox["1", "2"], ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "K"}], ")"}]}], ",", "0", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "K"}], ")"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         FractionBox[
          RowBox[{"1", "+", "K"}], "4"]}], "}"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Disclination", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"SIG", "=", 
    RowBox[{"AiryStress", "[", 
     RowBox[{"D", " ", 
      RowBox[{"r", "^", "2"}], " ", 
      RowBox[{"Log", "[", "r", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"EPS", "=", 
    RowBox[{"DDot", "[", 
     RowBox[{"IC", ",", "SIG"}], "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(SIG\\)\\\" is similar to existing symbol \\\"\\!\\(sig\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"D", "+", 
      RowBox[{"2", " ", "D", " ", 
       RowBox[{"Log", "[", "r", "]"}]}]}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"D", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}], ",", "0"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(EPS\\)\\\" is similar to existing symbol \\\"\\!\\(eps\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", "D", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", "K"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "K"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"D", "+", 
         RowBox[{"2", " ", "D", " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]}], ",", "0", ",", "0"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", "D", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "K"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", "K"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"D", "+", 
         RowBox[{"2", " ", "D", " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]}], ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", "D", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", "K"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"2", " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", "K"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"D", "+", 
         RowBox[{"2", " ", "D", " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Make", " ", "strain", " ", "tensor", " ", "compatible"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"EPSc", "=", "EPS"}], ";", " ", 
    RowBox[{
     RowBox[{"EPSc", "[", 
      RowBox[{"[", 
       RowBox[{"3", ",", "3"}], "]"}], "]"}], "=", "0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Inc", "[", "EPSc", "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Displacement", " ", "around", " ", "disclination"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"U", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"IntegrateStrain", "[", "EPSc", "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"U", "=", 
    RowBox[{
     RowBox[{"U", "/.", 
      RowBox[{"z", "\[Rule]", "0"}]}], "/.", "norigid"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"D", " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "K"}], ")"}], " ", 
        RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "z"}], " ", 
        RowBox[{"R", "[", "2", "]"}]}], "+", 
       RowBox[{"T", "[", "1", "]"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z", " ", 
        RowBox[{"R", "[", "1", "]"}]}], "+", 
       RowBox[{"T", "[", "2", "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"D", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "K"}], ")"}], " ", "r", " ", "\[Theta]"}], "-", 
    RowBox[{"r", " ", 
     RowBox[{"R", "[", "3", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z", " ", 
        RowBox[{"R", "[", "2", "]"}]}], "-", 
       RowBox[{"T", "[", "1", "]"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z", " ", 
        RowBox[{"R", "[", "1", "]"}]}], "+", 
       RowBox[{"T", "[", "2", "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"R", "[", "2", "]"}]}], "-", 
    RowBox[{"r", " ", 
     RowBox[{"R", "[", "1", "]"}], " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
    RowBox[{"T", "[", "3", "]"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"D", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "K"}], ")"}], " ", 
       RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}], ",", 
   RowBox[{"D", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "K"}], ")"}], " ", "r", " ", "\[Theta]"}], ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]]
},
WindowSize->{866, 586},
WindowMargins->{{47, Automatic}, {Automatic, 6}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.563, 842.375},
"PostScriptOutputFile":>FrontEnd`FileName[{
  "local", "constant", "ElasticaBook", "C05_StressFunctions", "NB"}, 
  "check_barber_integratestrain.nb.ps", CharacterEncoding -> "WindowsANSI"]},
ShowSelection->True,
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 76, 1, 32, "Input"],
Cell[1410, 41, 97, 1, 31, "Output"]
}, Open  ]],
Cell[1522, 45, 194, 3, 77, "Input"],
Cell[CellGroupData[{
Cell[1741, 52, 156, 3, 32, "Input"],
Cell[1900, 57, 105, 2, 31, "Output"]
}, Open  ]],
Cell[2020, 62, 372, 11, 32, "Input"],
Cell[CellGroupData[{
Cell[2417, 77, 857, 27, 55, "Input"],
Cell[3277, 106, 473, 14, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3787, 125, 97, 2, 32, "Input"],
Cell[3887, 129, 4074, 132, 186, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7998, 266, 404, 11, 70, "Input"],
Cell[8405, 279, 385, 8, 22, "Message"],
Cell[8793, 289, 509, 17, 29, "Output"],
Cell[9305, 308, 385, 8, 22, "Message"],
Cell[9693, 318, 1980, 66, 110, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11710, 389, 466, 14, 70, "Input"],
Cell[12179, 405, 260, 8, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12476, 418, 440, 13, 70, "Input"],
Cell[12919, 433, 1734, 55, 48, "Output"],
Cell[14656, 490, 439, 15, 29, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

