(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      7451,        270]
NotebookOptionsPosition[      6425,        232]
NotebookOutlinePosition[      6869,        250]
CellTagsIndexPosition[      6826,        247]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "MyPackageDir", "]"}]], "Input"],

Cell[BoxData["\<\"C:\\\\A1\\\\AMK06\\\\elastica\\\\ElasticaBook.AC\\\\\
Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "Displacement.m"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Disclin", "=", 
   RowBox[{
    RowBox[{"1", "/", "2"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", "\[Xi]"}], ")"}], "^", "2"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"y", "-", "\[Eta]"}], ")"}], "^", "2"}]}], ")"}], 
    RowBox[{"Log", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", "\[Xi]"}], ")"}], "^", "2"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"y", "-", "\[Eta]"}], ")"}], "^", "2"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Ay", "=", 
  RowBox[{"D", "[", 
   RowBox[{"Disclin", ",", "\[Xi]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Ax", "=", 
  RowBox[{"D", "[", 
   RowBox[{"Disclin", ",", "\[Eta]"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "x"}], "+", "\[Xi]", "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"x", "-", "\[Xi]"}], ")"}], " ", 
   RowBox[{"Log", "[", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"y", "-", "\[Eta]"}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "\[Xi]"}], ")"}], "2"]}], "]"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "y"}], "+", "\[Eta]", "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"y", "-", "\[Eta]"}], ")"}], " ", 
   RowBox[{"Log", "[", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"y", "-", "\[Eta]"}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "\[Xi]"}], ")"}], "2"]}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Ayx", "=", 
  RowBox[{"D", "[", 
   RowBox[{"Ay", ",", "\[Eta]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Axy", "=", 
  RowBox[{"D", "[", 
   RowBox[{"Ax", ",", "\[Xi]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Ayy", "=", 
  RowBox[{"D", "[", 
   RowBox[{"Ay", ",", "\[Xi]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Axx", "=", 
  RowBox[{"D", "[", 
   RowBox[{"Ax", ",", "\[Eta]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Axx", "+", "Ayy"}], "]"}]}], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{"y", "-", "\[Eta]"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"x", "-", "\[Xi]"}], ")"}]}], 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"y", "-", "\[Eta]"}], ")"}], "2"], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"x", "-", "\[Xi]"}], ")"}], "2"]}]]], "Output"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{"y", "-", "\[Eta]"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"x", "-", "\[Xi]"}], ")"}]}], 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"y", "-", "\[Eta]"}], ")"}], "2"], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"x", "-", "\[Xi]"}], ")"}], "2"]}]]], "Output"],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", "\[Xi]"}], ")"}], "2"]}], 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"y", "-", "\[Eta]"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", "\[Xi]"}], ")"}], "2"]}]], "+", 
  RowBox[{"Log", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"y", "-", "\[Eta]"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", "\[Xi]"}], ")"}], "2"]}], "]"}]}]], "Output"],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"y", "-", "\[Eta]"}], ")"}], "2"]}], 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"y", "-", "\[Eta]"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", "\[Xi]"}], ")"}], "2"]}]], "+", 
  RowBox[{"Log", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"y", "-", "\[Eta]"}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", "\[Xi]"}], ")"}], "2"]}], "]"}]}]], "Output"],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{"2", "+", 
    RowBox[{"Log", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"y", "-", "\[Eta]"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "\[Xi]"}], ")"}], "2"]}], "]"}]}], 
   ")"}]}]], "Output"]
}, Open  ]]
},
WindowSize->{671, 627},
WindowMargins->{{147, Automatic}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 76, 1, 32, "Input"],
Cell[1410, 41, 97, 1, 31, "Output"]
}, Open  ]],
Cell[1522, 45, 127, 2, 55, "Input"],
Cell[CellGroupData[{
Cell[1674, 51, 137, 3, 32, "Input"],
Cell[1814, 56, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1947, 63, 817, 27, 77, "Input"],
Cell[2767, 92, 387, 13, 33, "Output"],
Cell[3157, 107, 389, 13, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3583, 125, 528, 14, 121, "Input"],
Cell[4114, 141, 372, 13, 50, "Output"],
Cell[4489, 156, 372, 13, 50, "Output"],
Cell[4864, 171, 600, 21, 52, "Output"],
Cell[5467, 194, 601, 21, 47, "Output"],
Cell[6071, 217, 338, 12, 29, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

