(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     49138,       1666]
NotebookOptionsPosition[     45708,       1545]
NotebookOutlinePosition[     46153,       1563]
CellTagsIndexPosition[     46110,       1560]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "MyPackageDir", "]"}]], "Input"],

Cell[BoxData["\<\"C:\\\\A1\\\\AMK06\\\\elastica\\\\ElasticaBook.AC\\\\\
Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Displacement.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "IntegrateStrain.m"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"AiryStress", "[", "Airy_", "]"}], ":=", 
  RowBox[{"Inc", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "Airy"}], "}"}]}], "}"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Rotation", " ", "matrix"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"R", "[", " ", "\[Alpha]_", " ", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Alpha]", "]"}], ",", " ", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Sin", "[", "\[Alpha]", "]"}], ",", 
       RowBox[{"Cos", "[", "\[Alpha]", "]"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Example", " ", "rule", " ", "for", " ", "transforming", " ", 
    "expressions", " ", "from", " ", "cartesian", " ", "to", " ", 
    "cylindrical", " ", "coordinates"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"ccylrule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "y"}], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["x", "2"]}], ")"}], "\[Rule]", 
      RowBox[{"r", "^", "2"}]}], ",", 
     RowBox[{"x", "\[Rule]", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "t", "]"}]}], "+", "a"}], ")"}]}]}], 
    "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["x", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "y"}], "+", 
     SuperscriptBox["y", "2"]}], "\[Rule]", 
    SuperscriptBox["r", "2"]}], ",", 
   RowBox[{"x", "\[Rule]", 
    RowBox[{"r", " ", 
     RowBox[{"Cos", "[", "t", "]"}]}]}], ",", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{"a", "+", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", "t", "]"}]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Unit", " ", "force", " ", "in", " ", "positive", " ", "x"}], "-",
     
    RowBox[{"dir", " ", "at", " ", 
     RowBox[{"(", 
      RowBox[{"0", ",", "a"}], ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  
  RowBox[{
   RowBox[{"Airy1", "=", " ", 
    RowBox[{
     RowBox[{"-", " ", 
      RowBox[{"(", 
       RowBox[{"y", "-", "a"}], ")"}]}], "  ", 
     RowBox[{
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"y", "-", "a"}], ")"}], "/", "x"}], "]"}], "/", 
      "\[Pi]"}]}]}], ";"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SCar1", "=", 
  RowBox[{"AiryStress", "[", "Airy1", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["x", "3"]}], 
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["x", "2"], "-", 
           RowBox[{"2", " ", "a", " ", "y"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}], ",", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "y"}], ")"}]}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["x", "2"], "-", 
          RowBox[{"2", " ", "a", " ", "y"}], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]}]], ",", "0"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "y"}], ")"}]}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["x", "2"], "-", 
          RowBox[{"2", " ", "a", " ", "y"}], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]}]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "x", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "-", "y"}], ")"}], "2"]}], 
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["x", "2"], "-", 
           RowBox[{"2", " ", "a", " ", "y"}], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}], ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Cartesian", " ", "stresses", " ", "in", " ", "terms", " ", "of", " ", 
    "cyl", " ", "coords"}], " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"SCarCyl1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"SCar1", "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "y"}], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["x", "2"]}], "\[Rule]", 
       RowBox[{"r", "^", "2"}]}]}], "/.", 
     RowBox[{"x", "\[Rule]", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}]}]}], "/.", 
    RowBox[{"y", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"r", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], "+", "a"}], ")"}]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "t", "]"}], "3"]}], 
       RowBox[{"\[Pi]", " ", "r"}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "t", "]"}], "2"], " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], 
       RowBox[{"\[Pi]", " ", "r"}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "t", "]"}], "2"], " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], 
       RowBox[{"\[Pi]", " ", "r"}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "t", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
       RowBox[{"\[Pi]", " ", "r"}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Rotate", " ", "to", " ", "cyl", " ", "orientation", " ", "of", " ", 
     "stress"}], " ", "-", " ", 
    RowBox[{
    "get", " ", "correct", " ", "stress", " ", "in", " ", "cyl", " ", 
     "coords"}]}], " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"SCyl1", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Dot", "[", 
     RowBox[{
      RowBox[{"Dot", "[", 
       RowBox[{
        RowBox[{"R", "[", 
         RowBox[{"-", "t"}], "]"}], ",", "SCarCyl1"}], "]"}], ",", 
      RowBox[{"R", "[", "t", "]"}]}], "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], 
       RowBox[{"\[Pi]", " ", "r"}]]}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Verify", " ", "stresses", " ", "have", " ", "correct", " ", "resultant", 
    " ", "to", " ", "balance", " ", "external", " ", "force"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"SCyl1", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", 
     RowBox[{"Cos", "[", "t", "]"}], " ", "r"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{"-", "\[Pi]"}], ",", "0"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Unit", " ", "force", " ", "in", " ", "negative", " ", "x"}], "-",
     
    RowBox[{"dir", " ", "at", " ", 
     RowBox[{"(", 
      RowBox[{"0", ",", 
       RowBox[{"-", "a"}]}], ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Airy2", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"y", "+", "a"}], ")"}], " ", 
      RowBox[{
       RowBox[{"ArcTan", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"y", "+", "a"}], ")"}], "/", "x"}], "]"}], "/", 
       "\[Pi]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"B2", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "Airy2"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"SCar2", "=", 
    RowBox[{"Inc", "[", "B2", "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["x", "3"]}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["x", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "y"}], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]}]], ",", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "y"}], ")"}]}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["x", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "y"}], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]}]], ",", "0"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "y"}], ")"}]}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["x", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "y"}], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]}]], ",", 
     FractionBox[
      RowBox[{"2", " ", "x", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "+", "y"}], ")"}], "2"]}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["x", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "y"}], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]}]], ",", "0"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Cartesian", " ", "stresses", " ", "in", " ", "terms", " ", "of", " ", 
    "cyl", " ", "coords"}], " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"SCarCyl2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"SCar2", "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "y"}], "+", 
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"]}], "\[Rule]", 
       RowBox[{"r", "^", "2"}]}]}], "/.", 
     RowBox[{"x", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"r", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], ")"}]}]}], "/.", 
    RowBox[{"y", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"r", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], "-", "a"}], ")"}]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "t", "]"}], "3"]}], 
      RowBox[{"\[Pi]", " ", "r"}]], ",", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "t", "]"}], "2"], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{"\[Pi]", " ", "r"}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "t", "]"}], "2"], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{"\[Pi]", " ", "r"}]], ",", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
      RowBox[{"\[Pi]", " ", "r"}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Rotate", " ", "to", " ", "cyl", " ", "orientation", " ", "of", " ", 
     "stress"}], " ", "-", " ", 
    RowBox[{
    "get", " ", "correct", " ", "stress", " ", "in", " ", "cyl", " ", 
     "coords"}]}], " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"SCyl2", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Dot", "[", 
     RowBox[{
      RowBox[{"Dot", "[", 
       RowBox[{
        RowBox[{"R", "[", 
         RowBox[{"-", "t"}], "]"}], ",", "SCarCyl2"}], "]"}], ",", 
      RowBox[{"R", "[", "t", "]"}]}], "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], 
      RowBox[{"\[Pi]", " ", "r"}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"SCyl2", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", 
    RowBox[{"Cos", "[", "t", "]"}], " ", "r"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "\[Pi]"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData["1"], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Unit", " ", "force", " ", "in", " ", "positive", " ", "y"}], "-",
     
    RowBox[{"dir", " ", "at", " ", 
     RowBox[{"(", 
      RowBox[{"a", ",", "0"}], ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  
  RowBox[{
   RowBox[{"Airy3", "=", " ", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"x", "-", "a"}], ")"}]}], "  ", 
     RowBox[{
      RowBox[{"ArcTan", "[", 
       RowBox[{"y", "/", 
        RowBox[{"(", 
         RowBox[{"x", "-", "a"}], ")"}]}], "]"}], "/", "\[Pi]"}]}]}], 
   ";"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SCar3", "=", 
  RowBox[{"AiryStress", "[", "Airy3", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "x"}], ")"}], "2"], " ", "y"}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", "a", " ", "x"}], "+", 
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]}]], ",", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "x"}], ")"}], " ", 
       SuperscriptBox["y", "2"]}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", "a", " ", "x"}], "+", 
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]}]], ",", "0"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "x"}], ")"}], " ", 
       SuperscriptBox["y", "2"]}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", "a", " ", "x"}], "+", 
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]}]], ",", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["y", "3"]}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", "a", " ", "x"}], "+", 
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]}]], ",", "0"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Cartesian", " ", "stresses", " ", "in", " ", "terms", " ", "of", " ", 
    "cyl", " ", "coords"}], " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"SCarCyl3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"SCar3", "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "x"}], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["x", "2"]}], "\[Rule]", 
       RowBox[{"r", "^", "2"}]}]}], "/.", 
     RowBox[{"x", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "t", "]"}]}], "+", "a"}], ")"}]}]}], "/.", 
    RowBox[{"y", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"r", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], ")"}]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "t", "]"}], "2"], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{"\[Pi]", " ", "r"}]], ",", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
      RowBox[{"\[Pi]", " ", "r"}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
      RowBox[{"\[Pi]", " ", "r"}]], ",", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "t", "]"}], "3"]}], 
      RowBox[{"\[Pi]", " ", "r"}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Rotate", " ", "to", " ", "cyl", " ", "orientation", " ", "of", " ", 
     "stress"}], " ", "-", " ", 
    RowBox[{
    "get", " ", "correct", " ", "stress", " ", "in", " ", "cyl", " ", 
     "coords"}]}], " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"SCyl3", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Dot", "[", 
     RowBox[{
      RowBox[{"Dot", "[", 
       RowBox[{
        RowBox[{"R", "[", 
         RowBox[{"-", "t"}], "]"}], ",", "SCarCyl3"}], "]"}], ",", 
      RowBox[{"R", "[", "t", "]"}]}], "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{"\[Pi]", " ", "r"}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"SCyl3", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}], " ", "r"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"\[Pi]", "/", "2"}], ",", 
     RowBox[{
      RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Unit", " ", "force", " ", "in", " ", "negative", " ", "y"}], "-",
     
    RowBox[{"dir", " ", "at", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], ",", "0"}], ")"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Airy4", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "+", "a"}], ")"}], "  ", 
     RowBox[{
      RowBox[{"ArcTan", "[", 
       RowBox[{"y", "/", 
        RowBox[{"(", 
         RowBox[{"x", "+", "a"}], ")"}]}], "]"}], "/", "\[Pi]"}]}]}], 
   ";"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SCar4", "=", 
  RowBox[{"AiryStress", "[", "Airy4", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "y"}], 
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"a", "+", "x"}], ")"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           FractionBox[
            SuperscriptBox["y", "2"], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "+", "x"}], ")"}], "2"]]}], ")"}], "2"]}]]}], ",", 
     
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", "x"}], ")"}], " ", 
        SuperscriptBox["y", "2"]}], 
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           RowBox[{"2", " ", "a", " ", "x"}], "+", 
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}], ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", "x"}], ")"}], " ", 
        SuperscriptBox["y", "2"]}], 
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           RowBox[{"2", " ", "a", " ", "x"}], "+", 
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["y", "3"]}], 
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           RowBox[{"2", " ", "a", " ", "x"}], "+", 
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}], ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Cartesian", " ", "stresses", " ", "in", " ", "terms", " ", "of", " ", 
    "cyl", " ", "coords"}], " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"SCarCyl4", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"SCar4", "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "x"}], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["x", "2"]}], "\[Rule]", 
       RowBox[{"r", "^", "2"}]}]}], "/.", 
     RowBox[{"x", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "t", "]"}]}], "-", "a"}], ")"}]}]}], "/.", 
    RowBox[{"y", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"r", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], ")"}]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Sec", "[", "t", "]"}], " ", 
        RowBox[{"Tan", "[", "t", "]"}]}], 
       RowBox[{"\[Pi]", " ", "r", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"Tan", "[", "t", "]"}], "2"]}], ")"}], "2"]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "t", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
       RowBox[{"\[Pi]", " ", "r"}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "t", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
       RowBox[{"\[Pi]", " ", "r"}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "t", "]"}], "3"]}], 
       RowBox[{"\[Pi]", " ", "r"}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Rotate", " ", "to", " ", "cyl", " ", "orientation", " ", "of", " ", 
     "stress"}], " ", "-", " ", 
    RowBox[{
    "get", " ", "correct", " ", "stress", " ", "in", " ", "cyl", " ", 
     "coords"}]}], " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"SCyl4", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Dot", "[", 
     RowBox[{
      RowBox[{"Dot", "[", 
       RowBox[{
        RowBox[{"R", "[", 
         RowBox[{"-", "t"}], "]"}], ",", "SCarCyl4"}], "]"}], ",", 
      RowBox[{"R", "[", "t", "]"}]}], "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], 
       RowBox[{"\[Pi]", " ", "r"}]]}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"SCyl4", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}], " ", "r"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{
      RowBox[{"-", "\[Pi]"}], "/", "2"}], ",", 
     RowBox[{"\[Pi]", "/", "2"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FourForces", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"SCar1", "+", "SCar2", "+", "SCar3", "+", "SCar4"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "x"}], ")"}], "2"], " ", "y"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             RowBox[{"2", " ", "a", " ", "x"}], "+", 
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]], "-", 
         FractionBox[
          SuperscriptBox["x", "3"], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["x", "2"], "-", 
             RowBox[{"2", " ", "a", " ", "y"}], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]], "+", 
         FractionBox[
          SuperscriptBox["x", "3"], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["x", "2"], "+", 
             RowBox[{"2", " ", "a", " ", "y"}], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]], "-", 
         FractionBox["y", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", "x"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", 
              FractionBox[
               SuperscriptBox["y", "2"], 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"a", "+", "x"}], ")"}], "2"]]}], ")"}], "2"]}]]}], 
        ")"}]}], "\[Pi]"], ",", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "x"}], ")"}], " ", 
           SuperscriptBox["y", "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             RowBox[{"2", " ", "a", " ", "x"}], "+", 
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "x"}], ")"}], " ", 
           SuperscriptBox["y", "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             RowBox[{"2", " ", "a", " ", "x"}], "+", 
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["x", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "y"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["x", "2"], "-", 
             RowBox[{"2", " ", "a", " ", "y"}], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["x", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "y"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["x", "2"], "+", 
             RowBox[{"2", " ", "a", " ", "y"}], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]]}], ")"}]}], "\[Pi]"], 
     ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "x"}], ")"}], " ", 
           SuperscriptBox["y", "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             RowBox[{"2", " ", "a", " ", "x"}], "+", 
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "x"}], ")"}], " ", 
           SuperscriptBox["y", "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             RowBox[{"2", " ", "a", " ", "x"}], "+", 
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["x", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "y"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["x", "2"], "-", 
             RowBox[{"2", " ", "a", " ", "y"}], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["x", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "y"}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["x", "2"], "+", 
             RowBox[{"2", " ", "a", " ", "y"}], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]]}], ")"}]}], "\[Pi]"], 
     ",", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          SuperscriptBox["y", "3"], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             RowBox[{"2", " ", "a", " ", "x"}], "+", 
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]], "-", 
         FractionBox[
          SuperscriptBox["y", "3"], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             RowBox[{"2", " ", "a", " ", "x"}], "+", 
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]], "-", 
         FractionBox[
          RowBox[{"x", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "y"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["x", "2"], "-", 
             RowBox[{"2", " ", "a", " ", "y"}], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]], "+", 
         FractionBox[
          RowBox[{"x", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", "y"}], ")"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["x", "2"], "+", 
             RowBox[{"2", " ", "a", " ", "y"}], "+", 
             SuperscriptBox["y", "2"]}], ")"}], "2"]]}], ")"}]}], "\[Pi]"], 
     ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Evaluate", " ", "at", " ", "point", " ", "on", " ", "the", " ", "circle", 
    " ", "of", " ", "radius", " ", "a"}], " ", "*)"}], "\[IndentingNewLine]", 
  
  RowBox[{"RFour", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"FourForces", "/.", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{"a", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}]}]}], "/.", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"a", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Tan", "[", "t", "]"}]}], 
       RowBox[{"a", " ", "\[Pi]"}]]}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Cot", "[", "t", "]"}]}], 
      RowBox[{"a", " ", "\[Pi]"}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Rotate", " ", "to", " ", "cyl", " ", "centred", " ", "at", " ", 
     RowBox[{"(", 
      RowBox[{"0", ",", "0"}], ")"}]}], " ", "-", " ", 
    RowBox[{
    "note", " ", "presence", " ", "of", " ", "shear", " ", "tractions"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"SCylRFour", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Dot", "[", 
     RowBox[{
      RowBox[{"Dot", "[", 
       RowBox[{
        RowBox[{"R", "[", 
         RowBox[{"-", "t"}], "]"}], ",", "RFour"}], "]"}], ",", 
      RowBox[{"R", "[", "t", "]"}]}], "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox["2", 
      RowBox[{"a", " ", "\[Pi]"}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["2", 
      RowBox[{"a", " ", "\[Pi]"}]], ",", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"Cot", "[", 
        RowBox[{"2", " ", "t"}], "]"}]}], 
      RowBox[{"a", " ", "\[Pi]"}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Final", " ", "term", " ", "to", " ", "add", " ", "is", " ", "shear", 
      " ", "in", " ", "the", " ", "r"}], "-", 
     RowBox[{
     "t", " ", "coords", "\[IndentingNewLine]", "Note", " ", "that", " ", 
      "Airy"}]}], " ", "=", " ", 
    RowBox[{"theta", " ", "gives", " ", "shear", " ", "stress", " ", 
     RowBox[{"1", "/", 
      RowBox[{"r", "^", "2"}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Airy5", "=", " ", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "a", " ", 
      RowBox[{
       RowBox[{"ArcTan", "[", 
        RowBox[{"y", "/", "x"}], "]"}], "/", "\[Pi]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"SCar5", "=", 
    RowBox[{"AiryStress", "[", "Airy5", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"SCarCyl5", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"SCar5", "/.", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["x", "2"]}], ")"}], "\[Rule]", 
        RowBox[{"r", "^", "2"}]}]}], "/.", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", "t", "]"}]}], ")"}]}]}], "/.", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"r", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], ")"}]}]}]}], "\[IndentingNewLine]", 
   
   RowBox[{"SCyl5", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Dot", "[", 
      RowBox[{
       RowBox[{"Dot", "[", 
        RowBox[{
         RowBox[{"R", "[", 
          RowBox[{"-", "t"}], "]"}], ",", "SCarCyl5"}], "]"}], ",", 
       RowBox[{"R", "[", "t", "]"}]}], "]"}], "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", "a", " ", "x", " ", "y"}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]}]], ",", 
     FractionBox[
      RowBox[{"2", " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x", "2"]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}]}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]}]], ",", "0"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x", "2"]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}]}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"]}], ")"}], "2"]}]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "a", " ", "x", " ", "y"}], 
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}]]}], ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", "a", " ", 
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox["r", "2"]}]], ",", 
     FractionBox[
      RowBox[{"2", " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["r", "2"]}], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "t", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "t", "]"}], "2"]}]}], ")"}]}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox["r", "4"]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["r", "2"]}], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "t", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "t", "]"}], "2"]}]}], ")"}]}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox["r", "4"]}]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", "a", " ", 
        RowBox[{"Cos", "[", "t", "]"}], " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], 
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox["r", "2"]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "a"}], 
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox["r", "2"]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "a"}], 
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox["r", "2"]}]]}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Final", " ", "result", " ", "at", " ", "circumference", " ", "r"}], " ", 
    "=", " ", "a"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"SCylRFour", " ", "+", " ", "SCyl5"}], "/.", 
   RowBox[{"r", "\[Rule]", "a"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"Cot", "[", 
        RowBox[{"2", " ", "t"}], "]"}]}], 
      RowBox[{"a", " ", "\[Pi]"}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
},
WindowSize->{609, 643},
WindowMargins->{{374, Automatic}, {Automatic, 30}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 76, 1, 32, "Input"],
Cell[1410, 41, 97, 1, 31, "Output"]
}, Open  ]],
Cell[1522, 45, 184, 3, 77, "Input"],
Cell[1709, 50, 73, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[1807, 55, 137, 3, 32, "Input"],
Cell[1947, 60, 96, 2, 31, "Output"]
}, Open  ]],
Cell[2058, 65, 372, 11, 32, "Input"],
Cell[2433, 78, 664, 18, 55, "Input"],
Cell[CellGroupData[{
Cell[3122, 100, 888, 26, 99, "Input"],
Cell[4013, 128, 504, 16, 33, "Output"]
}, Open  ]],
Cell[4532, 147, 614, 21, 55, "Input"],
Cell[CellGroupData[{
Cell[5171, 172, 94, 2, 32, "Input"],
Cell[5268, 176, 1961, 62, 107, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7266, 243, 810, 24, 70, "Input"],
Cell[8079, 269, 1090, 35, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9206, 309, 619, 18, 70, "Input"],
Cell[9828, 329, 402, 13, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10267, 347, 560, 16, 70, "Input"],
Cell[10830, 365, 45, 1, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10912, 371, 1063, 34, 90, "Input"],
Cell[11978, 407, 1895, 60, 89, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13910, 472, 839, 25, 70, "Input"],
Cell[14752, 499, 983, 31, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15772, 535, 619, 18, 70, "Input"],
Cell[16394, 555, 377, 12, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16808, 572, 301, 9, 30, "Input"],
Cell[17112, 583, 28, 0, 29, "Output"]
}, Open  ]],
Cell[17155, 586, 606, 21, 50, "Input"],
Cell[CellGroupData[{
Cell[17786, 611, 94, 2, 30, "Input"],
Cell[17883, 615, 1945, 62, 89, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19865, 682, 840, 25, 70, "Input"],
Cell[20708, 709, 983, 31, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21728, 745, 619, 18, 70, "Input"],
Cell[22350, 765, 377, 12, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22764, 782, 379, 12, 30, "Input"],
Cell[23146, 796, 45, 1, 29, "Output"]
}, Open  ]],
Cell[23206, 800, 606, 21, 50, "Input"],
Cell[CellGroupData[{
Cell[23837, 825, 94, 2, 30, "Input"],
Cell[23934, 829, 2041, 66, 103, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26012, 900, 840, 25, 70, "Input"],
Cell[26855, 927, 1233, 39, 87, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28125, 971, 619, 18, 70, "Input"],
Cell[28747, 991, 402, 13, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29186, 1009, 379, 12, 30, "Input"],
Cell[29568, 1023, 45, 1, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29650, 1029, 157, 4, 30, "Input"],
Cell[29810, 1035, 7277, 211, 274, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37124, 1251, 550, 16, 50, "Input"],
Cell[37677, 1269, 519, 17, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38233, 1291, 638, 18, 70, "Input"],
Cell[38874, 1311, 516, 17, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39427, 1333, 1741, 52, 131, "Input"],
Cell[41171, 1387, 1583, 53, 89, "Output"],
Cell[42757, 1442, 1631, 51, 85, "Output"],
Cell[44391, 1495, 532, 18, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44960, 1518, 323, 9, 50, "Input"],
Cell[45286, 1529, 406, 13, 43, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

