(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     27324,        934]
NotebookOptionsPosition[     24870,        851]
NotebookOutlinePosition[     25671,        877]
CellTagsIndexPosition[     25628,        874]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "MyPackageDir", "]"}]], "Input"],

Cell[BoxData["\<\"C:\\\\A1\\\\AMK06\\\\elastica\\\\ElasticaBook.AC\\\\\
Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", " ", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Displacement.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "IntegrateStrain.m"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", " ", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", " ", "\[Theta]", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "\[Theta]", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"rigid", " ", "=", 
  RowBox[{"IntegrateStrain", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{
   RowBox[{"1", "/", "2"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Grad", "[", "%", "]"}], " ", "+", " ", 
     RowBox[{"Transpose", "[", " ", 
      RowBox[{"Grad", "[", "%", "]"}], " ", "]"}]}], ")"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{
   RowBox[{"1", "/", "2"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Grad", "[", "%%", "]"}], " ", "-", " ", 
     RowBox[{"Transpose", "[", " ", 
      RowBox[{"Grad", "[", "%%", "]"}], " ", "]"}]}], ")"}]}], 
  "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "z"}], " ", 
        RowBox[{"R", "[", "2", "]"}]}], "+", 
       RowBox[{"T", "[", "1", "]"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z", " ", 
        RowBox[{"R", "[", "1", "]"}]}], "+", 
       RowBox[{"T", "[", "2", "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "r"}], " ", 
     RowBox[{"R", "[", "3", "]"}]}], "-", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "z"}], " ", 
        RowBox[{"R", "[", "2", "]"}]}], "+", 
       RowBox[{"T", "[", "1", "]"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z", " ", 
        RowBox[{"R", "[", "1", "]"}]}], "+", 
       RowBox[{"T", "[", "2", "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"R", "[", "2", "]"}]}], "-", 
       RowBox[{
        RowBox[{"R", "[", "1", "]"}], " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}], "+", 
    RowBox[{"T", "[", "3", "]"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"R", "[", "3", "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], " ", 
       RowBox[{"R", "[", "2", "]"}]}], "+", 
      RowBox[{
       RowBox[{"R", "[", "1", "]"}], " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"R", "[", "3", "]"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"R", "[", "1", "]"}]}], "+", 
      RowBox[{
       RowBox[{"R", "[", "2", "]"}], " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"R", "[", "2", "]"}]}], "-", 
      RowBox[{
       RowBox[{"R", "[", "1", "]"}], " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], " ", 
       RowBox[{"R", "[", "1", "]"}]}], "-", 
      RowBox[{
       RowBox[{"R", "[", "2", "]"}], " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", "0"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rigid", " ", "=", 
  RowBox[{"IntegrateStrain", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", " ", 
    RowBox[{"Constants", " ", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"R", ",", "T"}], "}"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "z"}], " ", 
        RowBox[{"R", "[", "2", "]"}]}], "+", 
       RowBox[{"T", "[", "1", "]"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z", " ", 
        RowBox[{"R", "[", "1", "]"}]}], "+", 
       RowBox[{"T", "[", "2", "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "r"}], " ", 
     RowBox[{"R", "[", "3", "]"}]}], "-", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "z"}], " ", 
        RowBox[{"R", "[", "2", "]"}]}], "+", 
       RowBox[{"T", "[", "1", "]"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z", " ", 
        RowBox[{"R", "[", "1", "]"}]}], "+", 
       RowBox[{"T", "[", "2", "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"R", "[", "2", "]"}]}], "-", 
       RowBox[{
        RowBox[{"R", "[", "1", "]"}], " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}], "+", 
    RowBox[{"T", "[", "3", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"AiryStress", "[", "Airy_", "]"}], ":=", 
  RowBox[{"Inc", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "Airy"}], "}"}]}], "}"}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IC", "=", 
  RowBox[{"IsotropicComplianceK", "[", "K", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"1", "+", "K"}], "4"], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "K"}], ")"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "K"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox["1", "2"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "2"], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         FractionBox["1", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "2"], ",", "0", ",", "0"}], "}"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox["1", "2"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "2"], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "K"}], ")"}]}], ",", "0", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox[
          RowBox[{"1", "+", "K"}], "4"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "K"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         FractionBox["1", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox["1", "2"], ",", "0"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         FractionBox["1", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "2"], ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         FractionBox["1", "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox["1", "2"], ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "K"}], ")"}]}], ",", "0", ",", "0"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          FractionBox["1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "K"}], ")"}]}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         FractionBox[
          RowBox[{"1", "+", "K"}], "4"]}], "}"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Dislocation", " ", "b_y"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"SIG1", "=", 
    RowBox[{"AiryStress", "[", 
     RowBox[{"r", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], 
      RowBox[{"Log", "[", "r", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"EPS1", "=", 
    RowBox[{"DDot", "[", 
     RowBox[{"IC", ",", "SIG1"}], "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"Cos", "[", "\[Theta]", "]"}], "r"], ",", 
     FractionBox[
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "r"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "r"], ",", 
     FractionBox[
      RowBox[{"Cos", "[", "\[Theta]", "]"}], "r"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", "K"}], ")"}], " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], 
       RowBox[{"4", " ", "r"}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "K"}], ")"}], " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], 
       RowBox[{"4", " ", "r"}]]}], ",", 
     FractionBox[
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "r"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "r"], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", "K"}], ")"}], " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], 
       RowBox[{"4", " ", "r"}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "K"}], ")"}], " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], 
       RowBox[{"4", " ", "r"}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", "K"}], ")"}], " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], 
      RowBox[{"2", " ", "r"}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Make", " ", "strain", " ", "tensor", " ", "compatible"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"EPS1c", "=", "EPS1"}], ";", " ", 
    RowBox[{
     RowBox[{"EPS1c", "[", 
      RowBox[{"[", 
       RowBox[{"3", ",", "3"}], "]"}], "]"}], "=", "0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Inc", "[", "EPS1c", "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rulefun", "=", 
   RowBox[{
    RowBox[{"Rule", "[", 
     RowBox[{"#1", ",", "#2"}], "]"}], "&"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"norigid", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{"rulefun", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"R", "[", "i", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"T", "[", "i", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"R", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"R", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"R", "[", "3", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"T", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"T", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"T", "[", "3", "]"}], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Displacement", " ", "field", " ", "of", " ", "a", " ", "dislocation"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"U1", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"IntegrateStrain", "[", "EPS1c", "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"U1", "=", 
    RowBox[{
     RowBox[{"U1", "/.", 
      RowBox[{"z", "\[Rule]", "0"}]}], "/.", "norigid"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "K"}], ")"}], " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Theta]", "+", 
         RowBox[{"K", " ", "\[Theta]"}]}], ")"}], " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Theta]", "+", 
         RowBox[{"K", " ", "\[Theta]"}]}], ")"}], " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"Log", "[", "r", "]"}], "-", 
         RowBox[{"K", " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}], " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}], ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Force", " ", "F_x"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"SIG2", "=", 
    RowBox[{"AiryStress", "[", 
     RowBox[{"r", " ", "\[Theta]", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "]"}]}], "\[IndentingNewLine]",
    
   RowBox[{"EPS2", "=", 
    RowBox[{"DDot", "[", 
     RowBox[{"IC", ",", "SIG2"}], "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "r"], ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "K"}], ")"}], " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], 
      RowBox[{"2", " ", "r"}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", "K"}], ")"}], " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], 
      RowBox[{"2", " ", "r"}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", "K"}], ")"}], " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], 
      RowBox[{"2", " ", "r"}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Make", " ", "strain", " ", "tensor", " ", "compatible"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"EPS2c", "=", "EPS2"}], ";", " ", 
    RowBox[{
     RowBox[{"EPS2c", "[", 
      RowBox[{"[", 
       RowBox[{"3", ",", "3"}], "]"}], "]"}], "=", "0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Inc", "[", "EPS2c", "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(EPS2c\\)\\\" is similar to existing symbol \\\"\\!\\(EPS2\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Displacement", " ", "around", " ", "force", " ", "on", " ", "a", " ", "2",
     "\[Pi]", " ", "wedge"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"U2", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"IntegrateStrain", "[", "EPS2c", "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"U2", "=", 
    RowBox[{
     RowBox[{"U2", "/.", 
      RowBox[{"z", "\[Rule]", "0"}]}], "/.", "norigid"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "K"}], ")"}], " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "K"}], ")"}], " ", "\[Theta]", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "K"}], ")"}], " ", "\[Theta]", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"Log", "[", "r", "]"}], "+", 
         RowBox[{"K", " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}], " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}], ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "relationship", " ", "between", " ", "constants", " ", "k1", 
    " ", "and", " ", "k2", " ", "to", " ", "ensure", " ", "displacement", " ",
     "continuity"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"k1", " ", 
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"U1", "/.", 
            RowBox[{"\[Theta]", "\[Rule]", "0"}]}], ")"}], "-", 
          RowBox[{"(", 
           RowBox[{"U1", "/.", 
            RowBox[{"\[Theta]", "->", 
             RowBox[{"2", "\[Pi]"}]}]}], ")"}]}], "]"}]}], "+", 
       RowBox[{"k2", " ", 
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"U2", "/.", 
            RowBox[{"\[Theta]", "\[Rule]", "0"}]}], ")"}], "-", 
          RowBox[{"(", 
           RowBox[{"U2", "/.", 
            RowBox[{"\[Theta]", "->", 
             RowBox[{"2", "\[Pi]"}]}]}], ")"}]}], "]"}]}]}], "\[Equal]", 
      "0"}], ",", 
     RowBox[{"{", "k1", "}"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"k1", "\[Rule]", 
    FractionBox[
     RowBox[{"k2", "-", 
      RowBox[{"K", " ", "k2"}]}], 
     RowBox[{"1", "+", "K"}]]}], "}"}], "}"}]], "Output"]
}, Open  ]]
},
WindowSize->{707, 702},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.563, 842.375},
"PostScriptOutputFile":>FrontEnd`FileName[{
  "local", "constant", "ElasticaBook", "C05_StressFunctions", "NB"}, 
  "check_barber_integratestrain.nb.ps", CharacterEncoding -> "WindowsANSI"]},
ShowSelection->True,
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 76, 1, 32, "Input"],
Cell[1410, 41, 97, 1, 31, "Output"]
}, Open  ]],
Cell[1522, 45, 194, 3, 77, "Input"],
Cell[CellGroupData[{
Cell[1741, 52, 156, 3, 32, "Input"],
Cell[1900, 57, 105, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2042, 64, 952, 29, 77, "Input"],
Cell[2997, 95, 1460, 48, 72, "Output"],
Cell[4460, 145, 260, 8, 31, "Output"],
Cell[4723, 155, 1315, 42, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6075, 202, 487, 14, 32, "Input"],
Cell[6565, 218, 1460, 48, 72, "Output"]
}, Open  ]],
Cell[8040, 269, 372, 11, 32, "Input"],
Cell[CellGroupData[{
Cell[8437, 284, 97, 2, 32, "Input"],
Cell[8537, 288, 4074, 132, 221, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12648, 425, 441, 12, 70, "Input"],
Cell[13092, 439, 520, 16, 42, "Output"],
Cell[13615, 457, 1428, 47, 78, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15080, 509, 470, 14, 70, "Input"],
Cell[15553, 525, 260, 8, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15850, 538, 857, 27, 70, "Input"],
Cell[16710, 567, 473, 14, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17220, 586, 490, 15, 70, "Input"],
Cell[17713, 603, 1198, 39, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18948, 647, 417, 12, 70, "Input"],
Cell[19368, 661, 358, 12, 42, "Output"],
Cell[19729, 675, 841, 28, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20607, 708, 470, 14, 70, "Input"],
Cell[21080, 724, 388, 8, 37, "Message"],
Cell[21471, 734, 260, 8, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21768, 747, 519, 15, 70, "Input"],
Cell[22290, 764, 1141, 37, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23468, 806, 1175, 33, 130, "Input"],
Cell[24646, 841, 208, 7, 42, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

