(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     14498,        508]
NotebookOptionsPosition[     12739,        443]
NotebookOutlinePosition[     13181,        461]
CellTagsIndexPosition[     13138,        458]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetDirectory", "[", "myrootdir", "]"}], "\[IndentingNewLine]", 
 RowBox[{"SetDirectory", "[", "\"\<elastica\>\"", "]"}]}], "Input"],

Cell[BoxData["\<\"C:\\\\A1\\\\AMK06\"\>"], "Output"],

Cell[BoxData["\<\"C:\\\\A1\\\\AMK06\\\\elastica\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "InequalityGraphics`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Displacement.m"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Airy", "=", 
   RowBox[{
    RowBox[{"C", " ", "r", " ", "t", " ", 
     RowBox[{"Sin", "[", "t", "]"}]}], " ", "+", " ", 
    RowBox[{"D", " ", "r", " ", 
     RowBox[{"Log", "[", "r", "]"}], 
     RowBox[{"Cos", "[", "t", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Stress", "=", 
  RowBox[{"Inc", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "Airy"}], "}"}]}], "}"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "C"}], "+", "D"}], ")"}], " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], "r"], ",", 
     FractionBox[
      RowBox[{"D", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], "r"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"D", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], "r"], ",", 
     FractionBox[
      RowBox[{"D", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], "r"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SS", "=", 
   RowBox[{"Array", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "nu"}], " ", 
        RowBox[{"KroneckerDelta", "[", 
         RowBox[{"#1", ",", "#2"}], "]"}], " ", 
        RowBox[{"KroneckerDelta", "[", 
         RowBox[{"#3", ",", "#4"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], "/", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"KroneckerDelta", "[", 
            RowBox[{"#1", ",", "#3"}], "]"}], " ", 
           RowBox[{"KroneckerDelta", "[", 
            RowBox[{"#2", ",", "#4"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"KroneckerDelta", "[", 
            RowBox[{"#1", ",", "#4"}], "]"}], 
           RowBox[{"KroneckerDelta", "[", 
            RowBox[{"#2", ",", "#3"}], "]"}]}]}], ")"}]}]}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "3", ",", "3"}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DDot", "[", 
   RowBox[{"T4_", ",", "t2_"}], "]"}], ":=", 
  RowBox[{"GTr", "[", 
   RowBox[{
    RowBox[{"GDot", "[", 
     RowBox[{"T4", ",", "t2", ",", "1", ",", "1"}], "]"}], ",", "1", ",", 
    "4"}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Strain", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"DDot", "[", 
    RowBox[{"SS", ",", "Stress"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "C"}], "+", "D", "-", 
         RowBox[{"D", " ", "nu"}]}], ")"}], " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], "r"], ",", 
     FractionBox[
      RowBox[{"D", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], "r"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"D", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], "r"], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "C"}], "+", "D"}], ")"}], " ", "nu"}]}], ")"}], 
       " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], "r"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"C", "+", "D"}], ")"}], " ", "nu", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], "r"]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"??", "IntegrateGrad"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["\<\"IntegrateGrad[nf_vector] is an integral  operator which \
finds a field f such that Nabla[f] = nf\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{
      RowBox[{"Attributes", "[", "IntegrateGrad", "]"}], "=", 
      RowBox[{"{", 
       RowBox[{"Protected", ",", "ReadProtected"}], "}"}]}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[IntegrateGrad],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Inc", "[", "Strain", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"C", "+", "D"}], ")"}], " ", "nu", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], 
      SuperscriptBox["r", "3"]], ",", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"C", "+", "D"}], ")"}], " ", "nu", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      SuperscriptBox["r", "3"]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"C", "+", "D"}], ")"}], " ", "nu", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      SuperscriptBox["r", "3"]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"C", "+", "D"}], ")"}], " ", "nu", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], 
       SuperscriptBox["r", "3"]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gradtheta", "=", 
  RowBox[{"-", 
   RowBox[{"Curl", "[", "Strain", "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"C", "+", "D"}], ")"}], " ", "nu", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], 
       SuperscriptBox["r", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"C", "+", "D"}], ")"}], " ", "nu", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], 
      SuperscriptBox["r", "2"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"D", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{"Sin", "[", "t", "]"}]}], 
        SuperscriptBox["r", "2"]]}], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "C"}], "+", "D", "-", 
          RowBox[{"D", " ", "nu"}]}], ")"}], " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], 
       SuperscriptBox["r", "2"]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"D", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], 
       SuperscriptBox["r", "2"]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "C"}], "+", "D", "-", 
          RowBox[{"D", " ", "nu"}]}], ")"}], " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], 
       SuperscriptBox["r", "2"]]}], ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theta", "=", 
  RowBox[{"IntegrateGrad", "[", "gradtheta", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(theta\\)\\\" is similar to existing symbol \\\"\\!\\(Ttheta\\)\\\".\
\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"C", "+", "D"}], ")"}], " ", "nu", " ", "z", " ", 
      RowBox[{"Sin", "[", "t", "]"}]}], 
     SuperscriptBox["r", "2"]]}], ",", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"C", "+", "D"}], ")"}], " ", "nu", " ", "z", " ", 
     RowBox[{"Cos", "[", "t", "]"}]}], 
    SuperscriptBox["r", "2"]], ",", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], "+", 
       RowBox[{"D", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}], "r"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"omega", "=", 
  RowBox[{"Table", "[", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Signature", "[", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}], " ", 
      RowBox[{"theta", "[", 
       RowBox[{"[", "k", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "3"}], "}"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uint", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"IntegrateGrad", "[", 
    RowBox[{"Strain", " ", "+", " ", "omega"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "D"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", 
    RowBox[{"Cos", "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"Log", "[", "r", "]"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"D", "-", 
      RowBox[{"2", " ", "C", " ", "nu"}], "-", 
      RowBox[{"D", " ", "nu"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "C"}], "+", "D", "-", 
         RowBox[{"D", " ", "nu"}]}], ")"}], " ", 
       RowBox[{"Log", "[", "r", "]"}]}]}], ")"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"C", "+", "D"}], ")"}], " ", "nu", " ", "z", " ", 
      RowBox[{"Cos", "[", "t", "]"}]}], "r"]}]}], "}"}]], "Output"]
}, Open  ]]
},
WindowSize->{488, 574},
WindowMargins->{{6, Automatic}, {Automatic, 8}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 331, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 156, 2, 55, "Input"],
Cell[1490, 42, 52, 0, 31, "Output"],
Cell[1545, 44, 64, 0, 31, "Output"]
}, Open  ]],
Cell[1624, 47, 186, 3, 77, "Input"],
Cell[1813, 52, 73, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[1911, 57, 139, 3, 32, "Input"],
Cell[2053, 62, 98, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2188, 69, 626, 18, 55, "Input"],
Cell[2817, 89, 691, 23, 83, "Output"]
}, Open  ]],
Cell[3523, 115, 1046, 31, 231, "Input"],
Cell[4572, 148, 259, 8, 30, "Input"],
Cell[CellGroupData[{
Cell[4856, 160, 152, 4, 30, "Input"],
Cell[5011, 166, 1250, 41, 110, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6298, 212, 57, 1, 30, "Input"],
Cell[CellGroupData[{
Cell[6380, 217, 131, 1, 44, "Print"],
Cell[6514, 220, 439, 13, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7002, 239, 96, 2, 30, "Input"],
Cell[7101, 243, 1055, 33, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8193, 281, 112, 3, 30, "Input"],
Cell[8308, 286, 1627, 52, 110, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9972, 343, 101, 2, 30, "Input"],
Cell[10076, 347, 244, 6, 60, "Message"],
Cell[10323, 355, 716, 23, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11076, 383, 517, 16, 70, "Input"],
Cell[11596, 401, 28, 0, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11661, 406, 172, 4, 30, "Input"],
Cell[11836, 412, 887, 28, 86, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

