(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     64288,       3721]
NotebookOptionsPosition[     63158,       3680]
NotebookOutlinePosition[     63664,       3700]
CellTagsIndexPosition[     63621,       3697]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "MyPackageDir", "]"}]], "Input"],

Cell[BoxData["\<\"C:\\\\A1\\\\AMK06\\\\elastica\\\\ElasticaBook.AC\\\\\
Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "Tensor2Analysis.m"}]], "Input"],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"AiryStress", "[", "Airy_", "]"}], ":=", 
  RowBox[{"Inc", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "Airy"}], "}"}]}], "}"}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Airy", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", "\[Xi]"}], ")"}], "^", "2"}], "+", 
      RowBox[{"y", "^", "2"}]}], ")"}], 
    RowBox[{
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"x", "-", "\[Xi]"}], ",", "y"}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", "\[Pi]"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"D", "[", 
  RowBox[{"Airy", ",", "\[Xi]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["y", 
   RowBox[{"2", " ", "\[Pi]"}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", "-", "\[Xi]"}], ")"}], " ", 
    RowBox[{"ArcTan", "[", 
     RowBox[{
      RowBox[{"x", "-", "\[Xi]"}], ",", "y"}], "]"}]}], "\[Pi]"]}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Differentiate", " ", "to", " ", "find", " ", "point", " ", "function"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Airy1", "=", " ", 
     RowBox[{"Airy", "/.", 
      RowBox[{"\[Xi]", "\[Rule]", "a"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Airy2", "=", " ", 
     RowBox[{"Airy", "/.", 
      RowBox[{"\[Xi]", "\[Rule]", 
       RowBox[{"-", "a"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Stress", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"AiryStress", "[", 
       RowBox[{"Airy1", "-", "Airy2"}], "]"}], "]"}]}], ";"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"S22", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Stress", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "2"}], "]"}], "]"}], "/.", 
     RowBox[{"a", "\[Rule]", "1"}]}], "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rad", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ContourPlot", "[", 
  RowBox[{"S22", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "rad"}], ",", "rad"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", 
     RowBox[{"2", " ", "rad"}]}], "}"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "100"}]}], "]"}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.0192308 0.240385 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.25962 -0.0125 -6 -9 ]
[.25962 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -3 -9 ]
[.74038 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -6 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -6 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-2)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(-1)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(1)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(2)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(1)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(2)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(3)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(4)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.2 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.1 g
.01923 .43331 m
.02194 .42716 L
.02627 .41744 L
.02894 .41152 L
.03067 .40773 L
.03515 .39802 L
.03866 .39052 L
.0397 .38831 L
.04432 .37859 L
.04837 .37022 L
.04902 .36888 L
.05379 .35917 L
.05808 .35056 L
.05864 .34946 L
.06356 .33974 L
.06779 .33149 L
.06855 .33003 L
.07361 .32032 L
.07751 .31295 L
.07875 .31061 L
.08396 .30089 L
.08722 .29489 L
.08924 .29118 L
.0946 .28147 L
.09693 .27727 L
.10002 .27176 L
.10551 .26204 L
.10664 .26006 L
.11108 .25233 L
.11636 .24322 L
.1167 .24262 L
.1224 .23291 L
.12607 .22671 L
.12816 .22319 L
.13399 .21348 L
.13578 .21051 L
.13987 .20377 L
.14549 .19458 L
.14582 .19406 L
.15182 .18434 L
.15521 .1789 L
.15788 .17463 L
.16399 .16492 L
.16492 .16345 L
.17015 .15521 L
.17463 .14819 L
.17636 .14549 L
.18261 .13578 L
.18434 .1331 L
.18891 .12607 L
.19406 .11815 L
.19523 .11636 L
.2016 .10664 L
.20377 .10332 L
.208 .09693 L
.21348 .08859 L
.2144 .08722 L
.22086 .07751 L
.22319 .07392 L
.22734 .06779 L
.23291 .05931 L
.23376 .05808 L
.24051 .04837 L
.24262 .04472 L
.2476 .03866 L
.25233 .03009 L
.25377 .02894 L
.2541 .01923 L
.01923 .01923 L
F
0 g
.01923 .43331 m
.02194 .42716 L
.02627 .41744 L
.02894 .41152 L
.03067 .40773 L
.03515 .39802 L
.03866 .39052 L
.0397 .38831 L
.04432 .37859 L
.04837 .37022 L
.04902 .36888 L
.05379 .35917 L
.05808 .35056 L
.05864 .34946 L
.06356 .33974 L
.06779 .33149 L
.06855 .33003 L
.07361 .32032 L
.07751 .31295 L
.07875 .31061 L
.08396 .30089 L
.08722 .29489 L
.08924 .29118 L
.0946 .28147 L
.09693 .27727 L
.10002 .27176 L
.10551 .26204 L
.10664 .26006 L
.11108 .25233 L
.11636 .24322 L
.1167 .24262 L
.1224 .23291 L
.12607 .22671 L
.12816 .22319 L
.13399 .21348 L
.13578 .21051 L
.13987 .20377 L
.14549 .19458 L
.14582 .19406 L
.15182 .18434 L
.15521 .1789 L
.15788 .17463 L
.16399 .16492 L
.16492 .16345 L
.17015 .15521 L
.17463 .14819 L
.17636 .14549 L
.18261 .13578 L
.18434 .1331 L
.18891 .12607 L
Mistroke
.19406 .11815 L
.19523 .11636 L
.2016 .10664 L
.20377 .10332 L
.208 .09693 L
.21348 .08859 L
.2144 .08722 L
.22086 .07751 L
.22319 .07392 L
.22734 .06779 L
.23291 .05931 L
.23376 .05808 L
.24051 .04837 L
.24262 .04472 L
.2476 .03866 L
.25233 .03009 L
.25377 .02894 L
.2541 .01923 L
Mfstroke
.01923 .23665 m
.02308 .23291 L
.02894 .22724 L
.03314 .22319 L
.03866 .21789 L
.04327 .21348 L
.04837 .20862 L
.05349 .20377 L
.05808 .19942 L
.06378 .19406 L
.06779 .19029 L
.07416 .18434 L
.07751 .18123 L
.08462 .17463 L
.08722 .17222 L
.09515 .16492 L
.09693 .16328 L
.10575 .15521 L
.10664 .15439 L
.11636 .14556 L
.11643 .14549 L
.12607 .13678 L
.12718 .13578 L
.13578 .12805 L
.13799 .12607 L
.14549 .11936 L
.14887 .11636 L
.15521 .11071 L
.1598 .10664 L
.16492 .1021 L
.17078 .09693 L
.17463 .09352 L
.1818 .08722 L
.18434 .08497 L
.19286 .07751 L
.19406 .07645 L
.20377 .06794 L
.20393 .06779 L
.21348 .05946 L
.21511 .05808 L
.22319 .05101 L
.22642 .04837 L
.23291 .0427 L
.23749 .03866 L
.24262 .03609 L
.24877 .02894 L
.25233 .02515 L
.25312 .01923 L
.01923 .01923 L
F
.01923 .23665 m
.02308 .23291 L
.02894 .22724 L
.03314 .22319 L
.03866 .21789 L
.04327 .21348 L
.04837 .20862 L
.05349 .20377 L
.05808 .19942 L
.06378 .19406 L
.06779 .19029 L
.07416 .18434 L
.07751 .18123 L
.08462 .17463 L
.08722 .17222 L
.09515 .16492 L
.09693 .16328 L
.10575 .15521 L
.10664 .15439 L
.11636 .14556 L
.11643 .14549 L
.12607 .13678 L
.12718 .13578 L
.13578 .12805 L
.13799 .12607 L
.14549 .11936 L
.14887 .11636 L
.15521 .11071 L
.1598 .10664 L
.16492 .1021 L
.17078 .09693 L
.17463 .09352 L
.1818 .08722 L
.18434 .08497 L
.19286 .07751 L
.19406 .07645 L
.20377 .06794 L
.20393 .06779 L
.21348 .05946 L
.21511 .05808 L
.22319 .05101 L
.22642 .04837 L
.23291 .0427 L
.23749 .03866 L
.24262 .03609 L
.24877 .02894 L
.25233 .02515 L
.25312 .01923 L
s
.3 g
.20661 .98077 m
.20377 .9764 L
.20038 .97106 L
.19445 .96134 L
.19406 .96069 L
.1888 .95163 L
.18434 .94362 L
.18342 .94192 L
.1783 .93221 L
.17463 .92496 L
.17341 .92249 L
.16876 .91278 L
.16492 .90438 L
.16433 .90307 L
.16011 .89336 L
.1561 .88364 L
.15521 .88143 L
.15227 .87393 L
.14864 .86422 L
.14549 .8554 L
.14518 .85451 L
.1419 .84479 L
.13879 .83508 L
.13585 .82537 L
.13578 .82514 L
.13306 .81566 L
.13043 .80594 L
.12796 .79623 L
.12607 .78842 L
.12562 .78652 L
.12344 .77681 L
.12139 .76709 L
.11948 .75738 L
.11771 .74767 L
.11636 .73975 L
.11606 .73796 L
.11455 .72824 L
.11316 .71853 L
.1119 .70882 L
.11076 .69911 L
.10974 .68939 L
.10884 .67968 L
.10805 .66997 L
.10739 .66026 L
.10683 .65054 L
.10664 .64679 L
.10639 .64083 L
.10605 .63112 L
.10583 .62141 L
.10571 .61169 L
.1057 .60198 L
.1058 .59227 L
.106 .58256 L
.1063 .57284 L
.10664 .56436 L
.1067 .56313 L
.10721 .55342 L
.10781 .54371 L
.10852 .53399 L
.10932 .52428 L
.11022 .51457 L
.11122 .50486 L
.11231 .49514 L
.1135 .48543 L
.11478 .47572 L
.11616 .46601 L
.11636 .46467 L
.11763 .45629 L
.11919 .44658 L
.12084 .43687 L
.12258 .42716 L
.12442 .41744 L
.12607 .40906 L
.12634 .40773 L
.12835 .39802 L
.13044 .38831 L
.13263 .37859 L
.1349 .36888 L
.13578 .36518 L
.13725 .35917 L
.13969 .34946 L
.14221 .33974 L
.14481 .33003 L
.14549 .32753 L
.14749 .32032 L
.15026 .31061 L
.1531 .30089 L
.15521 .29384 L
.15601 .29118 L
.15901 .28147 L
.16207 .27176 L
.16492 .26294 L
.16521 .26204 L
.16842 .25233 L
.1717 .24262 L
.17463 .2341 L
.17505 .23291 L
.17846 .22319 L
.18193 .21348 L
.18434 .20682 L
.18546 .20377 L
.18905 .19406 L
.19269 .18434 L
.19406 .18073 L
.19638 .17463 L
.20013 .16492 L
.20377 .15556 L
.20391 .15521 L
.20774 .14549 L
.21161 .13578 L
.21348 .13109 L
.21551 .12607 L
.21944 .11636 L
.22319 .10712 L
.22339 .10664 L
.22738 .09693 L
.23138 .08722 L
.23291 .08348 L
.2354 .07751 L
.23947 .06779 L
.24262 .06003 L
.24346 .05808 L
.24775 .04837 L
.25194 .03866 L
.25233 .0366 L
.25804 .02894 L
.25501 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.20661 .98077 m
.20377 .9764 L
.20038 .97106 L
.19445 .96134 L
.19406 .96069 L
.1888 .95163 L
.18434 .94362 L
.18342 .94192 L
.1783 .93221 L
.17463 .92496 L
.17341 .92249 L
.16876 .91278 L
.16492 .90438 L
.16433 .90307 L
.16011 .89336 L
.1561 .88364 L
.15521 .88143 L
.15227 .87393 L
.14864 .86422 L
.14549 .8554 L
.14518 .85451 L
.1419 .84479 L
.13879 .83508 L
.13585 .82537 L
.13578 .82514 L
.13306 .81566 L
.13043 .80594 L
.12796 .79623 L
.12607 .78842 L
.12562 .78652 L
.12344 .77681 L
.12139 .76709 L
.11948 .75738 L
.11771 .74767 L
.11636 .73975 L
.11606 .73796 L
.11455 .72824 L
.11316 .71853 L
.1119 .70882 L
.11076 .69911 L
.10974 .68939 L
.10884 .67968 L
.10805 .66997 L
.10739 .66026 L
.10683 .65054 L
.10664 .64679 L
.10639 .64083 L
.10605 .63112 L
.10583 .62141 L
.10571 .61169 L
Mistroke
.1057 .60198 L
.1058 .59227 L
.106 .58256 L
.1063 .57284 L
.10664 .56436 L
.1067 .56313 L
.10721 .55342 L
.10781 .54371 L
.10852 .53399 L
.10932 .52428 L
.11022 .51457 L
.11122 .50486 L
.11231 .49514 L
.1135 .48543 L
.11478 .47572 L
.11616 .46601 L
.11636 .46467 L
.11763 .45629 L
.11919 .44658 L
.12084 .43687 L
.12258 .42716 L
.12442 .41744 L
.12607 .40906 L
.12634 .40773 L
.12835 .39802 L
.13044 .38831 L
.13263 .37859 L
.1349 .36888 L
.13578 .36518 L
.13725 .35917 L
.13969 .34946 L
.14221 .33974 L
.14481 .33003 L
.14549 .32753 L
.14749 .32032 L
.15026 .31061 L
.1531 .30089 L
.15521 .29384 L
.15601 .29118 L
.15901 .28147 L
.16207 .27176 L
.16492 .26294 L
.16521 .26204 L
.16842 .25233 L
.1717 .24262 L
.17463 .2341 L
.17505 .23291 L
.17846 .22319 L
.18193 .21348 L
.18434 .20682 L
Mistroke
.18546 .20377 L
.18905 .19406 L
.19269 .18434 L
.19406 .18073 L
.19638 .17463 L
.20013 .16492 L
.20377 .15556 L
.20391 .15521 L
.20774 .14549 L
.21161 .13578 L
.21348 .13109 L
.21551 .12607 L
.21944 .11636 L
.22319 .10712 L
.22339 .10664 L
.22738 .09693 L
.23138 .08722 L
.23291 .08348 L
.2354 .07751 L
.23947 .06779 L
.24262 .06003 L
.24346 .05808 L
.24775 .04837 L
.25194 .03866 L
.25233 .0366 L
.25804 .02894 L
.25501 .01923 L
Mfstroke
.4 g
.7441 .01923 m
.73972 .02894 L
.74468 .03866 L
.74716 .04837 L
.74767 .05043 L
.74937 .05808 L
.75164 .06779 L
.75391 .07751 L
.75615 .08722 L
.75738 .09255 L
.75837 .09693 L
.76058 .10664 L
.76276 .11636 L
.76492 .12607 L
.76704 .13578 L
.76709 .13601 L
.76913 .14549 L
.77119 .15521 L
.7732 .16492 L
.77517 .17463 L
.77681 .18291 L
.77709 .18434 L
.77895 .19406 L
.78075 .20377 L
.7825 .21348 L
.78418 .22319 L
.78579 .23291 L
.78652 .23746 L
.78733 .24262 L
.78879 .25233 L
.79017 .26204 L
.79148 .27176 L
.79269 .28147 L
.79382 .29118 L
.79487 .30089 L
.79581 .31061 L
.79623 .31521 L
.79667 .32032 L
.79742 .33003 L
.79807 .33974 L
.79862 .34946 L
.79907 .35917 L
.7994 .36888 L
.79962 .37859 L
.79973 .38831 L
.79973 .39802 L
.7996 .40773 L
.79935 .41744 L
.79898 .42716 L
.79848 .43687 L
.79785 .44658 L
.79708 .45629 L
.79623 .4655 L
.79618 .46601 L
.79514 .47572 L
.79395 .48543 L
.79261 .49514 L
.79113 .50486 L
.78948 .51457 L
.78768 .52428 L
.78652 .53009 L
.78571 .53399 L
.78356 .54371 L
.78124 .55342 L
.77874 .56313 L
.77681 .57018 L
.77605 .57284 L
.77316 .58256 L
.77006 .59227 L
.76709 .601 L
.76675 .60198 L
.76321 .61169 L
.75944 .62141 L
.75738 .62647 L
.75543 .63112 L
.75115 .64083 L
.74767 .64831 L
.7466 .65054 L
.74175 .66026 L
.73796 .66746 L
.7366 .66997 L
.7311 .67968 L
.72824 .6845 L
.72525 .68939 L
.719 .69911 L
.71853 .69982 L
.71233 .70882 L
.70882 .71368 L
.70519 .71853 L
.69911 .72629 L
.69752 .72824 L
.68939 .73781 L
.68927 .73796 L
.68034 .74767 L
.67968 .74835 L
.67063 .75738 L
.66997 .75802 L
.66026 .76687 L
.66 .76709 L
.65054 .77499 L
.64825 .77681 L
.64083 .78243 L
.63509 .78652 L
.63112 .78922 L
.62141 .7954 L
.62003 .79623 L
.61169 .80102 L
.60226 .80594 L
.60198 .80608 L
.59227 .81063 L
.58256 .81467 L
.57999 .81566 L
.57284 .81822 L
.56313 .8213 L
.55342 .82392 L
.5472 .82537 L
.54371 .82609 L
.53399 .82782 L
.52428 .82911 L
.51457 .82997 L
.50486 .83039 L
.49514 .83039 L
.48543 .82997 L
.47572 .82911 L
.46601 .82782 L
.45629 .82609 L
.4528 .82537 L
.44658 .82392 L
.43687 .8213 L
.42716 .81822 L
.42001 .81566 L
.41744 .81467 L
.40773 .81063 L
.39802 .80608 L
.39774 .80594 L
.38831 .80102 L
.37997 .79623 L
.37859 .7954 L
.36888 .78922 L
.36491 .78652 L
.35917 .78243 L
.35175 .77681 L
.34946 .77499 L
.34 .76709 L
.33974 .76687 L
.33003 .75802 L
.32937 .75738 L
.32032 .74835 L
.31966 .74767 L
.31073 .73796 L
.31061 .73781 L
.30248 .72824 L
.30089 .72629 L
.29481 .71853 L
.29118 .71368 L
.28767 .70882 L
.28147 .69982 L
.281 .69911 L
.27475 .68939 L
.27176 .6845 L
.2689 .67968 L
.2634 .66997 L
.26204 .66746 L
.25825 .66026 L
.2534 .65054 L
.25233 .64831 L
.24885 .64083 L
.24457 .63112 L
.24262 .62647 L
.24056 .62141 L
.23679 .61169 L
.23325 .60198 L
.23291 .601 L
.22994 .59227 L
.22684 .58256 L
.22395 .57284 L
.22319 .57018 L
.22126 .56313 L
.21876 .55342 L
.21644 .54371 L
.21429 .53399 L
.21348 .53009 L
.21232 .52428 L
.21052 .51457 L
.20887 .50486 L
.20739 .49514 L
.20605 .48543 L
.20486 .47572 L
.20382 .46601 L
.20377 .4655 L
.20292 .45629 L
.20215 .44658 L
.20152 .43687 L
.20102 .42716 L
.20065 .41744 L
.2004 .40773 L
.20027 .39802 L
.20027 .38831 L
.20038 .37859 L
.2006 .36888 L
.20093 .35917 L
.20138 .34946 L
.20193 .33974 L
.20258 .33003 L
.20333 .32032 L
.20377 .31521 L
.20419 .31061 L
.20513 .30089 L
.20618 .29118 L
.20731 .28147 L
.20852 .27176 L
.20983 .26204 L
.21121 .25233 L
.21267 .24262 L
.21348 .23746 L
.21421 .23291 L
.21582 .22319 L
.2175 .21348 L
.21925 .20377 L
.22105 .19406 L
.22291 .18434 L
.22319 .18291 L
.22483 .17463 L
.2268 .16492 L
.22881 .15521 L
.23087 .14549 L
.23291 .13601 L
.23296 .13578 L
.23508 .12607 L
.23724 .11636 L
.23942 .10664 L
.24163 .09693 L
.24262 .09255 L
.24385 .08722 L
.24609 .07751 L
.24836 .06779 L
.25063 .05808 L
.25233 .05043 L
.25284 .04837 L
.25532 .03866 L
.26028 .02894 L
.2559 .01923 L
F
0 g
.7441 .01923 m
.73972 .02894 L
.74468 .03866 L
.74716 .04837 L
.74767 .05043 L
.74937 .05808 L
.75164 .06779 L
.75391 .07751 L
.75615 .08722 L
.75738 .09255 L
.75837 .09693 L
.76058 .10664 L
.76276 .11636 L
.76492 .12607 L
.76704 .13578 L
.76709 .13601 L
.76913 .14549 L
.77119 .15521 L
.7732 .16492 L
.77517 .17463 L
.77681 .18291 L
.77709 .18434 L
.77895 .19406 L
.78075 .20377 L
.7825 .21348 L
.78418 .22319 L
.78579 .23291 L
.78652 .23746 L
.78733 .24262 L
.78879 .25233 L
.79017 .26204 L
.79148 .27176 L
.79269 .28147 L
.79382 .29118 L
.79487 .30089 L
.79581 .31061 L
.79623 .31521 L
.79667 .32032 L
.79742 .33003 L
.79807 .33974 L
.79862 .34946 L
.79907 .35917 L
.7994 .36888 L
.79962 .37859 L
.79973 .38831 L
.79973 .39802 L
.7996 .40773 L
.79935 .41744 L
.79898 .42716 L
.79848 .43687 L
Mistroke
.79785 .44658 L
.79708 .45629 L
.79623 .4655 L
.79618 .46601 L
.79514 .47572 L
.79395 .48543 L
.79261 .49514 L
.79113 .50486 L
.78948 .51457 L
.78768 .52428 L
.78652 .53009 L
.78571 .53399 L
.78356 .54371 L
.78124 .55342 L
.77874 .56313 L
.77681 .57018 L
.77605 .57284 L
.77316 .58256 L
.77006 .59227 L
.76709 .601 L
.76675 .60198 L
.76321 .61169 L
.75944 .62141 L
.75738 .62647 L
.75543 .63112 L
.75115 .64083 L
.74767 .64831 L
.7466 .65054 L
.74175 .66026 L
.73796 .66746 L
.7366 .66997 L
.7311 .67968 L
.72824 .6845 L
.72525 .68939 L
.719 .69911 L
.71853 .69982 L
.71233 .70882 L
.70882 .71368 L
.70519 .71853 L
.69911 .72629 L
.69752 .72824 L
.68939 .73781 L
.68927 .73796 L
.68034 .74767 L
.67968 .74835 L
.67063 .75738 L
.66997 .75802 L
.66026 .76687 L
.66 .76709 L
.65054 .77499 L
Mistroke
.64825 .77681 L
.64083 .78243 L
.63509 .78652 L
.63112 .78922 L
.62141 .7954 L
.62003 .79623 L
.61169 .80102 L
.60226 .80594 L
.60198 .80608 L
.59227 .81063 L
.58256 .81467 L
.57999 .81566 L
.57284 .81822 L
.56313 .8213 L
.55342 .82392 L
.5472 .82537 L
.54371 .82609 L
.53399 .82782 L
.52428 .82911 L
.51457 .82997 L
.50486 .83039 L
.49514 .83039 L
.48543 .82997 L
.47572 .82911 L
.46601 .82782 L
.45629 .82609 L
.4528 .82537 L
.44658 .82392 L
.43687 .8213 L
.42716 .81822 L
.42001 .81566 L
.41744 .81467 L
.40773 .81063 L
.39802 .80608 L
.39774 .80594 L
.38831 .80102 L
.37997 .79623 L
.37859 .7954 L
.36888 .78922 L
.36491 .78652 L
.35917 .78243 L
.35175 .77681 L
.34946 .77499 L
.34 .76709 L
.33974 .76687 L
.33003 .75802 L
.32937 .75738 L
.32032 .74835 L
.31966 .74767 L
.31073 .73796 L
Mistroke
.31061 .73781 L
.30248 .72824 L
.30089 .72629 L
.29481 .71853 L
.29118 .71368 L
.28767 .70882 L
.28147 .69982 L
.281 .69911 L
.27475 .68939 L
.27176 .6845 L
.2689 .67968 L
.2634 .66997 L
.26204 .66746 L
.25825 .66026 L
.2534 .65054 L
.25233 .64831 L
.24885 .64083 L
.24457 .63112 L
.24262 .62647 L
.24056 .62141 L
.23679 .61169 L
.23325 .60198 L
.23291 .601 L
.22994 .59227 L
.22684 .58256 L
.22395 .57284 L
.22319 .57018 L
.22126 .56313 L
.21876 .55342 L
.21644 .54371 L
.21429 .53399 L
.21348 .53009 L
.21232 .52428 L
.21052 .51457 L
.20887 .50486 L
.20739 .49514 L
.20605 .48543 L
.20486 .47572 L
.20382 .46601 L
.20377 .4655 L
.20292 .45629 L
.20215 .44658 L
.20152 .43687 L
.20102 .42716 L
.20065 .41744 L
.2004 .40773 L
.20027 .39802 L
.20027 .38831 L
.20038 .37859 L
.2006 .36888 L
Mistroke
.20093 .35917 L
.20138 .34946 L
.20193 .33974 L
.20258 .33003 L
.20333 .32032 L
.20377 .31521 L
.20419 .31061 L
.20513 .30089 L
.20618 .29118 L
.20731 .28147 L
.20852 .27176 L
.20983 .26204 L
.21121 .25233 L
.21267 .24262 L
.21348 .23746 L
.21421 .23291 L
.21582 .22319 L
.2175 .21348 L
.21925 .20377 L
.22105 .19406 L
.22291 .18434 L
.22319 .18291 L
.22483 .17463 L
.2268 .16492 L
.22881 .15521 L
.23087 .14549 L
.23291 .13601 L
.23296 .13578 L
.23508 .12607 L
.23724 .11636 L
.23942 .10664 L
.24163 .09693 L
.24262 .09255 L
.24385 .08722 L
.24609 .07751 L
.24836 .06779 L
.25063 .05808 L
.25233 .05043 L
.25284 .04837 L
.25532 .03866 L
.26028 .02894 L
.2559 .01923 L
Mfstroke
.5 g
.74324 .01923 m
.73879 .02894 L
.74162 .03866 L
.74252 .04837 L
.74328 .05808 L
.74401 .06779 L
.74473 .07751 L
.74544 .08722 L
.74613 .09693 L
.7468 .10664 L
.74745 .11636 L
.74767 .11976 L
.74807 .12607 L
.74866 .13578 L
.74921 .14549 L
.74972 .15521 L
.75019 .16492 L
.7506 .17463 L
.75096 .18434 L
.75125 .19406 L
.75147 .20377 L
.75163 .21348 L
.7517 .22319 L
.75169 .23291 L
.75159 .24262 L
.7514 .25233 L
.75111 .26204 L
.75071 .27176 L
.7502 .28147 L
.74958 .29118 L
.74883 .30089 L
.74796 .31061 L
.74767 .3136 L
.74696 .32032 L
.74582 .33003 L
.74454 .33974 L
.7431 .34946 L
.74151 .35917 L
.73975 .36888 L
.73796 .37796 L
.73783 .37859 L
.73572 .38831 L
.73343 .39802 L
.73094 .40773 L
.72824 .41743 L
.72824 .41744 L
.72533 .42716 L
.72218 .43687 L
.7188 .44658 L
.71853 .44732 L
.71516 .45629 L
.71124 .46601 L
.70882 .47169 L
.70704 .47572 L
.70252 .48543 L
.69911 .49233 L
.69766 .49514 L
.69244 .50486 L
.68939 .51021 L
.68682 .51457 L
.68076 .52428 L
.67968 .52594 L
.67421 .53399 L
.66997 .5399 L
.66712 .54371 L
.66026 .55237 L
.65939 .55342 L
.65094 .56313 L
.65054 .56357 L
.64164 .57284 L
.64083 .57364 L
.63129 .58256 L
.63112 .58271 L
.62141 .59087 L
.61963 .59227 L
.61169 .59819 L
.60621 .60198 L
.60198 .60474 L
.59227 .61057 L
.59025 .61169 L
.58256 .61572 L
.57284 .62022 L
.57004 .62141 L
.56313 .6241 L
.55342 .6274 L
.54371 .63011 L
.53953 .63112 L
.53399 .63227 L
.52428 .63387 L
.51457 .63494 L
.50486 .63547 L
.49514 .63547 L
.48543 .63494 L
.47572 .63387 L
.46601 .63227 L
.46047 .63112 L
.45629 .63011 L
.44658 .6274 L
.43687 .6241 L
.42996 .62141 L
.42716 .62022 L
.41744 .61572 L
.40975 .61169 L
.40773 .61057 L
.39802 .60474 L
.39379 .60198 L
.38831 .59819 L
.38037 .59227 L
.37859 .59087 L
.36888 .58271 L
.36871 .58256 L
.35917 .57364 L
.35836 .57284 L
.34946 .56357 L
.34906 .56313 L
.34061 .55342 L
.33974 .55237 L
.33288 .54371 L
.33003 .5399 L
.32579 .53399 L
.32032 .52594 L
.31924 .52428 L
.31318 .51457 L
.31061 .51021 L
.30756 .50486 L
.30234 .49514 L
.30089 .49233 L
.29748 .48543 L
.29296 .47572 L
.29118 .47169 L
.28876 .46601 L
.28484 .45629 L
.28147 .44732 L
.2812 .44658 L
.27782 .43687 L
.27467 .42716 L
.27176 .41744 L
.27176 .41743 L
.26906 .40773 L
.26657 .39802 L
.26428 .38831 L
.26217 .37859 L
.26204 .37796 L
.26025 .36888 L
.25849 .35917 L
.2569 .34946 L
.25546 .33974 L
.25418 .33003 L
.25304 .32032 L
.25233 .3136 L
.25204 .31061 L
.25117 .30089 L
.25042 .29118 L
.2498 .28147 L
.24929 .27176 L
.24889 .26204 L
.2486 .25233 L
.24841 .24262 L
.24831 .23291 L
.2483 .22319 L
.24837 .21348 L
.24853 .20377 L
.24875 .19406 L
.24904 .18434 L
.2494 .17463 L
.24981 .16492 L
.25028 .15521 L
.25079 .14549 L
.25134 .13578 L
.25193 .12607 L
.25233 .11976 L
.25255 .11636 L
.2532 .10664 L
.25387 .09693 L
.25456 .08722 L
.25527 .07751 L
.25599 .06779 L
.25672 .05808 L
.25748 .04837 L
.25838 .03866 L
.26121 .02894 L
.25676 .01923 L
F
0 g
.74324 .01923 m
.73879 .02894 L
.74162 .03866 L
.74252 .04837 L
.74328 .05808 L
.74401 .06779 L
.74473 .07751 L
.74544 .08722 L
.74613 .09693 L
.7468 .10664 L
.74745 .11636 L
.74767 .11976 L
.74807 .12607 L
.74866 .13578 L
.74921 .14549 L
.74972 .15521 L
.75019 .16492 L
.7506 .17463 L
.75096 .18434 L
.75125 .19406 L
.75147 .20377 L
.75163 .21348 L
.7517 .22319 L
.75169 .23291 L
.75159 .24262 L
.7514 .25233 L
.75111 .26204 L
.75071 .27176 L
.7502 .28147 L
.74958 .29118 L
.74883 .30089 L
.74796 .31061 L
.74767 .3136 L
.74696 .32032 L
.74582 .33003 L
.74454 .33974 L
.7431 .34946 L
.74151 .35917 L
.73975 .36888 L
.73796 .37796 L
.73783 .37859 L
.73572 .38831 L
.73343 .39802 L
.73094 .40773 L
.72824 .41743 L
.72824 .41744 L
.72533 .42716 L
.72218 .43687 L
.7188 .44658 L
.71853 .44732 L
Mistroke
.71516 .45629 L
.71124 .46601 L
.70882 .47169 L
.70704 .47572 L
.70252 .48543 L
.69911 .49233 L
.69766 .49514 L
.69244 .50486 L
.68939 .51021 L
.68682 .51457 L
.68076 .52428 L
.67968 .52594 L
.67421 .53399 L
.66997 .5399 L
.66712 .54371 L
.66026 .55237 L
.65939 .55342 L
.65094 .56313 L
.65054 .56357 L
.64164 .57284 L
.64083 .57364 L
.63129 .58256 L
.63112 .58271 L
.62141 .59087 L
.61963 .59227 L
.61169 .59819 L
.60621 .60198 L
.60198 .60474 L
.59227 .61057 L
.59025 .61169 L
.58256 .61572 L
.57284 .62022 L
.57004 .62141 L
.56313 .6241 L
.55342 .6274 L
.54371 .63011 L
.53953 .63112 L
.53399 .63227 L
.52428 .63387 L
.51457 .63494 L
.50486 .63547 L
.49514 .63547 L
.48543 .63494 L
.47572 .63387 L
.46601 .63227 L
.46047 .63112 L
.45629 .63011 L
.44658 .6274 L
.43687 .6241 L
.42996 .62141 L
Mistroke
.42716 .62022 L
.41744 .61572 L
.40975 .61169 L
.40773 .61057 L
.39802 .60474 L
.39379 .60198 L
.38831 .59819 L
.38037 .59227 L
.37859 .59087 L
.36888 .58271 L
.36871 .58256 L
.35917 .57364 L
.35836 .57284 L
.34946 .56357 L
.34906 .56313 L
.34061 .55342 L
.33974 .55237 L
.33288 .54371 L
.33003 .5399 L
.32579 .53399 L
.32032 .52594 L
.31924 .52428 L
.31318 .51457 L
.31061 .51021 L
.30756 .50486 L
.30234 .49514 L
.30089 .49233 L
.29748 .48543 L
.29296 .47572 L
.29118 .47169 L
.28876 .46601 L
.28484 .45629 L
.28147 .44732 L
.2812 .44658 L
.27782 .43687 L
.27467 .42716 L
.27176 .41744 L
.27176 .41743 L
.26906 .40773 L
.26657 .39802 L
.26428 .38831 L
.26217 .37859 L
.26204 .37796 L
.26025 .36888 L
.25849 .35917 L
.2569 .34946 L
.25546 .33974 L
.25418 .33003 L
.25304 .32032 L
.25233 .3136 L
Mistroke
.25204 .31061 L
.25117 .30089 L
.25042 .29118 L
.2498 .28147 L
.24929 .27176 L
.24889 .26204 L
.2486 .25233 L
.24841 .24262 L
.24831 .23291 L
.2483 .22319 L
.24837 .21348 L
.24853 .20377 L
.24875 .19406 L
.24904 .18434 L
.2494 .17463 L
.24981 .16492 L
.25028 .15521 L
.25079 .14549 L
.25134 .13578 L
.25193 .12607 L
.25233 .11976 L
.25255 .11636 L
.2532 .10664 L
.25387 .09693 L
.25456 .08722 L
.25527 .07751 L
.25599 .06779 L
.25672 .05808 L
.25748 .04837 L
.25838 .03866 L
.26121 .02894 L
.25676 .01923 L
Mfstroke
.6 g
.74238 .01923 m
.73847 .02894 L
.73887 .03866 L
.73819 .04837 L
.73796 .05134 L
.73746 .05808 L
.73672 .06779 L
.73597 .07751 L
.73521 .08722 L
.73443 .09693 L
.73363 .10664 L
.73281 .11636 L
.73195 .12607 L
.73106 .13578 L
.73013 .14549 L
.72914 .15521 L
.72824 .16359 L
.7281 .16492 L
.72699 .17463 L
.72581 .18434 L
.72455 .19406 L
.7232 .20377 L
.72176 .21348 L
.72021 .22319 L
.71854 .23291 L
.71853 .23296 L
.71675 .24262 L
.71483 .25233 L
.71277 .26204 L
.71055 .27176 L
.70882 .27888 L
.70817 .28147 L
.70561 .29118 L
.70286 .30089 L
.69991 .31061 L
.69911 .31312 L
.69674 .32032 L
.69333 .33003 L
.68967 .33974 L
.68939 .34046 L
.68574 .34946 L
.68152 .35917 L
.67968 .36317 L
.67697 .36888 L
.67206 .37859 L
.66997 .38252 L
.66676 .38831 L
.66103 .39802 L
.66026 .39928 L
.65481 .40773 L
.65054 .41395 L
.64804 .41744 L
.64083 .4269 L
.64062 .42716 L
.63245 .43687 L
.63112 .43836 L
.62337 .44658 L
.62141 .44855 L
.61316 .45629 L
.61169 .45759 L
.60198 .4656 L
.60146 .46601 L
.59227 .47268 L
.58768 .47572 L
.58256 .47889 L
.57284 .48429 L
.57059 .48543 L
.56313 .48893 L
.55342 .49284 L
.54671 .49514 L
.54371 .49606 L
.53399 .49861 L
.52428 .50051 L
.51457 .50177 L
.50486 .50239 L
.49514 .50239 L
.48543 .50177 L
.47572 .50051 L
.46601 .49861 L
.45629 .49606 L
.45329 .49514 L
.44658 .49284 L
.43687 .48893 L
.42941 .48543 L
.42716 .48429 L
.41744 .47889 L
.41232 .47572 L
.40773 .47268 L
.39854 .46601 L
.39802 .4656 L
.38831 .45759 L
.38684 .45629 L
.37859 .44855 L
.37663 .44658 L
.36888 .43836 L
.36755 .43687 L
.35938 .42716 L
.35917 .4269 L
.35196 .41744 L
.34946 .41395 L
.34519 .40773 L
.33974 .39928 L
.33897 .39802 L
.33324 .38831 L
.33003 .38252 L
.32794 .37859 L
.32303 .36888 L
.32032 .36317 L
.31848 .35917 L
.31426 .34946 L
.31061 .34046 L
.31033 .33974 L
.30667 .33003 L
.30326 .32032 L
.30089 .31312 L
.30009 .31061 L
.29714 .30089 L
.29439 .29118 L
.29183 .28147 L
.29118 .27888 L
.28945 .27176 L
.28723 .26204 L
.28517 .25233 L
.28325 .24262 L
.28147 .23296 L
.28146 .23291 L
.27979 .22319 L
.27824 .21348 L
.2768 .20377 L
.27545 .19406 L
.27419 .18434 L
.27301 .17463 L
.2719 .16492 L
.27176 .16359 L
.27086 .15521 L
.26987 .14549 L
.26894 .13578 L
.26805 .12607 L
.26719 .11636 L
.26637 .10664 L
.26557 .09693 L
.26479 .08722 L
.26403 .07751 L
.26328 .06779 L
.26254 .05808 L
.26204 .05134 L
.26181 .04837 L
.26113 .03866 L
.26153 .02894 L
.25762 .01923 L
F
0 g
.74238 .01923 m
.73847 .02894 L
.73887 .03866 L
.73819 .04837 L
.73796 .05134 L
.73746 .05808 L
.73672 .06779 L
.73597 .07751 L
.73521 .08722 L
.73443 .09693 L
.73363 .10664 L
.73281 .11636 L
.73195 .12607 L
.73106 .13578 L
.73013 .14549 L
.72914 .15521 L
.72824 .16359 L
.7281 .16492 L
.72699 .17463 L
.72581 .18434 L
.72455 .19406 L
.7232 .20377 L
.72176 .21348 L
.72021 .22319 L
.71854 .23291 L
.71853 .23296 L
.71675 .24262 L
.71483 .25233 L
.71277 .26204 L
.71055 .27176 L
.70882 .27888 L
.70817 .28147 L
.70561 .29118 L
.70286 .30089 L
.69991 .31061 L
.69911 .31312 L
.69674 .32032 L
.69333 .33003 L
.68967 .33974 L
.68939 .34046 L
.68574 .34946 L
.68152 .35917 L
.67968 .36317 L
.67697 .36888 L
.67206 .37859 L
.66997 .38252 L
.66676 .38831 L
.66103 .39802 L
.66026 .39928 L
.65481 .40773 L
Mistroke
.65054 .41395 L
.64804 .41744 L
.64083 .4269 L
.64062 .42716 L
.63245 .43687 L
.63112 .43836 L
.62337 .44658 L
.62141 .44855 L
.61316 .45629 L
.61169 .45759 L
.60198 .4656 L
.60146 .46601 L
.59227 .47268 L
.58768 .47572 L
.58256 .47889 L
.57284 .48429 L
.57059 .48543 L
.56313 .48893 L
.55342 .49284 L
.54671 .49514 L
.54371 .49606 L
.53399 .49861 L
.52428 .50051 L
.51457 .50177 L
.50486 .50239 L
.49514 .50239 L
.48543 .50177 L
.47572 .50051 L
.46601 .49861 L
.45629 .49606 L
.45329 .49514 L
.44658 .49284 L
.43687 .48893 L
.42941 .48543 L
.42716 .48429 L
.41744 .47889 L
.41232 .47572 L
.40773 .47268 L
.39854 .46601 L
.39802 .4656 L
.38831 .45759 L
.38684 .45629 L
.37859 .44855 L
.37663 .44658 L
.36888 .43836 L
.36755 .43687 L
.35938 .42716 L
.35917 .4269 L
.35196 .41744 L
.34946 .41395 L
Mistroke
.34519 .40773 L
.33974 .39928 L
.33897 .39802 L
.33324 .38831 L
.33003 .38252 L
.32794 .37859 L
.32303 .36888 L
.32032 .36317 L
.31848 .35917 L
.31426 .34946 L
.31061 .34046 L
.31033 .33974 L
.30667 .33003 L
.30326 .32032 L
.30089 .31312 L
.30009 .31061 L
.29714 .30089 L
.29439 .29118 L
.29183 .28147 L
.29118 .27888 L
.28945 .27176 L
.28723 .26204 L
.28517 .25233 L
.28325 .24262 L
.28147 .23296 L
.28146 .23291 L
.27979 .22319 L
.27824 .21348 L
.2768 .20377 L
.27545 .19406 L
.27419 .18434 L
.27301 .17463 L
.2719 .16492 L
.27176 .16359 L
.27086 .15521 L
.26987 .14549 L
.26894 .13578 L
.26805 .12607 L
.26719 .11636 L
.26637 .10664 L
.26557 .09693 L
.26479 .08722 L
.26403 .07751 L
.26328 .06779 L
.26254 .05808 L
.26204 .05134 L
.26181 .04837 L
.26113 .03866 L
.26153 .02894 L
.25762 .01923 L
Mistroke
Mfstroke
.7 g
.74152 .01923 m
.73803 .02894 L
.73796 .02951 L
.73639 .03866 L
.73376 .04837 L
.73137 .05808 L
.72906 .06779 L
.72824 .07122 L
.72678 .07751 L
.72448 .08722 L
.72216 .09693 L
.71981 .10664 L
.71853 .11188 L
.71744 .11636 L
.71502 .12607 L
.71255 .13578 L
.71003 .14549 L
.70882 .15006 L
.70744 .15521 L
.70477 .16492 L
.702 .17463 L
.69913 .18434 L
.69911 .18444 L
.69615 .19406 L
.69303 .20377 L
.68977 .21348 L
.68939 .21457 L
.68634 .22319 L
.68273 .23291 L
.67968 .2407 L
.67891 .24262 L
.67487 .25233 L
.67057 .26204 L
.66997 .26336 L
.666 .27176 L
.66111 .28147 L
.66026 .28309 L
.65587 .29118 L
.65054 .30036 L
.65022 .30089 L
.64413 .31061 L
.64083 .31555 L
.63751 .32032 L
.63112 .32894 L
.63027 .33003 L
.62231 .33974 L
.62141 .34078 L
.61344 .34946 L
.61169 .35125 L
.60344 .35917 L
.60198 .36048 L
.59227 .36861 L
.59192 .36888 L
.58256 .37571 L
.5782 .37859 L
.57284 .38188 L
.56313 .38715 L
.56079 .38831 L
.55342 .3916 L
.54371 .39525 L
.53445 .39802 L
.53399 .39814 L
.52428 .40028 L
.51457 .4017 L
.50486 .40241 L
.49514 .40241 L
.48543 .4017 L
.47572 .40028 L
.46601 .39814 L
.46555 .39802 L
.45629 .39525 L
.44658 .3916 L
.43921 .38831 L
.43687 .38715 L
.42716 .38188 L
.4218 .37859 L
.41744 .37571 L
.40808 .36888 L
.40773 .36861 L
.39802 .36048 L
.39656 .35917 L
.38831 .35125 L
.38656 .34946 L
.37859 .34078 L
.37769 .33974 L
.36973 .33003 L
.36888 .32894 L
.36249 .32032 L
.35917 .31555 L
.35587 .31061 L
.34978 .30089 L
.34946 .30036 L
.34413 .29118 L
.33974 .28309 L
.33889 .28147 L
.334 .27176 L
.33003 .26336 L
.32943 .26204 L
.32513 .25233 L
.32109 .24262 L
.32032 .2407 L
.31727 .23291 L
.31366 .22319 L
.31061 .21457 L
.31023 .21348 L
.30697 .20377 L
.30385 .19406 L
.30089 .18444 L
.30087 .18434 L
.298 .17463 L
.29523 .16492 L
.29256 .15521 L
.29118 .15006 L
.28997 .14549 L
.28745 .13578 L
.28498 .12607 L
.28256 .11636 L
.28147 .11188 L
.28019 .10664 L
.27784 .09693 L
.27552 .08722 L
.27322 .07751 L
.27176 .07122 L
.27094 .06779 L
.26863 .05808 L
.26624 .04837 L
.26361 .03866 L
.26204 .02951 L
.26197 .02894 L
.25848 .01923 L
F
0 g
.74152 .01923 m
.73803 .02894 L
.73796 .02951 L
.73639 .03866 L
.73376 .04837 L
.73137 .05808 L
.72906 .06779 L
.72824 .07122 L
.72678 .07751 L
.72448 .08722 L
.72216 .09693 L
.71981 .10664 L
.71853 .11188 L
.71744 .11636 L
.71502 .12607 L
.71255 .13578 L
.71003 .14549 L
.70882 .15006 L
.70744 .15521 L
.70477 .16492 L
.702 .17463 L
.69913 .18434 L
.69911 .18444 L
.69615 .19406 L
.69303 .20377 L
.68977 .21348 L
.68939 .21457 L
.68634 .22319 L
.68273 .23291 L
.67968 .2407 L
.67891 .24262 L
.67487 .25233 L
.67057 .26204 L
.66997 .26336 L
.666 .27176 L
.66111 .28147 L
.66026 .28309 L
.65587 .29118 L
.65054 .30036 L
.65022 .30089 L
.64413 .31061 L
.64083 .31555 L
.63751 .32032 L
.63112 .32894 L
.63027 .33003 L
.62231 .33974 L
.62141 .34078 L
.61344 .34946 L
.61169 .35125 L
.60344 .35917 L
Mistroke
.60198 .36048 L
.59227 .36861 L
.59192 .36888 L
.58256 .37571 L
.5782 .37859 L
.57284 .38188 L
.56313 .38715 L
.56079 .38831 L
.55342 .3916 L
.54371 .39525 L
.53445 .39802 L
.53399 .39814 L
.52428 .40028 L
.51457 .4017 L
.50486 .40241 L
.49514 .40241 L
.48543 .4017 L
.47572 .40028 L
.46601 .39814 L
.46555 .39802 L
.45629 .39525 L
.44658 .3916 L
.43921 .38831 L
.43687 .38715 L
.42716 .38188 L
.4218 .37859 L
.41744 .37571 L
.40808 .36888 L
.40773 .36861 L
.39802 .36048 L
.39656 .35917 L
.38831 .35125 L
.38656 .34946 L
.37859 .34078 L
.37769 .33974 L
.36973 .33003 L
.36888 .32894 L
.36249 .32032 L
.35917 .31555 L
.35587 .31061 L
.34978 .30089 L
.34946 .30036 L
.34413 .29118 L
.33974 .28309 L
.33889 .28147 L
.334 .27176 L
.33003 .26336 L
.32943 .26204 L
.32513 .25233 L
.32109 .24262 L
Mistroke
.32032 .2407 L
.31727 .23291 L
.31366 .22319 L
.31061 .21457 L
.31023 .21348 L
.30697 .20377 L
.30385 .19406 L
.30089 .18444 L
.30087 .18434 L
.298 .17463 L
.29523 .16492 L
.29256 .15521 L
.29118 .15006 L
.28997 .14549 L
.28745 .13578 L
.28498 .12607 L
.28256 .11636 L
.28147 .11188 L
.28019 .10664 L
.27784 .09693 L
.27552 .08722 L
.27322 .07751 L
.27176 .07122 L
.27094 .06779 L
.26863 .05808 L
.26624 .04837 L
.26361 .03866 L
.26204 .02951 L
.26197 .02894 L
.25848 .01923 L
Mfstroke
.8 g
.74064 .01923 m
.73796 .02531 L
.73575 .02894 L
.73298 .03866 L
.72824 .04837 L
.72824 .04837 L
.72431 .05808 L
.72015 .06779 L
.71853 .07159 L
.71608 .07751 L
.71198 .08722 L
.70882 .09462 L
.70784 .09693 L
.70369 .10664 L
.69947 .11636 L
.69911 .11719 L
.69521 .12607 L
.69086 .13578 L
.68939 .139 L
.68642 .14549 L
.68187 .15521 L
.67968 .15979 L
.67719 .16492 L
.67235 .17463 L
.66997 .17929 L
.66733 .18434 L
.6621 .19406 L
.66026 .19736 L
.65661 .20377 L
.65082 .21348 L
.65054 .21394 L
.6447 .22319 L
.64083 .22902 L
.63817 .23291 L
.63115 .24262 L
.63112 .24266 L
.62356 .25233 L
.62141 .25493 L
.61525 .26204 L
.61169 .26592 L
.60604 .27176 L
.60198 .2757 L
.59566 .28147 L
.59227 .28437 L
.58364 .29118 L
.58256 .29198 L
.57284 .2986 L
.56913 .30089 L
.56313 .30429 L
.55342 .30909 L
.54994 .31061 L
.54371 .31303 L
.53399 .31615 L
.52428 .31847 L
.51457 .32001 L
.51169 .32032 L
.50486 .32078 L
.49514 .32078 L
.48831 .32032 L
.48543 .32001 L
.47572 .31847 L
.46601 .31615 L
.45629 .31303 L
.45006 .31061 L
.44658 .30909 L
.43687 .30429 L
.43087 .30089 L
.42716 .2986 L
.41744 .29198 L
.41636 .29118 L
.40773 .28437 L
.40434 .28147 L
.39802 .2757 L
.39396 .27176 L
.38831 .26592 L
.38475 .26204 L
.37859 .25493 L
.37644 .25233 L
.36888 .24266 L
.36885 .24262 L
.36183 .23291 L
.35917 .22902 L
.3553 .22319 L
.34946 .21394 L
.34918 .21348 L
.34339 .20377 L
.33974 .19736 L
.3379 .19406 L
.33267 .18434 L
.33003 .17929 L
.32765 .17463 L
.32281 .16492 L
.32032 .15979 L
.31813 .15521 L
.31358 .14549 L
.31061 .139 L
.30914 .13578 L
.30479 .12607 L
.30089 .11719 L
.30053 .11636 L
.29631 .10664 L
.29216 .09693 L
.29118 .09462 L
.28802 .08722 L
.28392 .07751 L
.28147 .07159 L
.27985 .06779 L
.27569 .05808 L
.27176 .04837 L
.27176 .04837 L
.26702 .03866 L
.26425 .02894 L
.26204 .02531 L
.25936 .01923 L
F
0 g
.74064 .01923 m
.73796 .02531 L
.73575 .02894 L
.73298 .03866 L
.72824 .04837 L
.72824 .04837 L
.72431 .05808 L
.72015 .06779 L
.71853 .07159 L
.71608 .07751 L
.71198 .08722 L
.70882 .09462 L
.70784 .09693 L
.70369 .10664 L
.69947 .11636 L
.69911 .11719 L
.69521 .12607 L
.69086 .13578 L
.68939 .139 L
.68642 .14549 L
.68187 .15521 L
.67968 .15979 L
.67719 .16492 L
.67235 .17463 L
.66997 .17929 L
.66733 .18434 L
.6621 .19406 L
.66026 .19736 L
.65661 .20377 L
.65082 .21348 L
.65054 .21394 L
.6447 .22319 L
.64083 .22902 L
.63817 .23291 L
.63115 .24262 L
.63112 .24266 L
.62356 .25233 L
.62141 .25493 L
.61525 .26204 L
.61169 .26592 L
.60604 .27176 L
.60198 .2757 L
.59566 .28147 L
.59227 .28437 L
.58364 .29118 L
.58256 .29198 L
.57284 .2986 L
.56913 .30089 L
.56313 .30429 L
.55342 .30909 L
Mistroke
.54994 .31061 L
.54371 .31303 L
.53399 .31615 L
.52428 .31847 L
.51457 .32001 L
.51169 .32032 L
.50486 .32078 L
.49514 .32078 L
.48831 .32032 L
.48543 .32001 L
.47572 .31847 L
.46601 .31615 L
.45629 .31303 L
.45006 .31061 L
.44658 .30909 L
.43687 .30429 L
.43087 .30089 L
.42716 .2986 L
.41744 .29198 L
.41636 .29118 L
.40773 .28437 L
.40434 .28147 L
.39802 .2757 L
.39396 .27176 L
.38831 .26592 L
.38475 .26204 L
.37859 .25493 L
.37644 .25233 L
.36888 .24266 L
.36885 .24262 L
.36183 .23291 L
.35917 .22902 L
.3553 .22319 L
.34946 .21394 L
.34918 .21348 L
.34339 .20377 L
.33974 .19736 L
.3379 .19406 L
.33267 .18434 L
.33003 .17929 L
.32765 .17463 L
.32281 .16492 L
.32032 .15979 L
.31813 .15521 L
.31358 .14549 L
.31061 .139 L
.30914 .13578 L
.30479 .12607 L
.30089 .11719 L
.30053 .11636 L
Mistroke
.29631 .10664 L
.29216 .09693 L
.29118 .09462 L
.28802 .08722 L
.28392 .07751 L
.28147 .07159 L
.27985 .06779 L
.27569 .05808 L
.27176 .04837 L
.27176 .04837 L
.26702 .03866 L
.26425 .02894 L
.26204 .02531 L
.25936 .01923 L
Mfstroke
.9 g
.73972 .01923 m
.73796 .02261 L
.73282 .02894 L
.72824 .03765 L
.72742 .03866 L
.72116 .04837 L
.71853 .05198 L
.71463 .05808 L
.70882 .06652 L
.708 .06779 L
.70147 .07751 L
.69911 .08097 L
.69491 .08722 L
.68939 .09529 L
.68828 .09693 L
.6816 .10664 L
.67968 .10939 L
.67482 .11636 L
.66997 .1232 L
.66792 .12607 L
.66085 .13578 L
.66026 .13659 L
.65359 .14549 L
.65054 .14946 L
.64606 .15521 L
.64083 .16172 L
.63821 .16492 L
.63112 .17328 L
.62994 .17463 L
.62141 .18406 L
.62114 .18434 L
.61169 .19402 L
.61166 .19406 L
.60198 .20313 L
.60127 .20377 L
.59227 .21137 L
.58961 .21348 L
.58256 .21874 L
.57606 .22319 L
.57284 .22525 L
.56313 .2309 L
.55931 .23291 L
.55342 .23571 L
.54371 .2397 L
.53487 .24262 L
.53399 .24287 L
.52428 .24523 L
.51457 .24681 L
.50486 .24759 L
.49514 .24759 L
.48543 .24681 L
.47572 .24523 L
.46601 .24287 L
.46513 .24262 L
.45629 .2397 L
.44658 .23571 L
.44069 .23291 L
.43687 .2309 L
.42716 .22525 L
.42394 .22319 L
.41744 .21874 L
.41039 .21348 L
.40773 .21137 L
.39873 .20377 L
.39802 .20313 L
.38834 .19406 L
.38831 .19402 L
.37886 .18434 L
.37859 .18406 L
.37006 .17463 L
.36888 .17328 L
.36179 .16492 L
.35917 .16172 L
.35394 .15521 L
.34946 .14946 L
.34641 .14549 L
.33974 .13659 L
.33915 .13578 L
.33208 .12607 L
.33003 .1232 L
.32518 .11636 L
.32032 .10939 L
.3184 .10664 L
.31172 .09693 L
.31061 .09529 L
.30509 .08722 L
.30089 .08097 L
.29853 .07751 L
.292 .06779 L
.29118 .06652 L
.28537 .05808 L
.28147 .05198 L
.27884 .04837 L
.27258 .03866 L
.27176 .03765 L
.26718 .02894 L
.26204 .02261 L
.26028 .01923 L
F
0 g
.73972 .01923 m
.73796 .02261 L
.73282 .02894 L
.72824 .03765 L
.72742 .03866 L
.72116 .04837 L
.71853 .05198 L
.71463 .05808 L
.70882 .06652 L
.708 .06779 L
.70147 .07751 L
.69911 .08097 L
.69491 .08722 L
.68939 .09529 L
.68828 .09693 L
.6816 .10664 L
.67968 .10939 L
.67482 .11636 L
.66997 .1232 L
.66792 .12607 L
.66085 .13578 L
.66026 .13659 L
.65359 .14549 L
.65054 .14946 L
.64606 .15521 L
.64083 .16172 L
.63821 .16492 L
.63112 .17328 L
.62994 .17463 L
.62141 .18406 L
.62114 .18434 L
.61169 .19402 L
.61166 .19406 L
.60198 .20313 L
.60127 .20377 L
.59227 .21137 L
.58961 .21348 L
.58256 .21874 L
.57606 .22319 L
.57284 .22525 L
.56313 .2309 L
.55931 .23291 L
.55342 .23571 L
.54371 .2397 L
.53487 .24262 L
.53399 .24287 L
.52428 .24523 L
.51457 .24681 L
.50486 .24759 L
.49514 .24759 L
Mistroke
.48543 .24681 L
.47572 .24523 L
.46601 .24287 L
.46513 .24262 L
.45629 .2397 L
.44658 .23571 L
.44069 .23291 L
.43687 .2309 L
.42716 .22525 L
.42394 .22319 L
.41744 .21874 L
.41039 .21348 L
.40773 .21137 L
.39873 .20377 L
.39802 .20313 L
.38834 .19406 L
.38831 .19402 L
.37886 .18434 L
.37859 .18406 L
.37006 .17463 L
.36888 .17328 L
.36179 .16492 L
.35917 .16172 L
.35394 .15521 L
.34946 .14946 L
.34641 .14549 L
.33974 .13659 L
.33915 .13578 L
.33208 .12607 L
.33003 .1232 L
.32518 .11636 L
.32032 .10939 L
.3184 .10664 L
.31172 .09693 L
.31061 .09529 L
.30509 .08722 L
.30089 .08097 L
.29853 .07751 L
.292 .06779 L
.29118 .06652 L
.28537 .05808 L
.28147 .05198 L
.27884 .04837 L
.27258 .03866 L
.27176 .03765 L
.26718 .02894 L
.26204 .02261 L
.26028 .01923 L
Mfstroke
1 g
.73874 .01923 m
.73796 .02053 L
.72884 .02894 L
.72824 .03017 L
.71853 .03826 L
.71811 .03866 L
.70882 .04688 L
.70716 .04837 L
.69911 .05522 L
.69587 .05808 L
.68939 .0636 L
.68458 .06779 L
.67968 .07196 L
.67324 .07751 L
.66997 .08027 L
.66178 .08722 L
.66026 .08849 L
.65054 .09659 L
.65013 .09693 L
.64083 .10452 L
.6382 .10664 L
.63112 .11224 L
.62581 .11636 L
.62141 .11969 L
.61275 .12607 L
.61169 .12682 L
.60198 .13358 L
.59868 .13578 L
.59227 .13989 L
.58295 .14549 L
.58256 .14572 L
.57284 .15101 L
.56426 .15521 L
.56313 .15572 L
.55342 .15982 L
.54371 .16327 L
.53832 .16492 L
.53399 .16606 L
.52428 .16816 L
.51457 .16957 L
.50486 .17028 L
.49514 .17028 L
.48543 .16957 L
.47572 .16816 L
.46601 .16606 L
.46168 .16492 L
.45629 .16327 L
.44658 .15982 L
.43687 .15572 L
.43574 .15521 L
.42716 .15101 L
.41744 .14572 L
.41705 .14549 L
.40773 .13989 L
.40132 .13578 L
.39802 .13358 L
.38831 .12682 L
.38725 .12607 L
.37859 .11969 L
.37419 .11636 L
.36888 .11224 L
.3618 .10664 L
.35917 .10452 L
.34987 .09693 L
.34946 .09659 L
.33974 .08849 L
.33822 .08722 L
.33003 .08027 L
.32676 .07751 L
.32032 .07196 L
.31542 .06779 L
.31061 .0636 L
.30413 .05808 L
.30089 .05522 L
.29284 .04837 L
.29118 .04688 L
.28189 .03866 L
.28147 .03826 L
.27176 .03017 L
.27116 .02894 L
.26204 .02053 L
.26126 .01923 L
F
0 g
.73874 .01923 m
.73796 .02053 L
.72884 .02894 L
.72824 .03017 L
.71853 .03826 L
.71811 .03866 L
.70882 .04688 L
.70716 .04837 L
.69911 .05522 L
.69587 .05808 L
.68939 .0636 L
.68458 .06779 L
.67968 .07196 L
.67324 .07751 L
.66997 .08027 L
.66178 .08722 L
.66026 .08849 L
.65054 .09659 L
.65013 .09693 L
.64083 .10452 L
.6382 .10664 L
.63112 .11224 L
.62581 .11636 L
.62141 .11969 L
.61275 .12607 L
.61169 .12682 L
.60198 .13358 L
.59868 .13578 L
.59227 .13989 L
.58295 .14549 L
.58256 .14572 L
.57284 .15101 L
.56426 .15521 L
.56313 .15572 L
.55342 .15982 L
.54371 .16327 L
.53832 .16492 L
.53399 .16606 L
.52428 .16816 L
.51457 .16957 L
.50486 .17028 L
.49514 .17028 L
.48543 .16957 L
.47572 .16816 L
.46601 .16606 L
.46168 .16492 L
.45629 .16327 L
.44658 .15982 L
.43687 .15572 L
.43574 .15521 L
Mistroke
.42716 .15101 L
.41744 .14572 L
.41705 .14549 L
.40773 .13989 L
.40132 .13578 L
.39802 .13358 L
.38831 .12682 L
.38725 .12607 L
.37859 .11969 L
.37419 .11636 L
.36888 .11224 L
.3618 .10664 L
.35917 .10452 L
.34987 .09693 L
.34946 .09659 L
.33974 .08849 L
.33822 .08722 L
.33003 .08027 L
.32676 .07751 L
.32032 .07196 L
.31542 .06779 L
.31061 .0636 L
.30413 .05808 L
.30089 .05522 L
.29284 .04837 L
.29118 .04688 L
.28189 .03866 L
.28147 .03826 L
.27176 .03017 L
.27116 .02894 L
.26204 .02053 L
.26126 .01923 L
Mfstroke
.2 g
.79339 .98077 m
.79623 .9764 L
.79962 .97106 L
.80555 .96134 L
.80594 .96069 L
.8112 .95163 L
.81566 .94362 L
.81658 .94192 L
.8217 .93221 L
.82537 .92496 L
.82659 .92249 L
.83124 .91278 L
.83508 .90438 L
.83567 .90307 L
.83989 .89336 L
.8439 .88364 L
.84479 .88143 L
.84773 .87393 L
.85136 .86422 L
.85451 .8554 L
.85482 .85451 L
.8581 .84479 L
.86121 .83508 L
.86415 .82537 L
.86422 .82514 L
.86694 .81566 L
.86957 .80594 L
.87204 .79623 L
.87393 .78842 L
.87438 .78652 L
.87656 .77681 L
.87861 .76709 L
.88052 .75738 L
.88229 .74767 L
.88364 .73975 L
.88394 .73796 L
.88545 .72824 L
.88684 .71853 L
.8881 .70882 L
.88924 .69911 L
.89026 .68939 L
.89116 .67968 L
.89195 .66997 L
.89261 .66026 L
.89317 .65054 L
.89336 .64679 L
.89361 .64083 L
.89395 .63112 L
.89417 .62141 L
.89429 .61169 L
.8943 .60198 L
.8942 .59227 L
.894 .58256 L
.8937 .57284 L
.89336 .56436 L
.8933 .56313 L
.89279 .55342 L
.89219 .54371 L
.89148 .53399 L
.89068 .52428 L
.88978 .51457 L
.88878 .50486 L
.88769 .49514 L
.8865 .48543 L
.88522 .47572 L
.88384 .46601 L
.88364 .46467 L
.88237 .45629 L
.88081 .44658 L
.87916 .43687 L
.87742 .42716 L
.87558 .41744 L
.87393 .40906 L
.87366 .40773 L
.87165 .39802 L
.86956 .38831 L
.86737 .37859 L
.8651 .36888 L
.86422 .36518 L
.86275 .35917 L
.86031 .34946 L
.85779 .33974 L
.85519 .33003 L
.85451 .32753 L
.85251 .32032 L
.84974 .31061 L
.8469 .30089 L
.84479 .29384 L
.84399 .29118 L
.84099 .28147 L
.83793 .27176 L
.83508 .26294 L
.83479 .26204 L
.83158 .25233 L
.8283 .24262 L
.82537 .2341 L
.82495 .23291 L
.82154 .22319 L
.81807 .21348 L
.81566 .20682 L
.81454 .20377 L
.81095 .19406 L
.80731 .18434 L
.80594 .18073 L
.80362 .17463 L
.79987 .16492 L
.79623 .15556 L
.79609 .15521 L
.79226 .14549 L
.78839 .13578 L
.78652 .13109 L
.78449 .12607 L
.78056 .11636 L
.77681 .10712 L
.77661 .10664 L
.77262 .09693 L
.76862 .08722 L
.76709 .08348 L
.7646 .07751 L
.76053 .06779 L
.75738 .06003 L
.75654 .05808 L
.75225 .04837 L
.74806 .03866 L
.74767 .0366 L
.74196 .02894 L
.74499 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.79339 .98077 m
.79623 .9764 L
.79962 .97106 L
.80555 .96134 L
.80594 .96069 L
.8112 .95163 L
.81566 .94362 L
.81658 .94192 L
.8217 .93221 L
.82537 .92496 L
.82659 .92249 L
.83124 .91278 L
.83508 .90438 L
.83567 .90307 L
.83989 .89336 L
.8439 .88364 L
.84479 .88143 L
.84773 .87393 L
.85136 .86422 L
.85451 .8554 L
.85482 .85451 L
.8581 .84479 L
.86121 .83508 L
.86415 .82537 L
.86422 .82514 L
.86694 .81566 L
.86957 .80594 L
.87204 .79623 L
.87393 .78842 L
.87438 .78652 L
.87656 .77681 L
.87861 .76709 L
.88052 .75738 L
.88229 .74767 L
.88364 .73975 L
.88394 .73796 L
.88545 .72824 L
.88684 .71853 L
.8881 .70882 L
.88924 .69911 L
.89026 .68939 L
.89116 .67968 L
.89195 .66997 L
.89261 .66026 L
.89317 .65054 L
.89336 .64679 L
.89361 .64083 L
.89395 .63112 L
.89417 .62141 L
.89429 .61169 L
Mistroke
.8943 .60198 L
.8942 .59227 L
.894 .58256 L
.8937 .57284 L
.89336 .56436 L
.8933 .56313 L
.89279 .55342 L
.89219 .54371 L
.89148 .53399 L
.89068 .52428 L
.88978 .51457 L
.88878 .50486 L
.88769 .49514 L
.8865 .48543 L
.88522 .47572 L
.88384 .46601 L
.88364 .46467 L
.88237 .45629 L
.88081 .44658 L
.87916 .43687 L
.87742 .42716 L
.87558 .41744 L
.87393 .40906 L
.87366 .40773 L
.87165 .39802 L
.86956 .38831 L
.86737 .37859 L
.8651 .36888 L
.86422 .36518 L
.86275 .35917 L
.86031 .34946 L
.85779 .33974 L
.85519 .33003 L
.85451 .32753 L
.85251 .32032 L
.84974 .31061 L
.8469 .30089 L
.84479 .29384 L
.84399 .29118 L
.84099 .28147 L
.83793 .27176 L
.83508 .26294 L
.83479 .26204 L
.83158 .25233 L
.8283 .24262 L
.82537 .2341 L
.82495 .23291 L
.82154 .22319 L
.81807 .21348 L
.81566 .20682 L
Mistroke
.81454 .20377 L
.81095 .19406 L
.80731 .18434 L
.80594 .18073 L
.80362 .17463 L
.79987 .16492 L
.79623 .15556 L
.79609 .15521 L
.79226 .14549 L
.78839 .13578 L
.78652 .13109 L
.78449 .12607 L
.78056 .11636 L
.77681 .10712 L
.77661 .10664 L
.77262 .09693 L
.76862 .08722 L
.76709 .08348 L
.7646 .07751 L
.76053 .06779 L
.75738 .06003 L
.75654 .05808 L
.75225 .04837 L
.74806 .03866 L
.74767 .0366 L
.74196 .02894 L
.74499 .01923 L
Mfstroke
.1 g
.98077 .43331 m
.97806 .42716 L
.97373 .41744 L
.97106 .41152 L
.96933 .40773 L
.96485 .39802 L
.96134 .39052 L
.9603 .38831 L
.95568 .37859 L
.95163 .37022 L
.95098 .36888 L
.94621 .35917 L
.94192 .35056 L
.94136 .34946 L
.93644 .33974 L
.93221 .33149 L
.93145 .33003 L
.92639 .32032 L
.92249 .31295 L
.92125 .31061 L
.91604 .30089 L
.91278 .29489 L
.91076 .29118 L
.9054 .28147 L
.90307 .27727 L
.89998 .27176 L
.89449 .26204 L
.89336 .26006 L
.88892 .25233 L
.88364 .24322 L
.8833 .24262 L
.8776 .23291 L
.87393 .22671 L
.87184 .22319 L
.86601 .21348 L
.86422 .21051 L
.86013 .20377 L
.85451 .19458 L
.85418 .19406 L
.84818 .18434 L
.84479 .1789 L
.84212 .17463 L
.83601 .16492 L
.83508 .16345 L
.82985 .15521 L
.82537 .14819 L
.82364 .14549 L
.81739 .13578 L
.81566 .1331 L
.81109 .12607 L
.80594 .11815 L
.80477 .11636 L
.7984 .10664 L
.79623 .10332 L
.792 .09693 L
.78652 .08859 L
.7856 .08722 L
.77914 .07751 L
.77681 .07392 L
.77266 .06779 L
.76709 .05931 L
.76624 .05808 L
.75949 .04837 L
.75738 .04472 L
.7524 .03866 L
.74767 .03009 L
.74623 .02894 L
.7459 .01923 L
.98077 .01923 L
F
0 g
.98077 .43331 m
.97806 .42716 L
.97373 .41744 L
.97106 .41152 L
.96933 .40773 L
.96485 .39802 L
.96134 .39052 L
.9603 .38831 L
.95568 .37859 L
.95163 .37022 L
.95098 .36888 L
.94621 .35917 L
.94192 .35056 L
.94136 .34946 L
.93644 .33974 L
.93221 .33149 L
.93145 .33003 L
.92639 .32032 L
.92249 .31295 L
.92125 .31061 L
.91604 .30089 L
.91278 .29489 L
.91076 .29118 L
.9054 .28147 L
.90307 .27727 L
.89998 .27176 L
.89449 .26204 L
.89336 .26006 L
.88892 .25233 L
.88364 .24322 L
.8833 .24262 L
.8776 .23291 L
.87393 .22671 L
.87184 .22319 L
.86601 .21348 L
.86422 .21051 L
.86013 .20377 L
.85451 .19458 L
.85418 .19406 L
.84818 .18434 L
.84479 .1789 L
.84212 .17463 L
.83601 .16492 L
.83508 .16345 L
.82985 .15521 L
.82537 .14819 L
.82364 .14549 L
.81739 .13578 L
.81566 .1331 L
.81109 .12607 L
Mistroke
.80594 .11815 L
.80477 .11636 L
.7984 .10664 L
.79623 .10332 L
.792 .09693 L
.78652 .08859 L
.7856 .08722 L
.77914 .07751 L
.77681 .07392 L
.77266 .06779 L
.76709 .05931 L
.76624 .05808 L
.75949 .04837 L
.75738 .04472 L
.7524 .03866 L
.74767 .03009 L
.74623 .02894 L
.7459 .01923 L
Mfstroke
.98077 .23665 m
.97692 .23291 L
.97106 .22724 L
.96686 .22319 L
.96134 .21789 L
.95673 .21348 L
.95163 .20862 L
.94651 .20377 L
.94192 .19942 L
.93622 .19406 L
.93221 .19029 L
.92584 .18434 L
.92249 .18123 L
.91538 .17463 L
.91278 .17222 L
.90485 .16492 L
.90307 .16328 L
.89425 .15521 L
.89336 .15439 L
.88364 .14556 L
.88357 .14549 L
.87393 .13678 L
.87282 .13578 L
.86422 .12805 L
.86201 .12607 L
.85451 .11936 L
.85113 .11636 L
.84479 .11071 L
.8402 .10664 L
.83508 .1021 L
.82922 .09693 L
.82537 .09352 L
.8182 .08722 L
.81566 .08497 L
.80714 .07751 L
.80594 .07645 L
.79623 .06794 L
.79607 .06779 L
.78652 .05946 L
.78489 .05808 L
.77681 .05101 L
.77358 .04837 L
.76709 .0427 L
.76251 .03866 L
.75738 .03609 L
.75123 .02894 L
.74767 .02515 L
.74688 .01923 L
.98077 .01923 L
F
.98077 .23665 m
.97692 .23291 L
.97106 .22724 L
.96686 .22319 L
.96134 .21789 L
.95673 .21348 L
.95163 .20862 L
.94651 .20377 L
.94192 .19942 L
.93622 .19406 L
.93221 .19029 L
.92584 .18434 L
.92249 .18123 L
.91538 .17463 L
.91278 .17222 L
.90485 .16492 L
.90307 .16328 L
.89425 .15521 L
.89336 .15439 L
.88364 .14556 L
.88357 .14549 L
.87393 .13678 L
.87282 .13578 L
.86422 .12805 L
.86201 .12607 L
.85451 .11936 L
.85113 .11636 L
.84479 .11071 L
.8402 .10664 L
.83508 .1021 L
.82922 .09693 L
.82537 .09352 L
.8182 .08722 L
.81566 .08497 L
.80714 .07751 L
.80594 .07645 L
.79623 .06794 L
.79607 .06779 L
.78652 .05946 L
.78489 .05808 L
.77681 .05101 L
.77358 .04837 L
.76709 .0427 L
.76251 .03866 L
.75738 .03609 L
.75123 .02894 L
.74767 .02515 L
.74688 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 288},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.2447, -0.268382, 0.0151512, \
0.0151512}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "ContourGraphics", "\[SkeletonIndicator]"}],
  
  False,
  Editable->False]], "Output"]
}, Open  ]]
},
WindowSize->{496, 574},
WindowMargins->{{43, Automatic}, {Automatic, 17}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 331, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 76, 1, 32, "Input"],
Cell[1410, 41, 97, 1, 31, "Output"]
}, Open  ]],
Cell[1522, 45, 61, 1, 32, "Input"],
Cell[1586, 48, 73, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[1684, 53, 137, 3, 32, "Input"],
Cell[1824, 58, 96, 2, 31, "Output"]
}, Open  ]],
Cell[1935, 63, 372, 11, 55, "Input"],
Cell[CellGroupData[{
Cell[2332, 78, 514, 17, 55, "Input"],
Cell[2849, 97, 295, 10, 47, "Output"]
}, Open  ]],
Cell[3159, 110, 687, 20, 99, "Input"],
Cell[3849, 132, 254, 8, 32, "Input"],
Cell[CellGroupData[{
Cell[4128, 144, 393, 11, 77, "Input"],
Cell[4524, 157, 58471, 3513, 296, 51766, 3399, "GraphicsData", "PostScript", \
"Graphics"],
Cell[62998, 3672, 144, 5, 29, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

