(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      7323,        237]
NotebookOptionsPosition[      6747,        213]
NotebookOutlinePosition[      7191,        231]
CellTagsIndexPosition[      7148,        228]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["Create the isotropic compliance 4-tensor", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"IsotropicCompliance", "[", 
   RowBox[{"Y_", ",", "nu_"}], "]"}], ":=", " ", 
  RowBox[{"Array", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "nu"}], "/", "Y"}], " ", 
       RowBox[{"KroneckerDelta", "[", 
        RowBox[{"#1", ",", "#2"}], "]"}], " ", 
       RowBox[{"KroneckerDelta", "[", 
        RowBox[{"#3", ",", "#4"}], "]"}]}], " ", "+", "\[IndentingNewLine]", 
      "                 ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", "/", "2"}], "/", "Y"}], 
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"KroneckerDelta", "[", 
           RowBox[{"#1", ",", "#3"}], "]"}], " ", 
          RowBox[{"KroneckerDelta", "[", 
           RowBox[{"#2", ",", "#4"}], "]"}]}], "+", " ", 
         RowBox[{
          RowBox[{"KroneckerDelta", "[", 
           RowBox[{"#1", ",", "#4"}], "]"}], 
          RowBox[{"KroneckerDelta", "[", 
           RowBox[{"#2", ",", "#3"}], "]"}]}]}], ")"}]}]}], " ", "&"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"3", ",", "3", ",", "3", ",", "3"}], "}"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"IsotropicCompliance", "[", "nu_", "]"}], ":=", " ", 
  RowBox[{"IsotropicCompliance", "[", 
   RowBox[{"1", ",", "nu"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"SS", " ", "=", " ", 
  RowBox[{"IsotropicCompliance", "[", "nu", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DDot", "[", 
   RowBox[{"T4_", ",", "t2_"}], "]"}], ":=", 
  RowBox[{"GTr", "[", 
   RowBox[{
    RowBox[{"GDot", "[", 
     RowBox[{"T4", ",", "t2", ",", "1", ",", "1"}], "]"}], ",", "1", ",", 
    "4"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "nu"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "nu"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox[
          RowBox[{"1", "+", "nu"}], "2"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"1", "+", "nu"}], "2"], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         FractionBox[
          RowBox[{"1", "+", "nu"}], "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"1", "+", "nu"}], "2"], ",", "0", ",", "0"}], "}"}]}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox[
          RowBox[{"1", "+", "nu"}], "2"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"1", "+", "nu"}], "2"], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "nu"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "nu"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         FractionBox[
          RowBox[{"1", "+", "nu"}], "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox[
          RowBox[{"1", "+", "nu"}], "2"], ",", "0"}], "}"}]}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         FractionBox[
          RowBox[{"1", "+", "nu"}], "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"1", "+", "nu"}], "2"], ",", "0", ",", "0"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         FractionBox[
          RowBox[{"1", "+", "nu"}], "2"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         FractionBox[
          RowBox[{"1", "+", "nu"}], "2"], ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "nu"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "nu"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{899, 627},
WindowMargins->{{110, Automatic}, {0, Automatic}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 59, 0, 73, "Section"],
Cell[1393, 40, 1221, 35, 99, "Input"],
Cell[CellGroupData[{
Cell[2639, 79, 544, 14, 77, "Input"],
Cell[3186, 95, 3533, 114, 180, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

