(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    171567,       9292]
NotebookOptionsPosition[    169461,       9220]
NotebookOutlinePosition[    169938,       9239]
CellTagsIndexPosition[    169895,       9236]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mathdir", "=", "\"\<\\math\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"workdir", "=", 
   RowBox[{"myrootdir", "<>", "\"\<\\elastica\>\"", "<>", "mathdir"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetDirectory", "[", "workdir", "]"}], ";"}], "\n", 
 RowBox[{"Get", "[", "\"\<Tensor2Analysis.m\>\"", "]"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetCoordinates", "[", 
   RowBox[{"Cylindrical", "[", 
    RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CoordinatesToCartesian", "[", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"??", "SetCoordinates"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData["\<\"SetCoordinates[coordsys] sets the default coordinate system \
to be coordsys with default variables. SetCoordinates[coordsys[c1, c2, c3]] \
sets the default coordinate system to be coordsys with variables c1, c2, and \
c3.  Certain coordinate systems have parameters associated with them, and \
these parameters can be set by specifying the full description of the \
coordinate system.  For example, SetCoordinates[Conical[lambda, mu, nu]] sets \
only the variables of the conical coordinate system, but \
SetCoordinates[Conical[lambda, mu, nu, a, b]] sets both the variables and the \
parameters of the conical coordinate system. * * * * * * * Defined options \
for the coordinate systems are: Cartesian, Cylindrical, Spherical,  \
ParabolicCylindrical, Paraboloidal, EllipticCylindrical,  ProlateSpheroidal, \
OblateSpheroidal, Bipolar, Bispherical, Toroidal, Conical, \
ConfocalEllipsoidal,  ConfocaParaboloidal.\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{
      RowBox[{"Attributes", "[", "SetCoordinates", "]"}], "=", 
      RowBox[{"{", 
       RowBox[{"Protected", ",", "ReadProtected"}], "}"}]}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[SetCoordinates],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Now", " ", "create", " ", "a", " ", "tensor", " ", "A", " ", "to", " ", 
    "generate", " ", "the", " ", "general", " ", "plane", " ", "problem", " ",
     "stress", " ", "tensor", " ", "in", " ", "polar", " ", "coords"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"B", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"A0", "[", 
          RowBox[{"r", ",", "t"}], "]"}]}], "}"}]}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Stress", ":=", 
     RowBox[{"Inc", "[", "B", "]"}]}], " ", ";", 
    RowBox[{"Stress", "//", "MatrixForm"}]}]}]}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["A0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t"}], "]"}], "+", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["A0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t"}], "]"}]}]}], 
       SuperscriptBox["r", "2"]], 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["A0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t"}], "]"}], "-", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["A0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t"}], "]"}]}]}], 
       SuperscriptBox["r", "2"]], "0"},
     {
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["A0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t"}], "]"}], "-", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["A0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t"}], "]"}]}]}], 
       SuperscriptBox["r", "2"]], 
      RowBox[{
       SuperscriptBox["A0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"r", ",", "t"}], "]"}], "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"Div", "[", "Stress", "]"}], "]"}], " ", "//", "MatrixForm", 
  RowBox[{"(*", " ", 
   RowBox[{"Always", " ", "satisfies", " ", "equilibrium", " ", "equations"}],
    " ", "*)"}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0"},
     {"0"},
     {"0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{0, 0, 0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "cell", " ", "is", " ", "the", " ", "solution", " ", "to", 
    " ", "the", " ", 
    StyleBox["Kirsch",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["problem",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["about",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["a",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["circular",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["hole",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["in",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["infinite",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["plane",
     FontColor->RGBColor[1, 0, 0]]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "First", " ", "part", " ", "is", " ", "hydrostatic", " ", "tension", " ", 
    "Sig"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Psi1", "[", 
      RowBox[{"r", ",", "t"}], "]"}], " ", "=", 
     RowBox[{
      RowBox[{"Sig", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"r", "^", "2"}], "/", "2"}], "-", 
        RowBox[{
         RowBox[{"a", "^", "2"}], 
         RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"A0", "[", 
      RowBox[{"r", ",", "t"}], "]"}], "=", 
     RowBox[{"Psi1", "[", 
      RowBox[{"r", ",", "t"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{"2", " ", 
      RowBox[{"Stress", " ", "/", "Sig"}]}], "]"}], "//", 
    "MatrixForm"}]}]}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"1", "-", 
       FractionBox[
        SuperscriptBox["a", "2"], 
        SuperscriptBox["r", "2"]]}], "0", "0"},
     {"0", 
      RowBox[{"1", "+", 
       FractionBox[
        SuperscriptBox["a", "2"], 
        SuperscriptBox["r", "2"]]}], "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Second", " ", "part", " ", "is", " ", "combined", " ", "tension", " ", 
    "and", " ", "shear"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Psi2", "[", 
      RowBox[{"r", ",", "t"}], "]"}], "=", 
     RowBox[{"Sig", " ", 
      RowBox[{
       RowBox[{"Cos", " ", "[", 
        RowBox[{"2", "t"}], "]"}], "/", "4"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", 
         RowBox[{"a", "^", "2"}]}], "-", 
        RowBox[{"r", "^", "2"}], "-", 
        RowBox[{
         RowBox[{"a", "^", "4"}], "/", 
         RowBox[{"r", "^", "2"}]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{
     RowBox[{"A0", "[", 
      RowBox[{"r", ",", "t"}], "]"}], "=", 
     RowBox[{"Psi2", "[", 
      RowBox[{"r", ",", "t"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{"2", " ", 
      RowBox[{"Stress", " ", "/", "Sig"}]}], "]"}], "//", 
    "MatrixForm"}]}]}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "t"}], "]"}], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "t"}], "]"}]}], 
        SuperscriptBox["r", "4"]], "-", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "t"}], "]"}]}], 
        SuperscriptBox["r", "2"]]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Cos", "[", "t", "]"}], " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], "+", 
       FractionBox[
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Sin", "[", "t", "]"}]}], 
        SuperscriptBox["r", "4"]], "-", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Sin", "[", "t", "]"}]}], 
        SuperscriptBox["r", "2"]]}], "0"},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Cos", "[", "t", "]"}], " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], "+", 
       FractionBox[
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Sin", "[", "t", "]"}]}], 
        SuperscriptBox["r", "4"]], "-", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Sin", "[", "t", "]"}]}], 
        SuperscriptBox["r", "2"]]}], 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "t"}], "]"}]}], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "t"}], "]"}]}], 
        SuperscriptBox["r", "4"]]}], "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "superposition", " ", "provides", " ", "the", " ", "complete", 
    " ", "solution", " ", "of", " ", "the", " ", "Kirsch", " ", "problem"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"A0", "[", 
      RowBox[{"r", ",", "t"}], "]"}], "=", 
     RowBox[{
      RowBox[{"Psi1", "[", 
       RowBox[{"r", ",", "t"}], "]"}], "+", 
      RowBox[{"Psi2", "[", 
       RowBox[{"r", ",", "t"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Biharmonic", "[", 
     RowBox[{"A0", "[", 
      RowBox[{"r", ",", "t"}], "]"}], " ", "]"}], "]"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"Satisfies", " ", "compatibility"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Div", "[", "Stress", "]"}], "]"}], "  ", 
   RowBox[{"(*", " ", 
    RowBox[{"Satisfies", " ", "equilibrium"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{"2", " ", 
      RowBox[{
       RowBox[{"Stress", " ", "/", "Sig"}], "/", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "t"}], "]"}]}]}], "]"}], "//", 
    "MatrixForm"}]}]}]], "Input"],

Cell[BoxData["0"], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"]}], 
        SuperscriptBox["r", "4"]], "-", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"]}], 
        SuperscriptBox["r", "2"]], "+", 
       RowBox[{"Sec", "[", 
        RowBox[{"2", " ", "t"}], "]"}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"Sec", "[", 
          RowBox[{"2", " ", "t"}], "]"}]}], 
        SuperscriptBox["r", "2"]]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Cos", "[", "t", "]"}], " ", 
        RowBox[{"Sec", "[", 
         RowBox[{"2", " ", "t"}], "]"}], " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], "+", 
       FractionBox[
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Sec", "[", 
          RowBox[{"2", " ", "t"}], "]"}], " ", 
         RowBox[{"Sin", "[", "t", "]"}]}], 
        SuperscriptBox["r", "4"]], "-", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Sec", "[", 
          RowBox[{"2", " ", "t"}], "]"}], " ", 
         RowBox[{"Sin", "[", "t", "]"}]}], 
        SuperscriptBox["r", "2"]]}], "0"},
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Cos", "[", "t", "]"}], " ", 
        RowBox[{"Sec", "[", 
         RowBox[{"2", " ", "t"}], "]"}], " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], "+", 
       FractionBox[
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Sec", "[", 
          RowBox[{"2", " ", "t"}], "]"}], " ", 
         RowBox[{"Sin", "[", "t", "]"}]}], 
        SuperscriptBox["r", "4"]], "-", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Sec", "[", 
          RowBox[{"2", " ", "t"}], "]"}], " ", 
         RowBox[{"Sin", "[", "t", "]"}]}], 
        SuperscriptBox["r", "2"]]}], 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"]}], 
        SuperscriptBox["r", "4"]], "+", 
       RowBox[{"Sec", "[", 
        RowBox[{"2", " ", "t"}], "]"}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"Sec", "[", 
          RowBox[{"2", " ", "t"}], "]"}]}], 
        SuperscriptBox["r", "2"]]}], "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"B", ".", "c", ".", " ", "for"}], " ", "very", " ", "large", 
      " ", "Rr"}], ">>", "a"}], ";", " ", 
    RowBox[{
     RowBox[{
     "in", " ", "this", " ", "case", " ", "equivalent", " ", "to", " ", "a"}],
      "\[Rule]", "0"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Stress", "/.", " ", 
       RowBox[{"a", "\[Rule]", "0"}]}], " ", ")"}], "//", "MatrixForm"}], 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
     "Need", " ", "to", " ", "be", " ", "able", " ", "to", " ", "transform", 
      " ", "this", " ", "to", " ", "Cartesian", " ", "coords", " ", "to", " ",
       "show", " ", "what", " ", "it", " ", "is"}], " ", "*)"}], 
    "\[IndentingNewLine]"}], 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"B", ".", "c", ".", " ", "on"}], " ", "the", " ", "hole", " ", 
      "perimeter", " ", "at", " ", "Rr"}], "=", 
     RowBox[{"a", ":", " ", 
      RowBox[{"only", " ", "stt", " ", "component", " ", "present"}]}]}], " ",
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Stress", "/.", 
     RowBox[{"(", 
      RowBox[{"r", "\[Rule]", "a"}], ")"}]}], "//", "MatrixForm"}], 
   "\[IndentingNewLine]", 
   RowBox[{"stt", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Stress", "/.", " ", 
       RowBox[{"(", 
        RowBox[{"r", " ", "\[Rule]", "a"}], ")"}]}], " ", ")"}], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"stt", "/.", 
       RowBox[{"Sig", "\[Rule]", "1"}]}], " ", "/.", " ", 
      RowBox[{"a", "\[Rule]", "1"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"2", " ", "Pi"}]}], "}"}]}], "]"}]}], " "}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"Sig", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"]}]], 
      RowBox[{
       RowBox[{"-", "Sig"}], " ", 
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], "0"},
     {
      RowBox[{
       RowBox[{"-", "Sig"}], " ", 
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      FractionBox[
       RowBox[{"Sig", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "4"], "-", 
          RowBox[{
           SuperscriptBox["r", "4"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "4"]}]], "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"Sig", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["a", "4"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["a", "4"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "t"}], "]"}]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "4"]}]], "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"],

Cell[BoxData[
 FractionBox[
  RowBox[{"Sig", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["a", "4"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["a", "4"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "t"}], "]"}]}]}], ")"}]}], 
  RowBox[{"2", " ", 
   SuperscriptBox["a", "4"]}]]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.161866 0.147151 [
[.17539 .14937 -3 -9 ]
[.17539 .14937 3 0 ]
[.32696 .14937 -3 -9 ]
[.32696 .14937 3 0 ]
[.47854 .14937 -3 -9 ]
[.47854 .14937 3 0 ]
[.63011 .14937 -3 -9 ]
[.63011 .14937 3 0 ]
[.78169 .14937 -3 -9 ]
[.78169 .14937 3 0 ]
[.93327 .14937 -3 -9 ]
[.93327 .14937 3 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .45617 -6 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .16187 m
.17539 .16812 L
s
[(1)] .17539 .14937 0 1 Mshowa
.32696 .16187 m
.32696 .16812 L
s
[(2)] .32696 .14937 0 1 Mshowa
.47854 .16187 m
.47854 .16812 L
s
[(3)] .47854 .14937 0 1 Mshowa
.63011 .16187 m
.63011 .16812 L
s
[(4)] .63011 .14937 0 1 Mshowa
.78169 .16187 m
.78169 .16812 L
s
[(5)] .78169 .14937 0 1 Mshowa
.93327 .16187 m
.93327 .16812 L
s
[(6)] .93327 .14937 0 1 Mshowa
.125 Mabswid
.05412 .16187 m
.05412 .16562 L
s
.08444 .16187 m
.08444 .16562 L
s
.11476 .16187 m
.11476 .16562 L
s
.14507 .16187 m
.14507 .16562 L
s
.2057 .16187 m
.2057 .16562 L
s
.23602 .16187 m
.23602 .16562 L
s
.26633 .16187 m
.26633 .16562 L
s
.29665 .16187 m
.29665 .16562 L
s
.35728 .16187 m
.35728 .16562 L
s
.38759 .16187 m
.38759 .16562 L
s
.41791 .16187 m
.41791 .16562 L
s
.44822 .16187 m
.44822 .16562 L
s
.50885 .16187 m
.50885 .16562 L
s
.53917 .16187 m
.53917 .16562 L
s
.56948 .16187 m
.56948 .16562 L
s
.5998 .16187 m
.5998 .16562 L
s
.66043 .16187 m
.66043 .16562 L
s
.69074 .16187 m
.69074 .16562 L
s
.72106 .16187 m
.72106 .16562 L
s
.75138 .16187 m
.75138 .16562 L
s
.81201 .16187 m
.81201 .16562 L
s
.84232 .16187 m
.84232 .16562 L
s
.87264 .16187 m
.87264 .16562 L
s
.90295 .16187 m
.90295 .16562 L
s
.96358 .16187 m
.96358 .16562 L
s
.9939 .16187 m
.9939 .16562 L
s
.25 Mabswid
0 .16187 m
1 .16187 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(2)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(3)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01475 L
.02605 .01484 L
.02729 .01503 L
.02846 .01527 L
.03053 .01587 L
.03279 .01678 L
.03527 .01807 L
.0379 .01979 L
.04262 .02373 L
.05205 .03491 L
.06244 .05214 L
.0842 .10331 L
.10458 .16662 L
.14335 .31094 L
.18458 .46296 L
.20517 .52463 L
.21519 .54917 L
.22428 .5678 L
.2338 .58332 L
.24277 .59399 L
.2477 .59817 L
.25224 .60093 L
.25461 .60196 L
.25597 .60242 L
.25722 .60276 L
.25853 .60303 L
.25925 .60314 L
.25994 .60322 L
.26115 .6033 L
.26184 .60332 L
.26248 .60331 L
.26365 .60324 L
.26489 .60309 L
.26595 .6029 L
.26711 .60263 L
.2697 .60176 L
.2721 .60066 L
.27647 .5979 L
.28114 .59389 L
.28669 .58772 L
.29194 .58051 L
.30174 .56359 L
.32176 .51621 L
.34021 .45972 L
.37961 .31422 L
.4175 .17253 L
.43858 .10619 L
.45784 .05909 L
.46737 .04157 L
Mistroke
.4724 .03402 L
.47776 .0273 L
.48291 .02217 L
.48757 .01867 L
.48982 .01737 L
.49225 .01625 L
.49337 .01584 L
.49455 .01547 L
.49565 .0152 L
.49666 .015 L
.49789 .01483 L
.49854 .01477 L
.49922 .01473 L
.50037 .01472 L
.50164 .01478 L
.50276 .01491 L
.50398 .01512 L
.50512 .01539 L
.50617 .01569 L
.50854 .01658 L
.51113 .01788 L
.51634 .02153 L
.52094 .02588 L
.52585 .03167 L
.53469 .04501 L
.54496 .06499 L
.55607 .09166 L
.57624 .15148 L
.61721 .30188 L
.65666 .44917 L
.6765 .51136 L
.6946 .55618 L
.70461 .57505 L
.71409 .58868 L
.71929 .5943 L
.7241 .59831 L
.72661 .59995 L
.72938 .60138 L
.73077 .60195 L
.73228 .60245 L
.73369 .60282 L
.735 .60307 L
.73627 .60323 L
.73747 .60331 L
.73855 .60331 L
.73973 .60325 L
.741 .6031 L
.74165 .603 L
.74236 .60285 L
.74362 .60254 L
Mistroke
.74478 .60217 L
.74705 .60127 L
.74949 .6 L
.7539 .59695 L
.75897 .59223 L
.76451 .58563 L
.77459 .56986 L
.79428 .52609 L
.81525 .46353 L
.85686 .31013 L
.89694 .16147 L
.91533 .1046 L
.92577 .07747 L
.93551 .0561 L
.94506 .03919 L
.94997 .03216 L
.9553 .02583 L
.95822 .02295 L
.96091 .02067 L
.96344 .01887 L
.96623 .01725 L
.96872 .01614 L
.97106 .01539 L
.97235 .01509 L
.97353 .0149 L
.97483 .01476 L
.97548 .01473 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.367127, -1.1615, \
0.0237193, 0.0244325}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"myrule", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Cos", "[", "t", "]"}], ",", 
      RowBox[{"Sin", "[", "t", "]"}], ",", "r", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", "t"}], "]"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}]}], "]"}]}], ",", 
      RowBox[{"y", "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}]}], "]"}]}], ",", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"x", "^", "2"}], "+", 
        RowBox[{"y", "^", "2"}]}], "]"}], ",", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "-", 
         RowBox[{"y", "^", "2"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}]}], ")"}]}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"numrule", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a", "\[Rule]", "1"}], ",", 
    RowBox[{"Sig", "\[Rule]", "1"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StressCart", "=", 
   RowBox[{
    RowBox[{"FieldToCartesian", "[", "Stress", "]"}], "/.", "myrule"}]}], 
  ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "t", "]"}], "\[Rule]", 
    FractionBox["x", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}]]]}], ",", 
   RowBox[{
    RowBox[{"Sin", "[", "t", "]"}], "\[Rule]", 
    FractionBox["y", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}]]]}], ",", 
   RowBox[{"r", "\[Rule]", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"]}]]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", "t"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], "-", 
      SuperscriptBox["y", "2"]}], 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"]}]]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "1"}], ",", 
   RowBox[{"Sig", "\[Rule]", "1"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SS", "=", 
     RowBox[{
      RowBox[{"Stress", "/.", "myrule"}], "/.", "numrule"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SC", "=", 
     RowBox[{"StressCart", "/.", "numrule"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"d", "=", "3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"g1", "=", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"SC", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "d"}], ",", "d"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "d"}], ",", "d"}], "}"}], ",", " ", 
      RowBox[{"PlotPoints", "\[Rule]", "50"}], ",", 
      RowBox[{"Contours", "\[Rule]", "50"}], ",", 
      RowBox[{"Compiled", "\[Rule]", "True"}], ",", " ", 
      RowBox[{"ContourShading", "\[Rule]", "True"}], ",", 
      RowBox[{"ContourLines", "\[Rule]", "False"}], ",", " ", 
      RowBox[{"ColorFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Hue", "[", 
          RowBox[{
           RowBox[{"2", "/", "3"}], 
           RowBox[{"(", 
            RowBox[{"1", "-", "#"}], ")"}]}], "]"}], "&"}], ")"}]}], ",", 
      RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Graphics", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"GrayLevel", "[", "1", "]"}], ",", 
           RowBox[{"Disk", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], ",",
          
         RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
         RowBox[{"Axes", "\[Rule]", "Automatic"}]}], "]"}], ",", 
       RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"g1", ",", "g2"}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}]}], "]"}]}], 
  " "}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "ContourGraphics", "\[SkeletonIndicator]"}],
  
  False,
  Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.5 0.15873 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -3 -9 ]
[.81746 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02381 -12 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .18254 -12 -4.5 ]
[-0.0125 .18254 0 4.5 ]
[-0.0125 .34127 -12 -4.5 ]
[-0.0125 .34127 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .65873 -6 -4.5 ]
[-0.0125 .65873 0 4.5 ]
[-0.0125 .81746 -6 -4.5 ]
[-0.0125 .81746 0 4.5 ]
[-0.0125 .97619 -6 -4.5 ]
[-0.0125 .97619 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-3)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-2)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(1)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02381 m
.00625 .02381 L
s
[(-3)] -0.0125 .02381 1 0 Mshowa
0 .18254 m
.00625 .18254 L
s
[(-2)] -0.0125 .18254 1 0 Mshowa
0 .34127 m
.00625 .34127 L
s
[(-1)] -0.0125 .34127 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .65873 m
.00625 .65873 L
s
[(1)] -0.0125 .65873 1 0 Mshowa
0 .81746 m
.00625 .81746 L
s
[(2)] -0.0125 .81746 1 0 Mshowa
0 .97619 m
.00625 .97619 L
s
[(3)] -0.0125 .97619 1 0 Mshowa
.125 Mabswid
0 .05556 m
.00375 .05556 L
s
0 .0873 m
.00375 .0873 L
s
0 .11905 m
.00375 .11905 L
s
0 .15079 m
.00375 .15079 L
s
0 .21429 m
.00375 .21429 L
s
0 .24603 m
.00375 .24603 L
s
0 .27778 m
.00375 .27778 L
s
0 .30952 m
.00375 .30952 L
s
0 .37302 m
.00375 .37302 L
s
0 .40476 m
.00375 .40476 L
s
0 .43651 m
.00375 .43651 L
s
0 .46825 m
.00375 .46825 L
s
0 .53175 m
.00375 .53175 L
s
0 .56349 m
.00375 .56349 L
s
0 .59524 m
.00375 .59524 L
s
0 .62698 m
.00375 .62698 L
s
0 .69048 m
.00375 .69048 L
s
0 .72222 m
.00375 .72222 L
s
0 .75397 m
.00375 .75397 L
s
0 .78571 m
.00375 .78571 L
s
0 .84921 m
.00375 .84921 L
s
0 .88095 m
.00375 .88095 L
s
0 .9127 m
.00375 .9127 L
s
0 .94444 m
.00375 .94444 L
s
.25 Mabswid
0 0 m
0 1 L
s
.02381 .99375 m
.02381 1 L
s
.18254 .99375 m
.18254 1 L
s
.34127 .99375 m
.34127 1 L
s
.5 .99375 m
.5 1 L
s
.65873 .99375 m
.65873 1 L
s
.81746 .99375 m
.81746 1 L
s
.97619 .99375 m
.97619 1 L
s
.125 Mabswid
.05556 .99625 m
.05556 1 L
s
.0873 .99625 m
.0873 1 L
s
.11905 .99625 m
.11905 1 L
s
.15079 .99625 m
.15079 1 L
s
.21429 .99625 m
.21429 1 L
s
.24603 .99625 m
.24603 1 L
s
.27778 .99625 m
.27778 1 L
s
.30952 .99625 m
.30952 1 L
s
.37302 .99625 m
.37302 1 L
s
.40476 .99625 m
.40476 1 L
s
.43651 .99625 m
.43651 1 L
s
.46825 .99625 m
.46825 1 L
s
.53175 .99625 m
.53175 1 L
s
.56349 .99625 m
.56349 1 L
s
.59524 .99625 m
.59524 1 L
s
.62698 .99625 m
.62698 1 L
s
.69048 .99625 m
.69048 1 L
s
.72222 .99625 m
.72222 1 L
s
.75397 .99625 m
.75397 1 L
s
.78571 .99625 m
.78571 1 L
s
.84921 .99625 m
.84921 1 L
s
.88095 .99625 m
.88095 1 L
s
.9127 .99625 m
.9127 1 L
s
.94444 .99625 m
.94444 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .18254 m
1 .18254 L
s
.99375 .34127 m
1 .34127 L
s
.99375 .5 m
1 .5 L
s
.99375 .65873 m
1 .65873 L
s
.99375 .81746 m
1 .81746 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .05556 m
1 .05556 L
s
.99625 .0873 m
1 .0873 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .24603 m
1 .24603 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .30952 m
1 .30952 L
s
.99625 .37302 m
1 .37302 L
s
.99625 .40476 m
1 .40476 L
s
.99625 .43651 m
1 .43651 L
s
.99625 .46825 m
1 .46825 L
s
.99625 .53175 m
1 .53175 L
s
.99625 .56349 m
1 .56349 L
s
.99625 .59524 m
1 .59524 L
s
.99625 .62698 m
1 .62698 L
s
.99625 .69048 m
1 .69048 L
s
.99625 .72222 m
1 .72222 L
s
.99625 .75397 m
1 .75397 L
s
.99625 .78571 m
1 .78571 L
s
.99625 .84921 m
1 .84921 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .9127 m
1 .9127 L
s
.99625 .94444 m
1 .94444 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.16 1 0 r
.02381 .97619 m
.97619 .97619 L
.97619 .02381 L
.02381 .02381 L
F
.08 1 0 r
.02381 .15317 m
.03182 .15986 L
.04325 .16931 L
.05561 .1793 L
.06268 .18497 L
.08026 .19874 L
.08212 .20019 L
.10155 .21501 L
.10581 .21817 L
.12099 .22943 L
.13234 .23761 L
.14043 .24344 L
.15986 .25702 L
.1599 .25705 L
.1793 .27029 L
.18872 .27648 L
.19874 .28309 L
.21817 .29538 L
.21905 .29592 L
.23761 .30729 L
.25164 .31535 L
.25705 .31847 L
.27648 .32902 L
.28825 .33479 L
.29592 .33851 L
.31535 .34697 L
.33479 .35368 L
.33672 .35423 L
.35423 .35919 L
.37366 .36399 L
.3931 .3695 L
.4083 .37366 L
.41254 .37603 L
.43197 .38788 L
.43799 .3931 L
.45141 .4076 L
.45514 .41254 L
.4679 .43197 L
.47085 .4404 L
.47622 .45141 L
.4809 .47085 L
.49028 .47112 L
.50972 .47112 L
.52893 .49028 L
.52893 .50972 L
.52915 .51807 L
.54859 .52166 L
.56803 .52514 L
.58746 .52735 L
.6069 .52394 L
.62009 .50972 L
.62009 .49028 L
.6069 .47606 L
.58746 .47265 L
.56803 .47486 L
.54859 .47834 L
.52915 .48193 L
.5191 .47085 L
.52378 .45141 L
.52915 .4404 L
.5321 .43197 L
.54486 .41254 L
.54859 .4076 L
.56201 .3931 L
.56803 .38788 L
.58746 .37603 L
.5917 .37366 L
.6069 .3695 L
.62634 .36399 L
.64577 .35919 L
.66328 .35423 L
.66521 .35368 L
.68465 .34697 L
.70408 .33851 L
.71175 .33479 L
.72352 .32902 L
.74295 .31847 L
.74836 .31535 L
.76239 .30729 L
.78095 .29592 L
.78183 .29538 L
.80126 .28309 L
.81128 .27648 L
.8207 .27029 L
.8401 .25705 L
.84014 .25702 L
.85957 .24344 L
.86766 .23761 L
.87901 .22943 L
.89419 .21817 L
.89845 .21501 L
.91788 .20019 L
.91974 .19874 L
.93732 .18497 L
.94439 .1793 L
.95675 .16931 L
.96818 .15986 L
.97619 .15317 L
.97619 .97619 L
.02381 .97619 L
F
0 1 0 r
.02381 .2215 m
.04325 .22998 L
.06044 .23761 L
.06268 .23862 L
.08212 .24747 L
.10155 .25644 L
.10285 .25705 L
.12099 .26559 L
.14043 .27482 L
.14394 .27648 L
.15986 .28416 L
.1793 .29353 L
.18431 .29592 L
.19874 .30292 L
.21817 .31223 L
.22486 .31535 L
.23761 .32141 L
.25705 .33032 L
.26736 .33479 L
.27648 .33876 L
.29592 .34661 L
.31535 .35333 L
.31836 .35423 L
.33479 .35892 L
.35423 .36324 L
.37366 .36688 L
.3931 .37118 L
.40462 .37366 L
.41254 .37754 L
.43197 .38854 L
.43742 .3931 L
.45141 .40783 L
.45501 .41254 L
.46786 .43197 L
.47085 .44043 L
.47622 .45141 L
.48089 .47085 L
.49028 .47112 L
.50972 .47112 L
.52893 .49028 L
.52893 .50972 L
.52915 .51807 L
.54859 .52167 L
.56803 .52517 L
.58746 .52745 L
.6069 .52431 L
.62076 .50972 L
.62076 .49028 L
.6069 .47569 L
.58746 .47255 L
.56803 .47483 L
.54859 .47833 L
.52915 .48193 L
.51911 .47085 L
.52378 .45141 L
.52915 .44043 L
.53214 .43197 L
.54499 .41254 L
.54859 .40783 L
.56258 .3931 L
.56803 .38854 L
.58746 .37754 L
.59538 .37366 L
.6069 .37118 L
.62634 .36688 L
.64577 .36324 L
.66521 .35892 L
.68164 .35423 L
.68465 .35333 L
.70408 .34661 L
.72352 .33876 L
.73264 .33479 L
.74295 .33032 L
.76239 .32141 L
.77514 .31535 L
.78183 .31223 L
.80126 .30292 L
.81569 .29592 L
.8207 .29353 L
.84014 .28416 L
.85606 .27648 L
.85957 .27482 L
.87901 .26559 L
.89715 .25705 L
.89845 .25644 L
.91788 .24747 L
.93732 .23862 L
.93956 .23761 L
.95675 .22998 L
.97619 .2215 L
.97619 .97619 L
.02381 .97619 L
F
0 1 .08 r
.02381 .26924 m
.04325 .27324 L
.05771 .27648 L
.06268 .27768 L
.08212 .28256 L
.10155 .28784 L
.12099 .2935 L
.129 .29592 L
.14043 .29953 L
.15986 .30589 L
.1793 .31252 L
.18748 .31535 L
.19874 .3194 L
.21817 .32646 L
.23761 .33354 L
.24109 .33479 L
.25705 .34063 L
.27648 .34748 L
.29592 .35374 L
.29755 .35423 L
.31535 .35931 L
.33479 .36374 L
.35423 .36692 L
.37366 .36947 L
.3931 .37261 L
.3997 .37366 L
.41254 .37896 L
.43197 .38917 L
.43683 .3931 L
.45141 .40805 L
.45488 .41254 L
.46782 .43197 L
.47085 .44046 L
.47621 .45141 L
.48089 .47085 L
.49028 .47112 L
.50972 .47112 L
.52893 .49028 L
.52893 .50972 L
.52915 .51807 L
.54859 .52167 L
.56803 .52519 L
.58746 .52756 L
.6069 .52467 L
.62147 .50972 L
.62147 .49028 L
.6069 .47533 L
.58746 .47244 L
.56803 .47481 L
.54859 .47833 L
.52915 .48193 L
.51911 .47085 L
.52379 .45141 L
.52915 .44046 L
.53218 .43197 L
.54512 .41254 L
.54859 .40805 L
.56317 .3931 L
.56803 .38917 L
.58746 .37896 L
.6003 .37366 L
.6069 .37261 L
.62634 .36947 L
.64577 .36692 L
.66521 .36374 L
.68465 .35931 L
.70245 .35423 L
.70408 .35374 L
.72352 .34748 L
.74295 .34063 L
.75891 .33479 L
.76239 .33354 L
.78183 .32646 L
.80126 .3194 L
.81252 .31535 L
.8207 .31252 L
.84014 .30589 L
.85957 .29953 L
.871 .29592 L
.87901 .2935 L
.89845 .28784 L
.91788 .28256 L
.93732 .27768 L
.94229 .27648 L
.95675 .27324 L
.97619 .26924 L
.97619 .97619 L
.02381 .97619 L
F
0 1 .16 r
.02381 .30941 m
.04325 .30965 L
.06268 .3106 L
.08212 .31221 L
.10155 .31446 L
.10839 .31535 L
.12099 .31731 L
.14043 .32072 L
.15986 .32465 L
.1793 .32904 L
.19874 .33384 L
.20249 .33479 L
.21817 .339 L
.23761 .34442 L
.25705 .34992 L
.2726 .35423 L
.27648 .35531 L
.29592 .36044 L
.31535 .36485 L
.33479 .36816 L
.35423 .37027 L
.37366 .37179 L
.39182 .37366 L
.3931 .37393 L
.41254 .3803 L
.43197 .38978 L
.43622 .3931 L
.45141 .40827 L
.45474 .41254 L
.46778 .43197 L
.47085 .44048 L
.47621 .45141 L
.48089 .47085 L
.49028 .47112 L
.50972 .47112 L
.52893 .49028 L
.52893 .50972 L
.52915 .51808 L
.54859 .52168 L
.56803 .52522 L
.58746 .52767 L
.6069 .52504 L
.62222 .50972 L
.62222 .49028 L
.6069 .47496 L
.58746 .47233 L
.56803 .47478 L
.54859 .47832 L
.52915 .48192 L
.51911 .47085 L
.52379 .45141 L
.52915 .44048 L
.53222 .43197 L
.54526 .41254 L
.54859 .40827 L
.56378 .3931 L
.56803 .38978 L
.58746 .3803 L
.6069 .37393 L
.60818 .37366 L
.62634 .37179 L
.64577 .37027 L
.66521 .36816 L
.68465 .36485 L
.70408 .36044 L
.72352 .35531 L
.7274 .35423 L
.74295 .34992 L
.76239 .34442 L
.78183 .339 L
.79751 .33479 L
.80126 .33384 L
.8207 .32904 L
.84014 .32465 L
.85957 .32072 L
.87901 .31731 L
.89161 .31535 L
.89845 .31446 L
.91788 .31221 L
.93732 .3106 L
.95675 .30965 L
.97619 .30941 L
.97619 .97619 L
.02381 .97619 L
F
0 1 .24 r
.02381 .34697 m
.04325 .34331 L
.06268 .34076 L
.08212 .33923 L
.10155 .33861 L
.12099 .33884 L
.14043 .33986 L
.15986 .3416 L
.1793 .34399 L
.19874 .34697 L
.21817 .35045 L
.23722 .35423 L
.23761 .35431 L
.25705 .35846 L
.27648 .36267 L
.29592 .36664 L
.31535 .36997 L
.33479 .37226 L
.35423 .37336 L
.36726 .37366 L
.37366 .37396 L
.3931 .37575 L
.41254 .38156 L
.43197 .39037 L
.43558 .3931 L
.45141 .40849 L
.45461 .41254 L
.46775 .43197 L
.47085 .44051 L
.4762 .45141 L
.48089 .47085 L
.49028 .47112 L
.50972 .47112 L
.52893 .49028 L
.52893 .50972 L
.52915 .51808 L
.54859 .52168 L
.56803 .52525 L
.58746 .52777 L
.6069 .5254 L
.62301 .50972 L
.62301 .49028 L
.6069 .4746 L
.58746 .47223 L
.56803 .47475 L
.54859 .47832 L
.52915 .48192 L
.51911 .47085 L
.5238 .45141 L
.52915 .44051 L
.53225 .43197 L
.54539 .41254 L
.54859 .40849 L
.56442 .3931 L
.56803 .39037 L
.58746 .38156 L
.6069 .37575 L
.62634 .37396 L
.63274 .37366 L
.64577 .37336 L
.66521 .37226 L
.68465 .36997 L
.70408 .36664 L
.72352 .36267 L
.74295 .35846 L
.76239 .35431 L
.76278 .35423 L
.78183 .35045 L
.80126 .34697 L
.8207 .34399 L
.84014 .3416 L
.85957 .33986 L
.87901 .33884 L
.89845 .33861 L
.91788 .33923 L
.93732 .34076 L
.95675 .34331 L
.97619 .34697 L
.97619 .97619 L
.02381 .97619 L
F
0 1 .32 r
.02381 .38583 m
.04325 .37712 L
.05261 .37366 L
.06268 .3704 L
.08212 .36533 L
.10155 .36165 L
.12099 .3592 L
.14043 .35784 L
.15986 .35745 L
.1793 .35793 L
.19874 .35919 L
.21817 .36112 L
.23761 .3636 L
.25705 .36648 L
.27648 .36953 L
.29592 .37243 L
.30524 .37366 L
.31535 .37481 L
.33479 .37623 L
.35423 .37651 L
.37366 .37634 L
.3931 .37748 L
.41254 .38274 L
.43197 .39094 L
.43493 .3931 L
.45141 .4087 L
.45448 .41254 L
.46771 .43197 L
.47085 .44054 L
.4762 .45141 L
.48089 .47085 L
.49028 .47112 L
.50972 .47112 L
.52893 .49028 L
.52893 .50972 L
.52915 .51808 L
.54859 .52169 L
.56803 .52527 L
.58746 .52788 L
.6069 .52576 L
.62386 .50972 L
.62386 .49028 L
.6069 .47424 L
.58746 .47212 L
.56803 .47473 L
.54859 .47831 L
.52915 .48192 L
.51911 .47085 L
.5238 .45141 L
.52915 .44054 L
.53229 .43197 L
.54552 .41254 L
.54859 .4087 L
.56507 .3931 L
.56803 .39094 L
.58746 .38274 L
.6069 .37748 L
.62634 .37634 L
.64577 .37651 L
.66521 .37623 L
.68465 .37481 L
.69476 .37366 L
.70408 .37243 L
.72352 .36953 L
.74295 .36648 L
.76239 .3636 L
.78183 .36112 L
.80126 .35919 L
.8207 .35793 L
.84014 .35745 L
.85957 .35784 L
.87901 .3592 L
.89845 .36165 L
.91788 .36533 L
.93732 .3704 L
.94739 .37366 L
.95675 .37712 L
.97619 .38583 L
.97619 .97619 L
.02381 .97619 L
F
0 1 .4 r
.02381 .43375 m
.02543 .43197 L
.04325 .41517 L
.04673 .41254 L
.06268 .40199 L
.08007 .3931 L
.08212 .39219 L
.10155 .38476 L
.12099 .37925 L
.14043 .37532 L
.15149 .37366 L
.15986 .37271 L
.1793 .37126 L
.19874 .37082 L
.21817 .37124 L
.23761 .37238 L
.25393 .37366 L
.25705 .37405 L
.27648 .37604 L
.29592 .37801 L
.31535 .37953 L
.33479 .38009 L
.35423 .37953 L
.37366 .37861 L
.3931 .37912 L
.41254 .38385 L
.43197 .39149 L
.43425 .3931 L
.45141 .40891 L
.45434 .41254 L
.46767 .43197 L
.47085 .44057 L
.47619 .45141 L
.48089 .47085 L
.49028 .47112 L
.50972 .47112 L
.52893 .49028 L
.52893 .50972 L
.52915 .51808 L
.54859 .52169 L
.56803 .5253 L
.58746 .52798 L
.6069 .52613 L
.62477 .50972 L
.62477 .49028 L
.6069 .47387 L
.58746 .47202 L
.56803 .4747 L
.54859 .47831 L
.52915 .48192 L
.51911 .47085 L
.52381 .45141 L
.52915 .44057 L
.53233 .43197 L
.54566 .41254 L
.54859 .40891 L
.56575 .3931 L
.56803 .39149 L
.58746 .38385 L
.6069 .37912 L
.62634 .37861 L
.64577 .37953 L
.66521 .38009 L
.68465 .37953 L
.70408 .37801 L
.72352 .37604 L
.74295 .37405 L
.74607 .37366 L
.76239 .37238 L
.78183 .37124 L
.80126 .37082 L
.8207 .37126 L
.84014 .37271 L
.84851 .37366 L
.85957 .37532 L
.87901 .37925 L
.89845 .38476 L
.91788 .39219 L
.91993 .3931 L
.93732 .40199 L
.95327 .41254 L
.95675 .41517 L
.97457 .43197 L
.97619 .43375 L
.97619 .97619 L
.02381 .97619 L
F
0 1 .32 r
.02381 .56625 m
.02543 .56803 L
.04325 .58483 L
.04673 .58746 L
.06268 .59801 L
.08007 .6069 L
.08212 .60781 L
.10155 .61524 L
.12099 .62075 L
.14043 .62468 L
.15149 .62634 L
.15986 .62729 L
.1793 .62874 L
.19874 .62918 L
.21817 .62876 L
.23761 .62762 L
.25393 .62634 L
.25705 .62595 L
.27648 .62396 L
.29592 .62199 L
.31535 .62047 L
.33479 .61991 L
.35423 .62047 L
.37366 .62139 L
.3931 .62088 L
.41254 .61615 L
.43197 .60851 L
.43425 .6069 L
.45141 .59109 L
.45434 .58746 L
.46767 .56803 L
.47085 .55943 L
.47619 .54859 L
.48089 .52915 L
.47085 .51808 L
.45141 .52169 L
.43197 .5253 L
.41254 .52798 L
.3931 .52613 L
.37523 .50972 L
.37523 .49028 L
.3931 .47387 L
.41254 .47202 L
.43197 .4747 L
.45141 .47831 L
.47085 .48192 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51911 .52915 L
.52381 .54859 L
.52915 .55943 L
.53233 .56803 L
.54566 .58746 L
.54859 .59109 L
.56575 .6069 L
.56803 .60851 L
.58746 .61615 L
.6069 .62088 L
.62634 .62139 L
.64577 .62047 L
.66521 .61991 L
.68465 .62047 L
.70408 .62199 L
.72352 .62396 L
.74295 .62595 L
.74607 .62634 L
.76239 .62762 L
.78183 .62876 L
.80126 .62918 L
.8207 .62874 L
.84014 .62729 L
.84851 .62634 L
.85957 .62468 L
.87901 .62075 L
.89845 .61524 L
.91788 .60781 L
.91993 .6069 L
.93732 .59801 L
.95327 .58746 L
.95675 .58483 L
.97457 .56803 L
.97619 .56625 L
.97619 .97619 L
.02381 .97619 L
F
0 1 .24 r
.02381 .61417 m
.04325 .62288 L
.05261 .62634 L
.06268 .6296 L
.08212 .63467 L
.10155 .63835 L
.12099 .6408 L
.14043 .64216 L
.15986 .64255 L
.1793 .64207 L
.19874 .64081 L
.21817 .63888 L
.23761 .6364 L
.25705 .63352 L
.27648 .63047 L
.29592 .62757 L
.30524 .62634 L
.31535 .62519 L
.33479 .62377 L
.35423 .62349 L
.37366 .62366 L
.3931 .62252 L
.41254 .61726 L
.43197 .60906 L
.43493 .6069 L
.45141 .5913 L
.45448 .58746 L
.46771 .56803 L
.47085 .55946 L
.4762 .54859 L
.48089 .52915 L
.47085 .51808 L
.45141 .52169 L
.43197 .52527 L
.41254 .52788 L
.3931 .52576 L
.37614 .50972 L
.37614 .49028 L
.3931 .47424 L
.41254 .47212 L
.43197 .47473 L
.45141 .47831 L
.47085 .48192 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51911 .52915 L
.5238 .54859 L
.52915 .55946 L
.53229 .56803 L
.54552 .58746 L
.54859 .5913 L
.56507 .6069 L
.56803 .60906 L
.58746 .61726 L
.6069 .62252 L
.62634 .62366 L
.64577 .62349 L
.66521 .62377 L
.68465 .62519 L
.69476 .62634 L
.70408 .62757 L
.72352 .63047 L
.74295 .63352 L
.76239 .6364 L
.78183 .63888 L
.80126 .64081 L
.8207 .64207 L
.84014 .64255 L
.85957 .64216 L
.87901 .6408 L
.89845 .63835 L
.91788 .63467 L
.93732 .6296 L
.94739 .62634 L
.95675 .62288 L
.97619 .61417 L
.97619 .97619 L
.02381 .97619 L
F
0 1 .16 r
.02381 .65303 m
.04325 .65669 L
.06268 .65924 L
.08212 .66077 L
.10155 .66139 L
.12099 .66116 L
.14043 .66014 L
.15986 .6584 L
.1793 .65601 L
.19874 .65303 L
.21817 .64955 L
.23722 .64577 L
.23761 .64569 L
.25705 .64154 L
.27648 .63733 L
.29592 .63336 L
.31535 .63003 L
.33479 .62774 L
.35423 .62664 L
.36726 .62634 L
.37366 .62604 L
.3931 .62425 L
.41254 .61844 L
.43197 .60963 L
.43558 .6069 L
.45141 .59151 L
.45461 .58746 L
.46775 .56803 L
.47085 .55949 L
.4762 .54859 L
.48089 .52915 L
.47085 .51808 L
.45141 .52168 L
.43197 .52525 L
.41254 .52777 L
.3931 .5254 L
.37699 .50972 L
.37699 .49028 L
.3931 .4746 L
.41254 .47223 L
.43197 .47475 L
.45141 .47832 L
.47085 .48192 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51911 .52915 L
.5238 .54859 L
.52915 .55949 L
.53225 .56803 L
.54539 .58746 L
.54859 .59151 L
.56442 .6069 L
.56803 .60963 L
.58746 .61844 L
.6069 .62425 L
.62634 .62604 L
.63274 .62634 L
.64577 .62664 L
.66521 .62774 L
.68465 .63003 L
.70408 .63336 L
.72352 .63733 L
.74295 .64154 L
.76239 .64569 L
.76278 .64577 L
.78183 .64955 L
.80126 .65303 L
.8207 .65601 L
.84014 .6584 L
.85957 .66014 L
.87901 .66116 L
.89845 .66139 L
.91788 .66077 L
.93732 .65924 L
.95675 .65669 L
.97619 .65303 L
.97619 .97619 L
.02381 .97619 L
F
0 1 .08 r
.02381 .69059 m
.04325 .69035 L
.06268 .6894 L
.08212 .68779 L
.10155 .68554 L
.10839 .68465 L
.12099 .68269 L
.14043 .67928 L
.15986 .67535 L
.1793 .67096 L
.19874 .66616 L
.20249 .66521 L
.21817 .661 L
.23761 .65558 L
.25705 .65008 L
.2726 .64577 L
.27648 .64469 L
.29592 .63956 L
.31535 .63515 L
.33479 .63184 L
.35423 .62973 L
.37366 .62821 L
.39182 .62634 L
.3931 .62607 L
.41254 .6197 L
.43197 .61022 L
.43622 .6069 L
.45141 .59173 L
.45474 .58746 L
.46778 .56803 L
.47085 .55952 L
.47621 .54859 L
.48089 .52915 L
.47085 .51808 L
.45141 .52168 L
.43197 .52522 L
.41254 .52767 L
.3931 .52504 L
.37778 .50972 L
.37778 .49028 L
.3931 .47496 L
.41254 .47233 L
.43197 .47478 L
.45141 .47832 L
.47085 .48192 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51911 .52915 L
.52379 .54859 L
.52915 .55952 L
.53222 .56803 L
.54526 .58746 L
.54859 .59173 L
.56378 .6069 L
.56803 .61022 L
.58746 .6197 L
.6069 .62607 L
.60818 .62634 L
.62634 .62821 L
.64577 .62973 L
.66521 .63184 L
.68465 .63515 L
.70408 .63956 L
.72352 .64469 L
.7274 .64577 L
.74295 .65008 L
.76239 .65558 L
.78183 .661 L
.79751 .66521 L
.80126 .66616 L
.8207 .67096 L
.84014 .67535 L
.85957 .67928 L
.87901 .68269 L
.89161 .68465 L
.89845 .68554 L
.91788 .68779 L
.93732 .6894 L
.95675 .69035 L
.97619 .69059 L
.97619 .97619 L
.02381 .97619 L
F
0 1 0 r
.02381 .73076 m
.04325 .72676 L
.05771 .72352 L
.06268 .72232 L
.08212 .71744 L
.10155 .71216 L
.12099 .7065 L
.129 .70408 L
.14043 .70047 L
.15986 .69411 L
.1793 .68748 L
.18748 .68465 L
.19874 .6806 L
.21817 .67354 L
.23761 .66646 L
.24109 .66521 L
.25705 .65937 L
.27648 .65252 L
.29592 .64626 L
.29755 .64577 L
.31535 .64069 L
.33479 .63626 L
.35423 .63308 L
.37366 .63053 L
.3931 .62739 L
.3997 .62634 L
.41254 .62104 L
.43197 .61083 L
.43683 .6069 L
.45141 .59195 L
.45488 .58746 L
.46782 .56803 L
.47085 .55954 L
.47621 .54859 L
.48089 .52915 L
.47085 .51807 L
.45141 .52167 L
.43197 .52519 L
.41254 .52756 L
.3931 .52467 L
.37853 .50972 L
.37853 .49028 L
.3931 .47533 L
.41254 .47244 L
.43197 .47481 L
.45141 .47833 L
.47085 .48193 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51911 .52915 L
.52379 .54859 L
.52915 .55954 L
.53218 .56803 L
.54512 .58746 L
.54859 .59195 L
.56317 .6069 L
.56803 .61083 L
.58746 .62104 L
.6003 .62634 L
.6069 .62739 L
.62634 .63053 L
.64577 .63308 L
.66521 .63626 L
.68465 .64069 L
.70245 .64577 L
.70408 .64626 L
.72352 .65252 L
.74295 .65937 L
.75891 .66521 L
.76239 .66646 L
.78183 .67354 L
.80126 .6806 L
.81252 .68465 L
.8207 .68748 L
.84014 .69411 L
.85957 .70047 L
.871 .70408 L
.87901 .7065 L
.89845 .71216 L
.91788 .71744 L
.93732 .72232 L
.94229 .72352 L
.95675 .72676 L
.97619 .73076 L
.97619 .97619 L
.02381 .97619 L
F
.08 1 0 r
.02381 .7785 m
.04325 .77002 L
.06044 .76239 L
.06268 .76138 L
.08212 .75253 L
.10155 .74356 L
.10285 .74295 L
.12099 .73441 L
.14043 .72518 L
.14394 .72352 L
.15986 .71584 L
.1793 .70647 L
.18431 .70408 L
.19874 .69708 L
.21817 .68777 L
.22486 .68465 L
.23761 .67859 L
.25705 .66968 L
.26736 .66521 L
.27648 .66124 L
.29592 .65339 L
.31535 .64667 L
.31836 .64577 L
.33479 .64108 L
.35423 .63676 L
.37366 .63312 L
.3931 .62882 L
.40462 .62634 L
.41254 .62246 L
.43197 .61146 L
.43742 .6069 L
.45141 .59217 L
.45501 .58746 L
.46786 .56803 L
.47085 .55957 L
.47622 .54859 L
.48089 .52915 L
.47085 .51807 L
.45141 .52167 L
.43197 .52517 L
.41254 .52745 L
.3931 .52431 L
.37924 .50972 L
.37924 .49028 L
.3931 .47569 L
.41254 .47255 L
.43197 .47483 L
.45141 .47833 L
.47085 .48193 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51911 .52915 L
.52378 .54859 L
.52915 .55957 L
.53214 .56803 L
.54499 .58746 L
.54859 .59217 L
.56258 .6069 L
.56803 .61146 L
.58746 .62246 L
.59538 .62634 L
.6069 .62882 L
.62634 .63312 L
.64577 .63676 L
.66521 .64108 L
.68164 .64577 L
.68465 .64667 L
.70408 .65339 L
.72352 .66124 L
.73264 .66521 L
.74295 .66968 L
.76239 .67859 L
.77514 .68465 L
.78183 .68777 L
.80126 .69708 L
.81569 .70408 L
.8207 .70647 L
.84014 .71584 L
.85606 .72352 L
.85957 .72518 L
.87901 .73441 L
.89715 .74295 L
.89845 .74356 L
.91788 .75253 L
.93732 .76138 L
.93956 .76239 L
.95675 .77002 L
.97619 .7785 L
.97619 .97619 L
.02381 .97619 L
F
.16 1 0 r
.02381 .84683 m
.03182 .84014 L
.04325 .83069 L
.05561 .8207 L
.06268 .81503 L
.08026 .80126 L
.08212 .79981 L
.10155 .78499 L
.10581 .78183 L
.12099 .77057 L
.13234 .76239 L
.14043 .75656 L
.15986 .74298 L
.1599 .74295 L
.1793 .72971 L
.18872 .72352 L
.19874 .71691 L
.21817 .70462 L
.21905 .70408 L
.23761 .69271 L
.25164 .68465 L
.25705 .68153 L
.27648 .67098 L
.28825 .66521 L
.29592 .66149 L
.31535 .65303 L
.33479 .64632 L
.33672 .64577 L
.35423 .64081 L
.37366 .63601 L
.3931 .6305 L
.4083 .62634 L
.41254 .62397 L
.43197 .61212 L
.43799 .6069 L
.45141 .5924 L
.45514 .58746 L
.4679 .56803 L
.47085 .5596 L
.47622 .54859 L
.4809 .52915 L
.47085 .51807 L
.45141 .52166 L
.43197 .52514 L
.41254 .52735 L
.3931 .52394 L
.37991 .50972 L
.37991 .49028 L
.3931 .47606 L
.41254 .47265 L
.43197 .47486 L
.45141 .47834 L
.47085 .48193 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.5191 .52915 L
.52378 .54859 L
.52915 .5596 L
.5321 .56803 L
.54486 .58746 L
.54859 .5924 L
.56201 .6069 L
.56803 .61212 L
.58746 .62397 L
.5917 .62634 L
.6069 .6305 L
.62634 .63601 L
.64577 .64081 L
.66328 .64577 L
.66521 .64632 L
.68465 .65303 L
.70408 .66149 L
.71175 .66521 L
.72352 .67098 L
.74295 .68153 L
.74836 .68465 L
.76239 .69271 L
.78095 .70408 L
.78183 .70462 L
.80126 .71691 L
.81128 .72352 L
.8207 .72971 L
.8401 .74295 L
.84014 .74298 L
.85957 .75656 L
.86766 .76239 L
.87901 .77057 L
.89419 .78183 L
.89845 .78499 L
.91788 .79981 L
.91974 .80126 L
.93732 .81503 L
.94439 .8207 L
.95675 .83069 L
.96818 .84014 L
.97619 .84683 L
.97619 .97619 L
.02381 .97619 L
F
0 1 .48 r
.14043 .39291 m
.15986 .38781 L
.1793 .3843 L
.19874 .3821 L
.21817 .38102 L
.23761 .38084 L
.25705 .38137 L
.27648 .38233 L
.29592 .38339 L
.31535 .38405 L
.33479 .38379 L
.35423 .38243 L
.37366 .38076 L
.3931 .38068 L
.41254 .38489 L
.43197 .39203 L
.43355 .3931 L
.45141 .40912 L
.45421 .41254 L
.46763 .43197 L
.47085 .4406 L
.47619 .45141 L
.48089 .47085 L
.49028 .47112 L
.50972 .47112 L
.52893 .49028 L
.52893 .50972 L
.52915 .51808 L
.54859 .5217 L
.56803 .52533 L
.58746 .52809 L
.6069 .52649 L
.62575 .50972 L
.62575 .49028 L
.6069 .47351 L
.58746 .47191 L
.56803 .47467 L
.54859 .4783 L
.52915 .48192 L
.51911 .47085 L
.52381 .45141 L
.52915 .4406 L
.53237 .43197 L
.54579 .41254 L
.54859 .40912 L
.56645 .3931 L
.56803 .39203 L
.58746 .38489 L
.6069 .38068 L
.62634 .38076 L
.64577 .38243 L
.66521 .38379 L
.68465 .38405 L
.70408 .38339 L
.72352 .38233 L
.74295 .38137 L
.76239 .38084 L
.78183 .38102 L
.80126 .3821 L
.8207 .3843 L
.84014 .38781 L
.85957 .39291 L
.86019 .3931 L
.87901 .39991 L
.89845 .40945 L
.90362 .41254 L
.91788 .42245 L
.92856 .43197 L
.93732 .44136 L
.94443 .45141 L
.95406 .47085 L
.95675 .47979 L
.95865 .49028 L
.95865 .50972 L
.95675 .52021 L
.95406 .52915 L
.94443 .54859 L
.93732 .55864 L
.92856 .56803 L
.91788 .57755 L
.90362 .58746 L
.89845 .59055 L
.87901 .60009 L
.86019 .6069 L
.85957 .60709 L
.84014 .61219 L
.8207 .6157 L
.80126 .6179 L
.78183 .61898 L
.76239 .61916 L
.74295 .61863 L
.72352 .61767 L
.70408 .61661 L
.68465 .61595 L
.66521 .61621 L
.64577 .61757 L
.62634 .61924 L
.6069 .61932 L
.58746 .61511 L
.56803 .60797 L
.56645 .6069 L
.54859 .59088 L
.54579 .58746 L
.53237 .56803 L
.52915 .5594 L
.52381 .54859 L
.51911 .52915 L
.50972 .52888 L
.49028 .52888 L
.47107 .50972 L
.47107 .49028 L
.47085 .48192 L
.45141 .4783 L
.43197 .47467 L
.41254 .47191 L
.3931 .47351 L
.37425 .49028 L
.37425 .50972 L
.3931 .52649 L
.41254 .52809 L
.43197 .52533 L
.45141 .5217 L
.47085 .51808 L
.48089 .52915 L
.47619 .54859 L
.47085 .5594 L
.46763 .56803 L
.45421 .58746 L
.45141 .59088 L
.43355 .6069 L
.43197 .60797 L
.41254 .61511 L
.3931 .61932 L
.37366 .61924 L
.35423 .61757 L
.33479 .61621 L
.31535 .61595 L
.29592 .61661 L
.27648 .61767 L
.25705 .61863 L
.23761 .61916 L
.21817 .61898 L
.19874 .6179 L
.1793 .6157 L
.15986 .61219 L
.14043 .60709 L
.13981 .6069 L
.12099 .60009 L
.10155 .59055 L
.09638 .58746 L
.08212 .57755 L
.07144 .56803 L
.06268 .55864 L
.05557 .54859 L
.04594 .52915 L
.04325 .52021 L
.04135 .50972 L
.04135 .49028 L
.04325 .47979 L
.04594 .47085 L
.05557 .45141 L
.06268 .44136 L
.07144 .43197 L
.08212 .42245 L
.09638 .41254 L
.10155 .40945 L
.12099 .39991 L
.13981 .3931 L
F
.24 1 0 r
.93821 .02381 m
.93732 .03113 L
.93567 .04325 L
.93129 .06268 L
.92521 .08212 L
.91788 .1008 L
.91752 .10155 L
.90829 .12099 L
.89845 .13897 L
.89755 .14043 L
.88532 .15986 L
.87901 .16919 L
.87159 .1793 L
.85957 .19487 L
.85634 .19874 L
.84014 .21753 L
.83954 .21817 L
.8211 .23761 L
.8207 .23802 L
.80126 .25673 L
.80091 .25705 L
.78183 .27397 L
.77876 .27648 L
.76239 .28985 L
.75428 .29592 L
.74295 .30437 L
.72671 .31535 L
.72352 .31748 L
.70408 .32943 L
.69389 .33479 L
.68465 .33959 L
.66521 .34825 L
.64722 .35423 L
.64577 .3547 L
.62634 .36075 L
.6069 .36752 L
.58871 .37366 L
.58746 .37444 L
.56803 .3872 L
.56145 .3931 L
.54859 .40736 L
.54473 .41254 L
.53206 .43197 L
.52915 .44037 L
.52377 .45141 L
.5191 .47085 L
.52915 .48193 L
.54859 .47834 L
.56803 .47489 L
.58746 .47276 L
.6069 .47643 L
.61946 .49028 L
.61946 .50972 L
.6069 .52357 L
.58746 .52724 L
.56803 .52511 L
.54859 .52166 L
.52915 .51807 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.4809 .47085 L
.47623 .45141 L
.47085 .44037 L
.46794 .43197 L
.45527 .41254 L
.45141 .40736 L
.43855 .3931 L
.43197 .3872 L
.41254 .37444 L
.41129 .37366 L
.3931 .36752 L
.37366 .36075 L
.35423 .3547 L
.35278 .35423 L
.33479 .34825 L
.31535 .33959 L
.30611 .33479 L
.29592 .32943 L
.27648 .31748 L
.27329 .31535 L
.25705 .30437 L
.24572 .29592 L
.23761 .28985 L
.22124 .27648 L
.21817 .27397 L
.19909 .25705 L
.19874 .25673 L
.1793 .23802 L
.1789 .23761 L
.16046 .21817 L
.15986 .21753 L
.14366 .19874 L
.14043 .19487 L
.12841 .1793 L
.12099 .16919 L
.11468 .15986 L
.10245 .14043 L
.10155 .13897 L
.09171 .12099 L
.08248 .10155 L
.08212 .1008 L
.07479 .08212 L
.06871 .06268 L
.06433 .04325 L
.06268 .03113 L
.06179 .02381 L
F
.93821 .97619 m
.93732 .96887 L
.93567 .95675 L
.93129 .93732 L
.92521 .91788 L
.91788 .8992 L
.91752 .89845 L
.90829 .87901 L
.89845 .86103 L
.89755 .85957 L
.88532 .84014 L
.87901 .83081 L
.87159 .8207 L
.85957 .80513 L
.85634 .80126 L
.84014 .78247 L
.83954 .78183 L
.8211 .76239 L
.8207 .76198 L
.80126 .74327 L
.80091 .74295 L
.78183 .72603 L
.77876 .72352 L
.76239 .71015 L
.75428 .70408 L
.74295 .69563 L
.72671 .68465 L
.72352 .68252 L
.70408 .67057 L
.69389 .66521 L
.68465 .66041 L
.66521 .65175 L
.64722 .64577 L
.64577 .6453 L
.62634 .63925 L
.6069 .63248 L
.58871 .62634 L
.58746 .62556 L
.56803 .6128 L
.56145 .6069 L
.54859 .59264 L
.54473 .58746 L
.53206 .56803 L
.52915 .55963 L
.52377 .54859 L
.5191 .52915 L
.50972 .52888 L
.49028 .52888 L
.47107 .50972 L
.47107 .49028 L
.47085 .48193 L
.45141 .47834 L
.43197 .47489 L
.41254 .47276 L
.3931 .47643 L
.38054 .49028 L
.38054 .50972 L
.3931 .52357 L
.41254 .52724 L
.43197 .52511 L
.45141 .52166 L
.47085 .51807 L
.4809 .52915 L
.47623 .54859 L
.47085 .55963 L
.46794 .56803 L
.45527 .58746 L
.45141 .59264 L
.43855 .6069 L
.43197 .6128 L
.41254 .62556 L
.41129 .62634 L
.3931 .63248 L
.37366 .63925 L
.35423 .6453 L
.35278 .64577 L
.33479 .65175 L
.31535 .66041 L
.30611 .66521 L
.29592 .67057 L
.27648 .68252 L
.27329 .68465 L
.25705 .69563 L
.24572 .70408 L
.23761 .71015 L
.22124 .72352 L
.21817 .72603 L
.19909 .74295 L
.19874 .74327 L
.1793 .76198 L
.1789 .76239 L
.16046 .78183 L
.15986 .78247 L
.14366 .80126 L
.14043 .80513 L
.12841 .8207 L
.12099 .83081 L
.11468 .84014 L
.10245 .85957 L
.10155 .86103 L
.09171 .87901 L
.08248 .89845 L
.08212 .8992 L
.07479 .91788 L
.06871 .93732 L
.06433 .95675 L
.06268 .96887 L
.06179 .97619 L
F
0 1 .56 r
.21817 .39059 m
.23761 .38907 L
.25705 .38845 L
.27648 .38842 L
.29592 .38858 L
.31535 .38843 L
.33479 .38738 L
.35423 .38522 L
.37366 .38283 L
.3931 .38216 L
.41254 .38586 L
.43197 .39255 L
.43281 .3931 L
.45141 .40932 L
.45407 .41254 L
.46759 .43197 L
.47085 .44062 L
.47618 .45141 L
.48089 .47085 L
.49028 .47112 L
.50972 .47112 L
.52893 .49028 L
.52893 .50972 L
.52915 .51808 L
.54859 .5217 L
.56803 .52535 L
.58746 .5282 L
.6069 .52686 L
.62634 .51063 L
.62669 .50972 L
.62669 .49028 L
.62634 .48937 L
.6069 .47314 L
.58746 .4718 L
.56803 .47465 L
.54859 .4783 L
.52915 .48192 L
.51911 .47085 L
.52382 .45141 L
.52915 .44062 L
.53241 .43197 L
.54593 .41254 L
.54859 .40932 L
.56719 .3931 L
.56803 .39255 L
.58746 .38586 L
.6069 .38216 L
.62634 .38283 L
.64577 .38522 L
.66521 .38738 L
.68465 .38843 L
.70408 .38858 L
.72352 .38842 L
.74295 .38845 L
.76239 .38907 L
.78183 .39059 L
.80035 .3931 L
.80126 .39326 L
.8207 .39734 L
.84014 .40321 L
.85957 .41138 L
.86187 .41254 L
.87901 .4226 L
.89104 .43197 L
.89845 .43877 L
.90877 .45141 L
.91788 .46679 L
.91934 .47085 L
.92432 .49028 L
.92432 .50972 L
.91934 .52915 L
.91788 .53321 L
.90877 .54859 L
.89845 .56123 L
.89104 .56803 L
.87901 .5774 L
.86187 .58746 L
.85957 .58862 L
.84014 .59679 L
.8207 .60266 L
.80126 .60674 L
.80035 .6069 L
.78183 .60941 L
.76239 .61093 L
.74295 .61155 L
.72352 .61158 L
.70408 .61142 L
.68465 .61157 L
.66521 .61262 L
.64577 .61478 L
.62634 .61717 L
.6069 .61784 L
.58746 .61414 L
.56803 .60745 L
.56719 .6069 L
.54859 .59068 L
.54593 .58746 L
.53241 .56803 L
.52915 .55938 L
.52382 .54859 L
.51911 .52915 L
.50972 .52888 L
.49028 .52888 L
.47107 .50972 L
.47107 .49028 L
.47085 .48192 L
.45141 .4783 L
.43197 .47465 L
.41254 .4718 L
.3931 .47314 L
.37366 .48937 L
.37331 .49028 L
.37331 .50972 L
.37366 .51063 L
.3931 .52686 L
.41254 .5282 L
.43197 .52535 L
.45141 .5217 L
.47085 .51808 L
.48089 .52915 L
.47618 .54859 L
.47085 .55938 L
.46759 .56803 L
.45407 .58746 L
.45141 .59068 L
.43281 .6069 L
.43197 .60745 L
.41254 .61414 L
.3931 .61784 L
.37366 .61717 L
.35423 .61478 L
.33479 .61262 L
.31535 .61157 L
.29592 .61142 L
.27648 .61158 L
.25705 .61155 L
.23761 .61093 L
.21817 .60941 L
.19965 .6069 L
.19874 .60674 L
.1793 .60266 L
.15986 .59679 L
.14043 .58862 L
.13813 .58746 L
.12099 .5774 L
.10896 .56803 L
.10155 .56123 L
.09123 .54859 L
.08212 .53321 L
.08066 .52915 L
.07568 .50972 L
.07568 .49028 L
.08066 .47085 L
.08212 .46679 L
.09123 .45141 L
.10155 .43877 L
.10896 .43197 L
.12099 .4226 L
.13813 .41254 L
.14043 .41138 L
.15986 .40321 L
.1793 .39734 L
.19874 .39326 L
.19965 .3931 L
F
0 1 .64 r
.31535 .3927 m
.33479 .39087 L
.35423 .38791 L
.37366 .3848 L
.3931 .38356 L
.41254 .38677 L
.43197 .39306 L
.43204 .3931 L
.45141 .40952 L
.45393 .41254 L
.46755 .43197 L
.47085 .44065 L
.47618 .45141 L
.48088 .47085 L
.49028 .47112 L
.50972 .47112 L
.52893 .49028 L
.52893 .50972 L
.52915 .51808 L
.54859 .52171 L
.56803 .52538 L
.58746 .5283 L
.6069 .52722 L
.62634 .5125 L
.62752 .50972 L
.62752 .49028 L
.62634 .4875 L
.6069 .47278 L
.58746 .4717 L
.56803 .47462 L
.54859 .47829 L
.52915 .48192 L
.51912 .47085 L
.52382 .45141 L
.52915 .44065 L
.53245 .43197 L
.54607 .41254 L
.54859 .40952 L
.56796 .3931 L
.56803 .39306 L
.58746 .38677 L
.6069 .38356 L
.62634 .3848 L
.64577 .38791 L
.66521 .39087 L
.68465 .3927 L
.69118 .3931 L
.70408 .39365 L
.72352 .39435 L
.74295 .39539 L
.76239 .39718 L
.78183 .40009 L
.80126 .40447 L
.8207 .41077 L
.82512 .41254 L
.84014 .41954 L
.85938 .43197 L
.85957 .43211 L
.87901 .45131 L
.87908 .45141 L
.89056 .47085 L
.89594 .49028 L
.89594 .50972 L
.89056 .52915 L
.87908 .54859 L
.87901 .54869 L
.85957 .56789 L
.85938 .56803 L
.84014 .58046 L
.82512 .58746 L
.8207 .58923 L
.80126 .59553 L
.78183 .59991 L
.76239 .60282 L
.74295 .60461 L
.72352 .60565 L
.70408 .60635 L
.69118 .6069 L
.68465 .6073 L
.66521 .60913 L
.64577 .61209 L
.62634 .6152 L
.6069 .61644 L
.58746 .61323 L
.56803 .60694 L
.56796 .6069 L
.54859 .59048 L
.54607 .58746 L
.53245 .56803 L
.52915 .55935 L
.52382 .54859 L
.51912 .52915 L
.50972 .52888 L
.49028 .52888 L
.47107 .50972 L
.47107 .49028 L
.47085 .48192 L
.45141 .47829 L
.43197 .47462 L
.41254 .4717 L
.3931 .47278 L
.37366 .4875 L
.37248 .49028 L
.37248 .50972 L
.37366 .5125 L
.3931 .52722 L
.41254 .5283 L
.43197 .52538 L
.45141 .52171 L
.47085 .51808 L
.48088 .52915 L
.47618 .54859 L
.47085 .55935 L
.46755 .56803 L
.45393 .58746 L
.45141 .59048 L
.43204 .6069 L
.43197 .60694 L
.41254 .61323 L
.3931 .61644 L
.37366 .6152 L
.35423 .61209 L
.33479 .60913 L
.31535 .6073 L
.30882 .6069 L
.29592 .60635 L
.27648 .60565 L
.25705 .60461 L
.23761 .60282 L
.21817 .59991 L
.19874 .59553 L
.1793 .58923 L
.17488 .58746 L
.15986 .58046 L
.14062 .56803 L
.14043 .56789 L
.12099 .54869 L
.12092 .54859 L
.10944 .52915 L
.10406 .50972 L
.10406 .49028 L
.10944 .47085 L
.12092 .45141 L
.12099 .45131 L
.14043 .43211 L
.14062 .43197 L
.15986 .41954 L
.17488 .41254 L
.1793 .41077 L
.19874 .40447 L
.21817 .40009 L
.23761 .39718 L
.25705 .39539 L
.27648 .39435 L
.29592 .39365 L
.30882 .3931 L
F
0 1 .72 r
.35423 .39054 m
.37366 .3867 L
.3931 .3849 L
.41254 .38762 L
.43116 .3931 L
.43197 .39356 L
.45141 .40971 L
.45379 .41254 L
.46751 .43197 L
.47085 .44068 L
.47617 .45141 L
.48088 .47085 L
.49028 .47112 L
.50972 .47112 L
.52893 .49028 L
.52893 .50972 L
.52915 .51808 L
.54859 .52172 L
.56803 .52541 L
.58746 .52841 L
.6069 .52758 L
.62634 .51421 L
.6284 .50972 L
.6284 .49028 L
.62634 .48579 L
.6069 .47242 L
.58746 .47159 L
.56803 .47459 L
.54859 .47828 L
.52915 .48192 L
.51912 .47085 L
.52383 .45141 L
.52915 .44068 L
.53249 .43197 L
.54621 .41254 L
.54859 .40971 L
.56803 .39356 L
.56884 .3931 L
.58746 .38762 L
.6069 .3849 L
.62634 .3867 L
.64577 .39054 L
.65705 .3931 L
.66521 .39429 L
.68465 .39692 L
.70408 .39865 L
.72352 .40022 L
.74295 .40226 L
.76239 .40527 L
.78183 .40971 L
.79129 .41254 L
.80126 .41604 L
.8207 .42502 L
.83192 .43197 L
.84014 .43793 L
.85371 .45141 L
.85957 .45811 L
.86613 .47085 L
.87189 .49028 L
.87189 .50972 L
.86613 .52915 L
.85957 .54189 L
.85371 .54859 L
.84014 .56207 L
.83192 .56803 L
.8207 .57498 L
.80126 .58396 L
.79129 .58746 L
.78183 .59029 L
.76239 .59473 L
.74295 .59774 L
.72352 .59978 L
.70408 .60135 L
.68465 .60308 L
.66521 .60571 L
.65705 .6069 L
.64577 .60946 L
.62634 .6133 L
.6069 .6151 L
.58746 .61238 L
.56884 .6069 L
.56803 .60644 L
.54859 .59029 L
.54621 .58746 L
.53249 .56803 L
.52915 .55932 L
.52383 .54859 L
.51912 .52915 L
.50972 .52888 L
.49028 .52888 L
.47107 .50972 L
.47107 .49028 L
.47085 .48192 L
.45141 .47828 L
.43197 .47459 L
.41254 .47159 L
.3931 .47242 L
.37366 .48579 L
.3716 .49028 L
.3716 .50972 L
.37366 .51421 L
.3931 .52758 L
.41254 .52841 L
.43197 .52541 L
.45141 .52172 L
.47085 .51808 L
.48088 .52915 L
.47617 .54859 L
.47085 .55932 L
.46751 .56803 L
.45379 .58746 L
.45141 .59029 L
.43197 .60644 L
.43116 .6069 L
.41254 .61238 L
.3931 .6151 L
.37366 .6133 L
.35423 .60946 L
.34295 .6069 L
.33479 .60571 L
.31535 .60308 L
.29592 .60135 L
.27648 .59978 L
.25705 .59774 L
.23761 .59473 L
.21817 .59029 L
.20871 .58746 L
.19874 .58396 L
.1793 .57498 L
.16808 .56803 L
.15986 .56207 L
.14629 .54859 L
.14043 .54189 L
.13387 .52915 L
.12811 .50972 L
.12811 .49028 L
.13387 .47085 L
.14043 .45811 L
.14629 .45141 L
.15986 .43793 L
.16808 .43197 L
.1793 .42502 L
.19874 .41604 L
.20871 .41254 L
.21817 .40971 L
.23761 .40527 L
.25705 .40226 L
.27648 .40022 L
.29592 .39865 L
.31535 .39692 L
.33479 .39429 L
.34295 .3931 L
F
0 1 .8 r
.37366 .38852 m
.3931 .38616 L
.41254 .38841 L
.43022 .3931 L
.43197 .39406 L
.45141 .4099 L
.45365 .41254 L
.46747 .43197 L
.47085 .4407 L
.47617 .45141 L
.48088 .47085 L
.49028 .47112 L
.50972 .47112 L
.52893 .49028 L
.52893 .50972 L
.52915 .51809 L
.54859 .52172 L
.56803 .52543 L
.58746 .52852 L
.6069 .52795 L
.62634 .5158 L
.62933 .50972 L
.62933 .49028 L
.62634 .4842 L
.6069 .47205 L
.58746 .47148 L
.56803 .47457 L
.54859 .47828 L
.52915 .48191 L
.51912 .47085 L
.52383 .45141 L
.52915 .4407 L
.53253 .43197 L
.54635 .41254 L
.54859 .4099 L
.56803 .39406 L
.56978 .3931 L
.58746 .38841 L
.6069 .38616 L
.62634 .38852 L
.64574 .3931 L
.64577 .39311 L
.66521 .39769 L
.68465 .40109 L
.70408 .40361 L
.72352 .40605 L
.74295 .40914 L
.75874 .41254 L
.76239 .41346 L
.78183 .41956 L
.80126 .42834 L
.80755 .43197 L
.8207 .44098 L
.8316 .45141 L
.84014 .46132 L
.84497 .47085 L
.8511 .49028 L
.8511 .50972 L
.84497 .52915 L
.84014 .53868 L
.8316 .54859 L
.8207 .55902 L
.80755 .56803 L
.80126 .57166 L
.78183 .58044 L
.76239 .58654 L
.75874 .58746 L
.74295 .59086 L
.72352 .59395 L
.70408 .59639 L
.68465 .59891 L
.66521 .60231 L
.64577 .60689 L
.64574 .6069 L
.62634 .61148 L
.6069 .61384 L
.58746 .61159 L
.56978 .6069 L
.56803 .60594 L
.54859 .5901 L
.54635 .58746 L
.53253 .56803 L
.52915 .5593 L
.52383 .54859 L
.51912 .52915 L
.50972 .52888 L
.49028 .52888 L
.47107 .50972 L
.47107 .49028 L
.47085 .48191 L
.45141 .47828 L
.43197 .47457 L
.41254 .47148 L
.3931 .47205 L
.37366 .4842 L
.37067 .49028 L
.37067 .50972 L
.37366 .5158 L
.3931 .52795 L
.41254 .52852 L
.43197 .52543 L
.45141 .52172 L
.47085 .51809 L
.48088 .52915 L
.47617 .54859 L
.47085 .5593 L
.46747 .56803 L
.45365 .58746 L
.45141 .5901 L
.43197 .60594 L
.43022 .6069 L
.41254 .61159 L
.3931 .61384 L
.37366 .61148 L
.35426 .6069 L
.35423 .60689 L
.33479 .60231 L
.31535 .59891 L
.29592 .59639 L
.27648 .59395 L
.25705 .59086 L
.24126 .58746 L
.23761 .58654 L
.21817 .58044 L
.19874 .57166 L
.19245 .56803 L
.1793 .55902 L
.1684 .54859 L
.15986 .53868 L
.15503 .52915 L
.1489 .50972 L
.1489 .49028 L
.15503 .47085 L
.15986 .46132 L
.1684 .45141 L
.1793 .44098 L
.19245 .43197 L
.19874 .42834 L
.21817 .41956 L
.23761 .41346 L
.24126 .41254 L
.25705 .40914 L
.27648 .40605 L
.29592 .40361 L
.31535 .40109 L
.33479 .39769 L
.35423 .39311 L
.35426 .3931 L
F
0 1 .88 r
.37366 .39029 m
.3931 .38737 L
.41254 .38914 L
.4292 .3931 L
.43197 .39454 L
.45141 .41009 L
.45351 .41254 L
.46743 .43197 L
.47085 .44073 L
.47616 .45141 L
.48088 .47085 L
.49028 .47113 L
.50972 .47113 L
.52893 .49028 L
.52893 .50972 L
.52915 .51809 L
.54859 .52173 L
.56803 .52546 L
.58746 .52862 L
.6069 .52832 L
.62634 .5173 L
.63031 .50972 L
.63031 .49028 L
.62634 .4827 L
.6069 .47168 L
.58746 .47138 L
.56803 .47454 L
.54859 .47827 L
.52915 .48191 L
.51912 .47085 L
.52384 .45141 L
.52915 .44073 L
.53257 .43197 L
.54649 .41254 L
.54859 .41009 L
.56803 .39454 L
.5708 .3931 L
.58746 .38914 L
.6069 .38737 L
.62634 .39029 L
.63618 .3931 L
.64577 .39563 L
.66521 .40107 L
.68465 .40526 L
.70408 .40856 L
.72352 .41189 L
.72686 .41254 L
.74295 .41606 L
.76239 .42182 L
.78183 .43004 L
.7855 .43197 L
.80126 .44184 L
.81199 .45141 L
.8207 .46065 L
.82634 .47085 L
.83285 .49028 L
.83285 .50972 L
.82634 .52915 L
.8207 .53935 L
.81199 .54859 L
.80126 .55816 L
.7855 .56803 L
.78183 .56996 L
.76239 .57818 L
.74295 .58394 L
.72686 .58746 L
.72352 .58811 L
.70408 .59144 L
.68465 .59474 L
.66521 .59893 L
.64577 .60437 L
.63618 .6069 L
.62634 .60971 L
.6069 .61263 L
.58746 .61086 L
.5708 .6069 L
.56803 .60546 L
.54859 .58991 L
.54649 .58746 L
.53257 .56803 L
.52915 .55927 L
.52384 .54859 L
.51912 .52915 L
.50972 .52887 L
.49028 .52887 L
.47107 .50972 L
.47107 .49028 L
.47085 .48191 L
.45141 .47827 L
.43197 .47454 L
.41254 .47138 L
.3931 .47168 L
.37366 .4827 L
.36969 .49028 L
.36969 .50972 L
.37366 .5173 L
.3931 .52832 L
.41254 .52862 L
.43197 .52546 L
.45141 .52173 L
.47085 .51809 L
.48088 .52915 L
.47616 .54859 L
.47085 .55927 L
.46743 .56803 L
.45351 .58746 L
.45141 .58991 L
.43197 .60546 L
.4292 .6069 L
.41254 .61086 L
.3931 .61263 L
.37366 .60971 L
.36382 .6069 L
.35423 .60437 L
.33479 .59893 L
.31535 .59474 L
.29592 .59144 L
.27648 .58811 L
.27314 .58746 L
.25705 .58394 L
.23761 .57818 L
.21817 .56996 L
.2145 .56803 L
.19874 .55816 L
.18801 .54859 L
.1793 .53935 L
.17366 .52915 L
.16715 .50972 L
.16715 .49028 L
.17366 .47085 L
.1793 .46065 L
.18801 .45141 L
.19874 .44184 L
.2145 .43197 L
.21817 .43004 L
.23761 .42182 L
.25705 .41606 L
.27314 .41254 L
.27648 .41189 L
.29592 .40856 L
.31535 .40526 L
.33479 .40107 L
.35423 .39563 L
.36382 .3931 L
F
.32 1 0 r
.21817 .04181 m
.23761 .03386 L
.25705 .02987 L
.27648 .02877 L
.29592 .02992 L
.31535 .03291 L
.33479 .0374 L
.35423 .04308 L
.35475 .04325 L
.37366 .04964 L
.3931 .05668 L
.40946 .06268 L
.41254 .06379 L
.43197 .07047 L
.45141 .07616 L
.47085 .08032 L
.48491 .08212 L
.49028 .08252 L
.50972 .08252 L
.51509 .08212 L
.52915 .08032 L
.54859 .07616 L
.56803 .07047 L
.58746 .06379 L
.59054 .06268 L
.6069 .05668 L
.62634 .04964 L
.64525 .04325 L
.64577 .04308 L
.66521 .0374 L
.68465 .03291 L
.70408 .02992 L
.72352 .02877 L
.74295 .02987 L
.76239 .03386 L
.78183 .04181 L
.78442 .04325 L
.80126 .05612 L
.80723 .06268 L
.819 .08212 L
.8207 .08575 L
.825 .10155 L
.82702 .12099 L
.82592 .14043 L
.82216 .15986 L
.8207 .16633 L
.81603 .1793 L
.80766 .19874 L
.80126 .21152 L
.79714 .21817 L
.78446 .23761 L
.78183 .2414 L
.76953 .25705 L
.76239 .26564 L
.75217 .27648 L
.74295 .28598 L
.73197 .29592 L
.72352 .30343 L
.70806 .31535 L
.70408 .31835 L
.68465 .33127 L
.67807 .33479 L
.66521 .34179 L
.64577 .3504 L
.6341 .35423 L
.62634 .35711 L
.6069 .36521 L
.58746 .37292 L
.58615 .37366 L
.56803 .3865 L
.56091 .3931 L
.54859 .40713 L
.5446 .41254 L
.53202 .43197 L
.52915 .44034 L
.52377 .45141 L
.5191 .47085 L
.52915 .48193 L
.54859 .47835 L
.56803 .47491 L
.58746 .47286 L
.6069 .47679 L
.61885 .49028 L
.61885 .50972 L
.6069 .52321 L
.58746 .52714 L
.56803 .52509 L
.54859 .52165 L
.52915 .51807 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.4809 .47085 L
.47623 .45141 L
.47085 .44034 L
.46798 .43197 L
.4554 .41254 L
.45141 .40713 L
.43909 .3931 L
.43197 .3865 L
.41385 .37366 L
.41254 .37292 L
.3931 .36521 L
.37366 .35711 L
.3659 .35423 L
.35423 .3504 L
.33479 .34179 L
.32193 .33479 L
.31535 .33127 L
.29592 .31835 L
.29194 .31535 L
.27648 .30343 L
.26803 .29592 L
.25705 .28598 L
.24783 .27648 L
.23761 .26564 L
.23047 .25705 L
.21817 .2414 L
.21554 .23761 L
.20286 .21817 L
.19874 .21152 L
.19234 .19874 L
.18397 .1793 L
.1793 .16633 L
.17784 .15986 L
.17408 .14043 L
.17298 .12099 L
.175 .10155 L
.1793 .08575 L
.181 .08212 L
.19277 .06268 L
.19874 .05612 L
.21558 .04325 L
F
.3931 .47679 m
.41254 .47286 L
.43197 .47491 L
.45141 .47835 L
.47085 .48193 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.5191 .52915 L
.52377 .54859 L
.52915 .55966 L
.53202 .56803 L
.5446 .58746 L
.54859 .59287 L
.56091 .6069 L
.56803 .6135 L
.58615 .62634 L
.58746 .62708 L
.6069 .63479 L
.62634 .64289 L
.6341 .64577 L
.64577 .6496 L
.66521 .65821 L
.67807 .66521 L
.68465 .66873 L
.70408 .68165 L
.70806 .68465 L
.72352 .69657 L
.73197 .70408 L
.74295 .71402 L
.75217 .72352 L
.76239 .73436 L
.76953 .74295 L
.78183 .7586 L
.78446 .76239 L
.79714 .78183 L
.80126 .78848 L
.80766 .80126 L
.81603 .8207 L
.8207 .83367 L
.82216 .84014 L
.82592 .85957 L
.82702 .87901 L
.825 .89845 L
.8207 .91425 L
.819 .91788 L
.80723 .93732 L
.80126 .94388 L
.78442 .95675 L
.78183 .95819 L
.76239 .96614 L
.74295 .97013 L
.72352 .97123 L
.70408 .97008 L
.68465 .96709 L
.66521 .9626 L
.64577 .95692 L
.64525 .95675 L
.62634 .95036 L
.6069 .94332 L
.59054 .93732 L
.58746 .93621 L
.56803 .92953 L
.54859 .92384 L
.52915 .91968 L
.51509 .91788 L
.50972 .91748 L
.49028 .91748 L
.48491 .91788 L
.47085 .91968 L
.45141 .92384 L
.43197 .92953 L
.41254 .93621 L
.40946 .93732 L
.3931 .94332 L
.37366 .95036 L
.35475 .95675 L
.35423 .95692 L
.33479 .9626 L
.31535 .96709 L
.29592 .97008 L
.27648 .97123 L
.25705 .97013 L
.23761 .96614 L
.21817 .95819 L
.21558 .95675 L
.19874 .94388 L
.19277 .93732 L
.181 .91788 L
.1793 .91425 L
.175 .89845 L
.17298 .87901 L
.17408 .85957 L
.17784 .84014 L
.1793 .83367 L
.18397 .8207 L
.19234 .80126 L
.19874 .78848 L
.20286 .78183 L
.21554 .76239 L
.21817 .7586 L
.23047 .74295 L
.23761 .73436 L
.24783 .72352 L
.25705 .71402 L
.26803 .70408 L
.27648 .69657 L
.29194 .68465 L
.29592 .68165 L
.31535 .66873 L
.32193 .66521 L
.33479 .65821 L
.35423 .6496 L
.3659 .64577 L
.37366 .64289 L
.3931 .63479 L
.41254 .62708 L
.41385 .62634 L
.43197 .6135 L
.43909 .6069 L
.45141 .59287 L
.4554 .58746 L
.46798 .56803 L
.47085 .55966 L
.47623 .54859 L
.4809 .52915 L
.47085 .51807 L
.45141 .52165 L
.43197 .52509 L
.41254 .52714 L
.3931 .52321 L
.38115 .50972 L
.38115 .49028 L
F
0 1 .96 r
.37366 .39201 m
.3931 .38852 L
.41254 .38982 L
.4281 .3931 L
.43197 .395 L
.45141 .41028 L
.45337 .41254 L
.46739 .43197 L
.47085 .44076 L
.47616 .45141 L
.48088 .47085 L
.49028 .47113 L
.50972 .47113 L
.52893 .49028 L
.52893 .50972 L
.52915 .51809 L
.54859 .52173 L
.56803 .52549 L
.58746 .52873 L
.6069 .52868 L
.62634 .51873 L
.63136 .50972 L
.63136 .49028 L
.62634 .48127 L
.6069 .47132 L
.58746 .47127 L
.56803 .47451 L
.54859 .47827 L
.52915 .48191 L
.51912 .47085 L
.52384 .45141 L
.52915 .44076 L
.53261 .43197 L
.54663 .41254 L
.54859 .41028 L
.56803 .395 L
.5719 .3931 L
.58746 .38982 L
.6069 .38852 L
.62634 .39201 L
.62957 .3931 L
.64577 .39813 L
.66521 .40446 L
.68465 .40945 L
.69929 .41254 L
.70408 .41353 L
.72352 .41776 L
.74295 .42315 L
.76239 .43064 L
.7652 .43197 L
.78183 .44126 L
.79434 .45141 L
.80126 .45769 L
.80969 .47085 L
.81659 .49028 L
.81659 .50972 L
.80969 .52915 L
.80126 .54231 L
.79434 .54859 L
.78183 .55874 L
.7652 .56803 L
.76239 .56936 L
.74295 .57685 L
.72352 .58224 L
.70408 .58647 L
.69929 .58746 L
.68465 .59055 L
.66521 .59554 L
.64577 .60187 L
.62957 .6069 L
.62634 .60799 L
.6069 .61148 L
.58746 .61018 L
.5719 .6069 L
.56803 .605 L
.54859 .58972 L
.54663 .58746 L
.53261 .56803 L
.52915 .55924 L
.52384 .54859 L
.51912 .52915 L
.50972 .52887 L
.49028 .52887 L
.47107 .50972 L
.47107 .49028 L
.47085 .48191 L
.45141 .47827 L
.43197 .47451 L
.41254 .47127 L
.3931 .47132 L
.37366 .48127 L
.36864 .49028 L
.36864 .50972 L
.37366 .51873 L
.3931 .52868 L
.41254 .52873 L
.43197 .52549 L
.45141 .52173 L
.47085 .51809 L
.48088 .52915 L
.47616 .54859 L
.47085 .55924 L
.46739 .56803 L
.45337 .58746 L
.45141 .58972 L
.43197 .605 L
.4281 .6069 L
.41254 .61018 L
.3931 .61148 L
.37366 .60799 L
.37043 .6069 L
.35423 .60187 L
.33479 .59554 L
.31535 .59055 L
.30071 .58746 L
.29592 .58647 L
.27648 .58224 L
.25705 .57685 L
.23761 .56936 L
.2348 .56803 L
.21817 .55874 L
.20566 .54859 L
.19874 .54231 L
.19031 .52915 L
.18341 .50972 L
.18341 .49028 L
.19031 .47085 L
.19874 .45769 L
.20566 .45141 L
.21817 .44126 L
.2348 .43197 L
.23761 .43064 L
.25705 .42315 L
.27648 .41776 L
.29592 .41353 L
.30071 .41254 L
.31535 .40945 L
.33479 .40446 L
.35423 .39813 L
.37043 .3931 L
F
0 .96 1 r
.3931 .38962 m
.41254 .39045 L
.42688 .3931 L
.43197 .39546 L
.45141 .41047 L
.45323 .41254 L
.46735 .43197 L
.47085 .44078 L
.47615 .45141 L
.48088 .47085 L
.49028 .47113 L
.50972 .47113 L
.52893 .49028 L
.52893 .50972 L
.52915 .51809 L
.54859 .52174 L
.56803 .52551 L
.58746 .52884 L
.6069 .52905 L
.62634 .52012 L
.63248 .50972 L
.63248 .49028 L
.62634 .47988 L
.6069 .47095 L
.58746 .47116 L
.56803 .47449 L
.54859 .47826 L
.52915 .48191 L
.51912 .47085 L
.52385 .45141 L
.52915 .44078 L
.53265 .43197 L
.54677 .41254 L
.54859 .41047 L
.56803 .39546 L
.57312 .3931 L
.58746 .39045 L
.6069 .38962 L
.62465 .3931 L
.62634 .3937 L
.64577 .40064 L
.66521 .4079 L
.68028 .41254 L
.68465 .41366 L
.70408 .41852 L
.72352 .42377 L
.74295 .43056 L
.74629 .43197 L
.76239 .4399 L
.77824 .45141 L
.78183 .45412 L
.79464 .47085 L
.80126 .48715 L
.80193 .49028 L
.80193 .50972 L
.80126 .51285 L
.79464 .52915 L
.78183 .54588 L
.77824 .54859 L
.76239 .5601 L
.74629 .56803 L
.74295 .56944 L
.72352 .57623 L
.70408 .58148 L
.68465 .58634 L
.68028 .58746 L
.66521 .5921 L
.64577 .59936 L
.62634 .6063 L
.62465 .6069 L
.6069 .61038 L
.58746 .60955 L
.57312 .6069 L
.56803 .60454 L
.54859 .58953 L
.54677 .58746 L
.53265 .56803 L
.52915 .55922 L
.52385 .54859 L
.51912 .52915 L
.50972 .52887 L
.49028 .52887 L
.47107 .50972 L
.47107 .49028 L
.47085 .48191 L
.45141 .47826 L
.43197 .47449 L
.41254 .47116 L
.3931 .47095 L
.37366 .47988 L
.36752 .49028 L
.36752 .50972 L
.37366 .52012 L
.3931 .52905 L
.41254 .52884 L
.43197 .52551 L
.45141 .52174 L
.47085 .51809 L
.48088 .52915 L
.47615 .54859 L
.47085 .55922 L
.46735 .56803 L
.45323 .58746 L
.45141 .58953 L
.43197 .60454 L
.42688 .6069 L
.41254 .60955 L
.3931 .61038 L
.37535 .6069 L
.37366 .6063 L
.35423 .59936 L
.33479 .5921 L
.31972 .58746 L
.31535 .58634 L
.29592 .58148 L
.27648 .57623 L
.25705 .56944 L
.25371 .56803 L
.23761 .5601 L
.22176 .54859 L
.21817 .54588 L
.20536 .52915 L
.19874 .51285 L
.19807 .50972 L
.19807 .49028 L
.19874 .48715 L
.20536 .47085 L
.21817 .45412 L
.22176 .45141 L
.23761 .4399 L
.25371 .43197 L
.25705 .43056 L
.27648 .42377 L
.29592 .41852 L
.31535 .41366 L
.31972 .41254 L
.33479 .4079 L
.35423 .40064 L
.37366 .3937 L
.37535 .3931 L
F
0 .88 1 r
.3931 .39067 m
.41254 .39103 L
.42552 .3931 L
.43197 .39591 L
.45141 .41065 L
.45309 .41254 L
.46731 .43197 L
.47085 .44081 L
.47615 .45141 L
.48088 .47085 L
.49028 .47113 L
.50972 .47113 L
.52893 .49028 L
.52893 .50972 L
.52915 .51809 L
.54859 .52174 L
.56803 .52554 L
.58746 .52895 L
.58833 .52915 L
.6069 .52945 L
.6098 .52915 L
.62634 .52147 L
.6337 .50972 L
.6337 .49028 L
.62634 .47853 L
.6098 .47085 L
.6069 .47055 L
.58833 .47085 L
.58746 .47105 L
.56803 .47446 L
.54859 .47826 L
.52915 .48191 L
.51912 .47085 L
.52385 .45141 L
.52915 .44081 L
.53269 .43197 L
.54691 .41254 L
.54859 .41065 L
.56803 .39591 L
.57448 .3931 L
.58746 .39103 L
.6069 .39067 L
.62024 .3931 L
.62634 .39537 L
.64577 .40317 L
.66521 .4114 L
.66806 .41254 L
.68465 .41789 L
.70408 .42365 L
.72352 .43003 L
.7286 .43197 L
.74295 .43821 L
.76239 .45059 L
.76339 .45141 L
.78087 .47085 L
.78183 .47245 L
.78856 .49028 L
.78856 .50972 L
.78183 .52755 L
.78087 .52915 L
.76339 .54859 L
.76239 .54941 L
.74295 .56179 L
.7286 .56803 L
.72352 .56997 L
.70408 .57635 L
.68465 .58211 L
.66806 .58746 L
.66521 .5886 L
.64577 .59683 L
.62634 .60463 L
.62024 .6069 L
.6069 .60933 L
.58746 .60897 L
.57448 .6069 L
.56803 .60409 L
.54859 .58935 L
.54691 .58746 L
.53269 .56803 L
.52915 .55919 L
.52385 .54859 L
.51912 .52915 L
.50972 .52887 L
.49028 .52887 L
.47107 .50972 L
.47107 .49028 L
.47085 .48191 L
.45141 .47826 L
.43197 .47446 L
.41254 .47105 L
.41167 .47085 L
.3931 .47055 L
.3902 .47085 L
.37366 .47853 L
.3663 .49028 L
.3663 .50972 L
.37366 .52147 L
.3902 .52915 L
.3931 .52945 L
.41167 .52915 L
.41254 .52895 L
.43197 .52554 L
.45141 .52174 L
.47085 .51809 L
.48088 .52915 L
.47615 .54859 L
.47085 .55919 L
.46731 .56803 L
.45309 .58746 L
.45141 .58935 L
.43197 .60409 L
.42552 .6069 L
.41254 .60897 L
.3931 .60933 L
.37976 .6069 L
.37366 .60463 L
.35423 .59683 L
.33479 .5886 L
.33194 .58746 L
.31535 .58211 L
.29592 .57635 L
.27648 .56997 L
.2714 .56803 L
.25705 .56179 L
.23761 .54941 L
.23661 .54859 L
.21913 .52915 L
.21817 .52755 L
.21144 .50972 L
.21144 .49028 L
.21817 .47245 L
.21913 .47085 L
.23661 .45141 L
.23761 .45059 L
.25705 .43821 L
.2714 .43197 L
.27648 .43003 L
.29592 .42365 L
.31535 .41789 L
.33194 .41254 L
.33479 .4114 L
.35423 .40317 L
.37366 .39537 L
.37976 .3931 L
F
0 .8 1 r
.3931 .39168 m
.41254 .39157 L
.42396 .3931 L
.43197 .39635 L
.45141 .41083 L
.45294 .41254 L
.46726 .43197 L
.47085 .44084 L
.47614 .45141 L
.48088 .47085 L
.49028 .47113 L
.50972 .47113 L
.52893 .49028 L
.52893 .50972 L
.52915 .51809 L
.54859 .52175 L
.56803 .52557 L
.58746 .52906 L
.58786 .52915 L
.6069 .52985 L
.61307 .52915 L
.62634 .52279 L
.63504 .50972 L
.63504 .49028 L
.62634 .47721 L
.61307 .47085 L
.6069 .47015 L
.58786 .47085 L
.58746 .47094 L
.56803 .47443 L
.54859 .47825 L
.52915 .48191 L
.51912 .47085 L
.52386 .45141 L
.52915 .44084 L
.53274 .43197 L
.54706 .41254 L
.54859 .41083 L
.56803 .39635 L
.57604 .3931 L
.58746 .39157 L
.6069 .39168 L
.61569 .3931 L
.62634 .39702 L
.64577 .40574 L
.65921 .41254 L
.66521 .41478 L
.68465 .42227 L
.70408 .42898 L
.71224 .43197 L
.72352 .43642 L
.74295 .44671 L
.74952 .45141 L
.76239 .46234 L
.76814 .47085 L
.77625 .49028 L
.77625 .50972 L
.76814 .52915 L
.76239 .53766 L
.74952 .54859 L
.74295 .55329 L
.72352 .56358 L
.71224 .56803 L
.70408 .57102 L
.68465 .57773 L
.66521 .58522 L
.65921 .58746 L
.64577 .59426 L
.62634 .60298 L
.61569 .6069 L
.6069 .60832 L
.58746 .60843 L
.57604 .6069 L
.56803 .60365 L
.54859 .58917 L
.54706 .58746 L
.53274 .56803 L
.52915 .55916 L
.52386 .54859 L
.51912 .52915 L
.50972 .52887 L
.49028 .52887 L
.47107 .50972 L
.47107 .49028 L
.47085 .48191 L
.45141 .47825 L
.43197 .47443 L
.41254 .47094 L
.41214 .47085 L
.3931 .47015 L
.38693 .47085 L
.37366 .47721 L
.36496 .49028 L
.36496 .50972 L
.37366 .52279 L
.38693 .52915 L
.3931 .52985 L
.41214 .52915 L
.41254 .52906 L
.43197 .52557 L
.45141 .52175 L
.47085 .51809 L
.48088 .52915 L
.47614 .54859 L
.47085 .55916 L
.46726 .56803 L
.45294 .58746 L
.45141 .58917 L
.43197 .60365 L
.42396 .6069 L
.41254 .60843 L
.3931 .60832 L
.38431 .6069 L
.37366 .60298 L
.35423 .59426 L
.34079 .58746 L
.33479 .58522 L
.31535 .57773 L
.29592 .57102 L
.28776 .56803 L
.27648 .56358 L
.25705 .55329 L
.25048 .54859 L
.23761 .53766 L
.23186 .52915 L
.22375 .50972 L
.22375 .49028 L
.23186 .47085 L
.23761 .46234 L
.25048 .45141 L
.25705 .44671 L
.27648 .43642 L
.28776 .43197 L
.29592 .42898 L
.31535 .42227 L
.33479 .41478 L
.34079 .41254 L
.35423 .40574 L
.37366 .39702 L
.38431 .3931 L
F
.4 1 0 r
.27648 .11372 m
.29592 .10733 L
.31535 .10476 L
.33479 .10484 L
.35423 .10689 L
.37366 .11034 L
.3931 .11472 L
.41254 .11951 L
.41852 .12099 L
.43197 .12421 L
.45141 .12831 L
.47085 .13133 L
.49028 .13293 L
.50972 .13293 L
.52915 .13133 L
.54859 .12831 L
.56803 .12421 L
.58148 .12099 L
.58746 .11951 L
.6069 .11472 L
.62634 .11034 L
.64577 .10689 L
.66521 .10484 L
.68465 .10476 L
.70408 .10733 L
.72352 .11372 L
.73627 .12099 L
.74295 .12647 L
.75459 .14043 L
.76239 .15742 L
.76299 .15986 L
.76585 .1793 L
.76467 .19874 L
.76239 .2102 L
.76016 .21817 L
.75267 .23761 L
.74295 .2563 L
.74231 .25705 L
.72898 .27648 L
.72352 .28374 L
.71232 .29592 L
.70408 .30457 L
.69143 .31535 L
.68465 .32103 L
.66521 .33413 L
.66389 .33479 L
.64577 .34516 L
.62634 .35349 L
.62364 .35423 L
.6069 .36253 L
.58746 .37144 L
.5839 .37366 L
.56803 .38575 L
.56037 .3931 L
.54859 .40688 L
.54447 .41254 L
.53198 .43197 L
.52915 .44031 L
.52376 .45141 L
.5191 .47085 L
.52915 .48193 L
.54859 .47836 L
.56803 .47494 L
.58746 .47297 L
.6069 .47716 L
.61827 .49028 L
.61827 .50972 L
.6069 .52284 L
.58746 .52703 L
.56803 .52506 L
.54859 .52164 L
.52915 .51807 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.4809 .47085 L
.47624 .45141 L
.47085 .44031 L
.46802 .43197 L
.45553 .41254 L
.45141 .40688 L
.43963 .3931 L
.43197 .38575 L
.4161 .37366 L
.41254 .37144 L
.3931 .36253 L
.37636 .35423 L
.37366 .35349 L
.35423 .34516 L
.33611 .33479 L
.33479 .33413 L
.31535 .32103 L
.30857 .31535 L
.29592 .30457 L
.28768 .29592 L
.27648 .28374 L
.27102 .27648 L
.25769 .25705 L
.25705 .2563 L
.24733 .23761 L
.23984 .21817 L
.23761 .2102 L
.23533 .19874 L
.23415 .1793 L
.23701 .15986 L
.23761 .15742 L
.24541 .14043 L
.25705 .12647 L
.26373 .12099 L
F
.3931 .47716 m
.41254 .47297 L
.43197 .47494 L
.45141 .47836 L
.47085 .48193 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.5191 .52915 L
.52376 .54859 L
.52915 .55969 L
.53198 .56803 L
.54447 .58746 L
.54859 .59312 L
.56037 .6069 L
.56803 .61425 L
.5839 .62634 L
.58746 .62856 L
.6069 .63747 L
.62364 .64577 L
.62634 .64651 L
.64577 .65484 L
.66389 .66521 L
.66521 .66587 L
.68465 .67897 L
.69143 .68465 L
.70408 .69543 L
.71232 .70408 L
.72352 .71626 L
.72898 .72352 L
.74231 .74295 L
.74295 .7437 L
.75267 .76239 L
.76016 .78183 L
.76239 .7898 L
.76467 .80126 L
.76585 .8207 L
.76299 .84014 L
.76239 .84258 L
.75459 .85957 L
.74295 .87353 L
.73627 .87901 L
.72352 .88628 L
.70408 .89267 L
.68465 .89524 L
.66521 .89516 L
.64577 .89311 L
.62634 .88966 L
.6069 .88528 L
.58746 .88049 L
.58148 .87901 L
.56803 .87579 L
.54859 .87169 L
.52915 .86867 L
.50972 .86707 L
.49028 .86707 L
.47085 .86867 L
.45141 .87169 L
.43197 .87579 L
.41852 .87901 L
.41254 .88049 L
.3931 .88528 L
.37366 .88966 L
.35423 .89311 L
.33479 .89516 L
.31535 .89524 L
.29592 .89267 L
.27648 .88628 L
.26373 .87901 L
.25705 .87353 L
.24541 .85957 L
.23761 .84258 L
.23701 .84014 L
.23415 .8207 L
.23533 .80126 L
.23761 .7898 L
.23984 .78183 L
.24733 .76239 L
.25705 .7437 L
.25769 .74295 L
.27102 .72352 L
.27648 .71626 L
.28768 .70408 L
.29592 .69543 L
.30857 .68465 L
.31535 .67897 L
.33479 .66587 L
.33611 .66521 L
.35423 .65484 L
.37366 .64651 L
.37636 .64577 L
.3931 .63747 L
.41254 .62856 L
.4161 .62634 L
.43197 .61425 L
.43963 .6069 L
.45141 .59312 L
.45553 .58746 L
.46802 .56803 L
.47085 .55969 L
.47624 .54859 L
.4809 .52915 L
.47085 .51807 L
.45141 .52164 L
.43197 .52506 L
.41254 .52703 L
.3931 .52284 L
.38173 .50972 L
.38173 .49028 L
F
0 .72 1 r
.3931 .39266 m
.41254 .39206 L
.42209 .3931 L
.43197 .39677 L
.45141 .411 L
.4528 .41254 L
.46722 .43197 L
.47085 .44086 L
.47614 .45141 L
.48088 .47085 L
.49028 .47113 L
.50972 .47113 L
.52893 .49028 L
.52893 .50972 L
.52915 .51809 L
.54859 .52175 L
.56803 .52559 L
.57682 .52915 L
.58746 .52917 L
.6069 .53026 L
.61593 .52915 L
.62634 .52409 L
.63651 .50972 L
.63651 .49028 L
.62634 .47591 L
.61593 .47085 L
.6069 .46974 L
.58746 .47083 L
.57682 .47085 L
.56803 .47441 L
.54859 .47825 L
.52915 .48191 L
.51912 .47085 L
.52386 .45141 L
.52915 .44086 L
.53278 .43197 L
.5472 .41254 L
.54859 .411 L
.56803 .39677 L
.57791 .3931 L
.58746 .39206 L
.6069 .39266 L
.61011 .3931 L
.62634 .39866 L
.64577 .40838 L
.65243 .41254 L
.66521 .41823 L
.68465 .42686 L
.69766 .43197 L
.70408 .43444 L
.72352 .44331 L
.73644 .45141 L
.74295 .45564 L
.75625 .47085 L
.76239 .48233 L
.7648 .49028 L
.7648 .50972 L
.76239 .51767 L
.75625 .52915 L
.74295 .54436 L
.73644 .54859 L
.72352 .55669 L
.70408 .56556 L
.69766 .56803 L
.68465 .57314 L
.66521 .58177 L
.65243 .58746 L
.64577 .59162 L
.62634 .60134 L
.61011 .6069 L
.6069 .60734 L
.58746 .60794 L
.57791 .6069 L
.56803 .60323 L
.54859 .589 L
.5472 .58746 L
.53278 .56803 L
.52915 .55914 L
.52386 .54859 L
.51912 .52915 L
.50972 .52887 L
.49028 .52887 L
.47107 .50972 L
.47107 .49028 L
.47085 .48191 L
.45141 .47825 L
.43197 .47441 L
.42318 .47085 L
.41254 .47083 L
.3931 .46974 L
.38407 .47085 L
.37366 .47591 L
.36349 .49028 L
.36349 .50972 L
.37366 .52409 L
.38407 .52915 L
.3931 .53026 L
.41254 .52917 L
.42318 .52915 L
.43197 .52559 L
.45141 .52175 L
.47085 .51809 L
.48088 .52915 L
.47614 .54859 L
.47085 .55914 L
.46722 .56803 L
.4528 .58746 L
.45141 .589 L
.43197 .60323 L
.42209 .6069 L
.41254 .60794 L
.3931 .60734 L
.38989 .6069 L
.37366 .60134 L
.35423 .59162 L
.34757 .58746 L
.33479 .58177 L
.31535 .57314 L
.30234 .56803 L
.29592 .56556 L
.27648 .55669 L
.26356 .54859 L
.25705 .54436 L
.24375 .52915 L
.23761 .51767 L
.2352 .50972 L
.2352 .49028 L
.23761 .48233 L
.24375 .47085 L
.25705 .45564 L
.26356 .45141 L
.27648 .44331 L
.29592 .43444 L
.30234 .43197 L
.31535 .42686 L
.33479 .41823 L
.34757 .41254 L
.35423 .40838 L
.37366 .39866 L
.38989 .3931 L
F
0 .64 1 r
.41254 .39252 m
.41968 .3931 L
.43197 .39719 L
.45141 .41118 L
.45265 .41254 L
.46718 .43197 L
.47085 .44089 L
.47613 .45141 L
.48087 .47085 L
.49028 .47113 L
.50972 .47113 L
.52893 .49028 L
.52893 .50972 L
.52915 .5181 L
.54859 .52176 L
.56803 .52562 L
.57666 .52915 L
.58746 .5293 L
.6069 .53068 L
.6186 .52915 L
.62634 .52538 L
.63818 .50972 L
.63818 .49028 L
.62634 .47462 L
.6186 .47085 L
.6069 .46932 L
.58746 .4707 L
.57666 .47085 L
.56803 .47438 L
.54859 .47824 L
.52915 .4819 L
.51913 .47085 L
.52387 .45141 L
.52915 .44089 L
.53282 .43197 L
.54735 .41254 L
.54859 .41118 L
.56803 .39719 L
.58032 .3931 L
.58746 .39252 L
.60457 .3931 L
.6069 .39368 L
.62634 .40029 L
.64577 .4111 L
.64763 .41254 L
.66521 .42196 L
.68465 .43172 L
.68521 .43197 L
.70408 .44016 L
.72352 .45108 L
.724 .45141 L
.74295 .46775 L
.74502 .47085 L
.75403 .49028 L
.75403 .50972 L
.74502 .52915 L
.74295 .53225 L
.724 .54859 L
.72352 .54892 L
.70408 .55984 L
.68521 .56803 L
.68465 .56828 L
.66521 .57804 L
.64763 .58746 L
.64577 .5889 L
.62634 .59971 L
.6069 .60632 L
.60457 .6069 L
.58746 .60748 L
.58032 .6069 L
.56803 .60281 L
.54859 .58882 L
.54735 .58746 L
.53282 .56803 L
.52915 .55911 L
.52387 .54859 L
.51913 .52915 L
.50972 .52887 L
.49028 .52887 L
.47107 .50972 L
.47107 .49028 L
.47085 .4819 L
.45141 .47824 L
.43197 .47438 L
.42334 .47085 L
.41254 .4707 L
.3931 .46932 L
.3814 .47085 L
.37366 .47462 L
.36182 .49028 L
.36182 .50972 L
.37366 .52538 L
.3814 .52915 L
.3931 .53068 L
.41254 .5293 L
.42334 .52915 L
.43197 .52562 L
.45141 .52176 L
.47085 .5181 L
.48087 .52915 L
.47613 .54859 L
.47085 .55911 L
.46718 .56803 L
.45265 .58746 L
.45141 .58882 L
.43197 .60281 L
.41968 .6069 L
.41254 .60748 L
.39543 .6069 L
.3931 .60632 L
.37366 .59971 L
.35423 .5889 L
.35237 .58746 L
.33479 .57804 L
.31535 .56828 L
.31479 .56803 L
.29592 .55984 L
.27648 .54892 L
.276 .54859 L
.25705 .53225 L
.25498 .52915 L
.24597 .50972 L
.24597 .49028 L
.25498 .47085 L
.25705 .46775 L
.276 .45141 L
.27648 .45108 L
.29592 .44016 L
.31479 .43197 L
.31535 .43172 L
.33479 .42196 L
.35237 .41254 L
.35423 .4111 L
.37366 .40029 L
.3931 .39368 L
.39543 .3931 L
F
0 .56 1 r
.41254 .39295 m
.41587 .3931 L
.43197 .3976 L
.45141 .41135 L
.45251 .41254 L
.46714 .43197 L
.47085 .44091 L
.47613 .45141 L
.48087 .47085 L
.49028 .47113 L
.50972 .47113 L
.52893 .49028 L
.52893 .50972 L
.52915 .5181 L
.54859 .52176 L
.56803 .52565 L
.5765 .52915 L
.58746 .52943 L
.6069 .53109 L
.62118 .52915 L
.62634 .52665 L
.64009 .50972 L
.64009 .49028 L
.62634 .47335 L
.62118 .47085 L
.6069 .46891 L
.58746 .47057 L
.5765 .47085 L
.56803 .47435 L
.54859 .47824 L
.52915 .4819 L
.51913 .47085 L
.52387 .45141 L
.52915 .44091 L
.53286 .43197 L
.54749 .41254 L
.54859 .41135 L
.56803 .3976 L
.58413 .3931 L
.58746 .39295 L
.59938 .3931 L
.6069 .39475 L
.62634 .40193 L
.64351 .41254 L
.64577 .41294 L
.66521 .42606 L
.67518 .43197 L
.68465 .4365 L
.70408 .44653 L
.71205 .45141 L
.72352 .45873 L
.73429 .47085 L
.74295 .48722 L
.7438 .49028 L
.7438 .50972 L
.74295 .51278 L
.73429 .52915 L
.72352 .54127 L
.71205 .54859 L
.70408 .55347 L
.68465 .5635 L
.67518 .56803 L
.66521 .57394 L
.64577 .58706 L
.64351 .58746 L
.62634 .59807 L
.6069 .60525 L
.59938 .6069 L
.58746 .60705 L
.58413 .6069 L
.56803 .6024 L
.54859 .58865 L
.54749 .58746 L
.53286 .56803 L
.52915 .55909 L
.52387 .54859 L
.51913 .52915 L
.50972 .52887 L
.49028 .52887 L
.47107 .50972 L
.47107 .49028 L
.47085 .4819 L
.45141 .47824 L
.43197 .47435 L
.4235 .47085 L
.41254 .47057 L
.3931 .46891 L
.37882 .47085 L
.37366 .47335 L
.35991 .49028 L
.35991 .50972 L
.37366 .52665 L
.37882 .52915 L
.3931 .53109 L
.41254 .52943 L
.4235 .52915 L
.43197 .52565 L
.45141 .52176 L
.47085 .5181 L
.48087 .52915 L
.47613 .54859 L
.47085 .55909 L
.46714 .56803 L
.45251 .58746 L
.45141 .58865 L
.43197 .6024 L
.41587 .6069 L
.41254 .60705 L
.40062 .6069 L
.3931 .60525 L
.37366 .59807 L
.35649 .58746 L
.35423 .58706 L
.33479 .57394 L
.32482 .56803 L
.31535 .5635 L
.29592 .55347 L
.28795 .54859 L
.27648 .54127 L
.26571 .52915 L
.25705 .51278 L
.2562 .50972 L
.2562 .49028 L
.25705 .48722 L
.26571 .47085 L
.27648 .45873 L
.28795 .45141 L
.29592 .44653 L
.31535 .4365 L
.32482 .43197 L
.33479 .42606 L
.35423 .41294 L
.35649 .41254 L
.37366 .40193 L
.3931 .39475 L
.40062 .3931 L
F
0 .48 1 r
.37366 .40358 m
.3931 .3958 L
.41254 .39355 L
.43197 .39801 L
.45141 .41152 L
.45236 .41254 L
.4671 .43197 L
.47085 .44094 L
.47612 .45141 L
.48087 .47085 L
.49028 .47113 L
.50972 .47113 L
.52893 .49028 L
.52893 .50972 L
.52915 .5181 L
.54859 .52177 L
.56803 .52567 L
.57635 .52915 L
.58746 .52957 L
.6069 .53151 L
.62377 .52915 L
.62634 .52793 L
.64237 .50972 L
.64237 .49028 L
.62634 .47207 L
.62377 .47085 L
.6069 .46849 L
.58746 .47043 L
.57635 .47085 L
.56803 .47433 L
.54859 .47823 L
.52915 .4819 L
.51913 .47085 L
.52388 .45141 L
.52915 .44094 L
.5329 .43197 L
.54764 .41254 L
.54859 .41152 L
.56803 .39801 L
.58746 .39355 L
.6069 .3958 L
.62634 .40358 L
.63936 .41254 L
.64577 .41412 L
.66521 .43062 L
.66713 .43197 L
.68465 .4419 L
.70054 .45141 L
.70408 .4532 L
.72352 .47034 L
.72388 .47085 L
.73397 .49028 L
.73397 .50972 L
.72388 .52915 L
.72352 .52966 L
.70408 .5468 L
.70054 .54859 L
.68465 .5581 L
.66713 .56803 L
.66521 .56938 L
.64577 .58588 L
.63936 .58746 L
.62634 .59642 L
.6069 .6042 L
.58746 .60645 L
.56803 .60199 L
.54859 .58848 L
.54764 .58746 L
.5329 .56803 L
.52915 .55906 L
.52388 .54859 L
.51913 .52915 L
.50972 .52887 L
.49028 .52887 L
.47107 .50972 L
.47107 .49028 L
.47085 .4819 L
.45141 .47823 L
.43197 .47433 L
.42365 .47085 L
.41254 .47043 L
.3931 .46849 L
.37623 .47085 L
.37366 .47207 L
.35763 .49028 L
.35763 .50972 L
.37366 .52793 L
.37623 .52915 L
.3931 .53151 L
.41254 .52957 L
.42365 .52915 L
.43197 .52567 L
.45141 .52177 L
.47085 .5181 L
.48087 .52915 L
.47612 .54859 L
.47085 .55906 L
.4671 .56803 L
.45236 .58746 L
.45141 .58848 L
.43197 .60199 L
.41254 .60645 L
.3931 .6042 L
.37366 .59642 L
.36064 .58746 L
.35423 .58588 L
.33479 .56938 L
.33287 .56803 L
.31535 .5581 L
.29946 .54859 L
.29592 .5468 L
.27648 .52966 L
.27612 .52915 L
.26603 .50972 L
.26603 .49028 L
.27612 .47085 L
.27648 .47034 L
.29592 .4532 L
.29946 .45141 L
.31535 .4419 L
.33287 .43197 L
.33479 .43062 L
.35423 .41412 L
.36064 .41254 L
F
.48 1 0 r
.31535 .15977 m
.33479 .15421 L
.35423 .15219 L
.37366 .15247 L
.3931 .15422 L
.41254 .15681 L
.43197 .15965 L
.43347 .15986 L
.45141 .16226 L
.47085 .16423 L
.49028 .16529 L
.50972 .16529 L
.52915 .16423 L
.54859 .16226 L
.56653 .15986 L
.56803 .15965 L
.58746 .15681 L
.6069 .15422 L
.62634 .15247 L
.64577 .15219 L
.66521 .15421 L
.68465 .15977 L
.68488 .15986 L
.70408 .17157 L
.71148 .1793 L
.72173 .19874 L
.72352 .20574 L
.72485 .21817 L
.72352 .23531 L
.72309 .23761 L
.71733 .25705 L
.70784 .27648 L
.70408 .2834 L
.69443 .29592 L
.68465 .30807 L
.6763 .31535 L
.66521 .32557 L
.6512 .33479 L
.64577 .3385 L
.62634 .35015 L
.61547 .35423 L
.6069 .35943 L
.58746 .36986 L
.58188 .37366 L
.56803 .38498 L
.55986 .3931 L
.54859 .40663 L
.54434 .41254 L
.53194 .43197 L
.52915 .44028 L
.52376 .45141 L
.5191 .47085 L
.52915 .48193 L
.54859 .47836 L
.56803 .47497 L
.58746 .47307 L
.6069 .47753 L
.61772 .49028 L
.61772 .50972 L
.6069 .52247 L
.58746 .52693 L
.56803 .52503 L
.54859 .52164 L
.52915 .51807 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.4809 .47085 L
.47624 .45141 L
.47085 .44028 L
.46806 .43197 L
.45566 .41254 L
.45141 .40663 L
.44014 .3931 L
.43197 .38498 L
.41812 .37366 L
.41254 .36986 L
.3931 .35943 L
.38453 .35423 L
.37366 .35015 L
.35423 .3385 L
.3488 .33479 L
.33479 .32557 L
.3237 .31535 L
.31535 .30807 L
.30557 .29592 L
.29592 .2834 L
.29216 .27648 L
.28267 .25705 L
.27691 .23761 L
.27648 .23531 L
.27515 .21817 L
.27648 .20574 L
.27827 .19874 L
.28852 .1793 L
.29592 .17157 L
.31512 .15986 L
F
.3931 .47753 m
.41254 .47307 L
.43197 .47497 L
.45141 .47836 L
.47085 .48193 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.5191 .52915 L
.52376 .54859 L
.52915 .55972 L
.53194 .56803 L
.54434 .58746 L
.54859 .59337 L
.55986 .6069 L
.56803 .61502 L
.58188 .62634 L
.58746 .63014 L
.6069 .64057 L
.61547 .64577 L
.62634 .64985 L
.64577 .6615 L
.6512 .66521 L
.66521 .67443 L
.6763 .68465 L
.68465 .69193 L
.69443 .70408 L
.70408 .7166 L
.70784 .72352 L
.71733 .74295 L
.72309 .76239 L
.72352 .76469 L
.72485 .78183 L
.72352 .79426 L
.72173 .80126 L
.71148 .8207 L
.70408 .82843 L
.68488 .84014 L
.68465 .84023 L
.66521 .84579 L
.64577 .84781 L
.62634 .84753 L
.6069 .84578 L
.58746 .84319 L
.56803 .84035 L
.56653 .84014 L
.54859 .83774 L
.52915 .83577 L
.50972 .83471 L
.49028 .83471 L
.47085 .83577 L
.45141 .83774 L
.43347 .84014 L
.43197 .84035 L
.41254 .84319 L
.3931 .84578 L
.37366 .84753 L
.35423 .84781 L
.33479 .84579 L
.31535 .84023 L
.31512 .84014 L
.29592 .82843 L
.28852 .8207 L
.27827 .80126 L
.27648 .79426 L
.27515 .78183 L
.27648 .76469 L
.27691 .76239 L
.28267 .74295 L
.29216 .72352 L
.29592 .7166 L
.30557 .70408 L
.31535 .69193 L
.3237 .68465 L
.33479 .67443 L
.3488 .66521 L
.35423 .6615 L
.37366 .64985 L
.38453 .64577 L
.3931 .64057 L
.41254 .63014 L
.41812 .62634 L
.43197 .61502 L
.44014 .6069 L
.45141 .59337 L
.45566 .58746 L
.46806 .56803 L
.47085 .55972 L
.47624 .54859 L
.4809 .52915 L
.47085 .51807 L
.45141 .52164 L
.43197 .52503 L
.41254 .52693 L
.3931 .52247 L
.38228 .50972 L
.38228 .49028 L
F
0 .4 1 r
.37366 .40524 m
.3931 .39683 L
.41254 .39427 L
.43197 .3984 L
.45141 .41169 L
.45221 .41254 L
.46706 .43197 L
.47085 .44097 L
.47612 .45141 L
.48087 .47085 L
.49028 .47113 L
.50972 .47113 L
.52893 .49028 L
.52893 .50972 L
.52915 .5181 L
.54859 .52177 L
.56803 .5257 L
.57621 .52915 L
.58746 .5297 L
.6069 .53193 L
.62634 .5292 L
.62648 .52915 L
.64521 .50972 L
.64521 .49028 L
.62648 .47085 L
.62634 .4708 L
.6069 .46807 L
.58746 .4703 L
.57621 .47085 L
.56803 .4743 L
.54859 .47823 L
.52915 .4819 L
.51913 .47085 L
.52388 .45141 L
.52915 .44097 L
.53294 .43197 L
.54779 .41254 L
.54859 .41169 L
.56803 .3984 L
.58746 .39427 L
.6069 .39683 L
.62634 .40524 L
.63582 .41254 L
.64577 .41599 L
.66046 .43197 L
.66521 .43376 L
.68465 .44819 L
.68947 .45141 L
.70408 .46061 L
.71368 .47085 L
.72352 .48764 L
.72432 .49028 L
.72432 .50972 L
.72352 .51236 L
.71368 .52915 L
.70408 .53939 L
.68947 .54859 L
.68465 .55181 L
.66521 .56624 L
.66046 .56803 L
.64577 .58401 L
.63582 .58746 L
.62634 .59476 L
.6069 .60317 L
.58746 .60573 L
.56803 .6016 L
.54859 .58831 L
.54779 .58746 L
.53294 .56803 L
.52915 .55903 L
.52388 .54859 L
.51913 .52915 L
.50972 .52887 L
.49028 .52887 L
.47107 .50972 L
.47107 .49028 L
.47085 .4819 L
.45141 .47823 L
.43197 .4743 L
.42379 .47085 L
.41254 .4703 L
.3931 .46807 L
.37366 .4708 L
.37352 .47085 L
.35479 .49028 L
.35479 .50972 L
.37352 .52915 L
.37366 .5292 L
.3931 .53193 L
.41254 .5297 L
.42379 .52915 L
.43197 .5257 L
.45141 .52177 L
.47085 .5181 L
.48087 .52915 L
.47612 .54859 L
.47085 .55903 L
.46706 .56803 L
.45221 .58746 L
.45141 .58831 L
.43197 .6016 L
.41254 .60573 L
.3931 .60317 L
.37366 .59476 L
.36418 .58746 L
.35423 .58401 L
.33954 .56803 L
.33479 .56624 L
.31535 .55181 L
.31053 .54859 L
.29592 .53939 L
.28632 .52915 L
.27648 .51236 L
.27568 .50972 L
.27568 .49028 L
.27648 .48764 L
.28632 .47085 L
.29592 .46061 L
.31053 .45141 L
.31535 .44819 L
.33479 .43376 L
.33954 .43197 L
.35423 .41599 L
.36418 .41254 L
F
0 .32 1 r
.37366 .40694 m
.3931 .39783 L
.41254 .39498 L
.43197 .39879 L
.45141 .41186 L
.45206 .41254 L
.46702 .43197 L
.47085 .44099 L
.47611 .45141 L
.48087 .47085 L
.49028 .47113 L
.50972 .47113 L
.52893 .49028 L
.52893 .50972 L
.52915 .5181 L
.54859 .52178 L
.56803 .52573 L
.57607 .52915 L
.58746 .52984 L
.6069 .53235 L
.62634 .53055 L
.63079 .52915 L
.64577 .51583 L
.64807 .50972 L
.64807 .49028 L
.64577 .48417 L
.63079 .47085 L
.62634 .46945 L
.6069 .46765 L
.58746 .47016 L
.57607 .47085 L
.56803 .47427 L
.54859 .47822 L
.52915 .4819 L
.51913 .47085 L
.52389 .45141 L
.52915 .44099 L
.53298 .43197 L
.54794 .41254 L
.54859 .41186 L
.56803 .39879 L
.58746 .39498 L
.6069 .39783 L
.62634 .40694 L
.63284 .41254 L
.64577 .41885 L
.65497 .43197 L
.66521 .43821 L
.67904 .45141 L
.68465 .4543 L
.70332 .47085 L
.70408 .47178 L
.7149 .49028 L
.7149 .50972 L
.70408 .52822 L
.70332 .52915 L
.68465 .5457 L
.67904 .54859 L
.66521 .56179 L
.65497 .56803 L
.64577 .58115 L
.63284 .58746 L
.62634 .59306 L
.6069 .60217 L
.58746 .60502 L
.56803 .60121 L
.54859 .58814 L
.54794 .58746 L
.53298 .56803 L
.52915 .55901 L
.52389 .54859 L
.51913 .52915 L
.50972 .52887 L
.49028 .52887 L
.47107 .50972 L
.47107 .49028 L
.47085 .4819 L
.45141 .47822 L
.43197 .47427 L
.42393 .47085 L
.41254 .47016 L
.3931 .46765 L
.37366 .46945 L
.36921 .47085 L
.35423 .48417 L
.35193 .49028 L
.35193 .50972 L
.35423 .51583 L
.36921 .52915 L
.37366 .53055 L
.3931 .53235 L
.41254 .52984 L
.42393 .52915 L
.43197 .52573 L
.45141 .52178 L
.47085 .5181 L
.48087 .52915 L
.47611 .54859 L
.47085 .55901 L
.46702 .56803 L
.45206 .58746 L
.45141 .58814 L
.43197 .60121 L
.41254 .60502 L
.3931 .60217 L
.37366 .59306 L
.36716 .58746 L
.35423 .58115 L
.34503 .56803 L
.33479 .56179 L
.32096 .54859 L
.31535 .5457 L
.29668 .52915 L
.29592 .52822 L
.2851 .50972 L
.2851 .49028 L
.29592 .47178 L
.29668 .47085 L
.31535 .4543 L
.32096 .45141 L
.33479 .43821 L
.34503 .43197 L
.35423 .41885 L
.36716 .41254 L
F
0 .24 1 r
.37366 .40867 m
.3931 .39882 L
.41254 .39567 L
.43197 .39917 L
.45141 .41202 L
.45191 .41254 L
.46698 .43197 L
.47085 .44102 L
.47611 .45141 L
.48087 .47085 L
.49028 .47113 L
.50972 .47113 L
.52893 .49028 L
.52893 .50972 L
.52915 .5181 L
.54859 .52179 L
.56803 .52575 L
.57594 .52915 L
.58746 .52997 L
.6069 .53277 L
.62634 .53192 L
.63602 .52915 L
.64577 .52187 L
.65151 .50972 L
.65151 .49028 L
.64577 .47813 L
.63602 .47085 L
.62634 .46808 L
.6069 .46723 L
.58746 .47003 L
.57594 .47085 L
.56803 .47425 L
.54859 .47821 L
.52915 .4819 L
.51913 .47085 L
.52389 .45141 L
.52915 .44102 L
.53302 .43197 L
.54809 .41254 L
.54859 .41202 L
.56803 .39917 L
.58746 .39567 L
.6069 .39882 L
.62634 .40867 L
.63035 .41254 L
.64577 .423 L
.65057 .43197 L
.66521 .44608 L
.66943 .45141 L
.68465 .46266 L
.69289 .47085 L
.70408 .48843 L
.70474 .49028 L
.70474 .50972 L
.70408 .51157 L
.69289 .52915 L
.68465 .53734 L
.66943 .54859 L
.66521 .55392 L
.65057 .56803 L
.64577 .577 L
.63035 .58746 L
.62634 .59133 L
.6069 .60118 L
.58746 .60433 L
.56803 .60083 L
.54859 .58798 L
.54809 .58746 L
.53302 .56803 L
.52915 .55898 L
.52389 .54859 L
.51913 .52915 L
.50972 .52887 L
.49028 .52887 L
.47107 .50972 L
.47107 .49028 L
.47085 .4819 L
.45141 .47821 L
.43197 .47425 L
.42406 .47085 L
.41254 .47003 L
.3931 .46723 L
.37366 .46808 L
.36398 .47085 L
.35423 .47813 L
.34849 .49028 L
.34849 .50972 L
.35423 .52187 L
.36398 .52915 L
.37366 .53192 L
.3931 .53277 L
.41254 .52997 L
.42406 .52915 L
.43197 .52575 L
.45141 .52179 L
.47085 .5181 L
.48087 .52915 L
.47611 .54859 L
.47085 .55898 L
.46698 .56803 L
.45191 .58746 L
.45141 .58798 L
.43197 .60083 L
.41254 .60433 L
.3931 .60118 L
.37366 .59133 L
.36965 .58746 L
.35423 .577 L
.34943 .56803 L
.33479 .55392 L
.33057 .54859 L
.31535 .53734 L
.30711 .52915 L
.29592 .51157 L
.29526 .50972 L
.29526 .49028 L
.29592 .48843 L
.30711 .47085 L
.31535 .46266 L
.33057 .45141 L
.33479 .44608 L
.34943 .43197 L
.35423 .423 L
.36965 .41254 L
F
0 .16 1 r
.37366 .41044 m
.3931 .3998 L
.41254 .39634 L
.43197 .39954 L
.45141 .41218 L
.45175 .41254 L
.46694 .43197 L
.47085 .44104 L
.4761 .45141 L
.48087 .47085 L
.49028 .47113 L
.50972 .47113 L
.52893 .49028 L
.52893 .50972 L
.52915 .5181 L
.54859 .52179 L
.56803 .52578 L
.57581 .52915 L
.58746 .53011 L
.6069 .5332 L
.62634 .5333 L
.64314 .52915 L
.64577 .52759 L
.65646 .50972 L
.65646 .49028 L
.64577 .47241 L
.64314 .47085 L
.62634 .4667 L
.6069 .4668 L
.58746 .46989 L
.57581 .47085 L
.56803 .47422 L
.54859 .47821 L
.52915 .4819 L
.51913 .47085 L
.5239 .45141 L
.52915 .44104 L
.53306 .43197 L
.54825 .41254 L
.54859 .41218 L
.56803 .39954 L
.58746 .39634 L
.6069 .3998 L
.62634 .41044 L
.62827 .41254 L
.64577 .42874 L
.6471 .43197 L
.66108 .45141 L
.66521 .45707 L
.67961 .47085 L
.68465 .47606 L
.69378 .49028 L
.69378 .50972 L
.68465 .52394 L
.67961 .52915 L
.66521 .54293 L
.66108 .54859 L
.6471 .56803 L
.64577 .57126 L
.62827 .58746 L
.62634 .58956 L
.6069 .6002 L
.58746 .60366 L
.56803 .60046 L
.54859 .58782 L
.54825 .58746 L
.53306 .56803 L
.52915 .55896 L
.5239 .54859 L
.51913 .52915 L
.50972 .52887 L
.49028 .52887 L
.47107 .50972 L
.47107 .49028 L
.47085 .4819 L
.45141 .47821 L
.43197 .47422 L
.42419 .47085 L
.41254 .46989 L
.3931 .4668 L
.37366 .4667 L
.35686 .47085 L
.35423 .47241 L
.34354 .49028 L
.34354 .50972 L
.35423 .52759 L
.35686 .52915 L
.37366 .5333 L
.3931 .5332 L
.41254 .53011 L
.42419 .52915 L
.43197 .52578 L
.45141 .52179 L
.47085 .5181 L
.48087 .52915 L
.4761 .54859 L
.47085 .55896 L
.46694 .56803 L
.45175 .58746 L
.45141 .58782 L
.43197 .60046 L
.41254 .60366 L
.3931 .6002 L
.37366 .58956 L
.37173 .58746 L
.35423 .57126 L
.3529 .56803 L
.33892 .54859 L
.33479 .54293 L
.32039 .52915 L
.31535 .52394 L
.30622 .50972 L
.30622 .49028 L
.31535 .47606 L
.32039 .47085 L
.33479 .45707 L
.33892 .45141 L
.3529 .43197 L
.35423 .42874 L
.37173 .41254 L
F
.56 1 0 r
.3931 .4779 m
.41254 .47318 L
.43197 .47499 L
.45141 .47837 L
.47085 .48193 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.5191 .52915 L
.52375 .54859 L
.52915 .55975 L
.5319 .56803 L
.54421 .58746 L
.54859 .59362 L
.55935 .6069 L
.56803 .61584 L
.58004 .62634 L
.58746 .63185 L
.6069 .64412 L
.60913 .64577 L
.62634 .65466 L
.64003 .66521 L
.64577 .66813 L
.66243 .68465 L
.66521 .68611 L
.67782 .70408 L
.68465 .71605 L
.68796 .72352 L
.69337 .74295 L
.69372 .76239 L
.68747 .78183 L
.68465 .78659 L
.66927 .80126 L
.66521 .8037 L
.64577 .81136 L
.62634 .81479 L
.6069 .81582 L
.58746 .81544 L
.56803 .81438 L
.54859 .81316 L
.52915 .81215 L
.50972 .8116 L
.49028 .8116 L
.47085 .81215 L
.45141 .81316 L
.43197 .81438 L
.41254 .81544 L
.3931 .81582 L
.37366 .81479 L
.35423 .81136 L
.33479 .8037 L
.33073 .80126 L
.31535 .78659 L
.31253 .78183 L
.30628 .76239 L
.30663 .74295 L
.31204 .72352 L
.31535 .71605 L
.32218 .70408 L
.33479 .68611 L
.33757 .68465 L
.35423 .66813 L
.35997 .66521 L
.37366 .65466 L
.39087 .64577 L
.3931 .64412 L
.41254 .63185 L
.41996 .62634 L
.43197 .61584 L
.44065 .6069 L
.45141 .59362 L
.45579 .58746 L
.4681 .56803 L
.47085 .55975 L
.47625 .54859 L
.4809 .52915 L
.47085 .51807 L
.45141 .52163 L
.43197 .52501 L
.41254 .52682 L
.3931 .5221 L
.38282 .50972 L
.38282 .49028 L
F
.33479 .1963 m
.35423 .18864 L
.37366 .18521 L
.3931 .18418 L
.41254 .18456 L
.43197 .18562 L
.45141 .18684 L
.47085 .18785 L
.49028 .1884 L
.50972 .1884 L
.52915 .18785 L
.54859 .18684 L
.56803 .18562 L
.58746 .18456 L
.6069 .18418 L
.62634 .18521 L
.64577 .18864 L
.66521 .1963 L
.66927 .19874 L
.68465 .21341 L
.68747 .21817 L
.69372 .23761 L
.69337 .25705 L
.68796 .27648 L
.68465 .28395 L
.67782 .29592 L
.66521 .31389 L
.66243 .31535 L
.64577 .33187 L
.64003 .33479 L
.62634 .34534 L
.60913 .35423 L
.6069 .35588 L
.58746 .36815 L
.58004 .37366 L
.56803 .38416 L
.55935 .3931 L
.54859 .40638 L
.54421 .41254 L
.5319 .43197 L
.52915 .44025 L
.52375 .45141 L
.5191 .47085 L
.52915 .48193 L
.54859 .47837 L
.56803 .47499 L
.58746 .47318 L
.6069 .4779 L
.61718 .49028 L
.61718 .50972 L
.6069 .5221 L
.58746 .52682 L
.56803 .52501 L
.54859 .52163 L
.52915 .51807 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.4809 .47085 L
.47625 .45141 L
.47085 .44025 L
.4681 .43197 L
.45579 .41254 L
.45141 .40638 L
.44065 .3931 L
.43197 .38416 L
.41996 .37366 L
.41254 .36815 L
.3931 .35588 L
.39087 .35423 L
.37366 .34534 L
.35997 .33479 L
.35423 .33187 L
.33757 .31535 L
.33479 .31389 L
.32218 .29592 L
.31535 .28395 L
.31204 .27648 L
.30663 .25705 L
.30628 .23761 L
.31253 .21817 L
.31535 .21341 L
.33073 .19874 L
F
.64 1 0 r
.37366 .21285 m
.3931 .20859 L
.41254 .20663 L
.43197 .20591 L
.45141 .2058 L
.47085 .20591 L
.49028 .20602 L
.50972 .20602 L
.52915 .20591 L
.54859 .2058 L
.56803 .20591 L
.58746 .20663 L
.6069 .20859 L
.62634 .21285 L
.63989 .21817 L
.64577 .22148 L
.66235 .23761 L
.66521 .24269 L
.66949 .25705 L
.66886 .27648 L
.66521 .28918 L
.66225 .29592 L
.64974 .31535 L
.64577 .32108 L
.63031 .33479 L
.62634 .3386 L
.6069 .35219 L
.60373 .35423 L
.58746 .36629 L
.57834 .37366 L
.56803 .3833 L
.55886 .3931 L
.54859 .40612 L
.54408 .41254 L
.53186 .43197 L
.52915 .44022 L
.52375 .45141 L
.5191 .47085 L
.52915 .48194 L
.54859 .47837 L
.56803 .47502 L
.58746 .47328 L
.6069 .47828 L
.61667 .49028 L
.61667 .50972 L
.6069 .52172 L
.58746 .52672 L
.56803 .52498 L
.54859 .52163 L
.52915 .51806 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.4809 .47085 L
.47625 .45141 L
.47085 .44022 L
.46814 .43197 L
.45592 .41254 L
.45141 .40612 L
.44114 .3931 L
.43197 .3833 L
.42166 .37366 L
.41254 .36629 L
.39627 .35423 L
.3931 .35219 L
.37366 .3386 L
.36969 .33479 L
.35423 .32108 L
.35026 .31535 L
.33775 .29592 L
.33479 .28918 L
.33114 .27648 L
.33051 .25705 L
.33479 .24269 L
.33765 .23761 L
.35423 .22148 L
.36011 .21817 L
F
.3931 .47828 m
.41254 .47328 L
.43197 .47502 L
.45141 .47837 L
.47085 .48194 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.5191 .52915 L
.52375 .54859 L
.52915 .55978 L
.53186 .56803 L
.54408 .58746 L
.54859 .59388 L
.55886 .6069 L
.56803 .6167 L
.57834 .62634 L
.58746 .63371 L
.60373 .64577 L
.6069 .64781 L
.62634 .6614 L
.63031 .66521 L
.64577 .67892 L
.64974 .68465 L
.66225 .70408 L
.66521 .71082 L
.66886 .72352 L
.66949 .74295 L
.66521 .75731 L
.66235 .76239 L
.64577 .77852 L
.63989 .78183 L
.62634 .78715 L
.6069 .79141 L
.58746 .79337 L
.56803 .79409 L
.54859 .7942 L
.52915 .79409 L
.50972 .79398 L
.49028 .79398 L
.47085 .79409 L
.45141 .7942 L
.43197 .79409 L
.41254 .79337 L
.3931 .79141 L
.37366 .78715 L
.36011 .78183 L
.35423 .77852 L
.33765 .76239 L
.33479 .75731 L
.33051 .74295 L
.33114 .72352 L
.33479 .71082 L
.33775 .70408 L
.35026 .68465 L
.35423 .67892 L
.36969 .66521 L
.37366 .6614 L
.3931 .64781 L
.39627 .64577 L
.41254 .63371 L
.42166 .62634 L
.43197 .6167 L
.44114 .6069 L
.45141 .59388 L
.45592 .58746 L
.46814 .56803 L
.47085 .55978 L
.47625 .54859 L
.4809 .52915 L
.47085 .51806 L
.45141 .52163 L
.43197 .52498 L
.41254 .52672 L
.3931 .52172 L
.38333 .50972 L
.38333 .49028 L
F
0 .08 1 r
.37366 .41227 m
.3931 .40076 L
.41254 .397 L
.43197 .39991 L
.45141 .41234 L
.4516 .41254 L
.4669 .43197 L
.47085 .44107 L
.4761 .45141 L
.48087 .47085 L
.49028 .47113 L
.50972 .47113 L
.52893 .49028 L
.52893 .50972 L
.52915 .5181 L
.54859 .5218 L
.56803 .52581 L
.57568 .52915 L
.58746 .53024 L
.6069 .53363 L
.62634 .53471 L
.64577 .53382 L
.65407 .54859 L
.64577 .56519 L
.64383 .56803 L
.62656 .58746 L
.62634 .58773 L
.6069 .59924 L
.58746 .603 L
.56803 .60009 L
.54859 .58766 L
.5484 .58746 L
.5331 .56803 L
.52915 .55893 L
.5239 .54859 L
.51913 .52915 L
.50972 .52887 L
.49028 .52887 L
.47107 .50972 L
.47107 .49028 L
.47085 .4819 L
.45141 .4782 L
.43197 .47419 L
.42432 .47085 L
.41254 .46976 L
.3931 .46637 L
.37366 .46529 L
.35423 .46618 L
.34593 .45141 L
.35423 .43481 L
.35617 .43197 L
.37344 .41254 L
F
.43197 .52581 m
.45141 .5218 L
.47085 .5181 L
.48087 .52915 L
.4761 .54859 L
.47085 .55893 L
.4669 .56803 L
.4516 .58746 L
.45141 .58766 L
.43197 .60009 L
.41254 .603 L
.3931 .59924 L
.37366 .58773 L
.37344 .58746 L
.35617 .56803 L
.35423 .56519 L
.34593 .54859 L
.35423 .53382 L
.37366 .53471 L
.3931 .53363 L
.41254 .53024 L
.42432 .52915 L
F
.72 1 0 r
.3931 .22962 m
.41254 .22503 L
.43197 .22248 L
.45141 .22108 L
.47085 .22035 L
.49028 .22003 L
.50972 .22003 L
.52915 .22035 L
.54859 .22108 L
.56803 .22248 L
.58746 .22503 L
.6069 .22962 L
.62532 .23761 L
.62634 .23821 L
.64491 .25705 L
.64577 .25867 L
.6503 .27648 L
.64763 .29592 L
.64577 .30116 L
.63823 .31535 L
.62634 .33029 L
.62189 .33479 L
.6069 .34819 L
.59894 .35423 L
.58746 .36424 L
.57677 .37366 L
.56803 .38239 L
.55837 .3931 L
.54859 .40585 L
.54396 .41254 L
.53182 .43197 L
.52915 .44019 L
.52374 .45141 L
.5191 .47085 L
.52915 .48194 L
.54859 .47838 L
.56803 .47505 L
.58746 .47339 L
.6069 .47865 L
.61617 .49028 L
.61617 .50972 L
.6069 .52135 L
.58746 .52661 L
.56803 .52495 L
.54859 .52162 L
.52915 .51806 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.4809 .47085 L
.47626 .45141 L
.47085 .44019 L
.46818 .43197 L
.45604 .41254 L
.45141 .40585 L
.44163 .3931 L
.43197 .38239 L
.42323 .37366 L
.41254 .36424 L
.40106 .35423 L
.3931 .34819 L
.37811 .33479 L
.37366 .33029 L
.36177 .31535 L
.35423 .30116 L
.35237 .29592 L
.3497 .27648 L
.35423 .25867 L
.35509 .25705 L
.37366 .23821 L
.37468 .23761 L
F
.3931 .47865 m
.41254 .47339 L
.43197 .47505 L
.45141 .47838 L
.47085 .48194 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.5191 .52915 L
.52374 .54859 L
.52915 .55981 L
.53182 .56803 L
.54396 .58746 L
.54859 .59415 L
.55837 .6069 L
.56803 .61761 L
.57677 .62634 L
.58746 .63576 L
.59894 .64577 L
.6069 .65181 L
.62189 .66521 L
.62634 .66971 L
.63823 .68465 L
.64577 .69884 L
.64763 .70408 L
.6503 .72352 L
.64577 .74133 L
.64491 .74295 L
.62634 .76179 L
.62532 .76239 L
.6069 .77038 L
.58746 .77497 L
.56803 .77752 L
.54859 .77892 L
.52915 .77965 L
.50972 .77997 L
.49028 .77997 L
.47085 .77965 L
.45141 .77892 L
.43197 .77752 L
.41254 .77497 L
.3931 .77038 L
.37468 .76239 L
.37366 .76179 L
.35509 .74295 L
.35423 .74133 L
.3497 .72352 L
.35237 .70408 L
.35423 .69884 L
.36177 .68465 L
.37366 .66971 L
.37811 .66521 L
.3931 .65181 L
.40106 .64577 L
.41254 .63576 L
.42323 .62634 L
.43197 .61761 L
.44163 .6069 L
.45141 .59415 L
.45604 .58746 L
.46818 .56803 L
.47085 .55981 L
.47626 .54859 L
.4809 .52915 L
.47085 .51806 L
.45141 .52162 L
.43197 .52495 L
.41254 .52661 L
.3931 .52135 L
.38383 .50972 L
.38383 .49028 L
F
0 0 1 r
.3931 .40171 m
.41254 .39765 L
.43197 .40027 L
.45141 .4125 L
.45144 .41254 L
.46685 .43197 L
.47085 .44109 L
.47609 .45141 L
.48087 .47085 L
.49028 .47113 L
.50972 .47113 L
.52893 .49028 L
.52893 .50972 L
.52915 .51811 L
.54859 .5218 L
.56803 .52583 L
.57555 .52915 L
.58746 .53038 L
.6069 .53406 L
.62634 .53614 L
.64577 .54181 L
.64814 .54859 L
.64577 .55795 L
.64057 .56803 L
.62634 .58596 L
.6244 .58746 L
.6069 .59829 L
.58746 .60235 L
.56803 .59973 L
.54859 .5875 L
.54856 .58746 L
.53315 .56803 L
.52915 .55891 L
.52391 .54859 L
.51913 .52915 L
.50972 .52887 L
.49028 .52887 L
.47107 .50972 L
.47107 .49028 L
.47085 .48189 L
.45141 .4782 L
.43197 .47417 L
.42445 .47085 L
.41254 .46962 L
.3931 .46594 L
.37366 .46386 L
.35423 .45819 L
.35186 .45141 L
.35423 .44205 L
.35943 .43197 L
.37366 .41404 L
.3756 .41254 L
F
.43197 .52583 m
.45141 .5218 L
.47085 .51811 L
.48087 .52915 L
.47609 .54859 L
.47085 .55891 L
.46685 .56803 L
.45144 .58746 L
.45141 .5875 L
.43197 .59973 L
.41254 .60235 L
.3931 .59829 L
.3756 .58746 L
.37366 .58596 L
.35943 .56803 L
.35423 .55795 L
.35186 .54859 L
.35423 .54181 L
.37366 .53614 L
.3931 .53406 L
.41254 .53038 L
.42445 .52915 L
F
.8 1 0 r
.43197 .23646 m
.45141 .23381 L
.47085 .2323 L
.49028 .23161 L
.50972 .23161 L
.52915 .2323 L
.54859 .23381 L
.56803 .23646 L
.57412 .23761 L
.58746 .24095 L
.6069 .24871 L
.61903 .25705 L
.62634 .26289 L
.63224 .27648 L
.634 .29592 L
.62786 .31535 L
.62634 .31826 L
.61461 .33479 L
.6069 .3433 L
.59492 .35423 L
.58746 .36195 L
.57529 .37366 L
.56803 .38142 L
.5579 .3931 L
.54859 .40558 L
.54383 .41254 L
.53179 .43197 L
.52915 .44016 L
.52374 .45141 L
.5191 .47085 L
.52915 .48194 L
.54859 .47838 L
.56803 .47507 L
.58746 .47349 L
.6069 .47903 L
.6157 .49028 L
.6157 .50972 L
.6069 .52097 L
.58746 .52651 L
.56803 .52493 L
.54859 .52162 L
.52915 .51806 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.4809 .47085 L
.47626 .45141 L
.47085 .44016 L
.46821 .43197 L
.45617 .41254 L
.45141 .40558 L
.4421 .3931 L
.43197 .38142 L
.42471 .37366 L
.41254 .36195 L
.40508 .35423 L
.3931 .3433 L
.38539 .33479 L
.37366 .31826 L
.37214 .31535 L
.366 .29592 L
.36776 .27648 L
.37366 .26289 L
.38097 .25705 L
.3931 .24871 L
.41254 .24095 L
.42588 .23761 L
F
.3931 .47903 m
.41254 .47349 L
.43197 .47507 L
.45141 .47838 L
.47085 .48194 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.5191 .52915 L
.52374 .54859 L
.52915 .55984 L
.53179 .56803 L
.54383 .58746 L
.54859 .59442 L
.5579 .6069 L
.56803 .61858 L
.57529 .62634 L
.58746 .63805 L
.59492 .64577 L
.6069 .6567 L
.61461 .66521 L
.62634 .68174 L
.62786 .68465 L
.634 .70408 L
.63224 .72352 L
.62634 .73711 L
.61903 .74295 L
.6069 .75129 L
.58746 .75905 L
.57412 .76239 L
.56803 .76354 L
.54859 .76619 L
.52915 .7677 L
.50972 .76839 L
.49028 .76839 L
.47085 .7677 L
.45141 .76619 L
.43197 .76354 L
.42588 .76239 L
.41254 .75905 L
.3931 .75129 L
.38097 .74295 L
.37366 .73711 L
.36776 .72352 L
.366 .70408 L
.37214 .68465 L
.37366 .68174 L
.38539 .66521 L
.3931 .6567 L
.40508 .64577 L
.41254 .63805 L
.42471 .62634 L
.43197 .61858 L
.4421 .6069 L
.45141 .59442 L
.45617 .58746 L
.46821 .56803 L
.47085 .55984 L
.47626 .54859 L
.4809 .52915 L
.47085 .51806 L
.45141 .52162 L
.43197 .52493 L
.41254 .52651 L
.3931 .52097 L
.3843 .50972 L
.3843 .49028 L
F
.88 1 0 r
.41254 .25518 m
.43197 .2486 L
.45141 .24467 L
.47085 .24239 L
.49028 .24134 L
.50972 .24134 L
.52915 .24239 L
.54859 .24467 L
.56803 .2486 L
.58746 .25518 L
.59145 .25705 L
.6069 .26715 L
.61478 .27648 L
.62138 .29592 L
.61856 .31535 L
.60828 .33479 L
.6069 .33677 L
.59158 .35423 L
.58746 .35932 L
.5739 .37366 L
.56803 .38038 L
.55744 .3931 L
.54859 .4053 L
.54371 .41254 L
.53175 .43197 L
.52915 .44013 L
.52373 .45141 L
.51909 .47085 L
.52915 .48194 L
.54859 .47839 L
.56803 .4751 L
.58746 .47359 L
.6069 .47941 L
.61524 .49028 L
.61524 .50972 L
.6069 .52059 L
.58746 .52641 L
.56803 .5249 L
.54859 .52161 L
.52915 .51806 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.48091 .47085 L
.47627 .45141 L
.47085 .44013 L
.46825 .43197 L
.45629 .41254 L
.45141 .4053 L
.44256 .3931 L
.43197 .38038 L
.4261 .37366 L
.41254 .35932 L
.40842 .35423 L
.3931 .33677 L
.39172 .33479 L
.38144 .31535 L
.37862 .29592 L
.38522 .27648 L
.3931 .26715 L
.40855 .25705 L
F
.3931 .47941 m
.41254 .47359 L
.43197 .4751 L
.45141 .47839 L
.47085 .48194 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51909 .52915 L
.52373 .54859 L
.52915 .55987 L
.53175 .56803 L
.54371 .58746 L
.54859 .5947 L
.55744 .6069 L
.56803 .61962 L
.5739 .62634 L
.58746 .64068 L
.59158 .64577 L
.6069 .66323 L
.60828 .66521 L
.61856 .68465 L
.62138 .70408 L
.61478 .72352 L
.6069 .73285 L
.59145 .74295 L
.58746 .74482 L
.56803 .7514 L
.54859 .75533 L
.52915 .75761 L
.50972 .75866 L
.49028 .75866 L
.47085 .75761 L
.45141 .75533 L
.43197 .7514 L
.41254 .74482 L
.40855 .74295 L
.3931 .73285 L
.38522 .72352 L
.37862 .70408 L
.38144 .68465 L
.39172 .66521 L
.3931 .66323 L
.40842 .64577 L
.41254 .64068 L
.4261 .62634 L
.43197 .61962 L
.44256 .6069 L
.45141 .5947 L
.45629 .58746 L
.46825 .56803 L
.47085 .55987 L
.47627 .54859 L
.48091 .52915 L
.47085 .51806 L
.45141 .52161 L
.43197 .5249 L
.41254 .52641 L
.3931 .52059 L
.38476 .50972 L
.38476 .49028 L
F
.96 1 0 r
.3931 .47979 m
.41254 .4737 L
.43197 .47512 L
.45141 .47839 L
.47085 .48194 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51909 .52915 L
.52373 .54859 L
.52915 .5599 L
.53171 .56803 L
.54358 .58746 L
.54859 .59499 L
.55698 .6069 L
.56803 .62075 L
.57259 .62634 L
.58746 .64377 L
.5888 .64577 L
.60261 .66521 L
.6069 .67359 L
.61023 .68465 L
.60975 .70408 L
.6069 .71168 L
.59801 .72352 L
.58746 .7317 L
.56803 .74071 L
.56106 .74295 L
.54859 .74592 L
.52915 .74889 L
.50972 .75026 L
.49028 .75026 L
.47085 .74889 L
.45141 .74592 L
.43894 .74295 L
.43197 .74071 L
.41254 .7317 L
.40199 .72352 L
.3931 .71168 L
.39025 .70408 L
.38977 .68465 L
.3931 .67359 L
.39739 .66521 L
.4112 .64577 L
.41254 .64377 L
.42741 .62634 L
.43197 .62075 L
.44302 .6069 L
.45141 .59499 L
.45642 .58746 L
.46829 .56803 L
.47085 .5599 L
.47627 .54859 L
.48091 .52915 L
.47085 .51806 L
.45141 .52161 L
.43197 .52488 L
.41254 .5263 L
.3931 .52021 L
.38521 .50972 L
.38521 .49028 L
F
1 .96 0 r
.3931 .48017 m
.41254 .4738 L
.43197 .47515 L
.45141 .4784 L
.47085 .48194 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51909 .52915 L
.52372 .54859 L
.52915 .55993 L
.53167 .56803 L
.54346 .58746 L
.54859 .59529 L
.55653 .6069 L
.56803 .62197 L
.57134 .62634 L
.58613 .64577 L
.58746 .64747 L
.59754 .66521 L
.60269 .68465 L
.59905 .70408 L
.58746 .71925 L
.5818 .72352 L
.56803 .73106 L
.54859 .73759 L
.52915 .74132 L
.51148 .74295 L
.50972 .74304 L
.49028 .74304 L
.48852 .74295 L
.47085 .74132 L
.45141 .73759 L
.43197 .73106 L
.4182 .72352 L
.41254 .71925 L
.40095 .70408 L
.39731 .68465 L
.40246 .66521 L
.41254 .64747 L
.41387 .64577 L
.42866 .62634 L
.43197 .62197 L
.44347 .6069 L
.45141 .59529 L
.45654 .58746 L
.46833 .56803 L
.47085 .55993 L
.47628 .54859 L
.48091 .52915 L
.47085 .51806 L
.45141 .5216 L
.43197 .52485 L
.41254 .5262 L
.3931 .51983 L
.38565 .50972 L
.38565 .49028 L
F
1 .88 0 r
.3931 .48056 m
.41254 .47391 L
.43197 .47518 L
.45141 .4784 L
.47085 .48194 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51909 .52915 L
.52372 .54859 L
.52915 .55996 L
.53163 .56803 L
.54333 .58746 L
.54859 .59559 L
.55609 .6069 L
.56803 .62332 L
.57015 .62634 L
.58333 .64577 L
.58746 .6521 L
.59302 .66521 L
.59585 .68465 L
.58911 .70408 L
.58746 .70647 L
.56803 .72228 L
.5657 .72352 L
.54859 .73016 L
.52915 .73452 L
.50972 .73652 L
.49028 .73652 L
.47085 .73452 L
.45141 .73016 L
.4343 .72352 L
.43197 .72228 L
.41254 .70647 L
.41089 .70408 L
.40415 .68465 L
.40698 .66521 L
.41254 .6521 L
.41667 .64577 L
.42985 .62634 L
.43197 .62332 L
.44391 .6069 L
.45141 .59559 L
.45667 .58746 L
.46837 .56803 L
.47085 .55996 L
.47628 .54859 L
.48091 .52915 L
.47085 .51806 L
.45141 .5216 L
.43197 .52482 L
.41254 .52609 L
.3931 .51944 L
.38607 .50972 L
.38607 .49028 L
F
1 .8 0 r
.3931 .48095 m
.41254 .47401 L
.43197 .4752 L
.45141 .47841 L
.47085 .48194 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51909 .52915 L
.52371 .54859 L
.52915 .55999 L
.53159 .56803 L
.54321 .58746 L
.54859 .59591 L
.55566 .6069 L
.56803 .62482 L
.56901 .62634 L
.58076 .64577 L
.58746 .6594 L
.58896 .66521 L
.58959 .68465 L
.58746 .69202 L
.57977 .70408 L
.56803 .71411 L
.54859 .72351 L
.54856 .72352 L
.52915 .72849 L
.50972 .73074 L
.49028 .73074 L
.47085 .72849 L
.45144 .72352 L
.45141 .72351 L
.43197 .71411 L
.42023 .70408 L
.41254 .69202 L
.41041 .68465 L
.41104 .66521 L
.41254 .6594 L
.41924 .64577 L
.43099 .62634 L
.43197 .62482 L
.44434 .6069 L
.45141 .59591 L
.45679 .58746 L
.46841 .56803 L
.47085 .55999 L
.47629 .54859 L
.48091 .52915 L
.47085 .51806 L
.45141 .52159 L
.43197 .5248 L
.41254 .52599 L
.3931 .51905 L
.38648 .50972 L
.38648 .49028 L
F
1 .72 0 r
.3931 .48134 m
.41254 .47411 L
.43197 .47523 L
.45141 .47841 L
.47085 .48195 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51909 .52915 L
.52371 .54859 L
.52915 .56002 L
.53156 .56803 L
.54309 .58746 L
.54859 .59623 L
.55524 .6069 L
.5679 .62634 L
.56803 .6265 L
.57841 .64577 L
.58513 .66521 L
.58376 .68465 L
.57082 .70408 L
.56803 .70644 L
.54859 .71736 L
.52915 .7231 L
.52703 .72352 L
.50972 .72562 L
.49028 .72562 L
.47297 .72352 L
.47085 .7231 L
.45141 .71736 L
.43197 .70644 L
.42918 .70408 L
.41624 .68465 L
.41487 .66521 L
.42159 .64577 L
.43197 .6265 L
.4321 .62634 L
.44476 .6069 L
.45141 .59623 L
.45691 .58746 L
.46844 .56803 L
.47085 .56002 L
.47629 .54859 L
.48091 .52915 L
.47085 .51805 L
.45141 .52159 L
.43197 .52477 L
.41254 .52589 L
.3931 .51866 L
.38688 .50972 L
.38688 .49028 L
F
1 .64 0 r
.3931 .48174 m
.41254 .47422 L
.43197 .47526 L
.45141 .47842 L
.47085 .48195 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51909 .52915 L
.5237 .54859 L
.52915 .56006 L
.53152 .56803 L
.54296 .58746 L
.54859 .59657 L
.55482 .6069 L
.5667 .62634 L
.56803 .62814 L
.57626 .64577 L
.58149 .66521 L
.57828 .68465 L
.56803 .69918 L
.56214 .70408 L
.54859 .71174 L
.52915 .71808 L
.50972 .72091 L
.49028 .72091 L
.47085 .71808 L
.45141 .71174 L
.43786 .70408 L
.43197 .69918 L
.42172 .68465 L
.41851 .66521 L
.42374 .64577 L
.43197 .62814 L
.4333 .62634 L
.44518 .6069 L
.45141 .59657 L
.45704 .58746 L
.46848 .56803 L
.47085 .56006 L
.4763 .54859 L
.48091 .52915 L
.47085 .51805 L
.45141 .52158 L
.43197 .52474 L
.41254 .52578 L
.3931 .51826 L
.38726 .50972 L
.38726 .49028 L
F
1 .56 0 r
.3931 .48214 m
.41254 .47432 L
.43197 .47528 L
.45141 .47843 L
.47085 .48195 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51909 .52915 L
.5237 .54859 L
.52915 .56009 L
.53148 .56803 L
.54284 .58746 L
.54859 .59692 L
.55441 .6069 L
.56555 .62634 L
.56803 .63 L
.57428 .64577 L
.57811 .66521 L
.57311 .68465 L
.56803 .69209 L
.55334 .70408 L
.54859 .70659 L
.52915 .71351 L
.50972 .71656 L
.49028 .71656 L
.47085 .71351 L
.45141 .70659 L
.44666 .70408 L
.43197 .69209 L
.42689 .68465 L
.42189 .66521 L
.42572 .64577 L
.43197 .63 L
.43445 .62634 L
.44559 .6069 L
.45141 .59692 L
.45716 .58746 L
.46852 .56803 L
.47085 .56009 L
.4763 .54859 L
.48091 .52915 L
.47085 .51805 L
.45141 .52157 L
.43197 .52472 L
.41254 .52568 L
.3931 .51786 L
.38764 .50972 L
.38764 .49028 L
F
1 .48 0 r
.3931 .48254 m
.41254 .47443 L
.43197 .47531 L
.45141 .47843 L
.47085 .48195 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51908 .52915 L
.52369 .54859 L
.52915 .56012 L
.53144 .56803 L
.54272 .58746 L
.54859 .59728 L
.55401 .6069 L
.56445 .62634 L
.56803 .6322 L
.57247 .64577 L
.57496 .66521 L
.56817 .68465 L
.56803 .68487 L
.54859 .70178 L
.54459 .70408 L
.52915 .70934 L
.50972 .71259 L
.49028 .71259 L
.47085 .70934 L
.45541 .70408 L
.45141 .70178 L
.43197 .68487 L
.43183 .68465 L
.42504 .66521 L
.42753 .64577 L
.43197 .6322 L
.43555 .62634 L
.44599 .6069 L
.45141 .59728 L
.45728 .58746 L
.46856 .56803 L
.47085 .56012 L
.47631 .54859 L
.48092 .52915 L
.47085 .51805 L
.45141 .52157 L
.43197 .52469 L
.41254 .52557 L
.3931 .51746 L
.38801 .50972 L
.38801 .49028 L
F
1 .4 0 r
.3931 .48295 m
.41254 .47453 L
.43197 .47534 L
.45141 .47844 L
.47085 .48195 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51908 .52915 L
.52369 .54859 L
.52915 .56015 L
.5314 .56803 L
.5426 .58746 L
.54859 .59766 L
.55361 .6069 L
.56339 .62634 L
.56803 .63494 L
.5708 .64577 L
.57199 .66521 L
.56803 .67778 L
.5634 .68465 L
.54859 .69725 L
.53439 .70408 L
.52915 .70553 L
.50972 .70897 L
.49028 .70897 L
.47085 .70553 L
.46561 .70408 L
.45141 .69725 L
.4366 .68465 L
.43197 .67778 L
.42801 .66521 L
.4292 .64577 L
.43197 .63494 L
.43661 .62634 L
.44639 .6069 L
.45141 .59766 L
.4574 .58746 L
.4686 .56803 L
.47085 .56015 L
.47631 .54859 L
.48092 .52915 L
.47085 .51805 L
.45141 .52156 L
.43197 .52466 L
.41254 .52547 L
.3931 .51705 L
.38837 .50972 L
.38837 .49028 L
F
1 .32 0 r
.3931 .48337 m
.41254 .47463 L
.43197 .47536 L
.45141 .47844 L
.47085 .48195 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51908 .52915 L
.52368 .54859 L
.52915 .56018 L
.53137 .56803 L
.54248 .58746 L
.54859 .59805 L
.55322 .6069 L
.56237 .62634 L
.56803 .63878 L
.56926 .64577 L
.56919 .66521 L
.56803 .66961 L
.55872 .68465 L
.54859 .693 L
.52915 .70192 L
.52067 .70408 L
.50972 .70566 L
.49028 .70566 L
.47933 .70408 L
.47085 .70192 L
.45141 .693 L
.44128 .68465 L
.43197 .66961 L
.43081 .66521 L
.43074 .64577 L
.43197 .63878 L
.43763 .62634 L
.44678 .6069 L
.45141 .59805 L
.45752 .58746 L
.46863 .56803 L
.47085 .56018 L
.47632 .54859 L
.48092 .52915 L
.47085 .51805 L
.45141 .52156 L
.43197 .52464 L
.41254 .52537 L
.3931 .51663 L
.38872 .50972 L
.38872 .49028 L
F
1 .24 0 r
.3931 .48378 m
.41254 .47474 L
.43197 .47539 L
.45141 .47845 L
.47085 .48195 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51908 .52915 L
.52368 .54859 L
.52915 .56022 L
.53133 .56803 L
.54236 .58746 L
.54859 .59846 L
.55283 .6069 L
.56139 .62634 L
.56777 .64577 L
.56644 .66521 L
.55407 .68465 L
.54859 .68902 L
.52915 .69851 L
.50972 .70252 L
.49028 .70252 L
.47085 .69851 L
.45141 .68902 L
.44593 .68465 L
.43356 .66521 L
.43223 .64577 L
.43861 .62634 L
.44717 .6069 L
.45141 .59846 L
.45764 .58746 L
.46867 .56803 L
.47085 .56022 L
.47632 .54859 L
.48092 .52915 L
.47085 .51805 L
.45141 .52155 L
.43197 .52461 L
.41254 .52526 L
.3931 .51622 L
.38907 .50972 L
.38907 .49028 L
F
1 .16 0 r
.3931 .48421 m
.41254 .47484 L
.43197 .47541 L
.45141 .47845 L
.47085 .48195 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51908 .52915 L
.52367 .54859 L
.52915 .56025 L
.53129 .56803 L
.54224 .58746 L
.54859 .5989 L
.55245 .6069 L
.56045 .62634 L
.56609 .64577 L
.56374 .66521 L
.54939 .68465 L
.54859 .68526 L
.52915 .69533 L
.50972 .69952 L
.49028 .69952 L
.47085 .69533 L
.45141 .68526 L
.45061 .68465 L
.43626 .66521 L
.43391 .64577 L
.43955 .62634 L
.44755 .6069 L
.45141 .5989 L
.45776 .58746 L
.46871 .56803 L
.47085 .56025 L
.47633 .54859 L
.48092 .52915 L
.47085 .51805 L
.45141 .52155 L
.43197 .52459 L
.41254 .52516 L
.3931 .51579 L
.3894 .50972 L
.3894 .49028 L
F
1 .08 0 r
.3931 .48464 m
.41254 .47494 L
.43197 .47544 L
.45141 .47846 L
.47085 .48196 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51908 .52915 L
.52367 .54859 L
.52915 .56028 L
.53125 .56803 L
.54212 .58746 L
.54859 .59935 L
.55208 .6069 L
.55955 .62634 L
.56448 .64577 L
.56113 .66521 L
.54859 .68164 L
.54504 .68465 L
.52915 .69237 L
.50972 .69671 L
.49028 .69671 L
.47085 .69237 L
.45496 .68465 L
.45141 .68164 L
.43887 .66521 L
.43552 .64577 L
.44045 .62634 L
.44792 .6069 L
.45141 .59935 L
.45788 .58746 L
.46875 .56803 L
.47085 .56028 L
.47633 .54859 L
.48092 .52915 L
.47085 .51804 L
.45141 .52154 L
.43197 .52456 L
.41254 .52506 L
.3931 .51536 L
.38973 .50972 L
.38973 .49028 L
F
.96 1 0 r
.45141 .25408 m
.47085 .25111 L
.49028 .24974 L
.50972 .24974 L
.52915 .25111 L
.54859 .25408 L
.56106 .25705 L
.56803 .25929 L
.58746 .2683 L
.59801 .27648 L
.6069 .28832 L
.60975 .29592 L
.61023 .31535 L
.6069 .32641 L
.60261 .33479 L
.5888 .35423 L
.58746 .35623 L
.57259 .37366 L
.56803 .37925 L
.55698 .3931 L
.54859 .40501 L
.54358 .41254 L
.53171 .43197 L
.52915 .4401 L
.52373 .45141 L
.51909 .47085 L
.52915 .48194 L
.54859 .47839 L
.56803 .47512 L
.58746 .4737 L
.6069 .47979 L
.61479 .49028 L
.61479 .50972 L
.6069 .52021 L
.58746 .5263 L
.56803 .52488 L
.54859 .52161 L
.52915 .51806 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.48091 .47085 L
.47627 .45141 L
.47085 .4401 L
.46829 .43197 L
.45642 .41254 L
.45141 .40501 L
.44302 .3931 L
.43197 .37925 L
.42741 .37366 L
.41254 .35623 L
.4112 .35423 L
.39739 .33479 L
.3931 .32641 L
.38977 .31535 L
.39025 .29592 L
.3931 .28832 L
.40199 .27648 L
.41254 .2683 L
.43197 .25929 L
.43894 .25705 L
F
1 0 0 r
.3931 .48508 m
.41254 .47505 L
.43197 .47547 L
.45141 .47846 L
.47085 .48196 L
.47107 .49028 L
.47107 .50972 L
.49028 .52888 L
.50972 .52888 L
.51908 .52915 L
.52366 .54859 L
.52915 .56032 L
.53121 .56803 L
.542 .58746 L
.54859 .59983 L
.55171 .6069 L
.55869 .62634 L
.56292 .64577 L
.55859 .66521 L
.54859 .67817 L
.54041 .68465 L
.52915 .6896 L
.50972 .6941 L
.49028 .6941 L
.47085 .6896 L
.45959 .68465 L
.45141 .67817 L
.44141 .66521 L
.43708 .64577 L
.44131 .62634 L
.44829 .6069 L
.45141 .59983 L
.458 .58746 L
.46879 .56803 L
.47085 .56032 L
.47634 .54859 L
.48092 .52915 L
.47085 .51804 L
.45141 .52154 L
.43197 .52453 L
.41254 .52495 L
.3931 .51492 L
.39006 .50972 L
.39006 .49028 L
F
1 .96 0 r
.49028 .25696 m
.50972 .25696 L
.51148 .25705 L
.52915 .25868 L
.54859 .26241 L
.56803 .26894 L
.5818 .27648 L
.58746 .28075 L
.59905 .29592 L
.60269 .31535 L
.59754 .33479 L
.58746 .35253 L
.58613 .35423 L
.57134 .37366 L
.56803 .37803 L
.55653 .3931 L
.54859 .40471 L
.54346 .41254 L
.53167 .43197 L
.52915 .44007 L
.52372 .45141 L
.51909 .47085 L
.52915 .48194 L
.54859 .4784 L
.56803 .47515 L
.58746 .4738 L
.6069 .48017 L
.61435 .49028 L
.61435 .50972 L
.6069 .51983 L
.58746 .5262 L
.56803 .52485 L
.54859 .5216 L
.52915 .51806 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.48091 .47085 L
.47628 .45141 L
.47085 .44007 L
.46833 .43197 L
.45654 .41254 L
.45141 .40471 L
.44347 .3931 L
.43197 .37803 L
.42866 .37366 L
.41387 .35423 L
.41254 .35253 L
.40246 .33479 L
.39731 .31535 L
.40095 .29592 L
.41254 .28075 L
.4182 .27648 L
.43197 .26894 L
.45141 .26241 L
.47085 .25868 L
.48852 .25705 L
F
1 .88 0 r
.45141 .26984 m
.47085 .26548 L
.49028 .26348 L
.50972 .26348 L
.52915 .26548 L
.54859 .26984 L
.5657 .27648 L
.56803 .27772 L
.58746 .29353 L
.58911 .29592 L
.59585 .31535 L
.59302 .33479 L
.58746 .3479 L
.58333 .35423 L
.57015 .37366 L
.56803 .37668 L
.55609 .3931 L
.54859 .40441 L
.54333 .41254 L
.53163 .43197 L
.52915 .44004 L
.52372 .45141 L
.51909 .47085 L
.52915 .48194 L
.54859 .4784 L
.56803 .47518 L
.58746 .47391 L
.6069 .48056 L
.61393 .49028 L
.61393 .50972 L
.6069 .51944 L
.58746 .52609 L
.56803 .52482 L
.54859 .5216 L
.52915 .51806 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.48091 .47085 L
.47628 .45141 L
.47085 .44004 L
.46837 .43197 L
.45667 .41254 L
.45141 .40441 L
.44391 .3931 L
.43197 .37668 L
.42985 .37366 L
.41667 .35423 L
.41254 .3479 L
.40698 .33479 L
.40415 .31535 L
.41089 .29592 L
.41254 .29353 L
.43197 .27772 L
.4343 .27648 L
F
1 .8 0 r
.47085 .27151 m
.49028 .26926 L
.50972 .26926 L
.52915 .27151 L
.54856 .27648 L
.54859 .27649 L
.56803 .28589 L
.57977 .29592 L
.58746 .30798 L
.58959 .31535 L
.58896 .33479 L
.58746 .3406 L
.58076 .35423 L
.56901 .37366 L
.56803 .37518 L
.55566 .3931 L
.54859 .40409 L
.54321 .41254 L
.53159 .43197 L
.52915 .44001 L
.52371 .45141 L
.51909 .47085 L
.52915 .48194 L
.54859 .47841 L
.56803 .4752 L
.58746 .47401 L
.6069 .48095 L
.61352 .49028 L
.61352 .50972 L
.6069 .51905 L
.58746 .52599 L
.56803 .5248 L
.54859 .52159 L
.52915 .51806 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.48091 .47085 L
.47629 .45141 L
.47085 .44001 L
.46841 .43197 L
.45679 .41254 L
.45141 .40409 L
.44434 .3931 L
.43197 .37518 L
.43099 .37366 L
.41924 .35423 L
.41254 .3406 L
.41104 .33479 L
.41041 .31535 L
.41254 .30798 L
.42023 .29592 L
.43197 .28589 L
.45141 .27649 L
.45144 .27648 L
F
1 .72 0 r
.49028 .27438 m
.50972 .27438 L
.52703 .27648 L
.52915 .2769 L
.54859 .28264 L
.56803 .29356 L
.57082 .29592 L
.58376 .31535 L
.58513 .33479 L
.57841 .35423 L
.56803 .3735 L
.5679 .37366 L
.55524 .3931 L
.54859 .40377 L
.54309 .41254 L
.53156 .43197 L
.52915 .43998 L
.52371 .45141 L
.51909 .47085 L
.52915 .48195 L
.54859 .47841 L
.56803 .47523 L
.58746 .47411 L
.6069 .48134 L
.61312 .49028 L
.61312 .50972 L
.6069 .51866 L
.58746 .52589 L
.56803 .52477 L
.54859 .52159 L
.52915 .51805 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.48091 .47085 L
.47629 .45141 L
.47085 .43998 L
.46844 .43197 L
.45691 .41254 L
.45141 .40377 L
.44476 .3931 L
.4321 .37366 L
.43197 .3735 L
.42159 .35423 L
.41487 .33479 L
.41624 .31535 L
.42918 .29592 L
.43197 .29356 L
.45141 .28264 L
.47085 .2769 L
.47297 .27648 L
F
1 .64 0 r
.45141 .28826 m
.47085 .28192 L
.49028 .27909 L
.50972 .27909 L
.52915 .28192 L
.54859 .28826 L
.56214 .29592 L
.56803 .30082 L
.57828 .31535 L
.58149 .33479 L
.57626 .35423 L
.56803 .37186 L
.5667 .37366 L
.55482 .3931 L
.54859 .40343 L
.54296 .41254 L
.53152 .43197 L
.52915 .43994 L
.5237 .45141 L
.51909 .47085 L
.52915 .48195 L
.54859 .47842 L
.56803 .47526 L
.58746 .47422 L
.6069 .48174 L
.61274 .49028 L
.61274 .50972 L
.6069 .51826 L
.58746 .52578 L
.56803 .52474 L
.54859 .52158 L
.52915 .51805 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.48091 .47085 L
.4763 .45141 L
.47085 .43994 L
.46848 .43197 L
.45704 .41254 L
.45141 .40343 L
.44518 .3931 L
.4333 .37366 L
.43197 .37186 L
.42374 .35423 L
.41851 .33479 L
.42172 .31535 L
.43197 .30082 L
.43786 .29592 L
F
1 .56 0 r
.45141 .29341 m
.47085 .28649 L
.49028 .28344 L
.50972 .28344 L
.52915 .28649 L
.54859 .29341 L
.55334 .29592 L
.56803 .30791 L
.57311 .31535 L
.57811 .33479 L
.57428 .35423 L
.56803 .37 L
.56555 .37366 L
.55441 .3931 L
.54859 .40308 L
.54284 .41254 L
.53148 .43197 L
.52915 .43991 L
.5237 .45141 L
.51909 .47085 L
.52915 .48195 L
.54859 .47843 L
.56803 .47528 L
.58746 .47432 L
.6069 .48214 L
.61236 .49028 L
.61236 .50972 L
.6069 .51786 L
.58746 .52568 L
.56803 .52472 L
.54859 .52157 L
.52915 .51805 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.48091 .47085 L
.4763 .45141 L
.47085 .43991 L
.46852 .43197 L
.45716 .41254 L
.45141 .40308 L
.44559 .3931 L
.43445 .37366 L
.43197 .37 L
.42572 .35423 L
.42189 .33479 L
.42689 .31535 L
.43197 .30791 L
.44666 .29592 L
F
1 .48 0 r
.47085 .29066 m
.49028 .28741 L
.50972 .28741 L
.52915 .29066 L
.54459 .29592 L
.54859 .29822 L
.56803 .31513 L
.56817 .31535 L
.57496 .33479 L
.57247 .35423 L
.56803 .3678 L
.56445 .37366 L
.55401 .3931 L
.54859 .40272 L
.54272 .41254 L
.53144 .43197 L
.52915 .43988 L
.52369 .45141 L
.51908 .47085 L
.52915 .48195 L
.54859 .47843 L
.56803 .47531 L
.58746 .47443 L
.6069 .48254 L
.61199 .49028 L
.61199 .50972 L
.6069 .51746 L
.58746 .52557 L
.56803 .52469 L
.54859 .52157 L
.52915 .51805 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.48092 .47085 L
.47631 .45141 L
.47085 .43988 L
.46856 .43197 L
.45728 .41254 L
.45141 .40272 L
.44599 .3931 L
.43555 .37366 L
.43197 .3678 L
.42753 .35423 L
.42504 .33479 L
.43183 .31535 L
.43197 .31513 L
.45141 .29822 L
.45541 .29592 L
F
1 .4 0 r
.47085 .29447 m
.49028 .29103 L
.50972 .29103 L
.52915 .29447 L
.53439 .29592 L
.54859 .30275 L
.5634 .31535 L
.56803 .32222 L
.57199 .33479 L
.5708 .35423 L
.56803 .36506 L
.56339 .37366 L
.55361 .3931 L
.54859 .40234 L
.5426 .41254 L
.5314 .43197 L
.52915 .43985 L
.52369 .45141 L
.51908 .47085 L
.52915 .48195 L
.54859 .47844 L
.56803 .47534 L
.58746 .47453 L
.6069 .48295 L
.61163 .49028 L
.61163 .50972 L
.6069 .51705 L
.58746 .52547 L
.56803 .52466 L
.54859 .52156 L
.52915 .51805 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.48092 .47085 L
.47631 .45141 L
.47085 .43985 L
.4686 .43197 L
.4574 .41254 L
.45141 .40234 L
.44639 .3931 L
.43661 .37366 L
.43197 .36506 L
.4292 .35423 L
.42801 .33479 L
.43197 .32222 L
.4366 .31535 L
.45141 .30275 L
.46561 .29592 L
F
1 .32 0 r
.49028 .29434 m
.50972 .29434 L
.52067 .29592 L
.52915 .29808 L
.54859 .307 L
.55872 .31535 L
.56803 .33039 L
.56919 .33479 L
.56926 .35423 L
.56803 .36122 L
.56237 .37366 L
.55322 .3931 L
.54859 .40195 L
.54248 .41254 L
.53137 .43197 L
.52915 .43982 L
.52368 .45141 L
.51908 .47085 L
.52915 .48195 L
.54859 .47844 L
.56803 .47536 L
.58746 .47463 L
.6069 .48337 L
.61128 .49028 L
.61128 .50972 L
.6069 .51663 L
.58746 .52537 L
.56803 .52464 L
.54859 .52156 L
.52915 .51805 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.48092 .47085 L
.47632 .45141 L
.47085 .43982 L
.46863 .43197 L
.45752 .41254 L
.45141 .40195 L
.44678 .3931 L
.43763 .37366 L
.43197 .36122 L
.43074 .35423 L
.43081 .33479 L
.43197 .33039 L
.44128 .31535 L
.45141 .307 L
.47085 .29808 L
.47933 .29592 L
F
1 .24 0 r
.45141 .31098 m
.47085 .30149 L
.49028 .29748 L
.50972 .29748 L
.52915 .30149 L
.54859 .31098 L
.55407 .31535 L
.56644 .33479 L
.56777 .35423 L
.56139 .37366 L
.55283 .3931 L
.54859 .40154 L
.54236 .41254 L
.53133 .43197 L
.52915 .43978 L
.52368 .45141 L
.51908 .47085 L
.52915 .48195 L
.54859 .47845 L
.56803 .47539 L
.58746 .47474 L
.6069 .48378 L
.61093 .49028 L
.61093 .50972 L
.6069 .51622 L
.58746 .52526 L
.56803 .52461 L
.54859 .52155 L
.52915 .51805 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.48092 .47085 L
.47632 .45141 L
.47085 .43978 L
.46867 .43197 L
.45764 .41254 L
.45141 .40154 L
.44717 .3931 L
.43861 .37366 L
.43223 .35423 L
.43356 .33479 L
.44593 .31535 L
F
1 .16 0 r
.45141 .31474 m
.47085 .30467 L
.49028 .30048 L
.50972 .30048 L
.52915 .30467 L
.54859 .31474 L
.54939 .31535 L
.56374 .33479 L
.56609 .35423 L
.56045 .37366 L
.55245 .3931 L
.54859 .4011 L
.54224 .41254 L
.53129 .43197 L
.52915 .43975 L
.52367 .45141 L
.51908 .47085 L
.52915 .48195 L
.54859 .47845 L
.56803 .47541 L
.58746 .47484 L
.6069 .48421 L
.6106 .49028 L
.6106 .50972 L
.6069 .51579 L
.58746 .52516 L
.56803 .52459 L
.54859 .52155 L
.52915 .51805 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.48092 .47085 L
.47633 .45141 L
.47085 .43975 L
.46871 .43197 L
.45776 .41254 L
.45141 .4011 L
.44755 .3931 L
.43955 .37366 L
.43391 .35423 L
.43626 .33479 L
.45061 .31535 L
F
1 .08 0 r
.47085 .30763 m
.49028 .30329 L
.50972 .30329 L
.52915 .30763 L
.54504 .31535 L
.54859 .31836 L
.56113 .33479 L
.56448 .35423 L
.55955 .37366 L
.55208 .3931 L
.54859 .40065 L
.54212 .41254 L
.53125 .43197 L
.52915 .43972 L
.52367 .45141 L
.51908 .47085 L
.52915 .48196 L
.54859 .47846 L
.56803 .47544 L
.58746 .47494 L
.6069 .48464 L
.61027 .49028 L
.61027 .50972 L
.6069 .51536 L
.58746 .52506 L
.56803 .52456 L
.54859 .52154 L
.52915 .51804 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.48092 .47085 L
.47633 .45141 L
.47085 .43972 L
.46875 .43197 L
.45788 .41254 L
.45141 .40065 L
.44792 .3931 L
.44045 .37366 L
.43552 .35423 L
.43887 .33479 L
.45141 .31836 L
.45496 .31535 L
F
1 0 0 r
.47085 .3104 m
.49028 .3059 L
.50972 .3059 L
.52915 .3104 L
.54041 .31535 L
.54859 .32183 L
.55859 .33479 L
.56292 .35423 L
.55869 .37366 L
.55171 .3931 L
.54859 .40017 L
.542 .41254 L
.53121 .43197 L
.52915 .43968 L
.52366 .45141 L
.51908 .47085 L
.52915 .48196 L
.54859 .47846 L
.56803 .47547 L
.58746 .47505 L
.6069 .48508 L
.60994 .49028 L
.60994 .50972 L
.6069 .51492 L
.58746 .52495 L
.56803 .52453 L
.54859 .52154 L
.52915 .51804 L
.52893 .50972 L
.52893 .49028 L
.50972 .47112 L
.49028 .47112 L
.48092 .47085 L
.47634 .45141 L
.47085 .43968 L
.46879 .43197 L
.458 .41254 L
.45141 .40017 L
.44829 .3931 L
.44131 .37366 L
.43708 .35423 L
.44141 .33479 L
.45141 .32183 L
.45959 .31535 L
F
0 .08 1 r
.54859 .41234 m
.56803 .39991 L
.58746 .397 L
.6069 .40076 L
.62634 .41227 L
.62656 .41254 L
.64383 .43197 L
.64577 .43481 L
.65407 .45141 L
.64577 .46618 L
.62634 .46529 L
.6069 .46637 L
.58746 .46976 L
.57568 .47085 L
.56803 .47419 L
.54859 .4782 L
.52915 .4819 L
.51913 .47085 L
.5239 .45141 L
.52915 .44107 L
.5331 .43197 L
.5484 .41254 L
F
0 0 1 r
.54859 .4125 m
.56803 .40027 L
.58746 .39765 L
.6069 .40171 L
.6244 .41254 L
.62634 .41404 L
.64057 .43197 L
.64577 .44205 L
.64814 .45141 L
.64577 .45819 L
.62634 .46386 L
.6069 .46594 L
.58746 .46962 L
.57555 .47085 L
.56803 .47417 L
.54859 .4782 L
.52915 .48189 L
.51913 .47085 L
.52391 .45141 L
.52915 .44109 L
.53315 .43197 L
.54856 .41254 L
F
1 g
.5 .5 m
.5 .5 .15873 0 365.73 arc
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{472, 472},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 471}, {471, 0}} -> {-3.3956, -3.37561, 0.013901, \
0.013901}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<kirsh.eps\>\"", ",", "%"}], "]"}]], "Input"],

Cell[BoxData["\<\"kirsh.eps\"\>"], "Output"]
}, Open  ]]
},
ScreenStyleEnvironment->"Working",
WindowSize->{910, 643},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[1309, 36, 386, 9, 99, "Input"],
Cell[CellGroupData[{
Cell[1720, 49, 315, 9, 77, "Input"],
Cell[CellGroupData[{
Cell[2060, 62, 949, 12, 205, "Print"],
Cell[3012, 76, 441, 13, 24, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3502, 95, 874, 24, 99, "Input"],
Cell[4379, 121, 2193, 75, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6609, 201, 254, 6, 32, "Input"],
Cell[6866, 209, 173, 7, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7076, 221, 2084, 69, 121, "Input"],
Cell[9163, 292, 412, 15, 86, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9612, 312, 1055, 34, 99, "Input"],
Cell[10670, 348, 2167, 66, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12874, 419, 1254, 36, 121, "Input"],
Cell[14131, 457, 28, 0, 31, "Output"],
Cell[14162, 459, 83, 2, 31, "Output"],
Cell[14248, 463, 2803, 84, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17088, 552, 1922, 54, 165, "Input"],
Cell[19013, 608, 1130, 37, 96, "Output"],
Cell[20146, 647, 568, 19, 76, "Output"],
Cell[20717, 668, 350, 12, 52, "Output"],
Cell[21070, 682, 7720, 410, 186, 5306, 367, "GraphicsData", "PostScript", \
"Graphics"],
Cell[28793, 1094, 134, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28964, 1103, 1408, 45, 121, "Input"],
Cell[30375, 1150, 864, 31, 55, "Output"],
Cell[31242, 1183, 135, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31414, 1192, 2259, 65, 209, "Input"],
Cell[33676, 1259, 144, 5, 31, "Output"],
Cell[33823, 1266, 135303, 7936, 480, 116755, 7628, "GraphicsData", \
"PostScript", "Graphics"],
Cell[169129, 9204, 134, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[169300, 9213, 98, 2, 32, "Input"],
Cell[169401, 9217, 44, 0, 31, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

