(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     12716,        466]
NotebookOptionsPosition[     10965,        401]
NotebookOutlinePosition[     11408,        419]
CellTagsIndexPosition[     11365,        416]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "3", "rd", " ", "order", " ", "polynomial", " ", "solutions", " ", "for", 
    " ", "Love", " ", "strain", " ", "function"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"SetDirectory", "[", "myrootdir", "]"}]}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<elastica\\Packages\>\"", "]"}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\\\\elastica\\\\Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Displacement.m"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CIS", "=", 
   RowBox[{"IsotropicStiffness", "[", "nu", "]"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Third", " ", "order", " ", 
     RowBox[{"candidates", ":", "\[IndentingNewLine]", "Z"}]}], " ", "=", " ",
     
    RowBox[{"z", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"r", "^", "2"}], "+", 
       RowBox[{"z", "^", "2"}]}], ")"}]}]}], ",", " ", "\[IndentingNewLine]", 
   
   RowBox[{"Z", " ", "=", " ", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"z", "^", "3"}]}], "-", 
     RowBox[{"3", " ", 
      RowBox[{"r", "^", "2"}], " ", "z"}]}]}]}], "  ", "*)"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Z", " ", "=", " ", 
   RowBox[{
    RowBox[{"A", " ", "z", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"r", "^", "2"}], "+", 
       RowBox[{"z", "^", "2"}]}], ")"}]}], "+", 
    RowBox[{"B", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"z", "^", "3"}]}], "-", 
       RowBox[{"3", " ", 
        RowBox[{"r", "^", "2"}], " ", "z"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Love", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "Z"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Biharmonic", "[", "Love", "]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Laplacian", "[", "Love", "]"}], "-", 
    RowBox[{
     RowBox[{
      RowBox[{"Grad", "[", 
       RowBox[{"Div", "[", "Love", "]"}], "]"}], "/", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{"1", "-", "nu"}], ")"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"A", "-", 
       RowBox[{"3", " ", "B"}]}], ")"}], " ", "r"}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu"}]], ",", "0", ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", "B"}], "+", 
       RowBox[{"A", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "7"}], "+", 
          RowBox[{"10", " ", "nu"}]}], ")"}]}]}], ")"}], " ", "z"}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu"}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Strain", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Grad", "[", "u", "]"}], "+", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}], "/", "2"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"A", "-", 
       RowBox[{"3", " ", "B"}]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "nu"}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"A", "-", 
       RowBox[{"3", " ", "B"}]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "nu"}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"6", " ", "B"}], "+", 
       RowBox[{"A", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "7"}], "+", 
          RowBox[{"10", " ", "nu"}]}], ")"}]}]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "nu"}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Love", " ", "strain", " ", "function", " ", "for", " ", "uniaxial", " ", 
    "STRAIN", " ", "state"}], " ", "*)"}], "\[IndentingNewLine]", " ", 
  RowBox[{
   RowBox[{"Bsoluni", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Strain", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{"{", "B", "}"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Z", "/.", "Bsoluni"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"B", "\[Rule]", 
  FractionBox["A", "3"]}]], "Output"],

Cell[BoxData[
 FractionBox[
  RowBox[{"5", " ", "A", " ", 
   SuperscriptBox["z", "3"]}], "3"]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Stress", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"GTr", "[", 
    RowBox[{
     RowBox[{"GDot", "[", 
      RowBox[{"CIS", ",", "Strain", ",", "1", ",", "1"}], "]"}], ",", "1", 
     ",", "4"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"A", "-", 
       RowBox[{"3", " ", "B"}], "-", 
       RowBox[{"5", " ", "A", " ", "nu"}]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["nu", "2"]}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"A", "-", 
       RowBox[{"3", " ", "B"}], "-", 
       RowBox[{"5", " ", "A", " ", "nu"}]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["nu", "2"]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"6", " ", "B"}], "+", 
       RowBox[{"A", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "7"}], "+", 
          RowBox[{"5", " ", "nu"}]}], ")"}]}]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["nu", "2"]}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Div", "[", "Stress", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Love", " ", "strain", " ", "function", " ", "for", " ", "hydrostatic", 
    " ", "stress", " ", "state"}], " ", "*)"}], "\[IndentingNewLine]", " ", 
  RowBox[{
   RowBox[{"Bsolhyd", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Stress", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
         RowBox[{"Stress", "[", 
          RowBox[{"[", 
           RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "\[Equal]", "0"}], ",", 
       RowBox[{"{", "B", "}"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Z", "/.", "Bsolhyd"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"B", "\[Rule]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["2", "9"]}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "A"}], "+", 
     RowBox[{"5", " ", "A", " ", "nu"}]}], ")"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  FractionBox["5", "9"], " ", "A", " ", "z", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "3"}], "+", 
       RowBox[{"6", " ", "nu"}]}], ")"}], " ", 
     SuperscriptBox["r", "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"5", "-", 
       RowBox[{"4", " ", "nu"}]}], ")"}], " ", 
     SuperscriptBox["z", "2"]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Love", " ", "strain", " ", "function", " ", "for", " ", "uniaxial", " ", 
    "stress", " ", "state"}], " ", "*)"}], "\[IndentingNewLine]", " ", 
  RowBox[{
   RowBox[{"Bsoluni", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Stress", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{"{", "B", "}"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Z", "/.", "Bsoluni"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"B", "\[Rule]", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   RowBox[{"(", 
    RowBox[{"A", "-", 
     RowBox[{"5", " ", "A", " ", "nu"}]}], ")"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  FractionBox["5", "3"], " ", "A", " ", "z", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3", " ", "nu", " ", 
     SuperscriptBox["r", "2"]}], "+", 
    SuperscriptBox["z", "2"], "-", 
    RowBox[{"2", " ", "nu", " ", 
     SuperscriptBox["z", "2"]}]}], ")"}]}]], "Output"]
}, Open  ]]
},
WindowSize->{891, 574},
WindowMargins->{{Automatic, 31}, {Automatic, 9}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 289, 7, 55, "Input"],
Cell[1623, 47, 52, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1712, 52, 90, 1, 32, "Input"],
Cell[1805, 55, 76, 0, 31, "Output"]
}, Open  ]],
Cell[1896, 58, 239, 5, 77, "Input"],
Cell[CellGroupData[{
Cell[2160, 67, 139, 3, 32, "Input"],
Cell[2302, 72, 98, 2, 31, "Output"]
}, Open  ]],
Cell[2415, 77, 561, 18, 77, "Input"],
Cell[CellGroupData[{
Cell[3001, 99, 682, 23, 77, "Input"],
Cell[3686, 124, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3806, 131, 327, 10, 32, "Input"],
Cell[4136, 143, 579, 21, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4752, 169, 279, 9, 30, "Input"],
Cell[5034, 180, 796, 28, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5867, 213, 670, 19, 90, "Input"],
Cell[6540, 234, 77, 2, 42, "Output"],
Cell[6620, 238, 106, 3, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6763, 246, 249, 7, 30, "Input"],
Cell[7015, 255, 980, 33, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8032, 293, 96, 2, 30, "Input"],
Cell[8131, 297, 83, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8251, 304, 808, 23, 130, "Input"],
Cell[9062, 329, 255, 9, 42, "Output"],
Cell[9320, 340, 429, 15, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9786, 360, 670, 19, 90, "Input"],
Cell[10459, 381, 187, 6, 42, "Output"],
Cell[10649, 389, 300, 9, 42, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

