(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     21249,        753]
NotebookOptionsPosition[     19263,        679]
NotebookOutlinePosition[     19707,        697]
CellTagsIndexPosition[     19664,        694]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Solution", " ", "for", " ", "Kelvin", " ", "force", " ", "by", " ", 
    "Love", " ", "strain", " ", "function", " ", "after", " ", "Timoshenko"}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"SetDirectory", "[", "myrootdir", "]"}]}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<elastica\\Packages\>\"", "]"}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\\\\elastica\\\\Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Displacement.m"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Z", "=", 
   RowBox[{"B", " ", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"r", "^", "2"}], "+", 
      RowBox[{"z", "^", "2"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Love", "=", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "Z"}], "}"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"B", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      SuperscriptBox["z", "2"]}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Biharmonic", "[", "Love", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Laplacian", "[", "Love", "]"}], "-", 
    RowBox[{
     RowBox[{
      RowBox[{"Grad", "[", 
       RowBox[{"Div", "[", "Love", "]"}], "]"}], "/", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{"1", "-", "nu"}], ")"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"B", " ", "r", " ", "z"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "-", 
       RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}]], ",", "0", ",", 
   FractionBox[
    RowBox[{"B", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"4", " ", "nu"}]}], ")"}], " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
        SuperscriptBox["z", "2"]}]}], ")"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Strain", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Grad", "[", "u", "]"}], "+", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}], "/", "2"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"B", " ", "z", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["r", "2"]}], "+", 
          SuperscriptBox["z", "2"]}], ")"}]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]}]]}], ",", "0", ",", 
     FractionBox[
      RowBox[{"B", " ", "r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          SuperscriptBox["r", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "nu"}], ")"}], " ", 
          SuperscriptBox["z", "2"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"B", " ", "z"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "-", 
         RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"3", "/", "2"}]]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"B", " ", "r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          SuperscriptBox["r", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "nu"}], ")"}], " ", 
          SuperscriptBox["z", "2"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}]], ",", "0", ",", 
     FractionBox[
      RowBox[{"B", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"4", " ", "nu"}]}], ")"}], " ", 
          SuperscriptBox["r", "2"]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
          SuperscriptBox["z", "2"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"CIS", "=", 
   RowBox[{"IsotropicStiffness", "[", "nu", "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Stress", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"GTr", "[", 
    RowBox[{
     RowBox[{"GDot", "[", 
      RowBox[{"CIS", ",", "Strain", ",", "1", ",", "1"}], "]"}], ",", "1", 
     ",", "4"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"B", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          SuperscriptBox["r", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          SuperscriptBox["z", "2"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}]], ",", "0", ",", 
     FractionBox[
      RowBox[{"B", " ", "r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          SuperscriptBox["r", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "nu"}], ")"}], " ", 
          SuperscriptBox["z", "2"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"B", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "nu"}]}], ")"}], " ", "z"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"3", "/", "2"}]]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"B", " ", "r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          SuperscriptBox["r", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "nu"}], ")"}], " ", 
          SuperscriptBox["z", "2"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}]], ",", "0", ",", 
     FractionBox[
      RowBox[{"B", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          SuperscriptBox["r", "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "nu"}], ")"}], " ", 
          SuperscriptBox["z", "2"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Div", "[", "Stress", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StressSpherical", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Stress", "/.", 
       RowBox[{"r", "\[Rule]", 
        RowBox[{"R", " ", 
         RowBox[{"Sin", "[", "p", "]"}]}]}]}], "/.", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"R", " ", 
        RowBox[{"Cos", "[", "p", "]"}]}]}]}], "]"}], "/.", 
    RowBox[{
     SqrtBox[
      SuperscriptBox["R", "2"]], "\[Rule]", "R"}]}], "/.", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", 
      SqrtBox[
       SuperscriptBox["R", "2"]]}], ")"}], "\[Rule]", 
    RowBox[{"1", "/", "R"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"B", " ", 
       RowBox[{"Cos", "[", "p", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"4", " ", "nu"}], "-", 
         RowBox[{"3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox["R", "2"]}]], ",", "0", ",", 
     FractionBox[
      RowBox[{"B", " ", 
       RowBox[{"(", 
        RowBox[{"5", "-", 
         RowBox[{"4", " ", "nu"}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Sin", "[", "p", "]"}]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox["R", "2"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"B", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
       RowBox[{"Cos", "[", "p", "]"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox["R", "2"]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"B", " ", 
       RowBox[{"(", 
        RowBox[{"5", "-", 
         RowBox[{"4", " ", "nu"}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Sin", "[", "p", "]"}]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox["R", "2"]}]], ",", "0", ",", 
     FractionBox[
      RowBox[{"B", " ", 
       RowBox[{"Cos", "[", "p", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"5", "-", 
         RowBox[{"4", " ", "nu"}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}]}], 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox["R", "2"]}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"R", ",", "p", ",", "t"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eR", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Spherical", "[", 
  RowBox[{"R", ",", "p", ",", "t"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Traction", "=", 
  RowBox[{"Dot", "[", 
   RowBox[{"StressSpherical", ",", "eR"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"B", " ", 
      RowBox[{"Cos", "[", "p", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"4", " ", "nu"}], "-", 
        RowBox[{"3", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}]}], 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["nu", "2"]}], ")"}], " ", 
      SuperscriptBox["R", "2"]}]]}], ",", "0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"B", " ", 
      RowBox[{"(", 
       RowBox[{"5", "-", 
        RowBox[{"4", " ", "nu"}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}], " ", 
      RowBox[{"Sin", "[", "p", "]"}]}], 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["nu", "2"]}], ")"}], " ", 
      SuperscriptBox["R", "2"]}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResForce", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"FieldToCartesian", "[", "Traction", "]"}], " ", 
      RowBox[{"R", "^", "2"}], " ", 
      RowBox[{"Sin", "[", "p", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "0", ",", "Pi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"2", " ", "Pi"}]}], "}"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", "B", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"10", " ", "nu"}]}], ")"}], " ", "\[Pi]"}], 
     RowBox[{"15", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["nu", "2"]}], ")"}]}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ResForce", "+", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "P"}], "}"}]}], "\[Equal]", "0"}], ",", 
    "B"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"B", "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["nu", "2"]}], ")"}], " ", "P"}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"\[Pi]", "+", 
        RowBox[{"10", " ", "nu", " ", "\[Pi]"}]}], ")"}]}]]}], "}"}], 
  "}"}]], "Output"]
}, Open  ]]
},
WindowSize->{460, 574},
WindowMargins->{{18, Automatic}, {Automatic, 23}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 351, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 313, 7, 77, "Input"],
Cell[1647, 47, 52, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1736, 52, 90, 1, 32, "Input"],
Cell[1829, 55, 76, 0, 31, "Output"]
}, Open  ]],
Cell[1920, 58, 122, 2, 55, "Input"],
Cell[CellGroupData[{
Cell[2067, 64, 139, 3, 32, "Input"],
Cell[2209, 69, 98, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2344, 76, 316, 10, 55, "Input"],
Cell[2663, 88, 203, 7, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2903, 100, 101, 2, 32, "Input"],
Cell[3007, 104, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3127, 111, 327, 10, 55, "Input"],
Cell[3457, 123, 1126, 39, 108, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4620, 167, 279, 9, 30, "Input"],
Cell[4902, 178, 3410, 111, 209, "Output"]
}, Open  ]],
Cell[8327, 292, 116, 3, 30, "Input"],
Cell[CellGroupData[{
Cell[8468, 299, 249, 7, 30, "Input"],
Cell[8720, 308, 3858, 125, 209, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12615, 438, 96, 2, 30, "Input"],
Cell[12714, 442, 83, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12834, 449, 631, 21, 77, "Input"],
Cell[13468, 472, 2545, 81, 188, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16050, 558, 288, 8, 50, "Input"],
Cell[16341, 568, 96, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16474, 575, 125, 3, 30, "Input"],
Cell[16602, 580, 1039, 34, 80, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17678, 619, 470, 13, 90, "Input"],
Cell[18151, 634, 398, 13, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18586, 652, 252, 8, 30, "Input"],
Cell[18841, 662, 406, 14, 47, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

