(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     23046,        796]
NotebookOptionsPosition[     21135,        725]
NotebookOutlinePosition[     21579,        743]
CellTagsIndexPosition[     21536,        740]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Solution", " ", "for", " ", "momentless", " ", "force", " ", "dipole", 
    " ", "by", " ", "Love", " ", "strain", " ", "function"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"SetDirectory", "[", "myrootdir", "]"}]}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<elastica\\Packages\>\"", "]"}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\\\\elastica\\\\Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Displacement.m"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Z", "=", 
   RowBox[{"B", " ", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"r", "^", "2"}], "+", 
      RowBox[{"z", "^", "2"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Z1", "=", 
   RowBox[{"D", "[", 
    RowBox[{"Z", ",", "z"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Love", "=", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "Z1"}], "}"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   FractionBox[
    RowBox[{"B", " ", "z"}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      SuperscriptBox["z", "2"]}]]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Biharmonic", "[", "Love", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Laplacian", "[", "Love", "]"}], "-", 
    RowBox[{
     RowBox[{
      RowBox[{"Grad", "[", 
       RowBox[{"Div", "[", "Love", "]"}], "]"}], "/", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{"1", "-", "nu"}], ")"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"B", " ", "r", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["z", "2"]}]}], ")"}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r", "2"], "+", 
         SuperscriptBox["z", "2"]}], ")"}], 
       RowBox[{"5", "/", "2"}]]}]]}], ",", "0", ",", 
   FractionBox[
    RowBox[{"B", " ", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"4", " ", "nu"}]}], ")"}], " ", 
        SuperscriptBox["r", "2"]}], "-", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
        SuperscriptBox["z", "2"]}]}], ")"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}], 
      RowBox[{"5", "/", "2"}]]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Strain", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Grad", "[", "u", "]"}], "+", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}], "/", "2"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(Strain\\)\\\" is similar to existing symbol \
\\\"\\!\\(UStrain\\)\\\".\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"B", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["r", "4"]}], "-", 
         RowBox[{"11", " ", 
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox["z", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["z", "4"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"7", "/", "2"}]]}]], ",", "0", ",", 
     FractionBox[
      RowBox[{"3", " ", "B", " ", "r", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          SuperscriptBox["r", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "nu"}], ")"}], " ", 
          SuperscriptBox["z", "2"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"7", "/", "2"}]]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"B", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["z", "2"]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "B", " ", "r", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          SuperscriptBox["r", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "nu"}], ")"}], " ", 
          SuperscriptBox["z", "2"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"7", "/", "2"}]]}]], ",", "0", ",", 
     FractionBox[
      RowBox[{"B", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"4", " ", "nu"}]}], ")"}], " ", 
          SuperscriptBox["r", "4"]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", "nu"}], ")"}], " ", 
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox["z", "2"]}], "+", 
         RowBox[{"8", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
          SuperscriptBox["z", "4"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"7", "/", "2"}]]}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"CIS", "=", 
   RowBox[{"IsotropicStiffness", "[", "nu", "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Stress", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"GTr", "[", 
    RowBox[{
     RowBox[{"GDot", "[", 
      RowBox[{"CIS", ",", "Strain", ",", "1", ",", "1"}], "]"}], ",", "1", 
     ",", "4"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"B", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}], " ", 
          SuperscriptBox["r", "4"]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"11", "+", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox["z", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          SuperscriptBox["z", "4"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"7", "/", "2"}]]}]], ",", "0", ",", 
     FractionBox[
      RowBox[{"3", " ", "B", " ", "r", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          SuperscriptBox["r", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "nu"}], ")"}], " ", 
          SuperscriptBox["z", "2"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"7", "/", "2"}]]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"B", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r", "2"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["z", "2"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "B", " ", "r", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          SuperscriptBox["r", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "nu"}], ")"}], " ", 
          SuperscriptBox["z", "2"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"7", "/", "2"}]]}]], ",", "0", ",", 
     FractionBox[
      RowBox[{"B", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          SuperscriptBox["r", "4"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"4", "+", "nu"}], ")"}], " ", 
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox["z", "2"]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "nu"}], ")"}], " ", 
          SuperscriptBox["z", "4"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"7", "/", "2"}]]}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Div", "[", "Stress", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StressSpherical", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Stress", "/.", 
       RowBox[{"r", "\[Rule]", 
        RowBox[{"R", " ", 
         RowBox[{"Sin", "[", "p", "]"}]}]}]}], "/.", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"R", " ", 
        RowBox[{"Cos", "[", "p", "]"}]}]}]}], "]"}], "/.", 
    RowBox[{
     SqrtBox[
      SuperscriptBox["R", "2"]], "\[Rule]", "R"}]}], "/.", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", 
      SqrtBox[
       SuperscriptBox["R", "2"]]}], ")"}], "\[Rule]", 
    RowBox[{"1", "/", "R"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"B", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"8", " ", "nu"}], "-", 
         RowBox[{"24", " ", "nu", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "p"}], "]"}]}], "+", 
         RowBox[{"15", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", "p"}], "]"}]}]}], ")"}]}], 
      RowBox[{"16", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["nu", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         SuperscriptBox["R", "2"], ")"}], 
        RowBox[{"3", "/", "2"}]]}]], ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "B", " ", 
        RowBox[{"(", 
         RowBox[{"3", "-", 
          RowBox[{"4", " ", "nu"}], "+", 
          RowBox[{"5", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "p"}], "]"}]}], 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["nu", "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["R", "2"], ")"}], 
         RowBox[{"3", "/", "2"}]]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"B", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"3", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["nu", "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["R", "2"], ")"}], 
         RowBox[{"3", "/", "2"}]]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "B", " ", 
        RowBox[{"(", 
         RowBox[{"3", "-", 
          RowBox[{"4", " ", "nu"}], "+", 
          RowBox[{"5", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "p"}], "]"}]}], 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["nu", "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["R", "2"], ")"}], 
         RowBox[{"3", "/", "2"}]]}]]}], ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"B", " ", 
        RowBox[{"(", 
         RowBox[{"13", "-", 
          RowBox[{"8", " ", "nu"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"36", "-", 
             RowBox[{"24", " ", "nu"}]}], ")"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "p"}], "]"}]}], "+", 
          RowBox[{"15", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"4", " ", "p"}], "]"}]}]}], ")"}]}], 
       RowBox[{"16", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["nu", "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["R", "2"], ")"}], 
         RowBox[{"3", "/", "2"}]]}]]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"R", ",", "p", ",", "t"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eR", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Spherical", "[", 
  RowBox[{"R", ",", "p", ",", "t"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Traction", "=", 
  RowBox[{"Dot", "[", 
   RowBox[{"StressSpherical", ",", "eR"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"B", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"8", " ", "nu"}], "-", 
        RowBox[{"24", " ", "nu", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "p"}], "]"}]}], "+", 
        RowBox[{"15", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"4", " ", "p"}], "]"}]}]}], ")"}]}], 
     RowBox[{"16", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["nu", "2"]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["R", "2"], ")"}], 
       RowBox[{"3", "/", "2"}]]}]]}], ",", "0", ",", 
   FractionBox[
    RowBox[{"3", " ", "B", " ", 
     RowBox[{"(", 
      RowBox[{"3", "-", 
       RowBox[{"4", " ", "nu"}], "+", 
       RowBox[{"5", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "p"}], "]"}]}], 
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["nu", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["R", "2"], ")"}], 
      RowBox[{"3", "/", "2"}]]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResForce", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"FieldToCartesian", "[", "Traction", "]"}], " ", 
      RowBox[{"R", "^", "2"}], " ", 
      RowBox[{"Sin", "[", "p", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "0", ",", "Pi"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"2", " ", "Pi"}]}], "}"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]]
},
WindowSize->{826, 574},
WindowMargins->{{18, Automatic}, {Automatic, 23}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 298, 7, 55, "Input"],
Cell[1632, 47, 52, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1721, 52, 90, 1, 32, "Input"],
Cell[1814, 55, 76, 0, 31, "Output"]
}, Open  ]],
Cell[1905, 58, 122, 2, 55, "Input"],
Cell[CellGroupData[{
Cell[2052, 64, 139, 3, 32, "Input"],
Cell[2194, 69, 98, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2329, 76, 440, 14, 77, "Input"],
Cell[2772, 92, 226, 8, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3035, 105, 101, 2, 32, "Input"],
Cell[3139, 109, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3259, 116, 327, 10, 32, "Input"],
Cell[3589, 128, 1291, 44, 60, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4917, 177, 279, 9, 30, "Input"],
Cell[5199, 188, 246, 6, 78, "Message"],
Cell[5448, 196, 3892, 124, 212, "Output"]
}, Open  ]],
Cell[9355, 323, 116, 3, 30, "Input"],
Cell[CellGroupData[{
Cell[9496, 330, 249, 7, 30, "Input"],
Cell[9748, 339, 4410, 140, 212, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14195, 484, 96, 2, 30, "Input"],
Cell[14294, 488, 83, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14414, 495, 631, 21, 77, "Input"],
Cell[15048, 518, 3601, 113, 197, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18686, 636, 288, 8, 50, "Input"],
Cell[18977, 646, 96, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19110, 653, 125, 3, 30, "Input"],
Cell[19238, 658, 1288, 42, 83, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20563, 705, 470, 13, 90, "Input"],
Cell[21036, 720, 83, 2, 29, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

