(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     19462,        697]
NotebookOptionsPosition[     17179,        613]
NotebookOutlinePosition[     17623,        631]
CellTagsIndexPosition[     17580,        628]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", Cell[TextData[{
   "This notebook forms part of the supporting material for the book\n\n",
   StyleBox[
   "Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. Korsunsky\n\
published by Cambridge University Press, 2007\n(ISBN-13: 9780521842013)\n",
    FontSlant->"Italic"],
   "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
  }], "Text",
   CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
    3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
    3.402068091731965*^9}}]}]], "Input",
 CellChangeTimes->{{3.4020714724449*^9, 3.402071473169425*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Solution", " ", "for", " ", "torsional", " ", "stresses", " ", "in", " ", 
    "a", " ", "conical", " ", "shaft"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"SetDirectory", "[", "myrootdir", "]"}]}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<elastica\\Packages\>\"", "]"}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\\\\elastica\\\\Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Displacement.m"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pos", "=", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CIS", "=", 
   RowBox[{"IsotropicStiffness", "[", "nu", "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"R", "=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"x", "^", "2"}], "+", 
     RowBox[{"y", "^", "2"}], "+", 
     RowBox[{"z", "^", "2"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"psi", "=", 
  RowBox[{"Curl", "[", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"A", "/", "R"}]}], "}"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"phi", "=", 
   RowBox[{"-", 
    RowBox[{"pos", ".", "psi"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Laplacian", "[", "psi", "]"}], "]"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Laplacian", "[", "phi", "]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"A", " ", "y"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]]}], ",", 
   FractionBox[
    RowBox[{"A", " ", "x"}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"psi", "-", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"4", 
        RowBox[{"(", 
         RowBox[{"1", "-", "nu"}], ")"}]}], ")"}]}], 
     RowBox[{"Grad", "[", 
      RowBox[{
       RowBox[{"Dot", "[", 
        RowBox[{"pos", ",", "psi"}], "]"}], "+", "phi"}], "]"}]}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"A", " ", "y"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]]}], ",", 
   FractionBox[
    RowBox[{"A", " ", "x"}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Strain", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Grad", "[", "u", "]"}], "+", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}], "/", "2"}], "]"}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StressCar", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"GTr", "[", 
    RowBox[{
     RowBox[{"GDot", "[", 
      RowBox[{"CIS", ",", "Strain", ",", "1", ",", "1"}], "]"}], ",", "1", 
     ",", "4"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "A", " ", "x", " ", "y"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}]], ",", 
     FractionBox[
      RowBox[{"3", " ", "A", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x", "2"]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}]], ",", 
     FractionBox[
      RowBox[{"3", " ", "A", " ", "y", " ", "z"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "A", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x", "2"]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "A", " ", "x", " ", "y"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "A", " ", "x", " ", "z"}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "A", " ", "y", " ", "z"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "A", " ", "x", " ", "z"}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]}]]}], ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Div", "[", "StressCar", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"a", ",", "p", ",", "t"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Spherical", "[", 
  RowBox[{"a", ",", "p", ",", "t"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sub", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], "->", 
    RowBox[{"CoordinatesToCartesian", "[", 
     RowBox[{"{", 
      RowBox[{"a", ",", "p", ",", "t"}], "}"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", 
    RowBox[{"a", " ", 
     RowBox[{"Cos", "[", "t", "]"}], " ", 
     RowBox[{"Sin", "[", "p", "]"}]}]}], ",", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{"a", " ", 
     RowBox[{"Sin", "[", "p", "]"}], " ", 
     RowBox[{"Sin", "[", "t", "]"}]}]}], ",", 
   RowBox[{"z", "\[Rule]", 
    RowBox[{"a", " ", 
     RowBox[{"Cos", "[", "p", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StressSph", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"FieldFromCartesian", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{"StressCar", "/.", "sub"}], "]"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "A", " ", 
        RowBox[{"Sin", "[", "p", "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["a", "2"], ")"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "A", " ", 
        RowBox[{"Sin", "[", "p", "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["a", "2"], ")"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]]}], ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Traction", "=", 
  RowBox[{"StressSph", ".", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"subcyl", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], "->", 
    RowBox[{"CoordinatesToCartesian", "[", 
     RowBox[{"{", 
      RowBox[{"r", ",", "t", ",", "z"}], "}"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", 
    RowBox[{"r", " ", 
     RowBox[{"Cos", "[", "t", "]"}]}]}], ",", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "t", "]"}]}]}], ",", 
   RowBox[{"z", "\[Rule]", "z"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StressCyl", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"FieldFromCartesian", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{"StressCar", "/.", "subcyl"}], "]"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "A", " ", 
        SuperscriptBox["r", "2"]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "A", " ", 
        SuperscriptBox["r", "2"]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]}]]}], ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "A", " ", "r", " ", "z"}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "A", " ", "r", " ", "z"}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]}]]}], ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TractionZ", "=", 
  RowBox[{"StressCyl", ".", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", "A", " ", "r", " ", "z"}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "nu"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r", "2"], "+", 
         SuperscriptBox["z", "2"]}], ")"}], 
       RowBox[{"5", "/", "2"}]]}]]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Torque", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"TractionZ", "[", 
        RowBox[{"[", "2", "]"}], "]"}], " ", "2", " ", "Pi", " ", 
       RowBox[{"r", "^", "2"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"r", ",", "0", ",", "a"}], "}"}]}], "]"}], "/.", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", 
       SqrtBox[
        SuperscriptBox["z", "2"]]}], ")"}], "\[Rule]", 
     RowBox[{"1", "/", "z"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "A", " ", "\[Pi]"}], 
    RowBox[{"1", "+", "nu"}]]}], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox["a", "2"], " ", "A", " ", "\[Pi]", " ", "z"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["z", "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], "+", 
  FractionBox[
   RowBox[{"2", " ", "A", " ", "\[Pi]", " ", 
    SuperscriptBox["z", "3"]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["z", "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]]}]], "Output"]
}, Open  ]]
},
WindowSize->{460, 574},
WindowMargins->{{Automatic, 97}, {Automatic, 12}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 879, 15, 445, "Input"],
Cell[CellGroupData[{
Cell[1472, 40, 277, 6, 77, "Input"],
Cell[1752, 48, 52, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1841, 53, 90, 1, 32, "Input"],
Cell[1934, 56, 76, 0, 31, "Output"]
}, Open  ]],
Cell[2025, 59, 122, 2, 55, "Input"],
Cell[CellGroupData[{
Cell[2172, 65, 388, 11, 77, "Input"],
Cell[2563, 78, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2696, 85, 632, 20, 121, "Input"],
Cell[3331, 107, 609, 21, 55, "Output"],
Cell[3943, 130, 83, 2, 31, "Output"],
Cell[4029, 134, 28, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4094, 139, 401, 14, 50, "Input"],
Cell[4498, 155, 609, 21, 45, "Output"]
}, Open  ]],
Cell[5122, 179, 303, 10, 30, "Input"],
Cell[CellGroupData[{
Cell[5450, 193, 252, 7, 50, "Input"],
Cell[5705, 202, 3721, 117, 241, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9463, 324, 99, 2, 30, "Input"],
Cell[9565, 328, 83, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9685, 335, 137, 3, 30, "Input"],
Cell[9825, 340, 96, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9958, 347, 284, 8, 70, "Input"],
Cell[10245, 357, 433, 13, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10715, 375, 212, 5, 70, "Input"],
Cell[10930, 382, 943, 31, 83, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11910, 418, 146, 4, 30, "Input"],
Cell[12059, 424, 83, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12179, 431, 139, 3, 30, "Input"],
Cell[12321, 436, 98, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12456, 443, 287, 8, 50, "Input"],
Cell[12746, 453, 289, 9, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13072, 467, 215, 5, 70, "Input"],
Cell[13290, 474, 1816, 58, 127, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15143, 537, 147, 4, 30, "Input"],
Cell[15293, 543, 438, 14, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15768, 562, 549, 17, 98, "Input"],
Cell[16320, 581, 843, 29, 48, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

