(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     17730,        619]
NotebookOptionsPosition[     15931,        552]
NotebookOutlinePosition[     16375,        570]
CellTagsIndexPosition[     16332,        567]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Solution", " ", "for", " ", "torsional", " ", "stresses", " ", "in", " ", 
    "a", " ", "conical", " ", "shaft"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"SetDirectory", "[", "myrootdir", "]"}]}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<elastica\\Packages\>\"", "]"}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\\\\elastica\\\\Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Displacement.m"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pos", "=", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CIS", "=", 
   RowBox[{"IsotropicStiffness", "[", "nu", "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"R", "=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"x", "^", "2"}], "+", 
     RowBox[{"y", "^", "2"}], "+", 
     RowBox[{"z", "^", "2"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"psi", "=", 
  RowBox[{"Curl", "[", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"B", " ", "z", " ", 
       RowBox[{"R", "^", "2"}]}], "+", 
      RowBox[{"A", " ", 
       RowBox[{"z", "/", 
        RowBox[{"R", "^", "3"}]}]}]}]}], "}"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"phi", "=", 
   RowBox[{"-", 
    RowBox[{"pos", ".", "psi"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Laplacian", "[", "psi", "]"}], "]"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Laplacian", "[", "phi", "]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", "B", " ", "y", " ", "z"}], "-", 
    FractionBox[
     RowBox[{"3", " ", "A", " ", "y", " ", "z"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}], 
      RowBox[{"5", "/", "2"}]]]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "B", " ", "x", " ", "z"}], "+", 
    FractionBox[
     RowBox[{"3", " ", "A", " ", "x", " ", "z"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}], ")"}], 
      RowBox[{"5", "/", "2"}]]]}], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"psi", "-", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"4", 
        RowBox[{"(", 
         RowBox[{"1", "-", "nu"}], ")"}]}], ")"}]}], 
     RowBox[{"Grad", "[", 
      RowBox[{
       RowBox[{"Dot", "[", 
        RowBox[{"pos", ",", "psi"}], "]"}], "+", "phi"}], "]"}]}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"y", " ", "z", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "B"}], "-", 
      FractionBox[
       RowBox[{"3", " ", "A"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]]}], ")"}]}], ",", 
   RowBox[{"x", " ", "z", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "B"}], "+", 
      FractionBox[
       RowBox[{"3", " ", "A"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]]}], ")"}]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Strain", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Grad", "[", "u", "]"}], "+", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}], "/", "2"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(Strain\\)\\\" is similar to existing symbol \
\\\"\\!\\(UStrain\\)\\\".\"\>"}]], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StressCar", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"GTr", "[", 
    RowBox[{
     RowBox[{"GDot", "[", 
      RowBox[{"CIS", ",", "Strain", ",", "1", ",", "1"}], "]"}], ",", "1", 
     ",", "4"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"15", " ", "A", " ", "x", " ", "y", " ", "z"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"7", "/", "2"}]]}]], ",", 
     FractionBox[
      RowBox[{"15", " ", "A", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x", "2"]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], " ", "z"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"7", "/", "2"}]]}]], ",", 
     FractionBox[
      RowBox[{"y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "B"}], "-", 
         FractionBox[
          RowBox[{"3", " ", "A", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["z", "2"]}]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"], "+", 
             SuperscriptBox["z", "2"]}], ")"}], 
           RowBox[{"7", "/", "2"}]]]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"15", " ", "A", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x", "2"]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}], " ", "z"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"7", "/", "2"}]]}]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"15", " ", "A", " ", "x", " ", "y", " ", "z"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], 
         RowBox[{"7", "/", "2"}]]}]]}], ",", 
     FractionBox[
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "B"}], "+", 
         FractionBox[
          RowBox[{"3", " ", "A", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["z", "2"]}]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"], "+", 
             SuperscriptBox["z", "2"]}], ")"}], 
           RowBox[{"7", "/", "2"}]]]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "B"}], "-", 
         FractionBox[
          RowBox[{"3", " ", "A", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["z", "2"]}]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"], "+", 
             SuperscriptBox["z", "2"]}], ")"}], 
           RowBox[{"7", "/", "2"}]]]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}]}]], ",", 
     FractionBox[
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "B"}], "+", 
         FractionBox[
          RowBox[{"3", " ", "A", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["z", "2"]}]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"], "+", 
             SuperscriptBox["z", "2"]}], ")"}], 
           RowBox[{"7", "/", "2"}]]]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}]}]], ",", "0"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Div", "[", "StressCar", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"a", ",", "p", ",", "t"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Spherical", "[", 
  RowBox[{"a", ",", "p", ",", "t"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sub", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], "->", 
    RowBox[{"CoordinatesToCartesian", "[", 
     RowBox[{"{", 
      RowBox[{"a", ",", "p", ",", "t"}], "}"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", 
    RowBox[{"a", " ", 
     RowBox[{"Cos", "[", "t", "]"}], " ", 
     RowBox[{"Sin", "[", "p", "]"}]}]}], ",", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{"a", " ", 
     RowBox[{"Sin", "[", "p", "]"}], " ", 
     RowBox[{"Sin", "[", "t", "]"}]}]}], ",", 
   RowBox[{"z", "\[Rule]", 
    RowBox[{"a", " ", 
     RowBox[{"Cos", "[", "p", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StressSph", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"FieldFromCartesian", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{"StressCar", "/.", "sub"}], "]"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           SqrtBox[
            SuperscriptBox["a", "2"]], " ", "A"}], "+", 
          RowBox[{
           SuperscriptBox["a", "6"], " ", "B"}]}], ")"}], " ", 
        RowBox[{"Cos", "[", "p", "]"}], " ", 
        RowBox[{"Sin", "[", "p", "]"}]}], 
       RowBox[{
        SuperscriptBox["a", "5"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          SqrtBox[
           SuperscriptBox["a", "2"]], " ", "A"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "6"], " ", "B"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "p", "]"}], "2"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "5"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           SqrtBox[
            SuperscriptBox["a", "2"]], " ", "A"}], "+", 
          RowBox[{
           SuperscriptBox["a", "6"], " ", "B"}]}], ")"}], " ", 
        RowBox[{"Cos", "[", "p", "]"}], " ", 
        RowBox[{"Sin", "[", "p", "]"}]}], 
       RowBox[{
        SuperscriptBox["a", "5"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]]}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          SqrtBox[
           SuperscriptBox["a", "2"]], " ", "A"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "6"], " ", "B"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "p", "]"}], "2"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "5"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}]}]], ",", "0"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"StressSph", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "3"}], "]"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{"{", "B", "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"B", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"6", " ", 
       SqrtBox[
        SuperscriptBox["a", "2"]], " ", "A"}], 
      SuperscriptBox["a", "6"]]}]}], "}"}], "}"}]], "Output"]
}, Open  ]]
},
WindowSize->{460, 574},
WindowMargins->{{Automatic, 170}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 351, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 277, 6, 77, "Input"],
Cell[1611, 46, 52, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1700, 51, 90, 1, 32, "Input"],
Cell[1793, 54, 76, 0, 31, "Output"]
}, Open  ]],
Cell[1884, 57, 122, 2, 55, "Input"],
Cell[CellGroupData[{
Cell[2031, 63, 388, 11, 77, "Input"],
Cell[2422, 76, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2555, 83, 781, 25, 121, "Input"],
Cell[3339, 110, 798, 25, 101, "Output"],
Cell[4140, 137, 83, 2, 31, "Output"],
Cell[4226, 141, 28, 0, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4291, 146, 401, 14, 70, "Input"],
Cell[4695, 162, 882, 29, 84, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5614, 196, 303, 10, 30, "Input"],
Cell[5920, 208, 246, 6, 78, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6203, 219, 252, 7, 50, "Input"],
Cell[6458, 228, 5202, 162, 222, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11697, 395, 99, 2, 30, "Input"],
Cell[11799, 399, 83, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11919, 406, 137, 3, 30, "Input"],
Cell[12059, 411, 96, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12192, 418, 284, 8, 70, "Input"],
Cell[12479, 428, 433, 13, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12949, 446, 212, 5, 70, "Input"],
Cell[13164, 453, 2225, 73, 189, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15426, 531, 227, 7, 30, "Input"],
Cell[15656, 540, 259, 9, 47, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

