(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      9353,        359]
NotebookOptionsPosition[      7573,        292]
NotebookOutlinePosition[      8017,        310]
CellTagsIndexPosition[      7974,        307]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Solution", " ", "for", " ", "torsional", " ", "stresses", " ", "in", " ", 
    "a", " ", "conical", " ", "shaft"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"SetDirectory", "[", "myrootdir", "]"}]}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<elastica\\Packages\>\"", "]"}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\\\\elastica\\\\Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Displacement.m"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pos", "=", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0", ",", "z"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CIS", "=", 
   RowBox[{"IsotropicStiffness", "[", "nu", "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"R", "=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"r", "^", "2"}], "+", 
     RowBox[{"z", "^", "2"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"psi", "=", 
  RowBox[{"Curl", "[", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"B", " ", "z", " ", 
      RowBox[{"R", "^", "2"}]}]}], "}"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"phi", "=", 
   RowBox[{"-", 
    RowBox[{"pos", ".", "psi"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Laplacian", "[", "psi", "]"}], "]"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Laplacian", "[", "phi", "]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", "B", " ", "r", " ", "z"}], ",", "0"}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"psi", "-", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"4", 
        RowBox[{"(", 
         RowBox[{"1", "-", "nu"}], ")"}]}], ")"}]}], 
     RowBox[{"Grad", "[", 
      RowBox[{
       RowBox[{"Dot", "[", 
        RowBox[{"pos", ",", "psi"}], "]"}], "+", "phi"}], "]"}]}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", "B", " ", "r", " ", "z"}], ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Strain", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Grad", "[", "u", "]"}], "+", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}], "/", "2"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(Strain\\)\\\" is similar to existing symbol \
\\\"\\!\\(UStrain\\)\\\".\"\>"}]], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StressCyl", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"GTr", "[", 
    RowBox[{
     RowBox[{"GDot", "[", 
      RowBox[{"CIS", ",", "Strain", ",", "1", ",", "1"}], "]"}], ",", "1", 
     ",", "4"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"B", " ", "r"}], 
       RowBox[{"1", "+", "nu"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"B", " ", "r"}], 
       RowBox[{"1", "+", "nu"}]]}], ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Div", "[", "StressCyl", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TractionZ", "=", 
  RowBox[{"StressCyl", ".", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"B", " ", "r"}], 
     RowBox[{"1", "+", "nu"}]]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Bsol", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"TractionZ", "[", 
          RowBox[{"[", "2", "]"}], "]"}], " ", "2", " ", "Pi", " ", 
         RowBox[{"r", "^", "2"}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"r", ",", "0", ",", "b"}], "}"}]}], "]"}], "\[Equal]", "T"}],
      ",", 
     RowBox[{"{", "B", "}"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"B", "\[Rule]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}], " ", "T"}], 
    RowBox[{
     SuperscriptBox["b", "4"], " ", "\[Pi]"}]]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"usol", "=", 
  RowBox[{"u", "/.", "Bsol"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox[
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}], " ", "r", " ", "T", " ", "z"}], 
    RowBox[{
     SuperscriptBox["b", "4"], " ", "\[Pi]"}]], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"T", " ", "r", " ", 
  RowBox[{"z", "/", 
   RowBox[{"usol", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["b", "4"], " ", "\[Pi]"}], 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "nu"}], ")"}]}]]], "Output"]
}, Open  ]]
},
WindowSize->{460, 574},
WindowMargins->{{Automatic, 170}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 351, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 277, 6, 77, "Input"],
Cell[1611, 46, 52, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1700, 51, 90, 1, 32, "Input"],
Cell[1793, 54, 76, 0, 31, "Output"]
}, Open  ]],
Cell[1884, 57, 122, 2, 55, "Input"],
Cell[CellGroupData[{
Cell[2031, 63, 390, 11, 77, "Input"],
Cell[2424, 76, 98, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2559, 83, 633, 20, 121, "Input"],
Cell[3195, 105, 150, 5, 31, "Output"],
Cell[3348, 112, 83, 2, 31, "Output"],
Cell[3434, 116, 28, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3499, 121, 401, 14, 77, "Input"],
Cell[3903, 137, 150, 5, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4090, 147, 303, 10, 30, "Input"],
Cell[4396, 159, 246, 6, 78, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4679, 170, 252, 7, 50, "Input"],
Cell[4934, 179, 466, 16, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5437, 200, 99, 2, 30, "Input"],
Cell[5539, 204, 83, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5659, 211, 147, 4, 30, "Input"],
Cell[5809, 217, 178, 6, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6024, 228, 548, 17, 70, "Input"],
Cell[6575, 247, 241, 8, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6853, 260, 79, 2, 30, "Input"],
Cell[6935, 264, 270, 8, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7242, 277, 139, 4, 30, "Input"],
Cell[7384, 283, 173, 6, 47, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

