(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     34887,       1181]
NotebookOptionsPosition[     32195,       1085]
NotebookOutlinePosition[     32640,       1103]
CellTagsIndexPosition[     32597,       1100]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Solution", " ", "for", " ", "stresses", " ", "around", " ", "a", " ", 
     "spherical", " ", "cavity", " ", "by", " ", "Papkovich"}], "-", 
    "Neuber"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"SetDirectory", "[", "myrootdir", "]"}]}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<elastica\\Packages\>\"", "]"}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\\\\elastica\\\\Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Displacement.m"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pos", "=", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CIS", "=", 
   RowBox[{"IsotropicStiffness", "[", "nu", "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"R", "=", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"x", "^", "2"}], "+", 
       RowBox[{"y", "^", "2"}], "+", 
       RowBox[{"z", "^", "2"}]}], "]"}]}], ";"}], "\[IndentingNewLine]"}], 
  RowBox[{"(*", " ", 
   RowBox[{"Uniaxial", " ", "stress"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"psi1", "=", 
   RowBox[{"2", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "nu"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "nu"}]}], ")"}]}], 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "S"}], " ", "nu", " ", "x"}], ",", " ", 
      RowBox[{
       RowBox[{"-", "S"}], " ", "nu", " ", "y"}], ",", " ", 
      RowBox[{"S", " ", "z"}]}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"phi2", "=", "0"}], ";"}], " ", "\[IndentingNewLine]"}], 
  RowBox[{"(*", " ", 
   RowBox[{"Centre", " ", "of", " ", "dilatation"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"psi2", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"phi2", "=", 
     RowBox[{"A", "/", "R"}]}], ";"}], " ", "\[IndentingNewLine]"}], 
  RowBox[{"(*", " ", 
   RowBox[{"Force", " ", "dipole", " ", "zz"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"psi3", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"B", "/", "R"}], ",", "z"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"phi3", "=", "0"}], ";"}], "\[IndentingNewLine]"}], 
  RowBox[{"(*", " ", 
   RowBox[{"Galerkin", " ", "extra"}], " ", "*)"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"C", " ", 
      RowBox[{"z", "/", 
       RowBox[{"R", "^", "3"}]}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"psi4", "=", 
   RowBox[{"Laplacian", "[", "g", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"phi4", "=", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"Div", "[", "g", "]"}]}], "-", 
    RowBox[{"pos", ".", 
     RowBox[{"Laplacian", "[", "g", "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"psi", "=", 
   RowBox[{"psi1", "+", "psi2", "+", "psi3", "+", "psi4"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"phi", "=", 
   RowBox[{"phi1", "+", "phi2", "+", "phi3", "+", "phi4"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Laplacian", "[", "psi", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Laplacian", "[", "phi", "]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(psi2\\)\
\\\" is similar to existing symbol \\\"\\!\\(phi2\\)\\\".\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(phi3\\)\
\\\" is similar to existing symbol \\\"\\!\\(psi3\\)\\\".\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(phi4\\)\
\\\" is similar to existing symbol \\\"\\!\\(psi4\\)\\\".\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(phi1\\)\
\\\" is similar to existing symbol \\\"\\!\\(psi1\\)\\\".\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"psi", "-", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"4", 
        RowBox[{"(", 
         RowBox[{"1", "-", "nu"}], ")"}]}], ")"}]}], 
     RowBox[{"Grad", "[", 
      RowBox[{
       RowBox[{"Dot", "[", 
        RowBox[{"pos", ",", "psi"}], "]"}], "+", "phi"}], "]"}]}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", "C", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["z", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"], "+", 
            SuperscriptBox["z", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", "B", " ", 
             SuperscriptBox["z", "2"]}], "+", 
            RowBox[{"A", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"], "+", 
               SuperscriptBox["z", "2"]}], ")"}]}], "+", 
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", "nu", " ", "S", 
             " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["y", "2"], "+", 
                SuperscriptBox["z", "2"]}], ")"}], 
              RowBox[{"5", "/", "2"}]]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"7", "/", "2"}]]}], ")"}]}]}], ",", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", "C", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["z", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"], "+", 
            SuperscriptBox["z", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", "B", " ", 
             SuperscriptBox["z", "2"]}], "+", 
            RowBox[{"A", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"], "+", 
               SuperscriptBox["z", "2"]}], ")"}]}], "+", 
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", "nu", " ", "S", 
             " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["y", "2"], "+", 
                SuperscriptBox["z", "2"]}], ")"}], 
              RowBox[{"5", "/", "2"}]]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], ")"}], 
        RowBox[{"7", "/", "2"}]]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"z", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "6"}], " ", "C", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["x", "2"]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["y", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["z", "2"]}]}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"], "+", 
           SuperscriptBox["z", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["y", "2"], "+", 
              SuperscriptBox["z", "2"]}], ")"}]}], "-", 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", "S", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x", "2"], "+", 
               SuperscriptBox["y", "2"], "+", 
               SuperscriptBox["z", "2"]}], ")"}], 
             RowBox[{"5", "/", "2"}]]}], "+", 
           RowBox[{"B", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 RowBox[{"4", " ", "nu"}]}], ")"}], " ", 
               SuperscriptBox["x", "2"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 RowBox[{"4", " ", "nu"}]}], ")"}], " ", 
               SuperscriptBox["y", "2"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", 
                 RowBox[{"4", " ", "nu"}]}], ")"}], " ", 
               SuperscriptBox["z", "2"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"], "+", 
         SuperscriptBox["z", "2"]}], ")"}], 
       RowBox[{"7", "/", "2"}]]}], ")"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Strain", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Grad", "[", "u", "]"}], "+", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}], "/", "2"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(Strain\\)\\\" is similar to existing symbol \
\\\"\\!\\(UStrain\\)\\\".\"\>"}]], "Message"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"StressCar", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"GTr", "[", 
     RowBox[{
      RowBox[{"GDot", "[", 
       RowBox[{"CIS", ",", "Strain", ",", "1", ",", "1"}], "]"}], ",", "1", 
      ",", "4"}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Div", "[", "StressCar", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"r", ",", "p", ",", "t"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Spherical", "[", 
  RowBox[{"r", ",", "p", ",", "t"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sub", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], "->", 
    RowBox[{"CoordinatesToCartesian", "[", 
     RowBox[{"{", 
      RowBox[{"r", ",", "p", ",", "t"}], "}"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", 
    RowBox[{"r", " ", 
     RowBox[{"Cos", "[", "t", "]"}], " ", 
     RowBox[{"Sin", "[", "p", "]"}]}]}], ",", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "p", "]"}], " ", 
     RowBox[{"Sin", "[", "t", "]"}]}]}], ",", 
   RowBox[{"z", "\[Rule]", 
    RowBox[{"r", " ", 
     RowBox[{"Cos", "[", "p", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StressSph", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"FieldFromCartesian", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{"StressCar", "/.", "sub"}], "]"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "12"}], " ", "C"}], "+", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "A"}], "+", 
           RowBox[{"B", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "5"}], "+", 
              RowBox[{"3", " ", "nu"}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["nu", "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              SuperscriptBox["r", "2"], ")"}], 
             RowBox[{"3", "/", "2"}]], " ", "S"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "36"}], " ", "C"}], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "nu"}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["nu", "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 SuperscriptBox["r", "2"], ")"}], 
                RowBox[{"3", "/", "2"}]], " ", "S"}]}], ")"}]}]}], ")"}], " ",
          
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["nu", "2"]}], ")"}], " ", 
        SuperscriptBox["r", "4"], " ", 
        SqrtBox[
         SuperscriptBox["r", "2"]]}], ")"}]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"24", " ", "C"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "nu"}], ")"}], " ", 
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"B", "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                SuperscriptBox["r", "2"], ")"}], 
               RowBox[{"3", "/", "2"}]], " ", "S"}]}], ")"}]}]}], ")"}], " ", 
        
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "p"}], "]"}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["nu", "2"]}], ")"}], " ", 
        SuperscriptBox["r", "4"], " ", 
        SqrtBox[
         SuperscriptBox["r", "2"]]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"24", " ", "C"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "nu"}], ")"}], " ", 
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"B", "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                SuperscriptBox["r", "2"], ")"}], 
               RowBox[{"3", "/", "2"}]], " ", "S"}]}], ")"}]}]}], ")"}], " ", 
        
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "p"}], "]"}]}], 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["nu", "2"]}], ")"}], " ", 
        SuperscriptBox["r", "4"], " ", 
        SqrtBox[
         SuperscriptBox["r", "2"]]}]]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", "C"}], "+", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "A"}], "+", 
           RowBox[{"B", " ", 
            RowBox[{"(", 
             RowBox[{"5", "-", 
              RowBox[{"6", " ", "nu"}]}], ")"}]}], "+", 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["nu", "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              SuperscriptBox["r", "2"], ")"}], 
             RowBox[{"3", "/", "2"}]], " ", "S"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"42", " ", "C"}], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"B", "-", 
              RowBox[{"2", " ", "B", " ", "nu"}], "+", 
              RowBox[{"4", " ", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 SuperscriptBox["nu", "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 SuperscriptBox["r", "2"], ")"}], 
                RowBox[{"3", "/", "2"}]], " ", "S"}]}], ")"}]}]}], ")"}], " ",
          
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["nu", "2"]}], ")"}], " ", 
        SuperscriptBox["r", "4"], " ", 
        SqrtBox[
         SuperscriptBox["r", "2"]]}], ")"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"18", " ", "C"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "A"}], "+", 
           RowBox[{"3", " ", "B"}], "-", 
           RowBox[{"2", " ", "B", " ", "nu"}]}], ")"}], " ", 
         SuperscriptBox["r", "2"]}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"10", " ", "C"}], "+", 
           RowBox[{"B", " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
            SuperscriptBox["r", "2"]}]}], ")"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["nu", "2"]}], ")"}], " ", 
        SuperscriptBox["r", "4"], " ", 
        SqrtBox[
         SuperscriptBox["r", "2"]]}], ")"}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"normal", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(normal\\)\\\" is similar to existing symbol \
\\\"\\!\\(Normal\\)\\\".\"\>"}]], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Traction", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"StressSph", ".", "normal"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", "C"}], "+", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "A"}], "+", 
         RowBox[{"B", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "+", 
            RowBox[{"3", " ", "nu"}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["nu", "2"]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox["r", "2"], ")"}], 
           RowBox[{"3", "/", "2"}]], " ", "S"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "36"}], " ", "C"}], "+", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"B", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "+", "nu"}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["nu", "2"]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               SuperscriptBox["r", "2"], ")"}], 
              RowBox[{"3", "/", "2"}]], " ", "S"}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["nu", "2"]}], ")"}], " ", 
      SuperscriptBox["r", "4"], " ", 
      SqrtBox[
       SuperscriptBox["r", "2"]]}], ")"}]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"24", " ", "C"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"B", "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              SuperscriptBox["r", "2"], ")"}], 
             RowBox[{"3", "/", "2"}]], " ", "S"}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", "p"}], "]"}]}], 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["nu", "2"]}], ")"}], " ", 
      SuperscriptBox["r", "4"], " ", 
      SqrtBox[
       SuperscriptBox["r", "2"]]}]]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Csol", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Traction", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", "C", "}"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"C", "\[Rule]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "24"]}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "nu"}], ")"}], " ", 
   SuperscriptBox["r", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"B", "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["r", "2"], ")"}], 
       RowBox[{"3", "/", "2"}]], " ", "S"}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tr", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Traction", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/.", "Csol"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"4", " ", "A"}], "-", 
    RowBox[{"9", " ", "B"}], "+", 
    RowBox[{"7", " ", "B", " ", "nu"}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["r", "2"], ")"}], 
      RowBox[{"3", "/", "2"}]], " ", "S"}], "+", 
    RowBox[{"6", " ", 
     SuperscriptBox["nu", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["r", "2"], ")"}], 
      RowBox[{"3", "/", "2"}]], " ", "S"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "7"}], "+", 
          RowBox[{"5", " ", "nu"}]}], ")"}]}], "+", 
       RowBox[{"10", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["nu", "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["r", "2"], ")"}], 
         RowBox[{"3", "/", "2"}]], " ", "S"}]}], ")"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"8", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["nu", "2"]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["r", "2"], ")"}], 
     RowBox[{"3", "/", "2"}]]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Bsol", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"B", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "7"}], "+", 
          RowBox[{"5", " ", "nu"}]}], ")"}]}], "+", 
       RowBox[{"10", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["nu", "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["r", "2"], ")"}], 
         RowBox[{"3", "/", "2"}]], " ", "S"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", "B", "}"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(Bsol\\)\
\\\" is similar to existing symbol \\\"\\!\\(Csol\\)\\\".\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"B", "\[Rule]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"10", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["nu", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["r", "2"], ")"}], 
      RowBox[{"3", "/", "2"}]], " ", "S"}], 
    RowBox[{
     RowBox[{"-", "7"}], "+", 
     RowBox[{"5", " ", "nu"}]}]]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"trb", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"tr", "/.", "Bsol"}], "]"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"A", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "7"}], "+", 
      RowBox[{"5", " ", "nu"}]}], ")"}]}], "-", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"6", "-", 
      RowBox[{"5", " ", "nu"}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["nu", "2"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["nu", "3"]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["r", "2"], ")"}], 
     RowBox[{"3", "/", "2"}]], " ", "S"}]}], 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "7"}], "+", 
     RowBox[{"5", " ", "nu"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["nu", "2"]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["r", "2"], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"trb", "\[Equal]", "0"}], ",", 
    RowBox[{"{", "A", "}"}]}], "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "1"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"A", "\[Rule]", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"6", "-", 
      RowBox[{"5", " ", "nu"}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["nu", "2"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["nu", "3"]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["r", "2"], ")"}], 
     RowBox[{"3", "/", "2"}]], " ", "S"}], 
   RowBox[{
    RowBox[{"-", "7"}], "+", 
    RowBox[{"5", " ", "nu"}]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Csol", "/.", "Bsol"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"C", "\[Rule]", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["r", "2"], ")"}], 
     RowBox[{"5", "/", "2"}]], " ", "S"}], 
   RowBox[{
    RowBox[{"-", "7"}], "+", 
    RowBox[{"5", " ", "nu"}]}]]}]], "Output"]
}, Open  ]]
},
WindowSize->{730, 574},
WindowMargins->{{193, Automatic}, {Automatic, 22}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 332, 8, 55, "Input"],
Cell[1666, 48, 52, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1755, 53, 90, 1, 32, "Input"],
Cell[1848, 56, 76, 0, 31, "Output"]
}, Open  ]],
Cell[1939, 59, 122, 2, 55, "Input"],
Cell[CellGroupData[{
Cell[2086, 65, 388, 11, 77, "Input"],
Cell[2477, 78, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2610, 85, 2847, 93, 407, "Input"],
Cell[5460, 180, 239, 5, 60, "Message"],
Cell[5702, 187, 239, 5, 60, "Message"],
Cell[5944, 194, 239, 5, 60, "Message"],
Cell[6186, 201, 239, 5, 60, "Message"],
Cell[6428, 208, 83, 2, 29, "Output"],
Cell[6514, 212, 28, 0, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6579, 217, 401, 14, 50, "Input"],
Cell[6983, 233, 6212, 184, 265, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13232, 422, 303, 10, 30, "Input"],
Cell[13538, 434, 246, 6, 78, "Message"]
}, Open  ]],
Cell[13799, 443, 276, 8, 50, "Input"],
Cell[CellGroupData[{
Cell[14100, 455, 99, 2, 30, "Input"],
Cell[14202, 459, 83, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14322, 466, 137, 3, 30, "Input"],
Cell[14462, 471, 96, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14595, 478, 284, 8, 70, "Input"],
Cell[14882, 488, 433, 13, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15352, 506, 212, 5, 70, "Input"],
Cell[15567, 513, 6962, 212, 382, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22566, 730, 131, 4, 30, "Input"],
Cell[22700, 736, 245, 6, 78, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22982, 747, 128, 3, 30, "Input"],
Cell[23113, 752, 2809, 89, 164, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25959, 846, 313, 10, 30, "Input"],
Cell[26275, 858, 506, 17, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26818, 880, 176, 5, 30, "Input"],
Cell[26997, 887, 1388, 46, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28422, 938, 707, 23, 73, "Input"],
Cell[29132, 963, 239, 5, 60, "Message"],
Cell[29374, 970, 431, 15, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29842, 990, 115, 3, 30, "Input"],
Cell[29960, 995, 899, 32, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30896, 1032, 216, 7, 30, "Input"],
Cell[31115, 1041, 510, 17, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31662, 1063, 91, 2, 30, "Input"],
Cell[31756, 1067, 423, 15, 46, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

