(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     10142,        377]
NotebookOptionsPosition[      8544,        317]
NotebookOutlinePosition[      8987,        335]
CellTagsIndexPosition[      8944,        332]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Solution", " ", "for", " ", "stresses", " ", "around", " ", "a", " ", 
     "spherical", " ", "cavity", " ", "by", " ", "Papkovich"}], "-", 
    "Neuber"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"SetDirectory", "[", "myrootdir", "]"}]}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<elastica\\Packages\>\"", "]"}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\\\\elastica\\\\Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Displacement.m"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pos", "=", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0", ",", "z"}], "}"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"R", "=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"r", "^", "2"}], "+", 
     RowBox[{"z", "^", "2"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"psi", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", " ", "r"}], ",", " ", "0", ",", " ", 
     RowBox[{"B", " ", "z"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"phi", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Laplacian", "[", "psi", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Laplacian", "[", "phi", "]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"psi", "-", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"4", 
        RowBox[{"(", 
         RowBox[{"1", "-", "nu"}], ")"}]}], ")"}]}], 
     RowBox[{"Grad", "[", 
      RowBox[{
       RowBox[{"Dot", "[", 
        RowBox[{"pos", ",", "psi"}], "]"}], "+", "phi"}], "]"}]}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"A", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "nu"}]}], ")"}], " ", "r"}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "nu"}], ")"}]}]], ",", "0", ",", 
   FractionBox[
    RowBox[{"B", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "nu"}]}], ")"}], " ", "z"}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "nu"}], ")"}]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Strain", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Grad", "[", "u", "]"}], "+", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}], "/", "2"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"A", "-", 
       RowBox[{"2", " ", "A", " ", "nu"}]}], 
      RowBox[{"2", "-", 
       RowBox[{"2", " ", "nu"}]}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"A", "-", 
       RowBox[{"2", " ", "A", " ", "nu"}]}], 
      RowBox[{"2", "-", 
       RowBox[{"2", " ", "nu"}]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"B", "-", 
       RowBox[{"2", " ", "B", " ", "nu"}]}], 
      RowBox[{"2", "-", 
       RowBox[{"2", " ", "nu"}]}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"CIS", "=", 
   RowBox[{"IsotropicStiffness", "[", "nu", "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Stress", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"GTr", "[", 
    RowBox[{
     RowBox[{"GDot", "[", 
      RowBox[{"CIS", ",", "Strain", ",", "1", ",", "1"}], "]"}], ",", "1", 
     ",", "4"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"A", "+", 
       RowBox[{"B", " ", "nu"}]}], 
      RowBox[{"2", "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["nu", "2"]}]}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"A", "+", 
       RowBox[{"B", " ", "nu"}]}], 
      RowBox[{"2", "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["nu", "2"]}]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"B", "+", 
       RowBox[{"2", " ", "A", " ", "nu"}], "-", 
       RowBox[{"B", " ", "nu"}]}], 
      RowBox[{"2", "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["nu", "2"]}]}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Div", "[", "Stress", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Bsol", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Stress", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[Equal]", "0"}], ",", "B"}], 
    "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"StressUni", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Stress", "/.", "Bsol"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"B", "\[Rule]", 
  RowBox[{"-", 
   FractionBox["A", "nu"]}]}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"A", "-", 
       RowBox[{"2", " ", "A", " ", "nu"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "nu"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["nu", "2"]}]}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"StressUni", "/.", 
   RowBox[{"A", "\[Rule]", 
    RowBox[{"S", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "nu", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "nu"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "nu"}]}], ")"}]}]}], ")"}]}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "S"}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
},
WindowSize->{460, 574},
WindowMargins->{{Automatic, 1}, {Automatic, 29}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 351, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 332, 8, 99, "Input"],
Cell[1666, 48, 52, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1755, 53, 90, 1, 32, "Input"],
Cell[1848, 56, 76, 0, 31, "Output"]
}, Open  ]],
Cell[1939, 59, 122, 2, 55, "Input"],
Cell[CellGroupData[{
Cell[2086, 65, 270, 7, 55, "Input"],
Cell[2359, 74, 98, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2494, 81, 639, 18, 121, "Input"],
Cell[3136, 101, 83, 2, 31, "Output"],
Cell[3222, 105, 28, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3287, 110, 401, 14, 77, "Input"],
Cell[3691, 126, 611, 22, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4339, 153, 279, 9, 30, "Input"],
Cell[4621, 164, 698, 23, 76, "Output"]
}, Open  ]],
Cell[5334, 190, 116, 3, 30, "Input"],
Cell[CellGroupData[{
Cell[5475, 197, 249, 7, 30, "Input"],
Cell[5727, 206, 807, 27, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6571, 238, 96, 2, 30, "Input"],
Cell[6670, 242, 83, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6790, 249, 447, 14, 50, "Input"],
Cell[7240, 265, 97, 3, 42, "Output"],
Cell[7340, 270, 489, 16, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7866, 291, 399, 13, 30, "Input"],
Cell[8268, 306, 260, 8, 29, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

