(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     53281,       1820]
NotebookOptionsPosition[     49309,       1684]
NotebookOutlinePosition[     49753,       1702]
CellTagsIndexPosition[     49710,       1699]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["Bending of a plate ", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "Displacement.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "IntegrateStrain.m"}], "\[IndentingNewLine]"}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", ",", "y", ",", "z"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Plane elasticity field",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"u", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ux", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", " ", 
    RowBox[{"uy", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", " ", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Stress", " ", "[", 
    RowBox[{"Strain", "[", " ", 
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], "]"}], " ", ")"}], " ",
   "//", "  ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Div", "[", " ", 
    RowBox[{"Stress", " ", "[", 
     RowBox[{"Strain", "[", " ", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], "]"}], " ", "]"}], 
   " ", ")"}], " ", "//", "  ", 
  "MatrixForm"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox[
        RowBox[{"nu", " ", 
         RowBox[{
          SuperscriptBox["uy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}]}]], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"1", "+", "nu"}]], "+", 
          FractionBox["nu", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "nu"}], ")"}]}]]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["ux", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}], 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["ux", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}], "+", 
        RowBox[{
         SuperscriptBox["uy", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]], "0"},
     {
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["ux", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}], "+", 
        RowBox[{
         SuperscriptBox["uy", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]], 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"1", "+", "nu"}]], "+", 
          FractionBox["nu", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "nu"}], ")"}]}]]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["uy", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "+", 
       FractionBox[
        RowBox[{"nu", " ", 
         RowBox[{
          SuperscriptBox["ux", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}]}]]}], "0"},
     {"0", "0", 
      RowBox[{
       FractionBox[
        RowBox[{"nu", " ", 
         RowBox[{
          SuperscriptBox["uy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{"nu", " ", 
         RowBox[{
          SuperscriptBox["ux", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}]}]]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox[
        RowBox[{"nu", " ", 
         RowBox[{
          SuperscriptBox["uy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["ux", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}], "+", 
         RowBox[{
          SuperscriptBox["uy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}]}]], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"1", "+", "nu"}]], "+", 
          FractionBox["nu", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "nu"}], ")"}]}]]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["ux", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"1", "+", "nu"}]], "+", 
          FractionBox["nu", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "nu"}], ")"}]}]]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["uy", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "+", 
       FractionBox[
        RowBox[{"nu", " ", 
         RowBox[{
          SuperscriptBox["ux", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["ux", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}], "+", 
         RowBox[{
          SuperscriptBox["uy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}]}]]}]},
     {"0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{(1 - 2 nu)^(-1) nu (1 + nu)^(-1) Derivative[1, 1][uy][x, y] + 
    Rational[1, 2] (1 + nu)^(-1) (Derivative[0, 2][ux][x, y] + 
      Derivative[1, 1][uy][x, y]) + ((1 + nu)^(-1) + (1 - 2 nu)^(-1) nu/(1 + 
       nu)) Derivative[2, 0][ux][
      x, y], ((1 + nu)^(-1) + (1 - 2 nu)^(-1) nu/(1 + nu)) 
     Derivative[0, 2][uy][x, y] + (1 - 2 nu)^(-1) nu (1 + nu)^(-1) 
     Derivative[1, 1][ux][x, y] + 
    Rational[1, 2] (1 + nu)^(-1) (Derivative[1, 1][ux][x, y] + 
      Derivative[2, 0][uy][x, y]), 0}]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Construction of a statically admissible stress field",
 
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sig", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sxx", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      RowBox[{"sxy", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sxy", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      RowBox[{"syy", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", 
      RowBox[{"szz", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "}"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"eps", " ", "=", 
    RowBox[{"Simplify", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", "nu"}], ")"}], "/", "EE"}], "  ", 
       RowBox[{"sig", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], " ", "-", " ", 
      RowBox[{
       RowBox[{"nu", " ", "/", " ", "EE"}], " ", 
       RowBox[{"Tr", "[", " ", 
        RowBox[{"sig", "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], " ", 
       RowBox[{"IdentityMatrix", "[", "3", "]"}]}]}], " ", "]"}]}], " ", 
   ")"}], "   ", "//", " ", "MatrixForm"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sxx", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"sxy", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sxy", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"syy", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"szz", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"sxx", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "-", 
        RowBox[{"nu", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"syy", "[", 
            RowBox[{"x", ",", "y"}], "]"}], "+", 
           RowBox[{"szz", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]}], "EE"], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"sxy", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "EE"], "0"},
     {
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"sxy", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "EE"], 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "nu"}], " ", 
         RowBox[{"sxx", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], "+", 
        RowBox[{"syy", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "-", 
        RowBox[{"nu", " ", 
         RowBox[{"szz", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}]}], "EE"], "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "nu"}], " ", 
         RowBox[{"sxx", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], "-", 
        RowBox[{"nu", " ", 
         RowBox[{"syy", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], "+", 
        RowBox[{"szz", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "EE"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solszz", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"eps", "[", 
       RowBox[{"[", 
        RowBox[{"3", ",", "3"}], "]"}], "]"}], " ", "\[Equal]", " ", "0"}], 
     ",", " ", 
     RowBox[{"szz", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"szz", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Rule]", 
  RowBox[{
   RowBox[{"nu", " ", 
    RowBox[{"sxx", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}], "+", 
   RowBox[{"nu", " ", 
    RowBox[{"syy", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sig", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"sig", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "/.", " ", "solszz", 
   " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sxx", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"sxy", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sxy", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"syy", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"nu", " ", 
       RowBox[{"sxx", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "+", 
      RowBox[{"nu", " ", 
       RowBox[{"syy", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"divsig", " ", "=", " ", 
    RowBox[{"Div", "[", " ", 
     RowBox[{"sig", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]}], " ", ")"}], "//", 
  " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["sxy", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "+", 
       RowBox[{
        SuperscriptBox["sxx", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["syy", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}], "+", 
       RowBox[{
        SuperscriptBox["sxy", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]},
     {"0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   Derivative[0, 1][sxy][x, y] + Derivative[1, 0][sxx][x, y], 
    Derivative[0, 1][syy][x, y] + Derivative[1, 0][sxy][x, y], 0}]]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sxy", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"y", "^", "2"}], " ", "-", " ", 
     RowBox[{"ee", "^", "2"}]}], ")"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"divsig", " ", "=", " ", 
    RowBox[{"Div", "[", " ", 
     RowBox[{"sig", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]}], " ", ")"}], "//", 
  " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"2", " ", "a", " ", "y"}], "+", 
       RowBox[{
        SuperscriptBox["sxx", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]},
     {
      RowBox[{
       SuperscriptBox["syy", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]},
     {"0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{2 a y + Derivative[1, 0][sxx][x, y], 
    Derivative[0, 1][syy][x, y], 0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Integrate", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"divsig", "[", 
     RowBox[{"[", "1", "]"}], "]"}], " ", "/.", " ", 
    RowBox[{"x", " ", "\[Rule]", " ", "xx"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"xx", ",", " ", "x", ",", " ", "L"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"solsxx", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", "  ", 
    RowBox[{
     RowBox[{"%", " ", "\[Equal]", " ", "0"}], ",", 
     RowBox[{"sxx", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"sig", "[", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"sig", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "/.", " ", "solsxx"}], 
     " ", "/.", "  ", 
     RowBox[{
      RowBox[{"sxx", "[", 
       RowBox[{"L", ",", "y"}], "]"}], " ", "\[Rule]", " ", "0"}]}]}], " ", 
   ")"}], " ", "//", " ", "MatrixForm"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "a", " ", 
   RowBox[{"(", 
    RowBox[{"L", "-", "x"}], ")"}], " ", "y"}], "+", 
  RowBox[{"sxx", "[", 
   RowBox[{"L", ",", "y"}], "]"}], "-", 
  RowBox[{"sxx", "[", 
   RowBox[{"x", ",", "y"}], "]"}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sxx", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Rule]", 
  RowBox[{
   RowBox[{"2", " ", "a", " ", "L", " ", "y"}], "-", 
   RowBox[{"2", " ", "a", " ", "x", " ", "y"}], "+", 
   RowBox[{"sxx", "[", 
    RowBox[{"L", ",", "y"}], "]"}]}]}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"2", " ", "a", " ", "L", " ", "y"}], "-", 
       RowBox[{"2", " ", "a", " ", "x", " ", "y"}]}], 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["ee", "2"]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}]}], "0"},
     {
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["ee", "2"]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}]}], 
      RowBox[{"syy", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"nu", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a", " ", "L", " ", "y"}], "-", 
          RowBox[{"2", " ", "a", " ", "x", " ", "y"}]}], ")"}]}], "+", 
       RowBox[{"nu", " ", 
        RowBox[{"syy", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Integrate", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"divsig", "[", 
      RowBox[{"[", "2", "]"}], "]"}], " ", "/.", " ", 
     RowBox[{"y", " ", "\[Rule]", " ", "yy"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"yy", ",", " ", 
      RowBox[{"-", "h"}], ",", " ", "h"}], "}"}]}], "]"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"sig", "[", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"sig", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "/.", " ", 
     RowBox[{
      RowBox[{"syy", "[", 
       RowBox[{"x", ",", "y"}], "]"}], " ", "\[Rule]", " ", "0"}]}]}], " ", 
   ")"}], " ", "//", " ", "MatrixForm"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"syy", "[", 
    RowBox[{"x", ",", 
     RowBox[{"-", "h"}]}], "]"}]}], "+", 
  RowBox[{"syy", "[", 
   RowBox[{"x", ",", "h"}], "]"}]}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"2", " ", "a", " ", "L", " ", "y"}], "-", 
       RowBox[{"2", " ", "a", " ", "x", " ", "y"}]}], 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["ee", "2"]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}]}], "0"},
     {
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["ee", "2"]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}]}], "0", "0"},
     {"0", "0", 
      RowBox[{"nu", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a", " ", "L", " ", "y"}], "-", 
         RowBox[{"2", " ", "a", " ", "x", " ", "y"}]}], ")"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"Div", "[", 
    RowBox[{"sig", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], " ", "]"}], " ", "//", 
  " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0"},
     {"0"},
     {"0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{0, 0, 0}]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Determination of the unkwon coefficient a by \
minimization of the complementary energy",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"eps", " ", "=", " ", 
   RowBox[{"Simplify", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", " ", "+", " ", "nu"}], ")"}], " ", "/", " ", "EE"}], " ",
       
      RowBox[{"sig", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], " ", "-", " ", 
     RowBox[{
      RowBox[{"nu", " ", "/", " ", "EE"}], " ", 
      RowBox[{"Tr", "[", " ", 
       RowBox[{"sig", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", "]"}]}]}], " ", "]"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"%", " ", "//", " ", "MatrixForm"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["nu", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"L", "-", "x"}], ")"}], " ", "y"}], "EE"]}], ",", 
     FractionBox[
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["ee", "2"]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}]}], "EE"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["ee", "2"]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}]}], "EE"], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "a", " ", "nu", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"L", "-", "x"}], ")"}], " ", "y"}], "EE"]}], ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["nu", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"L", "-", "x"}], ")"}], " ", "y"}], "EE"]}], 
      FractionBox[
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["ee", "2"]}], "+", 
          SuperscriptBox["y", "2"]}], ")"}]}], "EE"], "0"},
     {
      FractionBox[
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["ee", "2"]}], "+", 
          SuperscriptBox["y", "2"]}], ")"}]}], "EE"], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "a", " ", "nu", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"L", "-", "x"}], ")"}], " ", "y"}], "EE"]}], "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"wdensity", " ", "=", " ", 
  RowBox[{"Tr", "[", " ", 
   RowBox[{"eps", "  ", ".", " ", 
    RowBox[{"sig", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["nu", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"L", "-", "x"}], ")"}], " ", "y", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "a", " ", "L", " ", "y"}], "-", 
       RowBox[{"2", " ", "a", " ", "x", " ", "y"}]}], ")"}]}], "EE"]}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["ee", "2"]}], "+", 
       SuperscriptBox["y", "2"]}], ")"}], "2"]}], "EE"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"W", " ", "=", " ", 
  RowBox[{
   RowBox[{"1", "/", "2"}], 
   RowBox[{"Integrate", "[", " ", 
    RowBox[{"wdensity", " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "0", ",", " ", "L"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", " ", 
       RowBox[{"-", "ee"}], ",", "ee"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{"-", "H"}], ",", "H"}], "}"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"8", " ", 
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["ee", "3"], " ", "H", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"12", " ", 
      SuperscriptBox["ee", "2"], " ", "L"}], "-", 
     RowBox[{"5", " ", 
      SuperscriptBox["L", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "nu"}], ")"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "nu"}], ")"}]}], 
  RowBox[{"45", " ", "EE"}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"normal", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "\[IndentingNewLine]", 
   RowBox[{"traction", " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"sig", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", ".", " ", "normal"}], 
     " ", "/.", " ", 
     RowBox[{"x", " ", "\[Rule]", " ", "L", " "}]}]}], "\[IndentingNewLine]", 
   
   RowBox[{"uext", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"0", ",", " ", "d", ",", " ", "0"}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Wext", " ", "=", " ", 
    RowBox[{"Integrate", "[", " ", 
     RowBox[{
      RowBox[{"uext", " ", ".", " ", "traction"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"y", ",", " ", 
        RowBox[{"-", "ee"}], ",", "ee"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", 
        RowBox[{"-", "H"}], ",", "H"}], "}"}]}], "]"}]}]}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(normal\\)\\\" is similar to existing symbol \
\\\"\\!\\(Normal\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["ee", "2"]}], "+", 
      SuperscriptBox["y", "2"]}], ")"}]}], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "d", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(Wext\\)\
\\\" is similar to existing symbols \\!\\({Next, Text}\\). \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["8", "3"]}], " ", "a", " ", "d", " ", 
  SuperscriptBox["ee", "3"], " ", "H"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"sola", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", " ", 
       RowBox[{
        RowBox[{"W", " ", "-", " ", "Wext"}], " ", ",", " ", "a"}], " ", 
       "]"}], " ", "\[Equal]", " ", "0"}], " ", ",", " ", "a"}], " ", "]"}], 
   "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"epsthick", " ", "=", " ", 
  RowBox[{"eps", " ", "/.", " ", "sola", " "}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"epsthick", "  ", "//", " ", "MatrixForm"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"Inc", "[", " ", "epsthick", " ", 
  "]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"a", "\[Rule]", 
  FractionBox[
   RowBox[{"15", " ", "d", " ", "EE"}], 
   RowBox[{"2", " ", "L", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "nu"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       SuperscriptBox["ee", "2"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["L", "2"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["L", "2"], " ", "nu"}]}], ")"}]}]]}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"15", " ", "d", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["nu", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"L", "-", "x"}], ")"}], " ", "y"}], 
       RowBox[{"L", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "12"}], " ", 
           SuperscriptBox["ee", "2"]}], "-", 
          RowBox[{"5", " ", 
           SuperscriptBox["L", "2"]}], "+", 
          RowBox[{"5", " ", 
           SuperscriptBox["L", "2"], " ", "nu"}]}], ")"}]}]]}], ",", 
     FractionBox[
      RowBox[{"15", " ", "d", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["ee", "2"]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}]}], 
      RowBox[{"2", " ", "L", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          SuperscriptBox["ee", "2"]}], "-", 
         RowBox[{"5", " ", 
          SuperscriptBox["L", "2"]}], "+", 
         RowBox[{"5", " ", 
          SuperscriptBox["L", "2"], " ", "nu"}]}], ")"}]}]], ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"15", " ", "d", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["ee", "2"]}], "+", 
         SuperscriptBox["y", "2"]}], ")"}]}], 
      RowBox[{"2", " ", "L", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "12"}], " ", 
          SuperscriptBox["ee", "2"]}], "-", 
         RowBox[{"5", " ", 
          SuperscriptBox["L", "2"]}], "+", 
         RowBox[{"5", " ", 
          SuperscriptBox["L", "2"], " ", "nu"}]}], ")"}]}]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"15", " ", "d", " ", "nu", " ", 
        RowBox[{"(", 
         RowBox[{"L", "-", "x"}], ")"}], " ", "y"}], 
       RowBox[{"L", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "12"}], " ", 
           SuperscriptBox["ee", "2"]}], "-", 
          RowBox[{"5", " ", 
           SuperscriptBox["L", "2"]}], "+", 
          RowBox[{"5", " ", 
           SuperscriptBox["L", "2"], " ", "nu"}]}], ")"}]}]]}], ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{"15", " ", "d", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["nu", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"L", "-", "x"}], ")"}], " ", "y"}], 
        RowBox[{"L", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "12"}], " ", 
            SuperscriptBox["ee", "2"]}], "-", 
           RowBox[{"5", " ", 
            SuperscriptBox["L", "2"]}], "+", 
           RowBox[{"5", " ", 
            SuperscriptBox["L", "2"], " ", "nu"}]}], ")"}]}]]}], 
      FractionBox[
       RowBox[{"15", " ", "d", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["ee", "2"]}], "+", 
          SuperscriptBox["y", "2"]}], ")"}]}], 
       RowBox[{"2", " ", "L", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "12"}], " ", 
           SuperscriptBox["ee", "2"]}], "-", 
          RowBox[{"5", " ", 
           SuperscriptBox["L", "2"]}], "+", 
          RowBox[{"5", " ", 
           SuperscriptBox["L", "2"], " ", "nu"}]}], ")"}]}]], "0"},
     {
      FractionBox[
       RowBox[{"15", " ", "d", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["ee", "2"]}], "+", 
          SuperscriptBox["y", "2"]}], ")"}]}], 
       RowBox[{"2", " ", "L", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "12"}], " ", 
           SuperscriptBox["ee", "2"]}], "-", 
          RowBox[{"5", " ", 
           SuperscriptBox["L", "2"]}], "+", 
          RowBox[{"5", " ", 
           SuperscriptBox["L", "2"], " ", "nu"}]}], ")"}]}]], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"15", " ", "d", " ", "nu", " ", 
         RowBox[{"(", 
          RowBox[{"L", "-", "x"}], ")"}], " ", "y"}], 
        RowBox[{"L", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "12"}], " ", 
            SuperscriptBox["ee", "2"]}], "-", 
           RowBox[{"5", " ", 
            SuperscriptBox["L", "2"]}], "+", 
           RowBox[{"5", " ", 
            SuperscriptBox["L", "2"], " ", "nu"}]}], ")"}]}]]}], "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uthick", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"IntegrateStrain", "[", "epsthick", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"5", " ", "d", " ", "y", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["ee", "2"]}], "+", 
       RowBox[{"6", " ", "L", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", "x"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["x", "2"]}], "-", 
       RowBox[{"3", " ", "nu", " ", 
        SuperscriptBox["x", "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["y", "2"]}], "+", 
       RowBox[{"nu", " ", 
        SuperscriptBox["y", "2"]}]}], ")"}]}], 
    RowBox[{"2", " ", "L", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"12", " ", 
        SuperscriptBox["ee", "2"]}], "-", 
       RowBox[{"5", " ", 
        SuperscriptBox["L", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "nu"}], ")"}]}]}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{"5", " ", "d", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["ee", "2"], " ", "x"}], "-", 
       SuperscriptBox["x", "3"], "+", 
       RowBox[{"nu", " ", 
        SuperscriptBox["x", "3"]}], "-", 
       RowBox[{"3", " ", "nu", " ", "x", " ", 
        SuperscriptBox["y", "2"]}], "+", 
       RowBox[{"3", " ", "L", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "-", 
          RowBox[{"nu", " ", 
           SuperscriptBox["x", "2"]}], "+", 
          RowBox[{"nu", " ", 
           SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}]}], 
    RowBox[{"2", " ", "L", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"12", " ", 
        SuperscriptBox["ee", "2"]}], "-", 
       RowBox[{"5", " ", 
        SuperscriptBox["L", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "nu"}], ")"}]}]}], ")"}]}]], ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{"Series", "[", " ", 
     RowBox[{
      RowBox[{"sola", " ", "/.", " ", 
       RowBox[{"ee", " ", "\[Rule]", " ", 
        RowBox[{"eta", " ", "L"}]}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"eta", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}], " ", "/.",
     " ", 
    RowBox[{"eta", " ", "\[Rule]", " ", 
     RowBox[{"ee", " ", "/", " ", "L"}]}]}], " ", "]"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"epsthin", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"eps", " ", "/.", " ", "%"}], " ", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"epsthin", " ", "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{"Inc", "[", "epsthin", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"a", "\[Rule]", 
  FractionBox[
   RowBox[{"3", " ", "d", " ", "EE"}], 
   RowBox[{"2", " ", 
    SuperscriptBox["L", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["nu", "2"]}], ")"}]}]]}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "d", " ", 
        RowBox[{"(", 
         RowBox[{"L", "-", "x"}], ")"}], " ", "y"}], 
       SuperscriptBox["L", "3"]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "d", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["ee", "2"], "-", 
          SuperscriptBox["y", "2"]}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["L", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "nu"}], ")"}]}]]}], ",", "0"}], "}"}], ",",
    
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "d", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["ee", "2"], "-", 
          SuperscriptBox["y", "2"]}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["L", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "nu"}], ")"}]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "d", " ", "nu", " ", 
        RowBox[{"(", 
         RowBox[{"L", "-", "x"}], ")"}], " ", "y"}], 
       RowBox[{
        SuperscriptBox["L", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "nu"}], ")"}]}]]}], ",", "0"}], "}"}], ",",
    
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "d", " ", 
         RowBox[{"(", 
          RowBox[{"L", "-", "x"}], ")"}], " ", "y"}], 
        SuperscriptBox["L", "3"]]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "d", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["ee", "2"], "-", 
           SuperscriptBox["y", "2"]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["L", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "nu"}], ")"}]}]]}], "0"},
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "d", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["ee", "2"], "-", 
           SuperscriptBox["y", "2"]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["L", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "nu"}], ")"}]}]]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", "d", " ", "nu", " ", 
         RowBox[{"(", 
          RowBox[{"L", "-", "x"}], ")"}], " ", "y"}], 
        RowBox[{
         SuperscriptBox["L", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "nu"}], ")"}]}]]}], "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[""], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"uthin", " ", "=", " ", 
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"IntegrateStrain", "[", "epsthin", "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"d", " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["ee", "2"]}], "+", 
        RowBox[{"6", " ", "L", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", "x"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"3", " ", "nu", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["y", "2"]}], "+", 
        RowBox[{"nu", " ", 
         SuperscriptBox["y", "2"]}]}], ")"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["L", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "nu"}], ")"}]}]]}], ",", 
   FractionBox[
    RowBox[{"d", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", 
        SuperscriptBox["ee", "2"], " ", "x"}], "+", 
       SuperscriptBox["x", "3"], "-", 
       RowBox[{"nu", " ", 
        SuperscriptBox["x", "3"]}], "+", 
       RowBox[{"3", " ", "nu", " ", "x", " ", 
        SuperscriptBox["y", "2"]}], "+", 
       RowBox[{"3", " ", "L", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["x", "2"]}], "+", 
          RowBox[{"nu", " ", 
           SuperscriptBox["x", "2"]}], "-", 
          RowBox[{"nu", " ", 
           SuperscriptBox["y", "2"]}]}], ")"}]}]}], ")"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["L", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "nu"}], ")"}]}]], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"],

Cell[BoxData["\[IndentingNewLine]"], "Input"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{816, 615},
WindowMargins->{{37, Automatic}, {Automatic, 26}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 62, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[1418, 43, 291, 8, 55, "Input"],
Cell[1712, 53, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1799, 56, 217, 3, 99, "Input"],
Cell[CellGroupData[{
Cell[2041, 63, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2153, 68, 137, 3, 32, "Input"],
Cell[2293, 73, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2426, 80, 132, 3, 32, "Input"],
Cell[2561, 85, 83, 2, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2693, 93, 88, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2806, 98, 882, 26, 99, "Input"],
Cell[3691, 126, 4722, 157, 106, "Output"],
Cell[8416, 285, 4232, 131, 89, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12697, 422, 120, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[12842, 428, 1362, 40, 59, "Input"],
Cell[14207, 470, 560, 18, 27, "Output"],
Cell[14770, 490, 1636, 53, 100, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16443, 548, 409, 13, 27, "Input"],
Cell[16855, 563, 299, 10, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17191, 578, 240, 7, 27, "Input"],
Cell[17434, 587, 710, 23, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18181, 615, 241, 7, 27, "Input"],
Cell[18425, 624, 1272, 43, 80, "Output"]
}, Open  ]],
Cell[19712, 670, 251, 8, 27, "Input"],
Cell[CellGroupData[{
Cell[19988, 682, 241, 7, 27, "Input"],
Cell[20232, 691, 757, 26, 80, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21026, 722, 1108, 32, 75, "Input"],
Cell[22137, 756, 260, 8, 27, "Output"],
Cell[22400, 766, 287, 8, 27, "Output"],
Cell[22690, 776, 1062, 34, 80, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23789, 815, 795, 23, 59, "Input"],
Cell[24587, 840, 199, 7, 27, "Output"],
Cell[24789, 849, 873, 28, 80, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25699, 882, 216, 6, 27, "Input"],
Cell[25918, 890, 173, 7, 76, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26140, 903, 153, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[26318, 909, 678, 19, 43, "Input"],
Cell[26999, 930, 1314, 43, 46, "Output"],
Cell[28316, 975, 1302, 42, 100, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29655, 1022, 210, 5, 27, "Input"],
Cell[29868, 1029, 770, 25, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30675, 1059, 467, 13, 27, "Input"],
Cell[31145, 1074, 496, 16, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31678, 1095, 958, 27, 75, "Input"],
Cell[32639, 1124, 391, 8, 20, "Message"],
Cell[33033, 1134, 83, 2, 27, "Output"],
Cell[33119, 1138, 238, 8, 29, "Output"],
Cell[33360, 1148, 83, 2, 27, "Output"],
Cell[33446, 1152, 386, 8, 20, "Message"],
Cell[33835, 1162, 145, 4, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34017, 1171, 706, 19, 91, "Input"],
Cell[34726, 1192, 474, 15, 46, "Output"],
Cell[35203, 1209, 2519, 80, 48, "Output"],
Cell[37725, 1291, 2538, 78, 104, "Output"],
Cell[40266, 1371, 260, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40563, 1384, 154, 3, 27, "Input"],
Cell[40720, 1389, 1932, 60, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42689, 1454, 770, 20, 75, "Input"],
Cell[43462, 1476, 274, 9, 46, "Output"],
Cell[43739, 1487, 1482, 50, 48, "Output"],
Cell[45224, 1539, 1473, 48, 104, "Output"],
Cell[46700, 1589, 260, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46997, 1602, 26, 0, 27, "Input"],
Cell[47026, 1604, 260, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47323, 1617, 190, 4, 43, "Input"],
Cell[47516, 1623, 1676, 52, 48, "Output"]
}, Open  ]],
Cell[49207, 1678, 26, 0, 27, "Input"],
Cell[49236, 1680, 45, 0, 43, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

