(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    382007,      12186]
NotebookOptionsPosition[    371623,      11846]
NotebookOutlinePosition[    372514,      11874]
CellTagsIndexPosition[    372471,      11871]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["Compression of Cylinder with friction", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "SetDirectory", "[", 
    "\"\</local/constant/Oxford/Tex/ElasticaBook/Packages\>\"", "]"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{"FileNames", "[", "\"\<*\>\"", "]"}]}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/Oxford/Tex/ElasticaBook/Packages\"\>"], \
"Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Displacement_Kolosov.m\"\>", ",", "\<\"Displacement.m\"\>", 
   ",", "\<\"Old_integrate_nabla.nb\"\>", ",", "\<\"T2Analysis.m\"\>", 
   ",", "\<\"Tensor2Analysis.m\"\>", ",", "\<\"Tensor2Analysis_Old.m\"\>", 
   ",", "\<\"Tensor2AnalysisOld.m\"\>"}], "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"<<", " ", "Tensor2Analysis.m"}], "\n", 
 RowBox[{"<<", " ", "Displacement.m"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}], "\n", 
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "t", ",", "z"}], "}"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", "z"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["R = H / ee - radius , H - height , ee =  H / R", "Subsection"],

Cell[BoxData[
 RowBox[{"u", " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"nu", " ", 
     RowBox[{"delta", " ", "/", " ", "H"}], " ", "r", "  ", 
     RowBox[{"ee", "/", " ", "H"}], "  ", 
     RowBox[{"f", "[", 
      RowBox[{"z", " ", "/", " ", "H"}], " ", "]"}]}], ",", " ", "0", ",", 
    "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", "delta"}], " ", "/", " ", "H"}], " ", "z"}]}], 
   "}"}]}]], "Input"],

Cell["check kinematic compatibility of the displacement field ", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Thread", "[", " ", 
   RowBox[{
    RowBox[{"Simplify", "[", " ", 
     RowBox[{"u", " ", "/.", " ", 
      RowBox[{"z", " ", "\[Rule]", " ", "H"}]}], " ", "]"}], " ", "\[Equal]", 
    " ", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", 
      RowBox[{"-", "delta"}]}], "}"}]}], "]"}], "   "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"delta", " ", "ee", " ", "nu", " ", "r", " ", 
      RowBox[{"f", "[", "1", "]"}]}], 
     SuperscriptBox["H", "2"]], "\[Equal]", "0"}], ",", "True", ",", "True"}],
   "}"}]], "Output"]
}, Open  ]],

Cell["compute strains and stresses", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{"Strain", "[", "u", "]"}]}], " ", ")"}], " ", "//", " ", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{"Stress", "[", "eps", "]"}]}], ")"}], " ", "//", " ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"delta", " ", "ee", " ", "nu", " ", 
        RowBox[{"f", "[", 
         FractionBox["z", "H"], "]"}]}], 
       SuperscriptBox["H", "2"]], "0", 
      FractionBox[
       RowBox[{"delta", " ", "ee", " ", "nu", " ", "r", " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox["z", "H"], "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["H", "3"]}]]},
     {"0", 
      FractionBox[
       RowBox[{"delta", " ", "ee", " ", "nu", " ", 
        RowBox[{"f", "[", 
         FractionBox["z", "H"], "]"}]}], 
       SuperscriptBox["H", "2"]], "0"},
     {
      FractionBox[
       RowBox[{"delta", " ", "ee", " ", "nu", " ", "r", " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox["z", "H"], "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["H", "3"]}]], "0", 
      RowBox[{"-", 
       FractionBox["delta", "H"]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"delta", " ", "nu"}], 
         RowBox[{"H", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}]}]]}], "+", 
       FractionBox[
        RowBox[{"delta", " ", "ee", " ", 
         SuperscriptBox["nu", "2"], " ", 
         RowBox[{"f", "[", 
          FractionBox["z", "H"], "]"}]}], 
        RowBox[{
         SuperscriptBox["H", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{"delta", " ", "ee", " ", "nu", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"1", "+", "nu"}]], "+", 
           FractionBox["nu", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "nu"}], ")"}]}]]}], ")"}], " ", 
         RowBox[{"f", "[", 
          FractionBox["z", "H"], "]"}]}], 
        SuperscriptBox["H", "2"]]}], "0", 
      FractionBox[
       RowBox[{"delta", " ", "ee", " ", "nu", " ", "r", " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox["z", "H"], "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["H", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]]},
     {"0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"delta", " ", "nu"}], 
         RowBox[{"H", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}]}]]}], "+", 
       FractionBox[
        RowBox[{"delta", " ", "ee", " ", 
         SuperscriptBox["nu", "2"], " ", 
         RowBox[{"f", "[", 
          FractionBox["z", "H"], "]"}]}], 
        RowBox[{
         SuperscriptBox["H", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}]}]], "+", 
       FractionBox[
        RowBox[{"delta", " ", "ee", " ", "nu", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"1", "+", "nu"}]], "+", 
           FractionBox["nu", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "nu"}], ")"}]}]]}], ")"}], " ", 
         RowBox[{"f", "[", 
          FractionBox["z", "H"], "]"}]}], 
        SuperscriptBox["H", "2"]]}], "0"},
     {
      FractionBox[
       RowBox[{"delta", " ", "ee", " ", "nu", " ", "r", " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox["z", "H"], "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["H", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "nu"}], ")"}]}]], "0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"delta", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", 
             RowBox[{"1", "+", "nu"}]], "+", 
            FractionBox["nu", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "nu"}], ")"}]}]]}], ")"}]}], "H"]}], "+", 
       FractionBox[
        RowBox[{"2", " ", "delta", " ", "ee", " ", 
         SuperscriptBox["nu", "2"], " ", 
         RowBox[{"f", "[", 
          FractionBox["z", "H"], "]"}]}], 
        RowBox[{
         SuperscriptBox["H", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}]}]]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
stresses are not a real solution = traction vector not zero at lateral \
surface\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sig", " ", ".", " ", 
  RowBox[{"{", 
   RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"delta", " ", "nu"}], 
      RowBox[{"H", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "nu"}], ")"}]}]]}], "+", 
    FractionBox[
     RowBox[{"delta", " ", "ee", " ", 
      SuperscriptBox["nu", "2"], " ", 
      RowBox[{"f", "[", 
       FractionBox["z", "H"], "]"}]}], 
     RowBox[{
      SuperscriptBox["H", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "nu"}], ")"}]}]], "+", 
    FractionBox[
     RowBox[{"delta", " ", "ee", " ", "nu", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"1", "+", "nu"}]], "+", 
        FractionBox["nu", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "nu"}], ")"}]}]]}], ")"}], " ", 
      RowBox[{"f", "[", 
       FractionBox["z", "H"], "]"}]}], 
     SuperscriptBox["H", "2"]]}], ",", "0", ",", 
   FractionBox[
    RowBox[{"delta", " ", "ee", " ", "nu", " ", "r", " ", 
     RowBox[{
      SuperscriptBox["f", "\[Prime]",
       MultilineFunction->None], "[", 
      FractionBox["z", "H"], "]"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["H", "3"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Div", "[", " ", "sig", " ", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"delta", " ", "ee", " ", "nu", " ", "r", " ", 
     RowBox[{
      SuperscriptBox["f", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", 
      FractionBox["z", "H"], "]"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["H", "4"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]], ",", "0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"delta", " ", "ee", " ", "nu", " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", 
       FractionBox["z", "H"], "]"}]}], 
     RowBox[{
      SuperscriptBox["H", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "nu", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["nu", "2"]}]}], ")"}]}]]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["computing the potential energy", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"w", " ", "=", " ", 
  RowBox[{
   RowBox[{"1", "/", " ", "2"}], " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Tr", "[", " ", 
     RowBox[{
      RowBox[{"DDot", "[", " ", 
       RowBox[{
        RowBox[{"IsotropicStiffness", "[", "nu", "]"}], ",", " ", "eps"}], 
       "]"}], "  ", ".", "  ", "eps"}], "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["delta", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["H", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "nu"}], ")"}]}], "+", 
     RowBox[{"8", " ", "ee", " ", 
      SuperscriptBox["H", "3"], " ", 
      SuperscriptBox["nu", "2"], " ", 
      RowBox[{"f", "[", 
       FractionBox["z", "H"], "]"}]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["ee", "2"], " ", 
      SuperscriptBox["H", "2"], " ", 
      SuperscriptBox["nu", "2"], " ", 
      SuperscriptBox[
       RowBox[{"f", "[", 
        FractionBox["z", "H"], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox["ee", "2"], " ", 
      SuperscriptBox["nu", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", 
        FractionBox["z", "H"], "]"}], "2"]}]}], ")"}]}], 
  RowBox[{"4", " ", 
   SuperscriptBox["H", "6"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["nu", "2"]}]}], ")"}]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"w", " ", "=", " ", 
  RowBox[{
   RowBox[{"1", " ", "/", " ", "2"}], "  ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Tr", "[", " ", 
     RowBox[{"eps", "  ", ".", " ", "sig"}], " ", "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["delta", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["H", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "nu"}], ")"}]}], "+", 
     RowBox[{"8", " ", "ee", " ", 
      SuperscriptBox["H", "3"], " ", 
      SuperscriptBox["nu", "2"], " ", 
      RowBox[{"f", "[", 
       FractionBox["z", "H"], "]"}]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["ee", "2"], " ", 
      SuperscriptBox["H", "2"], " ", 
      SuperscriptBox["nu", "2"], " ", 
      SuperscriptBox[
       RowBox[{"f", "[", 
        FractionBox["z", "H"], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox["ee", "2"], " ", 
      SuperscriptBox["nu", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", 
        FractionBox["z", "H"], "]"}], "2"]}]}], ")"}]}], 
  RowBox[{"4", " ", 
   SuperscriptBox["H", "6"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["nu", "2"]}]}], ")"}]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["cylindrical coordinates:  r dr dt dz       is the \
integration term", "Subsection"]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sf", " ", "=", " ", 
  RowBox[{"ScaleFactors", "[", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "r", ",", "1"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"wintr", " ", "=", " ", 
  RowBox[{"4", " ", "Pi", " ", 
   RowBox[{"Integrate", "[", " ", 
    RowBox[{
     RowBox[{"w", "  ", "r"}], " ", ",", " ", 
     RowBox[{"{", " ", 
      RowBox[{"r", ",", " ", "0", ",", " ", 
       RowBox[{"H", " ", "/", " ", "ee"}]}], "}"}]}], "]"}], " "}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["delta", "2"], " ", "\[Pi]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["H", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "nu"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["nu", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", "ee", " ", 
         RowBox[{"f", "[", 
          FractionBox["z", "H"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "H"}], "+", 
           RowBox[{"ee", " ", 
            RowBox[{"f", "[", 
             FractionBox["z", "H"], "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", 
           FractionBox["z", "H"], "]"}], "2"]}]}], ")"}]}]}], ")"}]}], 
  RowBox[{"4", " ", 
   SuperscriptBox["ee", "2"], " ", 
   SuperscriptBox["H", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["nu", "2"]}]}], ")"}]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"energy", " ", "=", " ", 
  RowBox[{"Thread", "[", " ", 
   RowBox[{
    RowBox[{"Integrate", "[", " ", 
     RowBox[{
      RowBox[{"Expand", "[", " ", "wintr", "]"}], " ", ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", " ", "0", ",", "H"}], "}"}]}], "]"}], ",", " ", 
    "Plus"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["delta", "2"], " ", "H", " ", "\[Pi]"}], 
    RowBox[{
     SuperscriptBox["ee", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "nu", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["nu", "2"]}]}], ")"}]}]]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["delta", "2"], " ", "H", " ", "nu", " ", "\[Pi]"}], 
   RowBox[{
    SuperscriptBox["ee", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "2"]}]}], ")"}]}]], "+", 
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", "H"], 
   RowBox[{
    FractionBox[
     RowBox[{"4", " ", 
      SuperscriptBox["delta", "2"], " ", 
      SuperscriptBox["nu", "2"], " ", "\[Pi]", " ", 
      RowBox[{"f", "[", 
       FractionBox["z", "H"], "]"}]}], 
     RowBox[{"ee", " ", "H", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "nu", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["nu", "2"]}]}], ")"}]}]], 
    RowBox[{"\[DifferentialD]", "z"}]}]}], "+", 
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", "H"], 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["delta", "2"], " ", 
       SuperscriptBox["nu", "2"], " ", "\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"f", "[", 
         FractionBox["z", "H"], "]"}], "2"]}], 
      RowBox[{
       SuperscriptBox["H", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["nu", "2"]}]}], ")"}]}]]}], 
    RowBox[{"\[DifferentialD]", "z"}]}]}], "+", 
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", "H"], 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["delta", "2"], " ", 
       SuperscriptBox["nu", "2"], " ", "\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox["z", "H"], "]"}], "2"]}], 
      RowBox[{"4", " ", 
       SuperscriptBox["ee", "2"], " ", 
       SuperscriptBox["H", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["nu", "2"]}]}], ")"}]}]]}], 
    RowBox[{"\[DifferentialD]", "z"}]}]}], "+", 
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", "H"], 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["delta", "2"], " ", 
      SuperscriptBox["nu", "3"], " ", "\[Pi]", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", 
        FractionBox["z", "H"], "]"}], "2"]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["ee", "2"], " ", 
      SuperscriptBox["H", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "nu", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["nu", "2"]}]}], ")"}]}]], 
    RowBox[{"\[DifferentialD]", "z"}]}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rule1", " ", "=", "  ", 
   RowBox[{
    RowBox[{"Integrate", "[", " ", 
     RowBox[{
      RowBox[{"a___", " ", 
       RowBox[{"h___", "[", 
        RowBox[{"z", "/", "H"}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "H"}], "}"}]}], "]"}], " ", "\[Rule]", " ",
     
    RowBox[{"If", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"D", " ", "[", 
        RowBox[{"a", ",", "z"}], "]"}], " ", "\[Equal]", " ", "0"}], ",", " ",
       
      RowBox[{"a", " ", "H", "  ", 
       RowBox[{"Integrate", "[", 
        RowBox[{
         RowBox[{"h", "[", "s", "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"s", ",", "0", ",", "1"}], "}"}]}], "]"}]}]}], "]"}]}]}], 
  " ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rule2", " ", "=", " ", 
   RowBox[{
    RowBox[{"Integrate", "[", " ", 
     RowBox[{
      RowBox[{"a___", " ", 
       RowBox[{"Power", "[", 
        RowBox[{
         RowBox[{"h___", "[", 
          RowBox[{"z", "/", "H"}], "]"}], ",", "n_"}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "H"}], "}"}]}], "]"}], " ", "\[Rule]", " ",
     
    RowBox[{"If", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"D", " ", "[", 
        RowBox[{"a", ",", "z"}], "]"}], " ", "\[Equal]", " ", "0"}], ",", " ",
       
      RowBox[{"a", " ", "H", "  ", 
       RowBox[{"Integrate", "[", 
        RowBox[{
         RowBox[{"Power", "[", 
          RowBox[{
           RowBox[{"h", "[", "s", "]"}], ",", "n"}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"s", ",", "0", ",", "1"}], "}"}]}], "]"}]}]}], "]"}]}]}], 
  " ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"rule3", " ", "=", " ", 
  RowBox[{
   RowBox[{"Integrate", "[", " ", 
    RowBox[{
     RowBox[{"Times", "[", " ", 
      RowBox[{"a___", ",", " ", 
       RowBox[{"Power", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", 
          RowBox[{"z", "/", "H"}], "]"}], ",", "2"}], "]"}]}], "]"}], ",", 
     " ", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0", ",", "H"}], "}"}]}], "]"}], " ", "\[Rule]", "  ",
    
   RowBox[{"If", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"D", " ", "[", 
       RowBox[{"a", ",", "z"}], "]"}], " ", "\[Equal]", " ", "0"}], ",", 
     RowBox[{"Times", "[", 
      RowBox[{"a", ",", "H", ",", "  ", 
       RowBox[{"Integrate", "[", "  ", 
        RowBox[{
         RowBox[{"Power", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "s",
             "]"}], ",", "2"}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"s", ",", "0", ",", "1"}], "}"}]}], "]"}]}], "]"}]}], " ", 
    "]"}]}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", "H"], 
   RowBox[{
    RowBox[{"a___", " ", 
     RowBox[{"h___", "[", 
      FractionBox["z", "H"], "]"}]}], 
    RowBox[{"\[DifferentialD]", "z"}]}]}], "\[Rule]", 
  RowBox[{"a", " ", "H", " ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], 
    RowBox[{
     RowBox[{"h", "[", "s", "]"}], 
     RowBox[{"\[DifferentialD]", "s"}]}]}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", "H"], 
   RowBox[{
    RowBox[{"a___", " ", 
     SuperscriptBox[
      RowBox[{"h___", "[", 
       FractionBox["z", "H"], "]"}], "n_"]}], 
    RowBox[{"\[DifferentialD]", "z"}]}]}], "\[Rule]", 
  RowBox[{"a", " ", "H", " ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"h", "[", "s", "]"}], "n"], 
     RowBox[{"\[DifferentialD]", "s"}]}]}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", "H"], 
   RowBox[{
    RowBox[{"a___", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", 
       FractionBox["z", "H"], "]"}], "2"]}], 
    RowBox[{"\[DifferentialD]", "z"}]}]}], "\[Rule]", 
  RowBox[{"a", " ", "H", " ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], 
     RowBox[{"\[DifferentialD]", "s"}]}]}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"energy", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"energy", "  ", "/.", " ", "rule1"}], " ", "/.", " ", "rule2"}], 
    " ", "/.", " ", "rule3"}]}], "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["delta", "2"], " ", "H", " ", "\[Pi]"}], 
    RowBox[{
     SuperscriptBox["ee", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "nu", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["nu", "2"]}]}], ")"}]}]]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["delta", "2"], " ", "H", " ", "nu", " ", "\[Pi]"}], 
   RowBox[{
    SuperscriptBox["ee", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "2"]}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["delta", "2"], " ", 
    SuperscriptBox["nu", "2"], " ", "\[Pi]", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], 
     RowBox[{
      RowBox[{"f", "[", "s", "]"}], 
      RowBox[{"\[DifferentialD]", "s"}]}]}]}], 
   RowBox[{"ee", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "2"]}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["delta", "2"], " ", 
    SuperscriptBox["nu", "2"], " ", "\[Pi]", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "s", "]"}], "2"], 
      RowBox[{"\[DifferentialD]", "s"}]}]}]}], 
   RowBox[{"H", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "2"]}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["delta", "2"], " ", 
    SuperscriptBox["nu", "2"], " ", "\[Pi]", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"], 
      RowBox[{"\[DifferentialD]", "s"}]}]}]}], 
   RowBox[{"4", " ", 
    SuperscriptBox["ee", "2"], " ", "H", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "2"]}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["delta", "2"], " ", 
    SuperscriptBox["nu", "3"], " ", "\[Pi]", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"], 
      RowBox[{"\[DifferentialD]", "s"}]}]}]}], 
   RowBox[{"2", " ", 
    SuperscriptBox["ee", "2"], " ", "H", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "2"]}]}], ")"}]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ww", " ", "=", " ", 
  RowBox[{"Simplify", "[", "%", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["delta", "2"], " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["H", "2"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["H", "2"], " ", "nu"}], "-", 
      RowBox[{"16", " ", "ee", " ", "H", " ", 
       SuperscriptBox["nu", "2"], " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "1"], 
        RowBox[{
         RowBox[{"f", "[", "s", "]"}], 
         RowBox[{"\[DifferentialD]", "s"}]}]}]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["ee", "2"], " ", 
       SuperscriptBox["nu", "2"], " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "1"], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "s", "]"}], "2"], 
         RowBox[{"\[DifferentialD]", "s"}]}]}]}], "+", 
      RowBox[{
       SuperscriptBox["nu", "2"], " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "1"], 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "2"], 
         RowBox[{"\[DifferentialD]", "s"}]}]}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "3"], " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "1"], 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "2"], 
         RowBox[{"\[DifferentialD]", "s"}]}]}]}]}], ")"}]}], 
   RowBox[{"4", " ", 
    SuperscriptBox["ee", "2"], " ", "H", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "2"]}]}], ")"}]}]]}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Triangular solution  ", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Wtriang", " ", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", " ", 
     RowBox[{"ww", " ", "/.", " ", 
      RowBox[{"f", " ", "\[Rule]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"q", " ", 
          RowBox[{"(", 
           RowBox[{"1", " ", "-", " ", "#"}], ")"}]}], " ", "&"}], ")"}]}]}], 
     "]"}], ",", " ", "q"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["delta", "2"], " ", "H", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", "\[Pi]"}], 
   RowBox[{
    SuperscriptBox["ee", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "2"]}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["delta", "2"], " ", 
    SuperscriptBox["nu", "2"], " ", "\[Pi]", " ", "q"}], 
   RowBox[{"ee", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "2"]}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["delta", "2"], " ", 
    SuperscriptBox["nu", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "3"}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["ee", "2"]}], "+", 
      RowBox[{"6", " ", "nu"}]}], ")"}], " ", "\[Pi]", " ", 
    SuperscriptBox["q", "2"]}], 
   RowBox[{"12", " ", 
    SuperscriptBox["ee", "2"], " ", "H", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "2"]}]}], ")"}]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qsol", " ", "=", " ", 
  RowBox[{
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"Solve", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"Wtriang", ",", " ", "q"}], "]"}], " ", "\[Equal]", " ", 
       "0"}], ",", " ", "q"}], "]"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"q", "\[Rule]", 
   FractionBox[
    RowBox[{"12", " ", "ee", " ", "H"}], 
    RowBox[{"3", "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["ee", "2"]}], "-", 
     RowBox[{"6", " ", "nu"}]}]]}], "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"wsol", " ", "=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Wtriang", " ", "/.", " ", "qsol"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"utriang", " ", "=", "  ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{"u", " ", "/.", "   ", 
     RowBox[{"f", " ", "\[Rule]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"q", " ", 
         RowBox[{"(", 
          RowBox[{"1", " ", "-", " ", "#"}], ")"}]}], " ", "&"}], ")"}]}]}], 
    " ", "/.", " ", "qsol"}], " ", "]"}]}]}], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["delta", "2"], " ", "H", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "3"}], "+", 
     RowBox[{"9", " ", "nu"}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["nu", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["ee", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"2", " ", "nu"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["nu", "2"]}]}], ")"}]}]}], ")"}], " ", "\[Pi]"}], 
  RowBox[{
   SuperscriptBox["ee", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"3", "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["ee", "2"]}], "-", 
     RowBox[{"6", " ", "nu"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["nu", "2"]}]}], ")"}]}]]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"12", " ", "delta", " ", 
     SuperscriptBox["ee", "2"], " ", "nu", " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{"H", "-", "z"}], ")"}]}], 
    RowBox[{
     SuperscriptBox["H", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["ee", "2"]}], "-", 
       RowBox[{"6", " ", "nu"}]}], ")"}]}]], ",", "0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"delta", " ", "z"}], "H"]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Test series solutions  ", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MinEnergy", "[", " ", 
   RowBox[{
   "testfunction_", " ", ",", " ", "testcoef_List", " ", ",", " ", 
    "potential_", ",", " ", "f_"}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"testpotential", " ", "=", " ", 
      RowBox[{"Evaluate", "[", " ", 
       RowBox[{"potential", "/.", " ", 
        RowBox[{"f", " ", "\[Rule]", " ", "testfunction"}]}], "  ", "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"eq", " ", "=", " ", 
      RowBox[{"Map", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", "  ", 
           RowBox[{"testpotential", " ", ",", "  ", "#"}], "]"}], " ", 
          "\[Equal]", " ", "0"}], " ", "&"}], " ", ",", " ", "testcoef"}], 
       " ", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"solcoef", " ", "=", " ", 
      RowBox[{"Solve", "[", " ", 
       RowBox[{"eq", " ", ",", " ", "testcoef"}], " ", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"optfunction", " ", "=", " ", 
      RowBox[{
       RowBox[{"Simplify", "[", " ", 
        RowBox[{"testfunction", " ", "/.", " ", "solcoef"}], " ", "]"}], "[", 
       
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"optfunction", ",", " ", 
       RowBox[{"Simplify", "[", " ", 
        RowBox[{"potential", "  ", "/.", " ", 
         RowBox[{"f", " ", "\[Rule]", " ", "optfunction"}]}], "]"}]}], 
      "}"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"testcoef", " ", "=", " ", 
   RowBox[{"Map", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"ToExpression", "[", 
       RowBox[{"\"\<c\>\"", "<>", 
        RowBox[{"ToString", "[", "#", "]"}]}], "]"}], " ", "&"}], " ", ",", 
     " ", 
     RowBox[{"Range", "[", "1", "]"}]}], " ", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"testfunction", " ", "=", " ", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"Sum", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"testcoef", "[", 
        RowBox[{"[", "i", "]"}], "]"}], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", " ", "-", " ", "#"}], ")"}], "^", "i"}], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", "#"}], ")"}], "^", "i"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "testcoef", "]"}]}], "}"}]}], "]"}], " ", 
    "]"}], " ", "&"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", "c1", "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c1", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "#1"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "#1"}], ")"}]}], "&"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{"MinEnergy", "[", 
   RowBox[{
   "testfunction", ",", " ", "testcoef", ",", " ", "ww", ",", " ", "f"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"20", " ", "ee", " ", "H"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "#1"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "#1"}], ")"}]}], 
     RowBox[{"5", "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["ee", "2"]}], "-", 
      RowBox[{"10", " ", "nu"}]}]], "&"}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["delta", "2"], " ", "H", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "15"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"3", " ", "nu"}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["nu", "2"]}]}], ")"}]}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["ee", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"3", " ", "nu"}], "+", 
          RowBox[{"5", " ", 
           SuperscriptBox["nu", "2"]}]}], ")"}]}]}], ")"}], " ", "\[Pi]"}], 
    RowBox[{"3", " ", 
     SuperscriptBox["ee", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["ee", "2"]}], "-", 
       RowBox[{"10", " ", "nu"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "nu", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["nu", "2"]}]}], ")"}]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"20", " ", "ee", " ", "H"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "#1"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "#1"}], ")"}]}], 
   RowBox[{"5", "+", 
    RowBox[{"16", " ", 
     SuperscriptBox["ee", "2"]}], "-", 
    RowBox[{"10", " ", "nu"}]}]], "&"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ff", "[", " ", 
   RowBox[{"ee_", ",", " ", "H_", ",", " ", "nu_"}], " ", "]"}], "=", " ", 
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{"f", "[", "s", "]"}], " ", "/.", " ", 
     RowBox[{"f", " ", "\[Rule]", " ", 
      RowBox[{"sol", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], "  ", ")"}], " ", "nu", " ", 
   RowBox[{"ee", " ", "/", " ", "H"}]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"20", " ", 
   SuperscriptBox["ee", "2"], " ", "nu", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "s"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "s"}], ")"}]}], 
  RowBox[{"5", "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["ee", "2"]}], "-", 
   RowBox[{"10", " ", "nu"}]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optww", "[", " ", 
   RowBox[{"ee_", ",", " ", "H_", ",", " ", "nu_"}], " ", "]"}], "=", " ", 
  RowBox[{"sol", "[", 
   RowBox[{"[", "2", "]"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["delta", "2"], " ", "H", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "15"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"3", " ", "nu"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["nu", "2"]}]}], ")"}]}], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["ee", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"3", " ", "nu"}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["nu", "2"]}]}], ")"}]}]}], ")"}], " ", "\[Pi]"}], 
  RowBox[{"3", " ", 
   SuperscriptBox["ee", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"5", "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["ee", "2"]}], "-", 
     RowBox[{"10", " ", "nu"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["nu", "2"]}]}], ")"}]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ff", "[", 
      RowBox[{"10", ",", " ", "1", ",", " ", 
       RowBox[{"-", "0.1"}]}], "]"}], ",", " ", 
     RowBox[{"ff", "[", 
      RowBox[{"1", ",", " ", "1", ",", " ", 
       RowBox[{"-", "0.1"}]}], "]"}]}], "}"}], " ", ",", " ", 
   RowBox[{"{", 
    RowBox[{"s", ",", " ", "0", ",", " ", "1"}], "}"}]}], " ", "]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.603319 4.72649 [
[.21429 .59082 -9 -9 ]
[.21429 .59082 9 0 ]
[.40476 .59082 -9 -9 ]
[.40476 .59082 9 0 ]
[.59524 .59082 -9 -9 ]
[.59524 .59082 9 0 ]
[.78571 .59082 -9 -9 ]
[.78571 .59082 9 0 ]
[.97619 .59082 -3 -9 ]
[.97619 .59082 3 0 ]
[.01131 .03614 -30 -4.5 ]
[.01131 .03614 0 4.5 ]
[.01131 .13067 -24 -4.5 ]
[.01131 .13067 0 4.5 ]
[.01131 .2252 -30 -4.5 ]
[.01131 .2252 0 4.5 ]
[.01131 .31973 -30 -4.5 ]
[.01131 .31973 0 4.5 ]
[.01131 .41426 -30 -4.5 ]
[.01131 .41426 0 4.5 ]
[.01131 .50879 -30 -4.5 ]
[.01131 .50879 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .60332 m
.21429 .60957 L
s
[(0.2)] .21429 .59082 0 1 Mshowa
.40476 .60332 m
.40476 .60957 L
s
[(0.4)] .40476 .59082 0 1 Mshowa
.59524 .60332 m
.59524 .60957 L
s
[(0.6)] .59524 .59082 0 1 Mshowa
.78571 .60332 m
.78571 .60957 L
s
[(0.8)] .78571 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(1)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.2619 .60332 m
.2619 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.5 .60332 m
.5 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.7381 .60332 m
.7381 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .03614 m
.03006 .03614 L
s
[(-0.12)] .01131 .03614 1 0 Mshowa
.02381 .13067 m
.03006 .13067 L
s
[(-0.1)] .01131 .13067 1 0 Mshowa
.02381 .2252 m
.03006 .2252 L
s
[(-0.08)] .01131 .2252 1 0 Mshowa
.02381 .31973 m
.03006 .31973 L
s
[(-0.06)] .01131 .31973 1 0 Mshowa
.02381 .41426 m
.03006 .41426 L
s
[(-0.04)] .01131 .41426 1 0 Mshowa
.02381 .50879 m
.03006 .50879 L
s
[(-0.02)] .01131 .50879 1 0 Mshowa
.125 Mabswid
.02381 .05977 m
.02756 .05977 L
s
.02381 .08341 m
.02756 .08341 L
s
.02381 .10704 m
.02756 .10704 L
s
.02381 .1543 m
.02756 .1543 L
s
.02381 .17793 m
.02756 .17793 L
s
.02381 .20157 m
.02756 .20157 L
s
.02381 .24883 m
.02756 .24883 L
s
.02381 .27246 m
.02756 .27246 L
s
.02381 .2961 m
.02756 .2961 L
s
.02381 .34336 m
.02756 .34336 L
s
.02381 .36699 m
.02756 .36699 L
s
.02381 .39063 m
.02756 .39063 L
s
.02381 .43789 m
.02756 .43789 L
s
.02381 .46152 m
.02756 .46152 L
s
.02381 .48516 m
.02756 .48516 L
s
.02381 .53242 m
.02756 .53242 L
s
.02381 .55605 m
.02756 .55605 L
s
.02381 .57969 m
.02756 .57969 L
s
.02381 .01251 m
.02756 .01251 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
.02381 .17364 m
.02499 .17364 L
.02605 .17364 L
.02729 .17364 L
.02846 .17365 L
.03053 .17366 L
.03279 .17368 L
.03527 .1737 L
.0379 .17373 L
.04262 .17381 L
.04749 .1739 L
.05205 .17402 L
.06244 .17435 L
.07305 .17479 L
.08274 .17528 L
.10458 .17673 L
.12357 .17835 L
.14429 .18051 L
.18493 .18594 L
.22406 .19264 L
.26565 .20134 L
.30571 .21128 L
.34426 .22228 L
.38527 .23553 L
.42475 .24979 L
.46273 .2649 L
.50315 .28248 L
.54206 .30087 L
.58342 .32199 L
.62326 .34387 L
.66159 .36633 L
.70238 .39177 L
.74164 .41774 L
.77939 .44409 L
.8196 .47364 L
.85828 .50351 L
.89942 .53684 L
.93905 .57046 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.134313, -0.134275, \
0.00403944, 0.00081394}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Variational Solution (Euler equation) ", "Subsection"],

Cell[BoxData[
 RowBox[{"<<", "Calculus`VariationalMethods`"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"wintr", " "}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["delta", "2"], " ", "\[Pi]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["H", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "nu"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["nu", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "8"}], " ", "ee", " ", 
         RowBox[{"f", "[", 
          FractionBox["z", "H"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "H"}], "+", 
           RowBox[{"ee", " ", 
            RowBox[{"f", "[", 
             FractionBox["z", "H"], "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", 
           FractionBox["z", "H"], "]"}], "2"]}]}], ")"}]}]}], ")"}]}], 
  RowBox[{"4", " ", 
   SuperscriptBox["ee", "2"], " ", 
   SuperscriptBox["H", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["nu", "2"]}]}], ")"}]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cc", " ", "=", "  ", 
  RowBox[{"Pi", " ", 
   RowBox[{
    SuperscriptBox["delta", "2"], " ", "/", " ", 
    RowBox[{"(", 
     RowBox[{"4", " ", 
      SuperscriptBox["ee", "2"], " ", 
      SuperscriptBox["H", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "nu", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["nu", "2"]}]}], ")"}]}], ")"}]}]}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["delta", "2"], " ", "\[Pi]"}], 
  RowBox[{"4", " ", 
   SuperscriptBox["ee", "2"], " ", 
   SuperscriptBox["H", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["nu", "2"]}]}], ")"}]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"int", " ", "=", " ", 
  RowBox[{
   RowBox[{"wintr", " ", "/", " ", "cc"}], "  ", "/.", " ", 
   RowBox[{
    RowBox[{"z", "/", "H"}], " ", "\[Rule]", " ", "s", " "}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", 
   SuperscriptBox["H", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu"}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["nu", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", "ee", " ", 
      RowBox[{"f", "[", "s", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "H"}], "+", 
        RowBox[{"ee", " ", 
         RowBox[{"f", "[", "s", "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"]}]}], 
    ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eueq", " ", "=", " ", 
  RowBox[{"EulerEquations", "[", " ", 
   RowBox[{"int", " ", ",", " ", 
    RowBox[{"f", "[", "s", "]"}], ",", " ", "s"}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SuperscriptBox["nu", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"8", " ", "ee", " ", "H"}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["ee", "2"], " ", 
      RowBox[{"f", "[", "s", "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "s", "]"}]}]}], ")"}]}], "\[Equal]", 
  "0"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eusol", " ", "=", " ", 
  RowBox[{
   RowBox[{"DSolve", "[", " ", 
    RowBox[{"eueq", "  ", ",", " ", "f", ",", " ", "s"}], " ", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"f", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "s", "}"}], ",", 
     RowBox[{
      FractionBox["H", "ee"], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "ee", " ", "s"}], 
         SqrtBox[
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "nu"}]}]]]], " ", 
       RowBox[{"C", "[", "1", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           SqrtBox["2"], " ", "ee", " ", "s"}], 
          SqrtBox[
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "nu"}]}]]]}]], " ", 
       RowBox[{"C", "[", "2", "]"}]}]}]}], "]"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eq", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", "s", "]"}], " ", "\[Equal]", " ", "0"}], " ", "/.", 
      " ", "eusol"}], " ", "/.", " ", 
     RowBox[{"s", " ", "\[Rule]", " ", 
      RowBox[{"-", "1"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", "s", "]"}], " ", "\[Equal]", " ", "0"}], " ", "/.", 
      " ", "eusol"}], " ", "/.", " ", 
     RowBox[{"s", " ", "\[Rule]", " ", "1"}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"csol", " ", "=", " ", 
  RowBox[{"Solve", "[", " ", 
   RowBox[{"eq", ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], ",", " ", 
      RowBox[{"C", "[", "2", "]"}]}], " ", "}"}]}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["H", "ee"], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "ee"}], 
         SqrtBox[
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "nu"}]}]]]}]], " ", 
      RowBox[{"C", "[", "1", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SqrtBox["2"], " ", "ee"}], 
        SqrtBox[
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "nu"}]}]]]], " ", 
      RowBox[{"C", "[", "2", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["H", "ee"], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", 
         SqrtBox["2"], " ", "ee"}], 
        SqrtBox[
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "nu"}]}]]]], " ", 
      RowBox[{"C", "[", "1", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "ee"}], 
         SqrtBox[
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "nu"}]}]]]}]], " ", 
      RowBox[{"C", "[", "2", "]"}]}]}], "\[Equal]", "0"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", 
           SqrtBox["2"], " ", "ee"}], 
          SqrtBox[
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "nu"}]}]]]], " ", "H"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"4", " ", 
             SqrtBox["2"], " ", "ee"}], 
            SqrtBox[
             RowBox[{"1", "-", 
              RowBox[{"2", " ", "nu"}]}]]]]}], ")"}], " ", "ee"}]]}]}], ",", 
    RowBox[{
     RowBox[{"C", "[", "2", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", 
           SqrtBox["2"], " ", "ee"}], 
          SqrtBox[
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "nu"}]}]]]], " ", "H"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"4", " ", 
             SqrtBox["2"], " ", "ee"}], 
            SqrtBox[
             RowBox[{"1", "-", 
              RowBox[{"2", " ", "nu"}]}]]]]}], ")"}], " ", "ee"}]]}]}]}], 
   "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fopt", " ", "=", " ", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"eusol", " ", "/.", " ", "csol"}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"f", "\[Rule]", 
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", "s", "}"}], ",", 
    RowBox[{
     FractionBox["H", "ee"], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "ee", " ", "s"}], 
         SqrtBox[
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "nu"}]}]]]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", 
             SqrtBox["2"], " ", "ee"}], 
            SqrtBox[
             RowBox[{"1", "-", 
              RowBox[{"2", " ", "nu"}]}]]]]}], " ", "H"}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"4", " ", 
            SqrtBox["2"], " ", "ee"}], 
           SqrtBox[
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "nu"}]}]]]]}], ")"}], " ", "ee"}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           SqrtBox["2"], " ", "ee", " ", "s"}], 
          SqrtBox[
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "nu"}]}]]]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", 
             SqrtBox["2"], " ", "ee"}], 
            SqrtBox[
             RowBox[{"1", "-", 
              RowBox[{"2", " ", "nu"}]}]]]]}], " ", "H"}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"4", " ", 
            SqrtBox["2"], " ", "ee"}], 
           SqrtBox[
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "nu"}]}]]]]}], ")"}], " ", "ee"}]]}]}], 
   "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "s", "]"}], " ", "/.", " ", "fopt"}], "/.", " ", 
       RowBox[{"nu", " ", "\[Rule]", " ", "0."}]}], "/.", " ", 
      RowBox[{"ee", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
     RowBox[{"H", " ", "\[Rule]", " ", "1"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{"Plot", "[", 
    RowBox[{"%", " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"s", ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
     RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]}], 
  " "}]], "Input"],

Cell[BoxData[
 RowBox[{"1", "-", 
  RowBox[{"0.0034813272970654068`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"2.8284271247461903`", "\[InvisibleSpace]"}], "-", 
     RowBox[{"2.8284271247461903`", " ", "s"}]}]]}], "-", 
  RowBox[{"0.0034813272970654068`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"2.8284271247461903`", "\[InvisibleSpace]"}], "+", 
     RowBox[{"2.8284271247461903`", " ", "s"}]}]]}]}]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.014715 0.6672 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .14816 -18 -4.5 ]
[.01131 .14816 0 4.5 ]
[.01131 .2816 -18 -4.5 ]
[.01131 .2816 0 4.5 ]
[.01131 .41504 -18 -4.5 ]
[.01131 .41504 0 4.5 ]
[.01131 .54848 -18 -4.5 ]
[.01131 .54848 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .14816 m
.03006 .14816 L
s
[(0.2)] .01131 .14816 1 0 Mshowa
.02381 .2816 m
.03006 .2816 L
s
[(0.4)] .01131 .2816 1 0 Mshowa
.02381 .41504 m
.03006 .41504 L
s
[(0.6)] .01131 .41504 1 0 Mshowa
.02381 .54848 m
.03006 .54848 L
s
[(0.8)] .01131 .54848 1 0 Mshowa
.125 Mabswid
.02381 .04808 m
.02756 .04808 L
s
.02381 .08144 m
.02756 .08144 L
s
.02381 .1148 m
.02756 .1148 L
s
.02381 .18152 m
.02756 .18152 L
s
.02381 .21488 m
.02756 .21488 L
s
.02381 .24824 m
.02756 .24824 L
s
.02381 .31496 m
.02756 .31496 L
s
.02381 .34832 m
.02756 .34832 L
s
.02381 .38168 m
.02756 .38168 L
s
.02381 .4484 m
.02756 .4484 L
s
.02381 .48176 m
.02756 .48176 L
s
.02381 .51512 m
.02756 .51512 L
s
.02381 .58184 m
.02756 .58184 L
s
.02381 .6152 m
.02756 .6152 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60331 L
.02846 .60331 L
.03053 .6033 L
.03279 .60329 L
.03527 .60327 L
.0379 .60325 L
.04262 .6032 L
.04749 .60312 L
.05205 .60304 L
.06244 .6028 L
.07305 .60248 L
.08274 .60211 L
.10458 .60105 L
.12357 .59984 L
.14429 .59823 L
.18493 .59415 L
.22406 .589 L
.26565 .58216 L
.30571 .57413 L
.34426 .56496 L
.38527 .55351 L
.42475 .5407 L
.46273 .52654 L
.50315 .50929 L
.54206 .49033 L
.58342 .46737 L
.62326 .44219 L
.66159 .4148 L
.70238 .38184 L
.74164 .34595 L
.77939 .30714 L
.8196 .26061 L
.85828 .21016 L
.89942 .14967 L
.93905 .08389 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzNmQlsFUUcxrfvUXoAFQQUFPBBKWopl6JyiVAuETmiRggmmMeVNoAcJQQi
aAghBAiB1IAgBFAIEIwQIAICngiEQ7xB5VK5LyF4cZfObP3vY/t907ftmLRp
9m1++5tvZmfmvdmjZ3RszpAR0bG5g6KRbmOio3JyB+VFuo4cU4jCCY6TEHEc
Z13EUfsFhbtFm4LC/4L6aqOIt5+tPkJKqaBB2HF17Tghta2gSIbRQyzdWCIs
RxvF6TWWtlR0m96xqOpYvfAvGaRkYDUVqA1MqcVww0B2Fqgv0XgyKaAEqTNJ
7SSqvfRydQqok0kLk4K3MCyTk3SenjtNAre6UtCp4akldmpcc9Na/wcbdq/P
/rdTyJRxc8fbqQkiM6UdqbLn/VKg0Um/u4Q3MXwphrmAGqK3KXaOp6kP3QfV
tQMLoO9LeWfoZ6o8tS/QeYRKmJot4mTNg3glVXobMHv6LcCSrek36Ywpla67
CkmpPPNGMP06YJWs6dcAq2xNvwpYFWv6v4Cl+QcHZabxzH8Au4frfwNW1Zr+
F2DVrOl/AnYv168AVr30uh4cJNXgmZcBq2lNvwTYfdb0PwC7n+sXAavl6iHp
PvNtEjpqiP3vwiPmiPpD11iJgF0ArLYxGS3Uus0aBc9Di2gYsPOAPWBMRpd4
IcDOAfZgHL1b7LIUDZ0h3JsR3qUlGqOzgNXhc/AMYHWt6acBq8f1U4A9xPWT
gEVidN1HKDPCM08AVp/rxwFrYE3/HbB0rv8GWENr+q+AZXD9GGCN/IODpId5
5tFg+hHAHuH6YcAe5fohwDK5/gtgja3pPwOWxfWfAGviHxwkNeWZB4PpBwBr
xvUfAWvO9R8Aa8H17wF7jOvfAfa4q5sXbvrEMf4KyrgwfgtYS2Oy95zPW7i/
ASlPlJxSfBFEK9jXgD1pDEdPxFDyfsCeMiZ7N+go7yvAWvnnAbqwQCNjCENz
cB9grbm+F7A2XN8DWFuu7wasXYyuOwJJT/PMXYC15/pOwJ7h+g7AOnD9S8A6
cn07YNlc/wKwTlz/HLDOXP8MsC7+wUFSV575CWDduP4xYM9yfRtg3bm+FbDn
uL4FsB5c/wiw57m+GbCeXN8EWC//4CCpN8/8ELA+XN8g9bzIpfWAGfR1gL3E
9bXShL5cWgNYkW5edb13euhH/APA+rmxZb+he1+qfqXUkTpxNQiPIzLMznqV
NGxAHA27uyzKWwmYneQVgL3qH3bvFQwaheXiDeTTaxlgBv1dyRzCpaWAGfTF
kpkTI2mwGOg5PGmhFBzGpQUijeDSfMAM+jzJHMWluYAZ9LckM49L+YAZ9DmS
Oc7f1bNlbzwvPwswgz5TMl/n0nSRJnFpmkhvcmmqSJO5NEWkKVyaLNJULr0h
375p/s6cKIdm8PITRJ/FpXGSNJtLeSLlc2m0VDeXS69J0ttcGi5J77hSWRai
XKlxkRtW9uVnqEQuKXWkLj5YWv6eMch8vxSVvOW2znCARK60FdlfbbW52j+o
5kevL0vBNXzKvCDSei7pC0Z9z72RS90laSuXuoj0qf+rmS2HtvPy+h4xSZFd
XNJPVlIU2c+lLDmng1zSzx+TFTnMJf0GJk2REzFSbQWu8FIFbiPtHdedqGnR
m10n4Q5RJ0jN\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0825959, -0.0693845, \
0.00385924, 0.00550879}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"energy", " ", "/.", "fopt"}], " ", "/.", " ", 
    RowBox[{"nu", " ", "\[Rule]", " ", "0.3"}]}], "/.", " ", 
   RowBox[{"ee", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
  RowBox[{"H", " ", "\[Rule]", " ", "1"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"3.3846958676770833`", " ", 
  SuperscriptBox["delta", "2"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"energyopt", " ", "=", 
  RowBox[{"energy", " ", "/.", "fopt", " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["delta", "2"], " ", "H", " ", "\[Pi]"}], 
    RowBox[{
     SuperscriptBox["ee", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "nu", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["nu", "2"]}]}], ")"}]}]]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["delta", "2"], " ", "H", " ", "nu", " ", "\[Pi]"}], 
   RowBox[{
    SuperscriptBox["ee", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "2"]}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["delta", "2"], " ", "H", " ", 
    SuperscriptBox["nu", "2"], " ", "\[Pi]", " ", 
    SuperscriptBox[
     RowBox[{"Sech", "[", 
      FractionBox[
       RowBox[{"2", " ", "ee"}], 
       SqrtBox[
        RowBox[{
         FractionBox["1", "2"], "-", "nu"}]]], "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"16", " ", "ee"}], "+", 
      RowBox[{"8", " ", "ee", " ", 
       RowBox[{"Cosh", "[", 
        FractionBox[
         RowBox[{"4", " ", "ee"}], 
         SqrtBox[
          RowBox[{
           FractionBox["1", "2"], "-", "nu"}]]], "]"}]}], "-", 
      RowBox[{"3", " ", 
       SqrtBox[
        RowBox[{"2", "-", 
         RowBox[{"4", " ", "nu"}]}]], " ", 
       RowBox[{"Sinh", "[", 
        FractionBox[
         RowBox[{"4", " ", "ee"}], 
         SqrtBox[
          RowBox[{
           FractionBox["1", "2"], "-", "nu"}]]], "]"}]}]}], ")"}]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["ee", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "2"]}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["delta", "2"], " ", "H", " ", 
    SuperscriptBox["nu", "2"], " ", "\[Pi]", " ", 
    SuperscriptBox[
     RowBox[{"Sech", "[", 
      FractionBox[
       RowBox[{"2", " ", "ee"}], 
       SqrtBox[
        RowBox[{
         FractionBox["1", "2"], "-", "nu"}]]], "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"8", " ", "ee"}], "-", 
      RowBox[{
       SqrtBox[
        RowBox[{"2", "-", 
         RowBox[{"4", " ", "nu"}]}]], " ", 
       RowBox[{"Sinh", "[", 
        FractionBox[
         RowBox[{"4", " ", "ee"}], 
         SqrtBox[
          RowBox[{
           FractionBox["1", "2"], "-", "nu"}]]], "]"}]}]}], ")"}]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["ee", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "2"]}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["delta", "2"], " ", "H", " ", 
    SuperscriptBox["nu", "3"], " ", "\[Pi]", " ", 
    SuperscriptBox[
     RowBox[{"Sech", "[", 
      FractionBox[
       RowBox[{"2", " ", "ee"}], 
       SqrtBox[
        RowBox[{
         FractionBox["1", "2"], "-", "nu"}]]], "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"8", " ", "ee"}], "-", 
      RowBox[{
       SqrtBox[
        RowBox[{"2", "-", 
         RowBox[{"4", " ", "nu"}]}]], " ", 
       RowBox[{"Sinh", "[", 
        FractionBox[
         RowBox[{"4", " ", "ee"}], 
         SqrtBox[
          RowBox[{
           FractionBox["1", "2"], "-", "nu"}]]], "]"}]}]}], ")"}]}], 
   RowBox[{"4", " ", 
    SuperscriptBox["ee", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "2"]}]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["delta", "2"], " ", "H", " ", 
    SuperscriptBox["nu", "2"], " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", "ee"}], "-", 
      RowBox[{
       SqrtBox[
        RowBox[{"2", "-", 
         RowBox[{"4", " ", "nu"}]}]], " ", 
       RowBox[{"Tanh", "[", 
        FractionBox[
         RowBox[{"2", " ", "ee"}], 
         SqrtBox[
          RowBox[{
           FractionBox["1", "2"], "-", "nu"}]]], "]"}]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["ee", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["nu", "2"]}]}], ")"}]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"energyopt", " ", "/.", " ", 
   RowBox[{"nu", " ", "\[Rule]", " ", "0.3"}]}], "/.", " ", 
  RowBox[{"ee", " ", "\[Rule]", " ", "1", " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"3.3846958676770833`", " ", 
  SuperscriptBox["delta", "2"], " ", "H"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"energyopt", " ", "/.", " ", 
   RowBox[{"nu", " ", "\[Rule]", " ", "0."}]}], "/.", " ", 
  RowBox[{"ee", " ", "\[Rule]", " ", "1", " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"3.141592653589793`", " ", 
  SuperscriptBox["delta", "2"], " ", "H"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot3D", "[", " ", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"energyopt", "  ", "/", " ", 
       RowBox[{"delta", "^", "2"}]}], "  ", "/", " ", "H"}], "  ", "]"}], ",",
     " ", 
    RowBox[{"{", 
     RowBox[{"nu", ",", 
      RowBox[{"-", "0.9"}], ",", "0.49"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"ee", ",", "0.5", ",", " ", "2"}], "}"}], ",", " ", 
    RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}], ",", " ", 
    RowBox[{"PlotPoints", " ", "\[Rule]", " ", "50"}]}], "]"}], 
  "  "}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.96818e-17 1.04977 -0.0679587 1.04977 [
[.19973 .17843 -23.4088 -9 ]
[.19973 .17843 .59123 0 ]
[.43236 .08694 -5.40221 -9 ]
[.43236 .08694 .59779 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 18 2.73794 ]
[.80849 .15988 0 -6.10118 ]
[.80849 .15988 6 2.89882 ]
[.90119 .30183 0 -5.96721 ]
[.90119 .30183 18 3.03279 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02448 .26281 -6 -2.74038 ]
[.02448 .26281 0 6.25962 ]
[.01498 .32238 -12 -2.79075 ]
[.01498 .32238 0 6.20925 ]
[.0051 .3843 -12 -2.84331 ]
[.0051 .3843 0 6.15669 ]
[-0.00518 .44872 -12 -2.89821 ]
[-0.00518 .44872 0 6.10179 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.20877 .18794 m
.2133 .19269 L
s
[(-0.5)] .19973 .17843 .95073 1 Mshowa
.44056 .09718 m
.44466 .1023 L
s
[(0)] .43236 .08694 .80074 1 Mshowa
.125 Mabswid
.25353 .17041 m
.2562 .17331 L
s
.29907 .15258 m
.30168 .15552 L
s
.3454 .13444 m
.34797 .13742 L
s
.39256 .11597 m
.39507 .119 L
s
.48942 .07804 m
.49183 .08116 L
s
.53918 .05856 m
.54152 .06172 L
s
.58985 .03872 m
.59213 .04193 L
s
.64146 .01851 m
.64368 .02177 L
s
.16478 .20517 m
.16753 .20798 L
s
.12152 .2221 m
.12432 .22487 L
s
.07899 .23876 m
.08183 .24149 L
s
.03716 .25514 m
.04004 .25782 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0.5)] .70096 -0.00478 -1 .39157 Mshowa
.79613 .16428 m
.78995 .16648 L
s
[(1)] .80849 .15988 -1 .35582 Mshowa
.88871 .30589 m
.88247 .30793 L
s
[(1.5)] .90119 .30183 -1 .32605 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(2)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.71157 .03492 m
.70789 .03634 L
s
.73369 .06877 m
.73001 .07015 L
s
.75514 .10158 m
.75145 .10294 L
s
.77594 .1334 m
.77224 .13474 L
s
.81573 .19425 m
.81201 .19555 L
s
.83476 .22337 m
.83104 .22465 L
s
.85326 .25166 m
.84953 .25292 L
s
.87123 .27915 m
.8675 .28039 L
s
.90572 .33191 m
.90197 .33311 L
s
.92227 .35722 m
.91851 .3584 L
s
.93838 .38186 m
.93462 .38303 L
s
.95406 .40586 m
.9503 .40701 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.0367 .25803 m
.04281 .25564 L
s
[(0)] .02448 .26281 1 -0.39103 Mshowa
.02724 .31772 m
.03338 .31539 L
s
[(20)] .01498 .32238 1 -0.37983 Mshowa
.01741 .37977 m
.02357 .3775 L
s
[(40)] .0051 .3843 1 -0.36815 Mshowa
.00718 .44432 m
.01336 .44212 L
s
[(60)] -0.00518 .44872 1 -0.35595 Mshowa
.125 Mabswid
.03437 .27274 m
.03804 .27132 L
s
.03202 .28759 m
.03569 .28617 L
s
.02964 .30258 m
.03332 .30118 L
s
.02482 .33301 m
.0285 .33162 L
s
.02237 .34844 m
.02606 .34706 L
s
.0199 .36403 m
.02359 .36266 L
s
.01489 .39567 m
.01859 .39432 L
s
.01235 .41172 m
.01605 .41038 L
s
.00978 .42794 m
.01348 .42661 L
s
.00456 .46086 m
.00827 .45955 L
s
.00191 .47758 m
.00563 .47628 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.696 .757 .899 r
.39875 .60176 .405 .60732 .41549 .60324 .40928 .59762 Metetra
.684 .753 .903 r
.40928 .59762 .41549 .60324 .42601 .5995 .41982 .59382 Metetra
.678 .75 .906 r
.41982 .59382 .42601 .5995 .43656 .59592 .4304 .5902 Metetra
.674 .749 .907 r
.4304 .5902 .43656 .59592 .44715 .59245 .44102 .58669 Metetra
.672 .748 .908 r
.44102 .58669 .44715 .59245 .45778 .58903 .45167 .58324 Metetra
.67 .747 .908 r
.45167 .58324 .45778 .58903 .46844 .58565 .46237 .57983 Metetra
.669 .746 .909 r
.46237 .57983 .46844 .58565 .47915 .5823 .4731 .57645 Metetra
.668 .746 .909 r
.4731 .57645 .47915 .5823 .4899 .57896 .48388 .57307 Metetra
.667 .746 .909 r
.48388 .57307 .4899 .57896 .50069 .57562 .49469 .56971 Metetra
.666 .745 .909 r
.49469 .56971 .50069 .57562 .51152 .57229 .50555 .56635 Metetra
.666 .745 .909 r
.50555 .56635 .51152 .57229 .52239 .56896 .51645 .56299 Metetra
.666 .745 .909 r
.51645 .56299 .52239 .56896 .53331 .56563 .5274 .55963 Metetra
.665 .745 .909 r
.5274 .55963 .53331 .56563 .54426 .56229 .53839 .55627 Metetra
.665 .744 .909 r
.53839 .55627 .54426 .56229 .55527 .55894 .54942 .55289 Metetra
.665 .744 .909 r
.54942 .55289 .55527 .55894 .56631 .55559 .56049 .54952 Metetra
.665 .744 .909 r
.56049 .54952 .56631 .55559 .5774 .55223 .57161 .54613 Metetra
.665 .744 .909 r
.57161 .54613 .5774 .55223 .58854 .54886 .58278 .54273 Metetra
.664 .744 .909 r
.58278 .54273 .58854 .54886 .59972 .54548 .59399 .53932 Metetra
.664 .744 .909 r
.59399 .53932 .59972 .54548 .61094 .54209 .60524 .53591 Metetra
.664 .744 .91 r
.60524 .53591 .61094 .54209 .62221 .53869 .61654 .53248 Metetra
.664 .744 .91 r
.61654 .53248 .62221 .53869 .63352 .53527 .62789 .52904 Metetra
.664 .744 .91 r
.62789 .52904 .63352 .53527 .64489 .53185 .63928 .52559 Metetra
.664 .744 .91 r
.63928 .52559 .64489 .53185 .65629 .52841 .65072 .52213 Metetra
.664 .744 .91 r
.65072 .52213 .65629 .52841 .66774 .52497 .6622 .51866 Metetra
.664 .744 .91 r
.6622 .51866 .66774 .52497 .67924 .52151 .67374 .51517 Metetra
.664 .744 .91 r
.67374 .51517 .67924 .52151 .69079 .51803 .68532 .51167 Metetra
.664 .744 .91 r
.68532 .51167 .69079 .51803 .70239 .51455 .69694 .50816 Metetra
.664 .744 .91 r
.69694 .50816 .70239 .51455 .71403 .51105 .70862 .50463 Metetra
.664 .744 .91 r
.70862 .50463 .71403 .51105 .72572 .50754 .72034 .5011 Metetra
.664 .744 .91 r
.72034 .5011 .72572 .50754 .73745 .50402 .73211 .49754 Metetra
.664 .743 .91 r
.73211 .49754 .73745 .50402 .74924 .50048 .74393 .49398 Metetra
.663 .743 .91 r
.74393 .49398 .74924 .50048 .76108 .49693 .7558 .4904 Metetra
.663 .743 .91 r
.7558 .4904 .76108 .49693 .77296 .49336 .76772 .48681 Metetra
.663 .743 .91 r
.76772 .48681 .77296 .49336 .78489 .48979 .77969 .48321 Metetra
.663 .743 .91 r
.77969 .48321 .78489 .48979 .79688 .48619 .79171 .47959 Metetra
.663 .743 .91 r
.79171 .47959 .79688 .48619 .80891 .48259 .80378 .47595 Metetra
.663 .743 .91 r
.80378 .47595 .80891 .48259 .82099 .47897 .8159 .47231 Metetra
.663 .743 .91 r
.8159 .47231 .82099 .47897 .83313 .47534 .82807 .46865 Metetra
.663 .743 .91 r
.82807 .46865 .83313 .47534 .84531 .47169 .84029 .46497 Metetra
.663 .743 .91 r
.84029 .46497 .84531 .47169 .85755 .46803 .85257 .46129 Metetra
.663 .743 .91 r
.85257 .46129 .85755 .46803 .86984 .46436 .86489 .45759 Metetra
.663 .743 .91 r
.86489 .45759 .86984 .46436 .88218 .46068 .87727 .45387 Metetra
.663 .743 .91 r
.87727 .45387 .88218 .46068 .89458 .45698 .88971 .45015 Metetra
.663 .743 .91 r
.88971 .45015 .89458 .45698 .90702 .45327 .90219 .44642 Metetra
.662 .743 .91 r
.90219 .44642 .90702 .45327 .91953 .44956 .91474 .44267 Metetra
.662 .743 .91 r
.91474 .44267 .91953 .44956 .93208 .44584 .92733 .43893 Metetra
.661 .743 .911 r
.92733 .43893 .93208 .44584 .9447 .44213 .93999 .43519 Metetra
.659 .742 .911 r
.93999 .43519 .9447 .44213 .95737 .43847 .9527 .4315 Metetra
.648 .737 .915 r
.9527 .4315 .95737 .43847 .97015 .43513 .96553 .42816 Metetra
.697 .757 .898 r
.39246 .59618 .39875 .60176 .40928 .59762 .40302 .59196 Metetra
.685 .753 .903 r
.40302 .59196 .40928 .59762 .41982 .59382 .41359 .58811 Metetra
.679 .751 .906 r
.41359 .58811 .41982 .59382 .4304 .5902 .4242 .58445 Metetra
.675 .749 .907 r
.4242 .58445 .4304 .5902 .44102 .58669 .43484 .5809 Metetra
.672 .748 .908 r
.43484 .5809 .44102 .58669 .45167 .58324 .44553 .57741 Metetra
.67 .747 .908 r
.44553 .57741 .45167 .58324 .46237 .57983 .45625 .57397 Metetra
.669 .747 .909 r
.45625 .57397 .46237 .57983 .4731 .57645 .46701 .57055 Metetra
.668 .746 .909 r
.46701 .57055 .4731 .57645 .48388 .57307 .47781 .56715 Metetra
.667 .746 .909 r
.47781 .56715 .48388 .57307 .49469 .56971 .48866 .56376 Metetra
.667 .745 .909 r
.48866 .56376 .49469 .56971 .50555 .56635 .49954 .56037 Metetra
.666 .745 .909 r
.49954 .56037 .50555 .56635 .51645 .56299 .51048 .55699 Metetra
.666 .745 .909 r
.51048 .55699 .51645 .56299 .5274 .55963 .52145 .5536 Metetra
.665 .745 .909 r
.52145 .5536 .5274 .55963 .53839 .55627 .53247 .55021 Metetra
.665 .745 .909 r
.53247 .55021 .53839 .55627 .54942 .55289 .54353 .54681 Metetra
.665 .744 .91 r
.54353 .54681 .54942 .55289 .56049 .54952 .55463 .5434 Metetra
.665 .744 .91 r
.55463 .5434 .56049 .54952 .57161 .54613 .56578 .53999 Metetra
.665 .744 .91 r
.56578 .53999 .57161 .54613 .58278 .54273 .57698 .53656 Metetra
.664 .744 .91 r
.57698 .53656 .58278 .54273 .59399 .53932 .58822 .53313 Metetra
.664 .744 .91 r
.58822 .53313 .59399 .53932 .60524 .53591 .5995 .52969 Metetra
.664 .744 .91 r
.5995 .52969 .60524 .53591 .61654 .53248 .61083 .52623 Metetra
.664 .744 .91 r
.61083 .52623 .61654 .53248 .62789 .52904 .62221 .52277 Metetra
.664 .744 .91 r
.62221 .52277 .62789 .52904 .63928 .52559 .63363 .51929 Metetra
.664 .744 .91 r
.63363 .51929 .63928 .52559 .65072 .52213 .6451 .5158 Metetra
.664 .744 .91 r
.6451 .5158 .65072 .52213 .6622 .51866 .65662 .5123 Metetra
.664 .744 .91 r
.65662 .5123 .6622 .51866 .67374 .51517 .66819 .50879 Metetra
.664 .744 .91 r
.66819 .50879 .67374 .51517 .68532 .51167 .6798 .50526 Metetra
.664 .744 .91 r
.6798 .50526 .68532 .51167 .69694 .50816 .69146 .50172 Metetra
.664 .744 .91 r
.69146 .50172 .69694 .50816 .70862 .50463 .70317 .49817 Metetra
.664 .744 .91 r
.70317 .49817 .70862 .50463 .72034 .5011 .71492 .49461 Metetra
.664 .744 .91 r
.71492 .49461 .72034 .5011 .73211 .49754 .72673 .49103 Metetra
.664 .744 .91 r
.72673 .49103 .73211 .49754 .74393 .49398 .73858 .48744 Metetra
.663 .744 .91 r
.73858 .48744 .74393 .49398 .7558 .4904 .75049 .48383 Metetra
.663 .744 .91 r
.75049 .48383 .7558 .4904 .76772 .48681 .76244 .48021 Metetra
.663 .744 .91 r
.76244 .48021 .76772 .48681 .77969 .48321 .77445 .47658 Metetra
.663 .744 .91 r
.77445 .47658 .77969 .48321 .79171 .47959 .7865 .47293 Metetra
.663 .744 .91 r
.7865 .47293 .79171 .47959 .80378 .47595 .79861 .46927 Metetra
.663 .744 .91 r
.79861 .46927 .80378 .47595 .8159 .47231 .81076 .4656 Metetra
.663 .744 .91 r
.81076 .4656 .8159 .47231 .82807 .46865 .82297 .46191 Metetra
.663 .743 .91 r
.82297 .46191 .82807 .46865 .84029 .46497 .83523 .45821 Metetra
.663 .743 .91 r
.83523 .45821 .84029 .46497 .85257 .46129 .84754 .45449 Metetra
.663 .743 .91 r
.84754 .45449 .85257 .46129 .86489 .45759 .85991 .45076 Metetra
.663 .743 .91 r
.85991 .45076 .86489 .45759 .87727 .45387 .87233 .44702 Metetra
.663 .743 .91 r
.87233 .44702 .87727 .45387 .88971 .45015 .8848 .44327 Metetra
.663 .743 .91 r
.8848 .44327 .88971 .45015 .90219 .44642 .89733 .43951 Metetra
.662 .743 .91 r
.89733 .43951 .90219 .44642 .91474 .44267 .90991 .43574 Metetra
.662 .743 .91 r
.90991 .43574 .91474 .44267 .92733 .43893 .92254 .43196 Metetra
.661 .743 .911 r
.92254 .43196 .92733 .43893 .93999 .43519 .93524 .4282 Metetra
.659 .742 .911 r
.93524 .4282 .93999 .43519 .9527 .4315 .948 .42449 Metetra
.647 .737 .915 r
.948 .42449 .9527 .4315 .96553 .42816 .96086 .42114 Metetra
.699 .758 .898 r
.38612 .59057 .39246 .59618 .40302 .59196 .39671 .58628 Metetra
.686 .754 .903 r
.39671 .58628 .40302 .59196 .41359 .58811 .40731 .58237 Metetra
.68 .751 .905 r
.40731 .58237 .41359 .58811 .4242 .58445 .41795 .57866 Metetra
.675 .75 .907 r
.41795 .57866 .4242 .58445 .43484 .5809 .42862 .57507 Metetra
.672 .748 .908 r
.42862 .57507 .43484 .5809 .44553 .57741 .43933 .57155 Metetra
.67 .748 .908 r
.43933 .57155 .44553 .57741 .45625 .57397 .45008 .56807 Metetra
.669 .747 .909 r
.45008 .56807 .45625 .57397 .46701 .57055 .46087 .56462 Metetra
.668 .746 .909 r
.46087 .56462 .46701 .57055 .47781 .56715 .4717 .56119 Metetra
.667 .746 .909 r
.4717 .56119 .47781 .56715 .48866 .56376 .48258 .55777 Metetra
.667 .746 .909 r
.48258 .55777 .48866 .56376 .49954 .56037 .49349 .55436 Metetra
.666 .745 .909 r
.49349 .55436 .49954 .56037 .51048 .55699 .50445 .55094 Metetra
.666 .745 .909 r
.50445 .55094 .51048 .55699 .52145 .5536 .51545 .54752 Metetra
.665 .745 .91 r
.51545 .54752 .52145 .5536 .53247 .55021 .5265 .5441 Metetra
.665 .745 .91 r
.5265 .5441 .53247 .55021 .54353 .54681 .53759 .54068 Metetra
.665 .745 .91 r
.53759 .54068 .54353 .54681 .55463 .5434 .54873 .53724 Metetra
.665 .745 .91 r
.54873 .53724 .55463 .5434 .56578 .53999 .55991 .5338 Metetra
.665 .744 .91 r
.55991 .5338 .56578 .53999 .57698 .53656 .57113 .53035 Metetra
.664 .744 .91 r
.57113 .53035 .57698 .53656 .58822 .53313 .5824 .52689 Metetra
.664 .744 .91 r
.5824 .52689 .58822 .53313 .5995 .52969 .59372 .52342 Metetra
.664 .744 .91 r
.59372 .52342 .5995 .52969 .61083 .52623 .60508 .51994 Metetra
.664 .744 .91 r
.60508 .51994 .61083 .52623 .62221 .52277 .61649 .51645 Metetra
.664 .744 .91 r
.61649 .51645 .62221 .52277 .63363 .51929 .62794 .51294 Metetra
.664 .744 .91 r
.62794 .51294 .63363 .51929 .6451 .5158 .63945 .50943 Metetra
.664 .744 .91 r
.63945 .50943 .6451 .5158 .65662 .5123 .651 .5059 Metetra
.664 .744 .91 r
.651 .5059 .65662 .5123 .66819 .50879 .66259 .50236 Metetra
.664 .744 .91 r
.66259 .50236 .66819 .50879 .6798 .50526 .67424 .49881 Metetra
.664 .744 .91 r
.67424 .49881 .6798 .50526 .69146 .50172 .68593 .49524 Metetra
.664 .744 .91 r
.68593 .49524 .69146 .50172 .70317 .49817 .69767 .49166 Metetra
.664 .744 .91 r
.69767 .49166 .70317 .49817 .71492 .49461 .70946 .48807 Metetra
.664 .744 .91 r
.70946 .48807 .71492 .49461 .72673 .49103 .7213 .48446 Metetra
.664 .744 .91 r
.7213 .48446 .72673 .49103 .73858 .48744 .73319 .48084 Metetra
.663 .744 .91 r
.73319 .48084 .73858 .48744 .75049 .48383 .74513 .47721 Metetra
.663 .744 .91 r
.74513 .47721 .75049 .48383 .76244 .48021 .75712 .47356 Metetra
.663 .744 .91 r
.75712 .47356 .76244 .48021 .77445 .47658 .76916 .4699 Metetra
.663 .744 .91 r
.76916 .4699 .77445 .47658 .7865 .47293 .78125 .46623 Metetra
.663 .744 .91 r
.78125 .46623 .7865 .47293 .79861 .46927 .7934 .46254 Metetra
.663 .744 .91 r
.7934 .46254 .79861 .46927 .81076 .4656 .80559 .45884 Metetra
.663 .744 .91 r
.80559 .45884 .81076 .4656 .82297 .46191 .81783 .45512 Metetra
.663 .744 .91 r
.81783 .45512 .82297 .46191 .83523 .45821 .83013 .45139 Metetra
.663 .744 .91 r
.83013 .45139 .83523 .45821 .84754 .45449 .84248 .44765 Metetra
.663 .744 .91 r
.84248 .44765 .84754 .45449 .85991 .45076 .85489 .44389 Metetra
.663 .744 .91 r
.85489 .44389 .85991 .45076 .87233 .44702 .86734 .44012 Metetra
.663 .744 .91 r
.86734 .44012 .87233 .44702 .8848 .44327 .87985 .43634 Metetra
.662 .743 .91 r
.87985 .43634 .8848 .44327 .89733 .43951 .89242 .43255 Metetra
.662 .743 .91 r
.89242 .43255 .89733 .43951 .90991 .43574 .90504 .42875 Metetra
.662 .743 .911 r
.90504 .42875 .90991 .43574 .92254 .43196 .91772 .42495 Metetra
.661 .743 .911 r
.91772 .42495 .92254 .43196 .93524 .4282 .93045 .42116 Metetra
.659 .742 .912 r
.93045 .42116 .93524 .4282 .948 .42449 .94325 .41742 Metetra
.646 .737 .915 r
.94325 .41742 .948 .42449 .96086 .42114 .95616 .41407 Metetra
.7 .759 .897 r
.37974 .58494 .38612 .59057 .39671 .58628 .39035 .58057 Metetra
.688 .755 .903 r
.39035 .58057 .39671 .58628 .40731 .58237 .40099 .5766 Metetra
.68 .752 .905 r
.40099 .5766 .40731 .58237 .41795 .57866 .41165 .57284 Metetra
.676 .75 .907 r
.41165 .57284 .41795 .57866 .42862 .57507 .42235 .56921 Metetra
.673 .749 .908 r
.42235 .56921 .42862 .57507 .43933 .57155 .43309 .56565 Metetra
.671 .748 .908 r
.43309 .56565 .43933 .57155 .45008 .56807 .44387 .56214 Metetra
.669 .747 .909 r
.44387 .56214 .45008 .56807 .46087 .56462 .45469 .55866 Metetra
.668 .747 .909 r
.45469 .55866 .46087 .56462 .4717 .56119 .46555 .55519 Metetra
.667 .746 .909 r
.46555 .55519 .4717 .56119 .48258 .55777 .47645 .55174 Metetra
.667 .746 .909 r
.47645 .55174 .48258 .55777 .49349 .55436 .48739 .5483 Metetra
.666 .746 .909 r
.48739 .5483 .49349 .55436 .50445 .55094 .49838 .54485 Metetra
.666 .745 .91 r
.49838 .54485 .50445 .55094 .51545 .54752 .50941 .54141 Metetra
.666 .745 .91 r
.50941 .54141 .51545 .54752 .5265 .5441 .52049 .53796 Metetra
.665 .745 .91 r
.52049 .53796 .5265 .5441 .53759 .54068 .53161 .53451 Metetra
.665 .745 .91 r
.53161 .53451 .53759 .54068 .54873 .53724 .54278 .53104 Metetra
.665 .745 .91 r
.54278 .53104 .54873 .53724 .55991 .5338 .55399 .52758 Metetra
.665 .745 .91 r
.55399 .52758 .55991 .5338 .57113 .53035 .56524 .5241 Metetra
.665 .744 .91 r
.56524 .5241 .57113 .53035 .5824 .52689 .57654 .52061 Metetra
.664 .744 .91 r
.57654 .52061 .5824 .52689 .59372 .52342 .58789 .51711 Metetra
.664 .744 .91 r
.58789 .51711 .59372 .52342 .60508 .51994 .59928 .5136 Metetra
.664 .744 .91 r
.59928 .5136 .60508 .51994 .61649 .51645 .61072 .51008 Metetra
.664 .744 .91 r
.61072 .51008 .61649 .51645 .62794 .51294 .62221 .50655 Metetra
.664 .744 .91 r
.62221 .50655 .62794 .51294 .63945 .50943 .63375 .50301 Metetra
.664 .744 .91 r
.63375 .50301 .63945 .50943 .651 .5059 .64533 .49946 Metetra
.664 .744 .91 r
.64533 .49946 .651 .5059 .66259 .50236 .65696 .49589 Metetra
.664 .744 .91 r
.65696 .49589 .66259 .50236 .67424 .49881 .66864 .49231 Metetra
.664 .744 .91 r
.66864 .49231 .67424 .49881 .68593 .49524 .68036 .48871 Metetra
.664 .744 .91 r
.68036 .48871 .68593 .49524 .69767 .49166 .69214 .48511 Metetra
.664 .744 .91 r
.69214 .48511 .69767 .49166 .70946 .48807 .70396 .48149 Metetra
.664 .744 .91 r
.70396 .48149 .70946 .48807 .7213 .48446 .71584 .47785 Metetra
.664 .744 .91 r
.71584 .47785 .7213 .48446 .73319 .48084 .72776 .4742 Metetra
.663 .744 .91 r
.72776 .4742 .73319 .48084 .74513 .47721 .73974 .47054 Metetra
.663 .744 .91 r
.73974 .47054 .74513 .47721 .75712 .47356 .75176 .46687 Metetra
.663 .744 .91 r
.75176 .46687 .75712 .47356 .76916 .4699 .76384 .46318 Metetra
.663 .744 .91 r
.76384 .46318 .76916 .4699 .78125 .46623 .77597 .45947 Metetra
.663 .744 .91 r
.77597 .45947 .78125 .46623 .7934 .46254 .78814 .45576 Metetra
.663 .744 .91 r
.78814 .45576 .7934 .46254 .80559 .45884 .80037 .45203 Metetra
.663 .744 .91 r
.80037 .45203 .80559 .45884 .81783 .45512 .81266 .44828 Metetra
.663 .744 .91 r
.81266 .44828 .81783 .45512 .83013 .45139 .82499 .44452 Metetra
.663 .744 .91 r
.82499 .44452 .83013 .45139 .84248 .44765 .83738 .44075 Metetra
.663 .744 .91 r
.83738 .44075 .84248 .44765 .85489 .44389 .84982 .43696 Metetra
.663 .744 .91 r
.84982 .43696 .85489 .44389 .86734 .44012 .86232 .43316 Metetra
.663 .744 .91 r
.86232 .43316 .86734 .44012 .87985 .43634 .87487 .42935 Metetra
.662 .744 .91 r
.87487 .42935 .87985 .43634 .89242 .43255 .88747 .42553 Metetra
.662 .744 .91 r
.88747 .42553 .89242 .43255 .90504 .42875 .90013 .42171 Metetra
.662 .743 .911 r
.90013 .42171 .90504 .42875 .91772 .42495 .91285 .41788 Metetra
.661 .743 .911 r
.91285 .41788 .91772 .42495 .93045 .42116 .92563 .41406 Metetra
.659 .742 .912 r
.92563 .41406 .93045 .42116 .94325 .41742 .93847 .4103 Metetra
.645 .737 .916 r
.93847 .4103 .94325 .41742 .95616 .41407 .95143 .40695 Metetra
.702 .76 .897 r
.3733 .57928 .37974 .58494 .39035 .58057 .38395 .57482 Metetra
.689 .755 .902 r
.38395 .57482 .39035 .58057 .40099 .5766 .39462 .57079 Metetra
.681 .752 .905 r
.39462 .57079 .40099 .5766 .41165 .57284 .40531 .56699 Metetra
.676 .751 .907 r
.40531 .56699 .41165 .57284 .42235 .56921 .41604 .56331 Metetra
.673 .749 .908 r
.41604 .56331 .42235 .56921 .43309 .56565 .42681 .55971 Metetra
.671 .748 .908 r
.42681 .55971 .43309 .56565 .44387 .56214 .43761 .55617 Metetra
.67 .748 .909 r
.43761 .55617 .44387 .56214 .45469 .55866 .44846 .55265 Metetra
.669 .747 .909 r
.44846 .55265 .45469 .55866 .46555 .55519 .45935 .54916 Metetra
.668 .747 .909 r
.45935 .54916 .46555 .55519 .47645 .55174 .47028 .54568 Metetra
.667 .746 .909 r
.47028 .54568 .47645 .55174 .48739 .5483 .48125 .5422 Metetra
.666 .746 .91 r
.48125 .5422 .48739 .5483 .49838 .54485 .49227 .53873 Metetra
.666 .746 .91 r
.49227 .53873 .49838 .54485 .50941 .54141 .50333 .53525 Metetra
.666 .745 .91 r
.50333 .53525 .50941 .54141 .52049 .53796 .51444 .53177 Metetra
.665 .745 .91 r
.51444 .53177 .52049 .53796 .53161 .53451 .52559 .52829 Metetra
.665 .745 .91 r
.52559 .52829 .53161 .53451 .54278 .53104 .53678 .5248 Metetra
.665 .745 .91 r
.53678 .5248 .54278 .53104 .55399 .52758 .54802 .52131 Metetra
.665 .745 .91 r
.54802 .52131 .55399 .52758 .56524 .5241 .55931 .5178 Metetra
.665 .745 .91 r
.55931 .5178 .56524 .5241 .57654 .52061 .57064 .51429 Metetra
.664 .745 .91 r
.57064 .51429 .57654 .52061 .58789 .51711 .58202 .51076 Metetra
.664 .744 .91 r
.58202 .51076 .58789 .51711 .59928 .5136 .59344 .50722 Metetra
.664 .744 .91 r
.59344 .50722 .59928 .5136 .61072 .51008 .60491 .50368 Metetra
.664 .744 .91 r
.60491 .50368 .61072 .51008 .62221 .50655 .61643 .50012 Metetra
.664 .744 .91 r
.61643 .50012 .62221 .50655 .63375 .50301 .628 .49655 Metetra
.664 .744 .91 r
.628 .49655 .63375 .50301 .64533 .49946 .63962 .49296 Metetra
.664 .744 .91 r
.63962 .49296 .64533 .49946 .65696 .49589 .65128 .48937 Metetra
.664 .744 .91 r
.65128 .48937 .65696 .49589 .66864 .49231 .66299 .48576 Metetra
.664 .744 .91 r
.66299 .48576 .66864 .49231 .68036 .48871 .67475 .48214 Metetra
.664 .744 .91 r
.67475 .48214 .68036 .48871 .69214 .48511 .68656 .4785 Metetra
.664 .744 .91 r
.68656 .4785 .69214 .48511 .70396 .48149 .69842 .47485 Metetra
.664 .744 .91 r
.69842 .47485 .70396 .48149 .71584 .47785 .71033 .47119 Metetra
.664 .744 .91 r
.71033 .47119 .71584 .47785 .72776 .4742 .72229 .46752 Metetra
.663 .744 .91 r
.72229 .46752 .72776 .4742 .73974 .47054 .7343 .46383 Metetra
.663 .744 .91 r
.7343 .46383 .73974 .47054 .75176 .46687 .74636 .46012 Metetra
.663 .744 .91 r
.74636 .46012 .75176 .46687 .76384 .46318 .75847 .4564 Metetra
.663 .744 .91 r
.75847 .4564 .76384 .46318 .77597 .45947 .77063 .45267 Metetra
.663 .744 .91 r
.77063 .45267 .77597 .45947 .78814 .45576 .78285 .44893 Metetra
.663 .744 .91 r
.78285 .44893 .78814 .45576 .80037 .45203 .79512 .44517 Metetra
.663 .744 .91 r
.79512 .44517 .80037 .45203 .81266 .44828 .80744 .44139 Metetra
.663 .744 .91 r
.80744 .44139 .81266 .44828 .82499 .44452 .81981 .4376 Metetra
.663 .744 .91 r
.81981 .4376 .82499 .44452 .83738 .44075 .83224 .4338 Metetra
.663 .744 .91 r
.83224 .4338 .83738 .44075 .84982 .43696 .84472 .42999 Metetra
.663 .744 .91 r
.84472 .42999 .84982 .43696 .86232 .43316 .85725 .42616 Metetra
.663 .744 .91 r
.85725 .42616 .86232 .43316 .87487 .42935 .86984 .42232 Metetra
.662 .744 .91 r
.86984 .42232 .87487 .42935 .88747 .42553 .88249 .41847 Metetra
.662 .744 .911 r
.88249 .41847 .88747 .42553 .90013 .42171 .89519 .41462 Metetra
.662 .744 .911 r
.89519 .41462 .90013 .42171 .91285 .41788 .90795 .41076 Metetra
.661 .743 .911 r
.90795 .41076 .91285 .41788 .92563 .41406 .92077 .40692 Metetra
.658 .742 .912 r
.92077 .40692 .92563 .41406 .93847 .4103 .93365 .40313 Metetra
.644 .737 .916 r
.93365 .40313 .93847 .4103 .95143 .40695 .94665 .39978 Metetra
.704 .761 .896 r
.36682 .5736 .3733 .57928 .38395 .57482 .3775 .56905 Metetra
.69 .756 .902 r
.3775 .56905 .38395 .57482 .39462 .57079 .3882 .56496 Metetra
.682 .753 .905 r
.3882 .56496 .39462 .57079 .40531 .56699 .39892 .5611 Metetra
.677 .751 .907 r
.39892 .5611 .40531 .56699 .41604 .56331 .40968 .55738 Metetra
.674 .75 .908 r
.40968 .55738 .41604 .56331 .42681 .55971 .42047 .55374 Metetra
.672 .749 .908 r
.42047 .55374 .42681 .55971 .43761 .55617 .43131 .55016 Metetra
.67 .748 .909 r
.43131 .55016 .43761 .55617 .44846 .55265 .44218 .54661 Metetra
.669 .747 .909 r
.44218 .54661 .44846 .55265 .45935 .54916 .4531 .54308 Metetra
.668 .747 .909 r
.4531 .54308 .45935 .54916 .47028 .54568 .46406 .53957 Metetra
.667 .746 .91 r
.46406 .53957 .47028 .54568 .48125 .5422 .47506 .53606 Metetra
.667 .746 .91 r
.47506 .53606 .48125 .5422 .49227 .53873 .48611 .53256 Metetra
.666 .746 .91 r
.48611 .53256 .49227 .53873 .50333 .53525 .4972 .52906 Metetra
.666 .746 .91 r
.4972 .52906 .50333 .53525 .51444 .53177 .50833 .52555 Metetra
.665 .745 .91 r
.50833 .52555 .51444 .53177 .52559 .52829 .51951 .52204 Metetra
.665 .745 .91 r
.51951 .52204 .52559 .52829 .53678 .5248 .53074 .51852 Metetra
.665 .745 .91 r
.53074 .51852 .53678 .5248 .54802 .52131 .54201 .51499 Metetra
.665 .745 .91 r
.54201 .51499 .54802 .52131 .55931 .5178 .55333 .51146 Metetra
.665 .745 .91 r
.55333 .51146 .55931 .5178 .57064 .51429 .56469 .50792 Metetra
.664 .745 .91 r
.56469 .50792 .57064 .51429 .58202 .51076 .5761 .50436 Metetra
.664 .745 .91 r
.5761 .50436 .58202 .51076 .59344 .50722 .58756 .5008 Metetra
.664 .745 .91 r
.58756 .5008 .59344 .50722 .60491 .50368 .59906 .49722 Metetra
.664 .744 .91 r
.59906 .49722 .60491 .50368 .61643 .50012 .61061 .49364 Metetra
.664 .744 .91 r
.61061 .49364 .61643 .50012 .628 .49655 .62221 .49004 Metetra
.664 .744 .91 r
.62221 .49004 .628 .49655 .63962 .49296 .63386 .48643 Metetra
.664 .744 .91 r
.63386 .48643 .63962 .49296 .65128 .48937 .64556 .4828 Metetra
.664 .744 .91 r
.64556 .4828 .65128 .48937 .66299 .48576 .6573 .47917 Metetra
.664 .744 .91 r
.6573 .47917 .66299 .48576 .67475 .48214 .6691 .47552 Metetra
.664 .744 .91 r
.6691 .47552 .67475 .48214 .68656 .4785 .68094 .47185 Metetra
.664 .744 .91 r
.68094 .47185 .68656 .4785 .69842 .47485 .69283 .46818 Metetra
.664 .744 .91 r
.69283 .46818 .69842 .47485 .71033 .47119 .70478 .46449 Metetra
.664 .744 .91 r
.70478 .46449 .71033 .47119 .72229 .46752 .71677 .46078 Metetra
.663 .744 .91 r
.71677 .46078 .72229 .46752 .7343 .46383 .72882 .45706 Metetra
.663 .744 .91 r
.72882 .45706 .7343 .46383 .74636 .46012 .74091 .45333 Metetra
.663 .744 .91 r
.74091 .45333 .74636 .46012 .75847 .4564 .75306 .44958 Metetra
.663 .744 .91 r
.75306 .44958 .75847 .4564 .77063 .45267 .76526 .44582 Metetra
.663 .744 .91 r
.76526 .44582 .77063 .45267 .78285 .44893 .77752 .44205 Metetra
.663 .744 .91 r
.77752 .44205 .78285 .44893 .79512 .44517 .78982 .43826 Metetra
.663 .744 .91 r
.78982 .43826 .79512 .44517 .80744 .44139 .80218 .43445 Metetra
.663 .744 .91 r
.80218 .43445 .80744 .44139 .81981 .4376 .81459 .43064 Metetra
.663 .744 .91 r
.81459 .43064 .81981 .4376 .83224 .4338 .82705 .4268 Metetra
.663 .744 .91 r
.82705 .4268 .83224 .4338 .84472 .42999 .83957 .42296 Metetra
.663 .744 .91 r
.83957 .42296 .84472 .42999 .85725 .42616 .85215 .4191 Metetra
.663 .744 .911 r
.85215 .4191 .85725 .42616 .86984 .42232 .86478 .41523 Metetra
.662 .744 .911 r
.86478 .41523 .86984 .42232 .88249 .41847 .87746 .41136 Metetra
.662 .744 .911 r
.87746 .41136 .88249 .41847 .89519 .41462 .8902 .40747 Metetra
.661 .744 .911 r
.8902 .40747 .89519 .41462 .90795 .41076 .903 .40359 Metetra
.66 .743 .911 r
.903 .40359 .90795 .41076 .92077 .40692 .91586 .39972 Metetra
.658 .742 .912 r
.91586 .39972 .92077 .40692 .93365 .40313 .92879 .39591 Metetra
.643 .736 .917 r
.92879 .39591 .93365 .40313 .94665 .39978 .94184 .39256 Metetra
.706 .762 .896 r
.36029 .56789 .36682 .5736 .3775 .56905 .371 .56326 Metetra
.691 .757 .902 r
.371 .56326 .3775 .56905 .3882 .56496 .38173 .55909 Metetra
.683 .754 .905 r
.38173 .55909 .3882 .56496 .39892 .5611 .39248 .55518 Metetra
.678 .752 .907 r
.39248 .55518 .39892 .5611 .40968 .55738 .40327 .55141 Metetra
.674 .75 .908 r
.40327 .55141 .40968 .55738 .42047 .55374 .41409 .54774 Metetra
.672 .749 .909 r
.41409 .54774 .42047 .55374 .43131 .55016 .42495 .54412 Metetra
.67 .748 .909 r
.42495 .54412 .43131 .55016 .44218 .54661 .43586 .54053 Metetra
.669 .748 .909 r
.43586 .54053 .44218 .54661 .4531 .54308 .4468 .53697 Metetra
.668 .747 .909 r
.4468 .53697 .4531 .54308 .46406 .53957 .45779 .53342 Metetra
.667 .747 .91 r
.45779 .53342 .46406 .53957 .47506 .53606 .46882 .52989 Metetra
.667 .746 .91 r
.46882 .52989 .47506 .53606 .48611 .53256 .4799 .52635 Metetra
.666 .746 .91 r
.4799 .52635 .48611 .53256 .4972 .52906 .49102 .52282 Metetra
.666 .746 .91 r
.49102 .52282 .4972 .52906 .50833 .52555 .50219 .51928 Metetra
.666 .746 .91 r
.50219 .51928 .50833 .52555 .51951 .52204 .5134 .51574 Metetra
.665 .745 .91 r
.5134 .51574 .51951 .52204 .53074 .51852 .52465 .51219 Metetra
.665 .745 .91 r
.52465 .51219 .53074 .51852 .54201 .51499 .53595 .50864 Metetra
.665 .745 .91 r
.53595 .50864 .54201 .51499 .55333 .51146 .5473 .50508 Metetra
.665 .745 .91 r
.5473 .50508 .55333 .51146 .56469 .50792 .5587 .50151 Metetra
.665 .745 .91 r
.5587 .50151 .56469 .50792 .5761 .50436 .57014 .49792 Metetra
.664 .745 .91 r
.57014 .49792 .5761 .50436 .58756 .5008 .58163 .49433 Metetra
.664 .745 .91 r
.58163 .49433 .58756 .5008 .59906 .49722 .59316 .49073 Metetra
.664 .745 .91 r
.59316 .49073 .59906 .49722 .61061 .49364 .60475 .48711 Metetra
.664 .745 .91 r
.60475 .48711 .61061 .49364 .62221 .49004 .61638 .48348 Metetra
.664 .745 .91 r
.61638 .48348 .62221 .49004 .63386 .48643 .62806 .47984 Metetra
.664 .744 .91 r
.62806 .47984 .63386 .48643 .64556 .4828 .63979 .47619 Metetra
.664 .744 .91 r
.63979 .47619 .64556 .4828 .6573 .47917 .65157 .47253 Metetra
.664 .744 .91 r
.65157 .47253 .6573 .47917 .6691 .47552 .6634 .46885 Metetra
.664 .744 .91 r
.6634 .46885 .6691 .47552 .68094 .47185 .67528 .46516 Metetra
.664 .744 .91 r
.67528 .46516 .68094 .47185 .69283 .46818 .6872 .46145 Metetra
.664 .744 .91 r
.6872 .46145 .69283 .46818 .70478 .46449 .69918 .45773 Metetra
.664 .744 .91 r
.69918 .45773 .70478 .46449 .71677 .46078 .71121 .454 Metetra
.663 .744 .91 r
.71121 .454 .71677 .46078 .72882 .45706 .72329 .45025 Metetra
.663 .744 .91 r
.72329 .45025 .72882 .45706 .74091 .45333 .73543 .44649 Metetra
.663 .744 .91 r
.73543 .44649 .74091 .45333 .75306 .44958 .74761 .44271 Metetra
.663 .744 .91 r
.74761 .44271 .75306 .44958 .76526 .44582 .75985 .43892 Metetra
.663 .744 .91 r
.75985 .43892 .76526 .44582 .77752 .44205 .77214 .43512 Metetra
.663 .744 .91 r
.77214 .43512 .77752 .44205 .78982 .43826 .78448 .4313 Metetra
.663 .744 .91 r
.78448 .4313 .78982 .43826 .80218 .43445 .79688 .42746 Metetra
.663 .744 .91 r
.79688 .42746 .80218 .43445 .81459 .43064 .80933 .42362 Metetra
.663 .744 .91 r
.80933 .42362 .81459 .43064 .82705 .4268 .82183 .41975 Metetra
.663 .744 .911 r
.82183 .41975 .82705 .4268 .83957 .42296 .83439 .41588 Metetra
.663 .744 .911 r
.83439 .41588 .83957 .42296 .85215 .4191 .847 .41199 Metetra
.662 .744 .911 r
.847 .41199 .85215 .4191 .86478 .41523 .85967 .40809 Metetra
.662 .744 .911 r
.85967 .40809 .86478 .41523 .87746 .41136 .8724 .40419 Metetra
.662 .744 .911 r
.8724 .40419 .87746 .41136 .8902 .40747 .88518 .40027 Metetra
.661 .744 .911 r
.88518 .40027 .8902 .40747 .903 .40359 .89802 .39636 Metetra
.66 .743 .912 r
.89802 .39636 .903 .40359 .91586 .39972 .91092 .39246 Metetra
.658 .742 .912 r
.91092 .39246 .91586 .39972 .92879 .39591 .92389 .38864 Metetra
.642 .736 .917 r
.92389 .38864 .92879 .39591 .94184 .39256 .93699 .38529 Metetra
.708 .763 .895 r
.3537 .56217 .36029 .56789 .371 .56326 .36445 .55743 Metetra
.693 .758 .902 r
.36445 .55743 .371 .56326 .38173 .55909 .37521 .5532 Metetra
.684 .754 .905 r
.37521 .5532 .38173 .55909 .39248 .55518 .38599 .54923 Metetra
.679 .752 .907 r
.38599 .54923 .39248 .55518 .40327 .55141 .39681 .54542 Metetra
.675 .751 .908 r
.39681 .54542 .40327 .55141 .41409 .54774 .40766 .54169 Metetra
.672 .75 .909 r
.40766 .54169 .41409 .54774 .42495 .54412 .41855 .53803 Metetra
.671 .749 .909 r
.41855 .53803 .42495 .54412 .43586 .54053 .42949 .53441 Metetra
.669 .748 .909 r
.42949 .53441 .43586 .54053 .4468 .53697 .44046 .53082 Metetra
.668 .747 .91 r
.44046 .53082 .4468 .53697 .45779 .53342 .45148 .52724 Metetra
.668 .747 .91 r
.45148 .52724 .45779 .53342 .46882 .52989 .46254 .52367 Metetra
.667 .747 .91 r
.46254 .52367 .46882 .52989 .4799 .52635 .47365 .5201 Metetra
.666 .746 .91 r
.47365 .5201 .4799 .52635 .49102 .52282 .4848 .51654 Metetra
.666 .746 .91 r
.4848 .51654 .49102 .52282 .50219 .51928 .49599 .51297 Metetra
.666 .746 .91 r
.49599 .51297 .50219 .51928 .5134 .51574 .50723 .5094 Metetra
.665 .746 .91 r
.50723 .5094 .5134 .51574 .52465 .51219 .51852 .50583 Metetra
.665 .745 .91 r
.51852 .50583 .52465 .51219 .53595 .50864 .52985 .50224 Metetra
.665 .745 .91 r
.52985 .50224 .53595 .50864 .5473 .50508 .54123 .49865 Metetra
.665 .745 .91 r
.54123 .49865 .5473 .50508 .5587 .50151 .55266 .49505 Metetra
.665 .745 .91 r
.55266 .49505 .5587 .50151 .57014 .49792 .56413 .49144 Metetra
.664 .745 .91 r
.56413 .49144 .57014 .49792 .58163 .49433 .57565 .48782 Metetra
.664 .745 .91 r
.57565 .48782 .58163 .49433 .59316 .49073 .58722 .48419 Metetra
.664 .745 .91 r
.58722 .48419 .59316 .49073 .60475 .48711 .59883 .48054 Metetra
.664 .745 .91 r
.59883 .48054 .60475 .48711 .61638 .48348 .6105 .47688 Metetra
.664 .745 .91 r
.6105 .47688 .61638 .48348 .62806 .47984 .62221 .47322 Metetra
.664 .745 .91 r
.62221 .47322 .62806 .47984 .63979 .47619 .63398 .46953 Metetra
.664 .745 .91 r
.63398 .46953 .63979 .47619 .65157 .47253 .64579 .46584 Metetra
.664 .745 .91 r
.64579 .46584 .65157 .47253 .6634 .46885 .65765 .46213 Metetra
.664 .744 .91 r
.65765 .46213 .6634 .46885 .67528 .46516 .66957 .45841 Metetra
.664 .744 .91 r
.66957 .45841 .67528 .46516 .6872 .46145 .68153 .45468 Metetra
.664 .744 .91 r
.68153 .45468 .6872 .46145 .69918 .45773 .69354 .45093 Metetra
.664 .744 .91 r
.69354 .45093 .69918 .45773 .71121 .454 .70561 .44716 Metetra
.663 .744 .91 r
.70561 .44716 .71121 .454 .72329 .45025 .71773 .44339 Metetra
.663 .744 .91 r
.71773 .44339 .72329 .45025 .73543 .44649 .7299 .43959 Metetra
.663 .744 .91 r
.7299 .43959 .73543 .44649 .74761 .44271 .74212 .43579 Metetra
.663 .744 .91 r
.74212 .43579 .74761 .44271 .75985 .43892 .75439 .43197 Metetra
.663 .744 .91 r
.75439 .43197 .75985 .43892 .77214 .43512 .76672 .42813 Metetra
.663 .744 .91 r
.76672 .42813 .77214 .43512 .78448 .4313 .7791 .42429 Metetra
.663 .744 .91 r
.7791 .42429 .78448 .4313 .79688 .42746 .79153 .42042 Metetra
.663 .744 .911 r
.79153 .42042 .79688 .42746 .80933 .42362 .80402 .41654 Metetra
.663 .744 .911 r
.80402 .41654 .80933 .42362 .82183 .41975 .81656 .41265 Metetra
.663 .744 .911 r
.81656 .41265 .82183 .41975 .83439 .41588 .82916 .40875 Metetra
.663 .744 .911 r
.82916 .40875 .83439 .41588 .847 .41199 .84182 .40483 Metetra
.662 .744 .911 r
.84182 .40483 .847 .41199 .85967 .40809 .85453 .4009 Metetra
.662 .744 .911 r
.85453 .4009 .85967 .40809 .8724 .40419 .86729 .39697 Metetra
.662 .744 .911 r
.86729 .39697 .8724 .40419 .88518 .40027 .88012 .39302 Metetra
.661 .744 .911 r
.88012 .39302 .88518 .40027 .89802 .39636 .893 .38908 Metetra
.66 .744 .912 r
.893 .38908 .89802 .39636 .91092 .39246 .90594 .38516 Metetra
.657 .743 .913 r
.90594 .38516 .91092 .39246 .92389 .38864 .91896 .38131 Metetra
.641 .736 .917 r
.91896 .38131 .92389 .38864 .93699 .38529 .9321 .37796 Metetra
.71 .764 .894 r
.34707 .55643 .3537 .56217 .36445 .55743 .35785 .55159 Metetra
.694 .759 .901 r
.35785 .55159 .36445 .55743 .37521 .5532 .36864 .54728 Metetra
.685 .755 .905 r
.36864 .54728 .37521 .5532 .38599 .54923 .37945 .54325 Metetra
.679 .753 .907 r
.37945 .54325 .38599 .54923 .39681 .54542 .3903 .53938 Metetra
.676 .751 .908 r
.3903 .53938 .39681 .54542 .40766 .54169 .40118 .53562 Metetra
.673 .75 .909 r
.40118 .53562 .40766 .54169 .41855 .53803 .4121 .53192 Metetra
.671 .749 .909 r
.4121 .53192 .41855 .53803 .42949 .53441 .42306 .52826 Metetra
.67 .748 .909 r
.42306 .52826 .42949 .53441 .44046 .53082 .43407 .52463 Metetra
.669 .748 .91 r
.43407 .52463 .44046 .53082 .45148 .52724 .44512 .52102 Metetra
.668 .747 .91 r
.44512 .52102 .45148 .52724 .46254 .52367 .45621 .51741 Metetra
.667 .747 .91 r
.45621 .51741 .46254 .52367 .47365 .5201 .46734 .51382 Metetra
.667 .747 .91 r
.46734 .51382 .47365 .5201 .4848 .51654 .47852 .51022 Metetra
.666 .746 .91 r
.47852 .51022 .4848 .51654 .49599 .51297 .48975 .50662 Metetra
.666 .746 .91 r
.48975 .50662 .49599 .51297 .50723 .5094 .50102 .50302 Metetra
.665 .746 .91 r
.50102 .50302 .50723 .5094 .51852 .50583 .51234 .49941 Metetra
.665 .746 .91 r
.51234 .49941 .51852 .50583 .52985 .50224 .5237 .4958 Metetra
.665 .746 .91 r
.5237 .4958 .52985 .50224 .54123 .49865 .53511 .49218 Metetra
.665 .745 .91 r
.53511 .49218 .54123 .49865 .55266 .49505 .54657 .48855 Metetra
.665 .745 .91 r
.54657 .48855 .55266 .49505 .56413 .49144 .55807 .48491 Metetra
.664 .745 .91 r
.55807 .48491 .56413 .49144 .57565 .48782 .56963 .48126 Metetra
.664 .745 .91 r
.56963 .48126 .57565 .48782 .58722 .48419 .58123 .4776 Metetra
.664 .745 .91 r
.58123 .4776 .58722 .48419 .59883 .48054 .59288 .47392 Metetra
.664 .745 .91 r
.59288 .47392 .59883 .48054 .6105 .47688 .60458 .47024 Metetra
.664 .745 .91 r
.60458 .47024 .6105 .47688 .62221 .47322 .61632 .46654 Metetra
.664 .745 .91 r
.61632 .46654 .62221 .47322 .63398 .46953 .62812 .46283 Metetra
.664 .745 .91 r
.62812 .46283 .63398 .46953 .64579 .46584 .63997 .45911 Metetra
.664 .745 .91 r
.63997 .45911 .64579 .46584 .65765 .46213 .65186 .45537 Metetra
.664 .745 .91 r
.65186 .45537 .65765 .46213 .66957 .45841 .66381 .45162 Metetra
.664 .745 .91 r
.66381 .45162 .66957 .45841 .68153 .45468 .67581 .44785 Metetra
.664 .745 .91 r
.67581 .44785 .68153 .45468 .69354 .45093 .68786 .44407 Metetra
.664 .745 .91 r
.68786 .44407 .69354 .45093 .70561 .44716 .69996 .44028 Metetra
.663 .745 .91 r
.69996 .44028 .70561 .44716 .71773 .44339 .71212 .43647 Metetra
.663 .745 .91 r
.71212 .43647 .71773 .44339 .7299 .43959 .72432 .43265 Metetra
.663 .744 .91 r
.72432 .43265 .7299 .43959 .74212 .43579 .73658 .42882 Metetra
.663 .744 .911 r
.73658 .42882 .74212 .43579 .75439 .43197 .74889 .42497 Metetra
.663 .744 .911 r
.74889 .42497 .75439 .43197 .76672 .42813 .76126 .4211 Metetra
.663 .744 .911 r
.76126 .4211 .76672 .42813 .7791 .42429 .77367 .41722 Metetra
.663 .744 .911 r
.77367 .41722 .7791 .42429 .79153 .42042 .78615 .41333 Metetra
.663 .744 .911 r
.78615 .41333 .79153 .42042 .80402 .41654 .79867 .40942 Metetra
.663 .744 .911 r
.79867 .40942 .80402 .41654 .81656 .41265 .81126 .4055 Metetra
.663 .744 .911 r
.81126 .4055 .81656 .41265 .82916 .40875 .82389 .40157 Metetra
.663 .744 .911 r
.82389 .40157 .82916 .40875 .84182 .40483 .83659 .39762 Metetra
.662 .744 .911 r
.83659 .39762 .84182 .40483 .85453 .4009 .84934 .39366 Metetra
.662 .744 .911 r
.84934 .39366 .85453 .4009 .86729 .39697 .86214 .38969 Metetra
.662 .744 .911 r
.86214 .38969 .86729 .39697 .88012 .39302 .87501 .38572 Metetra
.661 .744 .912 r
.87501 .38572 .88012 .39302 .893 .38908 .88794 .38175 Metetra
.66 .744 .912 r
.88794 .38175 .893 .38908 .90594 .38516 .90092 .3778 Metetra
.657 .743 .913 r
.90092 .3778 .90594 .38516 .91896 .38131 .91398 .37393 Metetra
.64 .735 .918 r
.91398 .37393 .91896 .38131 .9321 .37796 .92717 .37059 Metetra
.713 .765 .894 r
.34038 .55066 .34707 .55643 .35785 .55159 .3512 .54572 Metetra
.696 .76 .901 r
.3512 .54572 .35785 .55159 .36864 .54728 .36202 .54133 Metetra
.686 .756 .905 r
.36202 .54133 .36864 .54728 .37945 .54325 .37286 .53724 Metetra
.68 .754 .907 r
.37286 .53724 .37945 .54325 .3903 .53938 .38374 .53332 Metetra
.676 .752 .908 r
.38374 .53332 .3903 .53938 .40118 .53562 .39465 .52951 Metetra
.673 .751 .909 r
.39465 .52951 .40118 .53562 .4121 .53192 .4056 .52577 Metetra
.671 .75 .909 r
.4056 .52577 .4121 .53192 .42306 .52826 .41659 .52207 Metetra
.67 .749 .91 r
.41659 .52207 .42306 .52826 .43407 .52463 .42763 .5184 Metetra
.669 .748 .91 r
.42763 .5184 .43407 .52463 .44512 .52102 .43871 .51475 Metetra
.668 .748 .91 r
.43871 .51475 .44512 .52102 .45621 .51741 .44983 .51112 Metetra
.667 .747 .91 r
.44983 .51112 .45621 .51741 .46734 .51382 .46099 .50749 Metetra
.667 .747 .91 r
.46099 .50749 .46734 .51382 .47852 .51022 .4722 .50386 Metetra
.666 .747 .91 r
.4722 .50386 .47852 .51022 .48975 .50662 .48346 .50023 Metetra
.666 .746 .91 r
.48346 .50023 .48975 .50662 .50102 .50302 .49476 .4966 Metetra
.666 .746 .91 r
.49476 .4966 .50102 .50302 .51234 .49941 .50611 .49296 Metetra
.665 .746 .91 r
.50611 .49296 .51234 .49941 .5237 .4958 .5175 .48932 Metetra
.665 .746 .91 r
.5175 .48932 .5237 .4958 .53511 .49218 .52894 .48567 Metetra
.665 .746 .91 r
.52894 .48567 .53511 .49218 .54657 .48855 .54043 .48201 Metetra
.665 .745 .91 r
.54043 .48201 .54657 .48855 .55807 .48491 .55197 .47834 Metetra
.665 .745 .91 r
.55197 .47834 .55807 .48491 .56963 .48126 .56356 .47466 Metetra
.664 .745 .91 r
.56356 .47466 .56963 .48126 .58123 .4776 .57519 .47096 Metetra
.664 .745 .91 r
.57519 .47096 .58123 .4776 .59288 .47392 .58687 .46726 Metetra
.664 .745 .91 r
.58687 .46726 .59288 .47392 .60458 .47024 .5986 .46355 Metetra
.664 .745 .91 r
.5986 .46355 .60458 .47024 .61632 .46654 .61039 .45982 Metetra
.664 .745 .91 r
.61039 .45982 .61632 .46654 .62812 .46283 .62222 .45608 Metetra
.664 .745 .91 r
.62222 .45608 .62812 .46283 .63997 .45911 .6341 .45232 Metetra
.664 .745 .91 r
.6341 .45232 .63997 .45911 .65186 .45537 .64603 .44856 Metetra
.664 .745 .911 r
.64603 .44856 .65186 .45537 .66381 .45162 .65801 .44478 Metetra
.664 .745 .911 r
.65801 .44478 .66381 .45162 .67581 .44785 .67005 .44098 Metetra
.664 .745 .911 r
.67005 .44098 .67581 .44785 .68786 .44407 .68213 .43717 Metetra
.664 .745 .911 r
.68213 .43717 .68786 .44407 .69996 .44028 .69427 .43335 Metetra
.663 .745 .911 r
.69427 .43335 .69996 .44028 .71212 .43647 .70646 .42951 Metetra
.663 .745 .911 r
.70646 .42951 .71212 .43647 .72432 .43265 .7187 .42566 Metetra
.663 .745 .911 r
.7187 .42566 .72432 .43265 .73658 .42882 .731 .42179 Metetra
.663 .745 .911 r
.731 .42179 .73658 .42882 .74889 .42497 .74335 .41791 Metetra
.663 .745 .911 r
.74335 .41791 .74889 .42497 .76126 .4211 .75575 .41402 Metetra
.663 .745 .911 r
.75575 .41402 .76126 .4211 .77367 .41722 .76821 .41011 Metetra
.663 .745 .911 r
.76821 .41011 .77367 .41722 .78615 .41333 .78072 .40618 Metetra
.663 .745 .911 r
.78072 .40618 .78615 .41333 .79867 .40942 .79328 .40225 Metetra
.663 .745 .911 r
.79328 .40225 .79867 .40942 .81126 .4055 .8059 .39829 Metetra
.663 .745 .911 r
.8059 .39829 .81126 .4055 .82389 .40157 .81858 .39433 Metetra
.663 .745 .911 r
.81858 .39433 .82389 .40157 .83659 .39762 .83132 .39035 Metetra
.662 .744 .911 r
.83132 .39035 .83659 .39762 .84934 .39366 .84411 .38636 Metetra
.662 .744 .911 r
.84411 .38636 .84934 .39366 .86214 .38969 .85696 .38236 Metetra
.662 .744 .911 r
.85696 .38236 .86214 .38969 .87501 .38572 .86986 .37836 Metetra
.661 .744 .912 r
.86986 .37836 .87501 .38572 .88794 .38175 .88283 .37436 Metetra
.66 .744 .912 r
.88283 .37436 .88794 .38175 .90092 .3778 .89586 .37039 Metetra
.657 .743 .913 r
.89586 .37039 .90092 .3778 .91398 .37393 .90896 .36649 Metetra
.638 .735 .919 r
.90896 .36649 .91398 .37393 .92717 .37059 .9222 .36317 Metetra
.715 .766 .893 r
.33364 .54489 .34038 .55066 .3512 .54572 .34449 .53982 Metetra
.698 .761 .901 r
.34449 .53982 .3512 .54572 .36202 .54133 .35535 .53535 Metetra
.687 .757 .904 r
.35535 .53535 .36202 .54133 .37286 .53724 .36622 .5312 Metetra
.681 .754 .907 r
.36622 .5312 .37286 .53724 .38374 .53332 .37713 .52722 Metetra
.677 .752 .908 r
.37713 .52722 .38374 .53332 .39465 .52951 .38807 .52336 Metetra
.674 .751 .909 r
.38807 .52336 .39465 .52951 .4056 .52577 .39905 .51958 Metetra
.672 .75 .909 r
.39905 .51958 .4056 .52577 .41659 .52207 .41007 .51584 Metetra
.67 .749 .91 r
.41007 .51584 .41659 .52207 .42763 .5184 .42114 .51214 Metetra
.669 .749 .91 r
.42114 .51214 .42763 .5184 .43871 .51475 .43225 .50845 Metetra
.668 .748 .91 r
.43225 .50845 .43871 .51475 .44983 .51112 .4434 .50478 Metetra
.668 .748 .91 r
.4434 .50478 .44983 .51112 .46099 .50749 .45459 .50112 Metetra
.667 .747 .91 r
.45459 .50112 .46099 .50749 .4722 .50386 .46583 .49746 Metetra
.666 .747 .91 r
.46583 .49746 .4722 .50386 .48346 .50023 .47712 .4938 Metetra
.666 .747 .91 r
.47712 .4938 .48346 .50023 .49476 .4966 .48845 .49013 Metetra
.666 .746 .91 r
.48845 .49013 .49476 .4966 .50611 .49296 .49983 .48647 Metetra
.665 .746 .91 r
.49983 .48647 .50611 .49296 .5175 .48932 .51126 .48279 Metetra
.665 .746 .911 r
.51126 .48279 .5175 .48932 .52894 .48567 .52273 .47911 Metetra
.665 .746 .911 r
.52273 .47911 .52894 .48567 .54043 .48201 .53425 .47542 Metetra
.665 .746 .911 r
.53425 .47542 .54043 .48201 .55197 .47834 .54582 .47172 Metetra
.665 .746 .911 r
.54582 .47172 .55197 .47834 .56356 .47466 .55744 .46801 Metetra
.664 .746 .911 r
.55744 .46801 .56356 .47466 .57519 .47096 .56911 .46429 Metetra
.664 .745 .911 r
.56911 .46429 .57519 .47096 .58687 .46726 .58082 .46055 Metetra
.664 .745 .911 r
.58082 .46055 .58687 .46726 .5986 .46355 .59259 .45681 Metetra
.664 .745 .911 r
.59259 .45681 .5986 .46355 .61039 .45982 .6044 .45305 Metetra
.664 .745 .911 r
.6044 .45305 .61039 .45982 .62222 .45608 .61627 .44928 Metetra
.664 .745 .911 r
.61627 .44928 .62222 .45608 .6341 .45232 .62818 .44549 Metetra
.664 .745 .911 r
.62818 .44549 .6341 .45232 .64603 .44856 .64015 .4417 Metetra
.664 .745 .911 r
.64015 .4417 .64603 .44856 .65801 .44478 .65217 .43789 Metetra
.664 .745 .911 r
.65217 .43789 .65801 .44478 .67005 .44098 .66424 .43406 Metetra
.664 .745 .911 r
.66424 .43406 .67005 .44098 .68213 .43717 .67636 .43022 Metetra
.664 .745 .911 r
.67636 .43022 .68213 .43717 .69427 .43335 .68853 .42637 Metetra
.663 .745 .911 r
.68853 .42637 .69427 .43335 .70646 .42951 .70076 .4225 Metetra
.663 .745 .911 r
.70076 .4225 .70646 .42951 .7187 .42566 .71304 .41862 Metetra
.663 .745 .911 r
.71304 .41862 .7187 .42566 .731 .42179 .72537 .41472 Metetra
.663 .745 .911 r
.72537 .41472 .731 .42179 .74335 .41791 .73776 .41081 Metetra
.663 .745 .911 r
.73776 .41081 .74335 .41791 .75575 .41402 .7502 .40688 Metetra
.663 .745 .911 r
.7502 .40688 .75575 .41402 .76821 .41011 .76269 .40294 Metetra
.663 .745 .911 r
.76269 .40294 .76821 .41011 .78072 .40618 .77524 .39899 Metetra
.663 .745 .911 r
.77524 .39899 .78072 .40618 .79328 .40225 .78785 .39502 Metetra
.663 .745 .911 r
.78785 .39502 .79328 .40225 .8059 .39829 .80051 .39104 Metetra
.663 .745 .911 r
.80051 .39104 .8059 .39829 .81858 .39433 .81323 .38704 Metetra
.662 .745 .911 r
.81323 .38704 .81858 .39433 .83132 .39035 .826 .38303 Metetra
.662 .745 .911 r
.826 .38303 .83132 .39035 .84411 .38636 .83884 .37901 Metetra
.662 .745 .911 r
.83884 .37901 .84411 .38636 .85696 .38236 .85173 .37498 Metetra
.662 .745 .912 r
.85173 .37498 .85696 .38236 .86986 .37836 .86467 .37095 Metetra
.661 .744 .912 r
.86467 .37095 .86986 .37836 .88283 .37436 .87768 .36692 Metetra
.66 .744 .912 r
.87768 .36692 .88283 .37436 .89586 .37039 .89076 .36292 Metetra
.656 .743 .914 r
.89076 .36292 .89586 .37039 .90896 .36649 .9039 .359 Metetra
.637 .735 .919 r
.9039 .359 .90896 .36649 .9222 .36317 .91719 .35569 Metetra
.718 .768 .892 r
.32685 .53909 .33364 .54489 .34449 .53982 .33773 .53391 Metetra
.699 .762 .9 r
.33773 .53391 .34449 .53982 .35535 .53535 .34862 .52935 Metetra
.689 .758 .904 r
.34862 .52935 .35535 .53535 .36622 .5312 .35953 .52513 Metetra
.682 .755 .907 r
.35953 .52513 .36622 .5312 .37713 .52722 .37047 .5211 Metetra
.678 .753 .908 r
.37047 .5211 .37713 .52722 .38807 .52336 .38144 .51719 Metetra
.675 .752 .909 r
.38144 .51719 .38807 .52336 .39905 .51958 .39245 .51336 Metetra
.672 .751 .909 r
.39245 .51336 .39905 .51958 .41007 .51584 .4035 .50958 Metetra
.671 .75 .91 r
.4035 .50958 .41007 .51584 .42114 .51214 .4146 .50583 Metetra
.67 .749 .91 r
.4146 .50583 .42114 .51214 .43225 .50845 .42573 .50211 Metetra
.669 .748 .91 r
.42573 .50211 .43225 .50845 .4434 .50478 .43692 .49841 Metetra
.668 .748 .91 r
.43692 .49841 .4434 .50478 .45459 .50112 .44814 .49471 Metetra
.667 .748 .91 r
.44814 .49471 .45459 .50112 .46583 .49746 .45941 .49102 Metetra
.667 .747 .911 r
.45941 .49102 .46583 .49746 .47712 .4938 .47073 .48732 Metetra
.666 .747 .911 r
.47073 .48732 .47712 .4938 .48845 .49013 .48209 .48363 Metetra
.666 .747 .911 r
.48209 .48363 .48845 .49013 .49983 .48647 .4935 .47993 Metetra
.666 .746 .911 r
.4935 .47993 .49983 .48647 .51126 .48279 .50496 .47622 Metetra
.665 .746 .911 r
.50496 .47622 .51126 .48279 .52273 .47911 .51647 .47251 Metetra
.665 .746 .911 r
.51647 .47251 .52273 .47911 .53425 .47542 .52802 .46879 Metetra
.665 .746 .911 r
.52802 .46879 .53425 .47542 .54582 .47172 .53962 .46505 Metetra
.665 .746 .911 r
.53962 .46505 .54582 .47172 .55744 .46801 .55127 .46131 Metetra
.665 .746 .911 r
.55127 .46131 .55744 .46801 .56911 .46429 .56297 .45756 Metetra
.664 .746 .911 r
.56297 .45756 .56911 .46429 .58082 .46055 .57472 .4538 Metetra
.664 .746 .911 r
.57472 .4538 .58082 .46055 .59259 .45681 .58652 .45002 Metetra
.664 .745 .911 r
.58652 .45002 .59259 .45681 .6044 .45305 .59837 .44623 Metetra
.664 .745 .911 r
.59837 .44623 .6044 .45305 .61627 .44928 .61027 .44243 Metetra
.664 .745 .911 r
.61027 .44243 .61627 .44928 .62818 .44549 .62222 .43862 Metetra
.664 .745 .911 r
.62222 .43862 .62818 .44549 .64015 .4417 .63422 .43479 Metetra
.664 .745 .911 r
.63422 .43479 .64015 .4417 .65217 .43789 .64627 .43095 Metetra
.664 .745 .911 r
.64627 .43095 .65217 .43789 .66424 .43406 .65838 .42709 Metetra
.664 .745 .911 r
.65838 .42709 .66424 .43406 .67636 .43022 .67054 .42322 Metetra
.664 .745 .911 r
.67054 .42322 .67636 .43022 .68853 .42637 .68275 .41934 Metetra
.663 .745 .911 r
.68275 .41934 .68853 .42637 .70076 .4225 .69501 .41544 Metetra
.663 .745 .911 r
.69501 .41544 .70076 .4225 .71304 .41862 .70733 .41153 Metetra
.663 .745 .911 r
.70733 .41153 .71304 .41862 .72537 .41472 .7197 .4076 Metetra
.663 .745 .911 r
.7197 .4076 .72537 .41472 .73776 .41081 .73212 .40366 Metetra
.663 .745 .911 r
.73212 .40366 .73776 .41081 .7502 .40688 .7446 .3997 Metetra
.663 .745 .911 r
.7446 .3997 .7502 .40688 .76269 .40294 .75714 .39573 Metetra
.663 .745 .911 r
.75714 .39573 .76269 .40294 .77524 .39899 .76973 .39174 Metetra
.663 .745 .911 r
.76973 .39174 .77524 .39899 .78785 .39502 .78237 .38774 Metetra
.663 .745 .911 r
.78237 .38774 .78785 .39502 .80051 .39104 .79507 .38373 Metetra
.663 .745 .911 r
.79507 .38373 .80051 .39104 .81323 .38704 .80783 .3797 Metetra
.662 .745 .911 r
.80783 .3797 .81323 .38704 .826 .38303 .82065 .37566 Metetra
.662 .745 .911 r
.82065 .37566 .826 .38303 .83884 .37901 .83352 .37161 Metetra
.662 .745 .912 r
.83352 .37161 .83884 .37901 .85173 .37498 .84645 .36755 Metetra
.661 .745 .912 r
.84645 .36755 .85173 .37498 .86467 .37095 .85944 .36349 Metetra
.661 .745 .912 r
.85944 .36349 .86467 .37095 .87768 .36692 .8725 .35943 Metetra
.659 .744 .913 r
.8725 .35943 .87768 .36692 .89076 .36292 .88561 .3554 Metetra
.656 .743 .914 r
.88561 .3554 .89076 .36292 .9039 .359 .8988 .35146 Metetra
.635 .734 .92 r
.8988 .35146 .9039 .359 .91719 .35569 .91214 .34817 Metetra
.721 .769 .891 r
.32 .53329 .32685 .53909 .33773 .53391 .33092 .52797 Metetra
.701 .763 .9 r
.33092 .52797 .33773 .53391 .34862 .52935 .34185 .52332 Metetra
.69 .759 .904 r
.34185 .52332 .34862 .52935 .35953 .52513 .35278 .51903 Metetra
.683 .756 .907 r
.35278 .51903 .35953 .52513 .37047 .5211 .36375 .51494 Metetra
.679 .754 .908 r
.36375 .51494 .37047 .5211 .38144 .51719 .37476 .51098 Metetra
.675 .752 .909 r
.37476 .51098 .38144 .51719 .39245 .51336 .3858 .5071 Metetra
.673 .751 .909 r
.3858 .5071 .39245 .51336 .4035 .50958 .39688 .50328 Metetra
.671 .75 .91 r
.39688 .50328 .4035 .50958 .4146 .50583 .40801 .4995 Metetra
.67 .749 .91 r
.40801 .4995 .4146 .50583 .42573 .50211 .41917 .49574 Metetra
.669 .749 .91 r
.41917 .49574 .42573 .50211 .43692 .49841 .43038 .49199 Metetra
.668 .748 .91 r
.43038 .49199 .43692 .49841 .44814 .49471 .44164 .48826 Metetra
.667 .748 .911 r
.44164 .48826 .44814 .49471 .45941 .49102 .45294 .48453 Metetra
.667 .748 .911 r
.45294 .48453 .45941 .49102 .47073 .48732 .46429 .48081 Metetra
.666 .747 .911 r
.46429 .48081 .47073 .48732 .48209 .48363 .47569 .47708 Metetra
.666 .747 .911 r
.47569 .47708 .48209 .48363 .4935 .47993 .48713 .47335 Metetra
.666 .747 .911 r
.48713 .47335 .4935 .47993 .50496 .47622 .49862 .46961 Metetra
.665 .747 .911 r
.49862 .46961 .50496 .47622 .51647 .47251 .51016 .46586 Metetra
.665 .746 .911 r
.51016 .46586 .51647 .47251 .52802 .46879 .52174 .46211 Metetra
.665 .746 .911 r
.52174 .46211 .52802 .46879 .53962 .46505 .53338 .45835 Metetra
.665 .746 .911 r
.53338 .45835 .53962 .46505 .55127 .46131 .54506 .45457 Metetra
.665 .746 .911 r
.54506 .45457 .55127 .46131 .56297 .45756 .55679 .45079 Metetra
.664 .746 .911 r
.55679 .45079 .56297 .45756 .57472 .4538 .56857 .447 Metetra
.664 .746 .911 r
.56857 .447 .57472 .4538 .58652 .45002 .58041 .44319 Metetra
.664 .746 .911 r
.58041 .44319 .58652 .45002 .59837 .44623 .59229 .43937 Metetra
.664 .746 .911 r
.59229 .43937 .59837 .44623 .61027 .44243 .60422 .43554 Metetra
.664 .746 .911 r
.60422 .43554 .61027 .44243 .62222 .43862 .61621 .43169 Metetra
.664 .746 .911 r
.61621 .43169 .62222 .43862 .63422 .43479 .62825 .42783 Metetra
.664 .745 .911 r
.62825 .42783 .63422 .43479 .64627 .43095 .64034 .42396 Metetra
.664 .745 .911 r
.64034 .42396 .64627 .43095 .65838 .42709 .65248 .42007 Metetra
.664 .745 .911 r
.65248 .42007 .65838 .42709 .67054 .42322 .66467 .41617 Metetra
.664 .745 .911 r
.66467 .41617 .67054 .42322 .68275 .41934 .67692 .41226 Metetra
.663 .745 .911 r
.67692 .41226 .68275 .41934 .69501 .41544 .68922 .40833 Metetra
.663 .745 .911 r
.68922 .40833 .69501 .41544 .70733 .41153 .70157 .40438 Metetra
.663 .745 .911 r
.70157 .40438 .70733 .41153 .7197 .4076 .71398 .40042 Metetra
.663 .745 .911 r
.71398 .40042 .7197 .4076 .73212 .40366 .72644 .39645 Metetra
.663 .745 .911 r
.72644 .39645 .73212 .40366 .7446 .3997 .73896 .39246 Metetra
.663 .745 .911 r
.73896 .39246 .7446 .3997 .75714 .39573 .75153 .38846 Metetra
.663 .745 .911 r
.75153 .38846 .75714 .39573 .76973 .39174 .76416 .38444 Metetra
.663 .745 .911 r
.76416 .38444 .76973 .39174 .78237 .38774 .77685 .38041 Metetra
.663 .745 .911 r
.77685 .38041 .78237 .38774 .79507 .38373 .78959 .37636 Metetra
.663 .745 .911 r
.78959 .37636 .79507 .38373 .80783 .3797 .80239 .3723 Metetra
.662 .745 .912 r
.80239 .3723 .80783 .3797 .82065 .37566 .81525 .36823 Metetra
.662 .745 .912 r
.81525 .36823 .82065 .37566 .83352 .37161 .82816 .36415 Metetra
.662 .745 .912 r
.82816 .36415 .83352 .37161 .84645 .36755 .84114 .36006 Metetra
.661 .745 .912 r
.84114 .36006 .84645 .36755 .85944 .36349 .85417 .35597 Metetra
.661 .745 .912 r
.85417 .35597 .85944 .36349 .8725 .35943 .86727 .35188 Metetra
.659 .744 .913 r
.86727 .35188 .8725 .35943 .88561 .3554 .88043 .34783 Metetra
.655 .743 .914 r
.88043 .34783 .88561 .3554 .8988 .35146 .89366 .34387 Metetra
.633 .734 .92 r
.89366 .34387 .8988 .35146 .91214 .34817 .90705 .34059 Metetra
.724 .771 .89 r
.31309 .52748 .32 .53329 .33092 .52797 .32406 .52203 Metetra
.703 .764 .899 r
.32406 .52203 .33092 .52797 .34185 .52332 .33501 .51728 Metetra
.692 .76 .904 r
.33501 .51728 .34185 .52332 .35278 .51903 .34599 .5129 Metetra
.684 .757 .906 r
.34599 .5129 .35278 .51903 .36375 .51494 .35699 .50875 Metetra
.679 .755 .908 r
.35699 .50875 .36375 .51494 .37476 .51098 .36802 .50474 Metetra
.676 .753 .909 r
.36802 .50474 .37476 .51098 .3858 .5071 .37909 .50081 Metetra
.674 .752 .91 r
.37909 .50081 .3858 .5071 .39688 .50328 .39021 .49695 Metetra
.672 .751 .91 r
.39021 .49695 .39688 .50328 .40801 .4995 .40136 .49312 Metetra
.67 .75 .91 r
.40136 .49312 .40801 .4995 .41917 .49574 .41256 .48932 Metetra
.669 .749 .91 r
.41256 .48932 .41917 .49574 .43038 .49199 .4238 .48554 Metetra
.668 .749 .911 r
.4238 .48554 .43038 .49199 .44164 .48826 .43509 .48177 Metetra
.668 .748 .911 r
.43509 .48177 .44164 .48826 .45294 .48453 .44642 .47801 Metetra
.667 .748 .911 r
.44642 .47801 .45294 .48453 .46429 .48081 .4578 .47425 Metetra
.667 .748 .911 r
.4578 .47425 .46429 .48081 .47569 .47708 .46923 .47049 Metetra
.666 .747 .911 r
.46923 .47049 .47569 .47708 .48713 .47335 .4807 .46672 Metetra
.666 .747 .911 r
.4807 .46672 .48713 .47335 .49862 .46961 .49222 .46295 Metetra
.665 .747 .911 r
.49222 .46295 .49862 .46961 .51016 .46586 .50379 .45917 Metetra
.665 .747 .911 r
.50379 .45917 .51016 .46586 .52174 .46211 .51541 .45539 Metetra
.665 .747 .911 r
.51541 .45539 .52174 .46211 .53338 .45835 .52708 .45159 Metetra
.665 .746 .911 r
.52708 .45159 .53338 .45835 .54506 .45457 .53879 .44779 Metetra
.665 .746 .911 r
.53879 .44779 .54506 .45457 .55679 .45079 .55056 .44398 Metetra
.664 .746 .911 r
.55056 .44398 .55679 .45079 .56857 .447 .56238 .44015 Metetra
.664 .746 .911 r
.56238 .44015 .56857 .447 .58041 .44319 .57424 .43631 Metetra
.664 .746 .911 r
.57424 .43631 .58041 .44319 .59229 .43937 .58616 .43246 Metetra
.664 .746 .911 r
.58616 .43246 .59229 .43937 .60422 .43554 .59813 .4286 Metetra
.664 .746 .911 r
.59813 .4286 .60422 .43554 .61621 .43169 .61015 .42472 Metetra
.664 .746 .911 r
.61015 .42472 .61621 .43169 .62825 .42783 .62222 .42083 Metetra
.664 .746 .911 r
.62222 .42083 .62825 .42783 .64034 .42396 .63435 .41693 Metetra
.664 .746 .911 r
.63435 .41693 .64034 .42396 .65248 .42007 .64653 .41301 Metetra
.664 .746 .911 r
.64653 .41301 .65248 .42007 .66467 .41617 .65876 .40907 Metetra
.664 .746 .911 r
.65876 .40907 .66467 .41617 .67692 .41226 .67104 .40513 Metetra
.663 .746 .911 r
.67104 .40513 .67692 .41226 .68922 .40833 .68338 .40117 Metetra
.663 .746 .911 r
.68338 .40117 .68922 .40833 .70157 .40438 .69577 .39719 Metetra
.663 .745 .911 r
.69577 .39719 .70157 .40438 .71398 .40042 .70822 .3932 Metetra
.663 .745 .911 r
.70822 .3932 .71398 .40042 .72644 .39645 .72072 .38919 Metetra
.663 .745 .911 r
.72072 .38919 .72644 .39645 .73896 .39246 .73327 .38517 Metetra
.663 .745 .911 r
.73327 .38517 .73896 .39246 .75153 .38846 .74589 .38114 Metetra
.663 .745 .911 r
.74589 .38114 .75153 .38846 .76416 .38444 .75856 .37709 Metetra
.663 .745 .912 r
.75856 .37709 .76416 .38444 .77685 .38041 .77128 .37302 Metetra
.663 .745 .912 r
.77128 .37302 .77685 .38041 .78959 .37636 .78406 .36895 Metetra
.662 .745 .912 r
.78406 .36895 .78959 .37636 .80239 .3723 .7969 .36485 Metetra
.662 .745 .912 r
.7969 .36485 .80239 .3723 .81525 .36823 .8098 .36075 Metetra
.662 .745 .912 r
.8098 .36075 .81525 .36823 .82816 .36415 .82276 .35664 Metetra
.662 .745 .912 r
.82276 .35664 .82816 .36415 .84114 .36006 .83578 .35252 Metetra
.661 .745 .912 r
.83578 .35252 .84114 .36006 .85417 .35597 .84885 .3484 Metetra
.66 .745 .913 r
.84885 .3484 .85417 .35597 .86727 .35188 .86199 .34428 Metetra
.659 .744 .913 r
.86199 .34428 .86727 .35188 .88043 .34783 .8752 .3402 Metetra
.655 .743 .915 r
.8752 .3402 .88043 .34783 .89366 .34387 .88848 .33622 Metetra
.631 .733 .921 r
.88848 .33622 .89366 .34387 .90705 .34059 .90191 .33297 Metetra
.727 .772 .889 r
.30613 .52167 .31309 .52748 .32406 .52203 .31713 .51606 Metetra
.706 .766 .899 r
.31713 .51606 .32406 .52203 .33501 .51728 .32813 .51121 Metetra
.693 .761 .904 r
.32813 .51121 .33501 .51728 .34599 .5129 .33913 .50676 Metetra
.686 .758 .906 r
.33913 .50676 .34599 .5129 .35699 .50875 .35017 .50254 Metetra
.68 .755 .908 r
.35017 .50254 .35699 .50875 .36802 .50474 .36123 .49847 Metetra
.677 .754 .909 r
.36123 .49847 .36802 .50474 .37909 .50081 .37234 .49449 Metetra
.674 .752 .91 r
.37234 .49449 .37909 .50081 .39021 .49695 .38348 .49058 Metetra
.672 .751 .91 r
.38348 .49058 .39021 .49695 .40136 .49312 .39466 .48671 Metetra
.671 .751 .91 r
.39466 .48671 .40136 .49312 .41256 .48932 .40589 .48287 Metetra
.67 .75 .911 r
.40589 .48287 .41256 .48932 .4238 .48554 .41717 .47905 Metetra
.669 .749 .911 r
.41717 .47905 .4238 .48554 .43509 .48177 .42849 .47525 Metetra
.668 .749 .911 r
.42849 .47525 .43509 .48177 .44642 .47801 .43985 .47145 Metetra
.667 .748 .911 r
.43985 .47145 .44642 .47801 .4578 .47425 .45126 .46765 Metetra
.667 .748 .911 r
.45126 .46765 .4578 .47425 .46923 .47049 .46272 .46386 Metetra
.666 .748 .911 r
.46272 .46386 .46923 .47049 .4807 .46672 .47422 .46006 Metetra
.666 .747 .911 r
.47422 .46006 .4807 .46672 .49222 .46295 .48578 .45625 Metetra
.666 .747 .911 r
.48578 .45625 .49222 .46295 .50379 .45917 .49738 .45244 Metetra
.665 .747 .911 r
.49738 .45244 .50379 .45917 .51541 .45539 .50903 .44862 Metetra
.665 .747 .911 r
.50903 .44862 .51541 .45539 .52708 .45159 .52073 .4448 Metetra
.665 .747 .911 r
.52073 .4448 .52708 .45159 .53879 .44779 .53248 .44096 Metetra
.665 .747 .911 r
.53248 .44096 .53879 .44779 .55056 .44398 .54428 .43711 Metetra
.665 .746 .911 r
.54428 .43711 .55056 .44398 .56238 .44015 .55613 .43326 Metetra
.664 .746 .911 r
.55613 .43326 .56238 .44015 .57424 .43631 .56803 .42939 Metetra
.664 .746 .911 r
.56803 .42939 .57424 .43631 .58616 .43246 .57998 .4255 Metetra
.664 .746 .911 r
.57998 .4255 .58616 .43246 .59813 .4286 .59199 .42161 Metetra
.664 .746 .911 r
.59199 .42161 .59813 .4286 .61015 .42472 .60404 .4177 Metetra
.664 .746 .911 r
.60404 .4177 .61015 .42472 .62222 .42083 .61615 .41378 Metetra
.664 .746 .911 r
.61615 .41378 .62222 .42083 .63435 .41693 .62831 .40984 Metetra
.664 .746 .911 r
.62831 .40984 .63435 .41693 .64653 .41301 .64053 .40589 Metetra
.664 .746 .911 r
.64053 .40589 .64653 .41301 .65876 .40907 .65279 .40193 Metetra
.664 .746 .911 r
.65279 .40193 .65876 .40907 .67104 .40513 .66512 .39795 Metetra
.663 .746 .911 r
.66512 .39795 .67104 .40513 .68338 .40117 .67749 .39395 Metetra
.663 .746 .911 r
.67749 .39395 .68338 .40117 .69577 .39719 .68992 .38995 Metetra
.663 .746 .911 r
.68992 .38995 .69577 .39719 .70822 .3932 .70241 .38592 Metetra
.663 .746 .912 r
.70241 .38592 .70822 .3932 .72072 .38919 .71495 .38188 Metetra
.663 .746 .912 r
.71495 .38188 .72072 .38919 .73327 .38517 .72754 .37783 Metetra
.663 .746 .912 r
.72754 .37783 .73327 .38517 .74589 .38114 .74019 .37376 Metetra
.663 .746 .912 r
.74019 .37376 .74589 .38114 .75856 .37709 .7529 .36968 Metetra
.663 .746 .912 r
.7529 .36968 .75856 .37709 .77128 .37302 .76567 .36559 Metetra
.663 .746 .912 r
.76567 .36559 .77128 .37302 .78406 .36895 .77849 .36148 Metetra
.662 .746 .912 r
.77849 .36148 .78406 .36895 .7969 .36485 .79137 .35735 Metetra
.662 .746 .912 r
.79137 .35735 .7969 .36485 .8098 .36075 .80431 .35322 Metetra
.662 .746 .912 r
.80431 .35322 .8098 .36075 .82276 .35664 .81731 .34907 Metetra
.662 .745 .912 r
.81731 .34907 .82276 .35664 .83578 .35252 .83037 .34492 Metetra
.661 .745 .913 r
.83037 .34492 .83578 .35252 .84885 .3484 .84349 .34077 Metetra
.66 .745 .913 r
.84349 .34077 .84885 .3484 .86199 .34428 .85668 .33663 Metetra
.659 .745 .914 r
.85668 .33663 .86199 .34428 .8752 .3402 .86993 .33252 Metetra
.654 .743 .915 r
.86993 .33252 .8752 .3402 .88848 .33622 .88325 .32852 Metetra
.629 .733 .922 r
.88325 .32852 .88848 .33622 .90191 .33297 .89674 .3253 Metetra
.73 .774 .888 r
.2991 .51585 .30613 .52167 .31713 .51606 .31015 .51009 Metetra
.708 .767 .898 r
.31015 .51009 .31713 .51606 .32813 .51121 .32118 .50512 Metetra
.695 .762 .903 r
.32118 .50512 .32813 .51121 .33913 .50676 .33222 .50058 Metetra
.687 .759 .906 r
.33222 .50058 .33913 .50676 .35017 .50254 .34329 .4963 Metetra
.681 .756 .908 r
.34329 .4963 .35017 .50254 .36123 .49847 .35439 .49217 Metetra
.678 .755 .909 r
.35439 .49217 .36123 .49847 .37234 .49449 .36552 .48814 Metetra
.675 .753 .91 r
.36552 .48814 .37234 .49449 .38348 .49058 .3767 .48418 Metetra
.673 .752 .91 r
.3767 .48418 .38348 .49058 .39466 .48671 .38791 .48027 Metetra
.671 .751 .911 r
.38791 .48027 .39466 .48671 .40589 .48287 .39917 .47639 Metetra
.67 .75 .911 r
.39917 .47639 .40589 .48287 .41717 .47905 .41048 .47253 Metetra
.669 .75 .911 r
.41048 .47253 .41717 .47905 .42849 .47525 .42183 .46868 Metetra
.668 .749 .911 r
.42183 .46868 .42849 .47525 .43985 .47145 .43322 .46485 Metetra
.667 .749 .911 r
.43322 .46485 .43985 .47145 .45126 .46765 .44467 .46101 Metetra
.667 .748 .911 r
.44467 .46101 .45126 .46765 .46272 .46386 .45616 .45718 Metetra
.666 .748 .911 r
.45616 .45718 .46272 .46386 .47422 .46006 .4677 .45335 Metetra
.666 .748 .911 r
.4677 .45335 .47422 .46006 .48578 .45625 .47928 .44951 Metetra
.666 .748 .911 r
.47928 .44951 .48578 .45625 .49738 .45244 .49092 .44567 Metetra
.665 .747 .911 r
.49092 .44567 .49738 .45244 .50903 .44862 .5026 .44182 Metetra
.665 .747 .911 r
.5026 .44182 .50903 .44862 .52073 .4448 .51433 .43796 Metetra
.665 .747 .911 r
.51433 .43796 .52073 .4448 .53248 .44096 .52612 .43409 Metetra
.665 .747 .911 r
.52612 .43409 .53248 .44096 .54428 .43711 .53795 .43021 Metetra
.665 .747 .911 r
.53795 .43021 .54428 .43711 .55613 .43326 .54984 .42632 Metetra
.664 .747 .911 r
.54984 .42632 .55613 .43326 .56803 .42939 .56177 .42241 Metetra
.664 .747 .911 r
.56177 .42241 .56803 .42939 .57998 .4255 .57376 .4185 Metetra
.664 .746 .911 r
.57376 .4185 .57998 .4255 .59199 .42161 .5858 .41457 Metetra
.664 .746 .911 r
.5858 .41457 .59199 .42161 .60404 .4177 .59789 .41063 Metetra
.664 .746 .912 r
.59789 .41063 .60404 .4177 .61615 .41378 .61003 .40668 Metetra
.664 .746 .912 r
.61003 .40668 .61615 .41378 .62831 .40984 .62223 .40271 Metetra
.664 .746 .912 r
.62223 .40271 .62831 .40984 .64053 .40589 .63448 .39872 Metetra
.664 .746 .912 r
.63448 .39872 .64053 .40589 .65279 .40193 .64678 .39473 Metetra
.664 .746 .912 r
.64678 .39473 .65279 .40193 .66512 .39795 .65914 .39072 Metetra
.663 .746 .912 r
.65914 .39072 .66512 .39795 .67749 .39395 .67156 .38669 Metetra
.663 .746 .912 r
.67156 .38669 .67749 .39395 .68992 .38995 .68402 .38265 Metetra
.663 .746 .912 r
.68402 .38265 .68992 .38995 .70241 .38592 .69655 .37859 Metetra
.663 .746 .912 r
.69655 .37859 .70241 .38592 .71495 .38188 .70913 .37452 Metetra
.663 .746 .912 r
.70913 .37452 .71495 .38188 .72754 .37783 .72176 .37044 Metetra
.663 .746 .912 r
.72176 .37044 .72754 .37783 .74019 .37376 .73445 .36634 Metetra
.663 .746 .912 r
.73445 .36634 .74019 .37376 .7529 .36968 .7472 .36222 Metetra
.663 .746 .912 r
.7472 .36222 .7529 .36968 .76567 .36559 .76001 .3581 Metetra
.663 .746 .912 r
.76001 .3581 .76567 .36559 .77849 .36148 .77287 .35395 Metetra
.662 .746 .912 r
.77287 .35395 .77849 .36148 .79137 .35735 .7858 .3498 Metetra
.662 .746 .912 r
.7858 .3498 .79137 .35735 .80431 .35322 .79878 .34563 Metetra
.662 .746 .912 r
.79878 .34563 .80431 .35322 .81731 .34907 .81182 .34145 Metetra
.661 .746 .913 r
.81182 .34145 .81731 .34907 .83037 .34492 .82492 .33727 Metetra
.661 .746 .913 r
.82492 .33727 .83037 .34492 .84349 .34077 .83809 .33309 Metetra
.66 .745 .913 r
.83809 .33309 .84349 .34077 .85668 .33663 .85131 .32892 Metetra
.658 .745 .914 r
.85131 .32892 .85668 .33663 .86993 .33252 .86461 .32478 Metetra
.654 .743 .915 r
.86461 .32478 .86993 .33252 .88325 .32852 .87798 .32077 Metetra
.627 .732 .923 r
.87798 .32077 .88325 .32852 .89674 .3253 .89152 .31758 Metetra
.734 .776 .887 r
.29202 .51004 .2991 .51585 .31015 .51009 .30311 .5041 Metetra
.711 .769 .898 r
.30311 .5041 .31015 .51009 .32118 .50512 .31418 .49902 Metetra
.697 .764 .903 r
.31418 .49902 .32118 .50512 .33222 .50058 .32526 .49439 Metetra
.688 .76 .906 r
.32526 .49439 .33222 .50058 .34329 .4963 .33636 .49003 Metetra
.682 .757 .908 r
.33636 .49003 .34329 .4963 .35439 .49217 .34749 .48584 Metetra
.678 .755 .909 r
.34749 .48584 .35439 .49217 .36552 .48814 .35866 .48175 Metetra
.675 .754 .91 r
.35866 .48175 .36552 .48814 .3767 .48418 .36986 .47775 Metetra
.673 .753 .91 r
.36986 .47775 .3767 .48418 .38791 .48027 .38111 .47379 Metetra
.672 .752 .911 r
.38111 .47379 .38791 .48027 .39917 .47639 .3924 .46986 Metetra
.67 .751 .911 r
.3924 .46986 .39917 .47639 .41048 .47253 .40374 .46596 Metetra
.669 .75 .911 r
.40374 .46596 .41048 .47253 .42183 .46868 .41512 .46208 Metetra
.668 .75 .911 r
.41512 .46208 .42183 .46868 .43322 .46485 .42655 .45821 Metetra
.668 .749 .911 r
.42655 .45821 .43322 .46485 .44467 .46101 .43802 .45434 Metetra
.667 .749 .911 r
.43802 .45434 .44467 .46101 .45616 .45718 .44954 .45047 Metetra
.667 .749 .912 r
.44954 .45047 .45616 .45718 .4677 .45335 .46111 .4466 Metetra
.666 .748 .912 r
.46111 .4466 .4677 .45335 .47928 .44951 .47273 .44273 Metetra
.666 .748 .912 r
.47273 .44273 .47928 .44951 .49092 .44567 .4844 .43885 Metetra
.666 .748 .912 r
.4844 .43885 .49092 .44567 .5026 .44182 .49612 .43496 Metetra
.665 .748 .912 r
.49612 .43496 .5026 .44182 .51433 .43796 .50788 .43107 Metetra
.665 .747 .912 r
.50788 .43107 .51433 .43796 .52612 .43409 .5197 .42717 Metetra
.665 .747 .912 r
.5197 .42717 .52612 .43409 .53795 .43021 .53157 .42326 Metetra
.665 .747 .912 r
.53157 .42326 .53795 .43021 .54984 .42632 .54349 .41933 Metetra
.665 .747 .912 r
.54349 .41933 .54984 .42632 .56177 .42241 .55546 .4154 Metetra
.664 .747 .912 r
.55546 .4154 .56177 .42241 .57376 .4185 .56748 .41145 Metetra
.664 .747 .912 r
.56748 .41145 .57376 .4185 .5858 .41457 .57955 .40749 Metetra
.664 .747 .912 r
.57955 .40749 .5858 .41457 .59789 .41063 .59168 .40351 Metetra
.664 .747 .912 r
.59168 .40351 .59789 .41063 .61003 .40668 .60386 .39953 Metetra
.664 .747 .912 r
.60386 .39953 .61003 .40668 .62223 .40271 .6161 .39553 Metetra
.664 .746 .912 r
.6161 .39553 .62223 .40271 .63448 .39872 .62838 .39151 Metetra
.664 .746 .912 r
.62838 .39151 .63448 .39872 .64678 .39473 .64072 .38748 Metetra
.664 .746 .912 r
.64072 .38748 .64678 .39473 .65914 .39072 .65312 .38344 Metetra
.663 .746 .912 r
.65312 .38344 .65914 .39072 .67156 .38669 .66557 .37938 Metetra
.663 .746 .912 r
.66557 .37938 .67156 .38669 .68402 .38265 .67808 .3753 Metetra
.663 .746 .912 r
.67808 .3753 .68402 .38265 .69655 .37859 .69064 .37122 Metetra
.663 .746 .912 r
.69064 .37122 .69655 .37859 .70913 .37452 .70326 .36711 Metetra
.663 .746 .912 r
.70326 .36711 .70913 .37452 .72176 .37044 .71593 .36299 Metetra
.663 .746 .912 r
.71593 .36299 .72176 .37044 .73445 .36634 .72866 .35886 Metetra
.663 .746 .912 r
.72866 .35886 .73445 .36634 .7472 .36222 .74145 .35471 Metetra
.663 .746 .912 r
.74145 .35471 .7472 .36222 .76001 .3581 .7543 .35055 Metetra
.662 .746 .912 r
.7543 .35055 .76001 .3581 .77287 .35395 .76721 .34638 Metetra
.662 .746 .912 r
.76721 .34638 .77287 .35395 .7858 .3498 .78017 .34219 Metetra
.662 .746 .913 r
.78017 .34219 .7858 .3498 .79878 .34563 .7932 .33799 Metetra
.662 .746 .913 r
.7932 .33799 .79878 .34563 .81182 .34145 .80628 .33378 Metetra
.661 .746 .913 r
.80628 .33378 .81182 .34145 .82492 .33727 .81943 .32957 Metetra
.661 .746 .913 r
.81943 .32957 .82492 .33727 .83809 .33309 .83264 .32535 Metetra
.66 .746 .914 r
.83264 .32535 .83809 .33309 .85131 .32892 .84591 .32115 Metetra
.658 .745 .914 r
.84591 .32115 .85131 .32892 .86461 .32478 .85925 .31699 Metetra
.653 .743 .916 r
.85925 .31699 .86461 .32478 .87798 .32077 .87267 .31297 Metetra
.625 .731 .924 r
.87267 .31297 .87798 .32077 .89152 .31758 .88626 .30981 Metetra
.738 .778 .885 r
.28488 .50423 .29202 .51004 .30311 .5041 .29602 .49811 Metetra
.714 .77 .897 r
.29602 .49811 .30311 .5041 .31418 .49902 .30712 .4929 Metetra
.699 .765 .903 r
.30712 .4929 .31418 .49902 .32526 .49439 .31824 .48818 Metetra
.69 .761 .906 r
.31824 .48818 .32526 .49439 .33636 .49003 .32937 .48374 Metetra
.684 .758 .908 r
.32937 .48374 .33636 .49003 .34749 .48584 .34053 .47948 Metetra
.679 .756 .909 r
.34053 .47948 .34749 .48584 .35866 .48175 .35173 .47534 Metetra
.676 .755 .91 r
.35173 .47534 .35866 .48175 .36986 .47775 .36297 .47128 Metetra
.674 .753 .911 r
.36297 .47128 .36986 .47775 .38111 .47379 .37425 .46728 Metetra
.672 .752 .911 r
.37425 .46728 .38111 .47379 .3924 .46986 .38557 .46331 Metetra
.671 .752 .911 r
.38557 .46331 .3924 .46986 .40374 .46596 .39694 .45937 Metetra
.67 .751 .911 r
.39694 .45937 .40374 .46596 .41512 .46208 .40836 .45544 Metetra
.669 .75 .912 r
.40836 .45544 .41512 .46208 .42655 .45821 .41982 .45153 Metetra
.668 .75 .912 r
.41982 .45153 .42655 .45821 .43802 .45434 .43132 .44762 Metetra
.667 .749 .912 r
.43132 .44762 .43802 .45434 .44954 .45047 .44288 .44372 Metetra
.667 .749 .912 r
.44288 .44372 .44954 .45047 .46111 .4466 .45448 .43981 Metetra
.666 .749 .912 r
.45448 .43981 .46111 .4466 .47273 .44273 .46613 .4359 Metetra
.666 .748 .912 r
.46613 .4359 .47273 .44273 .4844 .43885 .47783 .43199 Metetra
.666 .748 .912 r
.47783 .43199 .4844 .43885 .49612 .43496 .48958 .42807 Metetra
.665 .748 .912 r
.48958 .42807 .49612 .43496 .50788 .43107 .50138 .42414 Metetra
.665 .748 .912 r
.50138 .42414 .50788 .43107 .5197 .42717 .51323 .42021 Metetra
.665 .748 .912 r
.51323 .42021 .5197 .42717 .53157 .42326 .52514 .41626 Metetra
.665 .747 .912 r
.52514 .41626 .53157 .42326 .54349 .41933 .53709 .4123 Metetra
.665 .747 .912 r
.53709 .4123 .54349 .41933 .55546 .4154 .54909 .40833 Metetra
.664 .747 .912 r
.54909 .40833 .55546 .4154 .56748 .41145 .56115 .40435 Metetra
.664 .747 .912 r
.56115 .40435 .56748 .41145 .57955 .40749 .57326 .40036 Metetra
.664 .747 .912 r
.57326 .40036 .57955 .40749 .59168 .40351 .58542 .39635 Metetra
.664 .747 .912 r
.58542 .39635 .59168 .40351 .60386 .39953 .59764 .39233 Metetra
.664 .747 .912 r
.59764 .39233 .60386 .39953 .6161 .39553 .60991 .38829 Metetra
.664 .747 .912 r
.60991 .38829 .6161 .39553 .62838 .39151 .62224 .38425 Metetra
.664 .747 .912 r
.62224 .38425 .62838 .39151 .64072 .38748 .63461 .38018 Metetra
.664 .747 .912 r
.63461 .38018 .64072 .38748 .65312 .38344 .64705 .37611 Metetra
.663 .747 .912 r
.64705 .37611 .65312 .38344 .66557 .37938 .65954 .37201 Metetra
.663 .747 .912 r
.65954 .37201 .66557 .37938 .67808 .3753 .67208 .36791 Metetra
.663 .747 .912 r
.67208 .36791 .67808 .3753 .69064 .37122 .68468 .36379 Metetra
.663 .747 .912 r
.68468 .36379 .69064 .37122 .70326 .36711 .69734 .35965 Metetra
.663 .747 .912 r
.69734 .35965 .70326 .36711 .71593 .36299 .71006 .3555 Metetra
.663 .747 .912 r
.71006 .3555 .71593 .36299 .72866 .35886 .72283 .35133 Metetra
.663 .746 .912 r
.72283 .35133 .72866 .35886 .74145 .35471 .73566 .34715 Metetra
.663 .746 .912 r
.73566 .34715 .74145 .35471 .7543 .35055 .74855 .34296 Metetra
.662 .746 .913 r
.74855 .34296 .7543 .35055 .76721 .34638 .7615 .33875 Metetra
.662 .746 .913 r
.7615 .33875 .76721 .34638 .78017 .34219 .7745 .33453 Metetra
.662 .746 .913 r
.7745 .33453 .78017 .34219 .7932 .33799 .78757 .3303 Metetra
.662 .746 .913 r
.78757 .3303 .7932 .33799 .80628 .33378 .8007 .32606 Metetra
.661 .746 .913 r
.8007 .32606 .80628 .33378 .81943 .32957 .81389 .32181 Metetra
.661 .746 .913 r
.81389 .32181 .81943 .32957 .83264 .32535 .82714 .31757 Metetra
.659 .746 .914 r
.82714 .31757 .83264 .32535 .84591 .32115 .84046 .31334 Metetra
.657 .745 .915 r
.84046 .31334 .84591 .32115 .85925 .31699 .85385 .30915 Metetra
.652 .744 .916 r
.85385 .30915 .85925 .31699 .87267 .31297 .86731 .30511 Metetra
.622 .731 .925 r
.86731 .30511 .87267 .31297 .88626 .30981 .88095 .302 Metetra
.742 .78 .884 r
.27767 .49844 .28488 .50423 .29602 .49811 .28886 .49212 Metetra
.717 .772 .896 r
.28886 .49212 .29602 .49811 .30712 .4929 .30001 .48678 Metetra
.701 .767 .903 r
.30001 .48678 .30712 .4929 .31824 .48818 .31116 .48195 Metetra
.692 .763 .906 r
.31116 .48195 .31824 .48818 .32937 .48374 .32232 .47743 Metetra
.685 .76 .908 r
.32232 .47743 .32937 .48374 .34053 .47948 .33352 .47311 Metetra
.68 .757 .909 r
.33352 .47311 .34053 .47948 .35173 .47534 .34475 .4689 Metetra
.677 .756 .91 r
.34475 .4689 .35173 .47534 .36297 .47128 .35602 .46479 Metetra
.675 .754 .911 r
.35602 .46479 .36297 .47128 .37425 .46728 .36734 .46073 Metetra
.673 .753 .911 r
.36734 .46073 .37425 .46728 .38557 .46331 .37869 .45672 Metetra
.671 .752 .911 r
.37869 .45672 .38557 .46331 .39694 .45937 .39009 .45273 Metetra
.67 .752 .912 r
.39009 .45273 .39694 .45937 .40836 .45544 .40154 .44877 Metetra
.669 .751 .912 r
.40154 .44877 .40836 .45544 .41982 .45153 .41303 .44481 Metetra
.668 .75 .912 r
.41303 .44481 .41982 .45153 .43132 .44762 .42457 .44087 Metetra
.668 .75 .912 r
.42457 .44087 .43132 .44762 .44288 .44372 .43616 .43692 Metetra
.667 .75 .912 r
.43616 .43692 .44288 .44372 .45448 .43981 .44779 .43298 Metetra
.667 .749 .912 r
.44779 .43298 .45448 .43981 .46613 .4359 .45948 .42904 Metetra
.666 .749 .912 r
.45948 .42904 .46613 .4359 .47783 .43199 .47121 .42509 Metetra
.666 .749 .912 r
.47121 .42509 .47783 .43199 .48958 .42807 .48299 .42113 Metetra
.666 .748 .912 r
.48299 .42113 .48958 .42807 .50138 .42414 .49483 .41717 Metetra
.665 .748 .912 r
.49483 .41717 .50138 .42414 .51323 .42021 .50671 .4132 Metetra
.665 .748 .912 r
.50671 .4132 .51323 .42021 .52514 .41626 .51865 .40922 Metetra
.665 .748 .912 r
.51865 .40922 .52514 .41626 .53709 .4123 .53064 .40522 Metetra
.665 .748 .912 r
.53064 .40522 .53709 .4123 .54909 .40833 .54268 .40122 Metetra
.664 .748 .912 r
.54268 .40122 .54909 .40833 .56115 .40435 .55477 .39721 Metetra
.664 .748 .912 r
.55477 .39721 .56115 .40435 .57326 .40036 .56692 .39318 Metetra
.664 .747 .912 r
.56692 .39318 .57326 .40036 .58542 .39635 .57912 .38914 Metetra
.664 .747 .912 r
.57912 .38914 .58542 .39635 .59764 .39233 .59137 .38508 Metetra
.664 .747 .912 r
.59137 .38508 .59764 .39233 .60991 .38829 .60368 .38102 Metetra
.664 .747 .912 r
.60368 .38102 .60991 .38829 .62224 .38425 .61604 .37693 Metetra
.664 .747 .912 r
.61604 .37693 .62224 .38425 .63461 .38018 .62846 .37284 Metetra
.664 .747 .912 r
.62846 .37284 .63461 .38018 .64705 .37611 .64093 .36873 Metetra
.663 .747 .912 r
.64093 .36873 .64705 .37611 .65954 .37201 .65345 .3646 Metetra
.663 .747 .912 r
.65345 .3646 .65954 .37201 .67208 .36791 .66604 .36046 Metetra
.663 .747 .912 r
.66604 .36046 .67208 .36791 .68468 .36379 .67868 .35631 Metetra
.663 .747 .912 r
.67868 .35631 .68468 .36379 .69734 .35965 .69138 .35214 Metetra
.663 .747 .913 r
.69138 .35214 .69734 .35965 .71006 .3555 .70413 .34795 Metetra
.663 .747 .913 r
.70413 .34795 .71006 .3555 .72283 .35133 .71694 .34375 Metetra
.663 .747 .913 r
.71694 .34375 .72283 .35133 .73566 .34715 .72982 .33954 Metetra
.663 .747 .913 r
.72982 .33954 .73566 .34715 .74855 .34296 .74275 .33531 Metetra
.662 .747 .913 r
.74275 .33531 .74855 .34296 .7615 .33875 .75574 .33107 Metetra
.662 .747 .913 r
.75574 .33107 .7615 .33875 .7745 .33453 .76879 .32681 Metetra
.662 .747 .913 r
.76879 .32681 .7745 .33453 .78757 .3303 .7819 .32255 Metetra
.661 .747 .913 r
.7819 .32255 .78757 .3303 .8007 .32606 .79507 .31828 Metetra
.661 .747 .914 r
.79507 .31828 .8007 .32606 .81389 .32181 .8083 .314 Metetra
.66 .746 .914 r
.8083 .314 .81389 .32181 .82714 .31757 .8216 .30973 Metetra
.659 .746 .914 r
.8216 .30973 .82714 .31757 .84046 .31334 .83496 .30547 Metetra
.657 .746 .915 r
.83496 .30547 .84046 .31334 .85385 .30915 .84839 .30126 Metetra
.652 .744 .917 r
.84839 .30126 .85385 .30915 .86731 .30511 .86191 .29721 Metetra
.619 .73 .926 r
.86191 .29721 .86731 .30511 .88095 .302 .87561 .29415 Metetra
.746 .782 .882 r
.2704 .49266 .27767 .49844 .28886 .49212 .28164 .48614 Metetra
.72 .774 .896 r
.28164 .48614 .28886 .49212 .30001 .48678 .29283 .48065 Metetra
.704 .768 .902 r
.29283 .48065 .30001 .48678 .31116 .48195 .30402 .47571 Metetra
.693 .764 .906 r
.30402 .47571 .31116 .48195 .32232 .47743 .31522 .47111 Metetra
.686 .761 .908 r
.31522 .47111 .32232 .47743 .33352 .47311 .32645 .46671 Metetra
.682 .759 .91 r
.32645 .46671 .33352 .47311 .34475 .4689 .33772 .46244 Metetra
.678 .757 .91 r
.33772 .46244 .34475 .4689 .35602 .46479 .34902 .45827 Metetra
.675 .755 .911 r
.34902 .45827 .35602 .46479 .36734 .46073 .36037 .45416 Metetra
.673 .754 .911 r
.36037 .45416 .36734 .46073 .37869 .45672 .37175 .4501 Metetra
.672 .753 .912 r
.37175 .4501 .37869 .45672 .39009 .45273 .38319 .44607 Metetra
.67 .752 .912 r
.38319 .44607 .39009 .45273 .40154 .44877 .39466 .44206 Metetra
.669 .752 .912 r
.39466 .44206 .40154 .44877 .41303 .44481 .40619 .43806 Metetra
.669 .751 .912 r
.40619 .43806 .41303 .44481 .42457 .44087 .41776 .43407 Metetra
.668 .751 .912 r
.41776 .43407 .42457 .44087 .43616 .43692 .42938 .43009 Metetra
.667 .75 .912 r
.42938 .43009 .43616 .43692 .44779 .43298 .44105 .42611 Metetra
.667 .75 .912 r
.44105 .42611 .44779 .43298 .45948 .42904 .45277 .42213 Metetra
.666 .749 .912 r
.45277 .42213 .45948 .42904 .47121 .42509 .46453 .41814 Metetra
.666 .749 .912 r
.46453 .41814 .47121 .42509 .48299 .42113 .47635 .41415 Metetra
.666 .749 .912 r
.47635 .41415 .48299 .42113 .49483 .41717 .48822 .41015 Metetra
.665 .749 .912 r
.48822 .41015 .49483 .41717 .50671 .4132 .50014 .40615 Metetra
.665 .749 .912 r
.50014 .40615 .50671 .4132 .51865 .40922 .51211 .40213 Metetra
.665 .748 .912 r
.51211 .40213 .51865 .40922 .53064 .40522 .52413 .3981 Metetra
.665 .748 .912 r
.52413 .3981 .53064 .40522 .54268 .40122 .53621 .39407 Metetra
.665 .748 .912 r
.53621 .39407 .54268 .40122 .55477 .39721 .54834 .39002 Metetra
.664 .748 .912 r
.54834 .39002 .55477 .39721 .56692 .39318 .56052 .38595 Metetra
.664 .748 .912 r
.56052 .38595 .56692 .39318 .57912 .38914 .57276 .38188 Metetra
.664 .748 .912 r
.57276 .38188 .57912 .38914 .59137 .38508 .58505 .37779 Metetra
.664 .748 .913 r
.58505 .37779 .59137 .38508 .60368 .38102 .59739 .37369 Metetra
.664 .748 .913 r
.59739 .37369 .60368 .38102 .61604 .37693 .60979 .36957 Metetra
.664 .747 .913 r
.60979 .36957 .61604 .37693 .62846 .37284 .62224 .36544 Metetra
.664 .747 .913 r
.62224 .36544 .62846 .37284 .64093 .36873 .63475 .3613 Metetra
.663 .747 .913 r
.63475 .3613 .64093 .36873 .65345 .3646 .64732 .35714 Metetra
.663 .747 .913 r
.64732 .35714 .65345 .3646 .66604 .36046 .65994 .35296 Metetra
.663 .747 .913 r
.65994 .35296 .66604 .36046 .67868 .35631 .67262 .34878 Metetra
.663 .747 .913 r
.67262 .34878 .67868 .35631 .69138 .35214 .68536 .34457 Metetra
.663 .747 .913 r
.68536 .34457 .69138 .35214 .70413 .34795 .69816 .34035 Metetra
.663 .747 .913 r
.69816 .34035 .70413 .34795 .71694 .34375 .71101 .33612 Metetra
.663 .747 .913 r
.71101 .33612 .71694 .34375 .72982 .33954 .72392 .33187 Metetra
.662 .747 .913 r
.72392 .33187 .72982 .33954 .74275 .33531 .7369 .32761 Metetra
.662 .747 .913 r
.7369 .32761 .74275 .33531 .75574 .33107 .74993 .32333 Metetra
.662 .747 .913 r
.74993 .32333 .75574 .33107 .76879 .32681 .76302 .31905 Metetra
.662 .747 .913 r
.76302 .31905 .76879 .32681 .7819 .32255 .77617 .31475 Metetra
.661 .747 .914 r
.77617 .31475 .7819 .32255 .79507 .31828 .78939 .31044 Metetra
.661 .747 .914 r
.78939 .31044 .79507 .31828 .8083 .314 .80267 .30614 Metetra
.66 .747 .914 r
.80267 .30614 .8083 .314 .8216 .30973 .81601 .30183 Metetra
.659 .747 .915 r
.81601 .30183 .8216 .30973 .83496 .30547 .82942 .29755 Metetra
.657 .746 .916 r
.82942 .29755 .83496 .30547 .84839 .30126 .8429 .29332 Metetra
.651 .744 .918 r
.8429 .29332 .84839 .30126 .86191 .29721 .85646 .28925 Metetra
.615 .729 .927 r
.85646 .28925 .86191 .29721 .87561 .29415 .87022 .28625 Metetra
.751 .785 .88 r
.26306 .48691 .2704 .49266 .28164 .48614 .27435 .48016 Metetra
.723 .776 .895 r
.27435 .48016 .28164 .48614 .29283 .48065 .28559 .47452 Metetra
.706 .77 .902 r
.28559 .47452 .29283 .48065 .30402 .47571 .29681 .46947 Metetra
.695 .766 .906 r
.29681 .46947 .30402 .47571 .31522 .47111 .30805 .46477 Metetra
.688 .762 .908 r
.30805 .46477 .31522 .47111 .32645 .46671 .31932 .46029 Metetra
.683 .76 .91 r
.31932 .46029 .32645 .46671 .33772 .46244 .33062 .45595 Metetra
.679 .758 .911 r
.33062 .45595 .33772 .46244 .34902 .45827 .34196 .45172 Metetra
.676 .756 .911 r
.34196 .45172 .34902 .45827 .36037 .45416 .35334 .44756 Metetra
.674 .755 .912 r
.35334 .44756 .36037 .45416 .37175 .4501 .36476 .44345 Metetra
.672 .754 .912 r
.36476 .44345 .37175 .4501 .38319 .44607 .37622 .43937 Metetra
.671 .753 .912 r
.37622 .43937 .38319 .44607 .39466 .44206 .38773 .43531 Metetra
.67 .752 .912 r
.38773 .43531 .39466 .44206 .40619 .43806 .39929 .43127 Metetra
.669 .752 .912 r
.39929 .43127 .40619 .43806 .41776 .43407 .41089 .42725 Metetra
.668 .751 .913 r
.41089 .42725 .41776 .43407 .42938 .43009 .42255 .42323 Metetra
.668 .751 .913 r
.42255 .42323 .42938 .43009 .44105 .42611 .43425 .41921 Metetra
.667 .75 .913 r
.43425 .41921 .44105 .42611 .45277 .42213 .446 .41519 Metetra
.667 .75 .913 r
.446 .41519 .45277 .42213 .46453 .41814 .4578 .41116 Metetra
.666 .75 .913 r
.4578 .41116 .46453 .41814 .47635 .41415 .46965 .40713 Metetra
.666 .749 .913 r
.46965 .40713 .47635 .41415 .48822 .41015 .48156 .4031 Metetra
.666 .749 .913 r
.48156 .4031 .48822 .41015 .50014 .40615 .49351 .39905 Metetra
.665 .749 .913 r
.49351 .39905 .50014 .40615 .51211 .40213 .50552 .395 Metetra
.665 .749 .913 r
.50552 .395 .51211 .40213 .52413 .3981 .51758 .39094 Metetra
.665 .749 .913 r
.51758 .39094 .52413 .3981 .53621 .39407 .52969 .38687 Metetra
.665 .748 .913 r
.52969 .38687 .53621 .39407 .54834 .39002 .54185 .38278 Metetra
.664 .748 .913 r
.54185 .38278 .54834 .39002 .56052 .38595 .55407 .37869 Metetra
.664 .748 .913 r
.55407 .37869 .56052 .38595 .57276 .38188 .56634 .37458 Metetra
.664 .748 .913 r
.56634 .37458 .57276 .38188 .58505 .37779 .57867 .37045 Metetra
.664 .748 .913 r
.57867 .37045 .58505 .37779 .59739 .37369 .59105 .36632 Metetra
.664 .748 .913 r
.59105 .36632 .59739 .37369 .60979 .36957 .60349 .36217 Metetra
.664 .748 .913 r
.60349 .36217 .60979 .36957 .62224 .36544 .61598 .358 Metetra
.664 .748 .913 r
.61598 .358 .62224 .36544 .63475 .3613 .62853 .35382 Metetra
.663 .748 .913 r
.62853 .35382 .63475 .3613 .64732 .35714 .64114 .34963 Metetra
.663 .748 .913 r
.64114 .34963 .64732 .35714 .65994 .35296 .6538 .34542 Metetra
.663 .748 .913 r
.6538 .34542 .65994 .35296 .67262 .34878 .66652 .34119 Metetra
.663 .748 .913 r
.66652 .34119 .67262 .34878 .68536 .34457 .6793 .33696 Metetra
.663 .748 .913 r
.6793 .33696 .68536 .34457 .69816 .34035 .69213 .3327 Metetra
.663 .748 .913 r
.69213 .3327 .69816 .34035 .71101 .33612 .70503 .32844 Metetra
.663 .748 .913 r
.70503 .32844 .71101 .33612 .72392 .33187 .71798 .32415 Metetra
.662 .748 .913 r
.71798 .32415 .72392 .33187 .7369 .32761 .731 .31986 Metetra
.662 .748 .914 r
.731 .31986 .7369 .32761 .74993 .32333 .74407 .31555 Metetra
.662 .748 .914 r
.74407 .31555 .74993 .32333 .76302 .31905 .75721 .31123 Metetra
.662 .747 .914 r
.75721 .31123 .76302 .31905 .77617 .31475 .7704 .3069 Metetra
.661 .747 .914 r
.7704 .3069 .77617 .31475 .78939 .31044 .78366 .30256 Metetra
.661 .747 .914 r
.78366 .30256 .78939 .31044 .80267 .30614 .79699 .29822 Metetra
.66 .747 .915 r
.79699 .29822 .80267 .30614 .81601 .30183 .81037 .29389 Metetra
.659 .747 .915 r
.81037 .29389 .81601 .30183 .82942 .29755 .82383 .28957 Metetra
.656 .746 .916 r
.82383 .28957 .82942 .29755 .8429 .29332 .83736 .28532 Metetra
.65 .744 .918 r
.83736 .28532 .8429 .29332 .85646 .28925 .85097 .28125 Metetra
.612 .728 .928 r
.85097 .28125 .85646 .28925 .87022 .28625 .86478 .27831 Metetra
.756 .787 .878 r
.25566 .4812 .26306 .48691 .27435 .48016 .267 .4742 Metetra
.727 .779 .894 r
.267 .4742 .27435 .48016 .28559 .47452 .27828 .46839 Metetra
.709 .772 .902 r
.27828 .46839 .28559 .47452 .29681 .46947 .28955 .46321 Metetra
.697 .767 .906 r
.28955 .46321 .29681 .46947 .30805 .46477 .30083 .45841 Metetra
.69 .764 .908 r
.30083 .45841 .30805 .46477 .31932 .46029 .31213 .45385 Metetra
.684 .761 .91 r
.31213 .45385 .31932 .46029 .33062 .45595 .32347 .44945 Metetra
.68 .759 .911 r
.32347 .44945 .33062 .45595 .34196 .45172 .33484 .44515 Metetra
.677 .757 .912 r
.33484 .44515 .34196 .45172 .35334 .44756 .34625 .44093 Metetra
.675 .756 .912 r
.34625 .44093 .35334 .44756 .36476 .44345 .3577 .43677 Metetra
.673 .755 .912 r
.3577 .43677 .36476 .44345 .37622 .43937 .3692 .43264 Metetra
.672 .754 .913 r
.3692 .43264 .37622 .43937 .38773 .43531 .38074 .42854 Metetra
.67 .753 .913 r
.38074 .42854 .38773 .43531 .39929 .43127 .39233 .42445 Metetra
.669 .753 .913 r
.39233 .42445 .39929 .43127 .41089 .42725 .40397 .42038 Metetra
.669 .752 .913 r
.40397 .42038 .41089 .42725 .42255 .42323 .41566 .41632 Metetra
.668 .751 .913 r
.41566 .41632 .42255 .42323 .43425 .41921 .42739 .41226 Metetra
.667 .751 .913 r
.42739 .41226 .43425 .41921 .446 .41519 .43918 .4082 Metetra
.667 .751 .913 r
.43918 .4082 .446 .41519 .4578 .41116 .45101 .40414 Metetra
.666 .75 .913 r
.45101 .40414 .4578 .41116 .46965 .40713 .4629 .40007 Metetra
.666 .75 .913 r
.4629 .40007 .46965 .40713 .48156 .4031 .47484 .396 Metetra
.666 .75 .913 r
.47484 .396 .48156 .4031 .49351 .39905 .48683 .39192 Metetra
.665 .75 .913 r
.48683 .39192 .49351 .39905 .50552 .395 .49887 .38783 Metetra
.665 .749 .913 r
.49887 .38783 .50552 .395 .51758 .39094 .51096 .38373 Metetra
.665 .749 .913 r
.51096 .38373 .51758 .39094 .52969 .38687 .52311 .37962 Metetra
.665 .749 .913 r
.52311 .37962 .52969 .38687 .54185 .38278 .53531 .3755 Metetra
.665 .749 .913 r
.53531 .3755 .54185 .38278 .55407 .37869 .54757 .37137 Metetra
.664 .749 .913 r
.54757 .37137 .55407 .37869 .56634 .37458 .55988 .36723 Metetra
.664 .749 .913 r
.55988 .36723 .56634 .37458 .57867 .37045 .57224 .36307 Metetra
.664 .749 .913 r
.57224 .36307 .57867 .37045 .59105 .36632 .58466 .35889 Metetra
.664 .748 .913 r
.58466 .35889 .59105 .36632 .60349 .36217 .59714 .35471 Metetra
.664 .748 .913 r
.59714 .35471 .60349 .36217 .61598 .358 .60967 .35051 Metetra
.664 .748 .913 r
.60967 .35051 .61598 .358 .62853 .35382 .62225 .3463 Metetra
.663 .748 .913 r
.62225 .3463 .62853 .35382 .64114 .34963 .6349 .34207 Metetra
.663 .748 .913 r
.6349 .34207 .64114 .34963 .6538 .34542 .6476 .33782 Metetra
.663 .748 .913 r
.6476 .33782 .6538 .34542 .66652 .34119 .66036 .33356 Metetra
.663 .748 .913 r
.66036 .33356 .66652 .34119 .6793 .33696 .67318 .32929 Metetra
.663 .748 .913 r
.67318 .32929 .6793 .33696 .69213 .3327 .68606 .325 Metetra
.663 .748 .914 r
.68606 .325 .69213 .3327 .70503 .32844 .69899 .3207 Metetra
.663 .748 .914 r
.69899 .3207 .70503 .32844 .71798 .32415 .71199 .31639 Metetra
.662 .748 .914 r
.71199 .31639 .71798 .32415 .731 .31986 .72505 .31206 Metetra
.662 .748 .914 r
.72505 .31206 .731 .31986 .74407 .31555 .73816 .30771 Metetra
.662 .748 .914 r
.73816 .30771 .74407 .31555 .75721 .31123 .75134 .30336 Metetra
.661 .748 .914 r
.75134 .30336 .75721 .31123 .7704 .3069 .76458 .299 Metetra
.661 .748 .914 r
.76458 .299 .7704 .3069 .78366 .30256 .77789 .29463 Metetra
.66 .748 .915 r
.77789 .29463 .78366 .30256 .79699 .29822 .79126 .29025 Metetra
.66 .748 .915 r
.79126 .29025 .79699 .29822 .81037 .29389 .80469 .28589 Metetra
.658 .747 .916 r
.80469 .28589 .81037 .29389 .82383 .28957 .81819 .28155 Metetra
.656 .747 .917 r
.81819 .28155 .82383 .28957 .83736 .28532 .83177 .27728 Metetra
.649 .744 .919 r
.83177 .27728 .83736 .28532 .85097 .28125 .84543 .2732 Metetra
.608 .727 .929 r
.84543 .2732 .85097 .28125 .86478 .27831 .8593 .27034 Metetra
.762 .79 .876 r
.24818 .47553 .25566 .4812 .267 .4742 .25959 .46825 Metetra
.731 .781 .893 r
.25959 .46825 .267 .4742 .27828 .46839 .27091 .46226 Metetra
.712 .775 .901 r
.27091 .46226 .27828 .46839 .28955 .46321 .28222 .45696 Metetra
.7 .769 .906 r
.28222 .45696 .28955 .46321 .30083 .45841 .29354 .45205 Metetra
.691 .766 .908 r
.29354 .45205 .30083 .45841 .31213 .45385 .30488 .4474 Metetra
.686 .763 .91 r
.30488 .4474 .31213 .45385 .32347 .44945 .31625 .44292 Metetra
.681 .76 .911 r
.31625 .44292 .32347 .44945 .33484 .44515 .32766 .43856 Metetra
.678 .759 .912 r
.32766 .43856 .33484 .44515 .34625 .44093 .3391 .43428 Metetra
.676 .757 .912 r
.3391 .43428 .34625 .44093 .3577 .43677 .35059 .43006 Metetra
.674 .756 .913 r
.35059 .43006 .3577 .43677 .3692 .43264 .36212 .42588 Metetra
.672 .755 .913 r
.36212 .42588 .3692 .43264 .38074 .42854 .3737 .42173 Metetra
.671 .754 .913 r
.3737 .42173 .38074 .42854 .39233 .42445 .38532 .4176 Metetra
.67 .753 .913 r
.38532 .4176 .39233 .42445 .40397 .42038 .39699 .41349 Metetra
.669 .753 .913 r
.39699 .41349 .40397 .42038 .41566 .41632 .40871 .40938 Metetra
.668 .752 .913 r
.40871 .40938 .41566 .41632 .42739 .41226 .42048 .40528 Metetra
.668 .752 .913 r
.42048 .40528 .42739 .41226 .43918 .4082 .4323 .40118 Metetra
.667 .751 .913 r
.4323 .40118 .43918 .4082 .45101 .40414 .44417 .39708 Metetra
.667 .751 .913 r
.44417 .39708 .45101 .40414 .4629 .40007 .45609 .39297 Metetra
.666 .751 .913 r
.45609 .39297 .4629 .40007 .47484 .396 .46806 .38886 Metetra
.666 .75 .913 r
.46806 .38886 .47484 .396 .48683 .39192 .48009 .38474 Metetra
.666 .75 .913 r
.48009 .38474 .48683 .39192 .49887 .38783 .49217 .38062 Metetra
.665 .75 .913 r
.49217 .38062 .49887 .38783 .51096 .38373 .5043 .37648 Metetra
.665 .75 .913 r
.5043 .37648 .51096 .38373 .52311 .37962 .51648 .37234 Metetra
.665 .75 .913 r
.51648 .37234 .52311 .37962 .53531 .3755 .52872 .36818 Metetra
.665 .749 .913 r
.52872 .36818 .53531 .3755 .54757 .37137 .54101 .36401 Metetra
.664 .749 .913 r
.54101 .36401 .54757 .37137 .55988 .36723 .55336 .35983 Metetra
.664 .749 .913 r
.55336 .35983 .55988 .36723 .57224 .36307 .56576 .35564 Metetra
.664 .749 .913 r
.56576 .35564 .57224 .36307 .58466 .35889 .57821 .35143 Metetra
.664 .749 .914 r
.57821 .35143 .58466 .35889 .59714 .35471 .59073 .34721 Metetra
.664 .749 .914 r
.59073 .34721 .59714 .35471 .60967 .35051 .6033 .34297 Metetra
.664 .749 .914 r
.6033 .34297 .60967 .35051 .62225 .3463 .61593 .33872 Metetra
.663 .749 .914 r
.61593 .33872 .62225 .3463 .6349 .34207 .62861 .33446 Metetra
.663 .749 .914 r
.62861 .33446 .6349 .34207 .6476 .33782 .64135 .33018 Metetra
.663 .749 .914 r
.64135 .33018 .6476 .33782 .66036 .33356 .65415 .32589 Metetra
.663 .749 .914 r
.65415 .32589 .66036 .33356 .67318 .32929 .66701 .32158 Metetra
.663 .749 .914 r
.66701 .32158 .67318 .32929 .68606 .325 .67993 .31725 Metetra
.663 .748 .914 r
.67993 .31725 .68606 .325 .69899 .3207 .69291 .31292 Metetra
.662 .748 .914 r
.69291 .31292 .69899 .3207 .71199 .31639 .70595 .30857 Metetra
.662 .748 .914 r
.70595 .30857 .71199 .31639 .72505 .31206 .71905 .3042 Metetra
.662 .748 .914 r
.71905 .3042 .72505 .31206 .73816 .30771 .73221 .29983 Metetra
.662 .748 .914 r
.73221 .29983 .73816 .30771 .75134 .30336 .74543 .29544 Metetra
.661 .748 .915 r
.74543 .29544 .75134 .30336 .76458 .299 .75872 .29104 Metetra
.661 .748 .915 r
.75872 .29104 .76458 .299 .77789 .29463 .77207 .28664 Metetra
.66 .748 .915 r
.77207 .28664 .77789 .29463 .79126 .29025 .78548 .28224 Metetra
.659 .748 .916 r
.78548 .28224 .79126 .29025 .80469 .28589 .79896 .27784 Metetra
.658 .748 .916 r
.79896 .27784 .80469 .28589 .81819 .28155 .81251 .27348 Metetra
.655 .747 .917 r
.81251 .27348 .81819 .28155 .83177 .27728 .82613 .26918 Metetra
.648 .744 .92 r
.82613 .26918 .83177 .27728 .84543 .2732 .83985 .2651 Metetra
.603 .725 .931 r
.83985 .2651 .84543 .2732 .8593 .27034 .85377 .26233 Metetra
.767 .793 .874 r
.24063 .4699 .24818 .47553 .25959 .46825 .2521 .46234 Metetra
.736 .784 .892 r
.2521 .46234 .25959 .46825 .27091 .46226 .26348 .45616 Metetra
.715 .777 .901 r
.26348 .45616 .27091 .46226 .28222 .45696 .27483 .4507 Metetra
.702 .772 .906 r
.27483 .4507 .28222 .45696 .29354 .45205 .28619 .44569 Metetra
.693 .767 .909 r
.28619 .44569 .29354 .45205 .30488 .4474 .29757 .44094 Metetra
.687 .764 .91 r
.29757 .44094 .30488 .4474 .31625 .44292 .30897 .43638 Metetra
.683 .762 .911 r
.30897 .43638 .31625 .44292 .32766 .43856 .32041 .43195 Metetra
.679 .76 .912 r
.32041 .43195 .32766 .43856 .3391 .43428 .33189 .42761 Metetra
.676 .758 .913 r
.33189 .42761 .3391 .43428 .35059 .43006 .34341 .42333 Metetra
.674 .757 .913 r
.34341 .42333 .35059 .43006 .36212 .42588 .35498 .4191 Metetra
.673 .756 .913 r
.35498 .4191 .36212 .42588 .3737 .42173 .36659 .4149 Metetra
.671 .755 .913 r
.36659 .4149 .3737 .42173 .38532 .4176 .37825 .41072 Metetra
.67 .754 .914 r
.37825 .41072 .38532 .4176 .39699 .41349 .38995 .40656 Metetra
.669 .754 .914 r
.38995 .40656 .39699 .41349 .40871 .40938 .40171 .40241 Metetra
.669 .753 .914 r
.40171 .40241 .40871 .40938 .42048 .40528 .41351 .39827 Metetra
.668 .753 .914 r
.41351 .39827 .42048 .40528 .4323 .40118 .42537 .39412 Metetra
.667 .752 .914 r
.42537 .39412 .4323 .40118 .44417 .39708 .43727 .38998 Metetra
.667 .752 .914 r
.43727 .38998 .44417 .39708 .45609 .39297 .44923 .38584 Metetra
.666 .751 .914 r
.44923 .38584 .45609 .39297 .46806 .38886 .46123 .38169 Metetra
.666 .751 .914 r
.46123 .38169 .46806 .38886 .48009 .38474 .47329 .37753 Metetra
.666 .751 .914 r
.47329 .37753 .48009 .38474 .49217 .38062 .48541 .37337 Metetra
.665 .751 .914 r
.48541 .37337 .49217 .38062 .5043 .37648 .49757 .36919 Metetra
.665 .75 .914 r
.49757 .36919 .5043 .37648 .51648 .37234 .50979 .36501 Metetra
.665 .75 .914 r
.50979 .36501 .51648 .37234 .52872 .36818 .52207 .36081 Metetra
.665 .75 .914 r
.52207 .36081 .52872 .36818 .54101 .36401 .5344 .35661 Metetra
.664 .75 .914 r
.5344 .35661 .54101 .36401 .55336 .35983 .54678 .35239 Metetra
.664 .75 .914 r
.54678 .35239 .55336 .35983 .56576 .35564 .55922 .34816 Metetra
.664 .75 .914 r
.55922 .34816 .56576 .35564 .57821 .35143 .57171 .34392 Metetra
.664 .749 .914 r
.57171 .34392 .57821 .35143 .59073 .34721 .58427 .33966 Metetra
.664 .749 .914 r
.58427 .33966 .59073 .34721 .6033 .34297 .59688 .33539 Metetra
.664 .749 .914 r
.59688 .33539 .6033 .34297 .61593 .33872 .60954 .3311 Metetra
.663 .749 .914 r
.60954 .3311 .61593 .33872 .62861 .33446 .62227 .3268 Metetra
.663 .749 .914 r
.62227 .3268 .62861 .33446 .64135 .33018 .63505 .32249 Metetra
.663 .749 .914 r
.63505 .32249 .64135 .33018 .65415 .32589 .64789 .31816 Metetra
.663 .749 .914 r
.64789 .31816 .65415 .32589 .66701 .32158 .66079 .31382 Metetra
.663 .749 .914 r
.66079 .31382 .66701 .32158 .67993 .31725 .67375 .30946 Metetra
.663 .749 .914 r
.67375 .30946 .67993 .31725 .69291 .31292 .68677 .30509 Metetra
.662 .749 .914 r
.68677 .30509 .69291 .31292 .70595 .30857 .69985 .3007 Metetra
.662 .749 .915 r
.69985 .3007 .70595 .30857 .71905 .3042 .713 .2963 Metetra
.662 .749 .915 r
.713 .2963 .71905 .3042 .73221 .29983 .7262 .29189 Metetra
.662 .749 .915 r
.7262 .29189 .73221 .29983 .74543 .29544 .73947 .28747 Metetra
.661 .749 .915 r
.73947 .28747 .74543 .29544 .75872 .29104 .7528 .28304 Metetra
.661 .749 .915 r
.7528 .28304 .75872 .29104 .77207 .28664 .76619 .27861 Metetra
.66 .749 .916 r
.76619 .27861 .77207 .28664 .78548 .28224 .77965 .27417 Metetra
.659 .749 .916 r
.77965 .27417 .78548 .28224 .79896 .27784 .79318 .26975 Metetra
.657 .748 .917 r
.79318 .26975 .79896 .27784 .81251 .27348 .80678 .26536 Metetra
.654 .747 .918 r
.80678 .26536 .81251 .27348 .82613 .26918 .82045 .26104 Metetra
.647 .745 .921 r
.82045 .26104 .82613 .26918 .83985 .2651 .83421 .25696 Metetra
.598 .724 .932 r
.83421 .25696 .83985 .2651 .85377 .26233 .8482 .25429 Metetra
.774 .796 .871 r
.23301 .46435 .24063 .4699 .2521 .46234 .24454 .45647 Metetra
.74 .787 .89 r
.24454 .45647 .2521 .46234 .26348 .45616 .25597 .45007 Metetra
.719 .78 .9 r
.25597 .45007 .26348 .45616 .27483 .4507 .26737 .44446 Metetra
.705 .774 .905 r
.26737 .44446 .27483 .4507 .28619 .44569 .27877 .43932 Metetra
.696 .77 .909 r
.27877 .43932 .28619 .44569 .29757 .44094 .29019 .43448 Metetra
.689 .766 .911 r
.29019 .43448 .29757 .44094 .30897 .43638 .30163 .42984 Metetra
.684 .764 .912 r
.30163 .42984 .30897 .43638 .32041 .43195 .31311 .42533 Metetra
.68 .761 .913 r
.31311 .42533 .32041 .43195 .33189 .42761 .32462 .42092 Metetra
.677 .76 .913 r
.32462 .42092 .33189 .42761 .34341 .42333 .33618 .41658 Metetra
.675 .758 .913 r
.33618 .41658 .34341 .42333 .35498 .4191 .34778 .41229 Metetra
.673 .757 .914 r
.34778 .41229 .35498 .4191 .36659 .4149 .35942 .40804 Metetra
.672 .756 .914 r
.35942 .40804 .36659 .4149 .37825 .41072 .37112 .40381 Metetra
.671 .755 .914 r
.37112 .40381 .37825 .41072 .38995 .40656 .38286 .3996 Metetra
.67 .755 .914 r
.38286 .3996 .38995 .40656 .40171 .40241 .39464 .39541 Metetra
.669 .754 .914 r
.39464 .39541 .40171 .40241 .41351 .39827 .40648 .39122 Metetra
.668 .753 .914 r
.40648 .39122 .41351 .39827 .42537 .39412 .41837 .38703 Metetra
.668 .753 .914 r
.41837 .38703 .42537 .39412 .43727 .38998 .43031 .38285 Metetra
.667 .752 .914 r
.43031 .38285 .43727 .38998 .44923 .38584 .4423 .37866 Metetra
.667 .752 .914 r
.4423 .37866 .44923 .38584 .46123 .38169 .45434 .37447 Metetra
.666 .752 .914 r
.45434 .37447 .46123 .38169 .47329 .37753 .46644 .37028 Metetra
.666 .751 .914 r
.46644 .37028 .47329 .37753 .48541 .37337 .47859 .36607 Metetra
.666 .751 .914 r
.47859 .36607 .48541 .37337 .49757 .36919 .49079 .36186 Metetra
.665 .751 .914 r
.49079 .36186 .49757 .36919 .50979 .36501 .50305 .35764 Metetra
.665 .751 .914 r
.50305 .35764 .50979 .36501 .52207 .36081 .51536 .35341 Metetra
.665 .751 .914 r
.51536 .35341 .52207 .36081 .5344 .35661 .52773 .34916 Metetra
.665 .75 .914 r
.52773 .34916 .5344 .35661 .54678 .35239 .54015 .34491 Metetra
.664 .75 .914 r
.54015 .34491 .54678 .35239 .55922 .34816 .55263 .34064 Metetra
.664 .75 .914 r
.55263 .34064 .55922 .34816 .57171 .34392 .56516 .33636 Metetra
.664 .75 .914 r
.56516 .33636 .57171 .34392 .58427 .33966 .57775 .33207 Metetra
.664 .75 .914 r
.57775 .33207 .58427 .33966 .59688 .33539 .5904 .32776 Metetra
.664 .75 .914 r
.5904 .32776 .59688 .33539 .60954 .3311 .60311 .32344 Metetra
.663 .75 .914 r
.60311 .32344 .60954 .3311 .62227 .3268 .61587 .3191 Metetra
.663 .75 .915 r
.61587 .3191 .62227 .3268 .63505 .32249 .62869 .31475 Metetra
.663 .75 .915 r
.62869 .31475 .63505 .32249 .64789 .31816 .64158 .31039 Metetra
.663 .75 .915 r
.64158 .31039 .64789 .31816 .66079 .31382 .65452 .30601 Metetra
.663 .75 .915 r
.65452 .30601 .66079 .31382 .67375 .30946 .66752 .30161 Metetra
.663 .75 .915 r
.66752 .30161 .67375 .30946 .68677 .30509 .68058 .29721 Metetra
.662 .75 .915 r
.68058 .29721 .68677 .30509 .69985 .3007 .69371 .29279 Metetra
.662 .75 .915 r
.69371 .29279 .69985 .3007 .713 .2963 .70689 .28835 Metetra
.662 .75 .915 r
.70689 .28835 .713 .2963 .7262 .29189 .72014 .28391 Metetra
.661 .749 .915 r
.72014 .28391 .7262 .29189 .73947 .28747 .73345 .27945 Metetra
.661 .749 .916 r
.73345 .27945 .73947 .28747 .7528 .28304 .74683 .27499 Metetra
.66 .749 .916 r
.74683 .27499 .7528 .28304 .76619 .27861 .76027 .27052 Metetra
.66 .749 .916 r
.76027 .27052 .76619 .27861 .77965 .27417 .77378 .26606 Metetra
.659 .749 .917 r
.77378 .26606 .77965 .27417 .79318 .26975 .78735 .26161 Metetra
.657 .749 .918 r
.78735 .26161 .79318 .26975 .80678 .26536 .80099 .25719 Metetra
.654 .748 .919 r
.80099 .25719 .80678 .26536 .82045 .26104 .81472 .25286 Metetra
.645 .745 .922 r
.81472 .25286 .82045 .26104 .83421 .25696 .82853 .24878 Metetra
.593 .722 .934 r
.82853 .24878 .83421 .25696 .8482 .25429 .84258 .24622 Metetra
.78 .8 .869 r
.22531 .45887 .23301 .46435 .24454 .45647 .23691 .45064 Metetra
.745 .79 .889 r
.23691 .45064 .24454 .45647 .25597 .45007 .2484 .44401 Metetra
.723 .783 .9 r
.2484 .44401 .25597 .45007 .26737 .44446 .25984 .43824 Metetra
.708 .776 .905 r
.25984 .43824 .26737 .44446 .27877 .43932 .27129 .43297 Metetra
.698 .772 .909 r
.27129 .43297 .27877 .43932 .29019 .43448 .28274 .42802 Metetra
.691 .768 .911 r
.28274 .42802 .29019 .43448 .30163 .42984 .29422 .42328 Metetra
.686 .765 .912 r
.29422 .42328 .30163 .42984 .31311 .42533 .30574 .4187 Metetra
.682 .763 .913 r
.30574 .4187 .31311 .42533 .32462 .42092 .31729 .41422 Metetra
.679 .761 .914 r
.31729 .41422 .32462 .42092 .33618 .41658 .32888 .40981 Metetra
.676 .76 .914 r
.32888 .40981 .33618 .41658 .34778 .41229 .34051 .40546 Metetra
.674 .758 .914 r
.34051 .40546 .34778 .41229 .35942 .40804 .35219 .40116 Metetra
.673 .757 .914 r
.35219 .40116 .35942 .40804 .37112 .40381 .36392 .39688 Metetra
.671 .756 .914 r
.36392 .39688 .37112 .40381 .38286 .3996 .3757 .39262 Metetra
.67 .756 .915 r
.3757 .39262 .38286 .3996 .39464 .39541 .38752 .38838 Metetra
.669 .755 .915 r
.38752 .38838 .39464 .39541 .40648 .39122 .39939 .38414 Metetra
.669 .754 .915 r
.39939 .38414 .40648 .39122 .41837 .38703 .41132 .37991 Metetra
.668 .754 .915 r
.41132 .37991 .41837 .38703 .43031 .38285 .42329 .37568 Metetra
.667 .753 .915 r
.42329 .37568 .43031 .38285 .4423 .37866 .43532 .37146 Metetra
.667 .753 .915 r
.43532 .37146 .4423 .37866 .45434 .37447 .4474 .36722 Metetra
.666 .753 .915 r
.4474 .36722 .45434 .37447 .46644 .37028 .45953 .36299 Metetra
.666 .752 .915 r
.45953 .36299 .46644 .37028 .47859 .36607 .47171 .35874 Metetra
.666 .752 .915 r
.47171 .35874 .47859 .36607 .49079 .36186 .48395 .35449 Metetra
.665 .752 .915 r
.48395 .35449 .49079 .36186 .50305 .35764 .49625 .35023 Metetra
.665 .752 .915 r
.49625 .35023 .50305 .35764 .51536 .35341 .5086 .34596 Metetra
.665 .751 .915 r
.5086 .34596 .51536 .35341 .52773 .34916 .521 .34168 Metetra
.665 .751 .915 r
.521 .34168 .52773 .34916 .54015 .34491 .53346 .33739 Metetra
.664 .751 .915 r
.53346 .33739 .54015 .34491 .55263 .34064 .54598 .33308 Metetra
.664 .751 .915 r
.54598 .33308 .55263 .34064 .56516 .33636 .55855 .32876 Metetra
.664 .751 .915 r
.55855 .32876 .56516 .33636 .57775 .33207 .57118 .32443 Metetra
.664 .751 .915 r
.57118 .32443 .57775 .33207 .5904 .32776 .58387 .32009 Metetra
.664 .751 .915 r
.58387 .32009 .5904 .32776 .60311 .32344 .59661 .31573 Metetra
.663 .75 .915 r
.59661 .31573 .60311 .32344 .61587 .3191 .60942 .31136 Metetra
.663 .75 .915 r
.60942 .31136 .61587 .3191 .62869 .31475 .62228 .30697 Metetra
.663 .75 .915 r
.62228 .30697 .62869 .31475 .64158 .31039 .63521 .30257 Metetra
.663 .75 .915 r
.63521 .30257 .64158 .31039 .65452 .30601 .64819 .29815 Metetra
.663 .75 .915 r
.64819 .29815 .65452 .30601 .66752 .30161 .66123 .29372 Metetra
.662 .75 .915 r
.66123 .29372 .66752 .30161 .68058 .29721 .67434 .28928 Metetra
.662 .75 .915 r
.67434 .28928 .68058 .29721 .69371 .29279 .68751 .28482 Metetra
.662 .75 .916 r
.68751 .28482 .69371 .29279 .70689 .28835 .70074 .28036 Metetra
.662 .75 .916 r
.70074 .28036 .70689 .28835 .72014 .28391 .71403 .27588 Metetra
.661 .75 .916 r
.71403 .27588 .72014 .28391 .73345 .27945 .72739 .27139 Metetra
.661 .75 .916 r
.72739 .27139 .73345 .27945 .74683 .27499 .74081 .26689 Metetra
.66 .75 .917 r
.74081 .26689 .74683 .27499 .76027 .27052 .7543 .26239 Metetra
.659 .75 .917 r
.7543 .26239 .76027 .27052 .77378 .26606 .76785 .2579 Metetra
.658 .75 .918 r
.76785 .2579 .77378 .26606 .78735 .26161 .78147 .25342 Metetra
.656 .749 .918 r
.78147 .25342 .78735 .26161 .80099 .25719 .79516 .24898 Metetra
.653 .748 .92 r
.79516 .24898 .80099 .25719 .81472 .25286 .80893 .24463 Metetra
.644 .745 .923 r
.80893 .24463 .81472 .25286 .82853 .24878 .8228 .24056 Metetra
.586 .72 .936 r
.8228 .24056 .82853 .24878 .84258 .24622 .83691 .23814 Metetra
.787 .803 .866 r
.21752 .45348 .22531 .45887 .23691 .45064 .2292 .44488 Metetra
.751 .794 .888 r
.2292 .44488 .23691 .45064 .2484 .44401 .24075 .438 Metetra
.727 .786 .899 r
.24075 .438 .2484 .44401 .25984 .43824 .25225 .43204 Metetra
.711 .779 .905 r
.25225 .43204 .25984 .43824 .27129 .43297 .26373 .42663 Metetra
.701 .774 .909 r
.26373 .42663 .27129 .43297 .28274 .42802 .27523 .42156 Metetra
.693 .77 .911 r
.27523 .42156 .28274 .42802 .29422 .42328 .28675 .41673 Metetra
.687 .767 .912 r
.28675 .41673 .29422 .42328 .30574 .4187 .2983 .41206 Metetra
.683 .765 .913 r
.2983 .41206 .30574 .4187 .31729 .41422 .30989 .4075 Metetra
.68 .763 .914 r
.30989 .4075 .31729 .41422 .32888 .40981 .32152 .40303 Metetra
.677 .761 .914 r
.32152 .40303 .32888 .40981 .34051 .40546 .33319 .39862 Metetra
.675 .76 .915 r
.33319 .39862 .34051 .40546 .35219 .40116 .3449 .39425 Metetra
.673 .759 .915 r
.3449 .39425 .35219 .40116 .36392 .39688 .35667 .38992 Metetra
.672 .758 .915 r
.35667 .38992 .36392 .39688 .3757 .39262 .36848 .38561 Metetra
.671 .757 .915 r
.36848 .38561 .3757 .39262 .38752 .38838 .38033 .38132 Metetra
.67 .756 .915 r
.38033 .38132 .38752 .38838 .39939 .38414 .39224 .37704 Metetra
.669 .755 .915 r
.39224 .37704 .39939 .38414 .41132 .37991 .4042 .37276 Metetra
.668 .755 .915 r
.4042 .37276 .41132 .37991 .42329 .37568 .41621 .36849 Metetra
.668 .754 .915 r
.41621 .36849 .42329 .37568 .43532 .37146 .42827 .36422 Metetra
.667 .754 .915 r
.42827 .36422 .43532 .37146 .4474 .36722 .44039 .35994 Metetra
.667 .753 .915 r
.44039 .35994 .4474 .36722 .45953 .36299 .45256 .35566 Metetra
.666 .753 .915 r
.45256 .35566 .45953 .36299 .47171 .35874 .46478 .35138 Metetra
.666 .753 .915 r
.46478 .35138 .47171 .35874 .48395 .35449 .47706 .34709 Metetra
.666 .753 .915 r
.47706 .34709 .48395 .35449 .49625 .35023 .48939 .34279 Metetra
.665 .752 .915 r
.48939 .34279 .49625 .35023 .5086 .34596 .50177 .33848 Metetra
.665 .752 .915 r
.50177 .33848 .5086 .34596 .521 .34168 .51421 .33416 Metetra
.665 .752 .915 r
.51421 .33416 .521 .34168 .53346 .33739 .52671 .32982 Metetra
.664 .752 .915 r
.52671 .32982 .53346 .33739 .54598 .33308 .53927 .32548 Metetra
.664 .752 .915 r
.53927 .32548 .54598 .33308 .55855 .32876 .55188 .32112 Metetra
.664 .751 .915 r
.55188 .32112 .55855 .32876 .57118 .32443 .56455 .31675 Metetra
.664 .751 .915 r
.56455 .31675 .57118 .32443 .58387 .32009 .57728 .31237 Metetra
.664 .751 .915 r
.57728 .31237 .58387 .32009 .59661 .31573 .59006 .30798 Metetra
.663 .751 .915 r
.59006 .30798 .59661 .31573 .60942 .31136 .60291 .30357 Metetra
.663 .751 .916 r
.60291 .30357 .60942 .31136 .62228 .30697 .61582 .29914 Metetra
.663 .751 .916 r
.61582 .29914 .62228 .30697 .63521 .30257 .62878 .2947 Metetra
.663 .751 .916 r
.62878 .2947 .63521 .30257 .64819 .29815 .64181 .29025 Metetra
.663 .751 .916 r
.64181 .29025 .64819 .29815 .66123 .29372 .6549 .28579 Metetra
.662 .751 .916 r
.6549 .28579 .66123 .29372 .67434 .28928 .66804 .28131 Metetra
.662 .751 .916 r
.66804 .28131 .67434 .28928 .68751 .28482 .68126 .27682 Metetra
.662 .751 .916 r
.68126 .27682 .68751 .28482 .70074 .28036 .69453 .27231 Metetra
.661 .751 .916 r
.69453 .27231 .70074 .28036 .71403 .27588 .70787 .2678 Metetra
.661 .751 .917 r
.70787 .2678 .71403 .27588 .72739 .27139 .72127 .26328 Metetra
.661 .751 .917 r
.72127 .26328 .72739 .27139 .74081 .26689 .73474 .25875 Metetra
.66 .751 .917 r
.73474 .25875 .74081 .26689 .7543 .26239 .74827 .25422 Metetra
.659 .751 .918 r
.74827 .25422 .7543 .26239 .76785 .2579 .76187 .24969 Metetra
.658 .75 .918 r
.76187 .24969 .76785 .2579 .78147 .25342 .77554 .24519 Metetra
.656 .75 .919 r
.77554 .24519 .78147 .25342 .79516 .24898 .78928 .24073 Metetra
.652 .749 .921 r
.78928 .24073 .79516 .24898 .80893 .24463 .8031 .23637 Metetra
.642 .745 .924 r
.8031 .23637 .80893 .24463 .8228 .24056 .81702 .2323 Metetra
.579 .718 .938 r
.81702 .2323 .8228 .24056 .83691 .23814 .8312 .23003 Metetra
.794 .807 .862 r
.20965 .4482 .21752 .45348 .2292 .44488 .22142 .43918 Metetra
.757 .798 .886 r
.22142 .43918 .2292 .44488 .24075 .438 .23303 .43203 Metetra
.732 .789 .898 r
.23303 .43203 .24075 .438 .25225 .43204 .24457 .42587 Metetra
.715 .782 .905 r
.24457 .42587 .25225 .43204 .26373 .42663 .25611 .42031 Metetra
.703 .777 .909 r
.25611 .42031 .26373 .42663 .27523 .42156 .26765 .41512 Metetra
.695 .773 .911 r
.26765 .41512 .27523 .42156 .28675 .41673 .27921 .41018 Metetra
.689 .77 .913 r
.27921 .41018 .28675 .41673 .2983 .41206 .2908 .40542 Metetra
.685 .767 .914 r
.2908 .40542 .2983 .41206 .30989 .4075 .30242 .40079 Metetra
.681 .765 .914 r
.30242 .40079 .30989 .4075 .32152 .40303 .31409 .39624 Metetra
.678 .763 .915 r
.31409 .39624 .32152 .40303 .33319 .39862 .3258 .39177 Metetra
.676 .761 .915 r
.3258 .39177 .33319 .39862 .3449 .39425 .33755 .38734 Metetra
.674 .76 .915 r
.33755 .38734 .3449 .39425 .35667 .38992 .34935 .38295 Metetra
.673 .759 .916 r
.34935 .38295 .35667 .38992 .36848 .38561 .36119 .37858 Metetra
.671 .758 .916 r
.36119 .37858 .36848 .38561 .38033 .38132 .37309 .37424 Metetra
.67 .757 .916 r
.37309 .37424 .38033 .38132 .39224 .37704 .38503 .36991 Metetra
.67 .757 .916 r
.38503 .36991 .39224 .37704 .4042 .37276 .39702 .36558 Metetra
.669 .756 .916 r
.39702 .36558 .4042 .37276 .41621 .36849 .40907 .36126 Metetra
.668 .755 .916 r
.40907 .36126 .41621 .36849 .42827 .36422 .42117 .35695 Metetra
.668 .755 .916 r
.42117 .35695 .42827 .36422 .44039 .35994 .43332 .35263 Metetra
.667 .754 .916 r
.43332 .35263 .44039 .35994 .45256 .35566 .44553 .34831 Metetra
.667 .754 .916 r
.44553 .34831 .45256 .35566 .46478 .35138 .45778 .34398 Metetra
.666 .754 .916 r
.45778 .34398 .46478 .35138 .47706 .34709 .4701 .33965 Metetra
.666 .753 .916 r
.4701 .33965 .47706 .34709 .48939 .34279 .48247 .33531 Metetra
.665 .753 .916 r
.48247 .33531 .48939 .34279 .50177 .33848 .49489 .33095 Metetra
.665 .753 .916 r
.49489 .33095 .50177 .33848 .51421 .33416 .50737 .32659 Metetra
.665 .753 .916 r
.50737 .32659 .51421 .33416 .52671 .32982 .51991 .32222 Metetra
.665 .753 .916 r
.51991 .32222 .52671 .32982 .53927 .32548 .5325 .31784 Metetra
.664 .752 .916 r
.5325 .31784 .53927 .32548 .55188 .32112 .54515 .31345 Metetra
.664 .752 .916 r
.54515 .31345 .55188 .32112 .56455 .31675 .55786 .30904 Metetra
.664 .752 .916 r
.55786 .30904 .56455 .31675 .57728 .31237 .57063 .30462 Metetra
.664 .752 .916 r
.57063 .30462 .57728 .31237 .59006 .30798 .58346 .30018 Metetra
.663 .752 .916 r
.58346 .30018 .59006 .30798 .60291 .30357 .59635 .29574 Metetra
.663 .752 .916 r
.59635 .29574 .60291 .30357 .61582 .29914 .60929 .29128 Metetra
.663 .752 .916 r
.60929 .29128 .61582 .29914 .62878 .2947 .6223 .2868 Metetra
.663 .752 .916 r
.6223 .2868 .62878 .2947 .64181 .29025 .63537 .28231 Metetra
.663 .752 .916 r
.63537 .28231 .64181 .29025 .6549 .28579 .6485 .27781 Metetra
.662 .752 .917 r
.6485 .27781 .6549 .28579 .66804 .28131 .66169 .2733 Metetra
.662 .752 .917 r
.66169 .2733 .66804 .28131 .68126 .27682 .67495 .26877 Metetra
.662 .752 .917 r
.67495 .26877 .68126 .27682 .69453 .27231 .68827 .26423 Metetra
.661 .752 .917 r
.68827 .26423 .69453 .27231 .70787 .2678 .70165 .25968 Metetra
.661 .752 .917 r
.70165 .25968 .70787 .2678 .72127 .26328 .7151 .25513 Metetra
.66 .752 .918 r
.7151 .25513 .72127 .26328 .73474 .25875 .72861 .25056 Metetra
.66 .751 .918 r
.72861 .25056 .73474 .25875 .74827 .25422 .74219 .246 Metetra
.659 .751 .918 r
.74219 .246 .74827 .25422 .76187 .24969 .75584 .24145 Metetra
.657 .751 .919 r
.75584 .24145 .76187 .24969 .77554 .24519 .76956 .23692 Metetra
.655 .751 .92 r
.76956 .23692 .77554 .24519 .78928 .24073 .78335 .23244 Metetra
.651 .749 .922 r
.78335 .23244 .78928 .24073 .8031 .23637 .79722 .22807 Metetra
.64 .746 .925 r
.79722 .22807 .8031 .23637 .81702 .2323 .8112 .22402 Metetra
.571 .715 .94 r
.8112 .22402 .81702 .2323 .8312 .23003 .82544 .22191 Metetra
.802 .811 .858 r
.20169 .44306 .20965 .4482 .22142 .43918 .21355 .43358 Metetra
.763 .802 .884 r
.21355 .43358 .22142 .43918 .23303 .43203 .22522 .42613 Metetra
.737 .793 .897 r
.22522 .42613 .23303 .43203 .24457 .42587 .23683 .41975 Metetra
.719 .786 .905 r
.23683 .41975 .24457 .42587 .25611 .42031 .24841 .41402 Metetra
.707 .78 .909 r
.24841 .41402 .25611 .42031 .26765 .41512 .25999 .4087 Metetra
.698 .776 .912 r
.25999 .4087 .26765 .41512 .27921 .41018 .2716 .40365 Metetra
.691 .772 .913 r
.2716 .40365 .27921 .41018 .2908 .40542 .28323 .39879 Metetra
.686 .769 .914 r
.28323 .39879 .2908 .40542 .30242 .40079 .29489 .39407 Metetra
.682 .767 .915 r
.29489 .39407 .30242 .40079 .31409 .39624 .30659 .38945 Metetra
.679 .765 .916 r
.30659 .38945 .31409 .39624 .3258 .39177 .31834 .3849 Metetra
.677 .763 .916 r
.31834 .3849 .3258 .39177 .33755 .38734 .33013 .38041 Metetra
.675 .762 .916 r
.33013 .38041 .33755 .38734 .34935 .38295 .34196 .37596 Metetra
.674 .761 .916 r
.34196 .37596 .34935 .38295 .36119 .37858 .35384 .37154 Metetra
.672 .76 .916 r
.35384 .37154 .36119 .37858 .37309 .37424 .36577 .36714 Metetra
.671 .759 .916 r
.36577 .36714 .37309 .37424 .38503 .36991 .37775 .36276 Metetra
.67 .758 .916 r
.37775 .36276 .38503 .36991 .39702 .36558 .38978 .35838 Metetra
.669 .757 .916 r
.38978 .35838 .39702 .36558 .40907 .36126 .40187 .35402 Metetra
.669 .757 .916 r
.40187 .35402 .40907 .36126 .42117 .35695 .414 .34965 Metetra
.668 .756 .916 r
.414 .34965 .42117 .35695 .43332 .35263 .42619 .34529 Metetra
.667 .756 .916 r
.42619 .34529 .43332 .35263 .44553 .34831 .43843 .34092 Metetra
.667 .755 .916 r
.43843 .34092 .44553 .34831 .45778 .34398 .45073 .33655 Metetra
.666 .755 .916 r
.45073 .33655 .45778 .34398 .4701 .33965 .46308 .33218 Metetra
.666 .754 .916 r
.46308 .33218 .4701 .33965 .48247 .33531 .47549 .32779 Metetra
.666 .754 .916 r
.47549 .32779 .48247 .33531 .49489 .33095 .48795 .3234 Metetra
.665 .754 .916 r
.48795 .3234 .49489 .33095 .50737 .32659 .50047 .319 Metetra
.665 .754 .916 r
.50047 .319 .50737 .32659 .51991 .32222 .51304 .31459 Metetra
.665 .754 .916 r
.51304 .31459 .51991 .32222 .5325 .31784 .52568 .31017 Metetra
.664 .753 .916 r
.52568 .31017 .5325 .31784 .54515 .31345 .53837 .30573 Metetra
.664 .753 .916 r
.53837 .30573 .54515 .31345 .55786 .30904 .55112 .30128 Metetra
.664 .753 .917 r
.55112 .30128 .55786 .30904 .57063 .30462 .56393 .29682 Metetra
.664 .753 .917 r
.56393 .29682 .57063 .30462 .58346 .30018 .5768 .29235 Metetra
.663 .753 .917 r
.5768 .29235 .58346 .30018 .59635 .29574 .58973 .28787 Metetra
.663 .753 .917 r
.58973 .28787 .59635 .29574 .60929 .29128 .60271 .28337 Metetra
.663 .753 .917 r
.60271 .28337 .60929 .29128 .6223 .2868 .61576 .27886 Metetra
.663 .753 .917 r
.61576 .27886 .6223 .2868 .63537 .28231 .62888 .27433 Metetra
.662 .753 .917 r
.62888 .27433 .63537 .28231 .6485 .27781 .64205 .26979 Metetra
.662 .752 .917 r
.64205 .26979 .6485 .27781 .66169 .2733 .65529 .26524 Metetra
.662 .752 .917 r
.65529 .26524 .66169 .2733 .67495 .26877 .66859 .26068 Metetra
.662 .752 .918 r
.66859 .26068 .67495 .26877 .68827 .26423 .68195 .25611 Metetra
.661 .752 .918 r
.68195 .25611 .68827 .26423 .70165 .25968 .69538 .25152 Metetra
.661 .752 .918 r
.69538 .25152 .70165 .25968 .7151 .25513 .70887 .24693 Metetra
.66 .752 .918 r
.70887 .24693 .7151 .25513 .72861 .25056 .72243 .24234 Metetra
.659 .752 .919 r
.72243 .24234 .72861 .25056 .74219 .246 .73606 .23775 Metetra
.658 .752 .919 r
.73606 .23775 .74219 .246 .75584 .24145 .74976 .23317 Metetra
.657 .752 .92 r
.74976 .23317 .75584 .24145 .76956 .23692 .76352 .22861 Metetra
.654 .751 .921 r
.76352 .22861 .76956 .23692 .78335 .23244 .77737 .22411 Metetra
.65 .75 .923 r
.77737 .22411 .78335 .23244 .79722 .22807 .79129 .21973 Metetra
.638 .746 .927 r
.79129 .21973 .79722 .22807 .8112 .22402 .80532 .2157 Metetra
.561 .712 .942 r
.80532 .2157 .8112 .22402 .82544 .22191 .81964 .21379 Metetra
.811 .815 .854 r
.19364 .43806 .20169 .44306 .21355 .43358 .20559 .42809 Metetra
.77 .806 .882 r
.20559 .42809 .21355 .43358 .22522 .42613 .21734 .4203 Metetra
.742 .797 .896 r
.21734 .4203 .22522 .42613 .23683 .41975 .229 .41369 Metetra
.723 .79 .904 r
.229 .41369 .23683 .41975 .24841 .41402 .24063 .40778 Metetra
.71 .784 .909 r
.24063 .40778 .24841 .41402 .25999 .4087 .25227 .40231 Metetra
.701 .779 .912 r
.25227 .40231 .25999 .4087 .2716 .40365 .26391 .39714 Metetra
.694 .775 .914 r
.26391 .39714 .2716 .40365 .28323 .39879 .27558 .39218 Metetra
.688 .772 .915 r
.27558 .39218 .28323 .39879 .29489 .39407 .28729 .38736 Metetra
.684 .769 .916 r
.28729 .38736 .29489 .39407 .30659 .38945 .29903 .38266 Metetra
.681 .767 .916 r
.29903 .38266 .30659 .38945 .31834 .3849 .31081 .37804 Metetra
.678 .765 .917 r
.31081 .37804 .31834 .3849 .33013 .38041 .32264 .37348 Metetra
.676 .764 .917 r
.32264 .37348 .33013 .38041 .34196 .37596 .33451 .36896 Metetra
.674 .762 .917 r
.33451 .36896 .34196 .37596 .35384 .37154 .34643 .36448 Metetra
.673 .761 .917 r
.34643 .36448 .35384 .37154 .36577 .36714 .35839 .36003 Metetra
.672 .76 .917 r
.35839 .36003 .36577 .36714 .37775 .36276 .37041 .35559 Metetra
.671 .759 .917 r
.37041 .35559 .37775 .36276 .38978 .35838 .38248 .35116 Metetra
.67 .759 .917 r
.38248 .35116 .38978 .35838 .40187 .35402 .3946 .34675 Metetra
.669 .758 .917 r
.3946 .34675 .40187 .35402 .414 .34965 .40677 .34234 Metetra
.668 .757 .917 r
.40677 .34234 .414 .34965 .42619 .34529 .419 .33792 Metetra
.668 .757 .917 r
.419 .33792 .42619 .34529 .43843 .34092 .43128 .33351 Metetra
.667 .756 .917 r
.43128 .33351 .43843 .34092 .45073 .33655 .44361 .3291 Metetra
.667 .756 .917 r
.44361 .3291 .45073 .33655 .46308 .33218 .456 .32468 Metetra
.666 .756 .917 r
.456 .32468 .46308 .33218 .47549 .32779 .46845 .32025 Metetra
.666 .755 .917 r
.46845 .32025 .47549 .32779 .48795 .3234 .48095 .31582 Metetra
.665 .755 .917 r
.48095 .31582 .48795 .3234 .50047 .319 .4935 .31137 Metetra
.665 .755 .917 r
.4935 .31137 .50047 .319 .51304 .31459 .50612 .30692 Metetra
.665 .755 .917 r
.50612 .30692 .51304 .31459 .52568 .31017 .51879 .30246 Metetra
.665 .754 .917 r
.51879 .30246 .52568 .31017 .53837 .30573 .53153 .29798 Metetra
.664 .754 .917 r
.53153 .29798 .53837 .30573 .55112 .30128 .54432 .2935 Metetra
.664 .754 .917 r
.54432 .2935 .55112 .30128 .56393 .29682 .55717 .289 Metetra
.664 .754 .917 r
.55717 .289 .56393 .29682 .5768 .29235 .57008 .28449 Metetra
.663 .754 .917 r
.57008 .28449 .5768 .29235 .58973 .28787 .58305 .27996 Metetra
.663 .754 .917 r
.58305 .27996 .58973 .28787 .60271 .28337 .59608 .27543 Metetra
.663 .754 .918 r
.59608 .27543 .60271 .28337 .61576 .27886 .60917 .27088 Metetra
.663 .754 .918 r
.60917 .27088 .61576 .27886 .62888 .27433 .62233 .26631 Metetra
.662 .753 .918 r
.62233 .26631 .62888 .27433 .64205 .26979 .63554 .26174 Metetra
.662 .753 .918 r
.63554 .26174 .64205 .26979 .65529 .26524 .64882 .25715 Metetra
.662 .753 .918 r
.64882 .25715 .65529 .26524 .66859 .26068 .66217 .25255 Metetra
.661 .753 .918 r
.66217 .25255 .66859 .26068 .68195 .25611 .67558 .24794 Metetra
.661 .753 .919 r
.67558 .24794 .68195 .25611 .69538 .25152 .68905 .24333 Metetra
.66 .753 .919 r
.68905 .24333 .69538 .25152 .70887 .24693 .70259 .2387 Metetra
.66 .753 .919 r
.70259 .2387 .70887 .24693 .72243 .24234 .7162 .23408 Metetra
.659 .753 .92 r
.7162 .23408 .72243 .24234 .73606 .23775 .72988 .22946 Metetra
.658 .753 .92 r
.72988 .22946 .73606 .23775 .74976 .23317 .74362 .22485 Metetra
.656 .753 .921 r
.74362 .22485 .74976 .23317 .76352 .22861 .75744 .22027 Metetra
.654 .752 .922 r
.75744 .22027 .76352 .22861 .77737 .22411 .77133 .21575 Metetra
.649 .751 .924 r
.77133 .21575 .77737 .22411 .79129 .21973 .78531 .21137 Metetra
.636 .746 .928 r
.78531 .21137 .79129 .21973 .80532 .2157 .7994 .20737 Metetra
.551 .709 .945 r
.7994 .20737 .80532 .2157 .81964 .21379 .81378 .20568 Metetra
.82 .82 .849 r
.18549 .43325 .19364 .43806 .20559 .42809 .19754 .42272 Metetra
.778 .811 .879 r
.19754 .42272 .20559 .42809 .21734 .4203 .20937 .41457 Metetra
.748 .802 .895 r
.20937 .41457 .21734 .4203 .229 .41369 .22109 .4077 Metetra
.728 .794 .904 r
.22109 .4077 .229 .41369 .24063 .40778 .23278 .40159 Metetra
.714 .787 .909 r
.23278 .40159 .24063 .40778 .25227 .40231 .24446 .39596 Metetra
.704 .782 .912 r
.24446 .39596 .25227 .40231 .26391 .39714 .25615 .39066 Metetra
.696 .778 .914 r
.25615 .39066 .26391 .39714 .27558 .39218 .26787 .38558 Metetra
.69 .774 .916 r
.26787 .38558 .27558 .39218 .28729 .38736 .27961 .38067 Metetra
.686 .772 .916 r
.27961 .38067 .28729 .38736 .29903 .38266 .29139 .37588 Metetra
.682 .769 .917 r
.29139 .37588 .29903 .38266 .31081 .37804 .30321 .37118 Metetra
.68 .767 .917 r
.30321 .37118 .31081 .37804 .32264 .37348 .31508 .36655 Metetra
.677 .766 .918 r
.31508 .36655 .32264 .37348 .33451 .36896 .32699 .36197 Metetra
.675 .764 .918 r
.32699 .36197 .33451 .36896 .34643 .36448 .33894 .35742 Metetra
.674 .763 .918 r
.33894 .35742 .34643 .36448 .35839 .36003 .35095 .35291 Metetra
.672 .762 .918 r
.35095 .35291 .35839 .36003 .37041 .35559 .363 .34841 Metetra
.671 .761 .918 r
.363 .34841 .37041 .35559 .38248 .35116 .37511 .34393 Metetra
.67 .76 .918 r
.37511 .34393 .38248 .35116 .3946 .34675 .38727 .33946 Metetra
.669 .759 .918 r
.38727 .33946 .3946 .34675 .40677 .34234 .39948 .335 Metetra
.669 .759 .918 r
.39948 .335 .40677 .34234 .419 .33792 .41174 .33054 Metetra
.668 .758 .918 r
.41174 .33054 .419 .33792 .43128 .33351 .42406 .32608 Metetra
.667 .758 .918 r
.42406 .32608 .43128 .33351 .44361 .3291 .43643 .32162 Metetra
.667 .757 .918 r
.43643 .32162 .44361 .3291 .456 .32468 .44886 .31715 Metetra
.666 .757 .918 r
.44886 .31715 .456 .32468 .46845 .32025 .46134 .31268 Metetra
.666 .757 .918 r
.46134 .31268 .46845 .32025 .48095 .31582 .47388 .30821 Metetra
.666 .756 .918 r
.47388 .30821 .48095 .31582 .4935 .31137 .48648 .30372 Metetra
.665 .756 .918 r
.48648 .30372 .4935 .31137 .50612 .30692 .49913 .29922 Metetra
.665 .756 .918 r
.49913 .29922 .50612 .30692 .51879 .30246 .51185 .29472 Metetra
.665 .755 .918 r
.51185 .29472 .51879 .30246 .53153 .29798 .52462 .2902 Metetra
.664 .755 .918 r
.52462 .2902 .53153 .29798 .54432 .2935 .53745 .28568 Metetra
.664 .755 .918 r
.53745 .28568 .54432 .2935 .55717 .289 .55034 .28114 Metetra
.664 .755 .918 r
.55034 .28114 .55717 .289 .57008 .28449 .56329 .27659 Metetra
.663 .755 .918 r
.56329 .27659 .57008 .28449 .58305 .27996 .57631 .27202 Metetra
.663 .755 .918 r
.57631 .27202 .58305 .27996 .59608 .27543 .58938 .26745 Metetra
.663 .755 .918 r
.58938 .26745 .59608 .27543 .60917 .27088 .60252 .26286 Metetra
.663 .755 .919 r
.60252 .26286 .60917 .27088 .62233 .26631 .61572 .25826 Metetra
.662 .755 .919 r
.61572 .25826 .62233 .26631 .63554 .26174 .62898 .25365 Metetra
.662 .754 .919 r
.62898 .25365 .63554 .26174 .64882 .25715 .6423 .24903 Metetra
.662 .754 .919 r
.6423 .24903 .64882 .25715 .66217 .25255 .65569 .24439 Metetra
.661 .754 .919 r
.65569 .24439 .66217 .25255 .67558 .24794 .66915 .23975 Metetra
.661 .754 .92 r
.66915 .23975 .67558 .24794 .68905 .24333 .68267 .2351 Metetra
.66 .754 .92 r
.68267 .2351 .68905 .24333 .70259 .2387 .69626 .23044 Metetra
.659 .754 .92 r
.69626 .23044 .70259 .2387 .7162 .23408 .70991 .22579 Metetra
.659 .754 .921 r
.70991 .22579 .7162 .23408 .72988 .22946 .72364 .22114 Metetra
.657 .754 .921 r
.72364 .22114 .72988 .22946 .74362 .22485 .73743 .2165 Metetra
.656 .754 .922 r
.73743 .2165 .74362 .22485 .75744 .22027 .7513 .2119 Metetra
.653 .753 .924 r
.7513 .2119 .75744 .22027 .77133 .21575 .76525 .20737 Metetra
.647 .752 .926 r
.76525 .20737 .77133 .21575 .78531 .21137 .77928 .20299 Metetra
.633 .747 .93 r
.77928 .20299 .78531 .21137 .7994 .20737 .79342 .19903 Metetra
.538 .704 .947 r
.79342 .19903 .7994 .20737 .81378 .20568 .80788 .19759 Metetra
.829 .824 .844 r
.17723 .42866 .18549 .43325 .19754 .42272 .1894 .41751 Metetra
.786 .816 .877 r
.1894 .41751 .19754 .42272 .20937 .41457 .20131 .40896 Metetra
.755 .807 .894 r
.20131 .40896 .20937 .41457 .22109 .4077 .2131 .4018 Metetra
.734 .798 .904 r
.2131 .4018 .22109 .4077 .23278 .40159 .22485 .39547 Metetra
.718 .792 .909 r
.22485 .39547 .23278 .40159 .24446 .39596 .23658 .38967 Metetra
.707 .786 .913 r
.23658 .38967 .24446 .39596 .25615 .39066 .24832 .38422 Metetra
.699 .781 .915 r
.24832 .38422 .25615 .39066 .26787 .38558 .26008 .37902 Metetra
.693 .778 .916 r
.26008 .37902 .26787 .38558 .27961 .38067 .27186 .37401 Metetra
.688 .775 .917 r
.27186 .37401 .27961 .38067 .29139 .37588 .28369 .36912 Metetra
.684 .772 .918 r
.28369 .36912 .29139 .37588 .30321 .37118 .29555 .36434 Metetra
.681 .77 .918 r
.29555 .36434 .30321 .37118 .31508 .36655 .30745 .35963 Metetra
.678 .768 .918 r
.30745 .35963 .31508 .36655 .32699 .36197 .3194 .35497 Metetra
.676 .766 .919 r
.3194 .35497 .32699 .36197 .33894 .35742 .33139 .35036 Metetra
.675 .765 .919 r
.33139 .35036 .33894 .35742 .35095 .35291 .34344 .34578 Metetra
.673 .764 .919 r
.34344 .34578 .35095 .35291 .363 .34841 .35553 .34123 Metetra
.672 .763 .919 r
.35553 .34123 .363 .34841 .37511 .34393 .36767 .33669 Metetra
.671 .762 .919 r
.36767 .33669 .37511 .34393 .38727 .33946 .37987 .33217 Metetra
.67 .761 .919 r
.37987 .33217 .38727 .33946 .39948 .335 .39211 .32765 Metetra
.669 .76 .919 r
.39211 .32765 .39948 .335 .41174 .33054 .40442 .32314 Metetra
.669 .76 .919 r
.40442 .32314 .41174 .33054 .42406 .32608 .41677 .31863 Metetra
.668 .759 .919 r
.41677 .31863 .42406 .32608 .43643 .32162 .42918 .31412 Metetra
.667 .759 .919 r
.42918 .31412 .43643 .32162 .44886 .31715 .44165 .30961 Metetra
.667 .758 .919 r
.44165 .30961 .44886 .31715 .46134 .31268 .45417 .30509 Metetra
.666 .758 .919 r
.45417 .30509 .46134 .31268 .47388 .30821 .46675 .30057 Metetra
.666 .758 .919 r
.46675 .30057 .47388 .30821 .48648 .30372 .47939 .29604 Metetra
.665 .757 .919 r
.47939 .29604 .48648 .30372 .49913 .29922 .49209 .2915 Metetra
.665 .757 .919 r
.49209 .2915 .49913 .29922 .51185 .29472 .50484 .28696 Metetra
.665 .757 .919 r
.50484 .28696 .51185 .29472 .52462 .2902 .51765 .2824 Metetra
.664 .757 .919 r
.51765 .2824 .52462 .2902 .53745 .28568 .53053 .27783 Metetra
.664 .756 .919 r
.53053 .27783 .53745 .28568 .55034 .28114 .54346 .27325 Metetra
.664 .756 .919 r
.54346 .27325 .55034 .28114 .56329 .27659 .55645 .26866 Metetra
.663 .756 .919 r
.55645 .26866 .56329 .27659 .57631 .27202 .56951 .26406 Metetra
.663 .756 .919 r
.56951 .26406 .57631 .27202 .58938 .26745 .58263 .25944 Metetra
.663 .756 .919 r
.58263 .25944 .58938 .26745 .60252 .26286 .59581 .25482 Metetra
.662 .756 .919 r
.59581 .25482 .60252 .26286 .61572 .25826 .60905 .25018 Metetra
.662 .756 .92 r
.60905 .25018 .61572 .25826 .62898 .25365 .62236 .24553 Metetra
.662 .756 .92 r
.62236 .24553 .62898 .25365 .6423 .24903 .63573 .24087 Metetra
.661 .756 .92 r
.63573 .24087 .6423 .24903 .65569 .24439 .64916 .2362 Metetra
.661 .756 .92 r
.64916 .2362 .65569 .24439 .66915 .23975 .66266 .23152 Metetra
.66 .756 .921 r
.66266 .23152 .66915 .23975 .68267 .2351 .67623 .22684 Metetra
.66 .756 .921 r
.67623 .22684 .68267 .2351 .69626 .23044 .68987 .22215 Metetra
.659 .756 .921 r
.68987 .22215 .69626 .23044 .70991 .22579 .70357 .21746 Metetra
.658 .756 .922 r
.70357 .21746 .70991 .22579 .72364 .22114 .71735 .21279 Metetra
.657 .755 .923 r
.71735 .21279 .72364 .22114 .73743 .2165 .73119 .20813 Metetra
.655 .755 .924 r
.73119 .20813 .73743 .2165 .7513 .2119 .74511 .20351 Metetra
.652 .754 .925 r
.74511 .20351 .7513 .2119 .76525 .20737 .75911 .19896 Metetra
.645 .753 .927 r
.75911 .19896 .76525 .20737 .77928 .20299 .77319 .19459 Metetra
.63 .747 .932 r
.77319 .19459 .77928 .20299 .79342 .19903 .78739 .19067 Metetra
.524 .699 .95 r
.78739 .19067 .79342 .19903 .80788 .19759 .80193 .18953 Metetra
.839 .829 .838 r
.16885 .42431 .17723 .42866 .1894 .41751 .18115 .41248 Metetra
.794 .822 .874 r
.18115 .41248 .1894 .41751 .20131 .40896 .19315 .40348 Metetra
.762 .812 .893 r
.19315 .40348 .20131 .40896 .2131 .4018 .20502 .39601 Metetra
.739 .804 .903 r
.20502 .39601 .2131 .4018 .22485 .39547 .21683 .38944 Metetra
.723 .796 .91 r
.21683 .38944 .22485 .39547 .23658 .38967 .22861 .38344 Metetra
.711 .79 .913 r
.22861 .38344 .23658 .38967 .24832 .38422 .2404 .37784 Metetra
.702 .785 .916 r
.2404 .37784 .24832 .38422 .26008 .37902 .25221 .37251 Metetra
.695 .781 .917 r
.25221 .37251 .26008 .37902 .27186 .37401 .26404 .36738 Metetra
.69 .778 .918 r
.26404 .36738 .27186 .37401 .28369 .36912 .2759 .36239 Metetra
.686 .775 .919 r
.2759 .36239 .28369 .36912 .29555 .36434 .2878 .35751 Metetra
.683 .773 .919 r
.2878 .35751 .29555 .36434 .30745 .35963 .29975 .35272 Metetra
.68 .771 .919 r
.29975 .35272 .30745 .35963 .3194 .35497 .31174 .34799 Metetra
.678 .769 .92 r
.31174 .34799 .3194 .35497 .33139 .35036 .32377 .34331 Metetra
.676 .767 .92 r
.32377 .34331 .33139 .35036 .34344 .34578 .33585 .33866 Metetra
.674 .766 .92 r
.33585 .33866 .34344 .34578 .35553 .34123 .34798 .33404 Metetra
.673 .765 .92 r
.34798 .33404 .35553 .34123 .36767 .33669 .36016 .32945 Metetra
.672 .764 .92 r
.36016 .32945 .36767 .33669 .37987 .33217 .3724 .32487 Metetra
.671 .763 .92 r
.3724 .32487 .37987 .33217 .39211 .32765 .38469 .3203 Metetra
.67 .762 .92 r
.38469 .3203 .39211 .32765 .40442 .32314 .39703 .31573 Metetra
.669 .762 .92 r
.39703 .31573 .40442 .32314 .41677 .31863 .40942 .31117 Metetra
.668 .761 .92 r
.40942 .31117 .41677 .31863 .42918 .31412 .42187 .30661 Metetra
.668 .76 .92 r
.42187 .30661 .42918 .31412 .44165 .30961 .43438 .30205 Metetra
.667 .76 .92 r
.43438 .30205 .44165 .30961 .45417 .30509 .44694 .29749 Metetra
.667 .759 .92 r
.44694 .29749 .45417 .30509 .46675 .30057 .45956 .29292 Metetra
.666 .759 .92 r
.45956 .29292 .46675 .30057 .47939 .29604 .47224 .28835 Metetra
.666 .759 .92 r
.47224 .28835 .47939 .29604 .49209 .2915 .48497 .28376 Metetra
.665 .758 .92 r
.48497 .28376 .49209 .2915 .50484 .28696 .49777 .27917 Metetra
.665 .758 .92 r
.49777 .27917 .50484 .28696 .51765 .2824 .51062 .27457 Metetra
.665 .758 .92 r
.51062 .27457 .51765 .2824 .53053 .27783 .52354 .26996 Metetra
.664 .758 .92 r
.52354 .26996 .53053 .27783 .54346 .27325 .53651 .26534 Metetra
.664 .758 .92 r
.53651 .26534 .54346 .27325 .55645 .26866 .54955 .26071 Metetra
.663 .757 .92 r
.54955 .26071 .55645 .26866 .56951 .26406 .56265 .25607 Metetra
.663 .757 .92 r
.56265 .25607 .56951 .26406 .58263 .25944 .57581 .25141 Metetra
.663 .757 .92 r
.57581 .25141 .58263 .25944 .59581 .25482 .58903 .24675 Metetra
.662 .757 .92 r
.58903 .24675 .59581 .25482 .60905 .25018 .60232 .24207 Metetra
.662 .757 .921 r
.60232 .24207 .60905 .25018 .62236 .24553 .61567 .23739 Metetra
.662 .757 .921 r
.61567 .23739 .62236 .24553 .63573 .24087 .62909 .23269 Metetra
.661 .757 .921 r
.62909 .23269 .63573 .24087 .64916 .2362 .64257 .22799 Metetra
.661 .757 .921 r
.64257 .22799 .64916 .2362 .66266 .23152 .65612 .22327 Metetra
.66 .757 .922 r
.65612 .22327 .66266 .23152 .67623 .22684 .66974 .21856 Metetra
.659 .757 .922 r
.66974 .21856 .67623 .22684 .68987 .22215 .68342 .21384 Metetra
.659 .757 .923 r
.68342 .21384 .68987 .22215 .70357 .21746 .69717 .20912 Metetra
.658 .757 .923 r
.69717 .20912 .70357 .21746 .71735 .21279 .711 .20442 Metetra
.656 .757 .924 r
.711 .20442 .71735 .21279 .73119 .20813 .72489 .19973 Metetra
.654 .756 .925 r
.72489 .19973 .73119 .20813 .74511 .20351 .73886 .1951 Metetra
.65 .756 .927 r
.73886 .1951 .74511 .20351 .75911 .19896 .75291 .19055 Metetra
.644 .754 .929 r
.75291 .19055 .75911 .19896 .77319 .19459 .76705 .18618 Metetra
.626 .748 .935 r
.76705 .18618 .77319 .19459 .78739 .19067 .78131 .18233 Metetra
.507 .693 .952 r
.78131 .18233 .78739 .19067 .80193 .18953 .79593 .18151 Metetra
.849 .834 .832 r
.16035 .42026 .16885 .42431 .18115 .41248 .17279 .40766 Metetra
.804 .828 .87 r
.17279 .40766 .18115 .41248 .19315 .40348 .1849 .39817 Metetra
.77 .819 .891 r
.1849 .39817 .19315 .40348 .20502 .39601 .19684 .39035 Metetra
.746 .809 .903 r
.19684 .39035 .20502 .39601 .21683 .38944 .20872 .38351 Metetra
.728 .802 .91 r
.20872 .38351 .21683 .38944 .22861 .38344 .22056 .37731 Metetra
.715 .795 .914 r
.22056 .37731 .22861 .38344 .2404 .37784 .2324 .37153 Metetra
.706 .79 .916 r
.2324 .37153 .2404 .37784 .25221 .37251 .24425 .36606 Metetra
.698 .785 .918 r
.24425 .36606 .25221 .37251 .26404 .36738 .25613 .3608 Metetra
.693 .781 .919 r
.25613 .3608 .26404 .36738 .2759 .36239 .26804 .3557 Metetra
.688 .778 .92 r
.26804 .3557 .2759 .36239 .2878 .35751 .27999 .35073 Metetra
.684 .776 .92 r
.27999 .35073 .2878 .35751 .29975 .35272 .29197 .34584 Metetra
.681 .774 .921 r
.29197 .34584 .29975 .35272 .31174 .34799 .304 .34103 Metetra
.679 .772 .921 r
.304 .34103 .31174 .34799 .32377 .34331 .31607 .33627 Metetra
.677 .77 .921 r
.31607 .33627 .32377 .34331 .33585 .33866 .32819 .33156 Metetra
.675 .769 .921 r
.32819 .33156 .33585 .33866 .34798 .33404 .34037 .32687 Metetra
.674 .767 .921 r
.34037 .32687 .34798 .33404 .36016 .32945 .35259 .32221 Metetra
.672 .766 .921 r
.35259 .32221 .36016 .32945 .3724 .32487 .36486 .31757 Metetra
.671 .765 .921 r
.36486 .31757 .3724 .32487 .38469 .3203 .37719 .31294 Metetra
.67 .764 .921 r
.37719 .31294 .38469 .3203 .39703 .31573 .38957 .30832 Metetra
.67 .764 .921 r
.38957 .30832 .39703 .31573 .40942 .31117 .402 .30371 Metetra
.669 .763 .921 r
.402 .30371 .40942 .31117 .42187 .30661 .41449 .2991 Metetra
.668 .762 .921 r
.41449 .2991 .42187 .30661 .43438 .30205 .42704 .29449 Metetra
.667 .762 .921 r
.42704 .29449 .43438 .30205 .44694 .29749 .43964 .28988 Metetra
.667 .761 .921 r
.43964 .28988 .44694 .29749 .45956 .29292 .4523 .28526 Metetra
.666 .761 .921 r
.4523 .28526 .45956 .29292 .47224 .28835 .46502 .28064 Metetra
.666 .76 .921 r
.46502 .28064 .47224 .28835 .48497 .28376 .4778 .27601 Metetra
.665 .76 .921 r
.4778 .27601 .48497 .28376 .49777 .27917 .49063 .27137 Metetra
.665 .76 .921 r
.49063 .27137 .49777 .27917 .51062 .27457 .50353 .26673 Metetra
.665 .76 .921 r
.50353 .26673 .51062 .27457 .52354 .26996 .51649 .26208 Metetra
.664 .759 .921 r
.51649 .26208 .52354 .26996 .53651 .26534 .5295 .25741 Metetra
.664 .759 .921 r
.5295 .25741 .53651 .26534 .54955 .26071 .54258 .25274 Metetra
.663 .759 .921 r
.54258 .25274 .54955 .26071 .56265 .25607 .55573 .24806 Metetra
.663 .759 .921 r
.55573 .24806 .56265 .25607 .57581 .25141 .56893 .24336 Metetra
.663 .759 .921 r
.56893 .24336 .57581 .25141 .58903 .24675 .5822 .23866 Metetra
.662 .759 .922 r
.5822 .23866 .58903 .24675 .60232 .24207 .59553 .23395 Metetra
.662 .759 .922 r
.59553 .23395 .60232 .24207 .61567 .23739 .60893 .22922 Metetra
.661 .758 .922 r
.60893 .22922 .61567 .23739 .62909 .23269 .62239 .22449 Metetra
.661 .758 .922 r
.62239 .22449 .62909 .23269 .64257 .22799 .63592 .21975 Metetra
.66 .758 .923 r
.63592 .21975 .64257 .22799 .65612 .22327 .64952 .215 Metetra
.66 .758 .923 r
.64952 .215 .65612 .22327 .66974 .21856 .66318 .21025 Metetra
.659 .758 .923 r
.66318 .21025 .66974 .21856 .68342 .21384 .67692 .20551 Metetra
.658 .758 .924 r
.67692 .20551 .68342 .21384 .69717 .20912 .69072 .20076 Metetra
.657 .758 .925 r
.69072 .20076 .69717 .20912 .711 .20442 .70459 .19603 Metetra
.655 .758 .926 r
.70459 .19603 .711 .20442 .72489 .19973 .71854 .19133 Metetra
.653 .758 .927 r
.71854 .19133 .72489 .19973 .73886 .1951 .73256 .18668 Metetra
.649 .757 .928 r
.73256 .18668 .73886 .1951 .75291 .19055 .74667 .18213 Metetra
.641 .755 .931 r
.74667 .18213 .75291 .19055 .76705 .18618 .76086 .17778 Metetra
.622 .748 .937 r
.76086 .17778 .76705 .18618 .78131 .18233 .77519 .17399 Metetra
.486 .685 .955 r
.77519 .17399 .78131 .18233 .79593 .18151 .78989 .17356 Metetra
.86 .84 .824 r
.15172 .41656 .16035 .42026 .17279 .40766 .16432 .4031 Metetra
.814 .835 .866 r
.16432 .4031 .17279 .40766 .1849 .39817 .17654 .39306 Metetra
.779 .825 .889 r
.17654 .39306 .1849 .39817 .19684 .39035 .18857 .38484 Metetra
.753 .816 .902 r
.18857 .38484 .19684 .39035 .20872 .38351 .20051 .37771 Metetra
.734 .807 .91 r
.20051 .37771 .20872 .38351 .22056 .37731 .21242 .37128 Metetra
.72 .8 .914 r
.21242 .37128 .22056 .37731 .2324 .37153 .22431 .36532 Metetra
.71 .795 .917 r
.22431 .36532 .2324 .37153 .24425 .36606 .23622 .35968 Metetra
.702 .79 .919 r
.23622 .35968 .24425 .36606 .25613 .3608 .24814 .35429 Metetra
.695 .786 .92 r
.24814 .35429 .25613 .3608 .26804 .3557 .2601 .34907 Metetra
.69 .782 .921 r
.2601 .34907 .26804 .3557 .27999 .35073 .27209 .34399 Metetra
.686 .779 .922 r
.27209 .34399 .27999 .35073 .29197 .34584 .28412 .33901 Metetra
.683 .777 .922 r
.28412 .33901 .29197 .34584 .304 .34103 .29619 .33411 Metetra
.681 .775 .922 r
.29619 .33411 .304 .34103 .31607 .33627 .3083 .32927 Metetra
.678 .773 .922 r
.3083 .32927 .31607 .33627 .32819 .33156 .32046 .32447 Metetra
.676 .771 .922 r
.32046 .32447 .32819 .33156 .34037 .32687 .33267 .31972 Metetra
.675 .77 .922 r
.33267 .31972 .34037 .32687 .35259 .32221 .34494 .31499 Metetra
.673 .769 .922 r
.34494 .31499 .35259 .32221 .36486 .31757 .35725 .31029 Metetra
.672 .768 .922 r
.35725 .31029 .36486 .31757 .37719 .31294 .36962 .3056 Metetra
.671 .767 .922 r
.36962 .3056 .37719 .31294 .38957 .30832 .38204 .30092 Metetra
.67 .766 .922 r
.38204 .30092 .38957 .30832 .402 .30371 .39451 .29625 Metetra
.669 .765 .922 r
.39451 .29625 .402 .30371 .41449 .2991 .40704 .29159 Metetra
.669 .764 .922 r
.40704 .29159 .41449 .2991 .42704 .29449 .41963 .28692 Metetra
.668 .764 .922 r
.41963 .28692 .42704 .29449 .43964 .28988 .43227 .28226 Metetra
.667 .763 .922 r
.43227 .28226 .43964 .28988 .4523 .28526 .44497 .27759 Metetra
.667 .763 .922 r
.44497 .27759 .4523 .28526 .46502 .28064 .45773 .27292 Metetra
.666 .762 .922 r
.45773 .27292 .46502 .28064 .4778 .27601 .47055 .26825 Metetra
.666 .762 .922 r
.47055 .26825 .4778 .27601 .49063 .27137 .48343 .26357 Metetra
.665 .762 .922 r
.48343 .26357 .49063 .27137 .50353 .26673 .49637 .25888 Metetra
.665 .761 .922 r
.49637 .25888 .50353 .26673 .51649 .26208 .50937 .25418 Metetra
.664 .761 .922 r
.50937 .25418 .51649 .26208 .5295 .25741 .52243 .24948 Metetra
.664 .761 .922 r
.52243 .24948 .5295 .25741 .54258 .25274 .53555 .24476 Metetra
.663 .761 .922 r
.53555 .24476 .54258 .25274 .55573 .24806 .54874 .24004 Metetra
.663 .761 .923 r
.54874 .24004 .55573 .24806 .56893 .24336 .56199 .2353 Metetra
.663 .76 .923 r
.56199 .2353 .56893 .24336 .5822 .23866 .5753 .23056 Metetra
.662 .76 .923 r
.5753 .23056 .5822 .23866 .59553 .23395 .58868 .22581 Metetra
.662 .76 .923 r
.58868 .22581 .59553 .23395 .60893 .22922 .60213 .22105 Metetra
.661 .76 .923 r
.60213 .22105 .60893 .22922 .62239 .22449 .61564 .21628 Metetra
.661 .76 .924 r
.61564 .21628 .62239 .22449 .63592 .21975 .62921 .2115 Metetra
.66 .76 .924 r
.62921 .2115 .63592 .21975 .64952 .215 .64286 .20672 Metetra
.659 .76 .924 r
.64286 .20672 .64952 .215 .66318 .21025 .65657 .20194 Metetra
.659 .76 .925 r
.65657 .20194 .66318 .21025 .67692 .20551 .67035 .19717 Metetra
.658 .76 .926 r
.67035 .19717 .67692 .20551 .69072 .20076 .68421 .19239 Metetra
.656 .76 .926 r
.68421 .19239 .69072 .20076 .70459 .19603 .69813 .18764 Metetra
.654 .76 .927 r
.69813 .18764 .70459 .19603 .71854 .19133 .71213 .18292 Metetra
.652 .76 .929 r
.71213 .18292 .71854 .19133 .73256 .18668 .72621 .17826 Metetra
.647 .759 .93 r
.72621 .17826 .73256 .18668 .74667 .18213 .74037 .17371 Metetra
.639 .757 .934 r
.74037 .17371 .74667 .18213 .76086 .17778 .75462 .16939 Metetra
.617 .749 .94 r
.75462 .16939 .76086 .17778 .77519 .17399 .76901 .16569 Metetra
.462 .676 .957 r
.76901 .16569 .77519 .17399 .78989 .17356 .7838 .1657 Metetra
.871 .845 .816 r
.14295 .41327 .15172 .41656 .16432 .4031 .15572 .39885 Metetra
.825 .842 .861 r
.15572 .39885 .16432 .4031 .17654 .39306 .16806 .38819 Metetra
.788 .833 .886 r
.16806 .38819 .17654 .39306 .18857 .38484 .18019 .37953 Metetra
.761 .823 .901 r
.18019 .37953 .18857 .38484 .20051 .37771 .19221 .37208 Metetra
.74 .814 .91 r
.19221 .37208 .20051 .37771 .21242 .37128 .20418 .36539 Metetra
.725 .807 .915 r
.20418 .36539 .21242 .37128 .22431 .36532 .21614 .35921 Metetra
.714 .8 .918 r
.21614 .35921 .22431 .36532 .23622 .35968 .22809 .3534 Metetra
.705 .795 .92 r
.22809 .3534 .23622 .35968 .24814 .35429 .24007 .34786 Metetra
.698 .79 .922 r
.24007 .34786 .24814 .35429 .2601 .34907 .25207 .34251 Metetra
.693 .787 .922 r
.25207 .34251 .2601 .34907 .27209 .34399 .26411 .33731 Metetra
.689 .783 .923 r
.26411 .33731 .27209 .34399 .28412 .33901 .27618 .33223 Metetra
.685 .781 .923 r
.27618 .33223 .28412 .33901 .29619 .33411 .28829 .32723 Metetra
.682 .778 .923 r
.28829 .32723 .29619 .33411 .3083 .32927 .30045 .3223 Metetra
.68 .776 .924 r
.30045 .3223 .3083 .32927 .32046 .32447 .31265 .31743 Metetra
.678 .775 .924 r
.31265 .31743 .32046 .32447 .33267 .31972 .32491 .3126 Metetra
.676 .773 .924 r
.32491 .3126 .33267 .31972 .34494 .31499 .33721 .3078 Metetra
.674 .772 .924 r
.33721 .3078 .34494 .31499 .35725 .31029 .34957 .30303 Metetra
.673 .77 .924 r
.34957 .30303 .35725 .31029 .36962 .3056 .36197 .29827 Metetra
.672 .769 .923 r
.36197 .29827 .36962 .3056 .38204 .30092 .37443 .29354 Metetra
.671 .768 .923 r
.37443 .29354 .38204 .30092 .39451 .29625 .38695 .28881 Metetra
.67 .768 .923 r
.38695 .28881 .39451 .29625 .40704 .29159 .39952 .28408 Metetra
.669 .767 .923 r
.39952 .28408 .40704 .29159 .41963 .28692 .41215 .27937 Metetra
.668 .766 .923 r
.41215 .27937 .41963 .28692 .43227 .28226 .42483 .27465 Metetra
.668 .766 .923 r
.42483 .27465 .43227 .28226 .44497 .27759 .43758 .26993 Metetra
.667 .765 .923 r
.43758 .26993 .44497 .27759 .45773 .27292 .45038 .26521 Metetra
.666 .765 .923 r
.45038 .26521 .45773 .27292 .47055 .26825 .46324 .26049 Metetra
.666 .764 .923 r
.46324 .26049 .47055 .26825 .48343 .26357 .47616 .25576 Metetra
.665 .764 .923 r
.47616 .25576 .48343 .26357 .49637 .25888 .48914 .25103 Metetra
.665 .763 .923 r
.48914 .25103 .49637 .25888 .50937 .25418 .50219 .24628 Metetra
.664 .763 .924 r
.50219 .24628 .50937 .25418 .52243 .24948 .51529 .24153 Metetra
.664 .763 .924 r
.51529 .24153 .52243 .24948 .53555 .24476 .52846 .23678 Metetra
.663 .763 .924 r
.52846 .23678 .53555 .24476 .54874 .24004 .54169 .23201 Metetra
.663 .762 .924 r
.54169 .23201 .54874 .24004 .56199 .2353 .55499 .22724 Metetra
.663 .762 .924 r
.55499 .22724 .56199 .2353 .5753 .23056 .56834 .22245 Metetra
.662 .762 .924 r
.56834 .22245 .5753 .23056 .58868 .22581 .58177 .21766 Metetra
.662 .762 .925 r
.58177 .21766 .58868 .22581 .60213 .22105 .59526 .21287 Metetra
.661 .762 .925 r
.59526 .21287 .60213 .22105 .61564 .21628 .60882 .20806 Metetra
.66 .762 .925 r
.60882 .20806 .61564 .21628 .62921 .2115 .62244 .20325 Metetra
.66 .762 .926 r
.62244 .20325 .62921 .2115 .64286 .20672 .63614 .19844 Metetra
.659 .762 .926 r
.63614 .19844 .64286 .20672 .65657 .20194 .6499 .19363 Metetra
.658 .762 .927 r
.6499 .19363 .65657 .20194 .67035 .19717 .66373 .18882 Metetra
.657 .762 .927 r
.66373 .18882 .67035 .19717 .68421 .19239 .67763 .18403 Metetra
.655 .762 .928 r
.67763 .18403 .68421 .19239 .69813 .18764 .69161 .17926 Metetra
.653 .762 .929 r
.69161 .17926 .69813 .18764 .71213 .18292 .70566 .17452 Metetra
.65 .762 .931 r
.70566 .17452 .71213 .18292 .72621 .17826 .71979 .16986 Metetra
.645 .761 .933 r
.71979 .16986 .72621 .17826 .74037 .17371 .73401 .16532 Metetra
.636 .758 .936 r
.73401 .16532 .74037 .17371 .75462 .16939 .74832 .16103 Metetra
.611 .75 .944 r
.74832 .16103 .75462 .16939 .76901 .16569 .76277 .15744 Metetra
.433 .664 .958 r
.76277 .15744 .76901 .16569 .7838 .1657 .77766 .15796 Metetra
.882 .851 .807 r
.13401 .41047 .14295 .41327 .15572 .39885 .14699 .39496 Metetra
.836 .849 .855 r
.14699 .39496 .15572 .39885 .16806 .38819 .15946 .3836 Metetra
.798 .841 .883 r
.15946 .3836 .16806 .38819 .18019 .37953 .17169 .37446 Metetra
.769 .831 .9 r
.17169 .37446 .18019 .37953 .19221 .37208 .1838 .36663 Metetra
.748 .822 .91 r
.1838 .36663 .19221 .37208 .20418 .36539 .19584 .35965 Metetra
.731 .813 .916 r
.19584 .35965 .20418 .36539 .21614 .35921 .20786 .35325 Metetra
.719 .807 .919 r
.20786 .35325 .21614 .35921 .22809 .3534 .21988 .34724 Metetra
.709 .801 .922 r
.21988 .34724 .22809 .3534 .24007 .34786 .2319 .34153 Metetra
.702 .796 .923 r
.2319 .34153 .24007 .34786 .25207 .34251 .24396 .33604 Metetra
.696 .792 .924 r
.24396 .33604 .25207 .34251 .26411 .33731 .25604 .33072 Metetra
.691 .788 .925 r
.25604 .33072 .26411 .33731 .27618 .33223 .26816 .32552 Metetra
.687 .785 .925 r
.26816 .32552 .27618 .33223 .28829 .32723 .28032 .32042 Metetra
.684 .782 .925 r
.28032 .32042 .28829 .32723 .30045 .3223 .29252 .31539 Metetra
.681 .78 .925 r
.29252 .31539 .30045 .3223 .31265 .31743 .30477 .31043 Metetra
.679 .778 .925 r
.30477 .31043 .31265 .31743 .32491 .3126 .31706 .30552 Metetra
.677 .777 .925 r
.31706 .30552 .32491 .3126 .33721 .3078 .32941 .30065 Metetra
.676 .775 .925 r
.32941 .30065 .33721 .3078 .34957 .30303 .3418 .2958 Metetra
.674 .774 .925 r
.3418 .2958 .34957 .30303 .36197 .29827 .35425 .29098 Metetra
.673 .772 .925 r
.35425 .29098 .36197 .29827 .37443 .29354 .36676 .28618 Metetra
.672 .771 .925 r
.36676 .28618 .37443 .29354 .38695 .28881 .37931 .28139 Metetra
.671 .77 .925 r
.37931 .28139 .38695 .28881 .39952 .28408 .39193 .27661 Metetra
.67 .77 .925 r
.39193 .27661 .39952 .28408 .41215 .27937 .4046 .27183 Metetra
.669 .769 .925 r
.4046 .27183 .41215 .27937 .42483 .27465 .41732 .26706 Metetra
.668 .768 .925 r
.41732 .26706 .42483 .27465 .43758 .26993 .43011 .26229 Metetra
.667 .768 .925 r
.43011 .26229 .43758 .26993 .45038 .26521 .44295 .25752 Metetra
.667 .767 .925 r
.44295 .25752 .45038 .26521 .46324 .26049 .45586 .25274 Metetra
.666 .767 .925 r
.45586 .25274 .46324 .26049 .47616 .25576 .46882 .24796 Metetra
.666 .766 .925 r
.46882 .24796 .47616 .25576 .48914 .25103 .48185 .24318 Metetra
.665 .766 .925 r
.48185 .24318 .48914 .25103 .50219 .24628 .49494 .23839 Metetra
.664 .765 .925 r
.49494 .23839 .50219 .24628 .51529 .24153 .50808 .2336 Metetra
.664 .765 .925 r
.50808 .2336 .51529 .24153 .52846 .23678 .5213 .2288 Metetra
.663 .765 .925 r
.5213 .2288 .52846 .23678 .54169 .23201 .53457 .22399 Metetra
.663 .765 .926 r
.53457 .22399 .54169 .23201 .55499 .22724 .54791 .21918 Metetra
.662 .765 .926 r
.54791 .21918 .55499 .22724 .56834 .22245 .56132 .21435 Metetra
.662 .764 .926 r
.56132 .21435 .56834 .22245 .58177 .21766 .57479 .20953 Metetra
.661 .764 .926 r
.57479 .20953 .58177 .21766 .59526 .21287 .58833 .20469 Metetra
.661 .764 .927 r
.58833 .20469 .59526 .21287 .60882 .20806 .60194 .19985 Metetra
.66 .764 .927 r
.60194 .19985 .60882 .20806 .62244 .20325 .61561 .19501 Metetra
.659 .764 .927 r
.61561 .19501 .62244 .20325 .63614 .19844 .62935 .19017 Metetra
.658 .764 .928 r
.62935 .19017 .63614 .19844 .6499 .19363 .64316 .18533 Metetra
.657 .764 .929 r
.64316 .18533 .6499 .19363 .66373 .18882 .65705 .1805 Metetra
.656 .764 .929 r
.65705 .1805 .66373 .18882 .67763 .18403 .671 .17568 Metetra
.654 .764 .93 r
.671 .17568 .67763 .18403 .69161 .17926 .68503 .17089 Metetra
.652 .764 .932 r
.68503 .17089 .69161 .17926 .70566 .17452 .69914 .16614 Metetra
.649 .764 .933 r
.69914 .16614 .70566 .17452 .71979 .16986 .71333 .16148 Metetra
.643 .763 .936 r
.71333 .16148 .71979 .16986 .73401 .16532 .7276 .15695 Metetra
.632 .76 .94 r
.7276 .15695 .73401 .16532 .74832 .16103 .74197 .15272 Metetra
.604 .75 .947 r
.74197 .15272 .74832 .16103 .76277 .15744 .75649 .14925 Metetra
.398 .648 .958 r
.75649 .14925 .76277 .15744 .77766 .15796 .77148 .15036 Metetra
.894 .856 .797 r
.1249 .40824 .13401 .41047 .14699 .39496 .1381 .3915 Metetra
.848 .857 .849 r
.1381 .3915 .14699 .39496 .15946 .3836 .15073 .37935 Metetra
.809 .85 .88 r
.15073 .37935 .15946 .3836 .17169 .37446 .16307 .36966 Metetra
.779 .84 .898 r
.16307 .36966 .17169 .37446 .1838 .36663 .17527 .36142 Metetra
.756 .83 .909 r
.17527 .36142 .1838 .36663 .19584 .35965 .18739 .35412 Metetra
.738 .821 .916 r
.18739 .35412 .19584 .35965 .20786 .35325 .19948 .34746 Metetra
.725 .814 .92 r
.19948 .34746 .20786 .35325 .21988 .34724 .21156 .34124 Metetra
.714 .807 .923 r
.21156 .34124 .21988 .34724 .2319 .34153 .22364 .33534 Metetra
.706 .802 .925 r
.22364 .33534 .2319 .34153 .24396 .33604 .23575 .32969 Metetra
.699 .797 .926 r
.23575 .32969 .24396 .33604 .25604 .33072 .24788 .32423 Metetra
.694 .794 .926 r
.24788 .32423 .25604 .33072 .26816 .32552 .26005 .3189 Metetra
.69 .79 .927 r
.26005 .3189 .26816 .32552 .28032 .32042 .27225 .31369 Metetra
.686 .787 .927 r
.27225 .31369 .28032 .32042 .29252 .31539 .2845 .30856 Metetra
.683 .785 .927 r
.2845 .30856 .29252 .31539 .30477 .31043 .29679 .30351 Metetra
.681 .782 .927 r
.29679 .30351 .30477 .31043 .31706 .30552 .30913 .29851 Metetra
.679 .781 .927 r
.30913 .29851 .31706 .30552 .32941 .30065 .32152 .29355 Metetra
.677 .779 .927 r
.32152 .29355 .32941 .30065 .3418 .2958 .33396 .28863 Metetra
.675 .777 .927 r
.33396 .28863 .3418 .2958 .35425 .29098 .34645 .28374 Metetra
.674 .776 .927 r
.34645 .28374 .35425 .29098 .36676 .28618 .359 .27886 Metetra
.673 .775 .927 r
.359 .27886 .36676 .28618 .37931 .28139 .3716 .27401 Metetra
.671 .774 .927 r
.3716 .27401 .37931 .28139 .39193 .27661 .38426 .26916 Metetra
.67 .773 .927 r
.38426 .26916 .39193 .27661 .4046 .27183 .39697 .26433 Metetra
.669 .772 .927 r
.39697 .26433 .4046 .27183 .41732 .26706 .40974 .2595 Metetra
.669 .771 .927 r
.40974 .2595 .41732 .26706 .43011 .26229 .42257 .25467 Metetra
.668 .77 .927 r
.42257 .25467 .43011 .26229 .44295 .25752 .43546 .24984 Metetra
.667 .77 .927 r
.43546 .24984 .44295 .25752 .45586 .25274 .4484 .24502 Metetra
.666 .769 .927 r
.4484 .24502 .45586 .25274 .46882 .24796 .46141 .24019 Metetra
.666 .769 .927 r
.46141 .24019 .46882 .24796 .48185 .24318 .47448 .23536 Metetra
.665 .768 .927 r
.47448 .23536 .48185 .24318 .49494 .23839 .48761 .23052 Metetra
.665 .768 .927 r
.48761 .23052 .49494 .23839 .50808 .2336 .50081 .22568 Metetra
.664 .768 .927 r
.50081 .22568 .50808 .2336 .5213 .2288 .51407 .22084 Metetra
.663 .768 .927 r
.51407 .22084 .5213 .2288 .53457 .22399 .52739 .21599 Metetra
.663 .767 .927 r
.52739 .21599 .53457 .22399 .54791 .21918 .54078 .21113 Metetra
.662 .767 .928 r
.54078 .21113 .54791 .21918 .56132 .21435 .55423 .20627 Metetra
.662 .767 .928 r
.55423 .20627 .56132 .21435 .57479 .20953 .56775 .2014 Metetra
.661 .767 .928 r
.56775 .2014 .57479 .20953 .58833 .20469 .58134 .19653 Metetra
.66 .767 .929 r
.58134 .19653 .58833 .20469 .60194 .19985 .59499 .19166 Metetra
.66 .767 .929 r
.59499 .19166 .60194 .19985 .61561 .19501 .60871 .18679 Metetra
.659 .767 .93 r
.60871 .18679 .61561 .19501 .62935 .19017 .62251 .18191 Metetra
.658 .767 .93 r
.62251 .18191 .62935 .19017 .64316 .18533 .63637 .17705 Metetra
.657 .767 .931 r
.63637 .17705 .64316 .18533 .65705 .1805 .6503 .17219 Metetra
.655 .767 .932 r
.6503 .17219 .65705 .1805 .671 .17568 .66431 .16735 Metetra
.653 .767 .933 r
.66431 .16735 .671 .17568 .68503 .17089 .6784 .16255 Metetra
.651 .767 .934 r
.6784 .16255 .68503 .17089 .69914 .16614 .69256 .1578 Metetra
.647 .767 .936 r
.69256 .1578 .69914 .16614 .71333 .16148 .7068 .15314 Metetra
.64 .765 .939 r
.7068 .15314 .71333 .16148 .7276 .15695 .72113 .14864 Metetra
.628 .762 .943 r
.72113 .14864 .7276 .15695 .74197 .15272 .73557 .14447 Metetra
.595 .751 .952 r
.73557 .14447 .74197 .15272 .75649 .14925 .75016 .14115 Metetra
.355 .628 .956 r
.75016 .14115 .75649 .14925 .77148 .15036 .76525 .14296 Metetra
.906 .862 .786 r
.11559 .40669 .1249 .40824 .1381 .3915 .12904 .38855 Metetra
.861 .866 .841 r
.12904 .38855 .1381 .3915 .15073 .37935 .14184 .37551 Metetra
.821 .86 .876 r
.14184 .37551 .15073 .37935 .16307 .36966 .15432 .36519 Metetra
.789 .85 .896 r
.15432 .36519 .16307 .36966 .17527 .36142 .16662 .35649 Metetra
.765 .84 .909 r
.16662 .35649 .17527 .36142 .18739 .35412 .17883 .34883 Metetra
.746 .83 .917 r
.17883 .34883 .18739 .35412 .19948 .34746 .19099 .34188 Metetra
.731 .822 .921 r
.19099 .34188 .19948 .34746 .21156 .34124 .20313 .33542 Metetra
.719 .815 .924 r
.20313 .33542 .21156 .34124 .22364 .33534 .21528 .32932 Metetra
.711 .809 .926 r
.21528 .32932 .22364 .33534 .23575 .32969 .22744 .32349 Metetra
.703 .804 .928 r
.22744 .32349 .23575 .32969 .24788 .32423 .23963 .31787 Metetra
.698 .8 .928 r
.23963 .31787 .24788 .32423 .26005 .3189 .25185 .31241 Metetra
.693 .796 .929 r
.25185 .31241 .26005 .3189 .27225 .31369 .2641 .30707 Metetra
.689 .793 .929 r
.2641 .30707 .27225 .31369 .2845 .30856 .2764 .30183 Metetra
.686 .79 .929 r
.2764 .30183 .2845 .30856 .29679 .30351 .28874 .29667 Metetra
.683 .787 .929 r
.28874 .29667 .29679 .30351 .30913 .29851 .30112 .29158 Metetra
.68 .785 .929 r
.30112 .29158 .30913 .29851 .32152 .29355 .31355 .28653 Metetra
.678 .783 .929 r
.31355 .28653 .32152 .29355 .33396 .28863 .32604 .28153 Metetra
.676 .782 .929 r
.32604 .28153 .33396 .28863 .34645 .28374 .33858 .27656 Metetra
.675 .78 .929 r
.33858 .27656 .34645 .28374 .359 .27886 .35116 .27161 Metetra
.674 .779 .929 r
.35116 .27161 .359 .27886 .3716 .27401 .36381 .26668 Metetra
.672 .778 .929 r
.36381 .26668 .3716 .27401 .38426 .26916 .37651 .26177 Metetra
.671 .776 .929 r
.37651 .26177 .38426 .26916 .39697 .26433 .38927 .25687 Metetra
.67 .775 .929 r
.38927 .25687 .39697 .26433 .40974 .2595 .40208 .25198 Metetra
.669 .775 .929 r
.40208 .25198 .40974 .2595 .42257 .25467 .41495 .24709 Metetra
.668 .774 .929 r
.41495 .24709 .42257 .25467 .43546 .24984 .42788 .24221 Metetra
.668 .773 .929 r
.42788 .24221 .43546 .24984 .4484 .24502 .44088 .23733 Metetra
.667 .773 .929 r
.44088 .23733 .4484 .24502 .46141 .24019 .45393 .23245 Metetra
.666 .772 .929 r
.45393 .23245 .46141 .24019 .47448 .23536 .46704 .22757 Metetra
.665 .772 .929 r
.46704 .22757 .47448 .23536 .48761 .23052 .48022 .22269 Metetra
.665 .771 .929 r
.48022 .22269 .48761 .23052 .50081 .22568 .49346 .2178 Metetra
.664 .771 .929 r
.49346 .2178 .50081 .22568 .51407 .22084 .50677 .21291 Metetra
.663 .771 .929 r
.50677 .21291 .51407 .22084 .52739 .21599 .52014 .20802 Metetra
.663 .77 .93 r
.52014 .20802 .52739 .21599 .54078 .21113 .53357 .20312 Metetra
.662 .77 .93 r
.53357 .20312 .54078 .21113 .55423 .20627 .54707 .19822 Metetra
.661 .77 .93 r
.54707 .19822 .55423 .20627 .56775 .2014 .56064 .19331 Metetra
.661 .77 .93 r
.56064 .19331 .56775 .2014 .58134 .19653 .57427 .18841 Metetra
.66 .77 .931 r
.57427 .18841 .58134 .19653 .59499 .19166 .58798 .1835 Metetra
.659 .77 .931 r
.58798 .1835 .59499 .19166 .60871 .18679 .60175 .17859 Metetra
.658 .77 .932 r
.60175 .17859 .60871 .18679 .62251 .18191 .6156 .17369 Metetra
.657 .77 .933 r
.6156 .17369 .62251 .18191 .63637 .17705 .62951 .1688 Metetra
.656 .77 .933 r
.62951 .1688 .63637 .17705 .6503 .17219 .6435 .16393 Metetra
.654 .77 .934 r
.6435 .16393 .6503 .17219 .66431 .16735 .65756 .15908 Metetra
.652 .77 .936 r
.65756 .15908 .66431 .16735 .6784 .16255 .6717 .15426 Metetra
.649 .77 .937 r
.6717 .15426 .6784 .16255 .69256 .1578 .68592 .14951 Metetra
.644 .77 .939 r
.68592 .14951 .69256 .1578 .7068 .15314 .70022 .14487 Metetra
.637 .768 .942 r
.70022 .14487 .7068 .15314 .72113 .14864 .71461 .1404 Metetra
.623 .765 .947 r
.71461 .1404 .72113 .14864 .73557 .14447 .72911 .13631 Metetra
.585 .751 .957 r
.72911 .13631 .73557 .14447 .75016 .14115 .74377 .13318 Metetra
.301 .602 .95 r
.74377 .13318 .75016 .14115 .76525 .14296 .75898 .1358 Metetra
.918 .867 .773 r
.10605 .40596 .11559 .40669 .12904 .38855 .1198 .38622 Metetra
.875 .875 .832 r
.1198 .38622 .12904 .38855 .14184 .37551 .1328 .37216 Metetra
.834 .87 .87 r
.1328 .37216 .14184 .37551 .15432 .36519 .14542 .36113 Metetra
.801 .861 .894 r
.14542 .36113 .15432 .36519 .16662 .35649 .15783 .3519 Metetra
.774 .851 .908 r
.15783 .3519 .16662 .35649 .17883 .34883 .17014 .34384 Metetra
.754 .841 .917 r
.17014 .34384 .17883 .34883 .19099 .34188 .18238 .33655 Metetra
.738 .832 .923 r
.18238 .33655 .19099 .34188 .20313 .33542 .1946 .32982 Metetra
.725 .824 .926 r
.1946 .32982 .20313 .33542 .21528 .32932 .20681 .3235 Metetra
.716 .818 .928 r
.20681 .3235 .21528 .32932 .22744 .32349 .21903 .31747 Metetra
.708 .812 .93 r
.21903 .31747 .22744 .32349 .23963 .31787 .23127 .31168 Metetra
.701 .807 .931 r
.23127 .31168 .23963 .31787 .25185 .31241 .24355 .30606 Metetra
.696 .803 .931 r
.24355 .30606 .25185 .31241 .2641 .30707 .25585 .30059 Metetra
.692 .799 .932 r
.25585 .30059 .2641 .30707 .2764 .30183 .2682 .29523 Metetra
.688 .796 .932 r
.2682 .29523 .2764 .30183 .28874 .29667 .28059 .28996 Metetra
.685 .793 .932 r
.28059 .28996 .28874 .29667 .30112 .29158 .29302 .28476 Metetra
.682 .791 .932 r
.29302 .28476 .30112 .29158 .31355 .28653 .3055 .27961 Metetra
.68 .788 .932 r
.3055 .27961 .31355 .28653 .32604 .28153 .31803 .27452 Metetra
.678 .787 .932 r
.31803 .27452 .32604 .28153 .33858 .27656 .33061 .26946 Metetra
.676 .785 .931 r
.33061 .26946 .33858 .27656 .35116 .27161 .34325 .26444 Metetra
.675 .783 .931 r
.34325 .26444 .35116 .27161 .36381 .26668 .35593 .25943 Metetra
.673 .782 .931 r
.35593 .25943 .36381 .26668 .37651 .26177 .36868 .25445 Metetra
.672 .781 .931 r
.36868 .25445 .37651 .26177 .38927 .25687 .38148 .24948 Metetra
.671 .78 .931 r
.38148 .24948 .38927 .25687 .40208 .25198 .39434 .24453 Metetra
.67 .779 .931 r
.39434 .24453 .40208 .25198 .41495 .24709 .40726 .23958 Metetra
.669 .778 .931 r
.40726 .23958 .41495 .24709 .42788 .24221 .42023 .23464 Metetra
.668 .777 .931 r
.42023 .23464 .42788 .24221 .44088 .23733 .43327 .2297 Metetra
.667 .776 .931 r
.43327 .2297 .44088 .23733 .45393 .23245 .44637 .22477 Metetra
.666 .776 .931 r
.44637 .22477 .45393 .23245 .46704 .22757 .45953 .21983 Metetra
.666 .775 .931 r
.45953 .21983 .46704 .22757 .48022 .22269 .47276 .2149 Metetra
.665 .775 .931 r
.47276 .2149 .48022 .22269 .49346 .2178 .48604 .20997 Metetra
.664 .774 .932 r
.48604 .20997 .49346 .2178 .50677 .21291 .4994 .20503 Metetra
.663 .774 .932 r
.4994 .20503 .50677 .21291 .52014 .20802 .51281 .20009 Metetra
.663 .774 .932 r
.51281 .20009 .52014 .20802 .53357 .20312 .52629 .19515 Metetra
.662 .774 .932 r
.52629 .19515 .53357 .20312 .54707 .19822 .53984 .19021 Metetra
.661 .773 .933 r
.53984 .19021 .54707 .19822 .56064 .19331 .55346 .18527 Metetra
.66 .773 .933 r
.55346 .18527 .56064 .19331 .57427 .18841 .56715 .18033 Metetra
.659 .773 .934 r
.56715 .18033 .57427 .18841 .58798 .1835 .5809 .17539 Metetra
.658 .773 .934 r
.5809 .17539 .58798 .1835 .60175 .17859 .59472 .17046 Metetra
.657 .773 .935 r
.59472 .17046 .60175 .17859 .6156 .17369 .60862 .16553 Metetra
.656 .773 .936 r
.60862 .16553 .6156 .17369 .62951 .1688 .62259 .16062 Metetra
.654 .774 .936 r
.62259 .16062 .62951 .1688 .6435 .16393 .63663 .15572 Metetra
.652 .774 .938 r
.63663 .15572 .6435 .16393 .65756 .15908 .65075 .15086 Metetra
.65 .774 .939 r
.65075 .15086 .65756 .15908 .6717 .15426 .66494 .14605 Metetra
.647 .774 .941 r
.66494 .14605 .6717 .15426 .68592 .14951 .67922 .14131 Metetra
.641 .773 .943 r
.67922 .14131 .68592 .14951 .70022 .14487 .69358 .13668 Metetra
.633 .772 .947 r
.69358 .13668 .70022 .14487 .71461 .1404 .70804 .13227 Metetra
.617 .767 .952 r
.70804 .13227 .71461 .1404 .72911 .13631 .7226 .12827 Metetra
.572 .752 .962 r
.7226 .12827 .72911 .13631 .74377 .13318 .73734 .12537 Metetra
.234 .567 .938 r
.73734 .12537 .74377 .13318 .75898 .1358 .75267 .12894 Metetra
.93 .873 .76 r
.09626 .4062 .10605 .40596 .1198 .38622 .11035 .38462 Metetra
.889 .884 .822 r
.11035 .38462 .1198 .38622 .1328 .37216 .12357 .36939 Metetra
.848 .882 .864 r
.12357 .36939 .1328 .37216 .14542 .36113 .13636 .35755 Metetra
.814 .873 .89 r
.13636 .35755 .14542 .36113 .15783 .3519 .1489 .34773 Metetra
.785 .863 .907 r
.1489 .34773 .15783 .3519 .17014 .34384 .16131 .3392 Metetra
.763 .852 .917 r
.16131 .3392 .17014 .34384 .18238 .33655 .17364 .33154 Metetra
.746 .843 .924 r
.17364 .33154 .18238 .33655 .1946 .32982 .18594 .32451 Metetra
.732 .835 .928 r
.18594 .32451 .1946 .32982 .20681 .3235 .19822 .31792 Metetra
.721 .827 .931 r
.19822 .31792 .20681 .3235 .21903 .31747 .21051 .31168 Metetra
.713 .821 .932 r
.21051 .31168 .21903 .31747 .23127 .31168 .22281 .30569 Metetra
.706 .815 .933 r
.22281 .30569 .23127 .31168 .24355 .30606 .23514 .29991 Metetra
.7 .811 .934 r
.23514 .29991 .24355 .30606 .25585 .30059 .2475 .29428 Metetra
.695 .807 .934 r
.2475 .29428 .25585 .30059 .2682 .29523 .2599 .28878 Metetra
.691 .803 .935 r
.2599 .28878 .2682 .29523 .28059 .28996 .27234 .28339 Metetra
.687 .8 .935 r
.27234 .28339 .28059 .28996 .29302 .28476 .28482 .27807 Metetra
.684 .797 .935 r
.28482 .27807 .29302 .28476 .3055 .27961 .29735 .27282 Metetra
.682 .795 .934 r
.29735 .27282 .3055 .27961 .31803 .27452 .30993 .26763 Metetra
.68 .792 .934 r
.30993 .26763 .31803 .27452 .33061 .26946 .32256 .26248 Metetra
.678 .79 .934 r
.32256 .26248 .33061 .26946 .34325 .26444 .33524 .25737 Metetra
.676 .789 .934 r
.33524 .25737 .34325 .26444 .35593 .25943 .34797 .25229 Metetra
.674 .787 .934 r
.34797 .25229 .35593 .25943 .36868 .25445 .36076 .24723 Metetra
.673 .786 .934 r
.36076 .24723 .36868 .25445 .38148 .24948 .37361 .24219 Metetra
.672 .785 .934 r
.37361 .24219 .38148 .24948 .39434 .24453 .38652 .23716 Metetra
.671 .783 .934 r
.38652 .23716 .39434 .24453 .40726 .23958 .39948 .23215 Metetra
.669 .782 .934 r
.39948 .23215 .40726 .23958 .42023 .23464 .41251 .22715 Metetra
.668 .782 .934 r
.41251 .22715 .42023 .23464 .43327 .2297 .42559 .22215 Metetra
.668 .781 .934 r
.42559 .22215 .43327 .2297 .44637 .22477 .43874 .21716 Metetra
.667 .78 .934 r
.43874 .21716 .44637 .22477 .45953 .21983 .45194 .21217 Metetra
.666 .779 .934 r
.45194 .21217 .45953 .21983 .47276 .2149 .46521 .20719 Metetra
.665 .779 .934 r
.46521 .20719 .47276 .2149 .48604 .20997 .47855 .2022 Metetra
.664 .779 .934 r
.47855 .2022 .48604 .20997 .4994 .20503 .49195 .19722 Metetra
.663 .778 .935 r
.49195 .19722 .4994 .20503 .51281 .20009 .50541 .19224 Metetra
.662 .778 .935 r
.50541 .19224 .51281 .20009 .52629 .19515 .51895 .18726 Metetra
.662 .778 .935 r
.51895 .18726 .52629 .19515 .53984 .19021 .53254 .18228 Metetra
.661 .777 .936 r
.53254 .18228 .53984 .19021 .55346 .18527 .54621 .1773 Metetra
.66 .777 .936 r
.54621 .1773 .55346 .18527 .56715 .18033 .55995 .17232 Metetra
.659 .777 .937 r
.55995 .17232 .56715 .18033 .5809 .17539 .57375 .16735 Metetra
.657 .777 .937 r
.57375 .16735 .5809 .17539 .59472 .17046 .58763 .16239 Metetra
.656 .777 .938 r
.58763 .16239 .59472 .17046 .60862 .16553 .60158 .15744 Metetra
.655 .778 .939 r
.60158 .15744 .60862 .16553 .62259 .16062 .6156 .15251 Metetra
.653 .778 .94 r
.6156 .15251 .62259 .16062 .63663 .15572 .6297 .14761 Metetra
.651 .778 .941 r
.6297 .14761 .63663 .15572 .65075 .15086 .64387 .14274 Metetra
.648 .778 .943 r
.64387 .14274 .65075 .15086 .66494 .14605 .65813 .13793 Metetra
.644 .778 .945 r
.65813 .13793 .66494 .14605 .67922 .14131 .67246 .1332 Metetra
.638 .777 .948 r
.67246 .1332 .67922 .14131 .69358 .13668 .68688 .12862 Metetra
.628 .776 .951 r
.68688 .12862 .69358 .13668 .70804 .13227 .7014 .12427 Metetra
.609 .771 .958 r
.7014 .12427 .70804 .13227 .7226 .12827 .71604 .1204 Metetra
.557 .752 .968 r
.71604 .1204 .7226 .12827 .73734 .12537 .73085 .11776 Metetra
.151 .52 .917 r
.73085 .11776 .73734 .12537 .75267 .12894 .74632 .12247 Metetra
.941 .877 .744 r
.08618 .40763 .09626 .4062 .11035 .38462 .10066 .38391 Metetra
.903 .893 .81 r
.10066 .38391 .11035 .38462 .12357 .36939 .11414 .36734 Metetra
.863 .894 .856 r
.11414 .36734 .12357 .36939 .13636 .35755 .12711 .35457 Metetra
.827 .887 .886 r
.12711 .35457 .13636 .35755 .1489 .34773 .1398 .34406 Metetra
.798 .877 .905 r
.1398 .34406 .1489 .34773 .16131 .3392 .15233 .33499 Metetra
.774 .866 .917 r
.15233 .33499 .16131 .3392 .17364 .33154 .16476 .32692 Metetra
.755 .856 .925 r
.16476 .32692 .17364 .33154 .18594 .32451 .17714 .31953 Metetra
.74 .847 .93 r
.17714 .31953 .18594 .32451 .19822 .31792 .1895 .31266 Metetra
.728 .838 .933 r
.1895 .31266 .19822 .31792 .21051 .31168 .20186 .30616 Metetra
.718 .831 .935 r
.20186 .30616 .21051 .31168 .22281 .30569 .21423 .29996 Metetra
.71 .825 .936 r
.21423 .29996 .22281 .30569 .23514 .29991 .22662 .29399 Metetra
.704 .82 .937 r
.22662 .29399 .23514 .29991 .2475 .29428 .23904 .28819 Metetra
.699 .815 .937 r
.23904 .28819 .2475 .29428 .2599 .28878 .25149 .28254 Metetra
.694 .811 .938 r
.25149 .28254 .2599 .28878 .27234 .28339 .26399 .27701 Metetra
.69 .808 .938 r
.26399 .27701 .27234 .28339 .28482 .27807 .27652 .27156 Metetra
.687 .805 .938 r
.27652 .27156 .28482 .27807 .29735 .27282 .2891 .2662 Metetra
.684 .802 .938 r
.2891 .2662 .29735 .27282 .30993 .26763 .30173 .2609 Metetra
.681 .799 .938 r
.30173 .2609 .30993 .26763 .32256 .26248 .31441 .25565 Metetra
.679 .797 .937 r
.31441 .25565 .32256 .26248 .33524 .25737 .32714 .25044 Metetra
.677 .795 .937 r
.32714 .25044 .33524 .25737 .34797 .25229 .33992 .24527 Metetra
.676 .793 .937 r
.33992 .24527 .34797 .25229 .36076 .24723 .35276 .24013 Metetra
.674 .792 .937 r
.35276 .24013 .36076 .24723 .37361 .24219 .36566 .23501 Metetra
.673 .79 .937 r
.36566 .23501 .37361 .24219 .38652 .23716 .37861 .22992 Metetra
.671 .789 .937 r
.37861 .22992 .38652 .23716 .39948 .23215 .39162 .22483 Metetra
.67 .788 .937 r
.39162 .22483 .39948 .23215 .41251 .22715 .40469 .21976 Metetra
.669 .787 .937 r
.40469 .21976 .41251 .22715 .42559 .22215 .41782 .2147 Metetra
.668 .786 .937 r
.41782 .2147 .42559 .22215 .43874 .21716 .43102 .20965 Metetra
.667 .785 .937 r
.43102 .20965 .43874 .21716 .45194 .21217 .44427 .20461 Metetra
.666 .785 .937 r
.44427 .20461 .45194 .21217 .46521 .20719 .45759 .19957 Metetra
.665 .784 .937 r
.45759 .19957 .46521 .20719 .47855 .2022 .47098 .19453 Metetra
.664 .783 .938 r
.47098 .19453 .47855 .2022 .49195 .19722 .48443 .1895 Metetra
.663 .783 .938 r
.48443 .1895 .49195 .19722 .50541 .19224 .49794 .18448 Metetra
.662 .783 .938 r
.49794 .18448 .50541 .19224 .51895 .18726 .51152 .17945 Metetra
.661 .782 .939 r
.51152 .17945 .51895 .18726 .53254 .18228 .52517 .17443 Metetra
.66 .782 .939 r
.52517 .17443 .53254 .18228 .54621 .1773 .53889 .16942 Metetra
.659 .782 .939 r
.53889 .16942 .54621 .1773 .55995 .17232 .55268 .16441 Metetra
.658 .782 .94 r
.55268 .16441 .55995 .17232 .57375 .16735 .56654 .15941 Metetra
.656 .782 .941 r
.56654 .15941 .57375 .16735 .58763 .16239 .58047 .15443 Metetra
.655 .782 .942 r
.58047 .15443 .58763 .16239 .60158 .15744 .59447 .14946 Metetra
.653 .782 .943 r
.59447 .14946 .60158 .15744 .6156 .15251 .60855 .14452 Metetra
.651 .782 .944 r
.60855 .14452 .6156 .15251 .6297 .14761 .6227 .13961 Metetra
.648 .783 .945 r
.6227 .13961 .6297 .14761 .64387 .14274 .63693 .13474 Metetra
.645 .783 .947 r
.63693 .13474 .64387 .14274 .65813 .13793 .65125 .12994 Metetra
.64 .783 .95 r
.65125 .12994 .65813 .13793 .67246 .1332 .66564 .12525 Metetra
.633 .782 .953 r
.66564 .12525 .67246 .1332 .68688 .12862 .68013 .12071 Metetra
.622 .78 .957 r
.68013 .12071 .68688 .12862 .7014 .12427 .69471 .11645 Metetra
.599 .774 .964 r
.69471 .11645 .7014 .12427 .71604 .1204 .70942 .11273 Metetra
.536 .751 .975 r
.70942 .11273 .71604 .1204 .73085 .11776 .72432 .11043 Metetra
.049 .457 .88 r
.72432 .11043 .73085 .11776 .74632 .12247 .73994 .11648 Metetra
.952 .882 .727 r
.07576 .41047 .08618 .40763 .10066 .38391 .0907 .38428 Metetra
.917 .903 .795 r
.0907 .38428 .10066 .38391 .11414 .36734 .10448 .36614 Metetra
.878 .907 .845 r
.10448 .36614 .11414 .36734 .12711 .35457 .11766 .3523 Metetra
.842 .902 .879 r
.11766 .3523 .12711 .35457 .1398 .34406 .13051 .34099 Metetra
.811 .892 .902 r
.13051 .34099 .1398 .34406 .15233 .33499 .14317 .33132 Metetra
.785 .881 .916 r
.14317 .33132 .15233 .33499 .16476 .32692 .15572 .32276 Metetra
.765 .87 .925 r
.15572 .32276 .16476 .32692 .17714 .31953 .1682 .31498 Metetra
.748 .86 .931 r
.1682 .31498 .17714 .31953 .1895 .31266 .18064 .30777 Metetra
.735 .852 .935 r
.18064 .30777 .1895 .31266 .20186 .30616 .19308 .301 Metetra
.725 .844 .938 r
.19308 .301 .20186 .30616 .21423 .29996 .20552 .29455 Metetra
.716 .837 .939 r
.20552 .29455 .21423 .29996 .22662 .29399 .21798 .28836 Metetra
.709 .831 .94 r
.21798 .28836 .22662 .29399 .23904 .28819 .23046 .28237 Metetra
.703 .826 .941 r
.23046 .28237 .23904 .28819 .25149 .28254 .24297 .27655 Metetra
.698 .821 .941 r
.24297 .27655 .25149 .28254 .26399 .27701 .25552 .27086 Metetra
.693 .817 .941 r
.25552 .27086 .26399 .27701 .27652 .27156 .26811 .26528 Metetra
.69 .813 .942 r
.26811 .26528 .27652 .27156 .2891 .2662 .28075 .25979 Metetra
.686 .81 .941 r
.28075 .25979 .2891 .2662 .30173 .2609 .29343 .25437 Metetra
.684 .807 .941 r
.29343 .25437 .30173 .2609 .31441 .25565 .30616 .24901 Metetra
.681 .805 .941 r
.30616 .24901 .31441 .25565 .32714 .25044 .31894 .2437 Metetra
.679 .803 .941 r
.31894 .2437 .32714 .25044 .33992 .24527 .33177 .23843 Metetra
.677 .801 .941 r
.33177 .23843 .33992 .24527 .35276 .24013 .34466 .2332 Metetra
.675 .799 .941 r
.34466 .2332 .35276 .24013 .36566 .23501 .35761 .228 Metetra
.674 .797 .941 r
.35761 .228 .36566 .23501 .37861 .22992 .37061 .22282 Metetra
.672 .796 .941 r
.37061 .22282 .37861 .22992 .39162 .22483 .38367 .21766 Metetra
.671 .794 .941 r
.38367 .21766 .39162 .22483 .40469 .21976 .39679 .21252 Metetra
.67 .793 .941 r
.39679 .21252 .40469 .21976 .41782 .2147 .40997 .2074 Metetra
.668 .792 .941 r
.40997 .2074 .41782 .2147 .43102 .20965 .42321 .20228 Metetra
.667 .791 .941 r
.42321 .20228 .43102 .20965 .44427 .20461 .43652 .19718 Metetra
.666 .79 .941 r
.43652 .19718 .44427 .20461 .45759 .19957 .44989 .19208 Metetra
.665 .79 .941 r
.44989 .19208 .45759 .19957 .47098 .19453 .46332 .187 Metetra
.664 .789 .941 r
.46332 .187 .47098 .19453 .48443 .1895 .47682 .18192 Metetra
.663 .789 .942 r
.47682 .18192 .48443 .1895 .49794 .18448 .49039 .17684 Metetra
.662 .788 .942 r
.49039 .17684 .49794 .18448 .51152 .17945 .50402 .17178 Metetra
.66 .788 .942 r
.50402 .17178 .51152 .17945 .52517 .17443 .51772 .16672 Metetra
.659 .788 .943 r
.51772 .16672 .52517 .17443 .53889 .16942 .53149 .16167 Metetra
.658 .788 .944 r
.53149 .16167 .53889 .16942 .55268 .16441 .54534 .15663 Metetra
.657 .788 .944 r
.54534 .15663 .55268 .16441 .56654 .15941 .55925 .15161 Metetra
.655 .788 .945 r
.55925 .15161 .56654 .15941 .58047 .15443 .57323 .1466 Metetra
.653 .788 .946 r
.57323 .1466 .58047 .15443 .59447 .14946 .58729 .14162 Metetra
.651 .788 .947 r
.58729 .14162 .59447 .14946 .60855 .14452 .60143 .13667 Metetra
.649 .788 .949 r
.60143 .13667 .60855 .14452 .6227 .13961 .61564 .13176 Metetra
.646 .788 .95 r
.61564 .13176 .6227 .13961 .63693 .13474 .62993 .12691 Metetra
.642 .789 .952 r
.62993 .12691 .63693 .13474 .65125 .12994 .6443 .12213 Metetra
.636 .788 .955 r
.6443 .12213 .65125 .12994 .66564 .12525 .65876 .11748 Metetra
.628 .788 .959 r
.65876 .11748 .66564 .12525 .68013 .12071 .67331 .11301 Metetra
.614 .785 .964 r
.67331 .11301 .68013 .12071 .69471 .11645 .68797 .10886 Metetra
.586 .778 .971 r
.68797 .10886 .69471 .11645 .70942 .11273 .70275 .10534 Metetra
.509 .749 .982 r
.70275 .10534 .70942 .11273 .72432 .11043 .71774 .10344 Metetra
0 .374 .822 r
.71774 .10344 .72432 .11043 .73994 .11648 .73353 .11111 Metetra
.962 .886 .708 r
.06493 .41506 .07576 .41047 .0907 .38428 .08041 .38596 Metetra
.931 .912 .778 r
.08041 .38596 .0907 .38428 .10448 .36614 .09454 .36601 Metetra
.894 .92 .832 r
.09454 .36601 .10448 .36614 .11766 .3523 .10798 .35091 Metetra
.857 .918 .871 r
.10798 .35091 .11766 .3523 .13051 .34099 .12102 .33868 Metetra
.825 .909 .897 r
.12102 .33868 .13051 .34099 .14317 .33132 .13383 .32831 Metetra
.798 .898 .914 r
.13383 .32831 .14317 .33132 .15572 .32276 .1465 .31919 Metetra
.776 .887 .925 r
.1465 .31919 .15572 .32276 .1682 .31498 .15909 .31095 Metetra
.758 .877 .932 r
.15909 .31095 .1682 .31498 .18064 .30777 .17163 .30336 Metetra
.743 .867 .937 r
.17163 .30336 .18064 .30777 .19308 .301 .18415 .29626 Metetra
.732 .858 .941 r
.18415 .29626 .19308 .301 .20552 .29455 .19667 .28953 Metetra
.722 .851 .943 r
.19667 .28953 .20552 .29455 .21798 .28836 .2092 .2831 Metetra
.714 .844 .944 r
.2092 .2831 .21798 .28836 .23046 .28237 .22175 .27689 Metetra
.707 .838 .945 r
.22175 .27689 .23046 .28237 .24297 .27655 .23433 .27088 Metetra
.702 .833 .945 r
.23433 .27088 .24297 .27655 .25552 .27086 .24694 .26501 Metetra
.697 .828 .946 r
.24694 .26501 .25552 .27086 .26811 .26528 .25959 .25927 Metetra
.693 .824 .946 r
.25959 .25927 .26811 .26528 .28075 .25979 .27228 .25364 Metetra
.689 .82 .946 r
.27228 .25364 .28075 .25979 .29343 .25437 .28502 .24808 Metetra
.686 .817 .946 r
.28502 .24808 .29343 .25437 .30616 .24901 .2978 .2426 Metetra
.683 .814 .945 r
.2978 .2426 .30616 .24901 .31894 .2437 .31064 .23718 Metetra
.681 .812 .945 r
.31064 .23718 .31894 .2437 .33177 .23843 .32352 .23181 Metetra
.678 .809 .945 r
.32352 .23181 .33177 .23843 .34466 .2332 .33647 .22648 Metetra
.677 .807 .945 r
.33647 .22648 .34466 .2332 .35761 .228 .34946 .22118 Metetra
.675 .805 .945 r
.34946 .22118 .35761 .228 .37061 .22282 .36251 .21592 Metetra
.673 .804 .945 r
.36251 .21592 .37061 .22282 .38367 .21766 .37563 .21068 Metetra
.671 .802 .945 r
.37563 .21068 .38367 .21766 .39679 .21252 .3888 .20547 Metetra
.67 .801 .945 r
.3888 .20547 .39679 .21252 .40997 .2074 .40203 .20027 Metetra
.669 .8 .945 r
.40203 .20027 .40997 .2074 .42321 .20228 .41532 .19509 Metetra
.667 .799 .945 r
.41532 .19509 .42321 .20228 .43652 .19718 .42868 .18992 Metetra
.666 .798 .945 r
.42868 .18992 .43652 .19718 .44989 .19208 .4421 .18477 Metetra
.665 .797 .945 r
.4421 .18477 .44989 .19208 .46332 .187 .45559 .17962 Metetra
.664 .796 .946 r
.45559 .17962 .46332 .187 .47682 .18192 .46914 .17449 Metetra
.662 .796 .946 r
.46914 .17449 .47682 .18192 .49039 .17684 .48275 .16937 Metetra
.661 .795 .946 r
.48275 .16937 .49039 .17684 .50402 .17178 .49644 .16427 Metetra
.66 .795 .947 r
.49644 .16427 .50402 .17178 .51772 .16672 .5102 .15917 Metetra
.658 .795 .948 r
.5102 .15917 .51772 .16672 .53149 .16167 .52402 .15409 Metetra
.657 .794 .948 r
.52402 .15409 .53149 .16167 .54534 .15663 .53792 .14902 Metetra
.655 .794 .949 r
.53792 .14902 .54534 .15663 .55925 .15161 .55188 .14398 Metetra
.653 .794 .95 r
.55188 .14398 .55925 .15161 .57323 .1466 .56593 .13896 Metetra
.651 .795 .951 r
.56593 .13896 .57323 .1466 .58729 .14162 .58004 .13397 Metetra
.649 .795 .953 r
.58004 .13397 .58729 .14162 .60143 .13667 .59424 .12902 Metetra
.646 .795 .954 r
.59424 .12902 .60143 .13667 .61564 .13176 .60851 .12411 Metetra
.642 .795 .956 r
.60851 .12411 .61564 .13176 .62993 .12691 .62286 .11928 Metetra
.637 .796 .959 r
.62286 .11928 .62993 .12691 .6443 .12213 .6373 .11455 Metetra
.63 .795 .962 r
.6373 .11455 .6443 .12213 .65876 .11748 .65182 .10995 Metetra
.62 .795 .966 r
.65182 .10995 .65876 .11748 .67331 .11301 .66644 .10558 Metetra
.603 .792 .971 r
.66644 .10558 .67331 .11301 .68797 .10886 .68117 .10158 Metetra
.569 .782 .979 r
.68117 .10158 .68797 .10886 .70275 .10534 .69603 .0983 Metetra
.473 .744 .988 r
.69603 .0983 .70275 .10534 .71774 .10344 .71112 .09689 Metetra
0 .27 .736 r
.71112 .09689 .71774 .10344 .73353 .11111 .72709 .10652 Metetra
.972 .889 .688 r
.05362 .4218 .06493 .41506 .08041 .38596 .06975 .38927 Metetra
.944 .92 .758 r
.06975 .38927 .08041 .38596 .09454 .36601 .08429 .36717 Metetra
.909 .933 .816 r
.08429 .36717 .09454 .36601 .10798 .35091 .09801 .3506 Metetra
.873 .934 .859 r
.09801 .3506 .10798 .35091 .12102 .33868 .11128 .3373 Metetra
.84 .928 .889 r
.11128 .3373 .12102 .33868 .13383 .32831 .12426 .3261 Metetra
.811 .918 .91 r
.12426 .3261 .13383 .32831 .1465 .31919 .13708 .31633 Metetra
.788 .906 .923 r
.13708 .31633 .1465 .31919 .15909 .31095 .14979 .30756 Metetra
.768 .895 .933 r
.14979 .30756 .15909 .31095 .17163 .30336 .16244 .29953 Metetra
.752 .885 .939 r
.16244 .29953 .17163 .30336 .18415 .29626 .17506 .29206 Metetra
.739 .876 .943 r
.17506 .29206 .18415 .29626 .19667 .28953 .18767 .28501 Metetra
.729 .867 .946 r
.18767 .28501 .19667 .28953 .2092 .2831 .20028 .27829 Metetra
.72 .86 .948 r
.20028 .27829 .2092 .2831 .22175 .27689 .2129 .27184 Metetra
.712 .853 .949 r
.2129 .27184 .22175 .27689 .23433 .27088 .22555 .2656 Metetra
.706 .847 .95 r
.22555 .2656 .23433 .27088 .24694 .26501 .23823 .25954 Metetra
.7 .842 .95 r
.23823 .25954 .24694 .26501 .25959 .25927 .25094 .25362 Metetra
.696 .837 .95 r
.25094 .25362 .25959 .25927 .27228 .25364 .26369 .24782 Metetra
.692 .833 .951 r
.26369 .24782 .27228 .25364 .28502 .24808 .27649 .24212 Metetra
.688 .829 .95 r
.27649 .24212 .28502 .24808 .2978 .2426 .28933 .2365 Metetra
.685 .825 .95 r
.28933 .2365 .2978 .2426 .31064 .23718 .30222 .23095 Metetra
.683 .822 .95 r
.30222 .23095 .31064 .23718 .32352 .23181 .31516 .22547 Metetra
.68 .82 .95 r
.31516 .22547 .32352 .23181 .33647 .22648 .32816 .22003 Metetra
.678 .817 .95 r
.32816 .22003 .33647 .22648 .34946 .22118 .34121 .21463 Metetra
.676 .815 .95 r
.34121 .21463 .34946 .22118 .36251 .21592 .35432 .20927 Metetra
.674 .813 .95 r
.35432 .20927 .36251 .21592 .37563 .21068 .36748 .20395 Metetra
.672 .811 .95 r
.36748 .20395 .37563 .21068 .3888 .20547 .38071 .19865 Metetra
.67 .81 .95 r
.38071 .19865 .3888 .20547 .40203 .20027 .39399 .19337 Metetra
.669 .808 .95 r
.39399 .19337 .40203 .20027 .41532 .19509 .40734 .18812 Metetra
.667 .807 .95 r
.40734 .18812 .41532 .19509 .42868 .18992 .42075 .18289 Metetra
.666 .806 .95 r
.42075 .18289 .42868 .18992 .4421 .18477 .43422 .17767 Metetra
.664 .805 .95 r
.43422 .17767 .4421 .18477 .45559 .17962 .44776 .17247 Metetra
.663 .804 .951 r
.44776 .17247 .45559 .17962 .46914 .17449 .46136 .16729 Metetra
.661 .804 .951 r
.46136 .16729 .46914 .17449 .48275 .16937 .47504 .16212 Metetra
.66 .803 .952 r
.47504 .16212 .48275 .16937 .49644 .16427 .48878 .15697 Metetra
.658 .803 .952 r
.48878 .15697 .49644 .16427 .5102 .15917 .50259 .15184 Metetra
.657 .803 .953 r
.50259 .15184 .5102 .15917 .52402 .15409 .51647 .14673 Metetra
.655 .803 .954 r
.51647 .14673 .52402 .15409 .53792 .14902 .53042 .14164 Metetra
.653 .802 .955 r
.53042 .14164 .53792 .14902 .55188 .14398 .54444 .13658 Metetra
.651 .803 .956 r
.54444 .13658 .55188 .14398 .56593 .13896 .55854 .13155 Metetra
.648 .803 .957 r
.55854 .13155 .56593 .13896 .58004 .13397 .57272 .12655 Metetra
.645 .803 .959 r
.57272 .12655 .58004 .13397 .59424 .12902 .58697 .12161 Metetra
.641 .803 .961 r
.58697 .12161 .59424 .12902 .60851 .12411 .60131 .11673 Metetra
.637 .804 .963 r
.60131 .11673 .60851 .12411 .62286 .11928 .61572 .11194 Metetra
.631 .804 .966 r
.61572 .11194 .62286 .11928 .6373 .11455 .63022 .10726 Metetra
.622 .804 .969 r
.63022 .10726 .6373 .11455 .65182 .10995 .64482 .10275 Metetra
.61 .802 .974 r
.64482 .10275 .65182 .10995 .66644 .10558 .65951 .0985 Metetra
.589 .799 .98 r
.65951 .0985 .66644 .10558 .68117 .10158 .67431 .09468 Metetra
.546 .786 .988 r
.67431 .09468 .68117 .10158 .69603 .0983 .68926 .09171 Metetra
.424 .734 .991 r
.68926 .09171 .69603 .0983 .71112 .09689 .70445 .09091 Metetra
0 .148 .62 r
.70445 .09091 .71112 .09689 .72709 .10652 .72063 .10294 Metetra
.979 .892 .665 r
.04173 .43121 .05362 .4218 .06975 .38927 .05863 .39459 Metetra
.955 .927 .734 r
.05863 .39459 .06975 .38927 .08429 .36717 .07366 .36994 Metetra
.922 .946 .794 r
.07366 .36994 .08429 .36717 .09801 .3506 .08773 .35163 Metetra
.887 .951 .842 r
.08773 .35163 .09801 .3506 .11128 .3373 .10125 .33707 Metetra
.854 .947 .877 r
.10125 .33707 .11128 .3373 .12426 .3261 .11444 .3249 Metetra
.825 .939 .902 r
.11444 .3249 .12426 .3261 .13708 .31633 .12742 .31437 Metetra
.8 .928 .919 r
.12742 .31437 .13708 .31633 .14979 .30756 .14028 .30498 Metetra
.779 .917 .931 r
.14028 .30498 .14979 .30756 .16244 .29953 .15305 .29643 Metetra
.762 .906 .939 r
.15305 .29643 .16244 .29953 .17506 .29206 .16578 .28852 Metetra
.747 .895 .945 r
.16578 .28852 .17506 .29206 .18767 .28501 .17848 .2811 Metetra
.736 .886 .949 r
.17848 .2811 .18767 .28501 .20028 .27829 .19118 .27406 Metetra
.726 .878 .952 r
.19118 .27406 .20028 .27829 .2129 .27184 .20389 .26732 Metetra
.717 .87 .953 r
.20389 .26732 .2129 .27184 .22555 .2656 .21661 .26083 Metetra
.71 .864 .954 r
.21661 .26083 .22555 .2656 .23823 .25954 .22936 .25454 Metetra
.704 .857 .955 r
.22936 .25454 .23823 .25954 .25094 .25362 .24215 .24842 Metetra
.699 .852 .956 r
.24215 .24842 .25094 .25362 .26369 .24782 .25496 .24243 Metetra
.695 .847 .956 r
.25496 .24243 .26369 .24782 .27649 .24212 .26782 .23656 Metetra
.691 .843 .956 r
.26782 .23656 .27649 .24212 .28933 .2365 .28073 .23079 Metetra
.687 .839 .956 r
.28073 .23079 .28933 .2365 .30222 .23095 .29368 .2251 Metetra
.684 .836 .956 r
.29368 .2251 .30222 .23095 .31516 .22547 .30668 .21948 Metetra
.682 .832 .956 r
.30668 .21948 .31516 .22547 .32816 .22003 .31973 .21392 Metetra
.679 .83 .956 r
.31973 .21392 .32816 .22003 .34121 .21463 .33284 .20841 Metetra
.677 .827 .956 r
.33284 .20841 .34121 .21463 .35432 .20927 .34601 .20295 Metetra
.675 .825 .956 r
.34601 .20295 .35432 .20927 .36748 .20395 .35923 .19752 Metetra
.673 .823 .956 r
.35923 .19752 .36748 .20395 .38071 .19865 .37251 .19213 Metetra
.671 .821 .956 r
.37251 .19213 .38071 .19865 .39399 .19337 .38585 .18678 Metetra
.669 .819 .956 r
.38585 .18678 .39399 .19337 .40734 .18812 .39925 .18145 Metetra
.667 .818 .956 r
.39925 .18145 .40734 .18812 .42075 .18289 .41271 .17614 Metetra
.665 .817 .956 r
.41271 .17614 .42075 .18289 .43422 .17767 .42624 .17086 Metetra
.664 .816 .956 r
.42624 .17086 .43422 .17767 .44776 .17247 .43984 .1656 Metetra
.662 .815 .957 r
.43984 .1656 .44776 .17247 .46136 .16729 .4535 .16037 Metetra
.66 .814 .957 r
.4535 .16037 .46136 .16729 .47504 .16212 .46722 .15515 Metetra
.658 .813 .958 r
.46722 .15515 .47504 .16212 .48878 .15697 .48102 .14996 Metetra
.656 .813 .958 r
.48102 .14996 .48878 .15697 .50259 .15184 .49489 .1448 Metetra
.654 .812 .959 r
.49489 .1448 .50259 .15184 .51647 .14673 .50883 .13966 Metetra
.652 .812 .96 r
.50883 .13966 .51647 .14673 .53042 .14164 .52284 .13455 Metetra
.65 .812 .961 r
.52284 .13455 .53042 .14164 .54444 .13658 .53692 .12947 Metetra
.647 .812 .963 r
.53692 .12947 .54444 .13658 .55854 .13155 .55108 .12444 Metetra
.644 .813 .964 r
.55108 .12444 .55854 .13155 .57272 .12655 .56532 .11945 Metetra
.64 .813 .966 r
.56532 .11945 .57272 .12655 .58697 .12161 .57964 .11453 Metetra
.636 .813 .968 r
.57964 .11453 .58697 .12161 .60131 .11673 .59403 .10969 Metetra
.63 .813 .971 r
.59403 .10969 .60131 .11673 .61572 .11194 .60852 .10495 Metetra
.622 .814 .974 r
.60852 .10495 .61572 .11194 .63022 .10726 .62309 .10035 Metetra
.612 .813 .978 r
.62309 .10035 .63022 .10726 .64482 .10275 .63775 .09596 Metetra
.596 .811 .982 r
.63775 .09596 .64482 .10275 .65951 .0985 .65252 .09187 Metetra
.568 .806 .988 r
.65252 .09187 .65951 .0985 .67431 .09468 .66741 .08829 Metetra
.513 .789 .995 r
.66741 .08829 .67431 .09468 .68926 .09171 .68245 .0857 Metetra
.353 .714 .986 r
.68245 .0857 .68926 .09171 .70445 .09091 .69775 .08566 Metetra
.514 0 0 r
.69775 .08566 .70445 .09091 .72063 .10294 .71417 .10064 Metetra
.985 .893 .64 r
.02912 .44398 .04173 .43121 .05863 .39459 .04696 .40243 Metetra
.964 .932 .705 r
.04696 .40243 .05863 .39459 .07366 .36994 .06258 .37474 Metetra
.934 .956 .767 r
.06258 .37474 .07366 .36994 .08773 .35163 .07706 .35435 Metetra
.9 .966 .819 r
.07706 .35435 .08773 .35163 .10125 .33707 .09088 .33828 Metetra
.867 .967 .859 r
.09088 .33828 .10125 .33707 .11444 .3249 .10431 .32497 Metetra
.837 .961 .889 r
.10431 .32497 .11444 .3249 .12742 .31437 .11749 .31352 Metetra
.811 .951 .911 r
.11749 .31352 .12742 .31437 .14028 .30498 .13051 .3034 Metetra
.789 .94 .926 r
.13051 .3034 .14028 .30498 .15305 .29643 .14343 .29425 Metetra
.771 .929 .937 r
.14343 .29425 .15305 .29643 .16578 .28852 .15628 .28583 Metetra
.755 .918 .945 r
.15628 .28583 .16578 .28852 .17848 .2811 .16909 .27797 Metetra
.742 .908 .95 r
.16909 .27797 .17848 .2811 .19118 .27406 .18189 .27055 Metetra
.732 .899 .954 r
.18189 .27055 .19118 .27406 .20389 .26732 .19469 .26348 Metetra
.723 .891 .957 r
.19469 .26348 .20389 .26732 .21661 .26083 .2075 .2567 Metetra
.715 .883 .959 r
.2075 .2567 .21661 .26083 .22936 .25454 .22033 .25015 Metetra
.708 .877 .96 r
.22033 .25015 .22936 .25454 .24215 .24842 .23319 .24379 Metetra
.702 .87 .961 r
.23319 .24379 .24215 .24842 .25496 .24243 .24608 .23759 Metetra
.697 .865 .961 r
.24608 .23759 .25496 .24243 .26782 .23656 .25901 .23152 Metetra
.693 .86 .962 r
.25901 .23152 .26782 .23656 .28073 .23079 .27198 .22557 Metetra
.689 .855 .962 r
.27198 .22557 .28073 .23079 .29368 .2251 .285 .21972 Metetra
.686 .851 .962 r
.285 .21972 .29368 .2251 .30668 .21948 .29807 .21395 Metetra
.683 .848 .962 r
.29807 .21395 .30668 .21948 .31973 .21392 .31118 .20825 Metetra
.68 .844 .962 r
.31118 .20825 .31973 .21392 .33284 .20841 .32435 .20262 Metetra
.677 .841 .962 r
.32435 .20262 .33284 .20841 .34601 .20295 .33757 .19704 Metetra
.675 .839 .962 r
.33757 .19704 .34601 .20295 .35923 .19752 .35085 .19151 Metetra
.672 .836 .962 r
.35085 .19151 .35923 .19752 .37251 .19213 .36419 .18602 Metetra
.67 .834 .962 r
.36419 .18602 .37251 .19213 .38585 .18678 .37759 .18057 Metetra
.668 .832 .962 r
.37759 .18057 .38585 .18678 .39925 .18145 .39105 .17515 Metetra
.666 .831 .962 r
.39105 .17515 .39925 .18145 .41271 .17614 .40457 .16977 Metetra
.664 .829 .963 r
.40457 .16977 .41271 .17614 .42624 .17086 .41816 .16442 Metetra
.662 .828 .963 r
.41816 .16442 .42624 .17086 .43984 .1656 .43181 .1591 Metetra
.66 .827 .964 r
.43181 .1591 .43984 .1656 .4535 .16037 .44553 .15381 Metetra
.658 .826 .964 r
.44553 .15381 .4535 .16037 .46722 .15515 .45932 .14855 Metetra
.656 .825 .965 r
.45932 .14855 .46722 .15515 .48102 .14996 .47317 .14332 Metetra
.654 .825 .966 r
.47317 .14332 .48102 .14996 .49489 .1448 .4871 .13812 Metetra
.651 .824 .966 r
.4871 .13812 .49489 .1448 .50883 .13966 .5011 .13295 Metetra
.648 .824 .968 r
.5011 .13295 .50883 .13966 .52284 .13455 .51517 .12783 Metetra
.645 .824 .969 r
.51517 .12783 .52284 .13455 .53692 .12947 .52932 .12275 Metetra
.642 .824 .97 r
.52932 .12275 .53692 .12947 .55108 .12444 .54354 .11772 Metetra
.638 .824 .972 r
.54354 .11772 .55108 .12444 .56532 .11945 .55784 .11276 Metetra
.633 .825 .974 r
.55784 .11276 .56532 .11945 .57964 .11453 .57222 .10788 Metetra
.627 .825 .977 r
.57222 .10788 .57964 .11453 .59403 .10969 .58669 .10309 Metetra
.62 .825 .979 r
.58669 .10309 .59403 .10969 .60852 .10495 .60124 .09843 Metetra
.61 .825 .983 r
.60124 .09843 .60852 .10495 .62309 .10035 .61588 .09394 Metetra
.596 .824 .987 r
.61588 .09394 .62309 .10035 .63775 .09596 .63062 .0897 Metetra
.575 .821 .991 r
.63062 .0897 .63775 .09596 .65252 .09187 .64547 .08582 Metetra
.539 .813 .997 r
.64547 .08582 .65252 .09187 .66741 .08829 .66045 .08255 Metetra
.465 .787 .999 r
.66045 .08255 .66741 .08829 .68245 .0857 .67559 .08045 Metetra
.252 .676 .963 r
.67559 .08045 .68245 .0857 .69775 .08566 .69102 .08136 Metetra
.64 .112 0 r
.69102 .08136 .69775 .08566 .71417 .10064 .70771 .10003 Metetra
.989 .893 .613 r
.01561 .46103 .02912 .44398 .04696 .40243 .03459 .41348 Metetra
.968 .934 .672 r
.03459 .41348 .04696 .40243 .06258 .37474 .05094 .38209 Metetra
.94 .963 .732 r
.05094 .38209 .06258 .37474 .07706 .35435 .06591 .3592 Metetra
.908 .978 .786 r
.06591 .3592 .07706 .35435 .09088 .33828 .08011 .34131 Metetra
.876 .984 .832 r
.08011 .34131 .09088 .33828 .10431 .32497 .09382 .32663 Metetra
.846 .981 .867 r
.09382 .32663 .10431 .32497 .11749 .31352 .10723 .3141 Metetra
.82 .974 .894 r
.10723 .3141 .11749 .31352 .13051 .3034 .12045 .30311 Metetra
.797 .965 .914 r
.12045 .30311 .13051 .3034 .14343 .29425 .13352 .29324 Metetra
.778 .954 .929 r
.13352 .29324 .14343 .29425 .15628 .28583 .14652 .28421 Metetra
.761 .944 .94 r
.14652 .28421 .15628 .28583 .16909 .27797 .15946 .27583 Metetra
.748 .933 .948 r
.15946 .27583 .16909 .27797 .18189 .27055 .17238 .26796 Metetra
.736 .924 .954 r
.17238 .26796 .18189 .27055 .19469 .26348 .18528 .2605 Metetra
.726 .915 .958 r
.18528 .2605 .19469 .26348 .2075 .2567 .19819 .25337 Metetra
.718 .907 .961 r
.19819 .25337 .2075 .2567 .22033 .25015 .21111 .24651 Metetra
.711 .899 .964 r
.21111 .24651 .22033 .25015 .23319 .24379 .22405 .23988 Metetra
.705 .892 .965 r
.22405 .23988 .23319 .24379 .24608 .23759 .23703 .23343 Metetra
.699 .886 .966 r
.23703 .23343 .24608 .23759 .25901 .23152 .25003 .22714 Metetra
.694 .88 .967 r
.25003 .22714 .25901 .23152 .27198 .22557 .26308 .22099 Metetra
.69 .875 .968 r
.26308 .22099 .27198 .22557 .285 .21972 .27617 .21495 Metetra
.686 .87 .968 r
.27617 .21495 .285 .21972 .29807 .21395 .2893 .20901 Metetra
.683 .866 .968 r
.2893 .20901 .29807 .21395 .31118 .20825 .30248 .20316 Metetra
.68 .862 .969 r
.30248 .20316 .31118 .20825 .32435 .20262 .31572 .19738 Metetra
.677 .859 .969 r
.31572 .19738 .32435 .20262 .33757 .19704 .32901 .19166 Metetra
.674 .856 .969 r
.32901 .19166 .33757 .19704 .35085 .19151 .34235 .18601 Metetra
.671 .853 .969 r
.34235 .18601 .35085 .19151 .36419 .18602 .35575 .18041 Metetra
.669 .851 .969 r
.35575 .18041 .36419 .18602 .37759 .18057 .36921 .17486 Metetra
.666 .848 .97 r
.36921 .17486 .37759 .18057 .39105 .17515 .38273 .16935 Metetra
.664 .846 .97 r
.38273 .16935 .39105 .17515 .40457 .16977 .39632 .16389 Metetra
.662 .845 .97 r
.39632 .16389 .40457 .16977 .41816 .16442 .40996 .15846 Metetra
.659 .843 .971 r
.40996 .15846 .41816 .16442 .43181 .1591 .42368 .15307 Metetra
.657 .842 .971 r
.42368 .15307 .43181 .1591 .44553 .15381 .43746 .14772 Metetra
.654 .841 .972 r
.43746 .14772 .44553 .15381 .45932 .14855 .45131 .14241 Metetra
.652 .84 .973 r
.45131 .14241 .45932 .14855 .47317 .14332 .46522 .13714 Metetra
.649 .839 .973 r
.46522 .13714 .47317 .14332 .4871 .13812 .47921 .13191 Metetra
.646 .839 .975 r
.47921 .13191 .4871 .13812 .5011 .13295 .49327 .12673 Metetra
.642 .838 .976 r
.49327 .12673 .5011 .13295 .51517 .12783 .50741 .1216 Metetra
.638 .838 .977 r
.50741 .1216 .51517 .12783 .52932 .12275 .52162 .11653 Metetra
.634 .838 .979 r
.52162 .11653 .52932 .12275 .54354 .11772 .53591 .11152 Metetra
.629 .838 .981 r
.53591 .11152 .54354 .11772 .55784 .11276 .55028 .1066 Metetra
.622 .839 .983 r
.55028 .1066 .55784 .11276 .57222 .10788 .56473 .10177 Metetra
.614 .839 .985 r
.56473 .10177 .57222 .10788 .58669 .10309 .57926 .09706 Metetra
.604 .839 .988 r
.57926 .09706 .58669 .10309 .60124 .09843 .59389 .09252 Metetra
.591 .838 .991 r
.59389 .09252 .60124 .09843 .61588 .09394 .60861 .08818 Metetra
.572 .836 .995 r
.60861 .08818 .61588 .09394 .63062 .0897 .62343 .08414 Metetra
.543 .83 .998 r
.62343 .08414 .63062 .0897 .64547 .08582 .63837 .08054 Metetra
.493 .816 1 r
.63837 .08054 .64547 .08582 .66045 .08255 .65344 .07767 Metetra
.391 .774 .991 r
.65344 .07767 .66045 .08255 .67559 .08045 .66869 .07621 Metetra
.107 .604 .903 r
.66869 .07621 .67559 .08045 .69102 .08136 .68426 .07832 Metetra
.736 .225 0 r
.68426 .07832 .69102 .08136 .70771 .10003 .70128 .10164 Metetra
.989 .891 .583 r
.00095 .48363 .01561 .46103 .03459 .41348 .02137 .42865 Metetra
.968 .932 .633 r
.02137 .42865 .03459 .41348 .05094 .38209 .0386 .39273 Metetra
.939 .963 .687 r
.0386 .39273 .05094 .38209 .06591 .3592 .05418 .36678 Metetra
.907 .983 .741 r
.05418 .36678 .06591 .3592 .08011 .34131 .06883 .34669 Metetra
.876 .994 .79 r
.06883 .34669 .08011 .34131 .09382 .32663 .08289 .33033 Metetra
.846 .996 .831 r
.08289 .33033 .09382 .32663 .10723 .3141 .09658 .3165 Metetra
.82 .993 .864 r
.09658 .3165 .10723 .3141 .12045 .30311 .11002 .30445 Metetra
.798 .987 .89 r
.11002 .30445 .12045 .30311 .13352 .29324 .12329 .29371 Metetra
.779 .978 .911 r
.12329 .29371 .13352 .29324 .14652 .28421 .13645 .28396 Metetra
.762 .969 .927 r
.13645 .28396 .14652 .28421 .15946 .27583 .14955 .27496 Metetra
.748 .959 .939 r
.14955 .27496 .15946 .27583 .17238 .26796 .1626 .26656 Metetra
.737 .95 .948 r
.1626 .26656 .17238 .26796 .18528 .2605 .17562 .25863 Metetra
.727 .941 .955 r
.17562 .25863 .18528 .2605 .19819 .25337 .18864 .25109 Metetra
.718 .932 .96 r
.18864 .25109 .19819 .25337 .21111 .24651 .20166 .24387 Metetra
.71 .924 .964 r
.20166 .24387 .21111 .24651 .22405 .23988 .2147 .23691 Metetra
.704 .917 .967 r
.2147 .23691 .22405 .23988 .23703 .23343 .22777 .23017 Metetra
.698 .91 .969 r
.22777 .23017 .23703 .23343 .25003 .22714 .24086 .22362 Metetra
.693 .904 .971 r
.24086 .22362 .25003 .22714 .26308 .22099 .25399 .21722 Metetra
.688 .898 .972 r
.25399 .21722 .26308 .22099 .27617 .21495 .26715 .21097 Metetra
.684 .893 .973 r
.26715 .21097 .27617 .21495 .2893 .20901 .28036 .20483 Metetra
.681 .888 .974 r
.28036 .20483 .2893 .20901 .30248 .20316 .29362 .19879 Metetra
.677 .884 .975 r
.29362 .19879 .30248 .20316 .31572 .19738 .30693 .19285 Metetra
.674 .88 .975 r
.30693 .19285 .31572 .19738 .32901 .19166 .32028 .18699 Metetra
.671 .876 .976 r
.32028 .18699 .32901 .19166 .34235 .18601 .3337 .1812 Metetra
.668 .873 .976 r
.3337 .1812 .34235 .18601 .35575 .18041 .34716 .17547 Metetra
.665 .87 .976 r
.34716 .17547 .35575 .18041 .36921 .17486 .36069 .1698 Metetra
.662 .868 .977 r
.36069 .1698 .36921 .17486 .38273 .16935 .37428 .16419 Metetra
.66 .865 .977 r
.37428 .16419 .38273 .16935 .39632 .16389 .38793 .15864 Metetra
.657 .863 .978 r
.38793 .15864 .39632 .16389 .40996 .15846 .40164 .15313 Metetra
.654 .862 .978 r
.40164 .15313 .40996 .15846 .42368 .15307 .41542 .14767 Metetra
.651 .86 .979 r
.41542 .14767 .42368 .15307 .43746 .14772 .42927 .14226 Metetra
.648 .859 .98 r
.42927 .14226 .43746 .14772 .45131 .14241 .44318 .1369 Metetra
.645 .858 .981 r
.44318 .1369 .45131 .14241 .46522 .13714 .45716 .13159 Metetra
.641 .857 .982 r
.45716 .13159 .46522 .13714 .47921 .13191 .47122 .12633 Metetra
.637 .856 .983 r
.47122 .12633 .47921 .13191 .49327 .12673 .48534 .12114 Metetra
.632 .855 .984 r
.48534 .12114 .49327 .12673 .50741 .1216 .49955 .11601 Metetra
.627 .855 .986 r
.49955 .11601 .50741 .1216 .52162 .11653 .51383 .11095 Metetra
.621 .855 .987 r
.51383 .11095 .52162 .11653 .53591 .11152 .52818 .10599 Metetra
.614 .855 .989 r
.52818 .10599 .53591 .11152 .55028 .1066 .54262 .10112 Metetra
.605 .854 .991 r
.54262 .10112 .55028 .1066 .56473 .10177 .55715 .09638 Metetra
.594 .854 .993 r
.55715 .09638 .56473 .10177 .57926 .09706 .57176 .09179 Metetra
.58 .853 .995 r
.57176 .09179 .57926 .09706 .59389 .09252 .58647 .0874 Metetra
.561 .85 .997 r
.58647 .0874 .59389 .09252 .60861 .08818 .60127 .08327 Metetra
.534 .845 .999 r
.60127 .08327 .60861 .08818 .62343 .08414 .61618 .0795 Metetra
.492 .834 .998 r
.61618 .0795 .62343 .08414 .63837 .08054 .63121 .07627 Metetra
.421 .808 .989 r
.63121 .07627 .63837 .08054 .65344 .07767 .64638 .07392 Metetra
.277 .735 .953 r
.64638 .07392 .65344 .07767 .66869 .07621 .66175 .07328 Metetra
0 .48 .778 r
.66175 .07328 .66869 .07621 .68426 .07832 .67749 .07695 Metetra
.804 .317 0 r
.67749 .07695 .68426 .07832 .70128 .10164 .6949 .10623 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.20877 .18794 m
.2133 .19269 L
s
[(-0.5)] .19973 .17843 .95073 1 Mshowa
.44056 .09718 m
.44466 .1023 L
s
[(0)] .43236 .08694 .80074 1 Mshowa
.125 Mabswid
.25353 .17041 m
.2562 .17331 L
s
.29907 .15258 m
.30168 .15552 L
s
.3454 .13444 m
.34797 .13742 L
s
.39256 .11597 m
.39507 .119 L
s
.48942 .07804 m
.49183 .08116 L
s
.53918 .05856 m
.54152 .06172 L
s
.58985 .03872 m
.59213 .04193 L
s
.64146 .01851 m
.64368 .02177 L
s
.16478 .20517 m
.16753 .20798 L
s
.12152 .2221 m
.12432 .22487 L
s
.07899 .23876 m
.08183 .24149 L
s
.03716 .25514 m
.04004 .25782 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 233.562},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0468856, 0.0313911, \
0.00349554, 0.00349554}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "SurfaceGraphics", "\[SkeletonIndicator]"}],
  
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullForm", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"Times", "[", 
    RowBox[{"3.3846958676770833`", ",", 
     RowBox[{"Power", "[", 
      RowBox[{"delta", ",", "2"}], "]"}]}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"calcul", "[", "nc_", "]"}], " ", ":=", " ", 
   RowBox[{"(", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gg", " ", "=", " ", 
      RowBox[{"Sum", "[", "  ", 
       RowBox[{
        RowBox[{
         RowBox[{"ToExpression", "[", 
          RowBox[{"\"\<c\>\"", "<>", 
           RowBox[{"ToString", "[", "i", "]"}]}], "]"}], " ", 
         RowBox[{"z", "^", 
          RowBox[{"(", 
           RowBox[{"2", " ", "i"}], ")"}]}]}], " ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "0", ",", " ", "nc"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"cvector", " ", "=", " ", 
      RowBox[{"Table", "[", "  ", 
       RowBox[{
        RowBox[{"ToExpression", "[", 
         RowBox[{"\"\<c\>\"", "<>", 
          RowBox[{"ToString", "[", "i", "]"}]}], "]"}], "  ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "1", ",", " ", "nc"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"c0sol", " ", "=", " ", 
      RowBox[{
       RowBox[{"Solve", "[", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"gg", " ", "/.", " ", 
            RowBox[{"z", " ", "\[Rule]", " ", "H"}]}], " ", ")"}], "\[Equal]",
           " ", "0"}], " ", ",", " ", 
         RowBox[{"{", "c0", "}"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"g", " ", "=", 
      RowBox[{"gg", " ", "/.", " ", "c0sol"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"wseries", "=", "  ", 
      RowBox[{
       RowBox[{"w", " ", "/.", " ", 
        RowBox[{
         RowBox[{"f", "[", "z", "]"}], " ", "\[Rule]", " ", "g"}]}], "/.", 
       "  ", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "'"}], "[", "z", "]"}], " ", "\[Rule]", " ", 
        RowBox[{"D", "[", 
         RowBox[{"g", " ", ",", " ", "z"}], "]"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"W", " ", "=", " ", 
      RowBox[{"4", " ", "Pi", "  ", 
       RowBox[{"Integrate", "[", " ", 
        RowBox[{
         RowBox[{"wseries", "  ", "r"}], " ", ",", " ", 
         RowBox[{"{", 
          RowBox[{"r", ",", "0", ",", "R"}], "}"}], " ", ",", " ", 
         RowBox[{"{", 
          RowBox[{"z", ",", " ", "0", ",", " ", "H"}], "}"}]}], "]"}]}]}], 
     ";", "\n", 
     RowBox[{"eq", " ", "=", " ", 
      RowBox[{"Thread", "[", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"W", ",", " ", "#"}], " ", "]"}], " ", "&"}], ",", " ", 
          "cvector"}], "]"}], "\[Equal]", 
        RowBox[{"Array", "[", " ", 
         RowBox[{
          RowBox[{"0", " ", "&"}], " ", ",", " ", "nc"}], "]"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"csol", " ", "=", " ", 
      RowBox[{"Simplify", "[", " ", 
       RowBox[{"Solve", "[", " ", 
        RowBox[{"eq", ",", " ", "cvector"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"g1", "=", " ", 
      RowBox[{
       RowBox[{"Simplify", "[", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"g", " ", "/.", " ", "csol"}], ")"}], " ", "/.", " ", 
            RowBox[{"nu", " ", "\[Rule]", " ", "0.3"}]}], "  ", "/.", " ", 
           RowBox[{"R", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
          RowBox[{"delta", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
         RowBox[{"H", " ", "\[Rule]", " ", "1"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], " ", ";", "\[IndentingNewLine]", 
     RowBox[{"W1", "=", " ", 
      RowBox[{
       RowBox[{"Simplify", "[", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"W", " ", "/.", " ", "csol"}], ")"}], " ", "/.", " ", 
            RowBox[{"nu", " ", "\[Rule]", " ", "0.3"}]}], "  ", "/.", " ", 
           RowBox[{"R", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
          RowBox[{"delta", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
         RowBox[{"H", " ", "\[Rule]", " ", "1"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], " ", ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"nc", ",", " ", "g1", ",", " ", "W1"}], "}"}]}], ")"}]}], "\n", 
  "\[IndentingNewLine]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"calcul", "[", "1", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{
    RowBox[{"0.3333333333333333`", "\[InvisibleSpace]"}], "-", 
    RowBox[{"0.3333333333333333`", " ", 
     SuperscriptBox["z", "2"]}]}], ",", "3.4235304558350306`"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"calcul", "[", "2", "]"}], "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", 
   RowBox[{
    RowBox[{"0.2873900293255132`", "\[InvisibleSpace]"}], "+", 
    RowBox[{"0.020527859237536653`", " ", 
     SuperscriptBox["z", "2"]}], "-", 
    RowBox[{"0.30791788856304986`", " ", 
     SuperscriptBox["z", "4"]}]}], ",", "3.385734018164953`"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"calcul", "[", "3", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", 
   RowBox[{
    RowBox[{"0.29362278848854106`", "\[InvisibleSpace]"}], "-", 
    RowBox[{"0.0820869098057411`", " ", 
     SuperscriptBox["z", "2"]}], "-", 
    RowBox[{"0.05439494023272`", " ", 
     SuperscriptBox["z", "4"]}], "-", 
    RowBox[{"0.15714093845007995`", " ", 
     SuperscriptBox["z", "6"]}]}], ",", "3.384705556228062`"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"calcul", "[", "5", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", 
   RowBox[{
    RowBox[{"0.29314806018416467`", "\[InvisibleSpace]"}], "-", 
    RowBox[{"0.0685881373845568`", " ", 
     SuperscriptBox["z", "2"]}], "-", 
    RowBox[{"0.11356888735705402`", " ", 
     SuperscriptBox["z", "4"]}], "-", 
    RowBox[{"0.07869129137353197`", " ", 
     SuperscriptBox["z", "6"]}], "-", 
    RowBox[{"0.022678543708036646`", " ", 
     SuperscriptBox["z", "8"]}], "-", 
    RowBox[{"0.009621200360985243`", " ", 
     SuperscriptBox["z", "10"]}]}], ",", "3.3846958677402035`"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c0sol", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"gg", " ", "/.", " ", 
        RowBox[{"z", " ", "\[Rule]", " ", "H"}]}], " ", ")"}], "\[Equal]", 
      " ", "0"}], " ", ",", " ", 
     RowBox[{"{", "c0", "}"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"c0", "\[Rule]", 
  RowBox[{
   RowBox[{"-", "c1"}], " ", 
   SuperscriptBox["H", "2"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[""], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "c1"}], " ", 
   SuperscriptBox["H", "2"]}], "+", 
  RowBox[{"c1", " ", 
   SuperscriptBox["z", "2"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"wseries", "=", "  ", 
  RowBox[{
   RowBox[{"w", " ", "/.", " ", 
    RowBox[{
     RowBox[{"f", "[", "z", "]"}], " ", "\[Rule]", " ", "g"}]}], "/.", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], "[", "z", "]"}], " ", "\[Rule]", " ", 
    RowBox[{"D", "[", 
     RowBox[{"g", " ", ",", " ", "z"}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"W", " ", "=", " ", 
  RowBox[{"4", " ", "Pi", "  ", 
   RowBox[{"Integrate", "[", " ", 
    RowBox[{
     RowBox[{"wseries", "  ", "r"}], " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "R"}], "}"}], " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"z", ",", " ", "0", ",", " ", "H"}], "}"}]}], 
    "]"}]}]}], "\n"}], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["delta", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
    SuperscriptBox["R", "2"]}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["c1", "2"], " ", 
    SuperscriptBox["H", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
    SuperscriptBox["r", "2"], " ", 
    SuperscriptBox["z", "2"]}], "+", 
   RowBox[{"8", " ", "delta", " ", "H", " ", "nu", " ", "R", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "c1"}], " ", 
       SuperscriptBox["H", "2"]}], "+", 
      RowBox[{"c1", " ", 
       SuperscriptBox["z", "2"]}]}], ")"}]}], "-", 
   RowBox[{"4", " ", 
    SuperscriptBox["H", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "c1"}], " ", 
        SuperscriptBox["H", "2"]}], "+", 
       RowBox[{"c1", " ", 
        SuperscriptBox["z", "2"]}]}], ")"}], "2"]}]}], 
  RowBox[{"4", " ", 
   SuperscriptBox["H", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["nu", "2"]}]}], ")"}], " ", 
   SuperscriptBox["R", "2"]}]]], "Output"],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Pi]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "40"}], " ", "c1", " ", "delta", " ", 
      SuperscriptBox["H", "3"], " ", "nu", " ", "R"}], "+", 
     RowBox[{"15", " ", 
      SuperscriptBox["delta", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["c1", "2"], " ", 
      SuperscriptBox["H", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "16"}], " ", 
         SuperscriptBox["H", "2"]}], "+", 
        RowBox[{"5", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
         SuperscriptBox["R", "2"]}]}], ")"}]}]}], ")"}]}], 
  RowBox[{"15", " ", "H", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["nu", "2"]}]}], ")"}]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eq", " ", "=", " ", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"W", ",", " ", "#"}], " ", "]"}], " ", "&"}], ",", " ", 
      "cvector"}], "]"}], "\[Equal]", 
    RowBox[{"Array", "[", " ", 
     RowBox[{
      RowBox[{"0", " ", "&"}], " ", ",", " ", "nc"}], "]"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"csol", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"Solve", "[", " ", 
    RowBox[{"eq", ",", " ", "cvector"}], "]"}], "]"}]}], "\n"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "40"}], " ", "delta", " ", 
        SuperscriptBox["H", "3"], " ", "nu", " ", "R"}], "+", 
       RowBox[{"2", " ", "c1", " ", 
        SuperscriptBox["H", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "16"}], " ", 
           SuperscriptBox["H", "2"]}], "+", 
          RowBox[{"5", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
           SuperscriptBox["R", "2"]}]}], ")"}]}]}], ")"}]}], 
    RowBox[{"15", " ", "H", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "nu", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["nu", "2"]}]}], ")"}]}]], "\[Equal]", "0"}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"c1", "\[Rule]", 
    FractionBox[
     RowBox[{"20", " ", "delta", " ", "nu", " ", "R"}], 
     RowBox[{
      RowBox[{
       RowBox[{"-", "16"}], " ", 
       SuperscriptBox["H", "3"]}], "+", 
      RowBox[{"5", " ", "H", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
       SuperscriptBox["R", "2"]}]}]]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["g"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "c1"}], " ", 
   SuperscriptBox["H", "2"]}], "+", 
  RowBox[{"c1", " ", 
   SuperscriptBox["z", "2"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g1", "=", " ", 
  RowBox[{
   RowBox[{"Simplify", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"g", " ", "/.", " ", "csol"}], ")"}], " ", "/.", " ", 
        RowBox[{"nu", " ", "\[Rule]", " ", 
         RowBox[{"1", "/", "2"}]}]}], "  ", "/.", " ", 
       RowBox[{"R", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
      RowBox[{"delta", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
     RowBox[{"H", " ", "\[Rule]", " ", "1"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["5", "8"]}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    SuperscriptBox["z", "2"]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"g2", " ", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["7", "16"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["z", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["z", "4"]}]}], ")"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["7", "16"]}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["z", "4"]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"g2", ",", " ", "g3", ",", " ", "g5"}], "}"}], "  ", ",", " ", 
   RowBox[{"{", 
    RowBox[{"z", ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147149 1.00904 [
[.21429 .00221 -9 -9 ]
[.21429 .00221 9 0 ]
[.40476 .00221 -9 -9 ]
[.40476 .00221 9 0 ]
[.59524 .00221 -9 -9 ]
[.59524 .00221 9 0 ]
[.78571 .00221 -9 -9 ]
[.78571 .00221 9 0 ]
[.97619 .00221 -3 -9 ]
[.97619 .00221 3 0 ]
[.01131 .11562 -18 -4.5 ]
[.01131 .11562 0 4.5 ]
[.01131 .21652 -18 -4.5 ]
[.01131 .21652 0 4.5 ]
[.01131 .31743 -18 -4.5 ]
[.01131 .31743 0 4.5 ]
[.01131 .41833 -18 -4.5 ]
[.01131 .41833 0 4.5 ]
[.01131 .51923 -18 -4.5 ]
[.01131 .51923 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01471 m
.21429 .02096 L
s
[(0.2)] .21429 .00221 0 1 Mshowa
.40476 .01471 m
.40476 .02096 L
s
[(0.4)] .40476 .00221 0 1 Mshowa
.59524 .01471 m
.59524 .02096 L
s
[(0.6)] .59524 .00221 0 1 Mshowa
.78571 .01471 m
.78571 .02096 L
s
[(0.8)] .78571 .00221 0 1 Mshowa
.97619 .01471 m
.97619 .02096 L
s
[(1)] .97619 .00221 0 1 Mshowa
.125 Mabswid
.07143 .01471 m
.07143 .01846 L
s
.11905 .01471 m
.11905 .01846 L
s
.16667 .01471 m
.16667 .01846 L
s
.2619 .01471 m
.2619 .01846 L
s
.30952 .01471 m
.30952 .01846 L
s
.35714 .01471 m
.35714 .01846 L
s
.45238 .01471 m
.45238 .01846 L
s
.5 .01471 m
.5 .01846 L
s
.54762 .01471 m
.54762 .01846 L
s
.64286 .01471 m
.64286 .01846 L
s
.69048 .01471 m
.69048 .01846 L
s
.7381 .01471 m
.7381 .01846 L
s
.83333 .01471 m
.83333 .01846 L
s
.88095 .01471 m
.88095 .01846 L
s
.92857 .01471 m
.92857 .01846 L
s
.25 Mabswid
0 .01471 m
1 .01471 L
s
.02381 .11562 m
.03006 .11562 L
s
[(0.1)] .01131 .11562 1 0 Mshowa
.02381 .21652 m
.03006 .21652 L
s
[(0.2)] .01131 .21652 1 0 Mshowa
.02381 .31743 m
.03006 .31743 L
s
[(0.3)] .01131 .31743 1 0 Mshowa
.02381 .41833 m
.03006 .41833 L
s
[(0.4)] .01131 .41833 1 0 Mshowa
.02381 .51923 m
.03006 .51923 L
s
[(0.5)] .01131 .51923 1 0 Mshowa
.125 Mabswid
.02381 .0349 m
.02756 .0349 L
s
.02381 .05508 m
.02756 .05508 L
s
.02381 .07526 m
.02756 .07526 L
s
.02381 .09544 m
.02756 .09544 L
s
.02381 .1358 m
.02756 .1358 L
s
.02381 .15598 m
.02756 .15598 L
s
.02381 .17616 m
.02756 .17616 L
s
.02381 .19634 m
.02756 .19634 L
s
.02381 .2367 m
.02756 .2367 L
s
.02381 .25688 m
.02756 .25688 L
s
.02381 .27706 m
.02756 .27706 L
s
.02381 .29724 m
.02756 .29724 L
s
.02381 .33761 m
.02756 .33761 L
s
.02381 .35779 m
.02756 .35779 L
s
.02381 .37797 m
.02756 .37797 L
s
.02381 .39815 m
.02756 .39815 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .45869 m
.02756 .45869 L
s
.02381 .47887 m
.02756 .47887 L
s
.02381 .49905 m
.02756 .49905 L
s
.02381 .53941 m
.02756 .53941 L
s
.02381 .55959 m
.02756 .55959 L
s
.02381 .57977 m
.02756 .57977 L
s
.02381 .59996 m
.02756 .59996 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .45617 m
.02499 .45617 L
.02605 .45617 L
.02729 .45618 L
.02846 .45619 L
.03053 .45621 L
.03279 .45625 L
.03527 .4563 L
.0379 .45636 L
.04262 .45651 L
.04749 .45671 L
.05205 .45694 L
.06244 .45762 L
.07305 .45852 L
.08274 .45953 L
.10458 .46245 L
.14429 .46996 L
.18248 .47965 L
.22313 .4923 L
.26226 .50631 L
.30384 .5226 L
.34391 .539 L
.38246 .55474 L
.42346 .57057 L
.46295 .58402 L
.50092 .59433 L
.52043 .59832 L
.53129 .60009 L
.54134 .6014 L
.55152 .6024 L
.55688 .60279 L
.55963 .60294 L
.56258 .60308 L
.56516 .60318 L
.56628 .60321 L
.56752 .60325 L
.56861 .60327 L
.56977 .60329 L
.571 .60331 L
.57215 .60331 L
.57286 .60332 L
.57351 .60332 L
.57423 .60332 L
.57499 .60332 L
.57627 .60331 L
.577 .6033 L
.57768 .60329 L
.57894 .60326 L
.5801 .60324 L
.5827 .60316 L
Mistroke
.58521 .60305 L
.58748 .60294 L
.59257 .6026 L
.59729 .60219 L
.60173 .60171 L
.6117 .60031 L
.62246 .59826 L
.64244 .59292 L
.66352 .58493 L
.6832 .57508 L
.70154 .56365 L
.7405 .53144 L
.78192 .48388 L
.82182 .42323 L
.8602 .34935 L
.90103 .25198 L
.94035 .1379 L
.97619 .01472 L
Mfstroke
.02381 .55865 m
.02499 .55865 L
.02605 .55864 L
.02729 .55863 L
.02846 .55862 L
.03053 .5586 L
.03279 .55855 L
.03527 .55849 L
.0379 .55842 L
.04262 .55823 L
.04749 .55799 L
.05205 .55772 L
.06244 .55691 L
.07305 .55583 L
.08274 .55463 L
.10458 .55119 L
.14429 .5426 L
.18248 .53204 L
.22313 .51924 L
.26226 .50644 L
.30384 .49362 L
.32471 .48794 L
.34391 .48335 L
.36384 .47939 L
.38246 .47656 L
.39154 .47551 L
.40128 .47465 L
.40683 .47429 L
.40956 .47415 L
.41209 .47404 L
.41433 .47395 L
.41681 .47388 L
.4193 .47383 L
.42066 .4738 L
.42194 .47379 L
.42312 .47378 L
.42438 .47378 L
.42556 .47378 L
.42664 .47378 L
.42791 .4738 L
.42862 .4738 L
.42928 .47381 L
.43057 .47384 L
.43177 .47386 L
.43417 .47393 L
.4368 .47402 L
.44213 .47429 L
.44679 .4746 L
.45105 .47495 L
.46063 .47597 L
Mistroke
.4705 .47737 L
.47965 .47898 L
.50039 .48374 L
.52095 .48997 L
.53957 .49686 L
.57969 .51526 L
.6183 .53635 L
.65935 .5599 L
.67981 .57093 L
.69889 .58007 L
.71725 .58728 L
.72754 .59041 L
.73691 .59257 L
.74174 .59339 L
.74438 .59376 L
.74685 .59404 L
.74896 .59423 L
.75122 .59438 L
.75245 .59445 L
.75374 .59449 L
.75484 .59452 L
.75604 .59454 L
.75671 .59454 L
.75744 .59454 L
.75813 .59453 L
.75877 .59451 L
.75997 .59448 L
.76125 .59442 L
.76262 .59434 L
.7639 .59424 L
.76681 .59395 L
.76933 .59361 L
.77163 .59323 L
.77681 .59212 L
.78161 .59076 L
.78671 .58895 L
.79587 .58468 L
.80573 .57852 L
.81662 .56963 L
.83595 .54778 L
.84682 .53164 L
.8568 .51412 L
.8757 .47301 L
.89639 .41456 L
.91597 .34433 L
.93692 .25084 L
.97619 .01472 L
Mfstroke
.02381 .53993 m
.02499 .53992 L
.02605 .53992 L
.02729 .53991 L
.02846 .53989 L
.03053 .53986 L
.03279 .53981 L
.03527 .53973 L
.0379 .53963 L
.04262 .5394 L
.05205 .53875 L
.06244 .53775 L
.07293 .53644 L
.0842 .53473 L
.10458 .53093 L
.1458 .52128 L
.18551 .51128 L
.22371 .50309 L
.24338 .50005 L
.25438 .4988 L
.26435 .49798 L
.26923 .4977 L
.27189 .49757 L
.27438 .49748 L
.2765 .49742 L
.27877 .49736 L
.28007 .49734 L
.2813 .49732 L
.2824 .49732 L
.2836 .49731 L
.28488 .49731 L
.28609 .49731 L
.28678 .49732 L
.28741 .49732 L
.28884 .49734 L
.29014 .49736 L
.29156 .49739 L
.29441 .49748 L
.29692 .49757 L
.2996 .4977 L
.30442 .49799 L
.30975 .4984 L
.31466 .49887 L
.32576 .50022 L
.34592 .50367 L
.36468 .50792 L
.38532 .51352 L
.42566 .5259 L
.46448 .53707 L
.47461 .53946 L
Mistroke
.48566 .5417 L
.49609 .5434 L
.50576 .54456 L
.51085 .545 L
.51353 .54519 L
.51635 .54534 L
.51883 .54545 L
.52024 .54549 L
.52155 .54553 L
.52275 .54555 L
.52385 .54556 L
.52512 .54557 L
.52632 .54557 L
.52739 .54557 L
.52857 .54555 L
.5298 .54553 L
.53096 .5455 L
.53302 .54544 L
.53525 .54534 L
.53771 .5452 L
.54031 .54501 L
.54494 .54459 L
.54996 .54401 L
.55451 .54335 L
.56472 .54146 L
.5831 .53665 L
.60232 .52984 L
.62314 .52083 L
.66411 .50098 L
.6845 .49203 L
.69447 .48839 L
.70356 .48565 L
.70806 .48453 L
.71296 .48352 L
.71758 .48278 L
.71964 .48252 L
.72186 .48229 L
.72308 .48219 L
.7242 .48211 L
.72533 .48204 L
.72639 .48199 L
.72755 .48195 L
.72882 .48192 L
.73006 .48191 L
.73075 .48192 L
.73138 .48193 L
.73268 .48196 L
.73388 .48201 L
.73519 .48208 L
.73659 .48218 L
Mistroke
.73893 .48241 L
.7415 .48274 L
.7467 .48367 L
.75165 .4849 L
.76093 .48814 L
.77091 .49301 L
.78181 .49998 L
.8015 .51669 L
.82247 .53905 L
.84246 .56183 L
.85298 .57282 L
.85872 .5781 L
.86408 .58235 L
.86888 .58546 L
.87135 .58675 L
.87403 .5879 L
.87556 .58842 L
.87697 .58881 L
.87832 .5891 L
.879 .58921 L
.87975 .5893 L
.88104 .58941 L
.88177 .58943 L
.88244 .58942 L
.88367 .58934 L
.88496 .58917 L
.88616 .58892 L
.88726 .58862 L
.88971 .58766 L
.89199 .58642 L
.89413 .58491 L
.89895 .58023 L
.90166 .57673 L
.90416 .57292 L
.90884 .56414 L
.91387 .55206 L
.92294 .5223 L
.92848 .49834 L
.93373 .47097 L
.94359 .40569 L
.95178 .33534 L
.96051 .2417 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0825959, -0.0458834, \
0.00385924, 0.00364254}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Plot", "[", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"g1", ",", " ", "g2", ",", " ", "g5"}], "}"}], "  ", ",", " ", 
    RowBox[{"{", 
     RowBox[{"z", ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.014715 0.941766 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .10889 -18 -4.5 ]
[.01131 .10889 0 4.5 ]
[.01131 .20307 -18 -4.5 ]
[.01131 .20307 0 4.5 ]
[.01131 .29724 -18 -4.5 ]
[.01131 .29724 0 4.5 ]
[.01131 .39142 -18 -4.5 ]
[.01131 .39142 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .57977 -18 -4.5 ]
[.01131 .57977 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10889 m
.03006 .10889 L
s
[(0.1)] .01131 .10889 1 0 Mshowa
.02381 .20307 m
.03006 .20307 L
s
[(0.2)] .01131 .20307 1 0 Mshowa
.02381 .29724 m
.03006 .29724 L
s
[(0.3)] .01131 .29724 1 0 Mshowa
.02381 .39142 m
.03006 .39142 L
s
[(0.4)] .01131 .39142 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.5)] .01131 .4856 1 0 Mshowa
.02381 .57977 m
.03006 .57977 L
s
[(0.6)] .01131 .57977 1 0 Mshowa
.125 Mabswid
.02381 .03355 m
.02756 .03355 L
s
.02381 .05239 m
.02756 .05239 L
s
.02381 .07122 m
.02756 .07122 L
s
.02381 .09006 m
.02756 .09006 L
s
.02381 .12773 m
.02756 .12773 L
s
.02381 .14656 m
.02756 .14656 L
s
.02381 .1654 m
.02756 .1654 L
s
.02381 .18423 m
.02756 .18423 L
s
.02381 .2219 m
.02756 .2219 L
s
.02381 .24074 m
.02756 .24074 L
s
.02381 .25957 m
.02756 .25957 L
s
.02381 .27841 m
.02756 .27841 L
s
.02381 .31608 m
.02756 .31608 L
s
.02381 .33492 m
.02756 .33492 L
s
.02381 .35375 m
.02756 .35375 L
s
.02381 .37259 m
.02756 .37259 L
s
.02381 .41026 m
.02756 .41026 L
s
.02381 .42909 m
.02756 .42909 L
s
.02381 .44793 m
.02756 .44793 L
s
.02381 .46676 m
.02756 .46676 L
s
.02381 .50443 m
.02756 .50443 L
s
.02381 .52327 m
.02756 .52327 L
s
.02381 .5421 m
.02756 .5421 L
s
.02381 .56094 m
.02756 .56094 L
s
.02381 .59861 m
.02756 .59861 L
s
.02381 .61745 m
.02756 .61745 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60331 L
.02846 .6033 L
.03053 .60329 L
.03279 .60327 L
.03527 .60323 L
.0379 .60319 L
.04262 .60309 L
.04749 .60296 L
.05205 .6028 L
.06244 .60235 L
.07305 .60175 L
.08274 .60106 L
.10458 .59909 L
.12357 .59686 L
.14429 .5939 L
.18493 .58647 L
.22406 .5773 L
.26565 .56537 L
.30571 .55175 L
.34426 .53668 L
.38527 .51853 L
.42475 .499 L
.46273 .4783 L
.50315 .45421 L
.54206 .42903 L
.58342 .4001 L
.62326 .37013 L
.66159 .33935 L
.70238 .30451 L
.74164 .26893 L
.77939 .23284 L
.8196 .19236 L
.85828 .15143 L
.89942 .10578 L
.93905 .05973 L
.97619 .01472 L
s
.02381 .42674 m
.02499 .42674 L
.02605 .42674 L
.02729 .42675 L
.02846 .42676 L
.03053 .42678 L
.03279 .42681 L
.03527 .42686 L
.0379 .42692 L
.04262 .42706 L
.04749 .42725 L
.05205 .42746 L
.06244 .42809 L
.07305 .42893 L
.08274 .42988 L
.10458 .4326 L
.14429 .43961 L
.18248 .44866 L
.22313 .46046 L
.26226 .47354 L
.30384 .48874 L
.34391 .50405 L
.38246 .51874 L
.42346 .53352 L
.46295 .54606 L
.50092 .55569 L
.52043 .55942 L
.53129 .56106 L
.54134 .56229 L
.55152 .56322 L
.55688 .56358 L
.55963 .56373 L
.56258 .56386 L
.56516 .56395 L
.56628 .56398 L
.56752 .56401 L
.56861 .56403 L
.56977 .56405 L
.571 .56407 L
.57215 .56407 L
.57286 .56408 L
.57351 .56408 L
.57423 .56408 L
.57499 .56408 L
.57627 .56407 L
.577 .56406 L
.57768 .56405 L
.57894 .56403 L
.5801 .564 L
.5827 .56393 L
Mistroke
.58521 .56383 L
.58748 .56372 L
.59257 .56341 L
.59729 .56302 L
.60173 .56257 L
.6117 .56127 L
.62246 .55936 L
.64244 .55438 L
.66352 .54691 L
.6832 .53772 L
.70154 .52705 L
.7405 .49699 L
.78192 .45261 L
.82182 .396 L
.8602 .32704 L
.90103 .23617 L
.94035 .12968 L
.97619 .01472 L
Mfstroke
.02381 .50491 m
.02499 .50491 L
.02605 .5049 L
.02729 .50489 L
.02846 .50488 L
.03053 .50485 L
.03279 .5048 L
.03527 .50473 L
.0379 .50464 L
.04262 .50442 L
.05205 .50382 L
.06244 .50288 L
.07293 .50166 L
.0842 .50006 L
.10458 .49652 L
.1458 .48751 L
.18551 .47817 L
.22371 .47054 L
.24338 .46769 L
.25438 .46653 L
.26435 .46577 L
.26923 .4655 L
.27189 .46538 L
.27438 .4653 L
.2765 .46524 L
.27877 .46519 L
.28007 .46517 L
.2813 .46515 L
.2824 .46514 L
.2836 .46514 L
.28488 .46514 L
.28609 .46514 L
.28678 .46514 L
.28741 .46515 L
.28884 .46517 L
.29014 .46519 L
.29156 .46521 L
.29441 .46529 L
.29692 .46538 L
.2996 .4655 L
.30442 .46577 L
.30975 .46616 L
.31466 .46659 L
.32576 .46785 L
.34592 .47108 L
.36468 .47504 L
.38532 .48026 L
.42566 .49182 L
.46448 .50225 L
.47461 .50448 L
Mistroke
.48566 .50657 L
.49609 .50815 L
.50576 .50924 L
.51085 .50965 L
.51353 .50982 L
.51635 .50997 L
.51883 .51007 L
.52024 .51011 L
.52155 .51014 L
.52275 .51016 L
.52385 .51017 L
.52512 .51018 L
.52632 .51018 L
.52739 .51018 L
.52857 .51017 L
.5298 .51014 L
.53096 .51012 L
.53302 .51006 L
.53525 .50996 L
.53771 .50983 L
.54031 .50966 L
.54494 .50927 L
.54996 .50872 L
.55451 .50811 L
.56472 .50635 L
.5831 .50186 L
.60232 .4955 L
.62314 .48709 L
.66411 .46856 L
.6845 .46021 L
.69447 .45681 L
.70356 .45425 L
.70806 .45321 L
.71296 .45227 L
.71758 .45158 L
.71964 .45134 L
.72186 .45112 L
.72308 .45102 L
.7242 .45095 L
.72533 .45088 L
.72639 .45084 L
.72755 .4508 L
.72882 .45078 L
.73006 .45077 L
.73075 .45077 L
.73138 .45078 L
.73268 .45081 L
.73388 .45085 L
.73519 .45092 L
.73659 .45102 L
Mistroke
.73893 .45123 L
.7415 .45154 L
.7467 .45241 L
.75165 .45355 L
.76093 .45657 L
.77091 .46113 L
.78181 .46763 L
.8015 .48323 L
.82247 .50409 L
.84246 .52535 L
.85298 .53562 L
.85872 .54054 L
.86408 .5445 L
.86888 .54741 L
.87135 .54862 L
.87403 .54969 L
.87556 .55017 L
.87697 .55053 L
.87832 .5508 L
.879 .55091 L
.87975 .551 L
.88104 .55109 L
.88177 .55111 L
.88244 .5511 L
.88367 .55103 L
.88496 .55087 L
.88616 .55064 L
.88726 .55036 L
.88971 .54947 L
.89199 .54831 L
.89413 .5469 L
.89895 .54253 L
.90166 .53927 L
.90416 .53571 L
.90884 .52751 L
.91387 .51624 L
.92294 .48846 L
.92848 .4661 L
.93373 .44056 L
.94359 .37963 L
.95178 .31396 L
.96051 .22657 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0825959, -0.0491559, \
0.00385924, 0.00390274}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      FractionBox[
       RowBox[{"delta", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "ee", " ", "s"}], 
           SqrtBox[
            RowBox[{
             FractionBox["1", "2"], "-", "nu"}]]]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["\[ExponentialE]", 
            FractionBox[
             RowBox[{"2", " ", "ee"}], 
             SqrtBox[
              RowBox[{
               FractionBox["1", "2"], "-", "nu"}]]]]}], "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", "ee", " ", "s"}], 
            SqrtBox[
             RowBox[{
              FractionBox["1", "2"], "-", "nu"}]]]], "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", "ee", " ", 
             RowBox[{"(", 
              RowBox[{"2", "+", "s"}], ")"}]}], 
            SqrtBox[
             RowBox[{
              FractionBox["1", "2"], "-", "nu"}]]]], "-", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", "ee", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", "s"}]}], ")"}]}], 
            SqrtBox[
             RowBox[{
              FractionBox["1", "2"], "-", "nu"}]]]]}], ")"}], " ", "nu"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"4", " ", "ee"}], 
            SqrtBox[
             RowBox[{
              FractionBox["1", "2"], "-", "nu"}]]]]}], ")"}], " ", "ee"}]], 
      ")"}], "/.", " ", 
     RowBox[{"nu", " ", "->", " ", "0.3"}]}], " ", "/.", " ", 
    RowBox[{"ee", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
   RowBox[{"delta", " ", "\[Rule]", " ", "1."}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"0.000039139624560927945`", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "4.47213595499958`"}], " ", "s"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "87.54351245861726`"}], "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"4.47213595499958`", " ", "s"}]], "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"4.47213595499958`", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "s"}], ")"}]}]], "-", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"4.47213595499958`", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "s"}]}], ")"}]}]]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", " ", 
  RowBox[{
   RowBox[{"2", "g"}], " ", ",", " ", 
   RowBox[{"{", 
    RowBox[{"s", ",", " ", 
     RowBox[{"10.", "^", 
      RowBox[{"-", "5"}]}], ",", "1"}], "}"}]}], "]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 1.00394 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .11511 -18 -4.5 ]
[.01131 .11511 0 4.5 ]
[.01131 .2155 -18 -4.5 ]
[.01131 .2155 0 4.5 ]
[.01131 .3159 -18 -4.5 ]
[.01131 .3159 0 4.5 ]
[.01131 .41629 -18 -4.5 ]
[.01131 .41629 0 4.5 ]
[.01131 .51668 -18 -4.5 ]
[.01131 .51668 0 4.5 ]
[.01131 .61708 -18 -4.5 ]
[.01131 .61708 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11511 m
.03006 .11511 L
s
[(0.1)] .01131 .11511 1 0 Mshowa
.02381 .2155 m
.03006 .2155 L
s
[(0.2)] .01131 .2155 1 0 Mshowa
.02381 .3159 m
.03006 .3159 L
s
[(0.3)] .01131 .3159 1 0 Mshowa
.02381 .41629 m
.03006 .41629 L
s
[(0.4)] .01131 .41629 1 0 Mshowa
.02381 .51668 m
.03006 .51668 L
s
[(0.5)] .01131 .51668 1 0 Mshowa
.02381 .61708 m
.03006 .61708 L
s
[(0.6)] .01131 .61708 1 0 Mshowa
.125 Mabswid
.02381 .03479 m
.02756 .03479 L
s
.02381 .05487 m
.02756 .05487 L
s
.02381 .07495 m
.02756 .07495 L
s
.02381 .09503 m
.02756 .09503 L
s
.02381 .13519 m
.02756 .13519 L
s
.02381 .15527 m
.02756 .15527 L
s
.02381 .17535 m
.02756 .17535 L
s
.02381 .19542 m
.02756 .19542 L
s
.02381 .23558 m
.02756 .23558 L
s
.02381 .25566 m
.02756 .25566 L
s
.02381 .27574 m
.02756 .27574 L
s
.02381 .29582 m
.02756 .29582 L
s
.02381 .33598 m
.02756 .33598 L
s
.02381 .35605 m
.02756 .35605 L
s
.02381 .37613 m
.02756 .37613 L
s
.02381 .39621 m
.02756 .39621 L
s
.02381 .43637 m
.02756 .43637 L
s
.02381 .45645 m
.02756 .45645 L
s
.02381 .47653 m
.02756 .47653 L
s
.02381 .49661 m
.02756 .49661 L
s
.02381 .53676 m
.02756 .53676 L
s
.02381 .55684 m
.02756 .55684 L
s
.02381 .57692 m
.02756 .57692 L
s
.02381 .597 m
.02756 .597 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02382 .60332 m
.02499 .60332 L
.02606 .60332 L
.0273 .60332 L
.02847 .60332 L
.03054 .60331 L
.0328 .60331 L
.03528 .6033 L
.03791 .60329 L
.04263 .60327 L
.0475 .60323 L
.05206 .6032 L
.06245 .60309 L
.07305 .60295 L
.08275 .60279 L
.10459 .60232 L
.12357 .60178 L
.1443 .60106 L
.18494 .59919 L
.22407 .59677 L
.26565 .59345 L
.30572 .5894 L
.34427 .58457 L
.38527 .57826 L
.42476 .57082 L
.46273 .56217 L
.50315 .55102 L
.54206 .53805 L
.58342 .52134 L
.62327 .50183 L
.6616 .47925 L
.70238 .4503 L
.74165 .41663 L
.7794 .37784 L
.8196 .32821 L
.85829 .27072 L
.89942 .19696 L
.93905 .11109 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzNmndoFEEUxje5RJOoscbYvRRLYom99woWUBBUEOSwkCBqjBEVRUH/EEUF
UVFEbCiiqFgQe1dU7A17i7339lfMzsa3ydz35raFM8hm+eY337w383ac28vA
QG7mmPGB3KxRAX/fnEB2Ztaoyf4+E3MKJF+EpkX4NU3b5df0+/yC28JLfsG/
/CT9oivmfS/9V6SORAnBpxm4YLRI/RqlKylKDmnqHj5qTbXIpVMssUboPQuH
LooX/MRwsQSjcQBNVrkGyfboRmC8GGUysdYjLK3fRNNa/TcpoElOUqQQLKcq
IvQpEo6l2mlsO+oyoIffWsGFCtlabXo2//aW3ZyzEkshjdbNKA2tGrBMozji
ikcUya1OSvEeZmFILopaQIGIaylv2ivpvwrLS/u338Fe6KFBewHiwtX3f4/P
TV9FgTQDWoYLLqN4zeJB/7C5QPw3m6aBi+GQpyKEUJ5S0y+glQkX/hNoZeX5
QJ5lec8fQCsXLvw70OLlBJFnPO/5DWjlw4V/BVoFOUHkWcG5p9T0BWgVHeHR
FLH6EI5aPwOtkmFr4JYOZL6SdRZSyUX6CWiVw+RsnkqjQd+PQKsiFwE63aDg
FGbmM4CgBL5KP9jD3wOtqmf4O6Alygkiz0TnnlLTW6BV8wx/A7TqznExHwiq
wXu+toe/AlpNz/CXQKslJ4g8a/GeL4BW2xHuZpt+DrQ6hq1qI5F6oC3FvjM6
9ApUSM9Aa12ln9XN1L4z2gkjgZYHNL+F2Q2S0dIpzM2KMD9fojV6CrQkvgaf
AC1ZfgyQZzLv+RhoKZ7hj4CW6hwXCSKoHu/50B7+AGj1PcPvA62BnCCCGvKe
9+zhd4GWxuN3gJbO47eB1sg5LuYDQY15z1tAa8LjN4HW1MDVG7v5Cho92gpb
91vPDaBlKM3ZHVNI10FrM6Wf+T4QJX8NaM2dxefa2ca0XgVaC7kU1Dv6FaC1
lAsaQa34Cr1sD78EtNY8fhFobXj8AtDaOsfFfCCoHe95Hmjtefwc0Dp4hp8F
Wkc5QQR14j3PAK0zj58GWhcePwW0rjx+Emjd5AQR1J33PGEPPw60Hjx+DGjG
lyAhdnR2l5e0o0DrZQzg8ih8BGi9lc7m13vmUf0wcOkT2iVYRjvcIaD1VZqj
L8KQ8wFanH5KP/X/PfuB1k9efauvUvYBrb9c/AgawJfnXqAN5PE9NM4gHtoN
NAW+C2iD5bR20t0Q3mkH0BT4NvIcykNbCRrOQ1uApsA3k+cIOc/NAB/BO22k
jiN5aANBAR5aDzQFvpY8R8sprKG7sXz/1UBT4KvIM0t+etjXHD7uoVxJfccZ
Zi6PgSuA5tBZSMspvglKF/Vb3KXkkh3aReqL/JaQX44nfosp+lx5ScWeyr6l
WkjcVL5g5pP7dLk+51HTTL7/HAphNg/NImguD82g4ebx0DSCFsjhTqFBFvH9
J1H/JTw0npyW8VAWQSt5aAxBq+VwxZ4hjgDr+P7D9GuMrmzioUEEbeeh/jTc
Xh7qSU4HeUic8cWfPJyUcxJvfRL0u0tFmurrQh5vKK6l5Nq2/+G9qI/7j5Uu
3YSZVQ8TjrcwIIjTXTfpY7IZTeF30lrEXwVs2zo=\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0964665, -0.046175, \
0.00395019, 0.00374732}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"%81", ",", " ", "%95"}], "]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.014715 0.941766 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .10889 -18 -4.5 ]
[.01131 .10889 0 4.5 ]
[.01131 .20307 -18 -4.5 ]
[.01131 .20307 0 4.5 ]
[.01131 .29724 -18 -4.5 ]
[.01131 .29724 0 4.5 ]
[.01131 .39142 -18 -4.5 ]
[.01131 .39142 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .57977 -18 -4.5 ]
[.01131 .57977 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10889 m
.03006 .10889 L
s
[(0.1)] .01131 .10889 1 0 Mshowa
.02381 .20307 m
.03006 .20307 L
s
[(0.2)] .01131 .20307 1 0 Mshowa
.02381 .29724 m
.03006 .29724 L
s
[(0.3)] .01131 .29724 1 0 Mshowa
.02381 .39142 m
.03006 .39142 L
s
[(0.4)] .01131 .39142 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.5)] .01131 .4856 1 0 Mshowa
.02381 .57977 m
.03006 .57977 L
s
[(0.6)] .01131 .57977 1 0 Mshowa
.125 Mabswid
.02381 .03355 m
.02756 .03355 L
s
.02381 .05239 m
.02756 .05239 L
s
.02381 .07122 m
.02756 .07122 L
s
.02381 .09006 m
.02756 .09006 L
s
.02381 .12773 m
.02756 .12773 L
s
.02381 .14656 m
.02756 .14656 L
s
.02381 .1654 m
.02756 .1654 L
s
.02381 .18423 m
.02756 .18423 L
s
.02381 .2219 m
.02756 .2219 L
s
.02381 .24074 m
.02756 .24074 L
s
.02381 .25957 m
.02756 .25957 L
s
.02381 .27841 m
.02756 .27841 L
s
.02381 .31608 m
.02756 .31608 L
s
.02381 .33492 m
.02756 .33492 L
s
.02381 .35375 m
.02756 .35375 L
s
.02381 .37259 m
.02756 .37259 L
s
.02381 .41026 m
.02756 .41026 L
s
.02381 .42909 m
.02756 .42909 L
s
.02381 .44793 m
.02756 .44793 L
s
.02381 .46676 m
.02756 .46676 L
s
.02381 .50443 m
.02756 .50443 L
s
.02381 .52327 m
.02756 .52327 L
s
.02381 .5421 m
.02756 .5421 L
s
.02381 .56094 m
.02756 .56094 L
s
.02381 .59861 m
.02756 .59861 L
s
.02381 .61745 m
.02756 .61745 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60331 L
.02846 .6033 L
.03053 .60329 L
.03279 .60327 L
.03527 .60323 L
.0379 .60319 L
.04262 .60309 L
.04749 .60296 L
.05205 .6028 L
.06244 .60235 L
.07305 .60175 L
.08274 .60106 L
.10458 .59909 L
.12357 .59686 L
.14429 .5939 L
.18493 .58647 L
.22406 .5773 L
.26565 .56537 L
.30571 .55175 L
.34426 .53668 L
.38527 .51853 L
.42475 .499 L
.46273 .4783 L
.50315 .45421 L
.54206 .42903 L
.58342 .4001 L
.62326 .37013 L
.66159 .33935 L
.70238 .30451 L
.74164 .26893 L
.77939 .23284 L
.8196 .19236 L
.85828 .15143 L
.89942 .10578 L
.93905 .05973 L
.97619 .01472 L
s
.02381 .42674 m
.02499 .42674 L
.02605 .42674 L
.02729 .42675 L
.02846 .42676 L
.03053 .42678 L
.03279 .42681 L
.03527 .42686 L
.0379 .42692 L
.04262 .42706 L
.04749 .42725 L
.05205 .42746 L
.06244 .42809 L
.07305 .42893 L
.08274 .42988 L
.10458 .4326 L
.14429 .43961 L
.18248 .44866 L
.22313 .46046 L
.26226 .47354 L
.30384 .48874 L
.34391 .50405 L
.38246 .51874 L
.42346 .53352 L
.46295 .54606 L
.50092 .55569 L
.52043 .55942 L
.53129 .56106 L
.54134 .56229 L
.55152 .56322 L
.55688 .56358 L
.55963 .56373 L
.56258 .56386 L
.56516 .56395 L
.56628 .56398 L
.56752 .56401 L
.56861 .56403 L
.56977 .56405 L
.571 .56407 L
.57215 .56407 L
.57286 .56408 L
.57351 .56408 L
.57423 .56408 L
.57499 .56408 L
.57627 .56407 L
.577 .56406 L
.57768 .56405 L
.57894 .56403 L
.5801 .564 L
.5827 .56393 L
Mistroke
.58521 .56383 L
.58748 .56372 L
.59257 .56341 L
.59729 .56302 L
.60173 .56257 L
.6117 .56127 L
.62246 .55936 L
.64244 .55438 L
.66352 .54691 L
.6832 .53772 L
.70154 .52705 L
.7405 .49699 L
.78192 .45261 L
.82182 .396 L
.8602 .32704 L
.90103 .23617 L
.94035 .12968 L
.97619 .01472 L
Mfstroke
.02381 .50491 m
.02499 .50491 L
.02605 .5049 L
.02729 .50489 L
.02846 .50488 L
.03053 .50485 L
.03279 .5048 L
.03527 .50473 L
.0379 .50464 L
.04262 .50442 L
.05205 .50382 L
.06244 .50288 L
.07293 .50166 L
.0842 .50006 L
.10458 .49652 L
.1458 .48751 L
.18551 .47817 L
.22371 .47054 L
.24338 .46769 L
.25438 .46653 L
.26435 .46577 L
.26923 .4655 L
.27189 .46538 L
.27438 .4653 L
.2765 .46524 L
.27877 .46519 L
.28007 .46517 L
.2813 .46515 L
.2824 .46514 L
.2836 .46514 L
.28488 .46514 L
.28609 .46514 L
.28678 .46514 L
.28741 .46515 L
.28884 .46517 L
.29014 .46519 L
.29156 .46521 L
.29441 .46529 L
.29692 .46538 L
.2996 .4655 L
.30442 .46577 L
.30975 .46616 L
.31466 .46659 L
.32576 .46785 L
.34592 .47108 L
.36468 .47504 L
.38532 .48026 L
.42566 .49182 L
.46448 .50225 L
.47461 .50448 L
Mistroke
.48566 .50657 L
.49609 .50815 L
.50576 .50924 L
.51085 .50965 L
.51353 .50982 L
.51635 .50997 L
.51883 .51007 L
.52024 .51011 L
.52155 .51014 L
.52275 .51016 L
.52385 .51017 L
.52512 .51018 L
.52632 .51018 L
.52739 .51018 L
.52857 .51017 L
.5298 .51014 L
.53096 .51012 L
.53302 .51006 L
.53525 .50996 L
.53771 .50983 L
.54031 .50966 L
.54494 .50927 L
.54996 .50872 L
.55451 .50811 L
.56472 .50635 L
.5831 .50186 L
.60232 .4955 L
.62314 .48709 L
.66411 .46856 L
.6845 .46021 L
.69447 .45681 L
.70356 .45425 L
.70806 .45321 L
.71296 .45227 L
.71758 .45158 L
.71964 .45134 L
.72186 .45112 L
.72308 .45102 L
.7242 .45095 L
.72533 .45088 L
.72639 .45084 L
.72755 .4508 L
.72882 .45078 L
.73006 .45077 L
.73075 .45077 L
.73138 .45078 L
.73268 .45081 L
.73388 .45085 L
.73519 .45092 L
.73659 .45102 L
Mistroke
.73893 .45123 L
.7415 .45154 L
.7467 .45241 L
.75165 .45355 L
.76093 .45657 L
.77091 .46113 L
.78181 .46763 L
.8015 .48323 L
.82247 .50409 L
.84246 .52535 L
.85298 .53562 L
.85872 .54054 L
.86408 .5445 L
.86888 .54741 L
.87135 .54862 L
.87403 .54969 L
.87556 .55017 L
.87697 .55053 L
.87832 .5508 L
.879 .55091 L
.87975 .551 L
.88104 .55109 L
.88177 .55111 L
.88244 .5511 L
.88367 .55103 L
.88496 .55087 L
.88616 .55064 L
.88726 .55036 L
.88971 .54947 L
.89199 .54831 L
.89413 .5469 L
.89895 .54253 L
.90166 .53927 L
.90416 .53571 L
.90884 .52751 L
.91387 .51624 L
.92294 .48846 L
.92848 .4661 L
.93373 .44056 L
.94359 .37963 L
.95178 .31396 L
.96051 .22657 L
.97619 .01472 L
Mfstroke
.02382 .56687 m
.02499 .56687 L
.02606 .56687 L
.0273 .56687 L
.02847 .56686 L
.03054 .56686 L
.0328 .56686 L
.03528 .56685 L
.03791 .56684 L
.04263 .56682 L
.0475 .56679 L
.05206 .56675 L
.06245 .56665 L
.07305 .56652 L
.08275 .56637 L
.10459 .56593 L
.12357 .56542 L
.1443 .56475 L
.18494 .56299 L
.22407 .56073 L
.26565 .55761 L
.30572 .55381 L
.34427 .54928 L
.38527 .54336 L
.42476 .53638 L
.46273 .52826 L
.50315 .51781 L
.54206 .50564 L
.58342 .48997 L
.62327 .47166 L
.6616 .45049 L
.70238 .42332 L
.74165 .39174 L
.7794 .35535 L
.8196 .30879 L
.85828 .25487 L
.89942 .18568 L
.93905 .10513 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0825959, -0.0491559, \
0.00385924, 0.00390274}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"poly", "[", "nc_", "]"}], " ", ":=", " ", 
   RowBox[{"(", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gg", " ", "=", " ", 
      RowBox[{"Sum", "[", "  ", 
       RowBox[{
        RowBox[{
         RowBox[{"ToExpression", "[", 
          RowBox[{"\"\<c\>\"", "<>", 
           RowBox[{"ToString", "[", "i", "]"}]}], "]"}], " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", " ", "z"}], ")"}], "^", 
          RowBox[{"(", "i", ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", "z"}], ")"}], "^", 
          RowBox[{"(", "i", ")"}]}]}], " ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "1", ",", " ", "nc"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"cvector", " ", "=", " ", 
      RowBox[{"Table", "[", "  ", 
       RowBox[{
        RowBox[{"ToExpression", "[", 
         RowBox[{"\"\<c\>\"", "<>", 
          RowBox[{"ToString", "[", "i", "]"}]}], "]"}], "  ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "1", ",", " ", "nc"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"wseries", "=", "  ", 
      RowBox[{
       RowBox[{"w", " ", "/.", " ", 
        RowBox[{
         RowBox[{"f", "[", "z", "]"}], " ", "\[Rule]", " ", "gg"}]}], "/.", 
       "  ", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "'"}], "[", "z", "]"}], " ", "\[Rule]", " ", 
        RowBox[{"D", "[", 
         RowBox[{"gg", " ", ",", " ", "z"}], "]"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"W", " ", "=", " ", 
      RowBox[{"4", " ", "Pi", "  ", 
       RowBox[{"Integrate", "[", " ", 
        RowBox[{
         RowBox[{"wseries", "  ", "r"}], " ", ",", " ", 
         RowBox[{"{", 
          RowBox[{"r", ",", "0", ",", "R"}], "}"}], " ", ",", " ", 
         RowBox[{"{", 
          RowBox[{"z", ",", " ", "0", ",", " ", "H"}], "}"}]}], "]"}]}]}], 
     ";", "\n", 
     RowBox[{"eq", " ", "=", " ", 
      RowBox[{"Thread", "[", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"W", ",", " ", "#"}], " ", "]"}], " ", "&"}], ",", " ", 
          "cvector"}], "]"}], "\[Equal]", 
        RowBox[{"Array", "[", " ", 
         RowBox[{
          RowBox[{"0", " ", "&"}], " ", ",", " ", "nc"}], "]"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"csol", " ", "=", " ", 
      RowBox[{"Simplify", "[", " ", 
       RowBox[{"Solve", "[", " ", 
        RowBox[{"eq", ",", " ", "cvector"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"g1", "=", " ", 
      RowBox[{
       RowBox[{"Simplify", "[", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"gg", " ", "/.", " ", "csol"}], ")"}], " ", "/.", " ", 
            RowBox[{"nu", " ", "\[Rule]", " ", "0.3"}]}], "  ", "/.", " ", 
           RowBox[{"R", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
          RowBox[{"delta", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
         RowBox[{"H", " ", "\[Rule]", " ", "1"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], " ", ";", "\[IndentingNewLine]", 
     RowBox[{"W1", "=", " ", 
      RowBox[{
       RowBox[{"Simplify", "[", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"W", " ", "/.", " ", "csol"}], ")"}], " ", "/.", " ", 
            RowBox[{"nu", " ", "\[Rule]", " ", "0.3"}]}], "  ", "/.", " ", 
           RowBox[{"R", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
          RowBox[{"delta", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
         RowBox[{"H", " ", "\[Rule]", " ", "1"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], " ", ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"nc", ",", " ", "g1", ",", " ", "W1"}], "}"}]}], ")"}]}], 
  "\n"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"poly", "[", "1", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{
    RowBox[{"-", "0.3333333333333333`"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1.`"}], "+", "z"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"1.`", "\[InvisibleSpace]"}], "+", "z"}], ")"}]}], ",", 
   "3.4235304558350306`"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"poly", "[", "2", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", 
   RowBox[{
    RowBox[{"0.2873900293255131`", "\[InvisibleSpace]"}], "+", 
    RowBox[{"0.`", " ", "z"}], "+", 
    RowBox[{"0.02052785923753686`", " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{"0.`", " ", 
     SuperscriptBox["z", "3"]}], "-", 
    RowBox[{"0.30791788856304986`", " ", 
     SuperscriptBox["z", "4"]}]}], ",", "3.385734018164953`"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"poly", "[", "3", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", 
   RowBox[{
    RowBox[{"0.29362278848853607`", "\[InvisibleSpace]"}], "+", 
    RowBox[{"0.`", " ", "z"}], "-", 
    RowBox[{"0.08208690980573752`", " ", 
     SuperscriptBox["z", "2"]}], "+", 
    RowBox[{"1.1102230246251565`*^-16", " ", 
     SuperscriptBox["z", "3"]}], "-", 
    RowBox[{"0.05439494023271785`", " ", 
     SuperscriptBox["z", "4"]}], "+", 
    RowBox[{"0.`", " ", 
     SuperscriptBox["z", "5"]}], "-", 
    RowBox[{"0.15714093845008092`", " ", 
     SuperscriptBox["z", "6"]}]}], ",", "3.3847055562280635`"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ccos", "[", "nc_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"ccos", "[", "nc", "]"}], " ", "=", " ", 
   RowBox[{"(", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gg", " ", "=", " ", 
      RowBox[{"Sum", "[", "  ", 
       RowBox[{
        RowBox[{
         RowBox[{"ToExpression", "[", 
          RowBox[{"\"\<c\>\"", "<>", 
           RowBox[{"ToString", "[", "i", "]"}]}], "]"}], " ", 
         RowBox[{"Cos", "[", " ", 
          RowBox[{
           RowBox[{"z", "/", "H"}], " ", 
           RowBox[{"Pi", " ", "/", " ", "2"}], "  ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "i"}], " ", "+", " ", "1"}], ")"}]}], "]"}]}], " ", 
        ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "1", ",", " ", "nc"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"cvector", " ", "=", " ", 
      RowBox[{"Table", "[", "  ", 
       RowBox[{
        RowBox[{"ToExpression", "[", 
         RowBox[{"\"\<c\>\"", "<>", 
          RowBox[{"ToString", "[", "i", "]"}]}], "]"}], "  ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "1", ",", " ", "nc"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"wseries", "=", "  ", 
      RowBox[{
       RowBox[{"w", " ", "/.", " ", 
        RowBox[{
         RowBox[{"f", "[", "z", "]"}], " ", "\[Rule]", " ", "gg"}]}], "/.", 
       "  ", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "'"}], "[", "z", "]"}], " ", "\[Rule]", " ", 
        RowBox[{"D", "[", 
         RowBox[{"gg", " ", ",", " ", "z"}], "]"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"W", " ", "=", " ", 
      RowBox[{"4", " ", "Pi", "  ", 
       RowBox[{"Integrate", "[", " ", 
        RowBox[{
         RowBox[{"wseries", "  ", "r"}], " ", ",", " ", 
         RowBox[{"{", 
          RowBox[{"r", ",", "0", ",", "R"}], "}"}], " ", ",", " ", 
         RowBox[{"{", 
          RowBox[{"z", ",", " ", "0", ",", " ", "H"}], "}"}]}], "]"}]}]}], 
     ";", "\n", 
     RowBox[{"eq", " ", "=", " ", 
      RowBox[{"Thread", "[", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"W", ",", " ", "#"}], " ", "]"}], " ", "&"}], ",", " ", 
          "cvector"}], "]"}], "\[Equal]", 
        RowBox[{"Array", "[", " ", 
         RowBox[{
          RowBox[{"0", " ", "&"}], " ", ",", " ", "nc"}], "]"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"csol", " ", "=", " ", 
      RowBox[{"Simplify", "[", " ", 
       RowBox[{"Solve", "[", " ", 
        RowBox[{"eq", ",", " ", "cvector"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"g1", "=", " ", 
      RowBox[{
       RowBox[{"Simplify", "[", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"gg", " ", "/.", " ", "csol"}], ")"}], " ", "/.", " ", 
            RowBox[{"nu", " ", "\[Rule]", " ", "0.3"}]}], "  ", "/.", " ", 
           RowBox[{"R", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
          RowBox[{"delta", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
         RowBox[{"H", " ", "\[Rule]", " ", "1"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], " ", ";", "\[IndentingNewLine]", 
     RowBox[{"W1", "=", " ", 
      RowBox[{
       RowBox[{"Simplify", "[", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"W", " ", "/.", " ", "csol"}], ")"}], " ", "/.", " ", 
            RowBox[{"nu", " ", "\[Rule]", " ", "0.3"}]}], "  ", "/.", " ", 
           RowBox[{"R", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
          RowBox[{"delta", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
         RowBox[{"H", " ", "\[Rule]", " ", "1"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], " ", ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"nc", ",", " ", "g1", ",", " ", "W1"}], "}"}]}], 
    ")"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ccos", "[", "1", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{
    RowBox[{"-", "0.06033365615849769`"}], " ", 
    RowBox[{"Cos", "[", 
     FractionBox[
      RowBox[{"3", " ", "\[Pi]", " ", "z"}], "2"], "]"}]}], ",", 
   "4.182656528941261`"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ccos", "[", "2", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "0.06033365615849769`"}], " ", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"3", " ", "\[Pi]", " ", "z"}], "2"], "]"}]}], "+", 
    RowBox[{"0.018704620666925097`", " ", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"5", " ", "\[Pi]", " ", "z"}], "2"], "]"}]}]}], ",", 
   "4.174023627094988`"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ccos", "[", "3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "0.06033365615849769`"}], " ", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"3", " ", "\[Pi]", " ", "z"}], "2"], "]"}]}], "+", 
    RowBox[{"0.018704620666925097`", " ", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"5", " ", "\[Pi]", " ", "z"}], "2"], "]"}]}], "-", 
    RowBox[{"0.007745405433404745`", " ", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"7", " ", "\[Pi]", " ", "z"}], "2"], "]"}]}]}], ",", 
   "4.171470196732328`"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"ccos", "[", "1", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
      RowBox[{
       RowBox[{"ccos", "[", "2", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
      RowBox[{
       RowBox[{"ccos", "[", "3", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], " ", "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "1"}], "}"}], ",", " ", 
    RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.274984 4.31383 [
[.21429 .26248 -9 -9 ]
[.21429 .26248 9 0 ]
[.40476 .26248 -9 -9 ]
[.40476 .26248 9 0 ]
[.59524 .26248 -9 -9 ]
[.59524 .26248 9 0 ]
[.78571 .26248 -9 -9 ]
[.78571 .26248 9 0 ]
[.97619 .26248 -3 -9 ]
[.97619 .26248 3 0 ]
[.01131 .01615 -30 -4.5 ]
[.01131 .01615 0 4.5 ]
[.01131 .10243 -30 -4.5 ]
[.01131 .10243 0 4.5 ]
[.01131 .18871 -30 -4.5 ]
[.01131 .18871 0 4.5 ]
[.01131 .36126 -24 -4.5 ]
[.01131 .36126 0 4.5 ]
[.01131 .44754 -24 -4.5 ]
[.01131 .44754 0 4.5 ]
[.01131 .53381 -24 -4.5 ]
[.01131 .53381 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .27498 m
.21429 .28123 L
s
[(0.2)] .21429 .26248 0 1 Mshowa
.40476 .27498 m
.40476 .28123 L
s
[(0.4)] .40476 .26248 0 1 Mshowa
.59524 .27498 m
.59524 .28123 L
s
[(0.6)] .59524 .26248 0 1 Mshowa
.78571 .27498 m
.78571 .28123 L
s
[(0.8)] .78571 .26248 0 1 Mshowa
.97619 .27498 m
.97619 .28123 L
s
[(1)] .97619 .26248 0 1 Mshowa
.125 Mabswid
.07143 .27498 m
.07143 .27873 L
s
.11905 .27498 m
.11905 .27873 L
s
.16667 .27498 m
.16667 .27873 L
s
.2619 .27498 m
.2619 .27873 L
s
.30952 .27498 m
.30952 .27873 L
s
.35714 .27498 m
.35714 .27873 L
s
.45238 .27498 m
.45238 .27873 L
s
.5 .27498 m
.5 .27873 L
s
.54762 .27498 m
.54762 .27873 L
s
.64286 .27498 m
.64286 .27873 L
s
.69048 .27498 m
.69048 .27873 L
s
.7381 .27498 m
.7381 .27873 L
s
.83333 .27498 m
.83333 .27873 L
s
.88095 .27498 m
.88095 .27873 L
s
.92857 .27498 m
.92857 .27873 L
s
.25 Mabswid
0 .27498 m
1 .27498 L
s
.02381 .01615 m
.03006 .01615 L
s
[(-0.06)] .01131 .01615 1 0 Mshowa
.02381 .10243 m
.03006 .10243 L
s
[(-0.04)] .01131 .10243 1 0 Mshowa
.02381 .18871 m
.03006 .18871 L
s
[(-0.02)] .01131 .18871 1 0 Mshowa
.02381 .36126 m
.03006 .36126 L
s
[(0.02)] .01131 .36126 1 0 Mshowa
.02381 .44754 m
.03006 .44754 L
s
[(0.04)] .01131 .44754 1 0 Mshowa
.02381 .53381 m
.03006 .53381 L
s
[(0.06)] .01131 .53381 1 0 Mshowa
.125 Mabswid
.02381 .03772 m
.02756 .03772 L
s
.02381 .05929 m
.02756 .05929 L
s
.02381 .08086 m
.02756 .08086 L
s
.02381 .124 m
.02756 .124 L
s
.02381 .14557 m
.02756 .14557 L
s
.02381 .16714 m
.02756 .16714 L
s
.02381 .21028 m
.02756 .21028 L
s
.02381 .23185 m
.02756 .23185 L
s
.02381 .25342 m
.02756 .25342 L
s
.02381 .29655 m
.02756 .29655 L
s
.02381 .31812 m
.02756 .31812 L
s
.02381 .33969 m
.02756 .33969 L
s
.02381 .38283 m
.02756 .38283 L
s
.02381 .4044 m
.02756 .4044 L
s
.02381 .42597 m
.02756 .42597 L
s
.02381 .46911 m
.02756 .46911 L
s
.02381 .49068 m
.02756 .49068 L
s
.02381 .51224 m
.02756 .51224 L
s
.02381 .55538 m
.02756 .55538 L
s
.02381 .57695 m
.02756 .57695 L
s
.02381 .59852 m
.02756 .59852 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01473 L
.02729 .01475 L
.02846 .01478 L
.03053 .01486 L
.03279 .01497 L
.03527 .01513 L
.0379 .01535 L
.04262 .01584 L
.04749 .0165 L
.05205 .01725 L
.06244 .01946 L
.07305 .0224 L
.08274 .0257 L
.10458 .03523 L
.14429 .05961 L
.18248 .09089 L
.22313 .13136 L
.26226 .1758 L
.30384 .22705 L
.34391 .27838 L
.38246 .32766 L
.42346 .37794 L
.46295 .42238 L
.50092 .45986 L
.54134 .49257 L
.58025 .51588 L
.59042 .52053 L
.60149 .52488 L
.61106 .52805 L
.62161 .53088 L
.62652 .53195 L
.63181 .53295 L
.63638 .53366 L
.64139 .5343 L
.64673 .53479 L
.64964 .53499 L
.65103 .53506 L
.65235 .53512 L
.65357 .53517 L
.65489 .53521 L
.65609 .53523 L
.6572 .53525 L
.6584 .53525 L
.65973 .53525 L
.66039 .53524 L
.6611 .53524 L
.66239 .53521 L
.66308 .53519 L
Mistroke
.66373 .53517 L
.66494 .53513 L
.66765 .535 L
.66999 .53485 L
.67253 .53465 L
.67828 .53404 L
.68357 .53329 L
.69335 .53144 L
.70367 .52884 L
.72335 .52206 L
.74169 .51363 L
.78066 .48931 L
.82207 .45478 L
.86197 .41438 L
.90035 .37038 L
.94118 .31984 L
.97619 .27498 L
Mfstroke
.02381 .0954 m
.02499 .0954 L
.02605 .09541 L
.02729 .09541 L
.02846 .09541 L
.03053 .09542 L
.03279 .09544 L
.03527 .09546 L
.0379 .09549 L
.04262 .09556 L
.04749 .09565 L
.05205 .09576 L
.06244 .09608 L
.07305 .09653 L
.08274 .09705 L
.09407 .0978 L
.10458 .09867 L
.12357 .10067 L
.14429 .10364 L
.16481 .10755 L
.18342 .11207 L
.20429 .11842 L
.22348 .12563 L
.26204 .14458 L
.30152 .17096 L
.33949 .20342 L
.37992 .24545 L
.41883 .29228 L
.46019 .34704 L
.50003 .40201 L
.53836 .45397 L
.57915 .50466 L
.61841 .54542 L
.63811 .56183 L
.65616 .57409 L
.67551 .58395 L
.68567 .58769 L
.69127 .58932 L
.69637 .59051 L
.70128 .59141 L
.70591 .59203 L
.70846 .59227 L
.7108 .59244 L
.71203 .5925 L
.71338 .59255 L
.71406 .59257 L
.71479 .59258 L
.71611 .59259 L
.71733 .59258 L
.71846 .59256 L
Mistroke
.71971 .59252 L
.7204 .59249 L
.72103 .59246 L
.72344 .59231 L
.7257 .5921 L
.72992 .59157 L
.73447 .59078 L
.73941 .58967 L
.744 .58839 L
.75445 .58462 L
.76463 .5798 L
.77553 .57339 L
.79681 .55719 L
.81694 .53752 L
.85532 .48928 L
.89616 .42485 L
.93548 .35365 L
.97328 .28067 L
.97619 .27498 L
Mfstroke
.02381 .06199 m
.02499 .06199 L
.02605 .062 L
.02729 .06202 L
.02846 .06205 L
.03053 .06211 L
.03279 .06221 L
.03527 .06234 L
.0379 .06252 L
.04262 .06293 L
.04749 .06348 L
.05205 .06411 L
.06244 .06594 L
.07305 .06837 L
.08274 .07108 L
.10458 .07876 L
.14429 .09766 L
.18248 .12044 L
.22313 .14777 L
.26226 .17563 L
.30384 .20601 L
.34391 .23605 L
.38246 .26641 L
.42346 .30148 L
.46295 .33911 L
.50092 .37936 L
.54134 .42604 L
.58025 .47285 L
.62161 .52107 L
.66146 .56135 L
.67968 .57632 L
.69005 .5836 L
.69979 .58951 L
.7101 .59471 L
.71956 .59847 L
.72439 .59999 L
.72967 .60133 L
.73498 .60234 L
.73788 .60275 L
.73918 .6029 L
.74057 .60303 L
.74182 .60313 L
.7432 .60321 L
.74445 .60327 L
.74562 .6033 L
.74633 .60331 L
.747 .60332 L
.74826 .60331 L
.74896 .6033 L
.74961 .60328 L
Mistroke
.75033 .60326 L
.75109 .60322 L
.75238 .60315 L
.75378 .60304 L
.75631 .60278 L
.75877 .60244 L
.76103 .60206 L
.76534 .60114 L
.77007 .59983 L
.77961 .59624 L
.78985 .59095 L
.79916 .58484 L
.82009 .5666 L
.83921 .54456 L
.85999 .51508 L
.90082 .44233 L
.94014 .35831 L
.97619 .27498 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.134313, -0.0711424, \
0.00403944, 0.000891802}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", " ", "g_"}], "]"}], " ", ":=", " ", 
  RowBox[{"g", "[", "x", "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], " ", ":=", " ", "x"}], "]"}]], "Input"],

Cell[BoxData["Symbol"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"4.", ",", " ", "Sin"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", "0.7568024953079282`"}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"],

Cell[BoxData[""], "Input"]
}, Open  ]]
}, Open  ]]
},
PrintingStyleEnvironment->"Condensed",
CellGrouping->Manual,
WindowSize->{1066, 821},
WindowMargins->{{Automatic, 12}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.562, 842.375},
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "local", 
   "constant", "Oxford", "Tex", "ElasticaBook", "C07_EnergyVariational", 
   "NB"}, "compression_friction.nb.ps", CharacterEncoding -> "iso8859-1"]},
ShowSelection->True,
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 80, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[1436, 43, 401, 11, 99, "Input"],
Cell[1840, 56, 85, 1, 31, "Output"],
Cell[1928, 59, 312, 5, 52, "Output"],
Cell[CellGroupData[{
Cell[2265, 68, 138, 2, 77, "Input"],
Cell[2406, 72, 257, 6, 55, "Input"],
Cell[2666, 80, 98, 2, 31, "Output"],
Cell[2767, 84, 195, 6, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3011, 96, 68, 0, 39, "Subsection"],
Cell[3082, 98, 432, 13, 32, "Input"],
Cell[3517, 113, 78, 0, 39, "Subsection"],
Cell[CellGroupData[{
Cell[3620, 117, 349, 10, 26, "Input"],
Cell[3972, 129, 267, 8, 48, "Output"]
}, Open  ]],
Cell[4254, 140, 50, 0, 39, "Subsection"],
Cell[CellGroupData[{
Cell[4329, 144, 342, 10, 49, "Input"],
Cell[4674, 156, 1175, 36, 114, "Output"],
Cell[5852, 194, 4372, 131, 123, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10273, 331, 110, 3, 38, "Subsection"],
Cell[CellGroupData[{
Cell[10408, 338, 128, 3, 27, "Input"],
Cell[10539, 343, 1566, 50, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12142, 398, 103, 2, 27, "Input"],
Cell[12248, 402, 839, 26, 52, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13136, 434, 52, 0, 38, "Subsection"],
Cell[CellGroupData[{
Cell[13213, 438, 358, 10, 27, "Input"],
Cell[13574, 450, 1319, 42, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14930, 497, 235, 6, 27, "Input"],
Cell[15168, 505, 1319, 42, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16524, 552, 127, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[16676, 557, 94, 2, 27, "Input"],
Cell[16773, 561, 83, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16893, 568, 323, 8, 27, "Input"],
Cell[17219, 578, 1334, 43, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18590, 626, 334, 9, 27, "Input"],
Cell[18927, 637, 3143, 100, 113, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22107, 742, 2902, 86, 123, "Input"],
Cell[25012, 830, 441, 14, 43, "Output"],
Cell[25456, 846, 499, 16, 43, "Output"],
Cell[25958, 864, 633, 20, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26628, 889, 231, 6, 43, "Input"],
Cell[26862, 897, 2819, 91, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29718, 993, 95, 2, 27, "Input"],
Cell[29816, 997, 1810, 53, 51, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[31687, 1057, 44, 0, 38, "Subsection"],
Cell[CellGroupData[{
Cell[31756, 1061, 412, 12, 27, "Input"],
Cell[32171, 1075, 1270, 42, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33478, 1122, 355, 10, 27, "Input"],
Cell[33836, 1134, 255, 8, 44, "Output"],
Cell[CellGroupData[{
Cell[34116, 1146, 574, 16, 59, "Input"],
Cell[34693, 1164, 877, 29, 48, "Output"],
Cell[35573, 1195, 532, 17, 48, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36166, 1219, 46, 0, 38, "Subsection"],
Cell[36215, 1221, 1615, 40, 139, "Input"],
Cell[CellGroupData[{
Cell[37855, 1265, 980, 29, 59, "Input"],
Cell[38838, 1296, 51, 1, 27, "Output"],
Cell[38892, 1299, 179, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39108, 1310, 183, 5, 27, "Input"],
Cell[39294, 1317, 1461, 47, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40792, 1369, 79, 2, 27, "Input"],
Cell[40874, 1373, 382, 13, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41293, 1391, 417, 11, 27, "Input"],
Cell[41713, 1404, 338, 11, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42088, 1420, 204, 5, 27, "Input"],
Cell[42295, 1427, 972, 32, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43304, 1464, 432, 12, 27, "Input"],
Cell[43739, 1478, 6857, 342, 186, 4374, 298, "GraphicsData", "PostScript", \
"Graphics"],
Cell[50599, 1822, 134, 4, 27, "Output"]
}, Open  ]],
Cell[50748, 1829, 26, 0, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50811, 1834, 61, 0, 38, "Subsection"],
Cell[50875, 1836, 72, 1, 27, "Input"],
Cell[CellGroupData[{
Cell[50972, 1841, 48, 1, 27, "Input"],
Cell[51023, 1844, 1334, 43, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52394, 1892, 428, 13, 31, "Input"],
Cell[52825, 1907, 334, 11, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53196, 1923, 205, 5, 27, "Input"],
Cell[53404, 1930, 824, 29, 29, "Output"]
}, Open  ]],
Cell[54243, 1962, 26, 0, 27, "Input"],
Cell[CellGroupData[{
Cell[54294, 1966, 194, 4, 27, "Input"],
Cell[54491, 1972, 532, 17, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55060, 1994, 213, 5, 27, "Input"],
Cell[55276, 2001, 826, 26, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56139, 2032, 796, 24, 43, "Input"],
Cell[56938, 2058, 1373, 46, 62, "Output"],
Cell[58314, 2106, 1461, 48, 128, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59812, 2159, 223, 6, 27, "Input"],
Cell[60038, 2167, 2044, 66, 155, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62119, 2238, 644, 18, 43, "Input"],
Cell[62766, 2258, 474, 11, 29, "Output"],
Cell[63243, 2271, 5248, 266, 186, 3336, 231, "GraphicsData", "PostScript", \
"Graphics"],
Cell[68494, 2539, 134, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68665, 2548, 287, 7, 27, "Input"],
Cell[68955, 2557, 96, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69088, 2564, 104, 2, 27, "Input"],
Cell[69195, 2568, 4518, 154, 272, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73750, 2727, 185, 4, 27, "Input"],
Cell[73938, 2733, 106, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74081, 2740, 184, 4, 27, "Input"],
Cell[74268, 2746, 105, 2, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74410, 2753, 583, 16, 27, "Input"],
Cell[74996, 2771, 217153, 5492, 242, 196129, 5144, "GraphicsData", \
"PostScript", "Graphics"],
Cell[292152, 8265, 144, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[292333, 8275, 61, 1, 27, "Input"],
Cell[292397, 8278, 291, 10, 27, "Output"]
}, Open  ]],
Cell[292703, 8291, 4410, 112, 235, "Input"],
Cell[CellGroupData[{
Cell[297138, 8407, 59, 1, 27, "Input"],
Cell[297200, 8410, 252, 7, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[297489, 8422, 95, 2, 43, "Input"],
Cell[297587, 8426, 334, 9, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[297958, 8440, 95, 2, 43, "Input"],
Cell[298056, 8444, 411, 11, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[298504, 8460, 59, 1, 27, "Input"],
Cell[298566, 8463, 580, 15, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[299183, 8483, 402, 12, 27, "Input"],
Cell[299588, 8497, 125, 4, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[299750, 8506, 26, 0, 27, "Input"],
Cell[299779, 8508, 167, 6, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[299983, 8519, 729, 20, 59, "Input"],
Cell[300715, 8541, 1302, 43, 49, "Output"],
Cell[302020, 8586, 1039, 33, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[303096, 8624, 592, 17, 59, "Input"],
Cell[303691, 8643, 920, 29, 48, "Output"],
Cell[304614, 8674, 474, 15, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305125, 8694, 27, 0, 27, "Input"],
Cell[305155, 8696, 167, 6, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305359, 8707, 586, 15, 27, "Input"],
Cell[305948, 8724, 183, 7, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[306168, 8736, 355, 12, 62, "Input"],
Cell[306526, 8750, 272, 10, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[306835, 8765, 302, 7, 27, "Input"],
Cell[307140, 8774, 10769, 589, 186, 8101, 542, "GraphicsData", "PostScript", \
"Graphics"],
Cell[317912, 9365, 134, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[318083, 9374, 344, 8, 43, "Input"],
Cell[318430, 9384, 10328, 547, 186, 7351, 495, "GraphicsData", "PostScript", \
"Graphics"],
Cell[328761, 9933, 134, 4, 27, "Output"]
}, Open  ]],
Cell[328910, 9940, 45, 0, 43, "Input"],
Cell[CellGroupData[{
Cell[328980, 9944, 2018, 59, 161, "Input"],
Cell[331001, 10005, 670, 18, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[331708, 10028, 228, 7, 27, "Input"],
Cell[331939, 10037, 5783, 307, 186, 3905, 273, "GraphicsData", "PostScript", \
"Graphics"],
Cell[337725, 10346, 134, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[337896, 10355, 89, 2, 27, "Input"],
Cell[337988, 10359, 11179, 591, 186, 7970, 535, "GraphicsData", "PostScript", \
"Graphics"],
Cell[349170, 10952, 134, 4, 27, "Output"]
}, Open  ]],
Cell[349319, 10959, 4000, 103, 187, "Input"],
Cell[CellGroupData[{
Cell[353344, 11066, 57, 1, 27, "Input"],
Cell[353404, 11069, 343, 11, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[353784, 11085, 57, 1, 27, "Input"],
Cell[353844, 11088, 434, 12, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[354315, 11105, 93, 2, 43, "Input"],
Cell[354411, 11109, 602, 16, 29, "Output"]
}, Open  ]],
Cell[355028, 11128, 4052, 104, 171, "Input"],
Cell[CellGroupData[{
Cell[359105, 11236, 57, 1, 27, "Input"],
Cell[359165, 11239, 264, 8, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[359466, 11252, 57, 1, 27, "Input"],
Cell[359526, 11255, 438, 13, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[360001, 11273, 57, 1, 27, "Input"],
Cell[360061, 11276, 593, 17, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[360691, 11298, 613, 17, 43, "Input"],
Cell[361307, 11317, 9550, 488, 186, 6487, 434, "GraphicsData", "PostScript", \
"Graphics"],
Cell[370860, 11807, 134, 4, 27, "Output"]
}, Open  ]],
Cell[371009, 11814, 147, 4, 27, "Input"],
Cell[CellGroupData[{
Cell[371181, 11822, 120, 3, 27, "Input"],
Cell[371304, 11827, 33, 0, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[371374, 11832, 85, 2, 27, "Input"],
Cell[371462, 11836, 63, 1, 27, "Output"]
}, Open  ]],
Cell[371540, 11840, 26, 0, 27, "Input"],
Cell[371569, 11842, 26, 0, 27, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

