(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     39028,       1357]
NotebookOptionsPosition[     35588,       1241]
NotebookOutlinePosition[     36031,       1259]
CellTagsIndexPosition[     35988,       1256]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{" ", 
    RowBox[{"The", " ", "dam", " ", "problem"}]}], "Subtitle"], 
  TraditionalForm]], "Input",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
    "]"}], "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\n", 
 RowBox[{"<<", "Displacement.m"}], "\n"}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SetCoordinates", "[", 
   RowBox[{"Cartesian", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], "\n"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Kinematically admissible displacement field", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"ax", " ", "x"}], "  ", "+", " ", 
     RowBox[{"bx", " ", "y"}], " ", "+", " ", "ux"}], ",", " ", 
    RowBox[{
     RowBox[{"ay", " ", "x"}], "  ", "+", " ", 
     RowBox[{"by", " ", "y"}], " ", "+", " ", "uy"}], " ", ",", " ", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"Thread", "[", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"u", " ", "/.", " ", 
     RowBox[{"y", " ", "\[Rule]", " ", 
      RowBox[{"-", "H"}]}]}], " ", ")"}], " ", "\[Equal]", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ux", "+", 
    RowBox[{"ax", " ", "x"}], "+", 
    RowBox[{"bx", " ", "y"}]}], ",", 
   RowBox[{"uy", "+", 
    RowBox[{"ay", " ", "x"}], "+", 
    RowBox[{"by", " ", "y"}]}], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "bx"}], " ", "H"}], "+", "ux", "+", 
     RowBox[{"ax", " ", "x"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "by"}], " ", "H"}], "+", "uy", "+", 
     RowBox[{"ay", " ", "x"}]}], "\[Equal]", "0"}], ",", "True"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"ax", " ", "x"}], "  ", "+", " ", 
     RowBox[{"bx", " ", "y"}], " ", "+", " ", "ux"}], ",", " ", 
    RowBox[{
     RowBox[{"ay", " ", "x"}], "  ", "+", " ", 
     RowBox[{"by", " ", "y"}], " ", "+", " ", "uy"}], " ", ",", " ", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"Thread", "[", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"u", " ", "/.", " ", 
     RowBox[{"y", " ", "\[Rule]", " ", 
      RowBox[{"-", "H"}]}]}], " ", ")"}], " ", "\[Equal]", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ux", "+", 
    RowBox[{"ax", " ", "x"}], "+", 
    RowBox[{"bx", " ", "y"}]}], ",", 
   RowBox[{"uy", "+", 
    RowBox[{"ay", " ", "x"}], "+", 
    RowBox[{"by", " ", "y"}]}], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "bx"}], " ", "H"}], "+", "ux", "+", 
     RowBox[{"ax", " ", "x"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "by"}], " ", "H"}], "+", "uy", "+", 
     RowBox[{"ay", " ", "x"}]}], "\[Equal]", "0"}], ",", "True"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ax", " ", "\[Rule]", " ", "0"}], ",", " ", 
    RowBox[{"ay", " ", "\[Rule]", " ", "0"}], ",", " ", 
    RowBox[{"bx", " ", "\[Rule]", " ", 
     RowBox[{"ux", "/", " ", "H"}]}], ",", " ", 
    RowBox[{"by", " ", "\[Rule]", " ", 
     RowBox[{"uy", "/", "H"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"uu", " ", "=", 
  RowBox[{"u", " ", "/.", " ", "sol", "    "}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ax", "\[Rule]", "0"}], ",", 
   RowBox[{"ay", "\[Rule]", "0"}], ",", 
   RowBox[{"bx", "\[Rule]", 
    FractionBox["ux", "H"]}], ",", 
   RowBox[{"by", "\[Rule]", 
    FractionBox["uy", "H"]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ux", "+", 
    FractionBox[
     RowBox[{"ux", " ", "y"}], "H"]}], ",", 
   RowBox[{"uy", "+", 
    FractionBox[
     RowBox[{"uy", " ", "y"}], "H"]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eps", " ", "=", " ", 
  RowBox[{
   RowBox[{"1", "/", "2"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Grad", "[", " ", "uu", "]"}], " ", "+", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Grad", "[", "uu", "]"}], "]"}]}], 
    ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"sig", " ", "=", " ", 
  RowBox[{
   RowBox[{"\[Lambda]", " ", 
    RowBox[{"Tr", "[", "eps", "]"}], " ", 
    RowBox[{"IdentityMatrix", "[", "3", "]"}]}], " ", "+", " ", 
   RowBox[{"2", " ", "\[Mu]", " ", "eps", " "}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox["ux", 
      RowBox[{"2", " ", "H"}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["ux", 
      RowBox[{"2", " ", "H"}]], ",", 
     FractionBox["uy", "H"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"uy", " ", "\[Lambda]"}], "H"], ",", 
     FractionBox[
      RowBox[{"ux", " ", "\[Mu]"}], "H"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"ux", " ", "\[Mu]"}], "H"], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"uy", " ", "\[Lambda]"}], "H"], "+", 
      FractionBox[
       RowBox[{"2", " ", "uy", " ", "\[Mu]"}], "H"]}], ",", "0"}], "}"}], ",",
    
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"uy", " ", "\[Lambda]"}], "H"]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Wint", " ", "=", " ", 
   RowBox[{
    RowBox[{"1", "/", "2"}], "  ", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"Integrate", "[", "  ", 
       RowBox[{
        RowBox[{"Tr", "[", " ", 
         RowBox[{"eps", " ", ".", " ", "sig"}], " ", "]"}], " ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"y", ",", " ", 
          RowBox[{"-", "H"}], ",", "   ", 
          RowBox[{
           RowBox[{"-", "x"}], " ", "/", " ", 
           RowBox[{"Tan", "[", "\[Alpha]", "]"}]}]}], " ", "}"}]}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", " ", "0", ",", " ", 
        RowBox[{"H", " ", 
         RowBox[{"Tan", "[", "\[Alpha]", "]"}]}]}], "}"}]}], " ", "]"}]}]}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["ux", "2"], " ", "\[Mu]"}], "+", 
    RowBox[{
     SuperscriptBox["uy", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Lambda]", "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}], " ", 
  RowBox[{"Tan", "[", "\[Alpha]", "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pressure", " ", "=", " ", 
    RowBox[{"pw", " ", "y", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Wpressure", " ", "=", " ", 
    RowBox[{"Integrate", "[", " ", 
     RowBox[{
      RowBox[{"uu", " ", ".", " ", "pressure"}], " ", ",", " ", 
      RowBox[{"{", 
       RowBox[{"y", ",", " ", 
        RowBox[{"-", "H"}], ",", " ", "0"}], "}"}]}], "]"}]}]}], 
  "  "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "pw"}], " ", "y"}], ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(Wpressure\\)\\\" is similar to existing symbol \
\\\"\\!\\(pressure\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "6"], " ", 
  SuperscriptBox["H", "2"], " ", "pw", " ", "ux"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"weight", " ", "=", " ", 
  RowBox[{"g", " ", "pc", "  ", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "1"}], ",", "0"}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Wweight", " ", "=", " ", 
  RowBox[{"Integrate", "[", " ", 
   RowBox[{
    RowBox[{"Integrate", "[", " ", 
     RowBox[{
      RowBox[{"uu", " ", ".", " ", "weight"}], "  ", ",", " ", 
      RowBox[{"{", 
       RowBox[{"y", ",", " ", 
        RowBox[{"-", "H"}], ",", "   ", 
        RowBox[{
         RowBox[{"-", "x"}], " ", "/", " ", 
         RowBox[{"Tan", "[", "\[Alpha]", "]"}]}]}], " ", "}"}]}], "]"}], ",", 
    
    RowBox[{"{", 
     RowBox[{"x", ",", " ", "0", ",", " ", 
      RowBox[{"H", " ", 
       RowBox[{"Tan", "[", "\[Alpha]", "]"}]}]}], "}"}]}], " ", 
   "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "g"}], " ", "pc"}], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(Wweight\
\\)\\\" is similar to existing symbol \\\"\\!\\(weight\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "6"]}], " ", "g", " ", 
  SuperscriptBox["H", "2"], " ", "pc", " ", "uy", " ", 
  RowBox[{"Tan", "[", "\[Alpha]", "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"W", " ", "=", " ", 
  RowBox[{
  "Wint", " ", "-", " ", "Wweight", " ", "-", " ", 
   "Wpressure"}]}], "\[IndentingNewLine]", 
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{
   RowBox[{"FullSimplify", "[", " ", 
    RowBox[{"Solve", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"W", ",", " ", "ux"}], "]"}], " ", "\[Equal]", " ", "0"}], 
        " ", ",", " ", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"W", ",", " ", "uy"}], "]"}], " ", "\[Equal]", " ", "0"}]}],
        " ", "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"ux", ",", " ", "uy"}], "}"}]}], "]"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Wdispl1", " ", "=", "  ", 
  RowBox[{"FullSimplify", "[", "  ", 
   RowBox[{"W", " ", "/.", " ", "sol"}], " ", "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "6"]}], " ", 
   SuperscriptBox["H", "2"], " ", "pw", " ", "ux"}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", "g", " ", 
   SuperscriptBox["H", "2"], " ", "pc", " ", "uy", " ", 
   RowBox[{"Tan", "[", "\[Alpha]", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["ux", "2"], " ", "\[Mu]"}], "+", 
     RowBox[{
      SuperscriptBox["uy", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"\[Lambda]", "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}], " ", 
   RowBox[{"Tan", "[", "\[Alpha]", "]"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ux", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["H", "2"], " ", "pw", " ", 
      RowBox[{"Cot", "[", "\[Alpha]", "]"}]}], 
     RowBox[{"3", " ", "\[Mu]"}]]}], ",", 
   RowBox[{"uy", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"g", " ", 
       SuperscriptBox["H", "2"], " ", "pc"}], 
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["H", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["pw", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
       RowBox[{"Cot", "[", "\[Alpha]", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["g", "2"], " ", 
       SuperscriptBox["pc", "2"], " ", "\[Mu]", " ", 
       RowBox[{"Tan", "[", "\[Alpha]", "]"}]}]}], ")"}]}], 
   RowBox[{"36", " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{"\[Lambda]", "+", 
      RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EEnu", " ", "=", "  ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Lambda]", " ", "\[Rule]", " ", 
     RowBox[{"EE", " ", 
      RowBox[{
       RowBox[{"nu", " ", "/", 
        RowBox[{"(", 
         RowBox[{"1", " ", "-", " ", 
          RowBox[{"2", " ", "nu"}]}], ")"}]}], " ", "/", " ", 
       RowBox[{"(", " ", 
        RowBox[{"1", " ", "+", " ", "nu"}], ")"}]}]}]}], " ", ",", "  ", 
    RowBox[{"\[Mu]", " ", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"EE", " ", "/", " ", "2"}], " ", "/", " ", 
      RowBox[{"(", 
       RowBox[{"1", " ", "+", " ", "nu"}], ")"}]}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"material", " ", "=", " ", 
  RowBox[{"{", "  ", 
   RowBox[{
    RowBox[{"pw", " ", "\[Rule]", " ", "1."}], " ", ",", " ", 
    RowBox[{"pc", " ", "\[Rule]", " ", "2."}], " ", ",", " ", 
    RowBox[{"g", " ", "\[Rule]", " ", "10."}], ",", "  ", 
    RowBox[{"nu", " ", "\[Rule]", " ", "0.3"}], " ", ",", " ", 
    RowBox[{"EE", " ", "\[Rule]", " ", "1."}]}], "}"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Lambda]", "\[Rule]", 
    FractionBox[
     RowBox[{"EE", " ", "nu"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "nu"}], ")"}]}]]}], ",", 
   RowBox[{"\[Mu]", "\[Rule]", 
    FractionBox["EE", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "nu"}], ")"}]}]]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"pw", "\[Rule]", "1.`"}], ",", 
   RowBox[{"pc", "\[Rule]", "2.`"}], ",", 
   RowBox[{"g", "\[Rule]", "10.`"}], ",", 
   RowBox[{"nu", "\[Rule]", "0.3`"}], ",", 
   RowBox[{"EE", "\[Rule]", "1.`"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"uu", " ", "/.", " ", "sol"}], " ", "/.", " ", "EEnu"}], " ", "/.",
      " ", "material"}], " ", "/.", " ", 
    RowBox[{"y", " ", "\[Rule]", " ", "0"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Wdispl1", " ", "/.", " ", "EEnu"}], " ", "/.", "  ", 
    "material"}]}], "  "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.8666666666666667`", " ", 
    SuperscriptBox["H", "2"], " ", 
    RowBox[{"Cot", "[", "\[Alpha]", "]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "4.9523809523809526`"}], " ", 
    SuperscriptBox["H", "2"]}], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "0.05365079365079365`"}], " ", 
  SuperscriptBox["H", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"1.346153846153846`", " ", 
     RowBox[{"Cot", "[", "\[Alpha]", "]"}]}], "+", 
    RowBox[{"153.84615384615384`", " ", 
     RowBox[{"Tan", "[", "\[Alpha]", "]"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dim", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"H", " ", "\[Rule]", " ", "1"}], ",", " ", 
    RowBox[{"\[Alpha]", " ", "\[Rule]", " ", 
     RowBox[{"Pi", "/", "4"}]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"H", "\[Rule]", "1"}], ",", 
   RowBox[{"\[Alpha]", "\[Rule]", 
    FractionBox["\[Pi]", "4"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dam", " ", "=", " ", 
  RowBox[{"Join", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "yy"}], "}"}], " ", ",", " ", 
      RowBox[{"{", 
       RowBox[{"yy", ",", " ", 
        RowBox[{"-", "1"}], ",", " ", "0", ",", " ", "0.1"}], " ", "}"}]}], 
     " ", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Table", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"xx", ",", " ", 
        RowBox[{
         RowBox[{"-", " ", "xx"}], " ", "/", " ", 
         RowBox[{"Tan", "[", 
          RowBox[{"Pi", "/", "4"}], "]"}]}]}], "}"}], " ", ",", " ", 
      RowBox[{"{", 
       RowBox[{"xx", ",", "0", ",", " ", 
        RowBox[{"Tan", "[", 
         RowBox[{"Pi", "/", "4"}], "]"}], ",", " ", 
        RowBox[{"+", "0.1"}]}], " ", "}"}]}], "  ", "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Table", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"xx", ",", 
        RowBox[{"-", "1"}]}], "}"}], " ", ",", " ", 
      RowBox[{"{", 
       RowBox[{"xx", ",", " ", 
        RowBox[{"Tan", "[", 
         RowBox[{"Pi", "/", "4"}], "]"}], ",", " ", "0", ",", " ", 
        RowBox[{"-", "0.1"}]}], "}"}]}], " ", "]"}]}], "\[IndentingNewLine]", 
   "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "0.9`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "0.8`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "0.7`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "0.6`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "0.5`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "0.39999999999999997`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "0.29999999999999993`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "0.19999999999999996`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "0.09999999999999995`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.1`", ",", 
     RowBox[{"-", "0.1`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2`", ",", 
     RowBox[{"-", "0.2`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.30000000000000004`", ",", 
     RowBox[{"-", "0.30000000000000004`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4`", ",", 
     RowBox[{"-", "0.4`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5`", ",", 
     RowBox[{"-", "0.5`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6000000000000001`", ",", 
     RowBox[{"-", "0.6000000000000001`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7000000000000001`", ",", 
     RowBox[{"-", "0.7000000000000001`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8`", ",", 
     RowBox[{"-", "0.8`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9`", ",", 
     RowBox[{"-", "0.9`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9`", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8`", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7`", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6`", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5`", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.39999999999999997`", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.29999999999999993`", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.19999999999999996`", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.09999999999999995`", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"damplot", " ", "=", " ", 
  RowBox[{"Graphics", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"GrayLevel", "[", "0.9", "]"}], ",", " ", 
     RowBox[{"Polygon", "[", "dam", "]"}]}], "}"}], " ", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", " ", "damplot", "]"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.603319 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.9 g
.02381 .01472 m
.02381 .07358 L
.02381 .13244 L
.02381 .1913 L
.02381 .25016 L
.02381 .30902 L
.02381 .36788 L
.02381 .42674 L
.02381 .4856 L
.02381 .54446 L
.02381 .60332 L
.02381 .60332 L
.11905 .54446 L
.21429 .4856 L
.30952 .42674 L
.40476 .36788 L
.5 .30902 L
.59524 .25016 L
.69048 .1913 L
.78571 .13244 L
.88095 .07358 L
.97619 .01472 L
.97619 .01472 L
.88095 .01472 L
.78571 .01472 L
.69048 .01472 L
.59524 .01472 L
.5 .01472 L
.40476 .01472 L
.30952 .01472 L
.21429 .01472 L
.11905 .01472 L
.02381 .01472 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJyl1nloz3Ecx/HfNmMNm9w58qMhR44cOXJEZtHkiESOmWWTNWaISESOyBFN
siZHJHLkyBGJHBGJyJEj/HLkyJEj/OwZfXv2/U/q2/P77vHH5+9Xdk5Jfl5h
TklBbk50YHHO9PyC3JnRzKLiCkpKiEQSopFI5GA0wh2vOP8mXvHFmxLk3+4q
/OKRWCxWg6SGNY1UC2v1PwlpVZIe1tQ/j4c0hdQMa2VSO6zJpE5Yk0i9sCaS
+mFtIPgJNBL8ABoLvgNNBN+AqOAL0EzwGcgQfAKaCz4ALQXvgVaCd0BrwRug
reA10E7wCmgveAF0FMSAToLnQGfBU6Cr4AnQTfAY6C54CPQUPAB6Ce4BfQR3
gb6CO0A/wW2gv+AWMEBwE8gU3ACyBNeBQYJrwGDBVSBbcAUYIrgMDBVcBIYL
LgAjBOeBkYJzwCjBWWC04AwwRnAaGCs4BYwTnATGC44DEwXHgEmCo0Cu4DCQ
JzgETBEcBPIF+4Gpgn3ANMFeoFCwBygS7AZmCHYBxYKdQIlgOzBbsA2YI9gK
zBWUA/MEZcB8wRZggWAzsFCwCVgkKAUWCzYCSwQbgKWC9cAywVpghWANsFKw
GlglWAWsFqwE1giWA+sEy4D1gqXABsESYKNgMVAqWARsEiwENgsWAFsE84Ey
wTygXDAX2CqYA2wTzAJ2CEqAnYJiYJdgBrBbUATsERQCewXTgH2CqcB+QQFw
QDAFOCTIAw4LJgNHBJOAY4KJwHHBBOCEYBxwSjAWOC0YA5wRjAbOCkYB5wQj
gfOCEcAFwTDgkmAocFkwBLgiyAauCgYD1wSDgOuCLOCGIBO4KRgA3BL0B24L
+gF3BH2Bu4LewH1BL+CBoCfwUNADeCToBjwRdAWeCroAzwSdgJigI/BC0AF4
KWgHvBa0Bd4I2gBvBa2A94KWwAdBC+CjIAP4LGgGfBE0Bb4KmgDfBY2BH4KG
wC9BAyAuqB9AorReoEnSOoEmS2sHWllaM9AUaY1AvVvTA60qrR6od2u1QNOk
qYF6t6YE6t1aJdBa0uRAvVsrBVpXmhjo3936P3s+kvAbOrkBeQ==\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -1.02501, \
0.00366761, 0.00593432}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", " ", "\"\<Global`def\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"(", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{"uu", ",", " ", 
         RowBox[{"-", "1"}]}], "]"}], " ", "/.", " ", "sol"}], " ", "/.", " ",
       "EEnu"}], " ", "/.", " ", "material"}], " ", "/.", " ", 
    RowBox[{"H", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
   RowBox[{"\[Alpha]", " ", "\[Rule]", " ", 
    RowBox[{"Pi", "/", "4"}]}]}], " ", ")"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"def", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}], " ", "+", " ", 
   RowBox[{"0.05", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"uu", ",", " ", 
            RowBox[{"-", "1"}]}], "]"}], " ", "/.", " ", "sol"}], " ", "/.", 
         " ", "EEnu"}], " ", "/.", " ", "material"}], " ", "/.", " ", 
       RowBox[{"H", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
      RowBox[{"\[Alpha]", " ", "\[Rule]", " ", 
       RowBox[{"Pi", "/", "4"}]}]}], " ", ")"}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"0.8666666666666667`", "\[InvisibleSpace]"}], "+", 
    RowBox[{"0.8666666666666667`", " ", "y"}]}], ",", 
   RowBox[{
    RowBox[{"-", "4.9523809523809526`"}], "-", 
    RowBox[{"4.9523809523809526`", " ", "y"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "+", 
    RowBox[{"0.05`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.8666666666666667`", "\[InvisibleSpace]"}], "+", 
       RowBox[{"0.8666666666666667`", " ", "y"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"0.05`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "4.9523809523809526`"}], "-", 
       RowBox[{"4.9523809523809526`", " ", "y"}]}], ")"}]}], "+", "y"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"defdam", " ", "=", " ", 
  RowBox[{"Map", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"def", "[", " ", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], " ", "]"}], " ", "&"}], " ", ",", 
    " ", "dam"}], " ", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defplot", " ", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GrayLevel", "[", "0.4", "]"}], ",", " ", 
      RowBox[{"Polygon", "[", "defdam", "]"}]}], "}"}], " ", "]"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", " ", 
  RowBox[{"damplot", ",", " ", "defplot"}], " ", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.004333333333333334`", ",", 
     RowBox[{"-", "0.9247619047619048`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.008666666666666668`", ",", 
     RowBox[{"-", "0.8495238095238096`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.013000000000000001`", ",", 
     RowBox[{"-", "0.7742857142857142`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.017333333333333336`", ",", 
     RowBox[{"-", "0.699047619047619`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.021666666666666667`", ",", 
     RowBox[{"-", "0.6238095238095238`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.026000000000000002`", ",", 
     RowBox[{"-", "0.5485714285714285`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.030333333333333337`", ",", 
     RowBox[{"-", "0.4733333333333333`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.03466666666666667`", ",", 
     RowBox[{"-", "0.39809523809523806`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.03900000000000001`", ",", 
     RowBox[{"-", "0.32285714285714284`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.043333333333333335`", ",", 
     RowBox[{"-", "0.24761904761904763`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.043333333333333335`", ",", 
     RowBox[{"-", "0.24761904761904763`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.139`", ",", 
     RowBox[{"-", "0.32285714285714284`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2346666666666667`", ",", 
     RowBox[{"-", "0.3980952380952381`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.33033333333333337`", ",", 
     RowBox[{"-", "0.4733333333333334`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.42600000000000005`", ",", 
     RowBox[{"-", "0.5485714285714286`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5216666666666667`", ",", 
     RowBox[{"-", "0.6238095238095238`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6173333333333334`", ",", 
     RowBox[{"-", "0.6990476190476191`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7130000000000001`", ",", 
     RowBox[{"-", "0.7742857142857144`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8086666666666668`", ",", 
     RowBox[{"-", "0.8495238095238096`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9043333333333333`", ",", 
     RowBox[{"-", "0.9247619047619048`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.39999999999999997`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.29999999999999993`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.19999999999999996`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.09999999999999995`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.603319 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.9 g
.02381 .01472 m
.02381 .07358 L
.02381 .13244 L
.02381 .1913 L
.02381 .25016 L
.02381 .30902 L
.02381 .36788 L
.02381 .42674 L
.02381 .4856 L
.02381 .54446 L
.02381 .60332 L
.02381 .60332 L
.11905 .54446 L
.21429 .4856 L
.30952 .42674 L
.40476 .36788 L
.5 .30902 L
.59524 .25016 L
.69048 .1913 L
.78571 .13244 L
.88095 .07358 L
.97619 .01472 L
.97619 .01472 L
.88095 .01472 L
.78571 .01472 L
.69048 .01472 L
.59524 .01472 L
.5 .01472 L
.40476 .01472 L
.30952 .01472 L
.21429 .01472 L
.11905 .01472 L
.02381 .01472 L
F
.4 g
.02381 .01472 m
.02794 .059 L
.03206 .10329 L
.03619 .14757 L
.04032 .19186 L
.04444 .23614 L
.04857 .28043 L
.0527 .32471 L
.05683 .369 L
.06095 .41328 L
.06508 .45757 L
.06508 .45757 L
.15619 .41328 L
.2473 .369 L
.33841 .32471 L
.42952 .28043 L
.52063 .23614 L
.61175 .19186 L
.70286 .14757 L
.79397 .10329 L
.88508 .059 L
.97619 .01472 L
.97619 .01472 L
.88095 .01472 L
.78571 .01472 L
.69048 .01472 L
.59524 .01472 L
.5 .01472 L
.40476 .01472 L
.30952 .01472 L
.21429 .01472 L
.11905 .01472 L
.02381 .01472 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJyl2AtsTXccB/DTVrVUtfrQori6elXVq8MYmtow0lkYEUNU6UrWdKqI2SLY
skfqGWIPwhZiY2IWs02EiL2ETcRGPIIhNx6bCNkmIq7z/R/5+uWb3dwsS9rT
b76f381tz7nnf85peUV99YyaivqZlRWh4XUVr1bPrJwTGlZb51cJcZ4XF/I8
b1fIQ4748dEm4n9FOmCD5r/lJPcjwQuHw15VVZX7jmDbzMUAIsFbeMkxXtP0
X17TNMZrkrGJR58aY7IxJ9NiTDbCxvXpMSbjgnG/z4g++YBDWdGH7mObiCo7
+tA9DuVEH7ob/LF+lRt96G8OtY4+dAfbJFR5ZsjtwtvBvvdTW6VbpPZKN0FN
kEJKf5Dyla6TCpSuBh8bP3VUCpM6K10hdVW6BEpBKlS6SCpSOk8qVjoXnAx+
6qF0htTLkDsEp0h9lH4DpSKVKJ0g9VU6TuqvdAzUHOkppZ9JA5WOkAYpHSYN
UfoRlIZUqvQ9qUzpECgdaajSQdKzSgdALZCGGXLn4T7SCKW9pJFK34AykEYp
7SGVK+0GZSI9r7QLlIX0gtJO0hilHaBspLFK20njlD4DtUQar7SVNEFpMygH
aaIhtwJ9DMpFeklpI2my0gZQK6QpSh+Rpip9QJqmtA7UGqnSkFvZ1pBmKK0m
vay0EtQGqVppOWmWUgPpFaX3QHlINUrvkGoNuRX3LdJspaWgtkh1SotJ9UqL
SPOU3gC1Q5qvtJC0QGkBqD3Sa0rzSa8rzQWFgncVmkNapDSbtFipFtQBaYlS
DelNQ8nBAfQpP9jRQtWkt5WqSO8qTQc9ERxvoWmkBqWpoAKkZUpTSCuUJpFW
KU0EdQw+4kITSGuUxoM6Ia1VepG0TmkMqDPS+4bchXo06UOlctJ6pVGgLsEy
IfQcaaPScFBXpE1Kz4AKkT5RKiNtVioFdUPaojSYtFXpaVAR0qdKA0jblPqB
uiN9bsjdm5SAioMVX6g3aadST1APpC+UiklfKhWRdisVgnoifaXUhfS1UifS
t0oFoF5Ie5XySfuUQqT9Su1AvZEOKOWRDhpyd2qtSIeUckB9kL5Tyib9oJRJ
+kmpBagE6bBSGumIUiroSaSjSimkX5SagPoiHVNKIh1XSiSdUEoA9UP61dBQ
FCdNUYbilClKUZw2xWAUZ00xCMU5UwxEcd4UA1BcMEV/FL+bwv3Ol03h9soV
U7hDEjaF+xRdNYX7nF4zhTu1bpjCnbx/msKtATdN4RagW6ZwS9xtU7hF9I4p
3Ar+lyncleUfU7hr111TuGvqPVO4C/p9U7h7kAemcHc5EVPksog3bQ7bBNNm
s000bRbbxqbNYGuf89PZ2if5NLYppk1la5/lm7Ftrqd3JHiHx20yW/s8nsQ2
07SJbO0TdyO2LU0bz/bRM/X/+Z+JF/cQNJ8Aqw==\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -1.02501, \
0.00366761, 0.00593432}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", " ", 
  RowBox[{
  "\"\</local/constant/ElasticaBook/C07_EnergyVariational/FIG/deformed_dam.\
eps\>\"", ",", " ", "%"}], "]"}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/C07_EnergyVariational/FIG/\
deformed_dam.eps\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]]
},
WindowSize->{982, 821},
WindowMargins->{{Automatic, 78}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[1309, 36, 168, 6, 46, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1502, 46, 320, 9, 77, "Input"],
Cell[1825, 57, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1912, 60, 111, 2, 77, "Input"],
Cell[CellGroupData[{
Cell[2048, 66, 158, 4, 55, "Input"],
Cell[2209, 72, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2342, 79, 65, 0, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2432, 83, 662, 18, 55, "Input"],
Cell[3097, 103, 257, 8, 31, "Output"],
Cell[3357, 113, 375, 13, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3769, 131, 662, 18, 55, "Input"],
Cell[4434, 151, 257, 8, 31, "Output"],
Cell[4694, 161, 375, 13, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5106, 179, 472, 11, 55, "Input"],
Cell[5581, 192, 265, 8, 44, "Output"],
Cell[5849, 202, 233, 8, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6119, 215, 547, 15, 55, "Input"],
Cell[6669, 232, 389, 13, 41, "Output"],
Cell[7061, 247, 652, 22, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7750, 274, 774, 22, 43, "Input"],
Cell[8527, 298, 368, 12, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8932, 315, 521, 16, 43, "Input"],
Cell[9456, 333, 128, 4, 27, "Output"],
Cell[9587, 339, 396, 8, 20, "Message"],
Cell[9986, 349, 117, 3, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10140, 357, 803, 23, 43, "Input"],
Cell[10946, 382, 128, 4, 27, "Output"],
Cell[11077, 388, 392, 8, 20, "Message"],
Cell[11472, 398, 193, 5, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11702, 408, 906, 25, 59, "Input"],
Cell[12611, 435, 674, 21, 44, "Output"],
Cell[13288, 458, 531, 17, 48, "Output"],
Cell[13822, 477, 656, 20, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14515, 502, 1035, 26, 43, "Input"],
Cell[15553, 530, 469, 16, 45, "Output"],
Cell[16025, 548, 269, 7, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16331, 560, 385, 11, 43, "Input"],
Cell[16719, 573, 288, 8, 29, "Output"],
Cell[17010, 583, 333, 9, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17380, 597, 229, 6, 27, "Input"],
Cell[17612, 605, 167, 5, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17816, 615, 1305, 36, 91, "Input"],
Cell[19124, 653, 2987, 99, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22148, 757, 314, 8, 43, "Input"],
Cell[22465, 767, 134, 4, 27, "Output"],
Cell[22602, 773, 2460, 96, 186, 1120, 71, "GraphicsData", "PostScript", \
"Graphics"],
Cell[25065, 871, 134, 4, 27, "Output"]
}, Open  ]],
Cell[25214, 878, 80, 1, 27, "Input"],
Cell[CellGroupData[{
Cell[25319, 883, 1160, 33, 43, "Input"],
Cell[26482, 918, 299, 8, 27, "Output"],
Cell[26784, 928, 478, 15, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27299, 948, 743, 21, 59, "Input"],
Cell[28045, 971, 3551, 101, 107, "Output"],
Cell[31599, 1074, 134, 4, 27, "Output"],
Cell[31736, 1080, 3335, 137, 186, 1641, 106, "GraphicsData", "PostScript", \
"Graphics"],
Cell[35074, 1219, 134, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35245, 1228, 175, 4, 27, "Input"],
Cell[35423, 1234, 108, 1, 27, "Output"]
}, Open  ]],
Cell[35546, 1238, 26, 0, 27, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

