(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     25427,        886]
NotebookOptionsPosition[     22377,        779]
NotebookOutlinePosition[     22820,        797]
CellTagsIndexPosition[     22777,        794]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{"Drilling", " ", "problem"}], " ", "-", " ", 
     RowBox[{"tubular", " ", "joint"}]}]}], "Subtitle"], 
  TraditionalForm]], "Input",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
    "]"}], "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\n", 
 RowBox[{"<<", "Displacement.m"}], "\n"}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}], "\n", 
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "t", ",", "p"}], "}"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "p"}], "]"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", "p"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["statically admissible field", "Subsection"],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sig", " ", ":=", " ", 
    RowBox[{
     RowBox[{"srp", "[", " ", "r", "]"}], " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"sig", " ", "//", " ", "MatrixForm"}]}], " "}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{"srp", "[", "r", "]"}], "0"},
     {
      RowBox[{"srp", "[", "r", "]"}], "0", "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"divsig", " ", ":=", " ", 
  RowBox[{
  "Div", "[", " ", "sig", " ", 
   "]"}]}], "\[IndentingNewLine]", "divsig"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"srp", "[", "r", "]"}]}], "r"], "+", 
    RowBox[{
     SuperscriptBox["srp", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{
   RowBox[{"DSolve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"divsig", "[", 
       RowBox[{"[", "2", "]"}], "]"}], " ", "\[Equal]", " ", "0"}], " ", ",", 
     " ", 
     RowBox[{"srp", "[", "r", "]"}], " ", ",", " ", "r"}], " ", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"srp", "[", "r", "]"}], "\[Rule]", 
  FractionBox[
   RowBox[{"C", "[", "1", "]"}], 
   SuperscriptBox["r", "2"]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"thesig", " ", "=", " ", 
  RowBox[{"sig", " ", "/.", " ", "sol"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"C", "[", "1", "]"}], 
      SuperscriptBox["r", "2"]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"C", "[", "1", "]"}], 
      SuperscriptBox["r", "2"]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eps", "=", " ", 
  RowBox[{
   RowBox[{"1", " ", "/", " ", 
    RowBox[{"(", " ", 
     RowBox[{"2", " ", "\[Mu]"}], " ", ")"}]}], " ", "thesig", 
   " "}]}], "\[IndentingNewLine]", 
 RowBox[{"wint", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", " ", "1"}], "/", "2"}], "  ", "2", " ", "Pi", " ", "H", " ", 
   
   RowBox[{"Integrate", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Tr", "[", " ", 
       RowBox[{"eps", " ", ".", " ", "thesig"}], " ", "]"}], " ", "r"}], " ", 
     ",", " ", 
     RowBox[{"{", 
      RowBox[{"r", ",", " ", "RI", ",", " ", "RE"}], "}"}]}], "]"}], 
   " "}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"C", "[", "1", "]"}], 
      RowBox[{"2", " ", 
       SuperscriptBox["r", "2"], " ", "\[Mu]"}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"C", "[", "1", "]"}], 
      RowBox[{"2", " ", 
       SuperscriptBox["r", "2"], " ", "\[Mu]"}]], ",", "0", ",", "0"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", "\[Mu]"], 
   RowBox[{"(", 
    RowBox[{"H", " ", "\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{"RE", "-", "RI"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"C", "[", "1", "]"}], "2"], " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Re", "[", "RE", "]"}], ">", "0"}], "&&", 
         RowBox[{
          RowBox[{"Re", "[", "RI", "]"}], ">", "0"}]}], "||", 
        RowBox[{
         RowBox[{
          RowBox[{"Re", "[", "RE", "]"}], "<", "0"}], "&&", 
         RowBox[{
          RowBox[{"Re", "[", "RI", "]"}], "<", "0"}]}], "||", 
        RowBox[{"RE", "\[Equal]", "0"}], "||", 
        RowBox[{"RI", "\[Equal]", "0"}], "||", 
        RowBox[{
         RowBox[{"Im", "[", "RE", "]"}], "\[NotEqual]", "0"}], "||", 
        RowBox[{
         RowBox[{"Im", "[", "RI", "]"}], "\[NotEqual]", "0"}]}], ",", 
       FractionBox[
        RowBox[{"RE", "+", "RI"}], 
        RowBox[{"2", " ", 
         SuperscriptBox["RE", "2"], " ", 
         SuperscriptBox["RI", "2"]}]], ",", 
       RowBox[{"Integrate", "[", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"r", " ", 
              RowBox[{"(", 
               RowBox[{"RE", "-", "RI"}], ")"}]}], "+", "RI"}], ")"}], "3"]], 
         ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"Assumptions", "\[Rule]", 
          RowBox[{"!", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Re", "[", "RE", "]"}], ">", "0"}], "&&", 
              RowBox[{
               RowBox[{"Re", "[", "RI", "]"}], ">", "0"}]}], "||", 
             RowBox[{
              RowBox[{
               RowBox[{"Re", "[", "RE", "]"}], "<", "0"}], "&&", 
              RowBox[{
               RowBox[{"Re", "[", "RI", "]"}], "<", "0"}]}], "||", 
             RowBox[{"RE", "\[Equal]", "0"}], "||", 
             RowBox[{"RI", "\[Equal]", "0"}], "||", 
             RowBox[{
              RowBox[{"Im", "[", "RE", "]"}], "\[NotEqual]", "0"}], "||", 
             RowBox[{
              RowBox[{"Im", "[", "RI", "]"}], "\[NotEqual]", "0"}]}], 
            ")"}]}]}]}], "]"}]}], "]"}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Wint", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", " ", 
   RowBox[{"wint", " ", ",", " ", 
    RowBox[{"Assumptions", " ", "\[Rule]", " ", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"RI", " ", ">", " ", "0"}], " ", "&&", " ", 
       RowBox[{"RI", " ", "<", " ", "RE"}], " ", "&&", " ", 
       RowBox[{"RI", " ", ">", " ", "0"}]}], ")"}]}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(Wint\\)\
\\\" is similar to existing symbol \\\"\\!\\(wint\\)\\\". \\!\\(\\*ButtonBox[\
\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"H", " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{"RE", "-", "RI"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"RE", "+", "RI"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"C", "[", "1", "]"}], "2"]}], 
   RowBox[{"2", " ", 
    SuperscriptBox["RE", "2"], " ", 
    SuperscriptBox["RI", "2"], " ", "\[Mu]"}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"uRI", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", 
     RowBox[{"\[Alpha]", " ", "RI"}], ",", " ", "0"}], "}"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"Wext", " ", "=", " ", 
  RowBox[{"2", " ", "RI", " ", "Pi", " ", "H", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"uRI", " ", ".", " ", "thesig", " ", ".", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", " ", "0", ",", " ", "0"}], "}"}]}], " ", "/.",
      " ", 
     RowBox[{"r", " ", "\[Rule]", " ", "RI"}]}], " ", ")"}], 
   " "}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"RI", " ", "\[Alpha]"}], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(Wext\\)\
\\\" is similar to existing symbols \\!\\({Next, Text}\\). \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", "H", " ", "\[Pi]", " ", "\[Alpha]", " ", 
  RowBox[{"C", "[", "1", "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"W", " ", "=", " ", 
  RowBox[{"Wint", " ", "+", " ", "Wext"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c1sol", " ", "=", " ", 
   RowBox[{
    RowBox[{"Solve", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"D", "[", " ", 
         RowBox[{"W", ",", " ", 
          RowBox[{"C", "[", "1", "]"}]}], " ", "]"}], " ", "\[Equal]", " ", 
        "0"}], "}"}], ",", " ", 
      RowBox[{"C", "[", "1", "]"}]}], " ", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"W", " ", "/.", " ", "c1sol"}], " "}], "\[IndentingNewLine]", 
 RowBox[{"thesig", " ", "/.", " ", "c1sol"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", "H", " ", "\[Pi]", " ", "\[Alpha]", " ", 
   RowBox[{"C", "[", "1", "]"}]}], "-", 
  FractionBox[
   RowBox[{"H", " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{"RE", "-", "RI"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"RE", "+", "RI"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"C", "[", "1", "]"}], "2"]}], 
   RowBox[{"2", " ", 
    SuperscriptBox["RE", "2"], " ", 
    SuperscriptBox["RI", "2"], " ", "\[Mu]"}]]}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox["RE", "2"], " ", 
      SuperscriptBox["RI", "2"], " ", "\[Alpha]", " ", "\[Mu]"}], 
     RowBox[{
      SuperscriptBox["RE", "2"], "-", 
      SuperscriptBox["RI", "2"]}]]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "H", " ", "\[Pi]", " ", 
     SuperscriptBox["RE", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"RE", "-", "RI"}], ")"}], " ", 
     SuperscriptBox["RI", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"RE", "+", "RI"}], ")"}], " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", "\[Mu]"}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["RE", "2"], "-", 
       SuperscriptBox["RI", "2"]}], ")"}], "2"]]}], "+", 
  FractionBox[
   RowBox[{"4", " ", "H", " ", "\[Pi]", " ", 
    SuperscriptBox["RE", "2"], " ", 
    SuperscriptBox["RI", "2"], " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", "\[Mu]"}], 
   RowBox[{
    SuperscriptBox["RE", "2"], "-", 
    SuperscriptBox["RI", "2"]}]]}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["RE", "2"], " ", 
        SuperscriptBox["RI", "2"], " ", "\[Alpha]", " ", "\[Mu]"}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["RE", "2"], "-", 
          SuperscriptBox["RI", "2"]}], ")"}]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["RE", "2"], " ", 
        SuperscriptBox["RI", "2"], " ", "\[Alpha]", " ", "\[Mu]"}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["RE", "2"], "-", 
          SuperscriptBox["RI", "2"]}], ")"}]}]]}], ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"eps", " ", "/.", " ", "c1sol"}], " "}], "\[IndentingNewLine]", 
 RowBox[{"Inc", "[", "%", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["RE", "2"], " ", 
        SuperscriptBox["RI", "2"], " ", "\[Alpha]"}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["RE", "2"], "-", 
          SuperscriptBox["RI", "2"]}], ")"}]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["RE", "2"], " ", 
        SuperscriptBox["RI", "2"], " ", "\[Alpha]"}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["RE", "2"], "-", 
          SuperscriptBox["RI", "2"]}], ")"}]}]]}], ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", " ", "IntegrateStrain.m"}]], "Input"],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<Global`u*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "=", 
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{"IntegrateStrain", "[", "eps", " ", "]"}], " ", "+", 
     RowBox[{"{", 
      RowBox[{"a1", ",", "a2", ",", "a3"}], "}"}], " ", "+", " ", 
     RowBox[{"Cross", "[", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"b1", ",", "b2", ",", "b3"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0", ",", "z"}], "}"}]}], "]"}]}], "  ", ")"}], " ",
    "/.", " ", "c1sol"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a1", "+", 
    RowBox[{"b2", " ", "z"}]}], ",", 
   RowBox[{"a2", "+", 
    RowBox[{"b3", " ", "r"}], "-", 
    RowBox[{"b1", " ", "z"}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["RE", "2"], " ", 
      SuperscriptBox["RI", "2"], " ", "\[Alpha]"}], 
     RowBox[{"r", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["RE", "2"], "-", 
        SuperscriptBox["RI", "2"]}], ")"}]}]]}], ",", 
   RowBox[{"a3", "-", 
    RowBox[{"b2", " ", "r"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqRE", " ", "=", 
  RowBox[{"Thread", "[", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"u", " ", "/.", " ", 
      RowBox[{"r", " ", "\[Rule]", " ", "RE"}]}], " ", ")"}], "\[Equal]", " ",
     
    RowBox[{"{", 
     RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}]}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"a1", "+", 
     RowBox[{"b2", " ", "z"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"a2", "+", 
     RowBox[{"b3", " ", "RE"}], "-", 
     RowBox[{"b1", " ", "z"}], "+", 
     FractionBox[
      RowBox[{"RE", " ", 
       SuperscriptBox["RI", "2"], " ", "\[Alpha]"}], 
      RowBox[{
       SuperscriptBox["RE", "2"], "-", 
       SuperscriptBox["RI", "2"]}]]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"a3", "-", 
     RowBox[{"b2", " ", "RE"}]}], "\[Equal]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RErule", " ", "=", " ", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"a1", " ", "\[Rule]", " ", "0"}], ",", 
    RowBox[{"b1", "\[Rule]", " ", "0"}], ",", "  ", 
    RowBox[{"b2", " ", "\[Rule]", " ", "0"}], " ", ",", " ", 
    RowBox[{"a3", " ", "\[Rule]", " ", "0"}]}], "}"}], "  "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a1", "\[Rule]", "0"}], ",", 
   RowBox[{"b1", "\[Rule]", "0"}], ",", 
   RowBox[{"b2", "\[Rule]", "0"}], ",", 
   RowBox[{"a3", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqRE", " ", "=", 
  RowBox[{"eqRE", " ", "/.", " ", "RErule"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", 
   RowBox[{
    RowBox[{"a2", "+", 
     RowBox[{"b3", " ", "RE"}], "+", 
     FractionBox[
      RowBox[{"RE", " ", 
       SuperscriptBox["RI", "2"], " ", "\[Alpha]"}], 
      RowBox[{
       SuperscriptBox["RE", "2"], "-", 
       SuperscriptBox["RI", "2"]}]]}], "\[Equal]", "0"}], ",", "True"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"uRI", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", 
     RowBox[{"\[Alpha]", " ", "RI"}], ",", " ", "0"}], "}"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"eqRI", " ", "=", 
  RowBox[{
   RowBox[{"Thread", "[", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"u", " ", "/.", " ", 
       RowBox[{"r", " ", "\[Rule]", " ", "RI"}]}], " ", ")"}], "\[Equal]", 
     " ", "uRI"}], " ", "]"}], " ", "/.", " ", "RErule"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"RI", " ", "\[Alpha]"}], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", 
   RowBox[{
    RowBox[{"a2", "+", 
     RowBox[{"b3", " ", "RI"}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["RE", "2"], " ", "RI", " ", "\[Alpha]"}], 
      RowBox[{
       SuperscriptBox["RE", "2"], "-", 
       SuperscriptBox["RI", "2"]}]]}], "\[Equal]", 
    RowBox[{"RI", " ", "\[Alpha]"}]}], ",", "True"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{"Join", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"eqRI", "[", 
          RowBox[{"[", "2", "]"}], "]"}], " ", ",", " ", 
         RowBox[{"eqRE", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"a2", ",", " ", "b3"}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", " ", "RErule"}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a2", "\[Rule]", "0"}], ",", 
   RowBox[{"b3", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["RI", "2"], " ", "\[Alpha]"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"RE", "-", "RI"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"RE", "+", "RI"}], ")"}]}]]}]}], ",", 
   RowBox[{"a1", "\[Rule]", "0"}], ",", 
   RowBox[{"b1", "\[Rule]", "0"}], ",", 
   RowBox[{"b2", "\[Rule]", "0"}], ",", 
   RowBox[{"a3", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", " ", "=", " ", 
  RowBox[{"u", " ", "/.", " ", "sol"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"r", " ", 
       SuperscriptBox["RI", "2"], " ", "\[Alpha]"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"RE", "-", "RI"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"RE", "+", "RI"}], ")"}]}]]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["RE", "2"], " ", 
      SuperscriptBox["RI", "2"], " ", "\[Alpha]"}], 
     RowBox[{"r", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["RE", "2"], "-", 
        SuperscriptBox["RI", "2"]}], ")"}]}]]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{831, 780},
WindowMargins->{{Automatic, 14}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[1309, 36, 233, 8, 46, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1567, 48, 320, 9, 77, "Input"],
Cell[1890, 59, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1977, 62, 111, 2, 77, "Input"],
Cell[CellGroupData[{
Cell[2113, 68, 257, 6, 55, "Input"],
Cell[2373, 76, 98, 2, 31, "Output"],
Cell[2474, 80, 195, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2706, 91, 49, 0, 39, "Subsection"],
Cell[2758, 93, 73, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[2856, 98, 499, 15, 55, "Input"],
Cell[3358, 115, 287, 10, 60, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3682, 130, 149, 4, 55, "Input"],
Cell[3834, 136, 290, 10, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4161, 151, 384, 11, 32, "Input"],
Cell[4548, 164, 161, 5, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4746, 174, 102, 2, 32, "Input"],
Cell[4851, 178, 428, 14, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5316, 197, 646, 20, 43, "Input"],
Cell[5965, 219, 516, 17, 46, "Output"],
Cell[6484, 238, 2373, 66, 145, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8894, 309, 407, 9, 27, "Input"],
Cell[9304, 320, 385, 7, 20, "Message"],
Cell[9692, 329, 389, 12, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10118, 346, 590, 17, 43, "Input"],
Cell[10711, 365, 115, 3, 27, "Output"],
Cell[10829, 370, 386, 8, 20, "Message"],
Cell[11218, 380, 137, 3, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11392, 388, 692, 18, 75, "Input"],
Cell[12087, 408, 506, 15, 48, "Output"],
Cell[12596, 425, 359, 11, 46, "Output"],
Cell[12958, 438, 800, 24, 49, "Output"],
Cell[13761, 464, 985, 31, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14783, 500, 143, 3, 43, "Input"],
Cell[14929, 505, 937, 31, 48, "Output"],
Cell[15869, 538, 260, 8, 27, "Output"]
}, Open  ]],
Cell[16144, 549, 66, 1, 27, "Input"],
Cell[16213, 552, 74, 1, 27, "Input"],
Cell[CellGroupData[{
Cell[16312, 557, 508, 14, 27, "Input"],
Cell[16823, 573, 549, 18, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17409, 596, 327, 10, 27, "Input"],
Cell[17739, 608, 570, 18, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18346, 631, 321, 7, 27, "Input"],
Cell[18670, 640, 217, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18924, 651, 99, 2, 27, "Input"],
Cell[19026, 655, 373, 12, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19436, 672, 487, 14, 43, "Input"],
Cell[19926, 688, 115, 3, 27, "Output"],
Cell[20044, 693, 403, 12, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20484, 710, 537, 16, 27, "Input"],
Cell[21024, 728, 552, 17, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21613, 750, 96, 2, 27, "Input"],
Cell[21712, 754, 637, 21, 48, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

