(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     17836,        585]
NotebookOptionsPosition[     15901,        519]
NotebookOutlinePosition[     16344,        537]
CellTagsIndexPosition[     16301,        534]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{" ", 
    RowBox[{
    "The", " ", "heating", " ", "disk", " ", "glued", " ", "to", " ", 
     "plane"}]}], "Subtitle"], TraditionalForm]], "Input",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
    "]"}], "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\n", 
 RowBox[{"<<", "Displacement.m"}], "\n"}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SetCoordinates", "[", 
   RowBox[{"Cylindrical", "[", 
    RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}], "\n"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Kinematically admissible displacement field", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"u", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", " ", 
      RowBox[{"A", " ", "z"}]}], "}"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"u", " ", "/.", " ", 
    RowBox[{"z", " ", "\[Rule]", " ", "0"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{
     RowBox[{"1", "/", "2"}], " ", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"sig", " ", "=", " ", 
    RowBox[{
     RowBox[{"\[Lambda]", " ", 
      RowBox[{"Tr", "[", "eps", "]"}], " ", 
      RowBox[{"IdentityMatrix", "[", "3", "]"}]}], " ", "+", " ", 
     RowBox[{"2", " ", "\[Mu]", " ", "eps"}], " ", "-", " ", 
     RowBox[{"\[Alpha]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], " ", "+", " ", 
        RowBox[{"2", " ", "\[Mu]"}]}], " ", ")"}], "\[Theta]", " ", 
      RowBox[{"IdentityMatrix", "[", "3", "]"}]}]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"A", " ", "z"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "A"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"A", " ", "\[Lambda]"}], "-", 
      RowBox[{"\[Alpha]", " ", "\[Theta]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"A", " ", "\[Lambda]"}], "-", 
      RowBox[{"\[Alpha]", " ", "\[Theta]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"A", " ", "\[Lambda]"}], "+", 
      RowBox[{"2", " ", "A", " ", "\[Mu]"}], "-", 
      RowBox[{"\[Alpha]", " ", "\[Theta]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Wint", " ", "=", " ", 
  RowBox[{
   RowBox[{"1", "/", "2"}], "  ", "Pi", " ", 
   RowBox[{"R", "^", "2"}], " ", 
   RowBox[{"Integrate", "[", "  ", 
    RowBox[{
     RowBox[{"Tr", "[", " ", 
      RowBox[{"eps", " ", ".", " ", "sig"}], " ", "]"}], " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"z", ",", " ", "0", ",", " ", "H"}], "}"}]}], " ", 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"W", " ", "=", " ", "Wint"}], "\[IndentingNewLine]", 
 RowBox[{"sol", " ", "=", 
  RowBox[{"Solve", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", " ", 
      RowBox[{"W", ",", "A"}], "]"}], " ", "\[Equal]", " ", "0"}], ",", " ", 
    "A"}], " ", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"W1", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"W", " ", "/.", " ", "sol"}], " ", "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "A", " ", "H", " ", "\[Pi]", " ", 
  SuperscriptBox["R", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"A", " ", 
     RowBox[{"(", 
      RowBox[{"\[Lambda]", "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
    RowBox[{"\[Alpha]", " ", "\[Theta]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "\[Lambda]"}], "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "A", " ", "H", " ", "\[Pi]", " ", 
  SuperscriptBox["R", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"A", " ", 
     RowBox[{"(", 
      RowBox[{"\[Lambda]", "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "-", 
    RowBox[{"\[Alpha]", " ", "\[Theta]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "\[Lambda]"}], "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"A", "\[Rule]", 
    FractionBox[
     RowBox[{"\[Alpha]", " ", "\[Theta]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"\[Lambda]", "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], "}"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"H", " ", "\[Pi]", " ", 
     SuperscriptBox["R", "2"], " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SuperscriptBox["\[Theta]", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}], "2"]}], 
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{"\[Lambda]", "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<Global`Energy\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Energy", "[", " ", 
   RowBox[{"u_", " ", ",", " ", "params_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"eps", " ", "=", " ", 
      RowBox[{
       RowBox[{"1", "/", "2"}], " ", 
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
         RowBox[{"Transpose", "[", 
          RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sig", " ", "=", " ", 
      RowBox[{
       RowBox[{"\[Lambda]", " ", 
        RowBox[{"Tr", "[", "eps", "]"}], " ", 
        RowBox[{"IdentityMatrix", "[", "3", "]"}]}], " ", "+", " ", 
       RowBox[{"2", " ", "\[Mu]", " ", "eps"}], " ", "-", " ", 
       RowBox[{"\[Alpha]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Lambda]"}], " ", "+", " ", 
          RowBox[{"2", " ", "\[Mu]"}]}], " ", ")"}], "\[Theta]", " ", 
        RowBox[{"IdentityMatrix", "[", "3", "]"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Wint", " ", "=", " ", 
      RowBox[{
       RowBox[{"1", "/", "2"}], "  ", 
       RowBox[{"Integrate", "[", " ", 
        RowBox[{
         RowBox[{"Integrate", "[", "  ", 
          RowBox[{
           RowBox[{
            RowBox[{"Tr", "[", " ", 
             RowBox[{"eps", " ", ".", " ", "sig"}], " ", "]"}], " ", "r"}], 
           " ", ",", " ", 
           RowBox[{"{", 
            RowBox[{"z", ",", " ", "0", ",", " ", "H"}], "}"}]}], " ", "]"}], 
         ",", " ", 
         RowBox[{"{", 
          RowBox[{"r", ",", "0", ",", "R"}], "}"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"W", " ", "=", " ", "Wint"}], ";", "\[IndentingNewLine]", 
     RowBox[{"sol", " ", "=", 
      RowBox[{
       RowBox[{"Solve", "[", " ", 
        RowBox[{
         RowBox[{"Map", "[", " ", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"D", "[", " ", 
              RowBox[{"W", ",", " ", "#"}], " ", "]"}], " ", "\[Equal]", " ", 
             "0"}], " ", "&"}], " ", ",", " ", "params"}], " ", "]"}], ",", 
         " ", "params"}], " ", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", "sol", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"W", " ", "/.", " ", "sol"}], " ", "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", " ", 
    RowBox[{"A", " ", "z"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u", " ", "/.", " ", 
   RowBox[{"z", " ", "\[Rule]", " ", "0"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Energy", "[", " ", 
  RowBox[{"u", ",", " ", 
   RowBox[{"{", "A", "}"}]}], " ", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"A", " ", "z"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"A", "\[Rule]", 
   FractionBox[
    RowBox[{"\[Alpha]", " ", "\[Theta]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "\[Lambda]"}], "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"\[Lambda]", "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"H", " ", 
    SuperscriptBox["R", "2"], " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SuperscriptBox["\[Theta]", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "\[Lambda]"}], "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}], "2"]}], 
   RowBox[{"16", " ", 
    RowBox[{"(", 
     RowBox[{"\[Lambda]", "+", 
      RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"B", " ", "r", " ", "z"}], ",", "0", ",", " ", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u", " ", "/.", " ", 
   RowBox[{"z", " ", "\[Rule]", " ", "0"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Energy", "[", " ", 
  RowBox[{"u", ",", " ", 
   RowBox[{"{", "B", "}"}]}], " ", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"B", " ", "r", " ", "z"}], ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"B", "\[Rule]", 
   FractionBox[
    RowBox[{"3", " ", "H", " ", "\[Alpha]", " ", "\[Theta]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "\[Lambda]"}], "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], 
    RowBox[{
     RowBox[{"8", " ", 
      SuperscriptBox["H", "2"], " ", "\[Lambda]"}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["H", "2"], " ", "\[Mu]"}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["R", "2"], " ", "\[Mu]"}]}]]}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox["H", "3"], " ", 
    SuperscriptBox["R", "2"], " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SuperscriptBox["\[Theta]", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "\[Lambda]"}], "+", 
       RowBox[{"2", " ", "\[Mu]"}]}], ")"}], "2"]}], 
   RowBox[{"8", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["R", "2"], " ", "\[Mu]"}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["H", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]}], ")"}]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"B", " ", "r", " ", "z"}], ",", "0", ",", " ", 
    RowBox[{"A", " ", "z"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u", " ", "/.", " ", 
   RowBox[{"z", " ", "\[Rule]", " ", "0"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Energy", "[", " ", 
  RowBox[{"u", ",", " ", 
   RowBox[{"{", 
    RowBox[{"A", ",", " ", "B"}], "}"}]}], " ", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"B", " ", "r", " ", "z"}], ",", "0", ",", 
   RowBox[{"A", " ", "z"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"H", " ", 
     SuperscriptBox["R", "2"], " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SuperscriptBox["\[Theta]", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["R", "2"], " ", "\[Mu]"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["H", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", 
          RowBox[{"10", " ", "\[Mu]"}]}], ")"}]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"48", " ", 
      SuperscriptBox["R", "2"], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{"\[Lambda]", "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}], "+", 
     RowBox[{"32", " ", 
      SuperscriptBox["H", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Lambda]", "2"], "+", 
        RowBox[{"12", " ", "\[Lambda]", " ", "\[Mu]"}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["\[Mu]", "2"]}]}], ")"}]}]}]]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{982, 821},
WindowMargins->{{94, Automatic}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[1309, 36, 216, 7, 46, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1550, 47, 320, 9, 77, "Input"],
Cell[1873, 58, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1960, 61, 111, 2, 77, "Input"],
Cell[CellGroupData[{
Cell[2096, 67, 160, 4, 55, "Input"],
Cell[2259, 73, 98, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2394, 80, 65, 0, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2484, 84, 1186, 31, 165, "Input"],
Cell[3673, 117, 107, 3, 31, "Output"],
Cell[3783, 122, 83, 2, 31, "Output"],
Cell[3869, 126, 260, 8, 31, "Output"],
Cell[4132, 136, 1039, 31, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5208, 172, 845, 22, 99, "Input"],
Cell[6056, 196, 474, 14, 46, "Output"],
Cell[6533, 212, 474, 14, 44, "Output"],
Cell[7010, 228, 423, 13, 46, "Output"],
Cell[7436, 243, 524, 16, 48, "Output"]
}, Open  ]],
Cell[7975, 262, 78, 1, 27, "Input"],
Cell[8056, 265, 2510, 64, 155, "Input"],
Cell[CellGroupData[{
Cell[10591, 333, 410, 11, 75, "Input"],
Cell[11004, 346, 107, 3, 27, "Output"],
Cell[11114, 351, 83, 2, 27, "Output"],
Cell[11200, 355, 388, 12, 42, "Print"],
Cell[11591, 369, 474, 15, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12102, 389, 424, 12, 75, "Input"],
Cell[12529, 403, 117, 3, 27, "Output"],
Cell[12649, 408, 83, 2, 27, "Output"],
Cell[12735, 412, 533, 15, 42, "Print"],
Cell[13271, 429, 675, 21, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13983, 455, 475, 13, 75, "Input"],
Cell[14461, 470, 141, 4, 27, "Output"],
Cell[14605, 476, 83, 2, 27, "Output"],
Cell[14691, 480, 1182, 35, 48, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

