(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     14432,        518]
NotebookOptionsPosition[     12722,        452]
NotebookOutlinePosition[     13054,        467]
CellTagsIndexPosition[     13011,        464]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"",
   "]"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Tensor2Analysis.m"}], "\n", 
 RowBox[{"<<", "IntegrateStrain.m"}], "\n"}], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}], "\n", 
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "t", ",", "p"}], "}"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Spherical", "[", 
  RowBox[{"r", ",", "t", ",", "p"}], "]"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eps", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", " ", 
      RowBox[{
       RowBox[{"Sin", "[", "t", "]"}], " ", "/", " ", 
       RowBox[{"r", "^", "3"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Sin", "[", "t", "]"}], " ", "/", " ", 
       RowBox[{"r", "^", "3"}]}], ",", " ", "0", ",", " ", "0"}], "}"}]}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"Sin", "[", "t", "]"}], 
      SuperscriptBox["r", "3"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"Sin", "[", "t", "]"}], 
      SuperscriptBox["r", "3"]], ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Inc", "[", "eps", " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IntegrateStrain", "[", " ", "eps", " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"Sin", "[", "t", "]"}]}], 
     RowBox[{"3", " ", 
      SuperscriptBox["r", "2"]}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", " ", 
    RowBox[{
     RowBox[{"Sin", "[", "t", "]"}], " ", "r", " ", 
     RowBox[{"(", " ", 
      RowBox[{"a", " ", "-", " ", 
       RowBox[{"b", " ", 
        RowBox[{"r", "^", 
         RowBox[{"-", "3"}]}]}]}], ")"}]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "-", 
      FractionBox["b", 
       SuperscriptBox["r", "3"]]}], ")"}], " ", "r", " ", 
    RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{
   RowBox[{"1", "/", "2"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}]}], " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"3", " ", "b", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["r", "3"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "b", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["r", "3"]}]], ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grad", "[", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", " ", "0", ",", " ", "r"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      RowBox[{"Cot", "[", "t", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IntegrateGrad", "[", " ", "%", " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "r"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pbeps", " ", "=", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{"1", "/", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Grad", "[", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "0", ",", " ", "r"}], "}"}], "]"}], " ", "+", 
      " ", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Grad", "[", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "0", ",", " ", "r"}], "}"}], "]"}], "]"}]}], 
     ")"}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Cot", "[", "t", "]"}], "2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Cot", "[", "t", "]"}], "2"]}], ",", "0"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Inc", "[", " ", "pbeps", " ", "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pbu", " ", "=", 
  RowBox[{"IntegrateStrain", "[", " ", "pbeps", " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "r", " ", 
       SuperscriptBox["t", "2"], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "r", " ", 
       RowBox[{"Log", "[", 
        RowBox[{"Sin", "[", "t", "]"}], "]"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"p", " ", "r", " ", 
     RowBox[{"Cos", "[", "t", "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "p", " ", "r", " ", 
     RowBox[{"Cos", "[", "t", "]"}], " ", 
     RowBox[{"Log", "[", 
      RowBox[{"Sin", "[", "t", "]"}], "]"}]}], "+", 
    RowBox[{"p", " ", "r", " ", "t", " ", 
     RowBox[{"Sin", "[", "t", "]"}]}], "+", 
    RowBox[{"r", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "p"}], " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "p", " ", 
        RowBox[{"Cos", "[", "t", "]"}], " ", 
        RowBox[{"Log", "[", 
         RowBox[{"Sin", "[", "t", "]"}], "]"}]}], "-", 
       RowBox[{"p", " ", "t", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}], "+", 
    RowBox[{"p", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "r"}], " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "r", " ", 
        SuperscriptBox["t", "2"], " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], "-", 
       RowBox[{"r", " ", "t", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}]}], ",", 
   FractionBox[
    RowBox[{"r", " ", 
     SuperscriptBox["t", "2"]}], "2"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{
   RowBox[{"1", "/", "2"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Grad", "[", " ", "pbu", " ", "]"}], " ", "+", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Grad", "[", " ", "pbu", " ", "]"}], "]"}]}], ")"}]}], " ", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", "p", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["t", "2"], "+", 
        RowBox[{"Log", "[", 
         RowBox[{"Sin", "[", "t", "]"}], "]"}]}], ")"}], " ", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", "p", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["t", "2"], "+", 
           RowBox[{"Log", "[", 
            RowBox[{"Sin", "[", "t", "]"}], "]"}]}], ")"}]}], "+", 
        RowBox[{"2", " ", "t", " ", 
         RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["t", "2"], "+", 
        RowBox[{"Log", "[", 
         RowBox[{"Sin", "[", "t", "]"}], "]"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", "p", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["t", "2"], "+", 
           RowBox[{"Log", "[", 
            RowBox[{"Sin", "[", "t", "]"}], "]"}]}], ")"}]}], "+", 
        RowBox[{"2", " ", "t", " ", 
         RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", "p", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"Sin", "[", "t", "]"}], "]"}], " ", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Cot", "[", "t", "]"}], "2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["t", "2"], "+", 
        RowBox[{"Log", "[", 
         RowBox[{"Sin", "[", "t", "]"}], "]"}]}], ")"}]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Cot", "[", "t", "]"}], "2"]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", "p", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "t", " ", 
         RowBox[{"Cos", "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           SuperscriptBox["t", "2"]}], ")"}], " ", 
         RowBox[{"Csc", "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", 
           RowBox[{"Log", "[", 
            RowBox[{"Sin", "[", "t", "]"}], "]"}]}], ")"}], " ", 
         RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]]
},
WindowSize->{733, 694},
WindowMargins->{{Automatic, 42}, {Automatic, 2}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 227, 4, 99, "Input"],
Cell[1561, 44, 72, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1670, 49, 255, 6, 55, "Input"],
Cell[1928, 57, 96, 2, 31, "Output"],
Cell[2027, 61, 335, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2399, 76, 520, 16, 32, "Input"],
Cell[2922, 94, 435, 15, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3394, 114, 63, 1, 32, "Input"],
Cell[3460, 117, 260, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3757, 130, 80, 1, 32, "Input"],
Cell[3840, 133, 239, 8, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4116, 146, 339, 10, 32, "Input"],
Cell[4458, 158, 254, 8, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4749, 171, 285, 8, 32, "Input"],
Cell[5037, 181, 567, 19, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5641, 205, 129, 3, 32, "Input"],
Cell[5773, 210, 336, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6146, 226, 76, 1, 32, "Input"],
Cell[6225, 229, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6345, 236, 503, 15, 32, "Input"],
Cell[6851, 253, 425, 15, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7313, 273, 88, 2, 32, "Input"],
Cell[7404, 277, 260, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7701, 290, 112, 2, 32, "Input"],
Cell[7816, 294, 1752, 52, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9605, 351, 316, 9, 32, "Input"],
Cell[9924, 362, 2782, 87, 151, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

