(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     42993,       1479]
NotebookOptionsPosition[     38235,       1315]
NotebookOutlinePosition[     38567,       1330]
CellTagsIndexPosition[     38524,       1327]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{"Estimation", " ", "the", " ", "torsional", " ", "stiffness"}], 
     " ", "-", " ", 
     RowBox[{"spherical", " ", "joint"}]}]}], "Subtitle"], 
  TraditionalForm]], "Input",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
    "]"}], "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\n", 
 RowBox[{"<<", "Displacement.m"}], "\n"}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}], "\n", 
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "t", ",", "p"}], "}"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Spherical", "[", 
  RowBox[{"r", ",", "t", ",", "p"}], "]"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["statically admissible field", "Subsection"],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sig", " ", ":=", " ", 
    RowBox[{
     RowBox[{"srp", "[", " ", 
      RowBox[{"r", ",", " ", "t"}], "]"}], " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"sig", " ", "//", " ", "MatrixForm"}]}], " "}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      RowBox[{"srp", "[", 
       RowBox[{"r", ",", "t"}], "]"}]},
     {"0", "0", "0"},
     {
      RowBox[{"srp", "[", 
       RowBox[{"r", ",", "t"}], "]"}], "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"divsig", " ", ":=", " ", 
  RowBox[{
  "Div", "[", " ", "sig", " ", 
   "]"}]}], "\[IndentingNewLine]", "divsig"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"srp", "[", 
       RowBox[{"r", ",", "t"}], "]"}]}], "r"], "+", 
    RowBox[{
     SuperscriptBox["srp", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"r", ",", "t"}], "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"srp", "[", " ", 
    RowBox[{"r", ",", " ", "t"}], " ", "]"}], " ", "=", " ", 
   RowBox[{"srp", "[", "r", "]"}]}], 
  " "}], "\[IndentingNewLine]", "divsig", "\[IndentingNewLine]", 
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{
   RowBox[{"DSolve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"divsig", "[", 
       RowBox[{"[", "3", "]"}], "]"}], " ", "\[Equal]", " ", "0"}], " ", ",", 
     " ", 
     RowBox[{"srp", "[", "r", "]"}], " ", ",", " ", "r"}], " ", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"srp", "[", "r", "]"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"srp", "[", "r", "]"}]}], "r"], "+", 
    RowBox[{
     SuperscriptBox["srp", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"srp", "[", "r", "]"}], "\[Rule]", 
  FractionBox[
   RowBox[{"C", "[", "1", "]"}], 
   SuperscriptBox["r", "3"]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"srp", "[", " ", 
    RowBox[{"r", ",", " ", "t"}], " ", "]"}], " ", "=", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"srp", "[", "r", "]"}], " ", "/.", " ", "sol"}], " ", "/.", " ",
      
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], " ", "\[Rule]", " ", 
      RowBox[{"f", "[", "t", "]"}]}]}], ")"}]}], 
  " "}], "\[IndentingNewLine]", "sig"}], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"f", "[", "t", "]"}], 
  SuperscriptBox["r", "3"]]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"f", "[", "t", "]"}], 
      SuperscriptBox["r", "3"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"f", "[", "t", "]"}], 
      SuperscriptBox["r", "3"]], ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eps", "=", " ", 
  RowBox[{
   RowBox[{"1", " ", "/", " ", 
    RowBox[{"(", " ", 
     RowBox[{"2", " ", "\[Mu]"}], " ", ")"}]}], " ", "sig", 
   " "}]}], "\[IndentingNewLine]", 
 RowBox[{"wint", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", " ", "1"}], "/", "2"}], "  ", "2", " ", "Pi", " ", 
   RowBox[{"Integrate", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Tr", "[", " ", 
       RowBox[{"eps", " ", ".", " ", "sig"}], " ", "]"}], " ", 
      RowBox[{"r", "^", "2"}], " ", 
      RowBox[{"Sin", "[", "t", "]"}]}], " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"r", ",", " ", "RI", ",", " ", "RE"}], "}"}]}], "]"}], 
   " "}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"f", "[", "t", "]"}], 
      RowBox[{"2", " ", 
       SuperscriptBox["r", "3"], " ", "\[Mu]"}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"f", "[", "t", "]"}], 
      RowBox[{"2", " ", 
       SuperscriptBox["r", "3"], " ", "\[Mu]"}]], ",", "0", ",", "0"}], 
    "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", "\[Mu]"], 
   RowBox[{"(", 
    RowBox[{"\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{"RE", "-", "RI"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"f", "[", "t", "]"}], "2"], " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Re", "[", "RE", "]"}], ">", "0"}], "&&", 
         RowBox[{
          RowBox[{"Re", "[", "RI", "]"}], ">", "0"}]}], "||", 
        RowBox[{
         RowBox[{
          RowBox[{"Re", "[", "RE", "]"}], "<", "0"}], "&&", 
         RowBox[{
          RowBox[{"Re", "[", "RI", "]"}], "<", "0"}]}], "||", 
        RowBox[{"RE", "\[Equal]", "0"}], "||", 
        RowBox[{"RI", "\[Equal]", "0"}], "||", 
        RowBox[{
         RowBox[{"Im", "[", "RE", "]"}], "\[NotEqual]", "0"}], "||", 
        RowBox[{
         RowBox[{"Im", "[", "RI", "]"}], "\[NotEqual]", "0"}]}], ",", 
       FractionBox[
        RowBox[{
         SuperscriptBox["RE", "2"], "+", 
         RowBox[{"RE", " ", "RI"}], "+", 
         SuperscriptBox["RI", "2"]}], 
        RowBox[{"3", " ", 
         SuperscriptBox["RE", "3"], " ", 
         SuperscriptBox["RI", "3"]}]], ",", 
       RowBox[{"Integrate", "[", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"r", " ", 
              RowBox[{"(", 
               RowBox[{"RE", "-", "RI"}], ")"}]}], "+", "RI"}], ")"}], "4"]], 
         ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"Assumptions", "\[Rule]", 
          RowBox[{"!", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Re", "[", "RE", "]"}], ">", "0"}], "&&", 
              RowBox[{
               RowBox[{"Re", "[", "RI", "]"}], ">", "0"}]}], "||", 
             RowBox[{
              RowBox[{
               RowBox[{"Re", "[", "RE", "]"}], "<", "0"}], "&&", 
              RowBox[{
               RowBox[{"Re", "[", "RI", "]"}], "<", "0"}]}], "||", 
             RowBox[{"RE", "\[Equal]", "0"}], "||", 
             RowBox[{"RI", "\[Equal]", "0"}], "||", 
             RowBox[{
              RowBox[{"Im", "[", "RE", "]"}], "\[NotEqual]", "0"}], "||", 
             RowBox[{
              RowBox[{"Im", "[", "RI", "]"}], "\[NotEqual]", "0"}]}], 
            ")"}]}]}]}], "]"}]}], "]"}], " ", 
     RowBox[{"Sin", "[", "t", "]"}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"wint", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", " ", 
   RowBox[{"wint", " ", ",", " ", 
    RowBox[{"Assumptions", " ", "\[Rule]", " ", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"RI", " ", ">", " ", "0"}], " ", "&&", " ", 
       RowBox[{"RI", " ", "<", " ", "RE"}], " ", "&&", " ", 
       RowBox[{"RI", " ", ">", " ", "0"}]}], ")"}]}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Pi]", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["RE", "3"]], "-", 
     FractionBox["1", 
      SuperscriptBox["RI", "3"]]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", "t", "]"}], "2"], " ", 
   RowBox[{"Sin", "[", "t", "]"}]}], 
  RowBox[{"3", " ", "\[Mu]"}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ue", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", " ", "0", " ", ",", " ", 
    RowBox[{"\[Alpha]", "  ", "RE", " ", 
     RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"ui", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", " ", "0", " ", ",", " ", "0"}], "}"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"RE", " ", "\[Alpha]", " ", 
    RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ue", " ", ".", " ", "sig", " ", ".", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "}"}]}], " ", "/.", " ", 
  RowBox[{"r", " ", "\[Rule]", " ", "RE"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Alpha]", " ", 
   RowBox[{"f", "[", "t", "]"}], " ", 
   RowBox[{"Sin", "[", "t", "]"}]}], 
  SuperscriptBox["RE", "2"]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"wext", " ", "=", " ", 
  RowBox[{"2", " ", "Pi", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"ue", " ", ".", " ", "sig", " ", ".", " ", 
      RowBox[{"{", 
       RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "}"}]}], " ", "/.", " ", 
     RowBox[{"r", " ", "\[Rule]", " ", "RE"}]}], ")"}], " ", 
   RowBox[{"RE", "^", "2"}], " ", 
   RowBox[{"Sin", "[", "t", "]"}], "  "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"2", " ", "\[Pi]", " ", "\[Alpha]", " ", 
  RowBox[{"f", "[", "t", "]"}], " ", 
  SuperscriptBox[
   RowBox[{"Sin", "[", "t", "]"}], "2"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"w", "=", " ", 
  RowBox[{"wext", " ", "+", " ", "wint"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["RE", "3"]], "-", 
      FractionBox["1", 
       SuperscriptBox["RI", "3"]]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"f", "[", "t", "]"}], "2"], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], 
   RowBox[{"3", " ", "\[Mu]"}]], "+", 
  RowBox[{"2", " ", "\[Pi]", " ", "\[Alpha]", " ", 
   RowBox[{"f", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "t", "]"}], "2"]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "\"\<VariationalMethods`\>\""}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eueq", "=", 
  RowBox[{"EulerEquations", "[", 
   RowBox[{"w", ",", 
    RowBox[{"f", "[", "t", "]"}], ",", "t"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["2", "3"], " ", "\[Pi]", " ", 
   RowBox[{"Sin", "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["RE", "3"]], "-", 
         FractionBox["1", 
          SuperscriptBox["RI", "3"]]}], ")"}], " ", 
       RowBox[{"f", "[", "t", "]"}]}], "\[Mu]"], "+", 
     RowBox[{"3", " ", "\[Alpha]", " ", 
      RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}], "\[Equal]", 
  "0"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solf", " ", "=", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{"eueq", " ", ",", " ", 
     RowBox[{"f", "[", "t", "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(solf\\)\
\\\" is similar to existing symbol \\\"\\!\\(sol\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f", "[", "t", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", 
      SuperscriptBox["RE", "3"], " ", 
      SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", "\[Mu]", " ", 
      RowBox[{"Sin", "[", "t", "]"}]}], 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["RE", "3"]}], "+", 
      SuperscriptBox["RI", "3"]}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"fsig", " ", "=", 
  RowBox[{"sig", " ", "/.", " ", "solf"}]}], "\[IndentingNewLine]", 
 RowBox[{"feps", " ", "=", " ", 
  RowBox[{"eps", " ", "/.", " ", "solf"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(fsig\\)\
\\\" is similar to existing symbol \\\"\\!\\(sig\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox["RE", "3"], " ", 
        SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", "\[Mu]", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["RE", "3"]}], "+", 
          SuperscriptBox["RI", "3"]}], ")"}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox["RE", "3"], " ", 
        SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", "\[Mu]", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["RE", "3"]}], "+", 
          SuperscriptBox["RI", "3"]}], ")"}]}]]}], ",", "0", ",", "0"}], 
    "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(feps\\)\
\\\" is similar to existing symbol \\\"\\!\\(eps\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox["RE", "3"], " ", 
        SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["RE", "3"]}], "+", 
          SuperscriptBox["RI", "3"]}], ")"}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox["RE", "3"], " ", 
        SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["RE", "3"]}], "+", 
          SuperscriptBox["RI", "3"]}], ")"}]}]]}], ",", "0", ",", "0"}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{"Inc", "[", " ", "feps", "]"}], " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", " ", "IntegrateStrain.m"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fu", " ", "=", " ", 
  RowBox[{
   RowBox[{"IntegrateStrain", "[", " ", "feps", " ", "]"}], " ", "+", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "a2", ",", "a3"}], "}"}], "+", 
   RowBox[{"Cross", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b1", ",", "b2", ",", "b3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "0"}], "}"}]}], "]"}], " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a1", ",", 
   RowBox[{"a2", "+", 
    RowBox[{"b3", " ", "r"}]}], ",", 
   RowBox[{"a3", "-", 
    RowBox[{"b2", " ", "r"}], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["RE", "3"], " ", 
      SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", 
      RowBox[{"Sin", "[", "t", "]"}]}], 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["RE", "3"], "-", 
        SuperscriptBox["RI", "3"]}], ")"}]}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eqRI", " ", "=", 
  RowBox[{"Thread", "[", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"fu", " ", "/.", " ", 
      RowBox[{"r", " ", "\[Rule]", " ", "RI"}]}], " ", ")"}], " ", "\[Equal]",
     " ", "ui"}], " ", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"eqRE", " ", "=", 
  RowBox[{"Thread", "[", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"fu", " ", "/.", " ", 
      RowBox[{"r", " ", "\[Rule]", " ", "RE"}]}], " ", ")"}], " ", "\[Equal]",
     " ", "ue"}], " ", "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a1", "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"a2", "+", 
     RowBox[{"b3", " ", "RI"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"a3", "-", 
     RowBox[{"b2", " ", "RI"}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["RE", "3"], " ", "RI", " ", "\[Alpha]", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{
       SuperscriptBox["RE", "3"], "-", 
       SuperscriptBox["RI", "3"]}]]}], "\[Equal]", "0"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(eqRE\\)\
\\\" is similar to existing symbol \\\"\\!\\(eqRI\\)\\\". \\!\\(\\*ButtonBox[\
\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a1", "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"a2", "+", 
     RowBox[{"b3", " ", "RE"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"a3", "-", 
     RowBox[{"b2", " ", "RE"}], "-", 
     FractionBox[
      RowBox[{"RE", " ", 
       SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{
       SuperscriptBox["RE", "3"], "-", 
       SuperscriptBox["RI", "3"]}]]}], "\[Equal]", 
    RowBox[{"RE", " ", "\[Alpha]", " ", 
     RowBox[{"Sin", "[", "t", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"rules", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a1", " ", "\[Rule]", " ", "0"}], ",", " ", 
    RowBox[{"a2", " ", "\[Rule]", " ", "0"}], ",", " ", 
    RowBox[{"b3", " ", "\[Rule]", " ", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqRI", " ", "/.", " ", "rules"}], " "}], "\[IndentingNewLine]", 
 RowBox[{"eqRE", " ", "/.", " ", "rules"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a1", "\[Rule]", "0"}], ",", 
   RowBox[{"a2", "\[Rule]", "0"}], ",", 
   RowBox[{"b3", "\[Rule]", "0"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", 
   RowBox[{
    RowBox[{"a3", "-", 
     RowBox[{"b2", " ", "RI"}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["RE", "3"], " ", "RI", " ", "\[Alpha]", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{
       SuperscriptBox["RE", "3"], "-", 
       SuperscriptBox["RI", "3"]}]]}], "\[Equal]", "0"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", 
   RowBox[{
    RowBox[{"a3", "-", 
     RowBox[{"b2", " ", "RE"}], "-", 
     FractionBox[
      RowBox[{"RE", " ", 
       SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{
       SuperscriptBox["RE", "3"], "-", 
       SuperscriptBox["RI", "3"]}]]}], "\[Equal]", 
    RowBox[{"RE", " ", "\[Alpha]", " ", 
     RowBox[{"Sin", "[", "t", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{"Join", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"eqRI", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", 
          RowBox[{"eqRE", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], "}"}], " ", "/.", " ", "rules"}],
        " ", ",", " ", 
       RowBox[{"{", 
        RowBox[{"a3", ",", " ", "b2"}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", " ", "rules"}], " ", "]"}], 
  " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a3", "\[Rule]", "0"}], ",", 
   RowBox[{"b2", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["RE", "3"], " ", "\[Alpha]", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"RE", "-", "RI"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["RE", "2"], "+", 
         RowBox[{"RE", " ", "RI"}], "+", 
         SuperscriptBox["RI", "2"]}], ")"}]}]]}]}], ",", 
   RowBox[{"a1", "\[Rule]", "0"}], ",", 
   RowBox[{"a2", "\[Rule]", "0"}], ",", 
   RowBox[{"b3", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["kinetically admissible field", "Subsection"],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", " ", "0", ",", " ", 
    RowBox[{"\[Alpha]", " ", 
     RowBox[{"f", "[", "r", "]"}], " ", "r", " ", 
     RowBox[{"Sin", "[", "t", "]"}]}]}], " ", "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"r", " ", "\[Alpha]", " ", 
    RowBox[{"f", "[", "r", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eps", " ", "=", " ", 
  RowBox[{
   RowBox[{"1", "/", "2"}], " ", 
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Grad", "[", "u", "]"}], "]"}]}], " ", 
    ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"sig", " ", "=", " ", 
  RowBox[{"2", " ", "\[Mu]", " ", "eps"}]}], "\[IndentingNewLine]", 
 RowBox[{"divsig", " ", "=", " ", 
  RowBox[{"Div", "[", " ", "sig", " ", "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      FractionBox["1", "2"], " ", "r", " ", "\[Alpha]", " ", 
      RowBox[{"Sin", "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", "r", " ", "\[Alpha]", " ", 
      RowBox[{"Sin", "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], ",", "0", ",", "0"}], 
    "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"r", " ", "\[Alpha]", " ", "\[Mu]", " ", 
      RowBox[{"Sin", "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", " ", "\[Alpha]", " ", "\[Mu]", " ", 
      RowBox[{"Sin", "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], ",", "0", ",", "0"}], 
    "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"4", " ", "\[Alpha]", " ", "\[Mu]", " ", 
     RowBox[{"Sin", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], "+", 
    RowBox[{"r", " ", "\[Alpha]", " ", "\[Mu]", " ", 
     RowBox[{"Sin", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fsol", " ", "=", 
  RowBox[{
   RowBox[{"DSolve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"divsig", "[", 
       RowBox[{"[", "3", "]"}], "]"}], " ", "\[Equal]", " ", "0"}], " ", ",", 
     " ", 
     RowBox[{"f", "[", "r", "]"}], ",", " ", "r"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(fsol\\)\
\\\" is similar to existing symbol \\\"\\!\\(sol\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f", "[", "r", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"C", "[", "1", "]"}], 
      RowBox[{"3", " ", 
       SuperscriptBox["r", "3"]}]]}], "+", 
    RowBox[{"C", "[", "2", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"csol", " ", "=", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", "r", "]"}], " ", "/.", " ", "fsol"}], " ", "/.", 
          " ", 
          RowBox[{"r", " ", "\[Rule]", " ", "RE"}]}], ")"}], " ", "\[Equal]", 
        " ", "1"}], ",", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", "r", "]"}], " ", "/.", " ", "fsol"}], " ", "/.", 
          " ", 
          RowBox[{"r", " ", "\[Rule]", " ", "RI"}]}], ")"}], " ", "\[Equal]", 
        " ", "0"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"C", "[", "1", "]"}], ",", " ", 
       RowBox[{"C", "[", "2", "]"}]}], "}"}]}], " ", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"3", " ", 
      SuperscriptBox["RE", "3"], " ", 
      SuperscriptBox["RI", "3"]}], 
     RowBox[{
      SuperscriptBox["RE", "3"], "-", 
      SuperscriptBox["RI", "3"]}]]}], ",", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], "\[Rule]", 
    FractionBox[
     SuperscriptBox["RE", "3"], 
     RowBox[{
      SuperscriptBox["RE", "3"], "-", 
      SuperscriptBox["RI", "3"]}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", " ", "0", ",", " ", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"f", "[", "r", "]"}], " ", "r", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}], " ", "}"}], " ", "/.", " ", 
    "fsol"}], " ", "/.", " ", "csol"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"r", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox["RE", "3"], 
       RowBox[{
        SuperscriptBox["RE", "3"], "-", 
        SuperscriptBox["RI", "3"]}]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["RE", "3"], " ", 
        SuperscriptBox["RI", "3"]}], 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["RE", "3"], "-", 
          SuperscriptBox["RI", "3"]}], ")"}]}]]}], ")"}], " ", "\[Alpha]", 
    " ", 
    RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eps", " ", "=", " ", 
  RowBox[{
   RowBox[{"1", "/", "2"}], " ", 
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Grad", "[", "u", "]"}], "]"}]}], " ", 
    ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"sig", " ", "=", " ", 
  RowBox[{"2", " ", "\[Mu]", " ", "eps"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox["RE", "3"], " ", 
       SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["r", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["RE", "3"], "-", 
         SuperscriptBox["RI", "3"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox["RE", "3"], " ", 
       SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["r", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["RE", "3"], "-", 
         SuperscriptBox["RI", "3"]}], ")"}]}]], ",", "0", ",", "0"}], "}"}]}],
   "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox["RE", "3"], " ", 
       SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", "\[Mu]", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{
       SuperscriptBox["r", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["RE", "3"], "-", 
         SuperscriptBox["RI", "3"]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox["RE", "3"], " ", 
       SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", "\[Mu]", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{
       SuperscriptBox["r", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["RE", "3"], "-", 
         SuperscriptBox["RI", "3"]}], ")"}]}]], ",", "0", ",", "0"}], "}"}]}],
   "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"traction", " ", "=", 
  RowBox[{
   RowBox[{"sig", "  ", ".", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "}"}]}], " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["RE", "3"], " ", 
     SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", "\[Mu]", " ", 
     RowBox[{"Sin", "[", "t", "]"}]}], 
    RowBox[{
     SuperscriptBox["r", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["RE", "3"], "-", 
       SuperscriptBox["RI", "3"]}], ")"}]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"moment", " ", "=", " ", 
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r", " ", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
    "traction"}], " ", "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", 
      SuperscriptBox["RE", "3"], " ", 
      SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", "\[Mu]", " ", 
      RowBox[{"Sin", "[", "t", "]"}]}], 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["RE", "3"], "-", 
        SuperscriptBox["RI", "3"]}], ")"}]}]]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mm", " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", " ", 
     RowBox[{"moment", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], " ", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"Sin", "[", "t", "]"}], " ", 
       RowBox[{"Cos", "[", "p", "]"}]}], ",", " ", 
      RowBox[{
       RowBox[{"Sin", "[", "t", "]"}], " ", 
       RowBox[{"Sin", "[", "p", "]"}]}], ",", " ", 
      RowBox[{"-", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}], " ", 
    RowBox[{"r", "^", "2"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], " ", "/.", " ", 
   RowBox[{"r", " ", "\[Rule]", " ", "RE"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["RE", "3"], " ", 
     SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", "\[Mu]", " ", 
     RowBox[{"Cos", "[", "p", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "t", "]"}], "3"]}], 
    RowBox[{
     SuperscriptBox["RE", "3"], "-", 
     SuperscriptBox["RI", "3"]}]], ",", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["RE", "3"], " ", 
     SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", "\[Mu]", " ", 
     RowBox[{"Sin", "[", "p", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "t", "]"}], "3"]}], 
    RowBox[{
     SuperscriptBox["RE", "3"], "-", 
     SuperscriptBox["RI", "3"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", 
      SuperscriptBox["RE", "3"], " ", 
      SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", "\[Mu]", " ", 
      RowBox[{"Cos", "[", "t", "]"}], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
     RowBox[{
      SuperscriptBox["RE", "3"], "-", 
      SuperscriptBox["RI", "3"]}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Integrate", "[", " ", 
   RowBox[{"mm", " ", ",", " ", 
    RowBox[{"{", 
     RowBox[{"p", ",", " ", "0", ",", " ", 
      RowBox[{"2", " ", "Pi"}]}], "}"}], " ", ",", " ", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", " ", 
      RowBox[{"Pi", "/", "2"}]}], "}"}]}], "]"}], "  "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   FractionBox[
    RowBox[{"2", " ", "\[Pi]", " ", 
     SuperscriptBox["RE", "3"], " ", 
     SuperscriptBox["RI", "3"], " ", "\[Alpha]", " ", "\[Mu]"}], 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["RE", "3"]}], "+", 
     SuperscriptBox["RI", "3"]}]]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{987, 821},
WindowMargins->{{Automatic, 68}, {Automatic, 0}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[1309, 36, 275, 9, 46, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1609, 49, 320, 9, 77, "Input"],
Cell[1932, 60, 72, 0, 31, "Output"]
}, Open  ]],
Cell[2019, 63, 111, 2, 77, "Input"],
Cell[CellGroupData[{
Cell[2155, 69, 255, 6, 55, "Input"],
Cell[2413, 77, 96, 2, 31, "Output"],
Cell[2512, 81, 335, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2884, 96, 49, 0, 39, "Subsection"],
Cell[2936, 98, 73, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[3034, 103, 531, 16, 55, "Input"],
Cell[3568, 121, 343, 12, 60, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3948, 138, 149, 4, 55, "Input"],
Cell[4100, 144, 425, 15, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4562, 164, 602, 17, 77, "Input"],
Cell[5167, 183, 57, 1, 31, "Output"],
Cell[5227, 186, 287, 9, 46, "Output"],
Cell[5517, 197, 161, 5, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5715, 207, 428, 13, 55, "Input"],
Cell[6146, 222, 100, 3, 47, "Output"],
Cell[6249, 227, 431, 15, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6717, 247, 691, 20, 55, "Input"],
Cell[7411, 269, 517, 17, 49, "Output"],
Cell[7931, 288, 2510, 70, 130, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10478, 363, 407, 9, 32, "Input"],
Cell[10888, 374, 363, 12, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11288, 391, 344, 8, 55, "Input"],
Cell[11635, 401, 157, 4, 31, "Output"],
Cell[11795, 407, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11915, 414, 225, 5, 32, "Input"],
Cell[12143, 421, 173, 5, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12353, 431, 415, 10, 32, "Input"],
Cell[12771, 443, 174, 4, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12982, 452, 93, 2, 32, "Input"],
Cell[13078, 456, 547, 17, 57, "Output"]
}, Open  ]],
Cell[13640, 476, 71, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[13736, 481, 157, 4, 32, "Input"],
Cell[13896, 487, 553, 18, 63, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14486, 510, 221, 6, 32, "Input"],
Cell[14710, 518, 386, 8, 24, "Message"],
Cell[15099, 528, 426, 13, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15562, 546, 200, 4, 55, "Input"],
Cell[15765, 552, 386, 8, 24, "Message"],
Cell[16154, 562, 1131, 35, 55, "Output"],
Cell[17288, 599, 386, 8, 24, "Message"],
Cell[17677, 609, 1123, 35, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18837, 649, 109, 2, 32, "Input"],
Cell[18949, 653, 260, 8, 31, "Output"]
}, Open  ]],
Cell[19224, 664, 66, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[19315, 669, 408, 11, 32, "Input"],
Cell[19726, 682, 535, 17, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20298, 704, 521, 14, 55, "Input"],
Cell[20822, 720, 526, 16, 49, "Output"],
Cell[21351, 738, 385, 7, 24, "Message"],
Cell[21739, 747, 602, 18, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22378, 770, 416, 10, 77, "Input"],
Cell[22797, 782, 176, 5, 31, "Output"],
Cell[22976, 789, 415, 12, 49, "Output"],
Cell[23394, 803, 491, 14, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23922, 822, 592, 18, 32, "Input"],
Cell[24517, 842, 660, 20, 55, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[25226, 868, 50, 0, 39, "Subsection"],
Cell[25279, 870, 73, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[25377, 875, 247, 6, 32, "Input"],
Cell[25627, 883, 196, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25860, 893, 500, 13, 77, "Input"],
Cell[26363, 908, 711, 21, 46, "Output"],
Cell[27077, 931, 669, 19, 31, "Output"],
Cell[27749, 952, 509, 13, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28295, 970, 343, 10, 32, "Input"],
Cell[28641, 982, 386, 8, 24, "Message"],
Cell[29030, 992, 294, 10, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29361, 1007, 894, 27, 32, "Input"],
Cell[30258, 1036, 529, 18, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30824, 1059, 337, 9, 32, "Input"],
Cell[31164, 1070, 665, 22, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31866, 1097, 393, 11, 55, "Input"],
Cell[32262, 1110, 1003, 31, 55, "Output"],
Cell[33268, 1143, 1011, 31, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34316, 1179, 187, 5, 32, "Input"],
Cell[34506, 1186, 435, 13, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34978, 1204, 223, 6, 32, "Input"],
Cell[35204, 1212, 465, 14, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35706, 1231, 651, 19, 32, "Input"],
Cell[36360, 1252, 1129, 33, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37526, 1290, 334, 9, 32, "Input"],
Cell[37863, 1301, 344, 10, 49, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

