(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    761542,      37772]
NotebookOptionsPosition[    757160,      37628]
NotebookOutlinePosition[    757603,      37646]
CellTagsIndexPosition[    757560,      37643]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{"Estimation", " ", "the", " ", "torsional", " ", "stiffness"}], 
     " ", "-", " ", 
     RowBox[{"Triangluar", " ", "cross", " ", "section"}]}]}], "Subtitle"], 
  TraditionalForm]], "Input",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
    "]"}], "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\n", 
 RowBox[{"<<", "Displacement.m"}], "\n"}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SetCoordinates", "[", 
   RowBox[{"Cartesian", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], "\n"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Statically admissible field", "Subsection"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "\"\<Global`u*\>\"", ",", "\"\<Global`eps*\>\"", ",", "\"\<Global`sig*\>\"",
    ",", "\"\<Global`Psi*\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Psi", "[", 
   RowBox[{"x", ",", "y"}], "]"}], " ", ":=", " ", 
  RowBox[{"c", " ", 
   RowBox[{"(", " ", 
    RowBox[{"a", " ", "-", " ", "x"}], ")"}], " ", 
   RowBox[{"(", " ", 
    RowBox[{"x", " ", "-", " ", 
     RowBox[{"y", " ", 
      RowBox[{"Sqrt", "[", "3", "]"}]}], " ", "+", " ", 
     RowBox[{"2", " ", "a"}]}], ")"}], 
   RowBox[{"(", " ", 
    RowBox[{"x", " ", "+", " ", 
     RowBox[{"y", " ", 
      RowBox[{"Sqrt", "[", "3", "]"}]}], " ", "+", " ", 
     RowBox[{"2", " ", "a"}]}], ")"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"sig", " ", ":=", " ", 
    RowBox[{
     RowBox[{"Curl", "[", " ", 
      RowBox[{"\[Alpha]", " ", "\[Mu]", " ", 
       RowBox[{"Psi", "[", 
        RowBox[{"x", ",", "y"}], "]"}], " ", 
       RowBox[{"Outer", "[", 
        RowBox[{"Times", ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], " ", "]"}]}], " ", 
      "]"}], " ", "+", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{"\[Alpha]", " ", "\[Mu]", " ", 
       RowBox[{"Curl", "[", " ", 
        RowBox[{
         RowBox[{"Psi", "[", 
          RowBox[{"x", ",", "y"}], "]"}], " ", 
         RowBox[{"Outer", "[", 
          RowBox[{"Times", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], " ", "]"}]}], " ", 
        "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"sig", "  ", "//", " ", "MatrixForm"}], 
   "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "c", " ", 
        RowBox[{"(", 
         RowBox[{"a", "-", "x"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a"}], "+", "x", "-", 
          RowBox[{
           SqrtBox["3"], " ", "y"}]}], ")"}], " ", "\[Alpha]", " ", "\[Mu]"}],
        "-", 
       RowBox[{
        SqrtBox["3"], " ", "c", " ", 
        RowBox[{"(", 
         RowBox[{"a", "-", "x"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a"}], "+", "x", "+", 
          RowBox[{
           SqrtBox["3"], " ", "y"}]}], ")"}], " ", "\[Alpha]", " ", 
        "\[Mu]"}]}]},
     {"0", "0", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "c"}], " ", 
        RowBox[{"(", 
         RowBox[{"a", "-", "x"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a"}], "+", "x", "-", 
          RowBox[{
           SqrtBox["3"], " ", "y"}]}], ")"}], " ", "\[Alpha]", " ", "\[Mu]"}],
        "-", 
       RowBox[{"c", " ", 
        RowBox[{"(", 
         RowBox[{"a", "-", "x"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a"}], "+", "x", "+", 
          RowBox[{
           SqrtBox["3"], " ", "y"}]}], ")"}], " ", "\[Alpha]", " ", "\[Mu]"}],
        "+", 
       RowBox[{"c", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a"}], "+", "x", "-", 
          RowBox[{
           SqrtBox["3"], " ", "y"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "a"}], "+", "x", "+", 
          RowBox[{
           SqrtBox["3"], " ", "y"}]}], ")"}], " ", "\[Alpha]", " ", 
        "\[Mu]"}]}]},
     {
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SqrtBox["3"], " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "x"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", "x", "-", 
            RowBox[{
             SqrtBox["3"], " ", "y"}]}], ")"}]}], "-", 
         RowBox[{
          SqrtBox["3"], " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "x"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", "x", "+", 
            RowBox[{
             SqrtBox["3"], " ", "y"}]}], ")"}]}]}], ")"}], " ", "\[Alpha]", 
       " ", "\[Mu]"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "c"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "x"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", "x", "-", 
            RowBox[{
             SqrtBox["3"], " ", "y"}]}], ")"}]}], "-", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "x"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", "x", "+", 
            RowBox[{
             SqrtBox["3"], " ", "y"}]}], ")"}]}], "+", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", "x", "-", 
            RowBox[{
             SqrtBox["3"], " ", "y"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", "x", "+", 
            RowBox[{
             SqrtBox["3"], " ", "y"}]}], ")"}]}]}], ")"}], " ", "\[Alpha]", 
       " ", "\[Mu]"}], "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{"Div", "[", " ", "sig", " ", "]"}], " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", " ", 
  RowBox[{"-", " ", 
   RowBox[{"Grad", "[", 
    RowBox[{"a", " ", "-", " ", "x"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sig", " ", ".", " ", "normal"}], " ", "/.", " ", 
  RowBox[{"x", " ", "\[Rule]", " ", "a"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(normal\\)\\\" is similar to existing symbol \
\\\"\\!\\(Normal\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", " ", 
  RowBox[{"-", " ", 
   RowBox[{"Grad", "[", "  ", 
    RowBox[{"(", " ", 
     RowBox[{"x", " ", "-", " ", 
      RowBox[{"y", " ", 
       RowBox[{"Sqrt", "[", "3", "]"}]}], " ", "+", " ", 
      RowBox[{"2", " ", "a"}]}], ")"}], " ", 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sig", " ", ".", " ", "normal"}], " ", "/.", " ", 
  RowBox[{"x", " ", "\[Rule]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"y", " ", 
      RowBox[{"Sqrt", "[", "3", "]"}]}], " ", "-", " ", 
     RowBox[{"2", " ", "a"}]}], ")"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1"}], ",", 
   SqrtBox["3"], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"normal", " ", "=", " ", 
  RowBox[{"-", " ", 
   RowBox[{"Grad", "[", "  ", 
    RowBox[{"(", " ", 
     RowBox[{"x", " ", "+", " ", 
      RowBox[{"y", " ", 
       RowBox[{"Sqrt", "[", "3", "]"}]}], " ", "+", " ", 
      RowBox[{"2", " ", "a"}]}], ")"}], " ", 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sig", " ", ".", "  ", "normal"}], " ", "/.", " ", 
  RowBox[{"x", " ", "\[Rule]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", "y"}], " ", 
      RowBox[{"Sqrt", "[", "3", "]"}]}], " ", "-", " ", 
     RowBox[{"2", " ", "a"}]}], ")"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", 
    SqrtBox["3"]}], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"eps", " ", "=", " ", 
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", "\[Mu]"}], ")"}]}], " ", "sig"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"eps", " ", "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{"Wint", " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", " ", "1"}], "/", "2"}], " ", "L", " ", 
   RowBox[{"Integrate", "[", " ", 
    RowBox[{
     RowBox[{"Integrate", "[", "  ", 
      RowBox[{
       RowBox[{"Tr", "[", " ", 
        RowBox[{"eps", " ", ".", " ", "sig"}], " ", "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"y", ",", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"-", " ", 
            RowBox[{"Sqrt", "[", "3", "]"}]}], "/", "3"}], 
          RowBox[{"(", " ", 
           RowBox[{
            RowBox[{"2", " ", "a"}], " ", "+", " ", "x"}], ")"}]}], ",", " ", 
         
         RowBox[{
          RowBox[{
           RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}], 
          RowBox[{"(", " ", 
           RowBox[{
            RowBox[{"2", " ", "a"}], " ", "+", " ", "x"}], ")"}]}]}], "}"}]}],
       "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], " ", ",", " ", "a"}], "}"}]}], "]"}], 
   " "}]}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{
         SqrtBox["3"], " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", "x"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a"}], "+", "x", "-", 
           RowBox[{
            SqrtBox["3"], " ", "y"}]}], ")"}], " ", "\[Alpha]", " ", 
         "\[Mu]"}], "-", 
        RowBox[{
         SqrtBox["3"], " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", "x"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a"}], "+", "x", "+", 
           RowBox[{
            SqrtBox["3"], " ", "y"}]}], ")"}], " ", "\[Alpha]", " ", 
         "\[Mu]"}]}], 
       RowBox[{"2", " ", "\[Mu]"}]]},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "c"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", "x"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a"}], "+", "x", "-", 
           RowBox[{
            SqrtBox["3"], " ", "y"}]}], ")"}], " ", "\[Alpha]", " ", 
         "\[Mu]"}], "-", 
        RowBox[{"c", " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", "x"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a"}], "+", "x", "+", 
           RowBox[{
            SqrtBox["3"], " ", "y"}]}], ")"}], " ", "\[Alpha]", " ", 
         "\[Mu]"}], "+", 
        RowBox[{"c", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a"}], "+", "x", "-", 
           RowBox[{
            SqrtBox["3"], " ", "y"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a"}], "+", "x", "+", 
           RowBox[{
            SqrtBox["3"], " ", "y"}]}], ")"}], " ", "\[Alpha]", " ", 
         "\[Mu]"}]}], 
       RowBox[{"2", " ", "\[Mu]"}]]},
     {
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SqrtBox["3"], " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "x"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", "x", "-", 
            RowBox[{
             SqrtBox["3"], " ", "y"}]}], ")"}]}], "-", 
         RowBox[{
          SqrtBox["3"], " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "x"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", "x", "+", 
            RowBox[{
             SqrtBox["3"], " ", "y"}]}], ")"}]}]}], ")"}], " ", "\[Alpha]"}], 
      
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "c"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "x"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", "x", "-", 
            RowBox[{
             SqrtBox["3"], " ", "y"}]}], ")"}]}], "-", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "x"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", "x", "+", 
            RowBox[{
             SqrtBox["3"], " ", "y"}]}], ")"}]}], "+", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", "x", "-", 
            RowBox[{
             SqrtBox["3"], " ", "y"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", "x", "+", 
            RowBox[{
             SqrtBox["3"], " ", "y"}]}], ")"}]}]}], ")"}], " ", "\[Alpha]"}], 
      "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["162", "5"]}], " ", 
  SqrtBox["3"], " ", 
  SuperscriptBox["a", "6"], " ", 
  SuperscriptBox["c", "2"], " ", "L", " ", 
  SuperscriptBox["\[Alpha]", "2"], " ", "\[Mu]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Wend", " ", "=", " ", 
  RowBox[{
   RowBox[{"+", " ", 
    RowBox[{"Integrate", "[", " ", 
     RowBox[{
      RowBox[{"Integrate", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", " ", "\[Alpha]"}], "  ", "y"}], " ", ",", " ", 
           RowBox[{
            RowBox[{"+", " ", "\[Alpha]"}], "  ", "x"}], ",", " ", "0"}], 
          "}"}], " ", ".", " ", "sig", " ", ".", " ", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"y", ",", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"-", " ", 
             RowBox[{"Sqrt", "[", "3", "]"}]}], "/", "3"}], 
           RowBox[{"(", " ", 
            RowBox[{
             RowBox[{"2", " ", "a"}], " ", "+", " ", "x"}], ")"}]}], ",", " ",
           
          RowBox[{
           RowBox[{
            RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}], 
           RowBox[{"(", " ", 
            RowBox[{
             RowBox[{"2", " ", "a"}], " ", "+", " ", "x"}], ")"}]}]}], 
         "}"}]}], "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"x", ",", " ", 
        RowBox[{
         RowBox[{"-", "2"}], " ", "a"}], " ", ",", " ", "a"}], "}"}]}], 
     "]"}]}], " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["54", "5"], " ", 
  SqrtBox["3"], " ", 
  SuperscriptBox["a", "5"], " ", "c", " ", 
  SuperscriptBox["\[Alpha]", "2"], " ", "\[Mu]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"W", " ", "=", " ", 
  RowBox[{"Wint", " ", "+", " ", "Wend"}]}], "\[IndentingNewLine]", 
 RowBox[{"wsol", " ", "=", " ", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{"W", ",", " ", "c"}], "]"}], " ", "\[Equal]", " ", "0"}], " ", 
     ",", " ", "c"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Wstress", " ", "=", " ", 
  RowBox[{"W", " ", "/.", " ", "wsol", "  "}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["54", "5"], " ", 
   SqrtBox["3"], " ", 
   SuperscriptBox["a", "5"], " ", "c", " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", "\[Mu]"}], "-", 
  RowBox[{
   FractionBox["162", "5"], " ", 
   SqrtBox["3"], " ", 
   SuperscriptBox["a", "6"], " ", 
   SuperscriptBox["c", "2"], " ", "L", " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", "\[Mu]"}]}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"c", "\[Rule]", 
   FractionBox["1", 
    RowBox[{"6", " ", "a", " ", "L"}]]}], "}"}]], "Output"],

Cell[BoxData[
 FractionBox[
  RowBox[{"9", " ", 
   SqrtBox["3"], " ", 
   SuperscriptBox["a", "4"], " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", "\[Mu]"}], 
  RowBox[{"10", " ", "L"}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Inc", "[", " ", "eps", " ", "]"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "IntegrateStrain.m"}], "\[IndentingNewLine]", 
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"IntegrateStrain", "[", "eps", "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "6"}], " ", "a", " ", "c", " ", "y", " ", "z", " ", 
    "\[Alpha]"}], ",", 
   RowBox[{"6", " ", "a", " ", "c", " ", "x", " ", "z", " ", "\[Alpha]"}], 
   ",", 
   RowBox[{
    RowBox[{"3", " ", "c", " ", 
     SuperscriptBox["x", "2"], " ", "y", " ", "\[Alpha]"}], "-", 
    RowBox[{"c", " ", 
     SuperscriptBox["y", "3"], " ", "\[Alpha]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", "/.", " ", 
       RowBox[{"z", " ", "\[Rule]", " ", "L"}]}], " ", ")"}], "\[Equal]", " ",
      
     RowBox[{
      RowBox[{"-", " ", "\[Alpha]"}], " ", "y"}]}], " ", ",", " ", "c"}], 
   "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"c", "\[Rule]", 
   FractionBox["1", 
    RowBox[{"6", " ", "a", " ", "L"}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"u3", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"[", "3", "]"}], "]"}], " ", "/.", " ", "wsol"}], " ", "/.", 
     " ", 
     RowBox[{"a", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
    RowBox[{"L", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
   RowBox[{"\[Alpha]", " ", "\[Rule]", " ", 
    RowBox[{"5.", " ", 
     RowBox[{"Pi", " ", "/", " ", "180."}]}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"uu3", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", " ", "u3"}], "  ", "}"}], " ", "/.", " ", 
    RowBox[{"y", " ", "\[Rule]", " ", 
     RowBox[{"(", " ", 
      RowBox[{"yy", " ", 
       RowBox[{
        RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}], 
       RowBox[{"(", " ", 
        RowBox[{"2", "  ", "+", " ", "x"}], ")"}]}], ")"}]}]}], " ", "/.", 
   " ", 
   RowBox[{"x", " ", "\[Rule]", " ", "xx"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.04363323129985824`", " ", 
   SuperscriptBox["x", "2"], " ", "y"}], "-", 
  RowBox[{"0.014544410433286078`", " ", 
   SuperscriptBox["y", "3"]}]}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"xx", ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", "xx"}], ")"}], " ", "yy"}], 
    SqrtBox["3"]], ",", 
   RowBox[{
    RowBox[{"0.025191657836586355`", " ", 
     SuperscriptBox["xx", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", "xx"}], ")"}], " ", "yy"}], "-", 
    RowBox[{"0.002799073092954039`", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "+", "xx"}], ")"}], "3"], " ", 
     SuperscriptBox["yy", "3"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "Graphics`PlotField`"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["sig"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       SqrtBox["3"], " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "x"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a"}], "+", "x", "-", 
         RowBox[{
          SqrtBox["3"], " ", "y"}]}], ")"}], " ", "\[Alpha]", " ", "\[Mu]"}], 
      "-", 
      RowBox[{
       SqrtBox["3"], " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "x"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a"}], "+", "x", "+", 
         RowBox[{
          SqrtBox["3"], " ", "y"}]}], ")"}], " ", "\[Alpha]", " ", 
       "\[Mu]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "c"}], " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "x"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a"}], "+", "x", "-", 
         RowBox[{
          SqrtBox["3"], " ", "y"}]}], ")"}], " ", "\[Alpha]", " ", "\[Mu]"}], 
      "-", 
      RowBox[{"c", " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "x"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a"}], "+", "x", "+", 
         RowBox[{
          SqrtBox["3"], " ", "y"}]}], ")"}], " ", "\[Alpha]", " ", "\[Mu]"}], 
      "+", 
      RowBox[{"c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a"}], "+", "x", "-", 
         RowBox[{
          SqrtBox["3"], " ", "y"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a"}], "+", "x", "+", 
         RowBox[{
          SqrtBox["3"], " ", "y"}]}], ")"}], " ", "\[Alpha]", " ", 
       "\[Mu]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SqrtBox["3"], " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", "x"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a"}], "+", "x", "-", 
           RowBox[{
            SqrtBox["3"], " ", "y"}]}], ")"}]}], "-", 
        RowBox[{
         SqrtBox["3"], " ", "c", " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", "x"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a"}], "+", "x", "+", 
           RowBox[{
            SqrtBox["3"], " ", "y"}]}], ")"}]}]}], ")"}], " ", "\[Alpha]", 
      " ", "\[Mu]"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "c"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", "x"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a"}], "+", "x", "-", 
           RowBox[{
            SqrtBox["3"], " ", "y"}]}], ")"}]}], "-", 
        RowBox[{"c", " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", "x"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a"}], "+", "x", "+", 
           RowBox[{
            SqrtBox["3"], " ", "y"}]}], ")"}]}], "+", 
        RowBox[{"c", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a"}], "+", "x", "-", 
           RowBox[{
            SqrtBox["3"], " ", "y"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "a"}], "+", "x", "+", 
           RowBox[{
            SqrtBox["3"], " ", "y"}]}], ")"}]}]}], ")"}], " ", "\[Alpha]", 
      " ", "\[Mu]"}], ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"traction", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"sig", " ", ".", " ", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], " ", "/.", " ", 
        "wsol"}], " ", "/.", " ", 
       RowBox[{"z", " ", "\[Rule]", " ", "L"}]}], " ", "/.", " ", 
      RowBox[{"a", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
     RowBox[{"L", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
    RowBox[{"\[Alpha]", " ", "\[Rule]", " ", 
     RowBox[{"5.", " ", 
      RowBox[{"Pi", " ", "/", " ", "180."}]}]}]}], "  ", "/.", " ", 
   RowBox[{"\[Mu]", " ", "\[Rule]", " ", "1."}]}]}], "\[IndentingNewLine]", 
 RowBox[{"tractionplot", " ", "=", " ", 
  RowBox[{"PlotVectorField", "[", 
   RowBox[{
    RowBox[{"Drop", "[", " ", 
     RowBox[{"traction", ",", " ", 
      RowBox[{"-", "1"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "2"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       RowBox[{"Sqrt", "[", "3", "]"}]}], ",", 
      RowBox[{"Sqrt", "[", "3", "]"}]}], "}"}], ",", " ", 
    RowBox[{"PlotPoints", "\[Rule]", " ", "8"}], ",", " ", 
    RowBox[{"Frame", " ", "\[Rule]", " ", "True"}], ",", 
    RowBox[{"ScaleFunction", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"5.9", "#"}], "&"}], ")"}]}], ",", " ", 
    RowBox[{"ScaleFactor", "\[Rule]", "None"}]}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"0.025191657836586355`", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", "x", "-", 
       RowBox[{
        SqrtBox["3"], " ", "y"}]}], ")"}]}], "-", 
    RowBox[{"0.025191657836586355`", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", "x", "+", 
       RowBox[{
        SqrtBox["3"], " ", "y"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "0.014544410433286078`"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", "x", "-", 
       RowBox[{
        SqrtBox["3"], " ", "y"}]}], ")"}]}], "-", 
    RowBox[{"0.014544410433286078`", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", "x", "+", 
       RowBox[{
        SqrtBox["3"], " ", "y"}]}], ")"}]}], "+", 
    RowBox[{"0.014544410433286078`", " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", "x", "-", 
       RowBox[{
        SqrtBox["3"], " ", "y"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", "x", "+", 
       RowBox[{
        SqrtBox["3"], " ", "y"}]}], ")"}]}]}], ",", "0"}], "}"}]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .79089 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.808381 0.16781 0.481406 0.16781 [
[.13714 -0.0125 -6 -9 ]
[.13714 -0.0125 6 0 ]
[.30495 -0.0125 -6 -9 ]
[.30495 -0.0125 6 0 ]
[.47276 -0.0125 -6 -9 ]
[.47276 -0.0125 6 0 ]
[.64057 -0.0125 -6 -9 ]
[.64057 -0.0125 6 0 ]
[.80838 -0.0125 -3 -9 ]
[.80838 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14579 -12 -4.5 ]
[-0.0125 .14579 0 4.5 ]
[-0.0125 .3136 -12 -4.5 ]
[-0.0125 .3136 0 4.5 ]
[-0.0125 .48141 -6 -4.5 ]
[-0.0125 .48141 0 4.5 ]
[-0.0125 .64922 -6 -4.5 ]
[-0.0125 .64922 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .79089 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .79089 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13714 0 m
.13714 .00625 L
s
[(-4)] .13714 -0.0125 0 1 Mshowa
.30495 0 m
.30495 .00625 L
s
[(-3)] .30495 -0.0125 0 1 Mshowa
.47276 0 m
.47276 .00625 L
s
[(-2)] .47276 -0.0125 0 1 Mshowa
.64057 0 m
.64057 .00625 L
s
[(-1)] .64057 -0.0125 0 1 Mshowa
.80838 0 m
.80838 .00625 L
s
[(0)] .80838 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.1707 0 m
.1707 .00375 L
s
.20426 0 m
.20426 .00375 L
s
.23783 0 m
.23783 .00375 L
s
.27139 0 m
.27139 .00375 L
s
.33851 0 m
.33851 .00375 L
s
.37207 0 m
.37207 .00375 L
s
.40564 0 m
.40564 .00375 L
s
.4392 0 m
.4392 .00375 L
s
.50632 0 m
.50632 .00375 L
s
.53988 0 m
.53988 .00375 L
s
.57345 0 m
.57345 .00375 L
s
.60701 0 m
.60701 .00375 L
s
.67413 0 m
.67413 .00375 L
s
.70769 0 m
.70769 .00375 L
s
.74126 0 m
.74126 .00375 L
s
.77482 0 m
.77482 .00375 L
s
.84194 0 m
.84194 .00375 L
s
.8755 0 m
.8755 .00375 L
s
.90907 0 m
.90907 .00375 L
s
.94263 0 m
.94263 .00375 L
s
.10358 0 m
.10358 .00375 L
s
.07002 0 m
.07002 .00375 L
s
.03645 0 m
.03645 .00375 L
s
.00289 0 m
.00289 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14579 m
.00625 .14579 L
s
[(-2)] -0.0125 .14579 1 0 Mshowa
0 .3136 m
.00625 .3136 L
s
[(-1)] -0.0125 .3136 1 0 Mshowa
0 .48141 m
.00625 .48141 L
s
[(0)] -0.0125 .48141 1 0 Mshowa
0 .64922 m
.00625 .64922 L
s
[(1)] -0.0125 .64922 1 0 Mshowa
.125 Mabswid
0 .17935 m
.00375 .17935 L
s
0 .21291 m
.00375 .21291 L
s
0 .24647 m
.00375 .24647 L
s
0 .28003 m
.00375 .28003 L
s
0 .34716 m
.00375 .34716 L
s
0 .38072 m
.00375 .38072 L
s
0 .41428 m
.00375 .41428 L
s
0 .44784 m
.00375 .44784 L
s
0 .51497 m
.00375 .51497 L
s
0 .54853 m
.00375 .54853 L
s
0 .58209 m
.00375 .58209 L
s
0 .61565 m
.00375 .61565 L
s
0 .11222 m
.00375 .11222 L
s
0 .07866 m
.00375 .07866 L
s
0 .0451 m
.00375 .0451 L
s
0 .01154 m
.00375 .01154 L
s
0 .68278 m
.00375 .68278 L
s
0 .71634 m
.00375 .71634 L
s
0 .7499 m
.00375 .7499 L
s
0 .78346 m
.00375 .78346 L
s
.25 Mabswid
0 0 m
0 .79089 L
s
.13714 .78464 m
.13714 .79089 L
s
.30495 .78464 m
.30495 .79089 L
s
.47276 .78464 m
.47276 .79089 L
s
.64057 .78464 m
.64057 .79089 L
s
.80838 .78464 m
.80838 .79089 L
s
.97619 .78464 m
.97619 .79089 L
s
.125 Mabswid
.1707 .78714 m
.1707 .79089 L
s
.20426 .78714 m
.20426 .79089 L
s
.23783 .78714 m
.23783 .79089 L
s
.27139 .78714 m
.27139 .79089 L
s
.33851 .78714 m
.33851 .79089 L
s
.37207 .78714 m
.37207 .79089 L
s
.40564 .78714 m
.40564 .79089 L
s
.4392 .78714 m
.4392 .79089 L
s
.50632 .78714 m
.50632 .79089 L
s
.53988 .78714 m
.53988 .79089 L
s
.57345 .78714 m
.57345 .79089 L
s
.60701 .78714 m
.60701 .79089 L
s
.67413 .78714 m
.67413 .79089 L
s
.70769 .78714 m
.70769 .79089 L
s
.74126 .78714 m
.74126 .79089 L
s
.77482 .78714 m
.77482 .79089 L
s
.84194 .78714 m
.84194 .79089 L
s
.8755 .78714 m
.8755 .79089 L
s
.90907 .78714 m
.90907 .79089 L
s
.94263 .78714 m
.94263 .79089 L
s
.10358 .78714 m
.10358 .79089 L
s
.07002 .78714 m
.07002 .79089 L
s
.03645 .78714 m
.03645 .79089 L
s
.00289 .78714 m
.00289 .79089 L
s
.25 Mabswid
0 .79089 m
1 .79089 L
s
.99375 .14579 m
1 .14579 L
s
.99375 .3136 m
1 .3136 L
s
.99375 .48141 m
1 .48141 L
s
.99375 .64922 m
1 .64922 L
s
.125 Mabswid
.99625 .17935 m
1 .17935 L
s
.99625 .21291 m
1 .21291 L
s
.99625 .24647 m
1 .24647 L
s
.99625 .28003 m
1 .28003 L
s
.99625 .34716 m
1 .34716 L
s
.99625 .38072 m
1 .38072 L
s
.99625 .41428 m
1 .41428 L
s
.99625 .44784 m
1 .44784 L
s
.99625 .51497 m
1 .51497 L
s
.99625 .54853 m
1 .54853 L
s
.99625 .58209 m
1 .58209 L
s
.99625 .61565 m
1 .61565 L
s
.99625 .11222 m
1 .11222 L
s
.99625 .07866 m
1 .07866 L
s
.99625 .0451 m
1 .0451 L
s
.99625 .01154 m
1 .01154 L
s
.99625 .68278 m
1 .68278 L
s
.99625 .71634 m
1 .71634 L
s
.99625 .7499 m
1 .7499 L
s
.99625 .78346 m
1 .78346 L
s
.25 Mabswid
1 0 m
1 .79089 L
s
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.47276 .19075 m
.92171 .06115 L
s
% Start of user PostScript
-2. -1.73205 0.675354 -2.50436 MAarrowhead1
% End of user PostScript
.47276 .27379 m
.79344 .20767 L
s
% Start of user PostScript
-2. -1.23718 -0.0890328 -1.63121 MAarrowhead1
% End of user PostScript
.47276 .35684 m
.66517 .33303 L
s
% Start of user PostScript
-2. -0.742307 -0.85342 -0.88416 MAarrowhead1
% End of user PostScript
.47276 .43988 m
.5369 .43724 L
s
% Start of user PostScript
-2. -0.247436 -1.61781 -0.263197 MAarrowhead1
% End of user PostScript
.47276 .52293 m
.40862 .52028 L
s
% Start of user PostScript
-2. 0.247436 -2.38219 0.231674 MAarrowhead1
% End of user PostScript
.47276 .60597 m
.28035 .58217 L
s
% Start of user PostScript
-2. 0.742307 -3.14658 0.600455 MAarrowhead1
% End of user PostScript
.47276 .68902 m
.15208 .62289 L
s
% Start of user PostScript
-2. 1.23718 -3.91097 0.843144 MAarrowhead1
% End of user PostScript
.47276 .77206 m
.02381 .64246 L
s
% Start of user PostScript
-2. 1.73205 -4.67535 0.959743 MAarrowhead1
% End of user PostScript
.54468 .19075 m
.92949 .03206 L
s
% Start of user PostScript
-1.57143 -1.73205 0.721732 -2.67773 MAarrowhead1
% End of user PostScript
.54468 .27379 m
.81955 .17858 L
s
% Start of user PostScript
-1.57143 -1.23718 0.0665433 -1.80459 MAarrowhead1
% End of user PostScript
.54468 .35684 m
.7096 .30394 L
s
% Start of user PostScript
-1.57143 -0.742307 -0.588645 -1.05754 MAarrowhead1
% End of user PostScript
.54468 .43988 m
.59965 .40814 L
s
% Start of user PostScript
-1.57143 -0.247436 -1.24383 -0.436573 MAarrowhead1
% End of user PostScript
.54468 .52293 m
.48971 .49119 L
s
% Start of user PostScript
-1.57143 0.247436 -1.89902 0.0582991 MAarrowhead1
% End of user PostScript
.54468 .60597 m
.37976 .55307 L
s
% Start of user PostScript
-1.57143 0.742307 -2.55421 0.42708 MAarrowhead1
% End of user PostScript
.54468 .68902 m
.26981 .5938 L
s
% Start of user PostScript
-1.57143 1.23718 -3.2094 0.669769 MAarrowhead1
% End of user PostScript
.54468 .77206 m
.15986 .61337 L
s
% Start of user PostScript
-1.57143 1.73205 -3.86459 0.786367 MAarrowhead1
% End of user PostScript
.6166 .19075 m
.93728 .01883 L
s
% Start of user PostScript
-1.14286 -1.73205 0.76811 -2.75654 MAarrowhead1
% End of user PostScript
.6166 .27379 m
.84565 .16535 L
s
% Start of user PostScript
-1.14286 -1.23718 0.222119 -1.8834 MAarrowhead1
% End of user PostScript
.6166 .35684 m
.75403 .29072 L
s
% Start of user PostScript
-1.14286 -0.742307 -0.323871 -1.13634 MAarrowhead1
% End of user PostScript
.6166 .43988 m
.66241 .39492 L
s
% Start of user PostScript
-1.14286 -0.247436 -0.869862 -0.515379 MAarrowhead1
% End of user PostScript
.6166 .52293 m
.57079 .47796 L
s
% Start of user PostScript
-1.14286 0.247436 -1.41585 -0.0205078 MAarrowhead1
% End of user PostScript
.6166 .60597 m
.47916 .53985 L
s
% Start of user PostScript
-1.14286 0.742307 -1.96184 0.348273 MAarrowhead1
% End of user PostScript
.6166 .68902 m
.38754 .58058 L
s
% Start of user PostScript
-1.14286 1.23718 -2.50783 0.590962 MAarrowhead1
% End of user PostScript
.6166 .77206 m
.29592 .60014 L
s
% Start of user PostScript
-1.14286 1.73205 -3.05382 0.70756 MAarrowhead1
% End of user PostScript
.68852 .19075 m
.94506 .02148 L
s
% Start of user PostScript
-0.714286 -1.73205 0.814488 -2.74078 MAarrowhead1
% End of user PostScript
.68852 .27379 m
.87176 .168 L
s
% Start of user PostScript
-0.714286 -1.23718 0.377696 -1.86763 MAarrowhead1
% End of user PostScript
.68852 .35684 m
.79846 .29336 L
s
% Start of user PostScript
-0.714286 -0.742307 -0.059097 -1.12058 MAarrowhead1
% End of user PostScript
.68852 .43988 m
.72517 .39756 L
s
% Start of user PostScript
-0.714286 -0.247436 -0.495889 -0.499618 MAarrowhead1
% End of user PostScript
.68852 .52293 m
.65187 .48061 L
s
% Start of user PostScript
-0.714286 0.247436 -0.932682 -0.00474644 MAarrowhead1
% End of user PostScript
.68852 .60597 m
.57857 .54249 L
s
% Start of user PostScript
-0.714286 0.742307 -1.36947 0.364034 MAarrowhead1
% End of user PostScript
.68852 .68902 m
.50527 .58322 L
s
% Start of user PostScript
-0.714286 1.23718 -1.80627 0.606723 MAarrowhead1
% End of user PostScript
.68852 .77206 m
.43197 .60279 L
s
% Start of user PostScript
-0.714286 1.73205 -2.24306 0.723322 MAarrowhead1
% End of user PostScript
.76043 .19075 m
.95284 .03999 L
s
% Start of user PostScript
-0.285714 -1.73205 0.860866 -2.63045 MAarrowhead1
% End of user PostScript
.76043 .27379 m
.89787 .18651 L
s
% Start of user PostScript
-0.285714 -1.23718 0.533272 -1.75731 MAarrowhead1
% End of user PostScript
.76043 .35684 m
.8429 .31188 L
s
% Start of user PostScript
-0.285714 -0.742307 0.205677 -1.01025 MAarrowhead1
% End of user PostScript
.76043 .43988 m
.78792 .41608 L
s
% Start of user PostScript
-0.285714 -0.247436 -0.121917 -0.389288 MAarrowhead1
% End of user PostScript
.76043 .52293 m
.73295 .49912 L
s
% Start of user PostScript
-0.285714 0.247436 -0.449511 0.105583 MAarrowhead1
% End of user PostScript
.76043 .60597 m
.67797 .56101 L
s
% Start of user PostScript
-0.285714 0.742307 -0.777106 0.474364 MAarrowhead1
% End of user PostScript
.76043 .68902 m
.623 .60173 L
s
% Start of user PostScript
-0.285714 1.23718 -1.1047 0.717053 MAarrowhead1
% End of user PostScript
.76043 .77206 m
.56803 .6213 L
s
% Start of user PostScript
-0.285714 1.73205 -1.43229 0.833651 MAarrowhead1
% End of user PostScript
.83235 .19075 m
.96063 .07437 L
s
% Start of user PostScript
0.142857 -1.73205 0.907244 -2.42555 MAarrowhead1
% End of user PostScript
.83235 .27379 m
.92398 .2209 L
s
% Start of user PostScript
0.142857 -1.23718 0.688848 -1.55241 MAarrowhead1
% End of user PostScript
.83235 .35684 m
.88733 .34626 L
s
% Start of user PostScript
0.142857 -0.742307 0.470452 -0.805353 MAarrowhead1
% End of user PostScript
.83235 .43988 m
.85068 .45046 L
s
% Start of user PostScript
0.142857 -0.247436 0.252055 -0.18439 MAarrowhead1
% End of user PostScript
.83235 .52293 m
.81403 .53351 L
s
% Start of user PostScript
0.142857 0.247436 0.033659 0.310481 MAarrowhead1
% End of user PostScript
.83235 .60597 m
.77738 .59539 L
s
% Start of user PostScript
0.142857 0.742307 -0.184737 0.679262 MAarrowhead1
% End of user PostScript
.83235 .68902 m
.74073 .63612 L
s
% Start of user PostScript
0.142857 1.23718 -0.403133 0.921951 MAarrowhead1
% End of user PostScript
.83235 .77206 m
.70408 .65568 L
s
% Start of user PostScript
0.142857 1.73205 -0.62153 1.03855 MAarrowhead1
% End of user PostScript
.90427 .19075 m
.96841 .12463 L
s
% Start of user PostScript
0.571429 -1.73205 0.953622 -2.12609 MAarrowhead1
% End of user PostScript
.90427 .27379 m
.95008 .27115 L
s
% Start of user PostScript
0.571429 -1.23718 0.844424 -1.25294 MAarrowhead1
% End of user PostScript
.90427 .35684 m
.93176 .39651 L
s
% Start of user PostScript
0.571429 -0.742307 0.735226 -0.505887 MAarrowhead1
% End of user PostScript
.90427 .43988 m
.91343 .50072 L
s
% Start of user PostScript
0.571429 -0.247436 0.626028 0.115076 MAarrowhead1
% End of user PostScript
.90427 .52293 m
.89511 .58376 L
s
% Start of user PostScript
0.571429 0.247436 0.51683 0.609948 MAarrowhead1
% End of user PostScript
.90427 .60597 m
.87679 .64565 L
s
% Start of user PostScript
0.571429 0.742307 0.407631 0.978728 MAarrowhead1
% End of user PostScript
.90427 .68902 m
.85846 .68637 L
s
% Start of user PostScript
0.571429 1.23718 0.298433 1.22142 MAarrowhead1
% End of user PostScript
.90427 .77206 m
.84014 .70594 L
s
% Start of user PostScript
0.571429 1.73205 0.189235 1.33802 MAarrowhead1
% End of user PostScript
.97619 .19075 m
.97619 .19075 L
s
% Start of user PostScript
1. -1.73205 MAarrowzero1
% End of user PostScript
.97619 .27379 m
.97619 .33727 L
s
% Start of user PostScript
1. -1.23718 1. -0.858906 MAarrowhead1
% End of user PostScript
.97619 .35684 m
.97619 .46264 L
s
% Start of user PostScript
1. -0.742307 1. -0.111852 MAarrowhead1
% End of user PostScript
.97619 .43988 m
.97619 .56684 L
s
% Start of user PostScript
1. -0.247436 1. 0.509111 MAarrowhead1
% End of user PostScript
.97619 .52293 m
.97619 .64988 L
s
% Start of user PostScript
1. 0.247436 1. 1.00398 MAarrowhead1
% End of user PostScript
.97619 .60597 m
.97619 .71177 L
s
% Start of user PostScript
1. 0.742307 1. 1.37276 MAarrowhead1
% End of user PostScript
.97619 .68902 m
.97619 .75249 L
s
% Start of user PostScript
1. 1.23718 1. 1.61545 MAarrowhead1
% End of user PostScript
.97619 .77206 m
.97619 .77206 L
s
% Start of user PostScript
1. 1.73205 MAarrowzero1
% End of user PostScript
0 0 m
1 0 L
1 .79089 L
0 .79089 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 227.75},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {226.75, 0}} -> {-5.16052, -3.14115, 0.0219864, \
0.0219864}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"triangle", " ", "=", " ", 
  RowBox[{
   RowBox[{"Graphics", "[", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GrayLevel", "[", "0.9", "]"}], ",", " ", 
      RowBox[{"Polygon", "[", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", " ", "2"}], " ", "a"}], ",", " ", "0."}], "}"}], ",",
          " ", 
         RowBox[{"{", 
          RowBox[{"a", " ", ",", " ", 
           RowBox[{
            RowBox[{"Sqrt", "[", "3", "]"}], " ", "a"}]}], "  ", "}"}], ",", 
         " ", 
         RowBox[{"{", 
          RowBox[{"a", " ", ",", " ", 
           RowBox[{
            RowBox[{"-", " ", 
             RowBox[{"Sqrt", "[", "3", "]"}]}], " ", "a"}]}], "  ", "}"}]}], 
        "}"}], "]"}]}], "}"}], "]"}], " ", "/.", " ", 
   RowBox[{"a", " ", "\[Rule]", " ", "1"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", " ", 
  RowBox[{"triangle", ",", " ", "tractionplot"}], "]"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.808381 0.16781 0.376189 0.131133 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.9 g
.47276 .37619 m
.97619 .60332 L
.97619 .14906 L
F
0 g
.0001 w
[ ] 0 setdash
.47276 .14906 m
.92171 .04778 L
s
% Start of user PostScript
-2. -1.73205 0.675354 -2.50436 MAarrowhead1
% End of user PostScript
.47276 .21395 m
.79344 .16228 L
s
% Start of user PostScript
-2. -1.23718 -0.0890328 -1.63121 MAarrowhead1
% End of user PostScript
.47276 .27885 m
.66517 .26025 L
s
% Start of user PostScript
-2. -0.742307 -0.85342 -0.88416 MAarrowhead1
% End of user PostScript
.47276 .34374 m
.5369 .34168 L
s
% Start of user PostScript
-2. -0.247436 -1.61781 -0.263197 MAarrowhead1
% End of user PostScript
.47276 .40864 m
.40862 .40657 L
s
% Start of user PostScript
-2. 0.247436 -2.38219 0.231674 MAarrowhead1
% End of user PostScript
.47276 .47353 m
.28035 .45493 L
s
% Start of user PostScript
-2. 0.742307 -3.14658 0.600455 MAarrowhead1
% End of user PostScript
.47276 .53842 m
.15208 .48675 L
s
% Start of user PostScript
-2. 1.23718 -3.91097 0.843144 MAarrowhead1
% End of user PostScript
.47276 .60332 m
.02381 .50204 L
s
% Start of user PostScript
-2. 1.73205 -4.67535 0.959743 MAarrowhead1
% End of user PostScript
.54468 .14906 m
.92949 .02505 L
s
% Start of user PostScript
-1.57143 -1.73205 0.721732 -2.67773 MAarrowhead1
% End of user PostScript
.54468 .21395 m
.81955 .13955 L
s
% Start of user PostScript
-1.57143 -1.23718 0.0665433 -1.80459 MAarrowhead1
% End of user PostScript
.54468 .27885 m
.7096 .23751 L
s
% Start of user PostScript
-1.57143 -0.742307 -0.588645 -1.05754 MAarrowhead1
% End of user PostScript
.54468 .34374 m
.59965 .31894 L
s
% Start of user PostScript
-1.57143 -0.247436 -1.24383 -0.436573 MAarrowhead1
% End of user PostScript
.54468 .40864 m
.48971 .38383 L
s
% Start of user PostScript
-1.57143 0.247436 -1.89902 0.0582991 MAarrowhead1
% End of user PostScript
.54468 .47353 m
.37976 .43219 L
s
% Start of user PostScript
-1.57143 0.742307 -2.55421 0.42708 MAarrowhead1
% End of user PostScript
.54468 .53842 m
.26981 .46402 L
s
% Start of user PostScript
-1.57143 1.23718 -3.2094 0.669769 MAarrowhead1
% End of user PostScript
.54468 .60332 m
.15986 .47931 L
s
% Start of user PostScript
-1.57143 1.73205 -3.86459 0.786367 MAarrowhead1
% End of user PostScript
.6166 .14906 m
.93728 .01472 L
s
% Start of user PostScript
-1.14286 -1.73205 0.76811 -2.75654 MAarrowhead1
% End of user PostScript
.6166 .21395 m
.84565 .12921 L
s
% Start of user PostScript
-1.14286 -1.23718 0.222119 -1.8834 MAarrowhead1
% End of user PostScript
.6166 .27885 m
.75403 .22718 L
s
% Start of user PostScript
-1.14286 -0.742307 -0.323871 -1.13634 MAarrowhead1
% End of user PostScript
.6166 .34374 m
.66241 .30861 L
s
% Start of user PostScript
-1.14286 -0.247436 -0.869862 -0.515379 MAarrowhead1
% End of user PostScript
.6166 .40864 m
.57079 .3735 L
s
% Start of user PostScript
-1.14286 0.247436 -1.41585 -0.0205078 MAarrowhead1
% End of user PostScript
.6166 .47353 m
.47916 .42186 L
s
% Start of user PostScript
-1.14286 0.742307 -1.96184 0.348273 MAarrowhead1
% End of user PostScript
.6166 .53842 m
.38754 .45368 L
s
% Start of user PostScript
-1.14286 1.23718 -2.50783 0.590962 MAarrowhead1
% End of user PostScript
.6166 .60332 m
.29592 .46897 L
s
% Start of user PostScript
-1.14286 1.73205 -3.05382 0.70756 MAarrowhead1
% End of user PostScript
.68852 .14906 m
.94506 .01678 L
s
% Start of user PostScript
-0.714286 -1.73205 0.814488 -2.74078 MAarrowhead1
% End of user PostScript
.68852 .21395 m
.87176 .13128 L
s
% Start of user PostScript
-0.714286 -1.23718 0.377696 -1.86763 MAarrowhead1
% End of user PostScript
.68852 .27885 m
.79846 .22924 L
s
% Start of user PostScript
-0.714286 -0.742307 -0.059097 -1.12058 MAarrowhead1
% End of user PostScript
.68852 .34374 m
.72517 .31067 L
s
% Start of user PostScript
-0.714286 -0.247436 -0.495889 -0.499618 MAarrowhead1
% End of user PostScript
.68852 .40864 m
.65187 .37557 L
s
% Start of user PostScript
-0.714286 0.247436 -0.932682 -0.00474644 MAarrowhead1
% End of user PostScript
.68852 .47353 m
.57857 .42393 L
s
% Start of user PostScript
-0.714286 0.742307 -1.36947 0.364034 MAarrowhead1
% End of user PostScript
.68852 .53842 m
.50527 .45575 L
s
% Start of user PostScript
-0.714286 1.23718 -1.80627 0.606723 MAarrowhead1
% End of user PostScript
.68852 .60332 m
.43197 .47104 L
s
% Start of user PostScript
-0.714286 1.73205 -2.24306 0.723322 MAarrowhead1
% End of user PostScript
.76043 .14906 m
.95284 .03125 L
s
% Start of user PostScript
-0.285714 -1.73205 0.860866 -2.63045 MAarrowhead1
% End of user PostScript
.76043 .21395 m
.89787 .14575 L
s
% Start of user PostScript
-0.285714 -1.23718 0.533272 -1.75731 MAarrowhead1
% End of user PostScript
.76043 .27885 m
.8429 .24371 L
s
% Start of user PostScript
-0.285714 -0.742307 0.205677 -1.01025 MAarrowhead1
% End of user PostScript
.76043 .34374 m
.78792 .32514 L
s
% Start of user PostScript
-0.285714 -0.247436 -0.121917 -0.389288 MAarrowhead1
% End of user PostScript
.76043 .40864 m
.73295 .39003 L
s
% Start of user PostScript
-0.285714 0.247436 -0.449511 0.105583 MAarrowhead1
% End of user PostScript
.76043 .47353 m
.67797 .43839 L
s
% Start of user PostScript
-0.285714 0.742307 -0.777106 0.474364 MAarrowhead1
% End of user PostScript
.76043 .53842 m
.623 .47022 L
s
% Start of user PostScript
-0.285714 1.23718 -1.1047 0.717053 MAarrowhead1
% End of user PostScript
.76043 .60332 m
.56803 .48551 L
s
% Start of user PostScript
-0.285714 1.73205 -1.43229 0.833651 MAarrowhead1
% End of user PostScript
.83235 .14906 m
.96063 .05812 L
s
% Start of user PostScript
0.142857 -1.73205 0.907244 -2.42555 MAarrowhead1
% End of user PostScript
.83235 .21395 m
.92398 .17262 L
s
% Start of user PostScript
0.142857 -1.23718 0.688848 -1.55241 MAarrowhead1
% End of user PostScript
.83235 .27885 m
.88733 .27058 L
s
% Start of user PostScript
0.142857 -0.742307 0.470452 -0.805353 MAarrowhead1
% End of user PostScript
.83235 .34374 m
.85068 .35201 L
s
% Start of user PostScript
0.142857 -0.247436 0.252055 -0.18439 MAarrowhead1
% End of user PostScript
.83235 .40864 m
.81403 .4169 L
s
% Start of user PostScript
0.142857 0.247436 0.033659 0.310481 MAarrowhead1
% End of user PostScript
.83235 .47353 m
.77738 .46526 L
s
% Start of user PostScript
0.142857 0.742307 -0.184737 0.679262 MAarrowhead1
% End of user PostScript
.83235 .53842 m
.74073 .49709 L
s
% Start of user PostScript
0.142857 1.23718 -0.403133 0.921951 MAarrowhead1
% End of user PostScript
.83235 .60332 m
.70408 .51238 L
s
% Start of user PostScript
0.142857 1.73205 -0.62153 1.03855 MAarrowhead1
% End of user PostScript
.90427 .14906 m
.96841 .09739 L
s
% Start of user PostScript
0.571429 -1.73205 0.953622 -2.12609 MAarrowhead1
% End of user PostScript
.90427 .21395 m
.95008 .21189 L
s
% Start of user PostScript
0.571429 -1.23718 0.844424 -1.25294 MAarrowhead1
% End of user PostScript
.90427 .27885 m
.93176 .30985 L
s
% Start of user PostScript
0.571429 -0.742307 0.735226 -0.505887 MAarrowhead1
% End of user PostScript
.90427 .34374 m
.91343 .39128 L
s
% Start of user PostScript
0.571429 -0.247436 0.626028 0.115076 MAarrowhead1
% End of user PostScript
.90427 .40864 m
.89511 .45617 L
s
% Start of user PostScript
0.571429 0.247436 0.51683 0.609948 MAarrowhead1
% End of user PostScript
.90427 .47353 m
.87679 .50453 L
s
% Start of user PostScript
0.571429 0.742307 0.407631 0.978728 MAarrowhead1
% End of user PostScript
.90427 .53842 m
.85846 .53636 L
s
% Start of user PostScript
0.571429 1.23718 0.298433 1.22142 MAarrowhead1
% End of user PostScript
.90427 .60332 m
.84014 .55165 L
s
% Start of user PostScript
0.571429 1.73205 0.189235 1.33802 MAarrowhead1
% End of user PostScript
.97619 .14906 m
.97619 .14906 L
s
% Start of user PostScript
1. -1.73205 MAarrowzero1
% End of user PostScript
.97619 .21395 m
.97619 .26356 L
s
% Start of user PostScript
1. -1.23718 1. -0.858906 MAarrowhead1
% End of user PostScript
.97619 .27885 m
.97619 .36152 L
s
% Start of user PostScript
1. -0.742307 1. -0.111852 MAarrowhead1
% End of user PostScript
.97619 .34374 m
.97619 .44295 L
s
% Start of user PostScript
1. -0.247436 1. 0.509111 MAarrowhead1
% End of user PostScript
.97619 .40864 m
.97619 .50784 L
s
% Start of user PostScript
1. 0.247436 1. 1.00398 MAarrowhead1
% End of user PostScript
.97619 .47353 m
.97619 .5562 L
s
% Start of user PostScript
1. 0.742307 1. 1.37276 MAarrowhead1
% End of user PostScript
.97619 .53842 m
.97619 .58803 L
s
% Start of user PostScript
1. 1.23718 1. 1.61545 MAarrowhead1
% End of user PostScript
.97619 .60332 m
.97619 .60332 L
s
% Start of user PostScript
1. 1.73205 MAarrowzero1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{458, 283.062},
 ImageMargins->{{43, 0}, {0, 1}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 457}, {282.062, 0}} -> {-4.82122, -2.86876, \
0.0130571, 0.0167091}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", " ", 
  RowBox[{
  "\"\</local/constant/ElasticaBook/C07_EnergyVariational/EPS/C07_triangle_\
wrapping_tractions.eps\>\"", ",", " ", "%79"}], "]"}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/C07_EnergyVariational/EPS/C07_\
triangle_wrapping_tractions.eps\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", " ", 
  RowBox[{"uu3", " ", ",", " ", 
   RowBox[{"{", 
    RowBox[{"xx", ",", 
     RowBox[{"-", "2"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"yy", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", " ", 
   RowBox[{"BoxRatios", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "0.3"}], "}"}]}]}], "]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .76154 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.08998e-17 1.04933 -0.0923501 1.04933 [
[.03249 .24209 -12 -8.67431 ]
[.03249 .24209 0 .32569 ]
[.22754 .16633 -11.6554 -9 ]
[.22754 .16633 .34459 0 ]
[.43823 .08455 -5.42134 -9 ]
[.43823 .08455 .57866 0 ]
[.66654 -0.004 -5.01498 -9 ]
[.66654 -0.004 .98502 0 ]
[.77962 .10984 0 -6.12741 ]
[.77962 .10984 12 2.87259 ]
[.86209 .23465 0 -6.0092 ]
[.86209 .23465 6 2.9908 ]
[.9353 .34546 0 -5.90701 ]
[.9353 .34546 6 3.09299 ]
[.01122 .29031 -30 -2.78555 ]
[.01122 .29031 0 6.21445 ]
[.00214 .34721 -6 -2.83339 ]
[.00214 .34721 0 6.16661 ]
[-0.00727 .4062 -24 -2.88317 ]
[-0.00727 .4062 0 6.11683 ]
[ 0 0 0 0 ]
[ 1 .76154 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02811 .25642 m
.69167 0 L
s
.04211 .25101 m
.04692 .25547 L
s
[(-2)] .03249 .24209 1 .92762 Mshowa
.23653 .17588 m
.24103 .18065 L
s
[(-1)] .22754 .16633 .94257 1 Mshowa
.44647 .09475 m
.45059 .09986 L
s
[(0)] .43823 .08455 .80711 1 Mshowa
.67386 .00689 m
.67751 .01233 L
s
[(1)] .66654 -0.004 .67166 1 Mshowa
.125 Mabswid
.07984 .23643 m
.08269 .23914 L
s
.11813 .22163 m
.12095 .22438 L
s
.157 .20661 m
.15978 .2094 L
s
.19646 .19136 m
.1992 .19418 L
s
.27722 .16015 m
.27988 .16306 L
s
.31854 .14419 m
.32116 .14713 L
s
.36052 .12797 m
.36308 .13095 L
s
.40315 .11149 m
.40567 .11451 L
s
.49048 .07774 m
.4929 .08085 L
s
.53521 .06046 m
.53758 .0636 L
s
.58067 .04289 m
.58298 .04608 L
s
.62688 .02504 m
.62913 .02826 L
s
.25 Mabswid
.69167 0 m
.97681 .43105 L
s
.76728 .1143 m
.76112 .11653 L
s
[(-1)] .77962 .10984 -1 .36165 Mshowa
.84966 .23882 m
.84344 .24091 L
s
[(0)] .86209 .23465 -1 .33538 Mshowa
.92279 .34938 m
.91653 .35133 L
s
[(1)] .9353 .34546 -1 .31267 Mshowa
.125 Mabswid
.78458 .14045 m
.78087 .14177 L
s
.80145 .16595 m
.79774 .16725 L
s
.81791 .19083 m
.81419 .19212 L
s
.83397 .21512 m
.83025 .21639 L
s
.86497 .26197 m
.86123 .26321 L
s
.87993 .28459 m
.87619 .28581 L
s
.89454 .30668 m
.8908 .30788 L
s
.90882 .32827 m
.90507 .32946 L
s
.74954 .08748 m
.74585 .08884 L
s
.73134 .05997 m
.72766 .06134 L
s
.71266 .03173 m
.70899 .03313 L
s
.69349 .00274 m
.68982 .00416 L
s
.93644 .37001 m
.93268 .37117 L
s
.94979 .3902 m
.94603 .39135 L
s
.96285 .40995 m
.95908 .41108 L
s
.97563 .42927 m
.97186 .43039 L
s
.25 Mabswid
.02811 .25642 m
0 .43378 L
s
.02348 .28564 m
.0296 .2833 L
s
[(-0.02)] .01122 .29031 1 -0.38099 Mshowa
.01444 .34266 m
.02059 .34038 L
s
[(0)] .00214 .34721 1 -0.37036 Mshowa
.00507 .40177 m
.01124 .39955 L
s
[(0.02)] -0.00727 .4062 1 -0.3593 Mshowa
.125 Mabswid
.02125 .2997 m
.02493 .29831 L
s
.019 .31389 m
.02268 .31251 L
s
.01673 .32821 m
.02042 .32684 L
s
.01213 .35724 m
.01582 .35588 L
s
.0098 .37194 m
.0135 .3706 L
s
.00745 .38679 m
.01115 .38545 L
s
.02569 .2717 m
.02936 .27029 L
s
.02787 .25788 m
.03155 .25646 L
s
.00268 .41689 m
.00638 .41557 L
s
.00026 .43215 m
.00397 .43084 L
s
.25 Mabswid
.02811 .25642 m
0 .43378 L
s
0 .43378 m
.39748 .76154 L
s
.39748 .76154 m
.40309 .60101 L
s
.40309 .60101 m
.02811 .25642 L
s
.69167 0 m
.97681 .43105 L
s
.97681 .43105 m
1 .60069 L
s
1 .60069 m
.70245 .18561 L
s
.70245 .18561 m
.69167 0 L
s
.02811 .25642 m
0 .43378 L
s
0 .43378 m
.70245 .18561 L
s
.70245 .18561 m
.69167 0 L
s
.69167 0 m
.02811 .25642 L
s
.40309 .60101 m
.97681 .43105 L
s
.97681 .43105 m
1 .60069 L
s
1 .60069 m
.39748 .76154 L
s
.39748 .76154 m
.40309 .60101 L
s
0 0 m
1 0 L
1 .76154 L
0 .76154 L
closepath
clip
newpath
.5 Mabswid
.593 .142 .151 r
.83369 .43565 m .80888 .43396 L .8035 .44271 L p F P
0 g
s
.528 .064 .096 r
.80888 .43396 m .78438 .43562 L .77892 .44313 L p F P
0 g
s
.528 .064 .096 r
.77892 .44313 m .8035 .44271 L .80888 .43396 L p F P
0 g
s
.443 0 .018 r
.78438 .43562 m .76009 .44024 L .75458 .44648 L p F P
0 g
s
.443 0 .018 r
.75458 .44648 m .77892 .44313 L .78438 .43562 L p F P
0 g
s
.644 .204 .19 r
.85892 .44111 m .83369 .43565 L .82841 .4456 L p F P
0 g
s
.593 .142 .151 r
.8035 .44271 m .82841 .4456 L .83369 .43565 L p F P
0 g
s
.326 0 0 r
.76009 .44024 m .73591 .44744 L .73038 .45238 L p F P
0 g
s
.326 0 0 r
.73038 .45238 m .75458 .44648 L .76009 .44024 L p F P
0 g
s
.16 0 0 r
.73591 .44744 m .71177 .45686 L .70625 .46047 L p F P
0 g
s
.16 0 0 r
.70625 .46047 m .73038 .45238 L .73591 .44744 L p F P
0 g
s
.686 .254 .218 r
.8847 .45077 m .85892 .44111 L .85377 .4522 L p F P
0 g
s
.644 .204 .19 r
.82841 .4456 m .85377 .4522 L .85892 .44111 L p F P
0 g
s
0 0 0 r
.6876 .46814 m .68213 .4704 L p .69451 .46475 L F P
0 g
s
0 0 0 r
.69639 .46404 m .6876 .46814 L p .69451 .46475 L F P
0 g
s
0 0 0 r
.71177 .45686 m .69639 .46404 L p .69451 .46475 L F P
0 g
s
.353 .808 .685 r
.6876 .46814 m .66335 .48089 L .65795 .48182 L p F P
0 g
s
.353 .808 .685 r
.68213 .4704 m .6876 .46814 L p .67353 .47463 L F P
0 g
s
.353 .808 .685 r
.65795 .48182 m .68213 .4704 L p .67353 .47463 L F P
0 g
s
0 0 0 r
.68213 .4704 m .67652 .47139 L p .69077 .46615 L F P
0 g
s
0 0 0 r
.69414 .46492 m .70625 .46047 L .71177 .45686 L p F P
0 g
s
0 0 0 r
.70625 .46047 m .68213 .4704 L p .69077 .46615 L F P
0 g
s
0 0 0 r
.70057 .46259 m .70625 .46047 L p .69312 .46529 L F P
0 g
s
.014 0 0 r
.70625 .46047 m .70057 .46259 L p .71075 .4591 L F P
0 g
s
.014 0 0 r
.73038 .45238 m .70977 .45929 L p .71075 .4591 L F P
0 g
s
.014 0 0 r
.70977 .45929 m .70625 .46047 L p .71075 .4591 L F P
0 g
s
.014 0 0 r
.72465 .4556 m .73038 .45238 L p .71743 .45681 L F P
0 g
s
.014 0 0 r
.70057 .46259 m .72465 .4556 L p .71743 .45681 L F P
0 g
s
0 0 0 r
.72465 .4556 m .70057 .46259 L p .70807 .45987 L F P
0 g
s
.062 0 0 r
.72465 .4556 m .71873 .45721 L p .72019 .4569 L F P
0 g
s
.062 0 0 r
.72019 .4569 m .73193 .45438 L .72465 .4556 L F
.74883 .45076 m .72465 .4556 L p .73193 .45438 L F P
0 g
s
0 0 0 r
.71873 .45721 m .72465 .4556 L p .71198 .45886 L F P
0 g
s
.127 .675 .727 r
.71873 .45721 m .71264 .45729 L p .72554 .45554 L F P
0 g
s
.062 0 0 r
.74286 .45319 m .74883 .45076 L p .73612 .45348 L F P
0 g
s
.062 0 0 r
.71873 .45721 m .74286 .45319 L p .73612 .45348 L F P
0 g
s
.127 .675 .727 r
.74286 .45319 m .71873 .45721 L p .72554 .45554 L F P
0 g
s
.217 0 0 r
.75458 .44648 m .73038 .45238 L .72465 .4556 L p F P
0 g
s
.217 0 0 r
.72465 .4556 m .74883 .45076 L .75458 .44648 L p F P
0 g
s
.127 .675 .727 r
.73667 .45386 m .74286 .45319 L p .73035 .45489 L F P
0 g
s
.127 .675 .727 r
.71264 .45729 m .73667 .45386 L p .73035 .45489 L F P
0 g
s
.14 .683 .817 r
.73667 .45386 m .73029 .4529 L p .74305 .45283 L F P
0 g
s
.066 0 0 r
.74286 .45319 m .73667 .45386 L p .74966 .45289 L F P
0 g
s
.066 0 0 r
.76717 .45158 m .74286 .45319 L p .74966 .45289 L F P
0 g
s
.243 0 0 r
.77318 .44842 m .74883 .45076 L .74286 .45319 L p F P
0 g
s
.243 0 0 r
.74286 .45319 m .76717 .45158 L .77318 .44842 L p F P
0 g
s
.066 0 0 r
.7609 .45273 m .76717 .45158 L p .75446 .45253 L F P
0 g
s
.066 0 0 r
.73667 .45386 m .7609 .45273 L p .75446 .45253 L F P
0 g
s
.231 0 0 r
.79175 .45272 m .76717 .45158 L .7609 .45273 L p F P
0 g
s
.231 0 0 r
.78541 .45422 m .79175 .45272 L p .77875 .45272 L F P
0 g
s
.231 0 0 r
.7609 .45273 m .78541 .45422 L p .77875 .45272 L F P
0 g
s
0 .559 .732 r
.78541 .45422 m .7609 .45273 L p .76741 .45293 L F P
0 g
s
0 .559 .732 r
.77881 .45357 m .78541 .45422 L p .77254 .4533 L F P
0 g
s
0 .559 .732 r
.75441 .452 m .77881 .45357 L p .77254 .4533 L F P
0 g
s
.382 0 0 r
.79778 .44893 m .77318 .44842 L .76717 .45158 L p F P
0 g
s
.382 0 0 r
.76717 .45158 m .79175 .45272 L .79778 .44893 L p F P
0 g
s
.077 .605 .87 r
.77881 .45357 m .77195 .45093 L p .78514 .45384 L F P
0 g
s
.163 0 0 r
.78541 .45422 m .77881 .45357 L p .79216 .45573 L F P
0 g
s
.163 0 0 r
.81029 .45867 m .78541 .45422 L p .79216 .45573 L F P
0 g
s
.364 0 0 r
.81668 .45697 m .79175 .45272 L .78541 .45422 L p F P
0 g
s
.364 0 0 r
.78541 .45422 m .81029 .45867 L .81668 .45697 L p F P
0 g
s
.163 0 0 r
.80357 .45791 m .81029 .45867 L p .79701 .45652 L F P
0 g
s
.163 0 0 r
.77881 .45357 m .80357 .45791 L p .79701 .45652 L F P
0 g
s
.282 0 0 r
.83562 .46644 m .81029 .45867 L .80357 .45791 L p F P
0 g
s
0 .512 .828 r
.80357 .45791 m .79655 .45488 L p .81021 .45932 L F P
0 g
s
.282 0 0 r
.82878 .46536 m .83562 .46644 L p .82185 .46277 L F P
0 g
s
.282 0 0 r
.80357 .45791 m .82878 .46536 L p .82185 .46277 L F P
0 g
s
.468 0 0 r
.81029 .45867 m .83562 .46644 L .84209 .46472 L p F P
0 g
s
.377 0 0 r
.86154 .47791 m .83562 .46644 L .82878 .46536 L p F P
0 g
s
0 .422 .79 r
.82878 .46536 m .82159 .4617 L p .8358 .46799 L F P
0 g
s
.377 0 0 r
.85455 .47629 m .86154 .47791 L p .84719 .47241 L F P
0 g
s
.377 0 0 r
.82878 .46536 m .85455 .47629 L p .84719 .47241 L F P
0 g
s
.449 0 0 r
.88816 .49351 m .86154 .47791 L .85455 .47629 L p F P
0 g
s
.449 0 0 r
.88101 .49107 m .88816 .49351 L p .87313 .48581 L F P
0 g
s
.449 0 0 r
.85455 .47629 m .88101 .49107 L p .87313 .48581 L F P
0 g
s
.501 0 0 r
.91564 .51371 m .88816 .49351 L .88101 .49107 L p F P
0 g
s
.501 0 0 r
.90828 .51016 m .91564 .51371 L p .89982 .50337 L F P
0 g
s
.501 0 0 r
.88101 .49107 m .90828 .51016 L p .89982 .50337 L F P
0 g
s
.533 0 0 r
.94414 .53903 m .91564 .51371 L .90828 .51016 L p F P
0 g
s
0 .21 .705 r
.90828 .51016 m .90037 .5028 L p .91689 .51706 L F P
0 g
s
.533 0 0 r
.90828 .51016 m .93653 .53401 L .94414 .53903 L p F P
0 g
s
0 .21 .705 r
.93653 .53401 m .90828 .51016 L p .91689 .51706 L F P
0 g
s
0 .27 .729 r
.88101 .49107 m .87338 .48529 L p .88901 .49642 L F P
0 g
s
0 .27 .729 r
.90828 .51016 m .88101 .49107 L p .88901 .49642 L F P
0 g
s
0 .341 .757 r
.85455 .47629 m .84716 .47172 L p .86203 .48022 L F P
0 g
s
0 .341 .757 r
.88101 .49107 m .85455 .47629 L p .86203 .48022 L F P
0 g
s
0 .422 .79 r
.85455 .47629 m .82878 .46536 L p .8358 .46799 L F P
0 g
s
0 .512 .828 r
.82878 .46536 m .80357 .45791 L p .81021 .45932 L F P
0 g
s
.077 .605 .87 r
.80357 .45791 m .77881 .45357 L p .78514 .45384 L F P
0 g
s
0 .559 .732 r
.7609 .45273 m .75441 .452 L p .76741 .45293 L F P
0 g
s
.14 .683 .817 r
.7609 .45273 m .73667 .45386 L p .74305 .45283 L F P
0 g
s
0 0 0 r
.71194 .45888 m .71873 .45721 L .71198 .45886 L F
.70057 .46259 m .69473 .46331 L p .70807 .45987 L F P
0 g
s
0 0 0 r
.69473 .46331 m .71288 .4587 L p .71194 .45888 L F P
0 g
s
0 0 0 r
.71288 .4587 m .71873 .45721 L p .71194 .45888 L F P
0 g
s
0 0 0 r
.69143 .46591 m .70057 .46259 L .69312 .46529 L F
.67652 .47139 m .68968 .46657 L p .69143 .46591 L F P
0 g
s
0 0 0 r
.68968 .46657 m .70057 .46259 L p .69143 .46591 L F P
0 g
s
.721 .296 .237 r
.9112 .46511 m .8847 .45077 L .8797 .46294 L p F P
0 g
s
.686 .254 .218 r
.85377 .4522 m .8797 .46294 L .8847 .45077 L p F P
0 g
s
.474 0 0 r
.8035 .44271 m .77892 .44313 L .77318 .44842 L p F P
0 g
s
.366 0 0 r
.77892 .44313 m .75458 .44648 L .74883 .45076 L p F P
0 g
s
.366 0 0 r
.74883 .45076 m .77318 .44842 L .77892 .44313 L p F P
0 g
s
.556 .06 .033 r
.82841 .4456 m .8035 .44271 L .79778 .44893 L p F P
0 g
s
.474 0 0 r
.77318 .44842 m .79778 .44893 L .8035 .44271 L p F P
0 g
s
.752 .332 .25 r
.93857 .48467 m .9112 .46511 L .90636 .47831 L p F P
0 g
s
.721 .296 .237 r
.8797 .46294 m .90636 .47831 L .9112 .46511 L p F P
0 g
s
.602 .952 .851 r
.66335 .48089 m .63896 .49476 L .63369 .49436 L p F P
0 g
s
.602 .952 .851 r
.63369 .49436 m .65795 .48182 L .66335 .48089 L p F P
0 g
s
.62 .136 .084 r
.85377 .4522 m .82841 .4456 L .82273 .45266 L p F P
0 g
s
.556 .06 .033 r
.79778 .44893 m .82273 .45266 L .82841 .4456 L p F P
0 g
s
.671 .198 .119 r
.8797 .46294 m .85377 .4522 L .84815 .46002 L p F P
0 g
s
.62 .136 .084 r
.82273 .45266 m .84815 .46002 L .85377 .4522 L p F P
0 g
s
.487 .901 .829 r
.68213 .4704 m .65795 .48182 L .65245 .48165 L p F P
0 g
s
.487 .901 .829 r
.65245 .48165 m .67652 .47139 L .68213 .4704 L p F P
0 g
s
.752 .98 .914 r
.63896 .49476 m .61441 .50934 L .60929 .50765 L p F P
0 g
s
.752 .98 .914 r
.60929 .50765 m .63369 .49436 L .63896 .49476 L p F P
0 g
s
.577 .438 .656 r
.26924 .45811 m .25482 .48823 L .25454 .48607 L p F P
0 g
s
.577 .438 .656 r
.25454 .48607 m .26863 .45419 L .26924 .45811 L p F P
0 g
s
.591 .44 .645 r
.24 .52345 m .25454 .48607 L .25482 .48823 L closepath p F P
0 g
s
.579 .439 .655 r
.26985 .46203 m .25511 .49038 L .25482 .48823 L p F P
0 g
s
.579 .439 .655 r
.25482 .48823 m .26924 .45811 L .26985 .46203 L p F P
0 g
s
.591 .44 .645 r
.24 .52345 m .25482 .48823 L .25511 .49038 L closepath p F P
0 g
s
.58 .44 .655 r
.27046 .46595 m .25539 .49254 L .25511 .49038 L p F P
0 g
s
.58 .44 .655 r
.25511 .49038 m .26985 .46203 L .27046 .46595 L p F P
0 g
s
.591 .44 .645 r
.24 .52345 m .25511 .49038 L .25539 .49254 L closepath p F P
0 g
s
.563 .438 .668 r
.28335 .43258 m .26924 .45811 L .26863 .45419 L p F P
0 g
s
.563 .438 .668 r
.26863 .45419 m .28239 .42727 L .28335 .43258 L p F P
0 g
s
.78 .363 .258 r
.96701 .51004 m .93857 .48467 L .93391 .49884 L p F P
0 g
s
.752 .332 .25 r
.90636 .47831 m .93391 .49884 L .93857 .48467 L p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .26259 .54694 L .26288 .54914 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .2623 .54475 L .26259 .54694 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .26201 .54256 L .2623 .54475 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .26172 .54037 L .26201 .54256 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .26143 .53819 L .26172 .54037 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .26114 .536 L .26143 .53819 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .26085 .53382 L .26114 .536 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .26056 .53163 L .26085 .53382 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .26027 .52945 L .26056 .53163 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .25999 .52727 L .26027 .52945 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .2597 .52509 L .25999 .52727 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .25941 .52291 L .2597 .52509 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .25912 .52073 L .25941 .52291 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .25883 .51855 L .25912 .52073 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .25855 .51638 L .25883 .51855 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .25826 .51421 L .25855 .51638 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .25797 .51203 L .25826 .51421 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .25768 .50986 L .25797 .51203 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .2574 .50769 L .25768 .50986 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .25711 .50552 L .2574 .50769 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .25682 .50336 L .25711 .50552 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .25654 .50119 L .25682 .50336 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .25625 .49903 L .25654 .50119 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .25597 .49686 L .25625 .49903 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .25568 .4947 L .25597 .49686 L closepath p F P
0 g
s
.59 .44 .645 r
.24 .52345 m .25539 .49254 L .25568 .4947 L closepath p F P
0 g
s
.581 .441 .655 r
.27107 .46988 m .25568 .4947 L .25539 .49254 L p F P
0 g
s
.581 .441 .655 r
.25539 .49254 m .27046 .46595 L .27107 .46988 L p F P
0 g
s
.582 .442 .655 r
.27168 .47382 m .25597 .49686 L .25568 .4947 L p F P
0 g
s
.582 .442 .655 r
.25568 .4947 m .27107 .46988 L .27168 .47382 L p F P
0 g
s
.67 .969 .917 r
.65795 .48182 m .63369 .49436 L .62832 .49303 L p F P
0 g
s
.67 .969 .917 r
.62832 .49303 m .65245 .48165 L .65795 .48182 L p F P
0 g
s
.565 .439 .668 r
.28432 .43791 m .26985 .46203 L .26924 .45811 L p F P
0 g
s
.565 .439 .668 r
.26924 .45811 m .28335 .43258 L .28432 .43791 L p F P
0 g
s
.583 .442 .655 r
.27229 .47776 m .25625 .49903 L .25597 .49686 L p F P
0 g
s
.583 .442 .655 r
.25597 .49686 m .27168 .47382 L .27229 .47776 L p F P
0 g
s
.568 .441 .667 r
.28529 .44325 m .27046 .46595 L .26985 .46203 L p F P
0 g
s
.568 .441 .667 r
.26985 .46203 m .28432 .43791 L .28529 .44325 L p F P
0 g
s
.584 .443 .655 r
.27291 .4817 m .25654 .50119 L .25625 .49903 L p F P
0 g
s
.584 .443 .655 r
.25625 .49903 m .27229 .47776 L .27291 .4817 L p F P
0 g
s
.586 .444 .655 r
.27352 .48565 m .25682 .50336 L .25654 .50119 L p F P
0 g
s
.586 .444 .655 r
.25654 .50119 m .27291 .4817 L .27352 .48565 L p F P
0 g
s
.57 .443 .667 r
.28625 .44861 m .27107 .46988 L .27046 .46595 L p F P
0 g
s
.57 .443 .667 r
.27046 .46595 m .28529 .44325 L .28625 .44861 L p F P
0 g
s
.714 .248 .144 r
.90636 .47831 m .8797 .46294 L .87415 .47142 L p F P
0 g
s
.671 .198 .119 r
.84815 .46002 m .87415 .47142 L .8797 .46294 L p F P
0 g
s
.587 .445 .655 r
.27413 .48961 m .25711 .50552 L .25682 .50336 L p F P
0 g
s
.587 .445 .655 r
.25682 .50336 m .27352 .48565 L .27413 .48961 L p F P
0 g
s
.588 .445 .655 r
.27475 .49357 m .2574 .50769 L .25711 .50552 L p F P
0 g
s
.588 .445 .655 r
.25711 .50552 m .27413 .48961 L .27475 .49357 L p F P
0 g
s
.573 .444 .667 r
.28722 .45397 m .27168 .47382 L .27107 .46988 L p F P
0 g
s
.573 .444 .667 r
.27107 .46988 m .28625 .44861 L .28722 .45397 L p F P
0 g
s
.813 .94 .91 r
.61441 .50934 m .58967 .52424 L .58474 .52132 L p F P
0 g
s
.813 .94 .91 r
.58474 .52132 m .60929 .50765 L .61441 .50934 L p F P
0 g
s
.589 .446 .655 r
.27536 .49753 m .25768 .50986 L .2574 .50769 L p F P
0 g
s
.589 .446 .655 r
.2574 .50769 m .27475 .49357 L .27536 .49753 L p F P
0 g
s
.546 .438 .682 r
.29723 .41121 m .28335 .43258 L .28239 .42727 L p F P
0 g
s
.546 .438 .682 r
.28239 .42727 m .29588 .40481 L .29723 .41121 L p F P
0 g
s
.575 .446 .667 r
.28819 .45934 m .27229 .47776 L .27168 .47382 L p F P
0 g
s
.575 .446 .667 r
.27168 .47382 m .28722 .45397 L .28819 .45934 L p F P
0 g
s
.59 .447 .655 r
.27597 .5015 m .25797 .51203 L .25768 .50986 L p F P
0 g
s
.59 .447 .655 r
.25768 .50986 m .27536 .49753 L .27597 .5015 L p F P
0 g
s
.391 .85 .824 r
.70057 .46259 m .67652 .47139 L .67079 .47116 L p F P
0 g
s
.391 .85 .824 r
.67079 .47116 m .69473 .46331 L .70057 .46259 L p F P
0 g
s
.591 .448 .655 r
.27659 .50547 m .25826 .51421 L .25797 .51203 L p F P
0 g
s
.591 .448 .655 r
.25797 .51203 m .27597 .5015 L .27659 .50547 L p F P
0 g
s
.55 .44 .682 r
.29859 .41763 m .28432 .43791 L .28335 .43258 L p F P
0 g
s
.55 .44 .682 r
.28335 .43258 m .29723 .41121 L .29859 .41763 L p F P
0 g
s
.578 .448 .667 r
.28916 .46472 m .27291 .4817 L .27229 .47776 L p F P
0 g
s
.578 .448 .667 r
.27229 .47776 m .28819 .45934 L .28916 .46472 L p F P
0 g
s
.488 0 0 r
.82273 .45266 m .79778 .44893 L .79175 .45272 L p F P
0 g
s
.592 .449 .655 r
.27721 .50945 m .25855 .51638 L .25826 .51421 L p F P
0 g
s
.592 .449 .655 r
.25826 .51421 m .27659 .50547 L .27721 .50945 L p F P
0 g
s
.768 .958 .932 r
.63369 .49436 m .60929 .50765 L .6041 .50518 L p F P
0 g
s
.768 .958 .932 r
.6041 .50518 m .62832 .49303 L .63369 .49436 L p F P
0 g
s
.594 .449 .655 r
.27782 .51343 m .25883 .51855 L .25855 .51638 L p F P
0 g
s
.594 .449 .655 r
.25855 .51638 m .27721 .50945 L .27782 .51343 L p F P
0 g
s
.58 .449 .667 r
.29013 .47012 m .27352 .48565 L .27291 .4817 L p F P
0 g
s
.58 .449 .667 r
.27291 .4817 m .28916 .46472 L .29013 .47012 L p F P
0 g
s
.554 .443 .682 r
.29994 .42406 m .28529 .44325 L .28432 .43791 L p F P
0 g
s
.554 .443 .682 r
.28432 .43791 m .29859 .41763 L .29994 .42406 L p F P
0 g
s
.595 .45 .655 r
.27844 .51742 m .25912 .52073 L .25883 .51855 L p F P
0 g
s
.595 .45 .655 r
.25883 .51855 m .27782 .51343 L .27844 .51742 L p F P
0 g
s
.583 .451 .667 r
.29111 .47552 m .27413 .48961 L .27352 .48565 L p F P
0 g
s
.583 .451 .667 r
.27352 .48565 m .29013 .47012 L .29111 .47552 L p F P
0 g
s
.596 .451 .655 r
.27906 .5214 m .25941 .52291 L .25912 .52073 L p F P
0 g
s
.596 .451 .655 r
.25912 .52073 m .27844 .51742 L .27906 .5214 L p F P
0 g
s
.558 .446 .681 r
.30129 .43052 m .28625 .44861 L .28529 .44325 L p F P
0 g
s
.558 .446 .681 r
.28529 .44325 m .29994 .42406 L .30129 .43052 L p F P
0 g
s
.583 .94 .918 r
.67652 .47139 m .65245 .48165 L .64685 .48044 L p F P
0 g
s
.583 .94 .918 r
.64685 .48044 m .67079 .47116 L .67652 .47139 L p F P
0 g
s
.597 .452 .655 r
.27968 .5254 m .2597 .52509 L .25941 .52291 L p F P
0 g
s
.597 .452 .655 r
.25941 .52291 m .27906 .5214 L .27968 .5254 L p F P
0 g
s
.585 .452 .666 r
.29208 .48093 m .27475 .49357 L .27413 .48961 L p F P
0 g
s
.585 .452 .666 r
.27413 .48961 m .29111 .47552 L .29208 .48093 L p F P
0 g
s
.563 .448 .681 r
.30265 .437 m .28722 .45397 L .28625 .44861 L p F P
0 g
s
.563 .448 .681 r
.28625 .44861 m .30129 .43052 L .30265 .437 L p F P
0 g
s
.598 .453 .655 r
.28029 .52939 m .25999 .52727 L .2597 .52509 L p F P
0 g
s
.598 .453 .655 r
.2597 .52509 m .27968 .5254 L .28029 .52939 L p F P
0 g
s
.588 .454 .666 r
.29305 .48635 m .27536 .49753 L .27475 .49357 L p F P
0 g
s
.588 .454 .666 r
.27475 .49357 m .29208 .48093 L .29305 .48635 L p F P
0 g
s
.599 .453 .655 r
.28091 .53339 m .26027 .52945 L .25999 .52727 L p F P
0 g
s
.599 .453 .655 r
.25999 .52727 m .28029 .52939 L .28091 .53339 L p F P
0 g
s
.567 .451 .681 r
.304 .44349 m .28819 .45934 L .28722 .45397 L p F P
0 g
s
.567 .451 .681 r
.28722 .45397 m .30265 .437 L .304 .44349 L p F P
0 g
s
.6 .454 .655 r
.28153 .53739 m .26056 .53163 L .26027 .52945 L p F P
0 g
s
.6 .454 .655 r
.26027 .52945 m .28091 .53339 L .28153 .53739 L p F P
0 g
s
.57 .034 0 r
.84815 .46002 m .82273 .45266 L .81668 .45697 L p F P
0 g
s
.488 0 0 r
.79175 .45272 m .81668 .45697 L .82273 .45266 L p F P
0 g
s
.59 .456 .666 r
.29403 .49177 m .27597 .5015 L .27536 .49753 L p F P
0 g
s
.59 .456 .666 r
.27536 .49753 m .29305 .48635 L .29403 .49177 L p F P
0 g
s
.601 .455 .655 r
.28216 .5414 m .26085 .53382 L .26056 .53163 L p F P
0 g
s
.601 .455 .655 r
.26056 .53163 m .28153 .53739 L .28216 .5414 L p F P
0 g
s
.571 .453 .68 r
.30536 .45 m .28916 .46472 L .28819 .45934 L p F P
0 g
s
.571 .453 .68 r
.28819 .45934 m .304 .44349 L .30536 .45 L p F P
0 g
s
.602 .456 .655 r
.28278 .54541 m .26114 .536 L .26085 .53382 L p F P
0 g
s
.602 .456 .655 r
.26085 .53382 m .28216 .5414 L .28278 .54541 L p F P
0 g
s
.592 .457 .666 r
.29501 .49721 m .27659 .50547 L .27597 .5015 L p F P
0 g
s
.592 .457 .666 r
.27597 .5015 m .29403 .49177 L .29501 .49721 L p F P
0 g
s
.827 .879 .881 r
.58967 .52424 m .56473 .53905 L .56003 .53497 L p F P
0 g
s
.827 .879 .881 r
.56003 .53497 m .58474 .52132 L .58967 .52424 L p F P
0 g
s
.526 .439 .7 r
.31097 .39356 m .29723 .41121 L .29588 .40481 L p F P
0 g
s
.526 .439 .7 r
.29588 .40481 m .3092 .38637 L .31097 .39356 L p F P
0 g
s
.604 .456 .655 r
.2834 .54942 m .26143 .53819 L .26114 .536 L p F P
0 g
s
.604 .456 .655 r
.26114 .536 m .28278 .54541 L .2834 .54942 L p F P
0 g
s
.707 .957 .948 r
.65245 .48165 m .62832 .49303 L .62288 .49082 L p F P
0 g
s
.707 .957 .948 r
.62288 .49082 m .64685 .48044 L .65245 .48165 L p F P
0 g
s
.575 .456 .68 r
.30672 .45653 m .29013 .47012 L .28916 .46472 L p F P
0 g
s
.575 .456 .68 r
.28916 .46472 m .30536 .45 L .30672 .45653 L p F P
0 g
s
.595 .459 .666 r
.29598 .50265 m .27721 .50945 L .27659 .50547 L p F P
0 g
s
.595 .459 .666 r
.27659 .50547 m .29501 .49721 L .29598 .50265 L p F P
0 g
s
.605 .457 .655 r
.28402 .55343 m .26172 .54037 L .26143 .53819 L p F P
0 g
s
.605 .457 .655 r
.26143 .53819 m .2834 .54942 L .28402 .55343 L p F P
0 g
s
.807 .91 .911 r
.60929 .50765 m .58474 .52132 L .57976 .51775 L p F P
0 g
s
.807 .91 .911 r
.57976 .51775 m .6041 .50518 L .60929 .50765 L p F P
0 g
s
.533 .443 .699 r
.31273 .40077 m .29859 .41763 L .29723 .41121 L p F P
0 g
s
.533 .443 .699 r
.29723 .41121 m .31097 .39356 L .31273 .40077 L p F P
0 g
s
.606 .458 .655 r
.28465 .55745 m .26201 .54256 L .26172 .54037 L p F P
0 g
s
.606 .458 .655 r
.26172 .54037 m .28402 .55343 L .28465 .55745 L p F P
0 g
s
.597 .46 .666 r
.29696 .50809 m .27782 .51343 L .27721 .50945 L p F P
0 g
s
.597 .46 .666 r
.27721 .50945 m .29598 .50265 L .29696 .50809 L p F P
0 g
s
.579 .458 .68 r
.30807 .46307 m .29111 .47552 L .29013 .47012 L p F P
0 g
s
.579 .458 .68 r
.29013 .47012 m .30672 .45653 L .30807 .46307 L p F P
0 g
s
.75 .291 .159 r
.93391 .49884 m .90636 .47831 L .90088 .48734 L p F P
0 g
s
.714 .248 .144 r
.87415 .47142 m .90088 .48734 L .90636 .47831 L p F P
0 g
s
.607 .459 .655 r
.28527 .56147 m .2623 .54475 L .26201 .54256 L p F P
0 g
s
.607 .459 .655 r
.26201 .54256 m .28465 .55745 L .28527 .56147 L p F P
0 g
s
.539 .447 .698 r
.31449 .40803 m .29994 .42406 L .29859 .41763 L p F P
0 g
s
.539 .447 .698 r
.29859 .41763 m .31273 .40077 L .31449 .40803 L p F P
0 g
s
.608 .46 .655 r
.2859 .56549 m .26259 .54694 L .2623 .54475 L p F P
0 g
s
.608 .46 .655 r
.2623 .54475 m .28527 .56147 L .2859 .56549 L p F P
0 g
s
.599 .462 .666 r
.29794 .51355 m .27844 .51742 L .27782 .51343 L p F P
0 g
s
.599 .462 .666 r
.27782 .51343 m .29696 .50809 L .29794 .51355 L p F P
0 g
s
.582 .461 .679 r
.30943 .46963 m .29208 .48093 L .29111 .47552 L p F P
0 g
s
.582 .461 .679 r
.29111 .47552 m .30807 .46307 L .30943 .46963 L p F P
0 g
s
.609 .46 .655 r
.28652 .56951 m .26288 .54914 L .26259 .54694 L p F P
0 g
s
.609 .46 .655 r
.26259 .54694 m .2859 .56549 L .28652 .56951 L p F P
0 g
s
.545 .45 .698 r
.31625 .41531 m .30129 .43052 L .29994 .42406 L p F P
0 g
s
.545 .45 .698 r
.29994 .42406 m .31449 .40803 L .31625 .41531 L p F P
0 g
s
.602 .463 .666 r
.29892 .51901 m .27906 .5214 L .27844 .51742 L p F P
0 g
s
.602 .463 .666 r
.27844 .51742 m .29794 .51355 L .29892 .51901 L p F P
0 g
s
.78 .363 .258 r
.93391 .49884 m .96254 .52512 L .96701 .51004 L p F P
0 g
s
.586 .463 .679 r
.31079 .47619 m .29305 .48635 L .29208 .48093 L p F P
0 g
s
.586 .463 .679 r
.29208 .48093 m .30943 .46963 L .31079 .47619 L p F P
0 g
s
.551 .454 .697 r
.31802 .42262 m .30265 .437 L .30129 .43052 L p F P
0 g
s
.551 .454 .697 r
.30129 .43052 m .31625 .41531 L .31802 .42262 L p F P
0 g
s
.604 .465 .665 r
.29991 .52447 m .27968 .5254 L .27906 .5214 L p F P
0 g
s
.604 .465 .665 r
.27906 .5214 m .29892 .51901 L .29991 .52447 L p F P
0 g
s
.771 .929 .937 r
.62832 .49303 m .6041 .50518 L .59885 .50197 L p F P
0 g
s
.771 .929 .937 r
.59885 .50197 m .62288 .49082 L .62832 .49303 L p F P
0 g
s
.634 .11 0 r
.87415 .47142 m .84815 .46002 L .84209 .46472 L p F P
0 g
s
.57 .034 0 r
.81668 .45697 m .84209 .46472 L .84815 .46002 L p F P
0 g
s
.59 .466 .679 r
.31216 .48277 m .29403 .49177 L .29305 .48635 L p F P
0 g
s
.59 .466 .679 r
.29305 .48635 m .31079 .47619 L .31216 .48277 L p F P
0 g
s
.557 .457 .696 r
.31978 .42995 m .304 .44349 L .30265 .437 L p F P
0 g
s
.557 .457 .696 r
.30265 .437 m .31802 .42262 L .31978 .42995 L p F P
0 g
s
.606 .467 .665 r
.30089 .52994 m .28029 .52939 L .27968 .5254 L p F P
0 g
s
.606 .467 .665 r
.27968 .5254 m .29991 .52447 L .30089 .52994 L p F P
0 g
s
.329 .814 .846 r
.71873 .45721 m .69473 .46331 L .68875 .4627 L p F P
0 g
s
.329 .814 .846 r
.68875 .4627 m .71264 .45729 L .71873 .45721 L p F P
0 g
s
.594 .468 .678 r
.31352 .48936 m .29501 .49721 L .29403 .49177 L p F P
0 g
s
.594 .468 .678 r
.29403 .49177 m .31216 .48277 L .31352 .48936 L p F P
0 g
s
.608 .468 .665 r
.30187 .53542 m .28091 .53339 L .28029 .52939 L p F P
0 g
s
.608 .468 .665 r
.28029 .52939 m .30089 .52994 L .30187 .53542 L p F P
0 g
s
.563 .461 .696 r
.32154 .43731 m .30536 .45 L .304 .44349 L p F P
0 g
s
.563 .461 .696 r
.304 .44349 m .31978 .42995 L .32154 .43731 L p F P
0 g
s
.509 .905 .927 r
.69473 .46331 m .67079 .47116 L .66493 .46979 L p F P
0 g
s
.509 .905 .927 r
.66493 .46979 m .68875 .4627 L .69473 .46331 L p F P
0 g
s
.597 .47 .678 r
.31489 .49595 m .29598 .50265 L .29501 .49721 L p F P
0 g
s
.597 .47 .678 r
.29501 .49721 m .31352 .48936 L .31489 .49595 L p F P
0 g
s
.61 .47 .665 r
.30286 .54089 m .28153 .53739 L .28091 .53339 L p F P
0 g
s
.61 .47 .665 r
.28091 .53339 m .30187 .53542 L .30286 .54089 L p F P
0 g
s
.814 .853 .878 r
.58474 .52132 m .56003 .53497 L .55529 .53036 L p F P
0 g
s
.814 .853 .878 r
.55529 .53036 m .57976 .51775 L .58474 .52132 L p F P
0 g
s
.82 .819 .848 r
.56473 .53905 m .53959 .55335 L .53516 .54821 L p F P
0 g
s
.82 .819 .848 r
.53516 .54821 m .56003 .53497 L .56473 .53905 L p F P
0 g
s
.569 .464 .695 r
.32331 .4447 m .30672 .45653 L .30536 .45 L p F P
0 g
s
.569 .464 .695 r
.30536 .45 m .32154 .43731 L .32331 .4447 L p F P
0 g
s
.613 .471 .665 r
.30385 .54637 m .28216 .5414 L .28153 .53739 L p F P
0 g
s
.613 .471 .665 r
.28153 .53739 m .30286 .54089 L .30385 .54637 L p F P
0 g
s
.642 .941 .961 r
.67079 .47116 m .64685 .48044 L .64115 .47825 L p F P
0 g
s
.642 .941 .961 r
.64115 .47825 m .66493 .46979 L .67079 .47116 L p F P
0 g
s
.601 .473 .678 r
.31625 .50256 m .29696 .50809 L .29598 .50265 L p F P
0 g
s
.601 .473 .678 r
.29598 .50265 m .31489 .49595 L .31625 .50256 L p F P
0 g
s
.574 .467 .695 r
.32507 .4521 m .30807 .46307 L .30672 .45653 L p F P
0 g
s
.574 .467 .695 r
.30672 .45653 m .32331 .4447 L .32507 .4521 L p F P
0 g
s
.615 .473 .665 r
.30484 .55186 m .28278 .54541 L .28216 .5414 L p F P
0 g
s
.615 .473 .665 r
.28216 .5414 m .30385 .54637 L .30484 .55186 L p F P
0 g
s
.796 .881 .908 r
.6041 .50518 m .57976 .51775 L .57474 .51356 L p F P
0 g
s
.796 .881 .908 r
.57474 .51356 m .59885 .50197 L .6041 .50518 L p F P
0 g
s
.604 .475 .678 r
.31762 .50917 m .29794 .51355 L .29696 .50809 L p F P
0 g
s
.604 .475 .678 r
.29696 .50809 m .31625 .50256 L .31762 .50917 L p F P
0 g
s
.504 .442 .721 r
.32462 .37924 m .31097 .39356 L .3092 .38637 L p F P
0 g
s
.504 .442 .721 r
.3092 .38637 m .32242 .37154 L .32462 .37924 L p F P
0 g
s
.58 .471 .694 r
.32684 .45952 m .30943 .46963 L .30807 .46307 L p F P
0 g
s
.58 .471 .694 r
.30807 .46307 m .32507 .4521 L .32684 .45952 L p F P
0 g
s
.617 .474 .665 r
.30583 .55734 m .2834 .54942 L .28278 .54541 L p F P
0 g
s
.617 .474 .665 r
.28278 .54541 m .30484 .55186 L .30583 .55734 L p F P
0 g
s
.513 .447 .719 r
.32681 .387 m .31273 .40077 L .31097 .39356 L p F P
0 g
s
.513 .447 .719 r
.31097 .39356 m .32462 .37924 L .32681 .387 L p F P
0 g
s
.608 .477 .677 r
.31899 .51579 m .29892 .51901 L .29794 .51355 L p F P
0 g
s
.608 .477 .677 r
.29794 .51355 m .31762 .50917 L .31899 .51579 L p F P
0 g
s
.585 .474 .693 r
.3286 .46696 m .31079 .47619 L .30943 .46963 L p F P
0 g
s
.585 .474 .693 r
.30943 .46963 m .32684 .45952 L .3286 .46696 L p F P
0 g
s
.724 .932 .958 r
.64685 .48044 m .62288 .49082 L .61736 .48778 L p F P
0 g
s
.724 .932 .958 r
.61736 .48778 m .64115 .47825 L .64685 .48044 L p F P
0 g
s
.619 .476 .665 r
.30682 .56283 m .28402 .55343 L .2834 .54942 L p F P
0 g
s
.619 .476 .665 r
.2834 .54942 m .30583 .55734 L .30682 .56283 L p F P
0 g
s
.522 .452 .718 r
.329 .3948 m .31449 .40803 L .31273 .40077 L p F P
0 g
s
.522 .452 .718 r
.31273 .40077 m .32681 .387 L .329 .3948 L p F P
0 g
s
.611 .48 .677 r
.32036 .52241 m .29991 .52447 L .29892 .51901 L p F P
0 g
s
.611 .48 .677 r
.29892 .51901 m .31899 .51579 L .32036 .52241 L p F P
0 g
s
.59 .477 .693 r
.33037 .47441 m .31216 .48277 L .31079 .47619 L p F P
0 g
s
.59 .477 .693 r
.31079 .47619 m .3286 .46696 L .33037 .47441 L p F P
0 g
s
.621 .477 .665 r
.30781 .56832 m .28465 .55745 L .28402 .55343 L p F P
0 g
s
.621 .477 .665 r
.28402 .55343 m .30682 .56283 L .30781 .56832 L p F P
0 g
s
.531 .456 .717 r
.33119 .40264 m .31625 .41531 L .31449 .40803 L p F P
0 g
s
.531 .456 .717 r
.31449 .40803 m .329 .3948 L .33119 .40264 L p F P
0 g
s
.615 .482 .677 r
.32173 .52904 m .30089 .52994 L .29991 .52447 L p F P
0 g
s
.615 .482 .677 r
.29991 .52447 m .32036 .52241 L .32173 .52904 L p F P
0 g
s
.623 .479 .665 r
.30881 .57381 m .28527 .56147 L .28465 .55745 L p F P
0 g
s
.623 .479 .665 r
.28465 .55745 m .30781 .56832 L .30881 .57381 L p F P
0 g
s
.595 .48 .692 r
.33214 .48188 m .31352 .48936 L .31216 .48277 L p F P
0 g
s
.595 .48 .692 r
.31216 .48277 m .33037 .47441 L .33214 .48188 L p F P
0 g
s
.539 .461 .716 r
.33338 .41053 m .31802 .42262 L .31625 .41531 L p F P
0 g
s
.539 .461 .716 r
.31625 .41531 m .33119 .40264 L .33338 .41053 L p F P
0 g
s
.687 .172 .003 r
.90088 .48734 m .87415 .47142 L .86808 .47636 L p F P
0 g
s
.634 .11 0 r
.84209 .46472 m .86808 .47636 L .87415 .47142 L p F P
0 g
s
.806 .799 .845 r
.56003 .53497 m .53516 .54821 L .5307 .54265 L p F P
0 g
s
.806 .799 .845 r
.5307 .54265 m .55529 .53036 L .56003 .53497 L p F P
0 g
s
.547 .465 .715 r
.33557 .41846 m .31978 .42995 L .31802 .42262 L p F P
0 g
s
.547 .465 .715 r
.31802 .42262 m .33338 .41053 L .33557 .41846 L p F P
0 g
s
.625 .48 .665 r
.3098 .5793 m .2859 .56549 L .28527 .56147 L p F P
0 g
s
.625 .48 .665 r
.28527 .56147 m .30881 .57381 L .3098 .5793 L p F P
0 g
s
.767 .898 .934 r
.62288 .49082 m .59885 .50197 L .59354 .49807 L p F P
0 g
s
.767 .898 .934 r
.59354 .49807 m .61736 .48778 L .62288 .49082 L p F P
0 g
s
.618 .484 .677 r
.32311 .53567 m .30187 .53542 L .30089 .52994 L p F P
0 g
s
.618 .484 .677 r
.30089 .52994 m .32173 .52904 L .32311 .53567 L p F P
0 g
s
.6 .483 .692 r
.33391 .48936 m .31489 .49595 L .31352 .48936 L p F P
0 g
s
.6 .483 .692 r
.31352 .48936 m .33214 .48188 L .33391 .48936 L p F P
0 g
s
.8 .83 .874 r
.57976 .51775 m .55529 .53036 L .55053 .52524 L p F P
0 g
s
.8 .83 .874 r
.55053 .52524 m .57474 .51356 L .57976 .51775 L p F P
0 g
s
.804 .765 .817 r
.53959 .55335 m .51426 .5667 L .51013 .56063 L p F P
0 g
s
.804 .765 .817 r
.51013 .56063 m .53516 .54821 L .53959 .55335 L p F P
0 g
s
.555 .47 .714 r
.33776 .42642 m .32154 .43731 L .31978 .42995 L p F P
0 g
s
.555 .47 .714 r
.31978 .42995 m .33557 .41846 L .33776 .42642 L p F P
0 g
s
.627 .482 .665 r
.3108 .58479 m .28652 .56951 L .2859 .56549 L p F P
0 g
s
.627 .482 .665 r
.2859 .56549 m .3098 .5793 L .3108 .58479 L p F P
0 g
s
.781 .327 .168 r
.96254 .52512 m .93391 .49884 L .9285 .50829 L p F P
0 g
s
.75 .291 .159 r
.90088 .48734 m .9285 .50829 L .93391 .49884 L p F P
0 g
s
.621 .486 .677 r
.32449 .5423 m .30286 .54089 L .30187 .53542 L p F P
0 g
s
.621 .486 .677 r
.30187 .53542 m .32311 .53567 L .32449 .5423 L p F P
0 g
s
.605 .486 .691 r
.33569 .49684 m .31625 .50256 L .31489 .49595 L p F P
0 g
s
.605 .486 .691 r
.31489 .49595 m .33391 .48936 L .33569 .49684 L p F P
0 g
s
.562 .474 .713 r
.33994 .43441 m .32331 .4447 L .32154 .43731 L p F P
0 g
s
.562 .474 .713 r
.32154 .43731 m .33776 .42642 L .33994 .43441 L p F P
0 g
s
.624 .489 .676 r
.32587 .54894 m .30385 .54637 L .30286 .54089 L p F P
0 g
s
.624 .489 .676 r
.30286 .54089 m .32449 .5423 L .32587 .54894 L p F P
0 g
s
.61 .489 .691 r
.33746 .50433 m .31762 .50917 L .31625 .50256 L p F P
0 g
s
.61 .489 .691 r
.31625 .50256 m .33569 .49684 L .33746 .50433 L p F P
0 g
s
.57 .478 .712 r
.34213 .44243 m .32507 .4521 L .32331 .4447 L p F P
0 g
s
.57 .478 .712 r
.32331 .4447 m .33994 .43441 L .34213 .44243 L p F P
0 g
s
.468 0 0 r
.84209 .46472 m .81668 .45697 L .81029 .45867 L p F P
0 g
s
.628 .491 .676 r
.32725 .55557 m .30484 .55186 L .30385 .54637 L p F P
0 g
s
.628 .491 .676 r
.30385 .54637 m .32587 .54894 L .32725 .55557 L p F P
0 g
s
.614 .493 .691 r
.33924 .51183 m .31899 .51579 L .31762 .50917 L p F P
0 g
s
.614 .493 .691 r
.31762 .50917 m .33746 .50433 L .33924 .51183 L p F P
0 g
s
.784 .854 .903 r
.59885 .50197 m .57474 .51356 L .56967 .5088 L p F P
0 g
s
.784 .854 .903 r
.56967 .5088 m .59354 .49807 L .59885 .50197 L p F P
0 g
s
.577 .482 .711 r
.34432 .45048 m .32684 .45952 L .32507 .4521 L p F P
0 g
s
.577 .482 .711 r
.32507 .4521 m .34213 .44243 L .34432 .45048 L p F P
0 g
s
.631 .493 .676 r
.32863 .5622 m .30583 .55734 L .30484 .55186 L p F P
0 g
s
.631 .493 .676 r
.30484 .55186 m .32725 .55557 L .32863 .5622 L p F P
0 g
s
.584 .486 .71 r
.34651 .45854 m .3286 .46696 L .32684 .45952 L p F P
0 g
s
.584 .486 .71 r
.32684 .45952 m .34432 .45048 L .34651 .45854 L p F P
0 g
s
.619 .496 .69 r
.34102 .51933 m .32036 .52241 L .31899 .51579 L p F P
0 g
s
.619 .496 .69 r
.31899 .51579 m .33924 .51183 L .34102 .51933 L p F P
0 g
s
.459 .872 .949 r
.71264 .45729 m .68875 .4627 L .68263 .46087 L p F P
0 g
s
.584 .913 .975 r
.68875 .4627 m .66493 .46979 L .65897 .46737 L p F P
0 g
s
.584 .913 .975 r
.65897 .46737 m .68263 .46087 L .68875 .4627 L p F P
0 g
s
.306 .792 .894 r
.73667 .45386 m .71264 .45729 L .70639 .45595 L p F P
0 g
s
.459 .872 .949 r
.68263 .46087 m .70639 .45595 L .71264 .45729 L p F P
0 g
s
.59 .49 .709 r
.3487 .46663 m .33037 .47441 L .3286 .46696 L p F P
0 g
s
.59 .49 .709 r
.3286 .46696 m .34651 .45854 L .3487 .46663 L p F P
0 g
s
.792 .781 .842 r
.55529 .53036 m .5307 .54265 L .52622 .53668 L p F P
0 g
s
.792 .781 .842 r
.52622 .53668 m .55053 .52524 L .55529 .53036 L p F P
0 g
s
.673 .92 .974 r
.66493 .46979 m .64115 .47825 L .63536 .47517 L p F P
0 g
s
.673 .92 .974 r
.63536 .47517 m .65897 .46737 L .66493 .46979 L p F P
0 g
s
.634 .495 .676 r
.33002 .56882 m .30682 .56283 L .30583 .55734 L p F P
0 g
s
.634 .495 .676 r
.30583 .55734 m .32863 .5622 L .33002 .56882 L p F P
0 g
s
.791 .75 .815 r
.53516 .54821 m .51013 .56063 L .50598 .55422 L p F P
0 g
s
.791 .75 .815 r
.50598 .55422 m .5307 .54265 L .53516 .54821 L p F P
0 g
s
.623 .499 .69 r
.3428 .52682 m .32173 .52904 L .32036 .52241 L p F P
0 g
s
.623 .499 .69 r
.32036 .52241 m .34102 .51933 L .3428 .52682 L p F P
0 g
s
.597 .494 .708 r
.35089 .47473 m .33214 .48188 L .33037 .47441 L p F P
0 g
s
.597 .494 .708 r
.33037 .47441 m .3487 .46663 L .35089 .47473 L p F P
0 g
s
.637 .497 .676 r
.3314 .57545 m .30781 .56832 L .30682 .56283 L p F P
0 g
s
.637 .497 .676 r
.30682 .56283 m .33002 .56882 L .3314 .57545 L p F P
0 g
s
.628 .501 .689 r
.34458 .53432 m .32311 .53567 L .32173 .52904 L p F P
0 g
s
.628 .501 .689 r
.32173 .52904 m .3428 .52682 L .34458 .53432 L p F P
0 g
s
.306 .792 .894 r
.70639 .45595 m .73029 .4529 L .73667 .45386 L p F P
0 g
s
.729 .901 .956 r
.64115 .47825 m .61736 .48778 L .61177 .48398 L p F P
0 g
s
.729 .901 .956 r
.61177 .48398 m .63536 .47517 L .64115 .47825 L p F P
0 g
s
.603 .498 .707 r
.35308 .48284 m .33391 .48936 L .33214 .48188 L p F P
0 g
s
.603 .498 .707 r
.33214 .48188 m .35089 .47473 L .35308 .48284 L p F P
0 g
s
.785 .718 .79 r
.51426 .5667 m .48877 .57864 L .48498 .57179 L p F P
0 g
s
.785 .718 .79 r
.48498 .57179 m .51013 .56063 L .51426 .5667 L p F P
0 g
s
.786 .808 .87 r
.57474 .51356 m .55053 .52524 L .54573 .51966 L p F P
0 g
s
.786 .808 .87 r
.54573 .51966 m .56967 .5088 L .57474 .51356 L p F P
0 g
s
.477 .447 .746 r
.33825 .36791 m .32462 .37924 L .32242 .37154 L p F P
0 g
s
.477 .447 .746 r
.32242 .37154 m .33561 .35994 L .33825 .36791 L p F P
0 g
s
.64 .5 .676 r
.3328 .58206 m .30881 .57381 L .30781 .56832 L p F P
0 g
s
.64 .5 .676 r
.30781 .56832 m .3314 .57545 L .3328 .58206 L p F P
0 g
s
.632 .504 .689 r
.34637 .54181 m .32449 .5423 L .32311 .53567 L p F P
0 g
s
.632 .504 .689 r
.32311 .53567 m .34458 .53432 L .34637 .54181 L p F P
0 g
s
.49 .453 .744 r
.34089 .37595 m .32681 .387 L .32462 .37924 L p F P
0 g
s
.49 .453 .744 r
.32462 .37924 m .33825 .36791 L .34089 .37595 L p F P
0 g
s
.609 .502 .706 r
.35527 .49096 m .33569 .49684 L .33391 .48936 L p F P
0 g
s
.609 .502 .706 r
.33391 .48936 m .35308 .48284 L .35527 .49096 L p F P
0 g
s
.502 .459 .742 r
.34353 .38406 m .329 .3948 L .32681 .387 L p F P
0 g
s
.502 .459 .742 r
.32681 .387 m .34089 .37595 L .34353 .38406 L p F P
0 g
s
.759 .869 .928 r
.61736 .48778 m .59354 .49807 L .58818 .49352 L p F P
0 g
s
.759 .869 .928 r
.58818 .49352 m .61177 .48398 L .61736 .48778 L p F P
0 g
s
.643 .502 .676 r
.33419 .58867 m .3098 .5793 L .30881 .57381 L p F P
0 g
s
.643 .502 .676 r
.30881 .57381 m .3328 .58206 L .33419 .58867 L p F P
0 g
s
.514 .465 .74 r
.34616 .39223 m .33119 .40264 L .329 .3948 L p F P
0 g
s
.514 .465 .74 r
.329 .3948 m .34353 .38406 L .34616 .39223 L p F P
0 g
s
.636 .507 .689 r
.34816 .54929 m .32587 .54894 L .32449 .5423 L p F P
0 g
s
.636 .507 .689 r
.32449 .5423 m .34637 .54181 L .34816 .54929 L p F P
0 g
s
.615 .506 .706 r
.35746 .49908 m .33746 .50433 L .33569 .49684 L p F P
0 g
s
.615 .506 .706 r
.33569 .49684 m .35527 .49096 L .35746 .49908 L p F P
0 g
s
.525 .471 .738 r
.34879 .40047 m .33338 .41053 L .33119 .40264 L p F P
0 g
s
.525 .471 .738 r
.33119 .40264 m .34616 .39223 L .34879 .40047 L p F P
0 g
s
.14 .683 .817 r
.73029 .4529 m .75441 .452 L .7609 .45273 L p F P
0 g
s
.536 .476 .736 r
.35142 .40875 m .33557 .41846 L .33338 .41053 L p F P
0 g
s
.536 .476 .736 r
.33338 .41053 m .34879 .40047 L .35142 .40875 L p F P
0 g
s
.646 .504 .675 r
.33558 .59527 m .3108 .58479 L .3098 .5793 L p F P
0 g
s
.646 .504 .675 r
.3098 .5793 m .33419 .58867 L .33558 .59527 L p F P
0 g
s
.621 .509 .705 r
.35966 .5072 m .33924 .51183 L .33746 .50433 L p F P
0 g
s
.621 .509 .705 r
.33746 .50433 m .35746 .49908 L .35966 .5072 L p F P
0 g
s
.641 .51 .688 r
.34995 .55677 m .32725 .55557 L .32587 .54894 L p F P
0 g
s
.641 .51 .688 r
.32587 .54894 m .34816 .54929 L .34995 .55677 L p F P
0 g
s
.55 0 0 r
.86808 .47636 m .84209 .46472 L .83562 .46644 L p F P
0 g
s
.779 .736 .813 r
.5307 .54265 m .50598 .55422 L .50182 .5475 L p F P
0 g
s
.779 .736 .813 r
.50182 .5475 m .52622 .53668 L .5307 .54265 L p F P
0 g
s
.546 .481 .734 r
.35404 .41709 m .33776 .42642 L .33557 .41846 L p F P
0 g
s
.546 .481 .734 r
.33557 .41846 m .35142 .40875 L .35404 .41709 L p F P
0 g
s
.73 .223 .022 r
.9285 .50829 m .90088 .48734 L .8948 .49235 L p F P
0 g
s
.687 .172 .003 r
.86808 .47636 m .8948 .49235 L .90088 .48734 L p F P
0 g
s
.627 .513 .704 r
.36186 .51532 m .34102 .51933 L .33924 .51183 L p F P
0 g
s
.627 .513 .704 r
.33924 .51183 m .35966 .5072 L .36186 .51532 L p F P
0 g
s
.556 .486 .733 r
.35666 .42548 m .33994 .43441 L .33776 .42642 L p F P
0 g
s
.556 .486 .733 r
.33776 .42642 m .35404 .41709 L .35666 .42548 L p F P
0 g
s
.774 .707 .789 r
.51013 .56063 m .48498 .57179 L .48117 .56469 L p F P
0 g
s
.774 .707 .789 r
.48117 .56469 m .50598 .55422 L .51013 .56063 L p F P
0 g
s
.779 .764 .84 r
.55053 .52524 m .52622 .53668 L .52172 .53033 L p F P
0 g
s
.779 .764 .84 r
.52172 .53033 m .54573 .51966 L .55053 .52524 L p F P
0 g
s
.645 .513 .688 r
.35174 .56423 m .32863 .5622 L .32725 .55557 L p F P
0 g
s
.645 .513 .688 r
.32725 .55557 m .34995 .55677 L .35174 .56423 L p F P
0 g
s
.772 .83 .897 r
.59354 .49807 m .56967 .5088 L .56456 .50351 L p F P
0 g
s
.772 .83 .897 r
.56456 .50351 m .58818 .49352 L .59354 .49807 L p F P
0 g
s
.565 .491 .731 r
.35929 .4339 m .34213 .44243 L .33994 .43441 L p F P
0 g
s
.565 .491 .731 r
.33994 .43441 m .35666 .42548 L .35929 .4339 L p F P
0 g
s
.633 .517 .704 r
.36405 .52342 m .3428 .52682 L .34102 .51933 L p F P
0 g
s
.633 .517 .704 r
.34102 .51933 m .36186 .51532 L .36405 .52342 L p F P
0 g
s
.574 .496 .729 r
.3619 .44235 m .34432 .45048 L .34213 .44243 L p F P
0 g
s
.574 .496 .729 r
.34213 .44243 m .35929 .4339 L .3619 .44235 L p F P
0 g
s
.649 .516 .688 r
.35354 .57168 m .33002 .56882 L .32863 .5622 L p F P
0 g
s
.649 .516 .688 r
.32863 .5622 m .35174 .56423 L .35354 .57168 L p F P
0 g
s
.582 .501 .728 r
.36452 .45083 m .34651 .45854 L .34432 .45048 L p F P
0 g
s
.582 .501 .728 r
.34432 .45048 m .3619 .44235 L .36452 .45083 L p F P
0 g
s
.638 .52 .703 r
.36626 .53152 m .34458 .53432 L .3428 .52682 L p F P
0 g
s
.638 .52 .703 r
.3428 .52682 m .36405 .52342 L .36626 .53152 L p F P
0 g
s
.764 .677 .766 r
.48877 .57864 m .46316 .58873 L .45973 .58128 L p F P
0 g
s
.764 .677 .766 r
.45973 .58128 m .48498 .57179 L .48877 .57864 L p F P
0 g
s
.653 .519 .688 r
.35534 .57911 m .3314 .57545 L .33002 .56882 L p F P
0 g
s
.653 .519 .688 r
.33002 .56882 m .35354 .57168 L .35534 .57911 L p F P
0 g
s
.591 .505 .727 r
.36714 .45934 m .3487 .46663 L .34651 .45854 L p F P
0 g
s
.591 .505 .727 r
.34651 .45854 m .36452 .45083 L .36714 .45934 L p F P
0 g
s
.644 .524 .702 r
.36846 .5396 m .34637 .54181 L .34458 .53432 L p F P
0 g
s
.644 .524 .702 r
.34458 .53432 m .36626 .53152 L .36846 .5396 L p F P
0 g
s
.772 .789 .867 r
.56967 .5088 m .54573 .51966 L .5409 .51365 L p F P
0 g
s
.772 .789 .867 r
.5409 .51365 m .56456 .50351 L .56967 .5088 L p F P
0 g
s
.599 .51 .725 r
.36976 .46785 m .35089 .47473 L .3487 .46663 L p F P
0 g
s
.599 .51 .725 r
.3487 .46663 m .36714 .45934 L .36976 .46785 L p F P
0 g
s
.657 .522 .687 r
.35714 .58653 m .3328 .58206 L .3314 .57545 L p F P
0 g
s
.657 .522 .687 r
.3314 .57545 m .35534 .57911 L .35714 .58653 L p F P
0 g
s
.607 .514 .724 r
.37238 .47638 m .35308 .48284 L .35089 .47473 L p F P
0 g
s
.607 .514 .724 r
.35089 .47473 m .36976 .46785 L .37238 .47638 L p F P
0 g
s
.763 .696 .788 r
.50598 .55422 m .48117 .56469 L .47736 .55735 L p F P
0 g
s
.763 .696 .788 r
.47736 .55735 m .50182 .5475 L .50598 .55422 L p F P
0 g
s
.649 .527 .702 r
.37067 .54767 m .34816 .54929 L .34637 .54181 L p F P
0 g
s
.649 .527 .702 r
.34637 .54181 m .36846 .5396 L .37067 .54767 L p F P
0 g
s
.767 .724 .812 r
.52622 .53668 m .50182 .5475 L .49765 .54049 L p F P
0 g
s
.767 .724 .812 r
.49765 .54049 m .52172 .53033 L .52622 .53668 L p F P
0 g
s
.614 .519 .723 r
.37499 .48492 m .35527 .49096 L .35308 .48284 L p F P
0 g
s
.614 .519 .723 r
.35308 .48284 m .37238 .47638 L .37499 .48492 L p F P
0 g
s
.661 .525 .687 r
.35894 .59392 m .33419 .58867 L .3328 .58206 L p F P
0 g
s
.661 .525 .687 r
.3328 .58206 m .35714 .58653 L .35894 .59392 L p F P
0 g
s
.654 .531 .701 r
.37288 .5557 m .34995 .55677 L .34816 .54929 L p F P
0 g
s
.654 .531 .701 r
.34816 .54929 m .37067 .54767 L .37288 .5557 L p F P
0 g
s
.755 .668 .766 r
.48498 .57179 m .45973 .58128 L .45629 .57366 L p F P
0 g
s
.755 .668 .766 r
.45629 .57366 m .48117 .56469 L .48498 .57179 L p F P
0 g
s
.621 .523 .722 r
.37761 .49345 m .35746 .49908 L .35527 .49096 L p F P
0 g
s
.621 .523 .722 r
.35527 .49096 m .37499 .48492 L .37761 .49345 L p F P
0 g
s
.627 .896 .987 r
.68263 .46087 m .65897 .46737 L .6529 .46398 L p F P
0 g
s
.687 .891 .972 r
.65897 .46737 m .63536 .47517 L .62949 .47126 L p F P
0 g
s
.687 .891 .972 r
.62949 .47126 m .6529 .46398 L .65897 .46737 L p F P
0 g
s
.727 .871 .949 r
.63536 .47517 m .61177 .48398 L .60612 .47948 L p F P
0 g
s
.727 .871 .949 r
.60612 .47948 m .62949 .47126 L .63536 .47517 L p F P
0 g
s
.628 .528 .721 r
.38023 .50198 m .35966 .5072 L .35746 .49908 L p F P
0 g
s
.628 .528 .721 r
.35746 .49908 m .37761 .49345 L .38023 .50198 L p F P
0 g
s
.766 .749 .838 r
.54573 .51966 m .52172 .53033 L .5172 .52365 L p F P
0 g
s
.766 .749 .838 r
.5172 .52365 m .5409 .51365 L .54573 .51966 L p F P
0 g
s
.659 .535 .701 r
.37509 .56371 m .35174 .56423 L .34995 .55677 L p F P
0 g
s
.659 .535 .701 r
.34995 .55677 m .37288 .5557 L .37509 .56371 L p F P
0 g
s
.543 .88 .989 r
.70639 .45595 m .68263 .46087 L .67638 .45791 L p F P
0 g
s
.627 .896 .987 r
.6529 .46398 m .67638 .45791 L .68263 .46087 L p F P
0 g
s
.665 .527 .687 r
.36075 .60129 m .33558 .59527 L .33419 .58867 L p F P
0 g
s
.665 .527 .687 r
.33419 .58867 m .35894 .59392 L .36075 .60129 L p F P
0 g
s
.635 .532 .72 r
.38285 .51049 m .36186 .51532 L .35966 .5072 L p F P
0 g
s
.635 .532 .72 r
.35966 .5072 m .38023 .50198 L .38285 .51049 L p F P
0 g
s
.781 .327 .168 r
.9285 .50829 m .95721 .53485 L .96254 .52512 L p F P
0 g
s
.749 .842 .921 r
.61177 .48398 m .58818 .49352 L .58277 .4884 L p F P
0 g
s
.749 .842 .921 r
.58277 .4884 m .60612 .47948 L .61177 .48398 L p F P
0 g
s
.664 .538 .701 r
.3773 .57169 m .35354 .57168 L .35174 .56423 L p F P
0 g
s
.664 .538 .701 r
.35174 .56423 m .37509 .56371 L .3773 .57169 L p F P
0 g
s
.642 .536 .719 r
.38547 .51898 m .36405 .52342 L .36186 .51532 L p F P
0 g
s
.642 .536 .719 r
.36186 .51532 m .38285 .51049 L .38547 .51898 L p F P
0 g
s
.439 .84 .976 r
.73029 .4529 m .70639 .45595 L .69998 .4533 L p F P
0 g
s
.543 .88 .989 r
.67638 .45791 m .69998 .4533 L .70639 .45595 L p F P
0 g
s
.744 .641 .746 r
.46316 .58873 m .43748 .59649 L .43443 .58867 L p F P
0 g
s
.744 .641 .746 r
.43443 .58867 m .45973 .58128 L .46316 .58873 L p F P
0 g
s
.752 .686 .788 r
.50182 .5475 m .47736 .55735 L .47354 .54978 L p F P
0 g
s
.752 .686 .788 r
.47354 .54978 m .49765 .54049 L .50182 .5475 L p F P
0 g
s
.669 .542 .7 r
.37952 .57964 m .35534 .57911 L .35354 .57168 L p F P
0 g
s
.669 .542 .7 r
.35354 .57168 m .3773 .57169 L .37952 .57964 L p F P
0 g
s
.649 .541 .718 r
.3881 .52745 m .36626 .53152 L .36405 .52342 L p F P
0 g
s
.649 .541 .718 r
.36405 .52342 m .38547 .51898 L .3881 .52745 L p F P
0 g
s
.746 .66 .766 r
.48117 .56469 m .45629 .57366 L .45285 .56585 L p F P
0 g
s
.746 .66 .766 r
.45285 .56585 m .47736 .55735 L .48117 .56469 L p F P
0 g
s
.759 .808 .892 r
.58818 .49352 m .56456 .50351 L .55941 .49774 L p F P
0 g
s
.759 .808 .892 r
.55941 .49774 m .58277 .4884 L .58818 .49352 L p F P
0 g
s
.655 .545 .717 r
.39072 .53588 m .36846 .5396 L .36626 .53152 L p F P
0 g
s
.655 .545 .717 r
.36626 .53152 m .3881 .52745 L .39072 .53588 L p F P
0 g
s
.755 .712 .811 r
.52172 .53033 m .49765 .54049 L .49347 .53321 L p F P
0 g
s
.755 .712 .811 r
.49347 .53321 m .5172 .52365 L .52172 .53033 L p F P
0 g
s
.674 .545 .7 r
.38174 .58754 m .35714 .58653 L .35534 .57911 L p F P
0 g
s
.674 .545 .7 r
.35534 .57911 m .37952 .57964 L .38174 .58754 L p F P
0 g
s
.662 .549 .716 r
.39335 .54428 m .37067 .54767 L .36846 .5396 L p F P
0 g
s
.662 .549 .716 r
.36846 .5396 m .39072 .53588 L .39335 .54428 L p F P
0 g
s
.736 .634 .746 r
.45973 .58128 m .43443 .58867 L .43139 .58072 L p F P
0 g
s
.736 .634 .746 r
.43139 .58072 m .45629 .57366 L .45973 .58128 L p F P
0 g
s
.614 .048 0 r
.8948 .49235 m .86808 .47636 L .86154 .47791 L p F P
0 g
s
.55 0 0 r
.83562 .46644 m .86154 .47791 L .86808 .47636 L p F P
0 g
s
.679 .549 .7 r
.38396 .5954 m .35894 .59392 L .35714 .58653 L p F P
0 g
s
.679 .549 .7 r
.35714 .58653 m .38174 .58754 L .38396 .5954 L p F P
0 g
s
.668 .553 .716 r
.39598 .55263 m .37288 .5557 L .37067 .54767 L p F P
0 g
s
.668 .553 .716 r
.37067 .54767 m .39335 .54428 L .39598 .55263 L p F P
0 g
s
.759 .771 .863 r
.56456 .50351 m .5409 .51365 L .53604 .50725 L p F P
0 g
s
.759 .771 .863 r
.53604 .50725 m .55941 .49774 L .56456 .50351 L p F P
0 g
s
.32 .777 .949 r
.75441 .452 m .73029 .4529 L .72373 .45042 L p F P
0 g
s
.439 .84 .976 r
.69998 .4533 m .72373 .45042 L .73029 .4529 L p F P
0 g
s
.674 .558 .715 r
.39861 .56094 m .37509 .56371 L .37288 .5557 L p F P
0 g
s
.674 .558 .715 r
.37288 .5557 m .39598 .55263 L .39861 .56094 L p F P
0 g
s
.736 .652 .766 r
.47736 .55735 m .45285 .56585 L .44941 .55789 L p F P
0 g
s
.736 .652 .766 r
.44941 .55789 m .47354 .54978 L .47736 .55735 L p F P
0 g
s
.684 .552 .699 r
.38619 .60322 m .36075 .60129 L .35894 .59392 L p F P
0 g
s
.684 .552 .699 r
.35894 .59392 m .38396 .5954 L .38619 .60322 L p F P
0 g
s
.68 .562 .715 r
.40124 .56918 m .3773 .57169 L .37509 .56371 L p F P
0 g
s
.68 .562 .715 r
.37509 .56371 m .39861 .56094 L .40124 .56918 L p F P
0 g
s
.728 .627 .746 r
.45629 .57366 m .43139 .58072 L .42834 .57265 L p F P
0 g
s
.728 .627 .746 r
.42834 .57265 m .45285 .56585 L .45629 .57366 L p F P
0 g
s
.51 .483 .763 r
.3643 .39215 m .34879 .40047 L .34616 .39223 L p F P
0 g
s
.51 .483 .763 r
.34616 .39223 m .36122 .38378 L .3643 .39215 L p F P
0 g
s
.495 .477 .766 r
.36122 .38378 m .34616 .39223 L .34353 .38406 L p F P
0 g
s
.524 .489 .76 r
.36737 .4006 m .35142 .40875 L .34879 .40047 L p F P
0 g
s
.524 .489 .76 r
.34879 .40047 m .3643 .39215 L .36737 .4006 L p F P
0 g
s
.495 .477 .766 r
.34353 .38406 m .35813 .37549 L .36122 .38378 L p F P
0 g
s
.48 .47 .769 r
.35813 .37549 m .34353 .38406 L .34089 .37595 L p F P
0 g
s
.536 .495 .758 r
.37044 .40912 m .35404 .41709 L .35142 .40875 L p F P
0 g
s
.536 .495 .758 r
.35142 .40875 m .36737 .4006 L .37044 .40912 L p F P
0 g
s
.48 .47 .769 r
.34089 .37595 m .35504 .36729 L .35813 .37549 L p F P
0 g
s
.463 .462 .772 r
.35504 .36729 m .34089 .37595 L .33825 .36791 L p F P
0 g
s
.742 .677 .788 r
.49765 .54049 m .47354 .54978 L .46971 .54202 L p F P
0 g
s
.742 .677 .788 r
.46971 .54202 m .49347 .53321 L .49765 .54049 L p F P
0 g
s
.549 .501 .755 r
.3735 .4177 m .35666 .42548 L .35404 .41709 L p F P
0 g
s
.549 .501 .755 r
.35404 .41709 m .37044 .40912 L .3735 .4177 L p F P
0 g
s
.723 .609 .729 r
.43748 .59649 m .4118 .60147 L .40915 .59352 L p F P
0 g
s
.723 .609 .729 r
.40915 .59352 m .43443 .58867 L .43748 .59649 L p F P
0 g
s
.463 .462 .772 r
.33825 .36791 m .35194 .35919 L .35504 .36729 L p F P
0 g
s
.445 .455 .775 r
.35194 .35919 m .33825 .36791 L .33561 .35994 L p F P
0 g
s
.56 .507 .753 r
.37656 .42633 m .35929 .4339 L .35666 .42548 L p F P
0 g
s
.56 .507 .753 r
.35666 .42548 m .3735 .4177 L .37656 .42633 L p F P
0 g
s
.445 .455 .775 r
.33561 .35994 m .34882 .35119 L .35194 .35919 L p F P
0 g
s
.571 .512 .75 r
.37962 .43501 m .3619 .44235 L .35929 .4339 L p F P
0 g
s
.571 .512 .75 r
.35929 .4339 m .37656 .42633 L .37962 .43501 L p F P
0 g
s
.686 .566 .714 r
.40388 .57737 m .37952 .57964 L .3773 .57169 L p F P
0 g
s
.686 .566 .714 r
.3773 .57169 m .40124 .56918 L .40388 .57737 L p F P
0 g
s
.753 .735 .836 r
.5409 .51365 m .5172 .52365 L .51266 .51665 L p F P
0 g
s
.753 .735 .836 r
.51266 .51665 m .53604 .50725 L .5409 .51365 L p F P
0 g
s
.581 .518 .748 r
.38267 .44372 m .36452 .45083 L .3619 .44235 L p F P
0 g
s
.581 .518 .748 r
.3619 .44235 m .37962 .43501 L .38267 .44372 L p F P
0 g
s
.591 .523 .746 r
.38572 .45246 m .36714 .45934 L .36452 .45083 L p F P
0 g
s
.591 .523 .746 r
.36452 .45083 m .38267 .44372 L .38572 .45246 L p F P
0 g
s
.601 .528 .744 r
.38877 .46121 m .36976 .46785 L .36714 .45934 L p F P
0 g
s
.601 .528 .744 r
.36714 .45934 m .38572 .45246 L .38877 .46121 L p F P
0 g
s
.692 .571 .714 r
.40651 .58548 m .38174 .58754 L .37952 .57964 L p F P
0 g
s
.692 .571 .714 r
.37952 .57964 m .40388 .57737 L .40651 .58548 L p F P
0 g
s
.61 .533 .742 r
.39182 .46997 m .37238 .47638 L .36976 .46785 L p F P
0 g
s
.61 .533 .742 r
.36976 .46785 m .38877 .46121 L .39182 .46997 L p F P
0 g
s
.717 .603 .729 r
.43443 .58867 m .40915 .59352 L .40651 .58548 L p F P
0 g
s
.717 .603 .729 r
.40651 .58548 m .43139 .58072 L .43443 .58867 L p F P
0 g
s
.619 .538 .741 r
.39486 .47874 m .37499 .48492 L .37238 .47638 L p F P
0 g
s
.619 .538 .741 r
.37238 .47638 m .39182 .46997 L .39486 .47874 L p F P
0 g
s
.628 .543 .739 r
.39791 .4875 m .37761 .49345 L .37499 .48492 L p F P
0 g
s
.628 .543 .739 r
.37499 .48492 m .39486 .47874 L .39791 .4875 L p F P
0 g
s
.698 .575 .713 r
.40915 .59352 m .38396 .5954 L .38174 .58754 L p F P
0 g
s
.698 .575 .713 r
.38174 .58754 m .40651 .58548 L .40915 .59352 L p F P
0 g
s
.636 .548 .738 r
.40095 .49624 m .38023 .50198 L .37761 .49345 L p F P
0 g
s
.636 .548 .738 r
.37761 .49345 m .39791 .4875 L .40095 .49624 L p F P
0 g
s
.72 .621 .747 r
.45285 .56585 m .42834 .57265 L .42529 .56447 L p F P
0 g
s
.72 .621 .747 r
.42529 .56447 m .44941 .55789 L .45285 .56585 L p F P
0 g
s
.644 .553 .737 r
.40399 .50495 m .38285 .51049 L .38023 .50198 L p F P
0 g
s
.644 .553 .737 r
.38023 .50198 m .40095 .49624 L .40399 .50495 L p F P
0 g
s
.71 .598 .729 r
.43139 .58072 m .40651 .58548 L .40388 .57737 L p F P
0 g
s
.71 .598 .729 r
.40388 .57737 m .42834 .57265 L .43139 .58072 L p F P
0 g
s
.652 .557 .735 r
.40703 .51363 m .38547 .51898 L .38285 .51049 L p F P
0 g
s
.652 .557 .735 r
.38285 .51049 m .40399 .50495 L .40703 .51363 L p F P
0 g
s
.704 .579 .713 r
.4118 .60147 m .38619 .60322 L .38396 .5954 L p F P
0 g
s
.704 .579 .713 r
.38396 .5954 m .40915 .59352 L .4118 .60147 L p F P
0 g
s
.727 .645 .766 r
.47354 .54978 m .44941 .55789 L .44596 .54979 L p F P
0 g
s
.727 .645 .766 r
.44596 .54979 m .46971 .54202 L .47354 .54978 L p F P
0 g
s
.66 .562 .734 r
.41008 .52227 m .3881 .52745 L .38547 .51898 L p F P
0 g
s
.66 .562 .734 r
.38547 .51898 m .40703 .51363 L .41008 .52227 L p F P
0 g
s
.744 .701 .811 r
.5172 .52365 m .49347 .53321 L .48927 .52568 L p F P
0 g
s
.744 .701 .811 r
.48927 .52568 m .51266 .51665 L .5172 .52365 L p F P
0 g
s
.667 .567 .733 r
.41312 .53085 m .39072 .53588 L .3881 .52745 L p F P
0 g
s
.667 .567 .733 r
.3881 .52745 m .41008 .52227 L .41312 .53085 L p F P
0 g
s
.674 .572 .732 r
.41616 .53937 m .39335 .54428 L .39072 .53588 L p F P
0 g
s
.674 .572 .732 r
.39072 .53588 m .41312 .53085 L .41616 .53937 L p F P
0 g
s
.682 .577 .732 r
.41921 .54782 m .39598 .55263 L .39335 .54428 L p F P
0 g
s
.682 .577 .732 r
.39335 .54428 m .41616 .53937 L .41921 .54782 L p F P
0 g
s
.689 .582 .731 r
.42225 .55619 m .39861 .56094 L .39598 .55263 L p F P
0 g
s
.689 .582 .731 r
.39598 .55263 m .41921 .54782 L .42225 .55619 L p F P
0 g
s
.703 .593 .73 r
.42834 .57265 m .40388 .57737 L .40124 .56918 L p F P
0 g
s
.696 .587 .73 r
.42529 .56447 m .40124 .56918 L .39861 .56094 L p F P
0 g
s
.696 .587 .73 r
.39861 .56094 m .42225 .55619 L .42529 .56447 L p F P
0 g
s
.703 .593 .73 r
.40124 .56918 m .42529 .56447 L .42834 .57265 L p F P
0 g
s
.196 .696 .912 r
.77881 .45357 m .75441 .452 L .7477 .44954 L p F P
0 g
s
.32 .777 .949 r
.72373 .45042 m .7477 .44954 L .75441 .452 L p F P
0 g
s
.712 .615 .747 r
.44941 .55789 m .42529 .56447 L .42225 .55619 L p F P
0 g
s
.712 .615 .747 r
.42225 .55619 m .44596 .54979 L .44941 .55789 L p F P
0 g
s
.732 .668 .788 r
.49347 .53321 m .46971 .54202 L .46588 .53407 L p F P
0 g
s
.732 .668 .788 r
.46588 .53407 m .48927 .52568 L .49347 .53321 L p F P
0 g
s
.764 .266 .031 r
.95721 .53485 m .9285 .50829 L .9224 .51318 L p F P
0 g
s
.73 .223 .022 r
.8948 .49235 m .9224 .51318 L .9285 .50829 L p F P
0 g
s
.704 .609 .748 r
.44596 .54979 m .42225 .55619 L .41921 .54782 L p F P
0 g
s
.718 .637 .767 r
.46971 .54202 m .44596 .54979 L .44252 .54155 L p F P
0 g
s
.718 .637 .767 r
.44252 .54155 m .46588 .53407 L .46971 .54202 L p F P
0 g
s
.721 .844 .94 r
.62949 .47126 m .60612 .47948 L .6004 .47435 L p F P
0 g
s
.738 .818 .914 r
.60612 .47948 m .58277 .4884 L .5773 .48274 L p F P
0 g
s
.738 .818 .914 r
.5773 .48274 m .6004 .47435 L .60612 .47948 L p F P
0 g
s
.692 .862 .963 r
.6529 .46398 m .62949 .47126 L .62354 .46659 L p F P
0 g
s
.721 .844 .94 r
.6004 .47435 m .62354 .46659 L .62949 .47126 L p F P
0 g
s
.704 .609 .748 r
.41921 .54782 m .44252 .54155 L .44596 .54979 L p F P
0 g
s
.746 .788 .887 r
.58277 .4884 m .55941 .49774 L .55423 .49153 L p F P
0 g
s
.746 .788 .887 r
.55423 .49153 m .5773 .48274 L .58277 .4884 L p F P
0 g
s
.695 .603 .749 r
.44252 .54155 m .41921 .54782 L .41616 .53937 L p F P
0 g
s
.746 .756 .86 r
.55941 .49774 m .53604 .50725 L .53116 .50048 L p F P
0 g
s
.746 .756 .86 r
.53116 .50048 m .55423 .49153 L .55941 .49774 L p F P
0 g
s
.695 .603 .749 r
.41616 .53937 m .43907 .53319 L .44252 .54155 L p F P
0 g
s
.687 .597 .75 r
.43907 .53319 m .41616 .53937 L .41312 .53085 L p F P
0 g
s
.649 .87 .982 r
.67638 .45791 m .6529 .46398 L .64674 .4597 L p F P
0 g
s
.692 .862 .963 r
.62354 .46659 m .64674 .4597 L .6529 .46398 L p F P
0 g
s
.741 .723 .835 r
.53604 .50725 m .51266 .51665 L .5081 .50937 L p F P
0 g
s
.741 .723 .835 r
.5081 .50937 m .53116 .50048 L .53604 .50725 L p F P
0 g
s
.687 .597 .75 r
.41312 .53085 m .43562 .52472 L .43907 .53319 L p F P
0 g
s
.679 .591 .751 r
.43562 .52472 m .41312 .53085 L .41008 .52227 L p F P
0 g
s
.709 .63 .768 r
.46588 .53407 m .44252 .54155 L .43907 .53319 L p F P
0 g
s
.679 .591 .751 r
.41008 .52227 m .43217 .51617 L .43562 .52472 L p F P
0 g
s
.67 .586 .752 r
.43217 .51617 m .41008 .52227 L .40703 .51363 L p F P
0 g
s
.732 .691 .81 r
.51266 .51665 m .48927 .52568 L .48506 .51794 L p F P
0 g
s
.732 .691 .81 r
.48506 .51794 m .5081 .50937 L .51266 .51665 L p F P
0 g
s
.721 .66 .788 r
.48927 .52568 m .46588 .53407 L .46204 .52596 L p F P
0 g
s
.709 .63 .768 r
.43907 .53319 m .46204 .52596 L .46588 .53407 L p F P
0 g
s
.721 .66 .788 r
.46204 .52596 m .48506 .51794 L .48927 .52568 L p F P
0 g
s
.592 .863 .994 r
.69998 .4533 m .67638 .45791 L .67002 .45391 L p F P
0 g
s
.649 .87 .982 r
.64674 .4597 m .67002 .45391 L .67638 .45791 L p F P
0 g
s
.67 .586 .752 r
.40703 .51363 m .42871 .50753 L .43217 .51617 L p F P
0 g
s
.662 .58 .753 r
.42871 .50753 m .40703 .51363 L .40399 .50495 L p F P
0 g
s
.662 .58 .753 r
.40399 .50495 m .42526 .49882 L .42871 .50753 L p F P
0 g
s
.653 .575 .755 r
.42526 .49882 m .40399 .50495 L .40095 .49624 L p F P
0 g
s
.699 .624 .768 r
.46204 .52596 m .43907 .53319 L .43562 .52472 L p F P
0 g
s
.653 .575 .755 r
.40095 .49624 m .4218 .49007 L .42526 .49882 L p F P
0 g
s
.643 .569 .756 r
.4218 .49007 m .40095 .49624 L .39791 .4875 L p F P
0 g
s
.643 .569 .756 r
.39791 .4875 m .41834 .48127 L .4218 .49007 L p F P
0 g
s
.634 .564 .758 r
.41834 .48127 m .39791 .4875 L .39486 .47874 L p F P
0 g
s
.196 .696 .912 r
.7477 .44954 m .77195 .45093 L .77881 .45357 L p F P
0 g
s
.634 .564 .758 r
.39486 .47874 m .41487 .47244 L .41834 .48127 L p F P
0 g
s
.624 .559 .76 r
.41487 .47244 m .39486 .47874 L .39182 .46997 L p F P
0 g
s
.699 .624 .768 r
.43562 .52472 m .4582 .5177 L .46204 .52596 L p F P
0 g
s
.69 .617 .77 r
.4582 .5177 m .43562 .52472 L .43217 .51617 L p F P
0 g
s
.711 .652 .789 r
.48506 .51794 m .46204 .52596 L .4582 .5177 L p F P
0 g
s
.624 .559 .76 r
.39182 .46997 m .4114 .4636 L .41487 .47244 L p F P
0 g
s
.614 .553 .763 r
.4114 .4636 m .39182 .46997 L .38877 .46121 L p F P
0 g
s
.522 .842 .999 r
.72373 .45042 m .69998 .4533 L .69343 .44945 L p F P
0 g
s
.592 .863 .994 r
.67002 .45391 m .69343 .44945 L .69998 .4533 L p F P
0 g
s
.614 .553 .763 r
.38877 .46121 m .40793 .45475 L .4114 .4636 L p F P
0 g
s
.603 .548 .765 r
.40793 .45475 m .38877 .46121 L .38572 .45246 L p F P
0 g
s
.603 .548 .765 r
.38572 .45246 m .40445 .44591 L .40793 .45475 L p F P
0 g
s
.592 .542 .768 r
.40445 .44591 m .38572 .45246 L .38267 .44372 L p F P
0 g
s
.721 .681 .811 r
.5081 .50937 m .48506 .51794 L .48084 .51 L p F P
0 g
s
.711 .652 .789 r
.4582 .5177 m .48084 .51 L .48506 .51794 L p F P
0 g
s
.69 .617 .77 r
.43217 .51617 m .45435 .50931 L .4582 .5177 L p F P
0 g
s
.681 .611 .771 r
.45435 .50931 m .43217 .51617 L .42871 .50753 L p F P
0 g
s
.592 .542 .768 r
.38267 .44372 m .40097 .4371 L .40445 .44591 L p F P
0 g
s
.581 .537 .77 r
.40097 .4371 m .38267 .44372 L .37962 .43501 L p F P
0 g
s
.729 .711 .834 r
.53116 .50048 m .5081 .50937 L .50353 .50183 L p F P
0 g
s
.721 .681 .811 r
.48084 .51 m .50353 .50183 L .5081 .50937 L p F P
0 g
s
.581 .537 .77 r
.37962 .43501 m .39748 .42831 L .40097 .4371 L p F P
0 g
s
.568 .531 .773 r
.39748 .42831 m .37962 .43501 L .37656 .42633 L p F P
0 g
s
.701 .644 .79 r
.48084 .51 m .4582 .5177 L .45435 .50931 L p F P
0 g
s
.733 .742 .858 r
.55423 .49153 m .53116 .50048 L .52625 .4934 L p F P
0 g
s
.729 .711 .834 r
.50353 .50183 m .52625 .4934 L .53116 .50048 L p F P
0 g
s
.663 .109 0 r
.9224 .51318 m .8948 .49235 L .88816 .49351 L p F P
0 g
s
.614 .048 0 r
.86154 .47791 m .88816 .49351 L .8948 .49235 L p F P
0 g
s
.568 .531 .773 r
.37656 .42633 m .39399 .41958 L .39748 .42831 L p F P
0 g
s
.555 .525 .777 r
.39399 .41958 m .37656 .42633 L .3735 .4177 L p F P
0 g
s
.681 .611 .771 r
.42871 .50753 m .4505 .50081 L .45435 .50931 L p F P
0 g
s
.671 .604 .772 r
.4505 .50081 m .42871 .50753 L .42526 .49882 L p F P
0 g
s
.733 .771 .883 r
.5773 .48274 m .55423 .49153 L .54901 .48492 L p F P
0 g
s
.733 .742 .858 r
.52625 .4934 m .54901 .48492 L .55423 .49153 L p F P
0 g
s
.555 .525 .777 r
.3735 .4177 m .39049 .4109 L .39399 .41958 L p F P
0 g
s
.541 .519 .78 r
.39049 .4109 m .3735 .4177 L .37044 .40912 L p F P
0 g
s
.727 .798 .908 r
.6004 .47435 m .5773 .48274 L .5718 .4766 L p F P
0 g
s
.733 .771 .883 r
.54901 .48492 m .5718 .4766 L .5773 .48274 L p F P
0 g
s
.541 .519 .78 r
.37044 .40912 m .38698 .40229 L .39049 .4109 L p F P
0 g
s
.527 .513 .784 r
.38698 .40229 m .37044 .40912 L .36737 .4006 L p F P
0 g
s
.671 .604 .772 r
.42526 .49882 m .44664 .49221 L .4505 .50081 L p F P
0 g
s
.661 .598 .774 r
.44664 .49221 m .42526 .49882 L .4218 .49007 L p F P
0 g
s
.443 .805 .996 r
.7477 .44954 m .72373 .45042 L .717 .44656 L p F P
0 g
s
.522 .842 .999 r
.69343 .44945 m .717 .44656 L .72373 .45042 L p F P
0 g
s
.527 .513 .784 r
.36737 .4006 m .38346 .39376 L .38698 .40229 L p F P
0 g
s
.511 .506 .788 r
.38346 .39376 m .36737 .4006 L .3643 .39215 L p F P
0 g
s
.713 .82 .931 r
.62354 .46659 m .6004 .47435 L .59463 .46864 L p F P
0 g
s
.727 .798 .908 r
.5718 .4766 m .59463 .46864 L .6004 .47435 L p F P
0 g
s
.71 .672 .811 r
.50353 .50183 m .48084 .51 L .47661 .50189 L p F P
0 g
s
.701 .644 .79 r
.45435 .50931 m .47661 .50189 L .48084 .51 L p F P
0 g
s
.69 .637 .791 r
.47661 .50189 m .45435 .50931 L .4505 .50081 L p F P
0 g
s
.511 .506 .788 r
.3643 .39215 m .37994 .38532 L .38346 .39376 L p F P
0 g
s
.493 .499 .792 r
.37994 .38532 m .3643 .39215 L .36122 .38378 L p F P
0 g
s
.661 .598 .774 r
.4218 .49007 m .44277 .48354 L .44664 .49221 L p F P
0 g
s
.651 .593 .776 r
.44277 .48354 m .4218 .49007 L .41834 .48127 L p F P
0 g
s
.691 .836 .952 r
.64674 .4597 m .62354 .46659 L .61752 .46125 L p F P
0 g
s
.713 .82 .931 r
.59463 .46864 m .61752 .46125 L .62354 .46659 L p F P
0 g
s
.493 .499 .792 r
.36122 .38378 m .3764 .37699 L .37994 .38532 L p F P
0 g
s
.475 .492 .796 r
.3764 .37699 m .36122 .38378 L .35813 .37549 L p F P
0 g
s
.651 .593 .776 r
.41834 .48127 m .4389 .47481 L .44277 .48354 L p F P
0 g
s
.64 .587 .779 r
.4389 .47481 m .41834 .48127 L .41487 .47244 L p F P
0 g
s
.717 .701 .834 r
.52625 .4934 m .50353 .50183 L .49894 .49407 L p F P
0 g
s
.71 .672 .811 r
.47661 .50189 m .49894 .49407 L .50353 .50183 L p F P
0 g
s
.475 .492 .796 r
.35813 .37549 m .37285 .36878 L .3764 .37699 L p F P
0 g
s
.454 .484 .8 r
.37285 .36878 m .35813 .37549 L .35504 .36729 L p F P
0 g
s
.69 .637 .791 r
.4505 .50081 m .47237 .49362 L .47661 .50189 L p F P
0 g
s
.68 .63 .793 r
.47237 .49362 m .4505 .50081 L .44664 .49221 L p F P
0 g
s
.077 .605 .87 r
.77195 .45093 m .79655 .45488 L .80357 .45791 L p F P
0 g
s
.454 .484 .8 r
.35504 .36729 m .36929 .36069 L .37285 .36878 L p F P
0 g
s
.432 .475 .804 r
.36929 .36069 m .35504 .36729 L .35194 .35919 L p F P
0 g
s
.64 .587 .779 r
.41487 .47244 m .43502 .46603 L .4389 .47481 L p F P
0 g
s
.629 .581 .781 r
.43502 .46603 m .41487 .47244 L .4114 .4636 L p F P
0 g
s
.66 .843 .97 r
.67002 .45391 m .64674 .4597 L .64049 .45463 L p F P
0 g
s
.691 .836 .952 r
.61752 .46125 m .64049 .45463 L .64674 .4597 L p F P
0 g
s
.699 .664 .812 r
.49894 .49407 m .47661 .50189 L .47237 .49362 L p F P
0 g
s
.721 .729 .857 r
.54901 .48492 m .52625 .4934 L .52132 .48604 L p F P
0 g
s
.717 .701 .834 r
.49894 .49407 m .52132 .48604 L .52625 .4934 L p F P
0 g
s
.432 .475 .804 r
.35194 .35919 m .36572 .35274 L .36929 .36069 L p F P
0 g
s
.407 .466 .809 r
.36572 .35274 m .35194 .35919 L .34882 .35119 L p F P
0 g
s
.629 .581 .781 r
.4114 .4636 m .43114 .45723 L .43502 .46603 L p F P
0 g
s
.618 .575 .784 r
.43114 .45723 m .4114 .4636 L .40793 .45475 L p F P
0 g
s
.68 .63 .793 r
.44664 .49221 m .46813 .48523 L .47237 .49362 L p F P
0 g
s
.669 .623 .795 r
.46813 .48523 m .44664 .49221 L .44277 .48354 L p F P
0 g
s
.36 .753 .986 r
.77195 .45093 m .7477 .44954 L .74079 .44548 L p F P
0 g
s
.443 .805 .996 r
.717 .44656 m .74079 .44548 L .7477 .44954 L p F P
0 g
s
.407 .466 .809 r
.34882 .35119 m .36213 .34494 L .36572 .35274 L p F P
0 g
s
.721 .756 .88 r
.5718 .4766 m .54901 .48492 L .54376 .47797 L p F P
0 g
s
.721 .729 .857 r
.52132 .48604 m .54376 .47797 L .54901 .48492 L p F P
0 g
s
.618 .575 .784 r
.40793 .45475 m .42724 .44843 L .43114 .45723 L p F P
0 g
s
.606 .57 .787 r
.42724 .44843 m .40793 .45475 L .40445 .44591 L p F P
0 g
s
.62 .839 .984 r
.69343 .44945 m .67002 .45391 L .66355 .44899 L p F P
0 g
s
.66 .843 .97 r
.64049 .45463 m .66355 .44899 L .67002 .45391 L p F P
0 g
s
.705 .691 .834 r
.52132 .48604 m .49894 .49407 L .49433 .48612 L p F P
0 g
s
.699 .664 .812 r
.47237 .49362 m .49433 .48612 L .49894 .49407 L p F P
0 g
s
.687 .656 .814 r
.49433 .48612 m .47237 .49362 L .46813 .48523 L p F P
0 g
s
.669 .623 .795 r
.44277 .48354 m .46387 .47674 L .46813 .48523 L p F P
0 g
s
.658 .617 .797 r
.46387 .47674 m .44277 .48354 L .4389 .47481 L p F P
0 g
s
.606 .57 .787 r
.40445 .44591 m .42334 .43963 L .42724 .44843 L p F P
0 g
s
.593 .564 .791 r
.42334 .43963 m .40445 .44591 L .40097 .4371 L p F P
0 g
s
.716 .78 .902 r
.59463 .46864 m .5718 .4766 L .56625 .47005 L p F P
0 g
s
.721 .756 .88 r
.54376 .47797 m .56625 .47005 L .5718 .4766 L p F P
0 g
s
.593 .564 .791 r
.40097 .4371 m .41943 .43086 L .42334 .43963 L p F P
0 g
s
.58 .558 .794 r
.41943 .43086 m .40097 .4371 L .39748 .42831 L p F P
0 g
s
.658 .617 .797 r
.4389 .47481 m .4596 .46817 L .46387 .47674 L p F P
0 g
s
.646 .611 .8 r
.4596 .46817 m .4389 .47481 L .43502 .46603 L p F P
0 g
s
.705 .799 .923 r
.61752 .46125 m .59463 .46864 L .5888 .46243 L p F P
0 g
s
.716 .78 .902 r
.56625 .47005 m .5888 .46243 L .59463 .46864 L p F P
0 g
s
.709 .718 .856 r
.54376 .47797 m .52132 .48604 L .51637 .47843 L p F P
0 g
s
.705 .691 .834 r
.49433 .48612 m .51637 .47843 L .52132 .48604 L p F P
0 g
s
.58 .558 .794 r
.39748 .42831 m .41551 .42213 L .41943 .43086 L p F P
0 g
s
.566 .553 .798 r
.41551 .42213 m .39748 .42831 L .39399 .41958 L p F P
0 g
s
.572 .825 .993 r
.717 .44656 m .69343 .44945 L .68675 .44453 L p F P
0 g
s
.62 .839 .984 r
.66355 .44899 m .68675 .44453 L .69343 .44945 L p F P
0 g
s
.687 .656 .814 r
.46813 .48523 m .48971 .478 L .49433 .48612 L p F P
0 g
s
.676 .649 .816 r
.48971 .478 m .46813 .48523 L .46387 .47674 L p F P
0 g
s
.764 .266 .031 r
.9224 .51318 m .95106 .53941 L .95721 .53485 L p F P
0 g
s
.693 .682 .835 r
.51637 .47843 m .49433 .48612 L .48971 .478 L p F P
0 g
s
.566 .553 .798 r
.39399 .41958 m .41158 .41346 L .41551 .42213 L p F P
0 g
s
.551 .547 .803 r
.41158 .41346 m .39399 .41958 L .39049 .4109 L p F P
0 g
s
.646 .611 .8 r
.43502 .46603 m .45531 .45953 L .4596 .46817 L p F P
0 g
s
.634 .605 .803 r
.45531 .45953 m .43502 .46603 L .43114 .45723 L p F P
0 g
s
.688 .813 .942 r
.64049 .45463 m .61752 .46125 L .61143 .45531 L p F P
0 g
s
.705 .799 .923 r
.5888 .46243 m .61143 .45531 L .61752 .46125 L p F P
0 g
s
.709 .743 .878 r
.56625 .47005 m .54376 .47797 L .53847 .47072 L p F P
0 g
s
.709 .718 .856 r
.51637 .47843 m .53847 .47072 L .54376 .47797 L p F P
0 g
s
.277 .692 .97 r
.79655 .45488 m .77195 .45093 L .76485 .44646 L p F P
0 g
s
.36 .753 .986 r
.74079 .44548 m .76485 .44646 L .77195 .45093 L p F P
0 g
s
.551 .547 .803 r
.39049 .4109 m .40764 .40487 L .41158 .41346 L p F P
0 g
s
.534 .54 .808 r
.40764 .40487 m .39049 .4109 L .38698 .40229 L p F P
0 g
s
.676 .649 .816 r
.46387 .47674 m .48507 .46975 L .48971 .478 L p F P
0 g
s
.664 .642 .818 r
.48507 .46975 m .46387 .47674 L .4596 .46817 L p F P
0 g
s
0 .512 .828 r
.79655 .45488 m .82159 .4617 L .82878 .46536 L p F P
0 g
s
.634 .605 .803 r
.43114 .45723 m .45102 .45087 L .45531 .45953 L p F P
0 g
s
.622 .599 .806 r
.45102 .45087 m .43114 .45723 L .42724 .44843 L p F P
0 g
s
.534 .54 .808 r
.38698 .40229 m .40369 .39637 L .40764 .40487 L p F P
0 g
s
.516 .534 .813 r
.40369 .39637 m .38698 .40229 L .38346 .39376 L p F P
0 g
s
.519 .799 .997 r
.74079 .44548 m .717 .44656 L .71012 .44146 L p F P
0 g
s
.572 .825 .993 r
.68675 .44453 m .71012 .44146 L .717 .44656 L p F P
0 g
s
.696 .708 .857 r
.53847 .47072 m .51637 .47843 L .51139 .47062 L p F P
0 g
s
.693 .682 .835 r
.48971 .478 m .51139 .47062 L .51637 .47843 L p F P
0 g
s
.664 .818 .957 r
.66355 .44899 m .64049 .45463 L .63415 .44886 L p F P
0 g
s
.688 .813 .942 r
.61143 .45531 m .63415 .44886 L .64049 .45463 L p F P
0 g
s
.705 .764 .898 r
.5888 .46243 m .56625 .47005 L .56066 .46313 L p F P
0 g
s
.709 .743 .878 r
.53847 .47072 m .56066 .46313 L .56625 .47005 L p F P
0 g
s
.681 .674 .837 r
.51139 .47062 m .48971 .478 L .48507 .46975 L p F P
0 g
s
.516 .534 .813 r
.38346 .39376 m .39972 .38797 L .40369 .39637 L p F P
0 g
s
.497 .527 .818 r
.39972 .38797 m .38346 .39376 L .37994 .38532 L p F P
0 g
s
.622 .599 .806 r
.42724 .44843 m .44672 .44219 L .45102 .45087 L p F P
0 g
s
.609 .593 .81 r
.44672 .44219 m .42724 .44843 L .42334 .43963 L p F P
0 g
s
.7 .159 0 r
.95106 .53941 m .9224 .51318 L .91564 .51371 L p F P
0 g
s
.663 .109 0 r
.88816 .49351 m .91564 .51371 L .9224 .51318 L p F P
0 g
s
.664 .642 .818 r
.4596 .46817 m .48042 .46139 L .48507 .46975 L p F P
0 g
s
.652 .636 .821 r
.48042 .46139 m .4596 .46817 L .45531 .45953 L p F P
0 g
s
.497 .527 .818 r
.37994 .38532 m .39574 .37971 L .39972 .38797 L p F P
0 g
s
.475 .52 .824 r
.39574 .37971 m .37994 .38532 L .3764 .37699 L p F P
0 g
s
.609 .593 .81 r
.42334 .43963 m .4424 .43352 L .44672 .44219 L p F P
0 g
s
.595 .588 .815 r
.4424 .43352 m .42334 .43963 L .41943 .43086 L p F P
0 g
s
.696 .782 .917 r
.61143 .45531 m .5888 .46243 L .58292 .45579 L p F P
0 g
s
.705 .764 .898 r
.56066 .46313 m .58292 .45579 L .5888 .46243 L p F P
0 g
s
.635 .816 .969 r
.68675 .44453 m .66355 .44899 L .65698 .44325 L p F P
0 g
s
.664 .818 .957 r
.63415 .44886 m .65698 .44325 L .66355 .44899 L p F P
0 g
s
.697 .731 .877 r
.56066 .46313 m .53847 .47072 L .53316 .46322 L p F P
0 g
s
.696 .708 .857 r
.51139 .47062 m .53316 .46322 L .53847 .47072 L p F P
0 g
s
.475 .52 .824 r
.3764 .37699 m .39175 .37159 L .39574 .37971 L p F P
0 g
s
.451 .512 .83 r
.39175 .37159 m .3764 .37699 L .37285 .36878 L p F P
0 g
s
.681 .674 .837 r
.48507 .46975 m .50639 .46264 L .51139 .47062 L p F P
0 g
s
.669 .667 .839 r
.50639 .46264 m .48507 .46975 L .48042 .46139 L p F P
0 g
s
.652 .636 .821 r
.45531 .45953 m .47575 .45296 L .48042 .46139 L p F P
0 g
s
.639 .63 .825 r
.47575 .45296 m .45531 .45953 L .45102 .45087 L p F P
0 g
s
.595 .588 .815 r
.41943 .43086 m .43807 .42489 L .4424 .43352 L p F P
0 g
s
.58 .582 .819 r
.43807 .42489 m .41943 .43086 L .41551 .42213 L p F P
0 g
s
.684 .699 .858 r
.53316 .46322 m .51139 .47062 L .50639 .46264 L p F P
0 g
s
.451 .512 .83 r
.37285 .36878 m .38774 .36362 L .39175 .37159 L p F P
0 g
s
.425 .503 .835 r
.38774 .36362 m .37285 .36878 L .36929 .36069 L p F P
0 g
s
.464 .762 .995 r
.76485 .44646 m .74079 .44548 L .7337 .44 L p F P
0 g
s
.519 .799 .997 r
.71012 .44146 m .7337 .44 L .74079 .44548 L p F P
0 g
s
.202 .623 .949 r
.82159 .4617 m .79655 .45488 L .78926 .44977 L p F P
0 g
s
.277 .692 .97 r
.76485 .44646 m .78926 .44977 L .79655 .45488 L p F P
0 g
s
.683 .793 .933 r
.63415 .44886 m .61143 .45531 L .60528 .44886 L p F P
0 g
s
.696 .782 .917 r
.58292 .45579 m .60528 .44886 L .61143 .45531 L p F P
0 g
s
.58 .582 .819 r
.41551 .42213 m .43373 .41631 L .43807 .42489 L p F P
0 g
s
.564 .577 .825 r
.43373 .41631 m .41551 .42213 L .41158 .41346 L p F P
0 g
s
.425 .503 .835 r
.36929 .36069 m .3837 .35583 L .38774 .36362 L p F P
0 g
s
.395 .492 .841 r
.3837 .35583 m .36929 .36069 L .36572 .35274 L p F P
0 g
s
.639 .63 .825 r
.45102 .45087 m .47106 .44448 L .47575 .45296 L p F P
0 g
s
.626 .624 .829 r
.47106 .44448 m .45102 .45087 L .44672 .44219 L p F P
0 g
s
.694 .752 .896 r
.58292 .45579 m .56066 .46313 L .55503 .4559 L p F P
0 g
s
.697 .731 .877 r
.53316 .46322 m .55503 .4559 L .56066 .46313 L p F P
0 g
s
.602 .804 .977 r
.71012 .44146 m .68675 .44453 L .67996 .43865 L p F P
0 g
s
.635 .816 .969 r
.65698 .44325 m .67996 .43865 L .68675 .44453 L p F P
0 g
s
.669 .667 .839 r
.48042 .46139 m .50137 .45453 L .50639 .46264 L p F P
0 g
s
.656 .66 .842 r
.50137 .45453 m .48042 .46139 L .47575 .45296 L p F P
0 g
s
.395 .492 .841 r
.36572 .35274 m .37965 .34823 L .3837 .35583 L p F P
0 g
s
.361 .481 .846 r
.37965 .34823 m .36572 .35274 L .36213 .34494 L p F P
0 g
s
.564 .577 .825 r
.41158 .41346 m .42937 .40781 L .43373 .41631 L p F P
0 g
s
.546 .571 .831 r
.42937 .40781 m .41158 .41346 L .40764 .40487 L p F P
0 g
s
.685 .721 .877 r
.55503 .4559 m .53316 .46322 L .52782 .4555 L p F P
0 g
s
.684 .699 .858 r
.50639 .46264 m .52782 .4555 L .53316 .46322 L p F P
0 g
s
.672 .691 .86 r
.52782 .4555 m .50639 .46264 L .50137 .45453 L p F P
0 g
s
.626 .624 .829 r
.44672 .44219 m .46636 .43599 L .47106 .44448 L p F P
0 g
s
.612 .619 .834 r
.46636 .43599 m .44672 .44219 L .4424 .43352 L p F P
0 g
s
.665 .798 .946 r
.65698 .44325 m .63415 .44886 L .62774 .44248 L p F P
0 g
s
.683 .793 .933 r
.60528 .44886 m .62774 .44248 L .63415 .44886 L p F P
0 g
s
0 .422 .79 r
.82159 .4617 m .84716 .47172 L .85455 .47629 L p F P
0 g
s
.361 .481 .846 r
.36213 .34494 m .37558 .34083 L .37965 .34823 L p F P
0 g
s
.688 .767 .912 r
.60528 .44886 m .58292 .45579 L .57699 .44877 L p F P
0 g
s
.694 .752 .896 r
.55503 .4559 m .57699 .44877 L .58292 .45579 L p F P
0 g
s
.546 .571 .831 r
.40764 .40487 m .42499 .39941 L .42937 .40781 L p F P
0 g
s
.527 .565 .837 r
.42499 .39941 m .40764 .40487 L .40369 .39637 L p F P
0 g
s
.656 .66 .842 r
.47575 .45296 m .49633 .44632 L .50137 .45453 L p F P
0 g
s
.643 .655 .846 r
.49633 .44632 m .47575 .45296 L .47106 .44448 L p F P
0 g
s
.41 .716 .987 r
.78926 .44977 m .76485 .44646 L .75755 .44036 L p F P
0 g
s
.464 .762 .995 r
.7337 .44 m .75755 .44036 L .76485 .44646 L p F P
0 g
s
.566 .783 .98 r
.7337 .44 m .71012 .44146 L .7031 .43526 L p F P
0 g
s
.602 .804 .977 r
.67996 .43865 m .7031 .43526 L .71012 .44146 L p F P
0 g
s
.612 .619 .834 r
.4424 .43352 m .46164 .42751 L .46636 .43599 L p F P
0 g
s
.597 .613 .839 r
.46164 .42751 m .4424 .43352 L .43807 .42489 L p F P
0 g
s
.527 .565 .837 r
.40369 .39637 m .4206 .39113 L .42499 .39941 L p F P
0 g
s
.506 .559 .844 r
.4206 .39113 m .40369 .39637 L .39972 .38797 L p F P
0 g
s
.683 .741 .895 r
.57699 .44877 m .55503 .4559 L .54936 .44842 L p F P
0 g
s
.685 .721 .877 r
.52782 .4555 m .54936 .44842 L .55503 .4559 L p F P
0 g
s
.644 .795 .955 r
.67996 .43865 m .65698 .44325 L .65032 .43679 L p F P
0 g
s
.665 .798 .946 r
.62774 .44248 m .65032 .43679 L .65698 .44325 L p F P
0 g
s
.672 .691 .86 r
.50137 .45453 m .52245 .44763 L .52782 .4555 L p F P
0 g
s
.659 .684 .863 r
.52245 .44763 m .50137 .45453 L .49633 .44632 L p F P
0 g
s
.673 .713 .878 r
.54936 .44842 m .52782 .4555 L .52245 .44763 L p F P
0 g
s
.678 .777 .926 r
.62774 .44248 m .60528 .44886 L .59906 .44196 L p F P
0 g
s
.688 .767 .912 r
.57699 .44877 m .59906 .44196 L .60528 .44886 L p F P
0 g
s
.643 .655 .846 r
.47106 .44448 m .49126 .43806 L .49633 .44632 L p F P
0 g
s
.629 .649 .851 r
.49126 .43806 m .47106 .44448 L .46636 .43599 L p F P
0 g
s
.137 .552 .924 r
.84716 .47172 m .82159 .4617 L .81408 .45566 L p F P
0 g
s
.202 .623 .949 r
.78926 .44977 m .81408 .45566 L .82159 .4617 L p F P
0 g
s
.506 .559 .844 r
.39972 .38797 m .41619 .383 L .4206 .39113 L p F P
0 g
s
.482 .552 .851 r
.41619 .383 m .39972 .38797 L .39574 .37971 L p F P
0 g
s
.597 .613 .839 r
.43807 .42489 m .4569 .41908 L .46164 .42751 L p F P
0 g
s
.58 .608 .845 r
.4569 .41908 m .43807 .42489 L .43373 .41631 L p F P
0 g
s
.482 .552 .851 r
.39574 .37971 m .41176 .37504 L .41619 .383 L p F P
0 g
s
.456 .545 .858 r
.41176 .37504 m .39574 .37971 L .39175 .37159 L p F P
0 g
s
.58 .608 .845 r
.43373 .41631 m .45214 .41072 L .4569 .41908 L p F P
0 g
s
.563 .603 .852 r
.45214 .41072 m .43373 .41631 L .42937 .40781 L p F P
0 g
s
.528 .753 .978 r
.75755 .44036 m .7337 .44 L .72646 .43324 L p F P
0 g
s
.566 .783 .98 r
.7031 .43526 m .72646 .43324 L .7337 .44 L p F P
0 g
s
.679 .756 .909 r
.59906 .44196 m .57699 .44877 L .57102 .44146 L p F P
0 g
s
.683 .741 .895 r
.54936 .44842 m .57102 .44146 L .57699 .44877 L p F P
0 g
s
.659 .684 .863 r
.49633 .44632 m .51705 .43964 L .52245 .44763 L p F P
0 g
s
.646 .679 .867 r
.51705 .43964 m .49633 .44632 L .49126 .43806 L p F P
0 g
s
.62 .784 .96 r
.7031 .43526 m .67996 .43865 L .67305 .43195 L p F P
0 g
s
.644 .795 .955 r
.65032 .43679 m .67305 .43195 L .67996 .43865 L p F P
0 g
s
.629 .649 .851 r
.46636 .43599 m .48617 .42978 L .49126 .43806 L p F P
0 g
s
.615 .644 .856 r
.48617 .42978 m .46636 .43599 L .46164 .42751 L p F P
0 g
s
.665 .781 .936 r
.65032 .43679 m .62774 .44248 L .62125 .43558 L p F P
0 g
s
.678 .777 .926 r
.59906 .44196 m .62125 .43558 L .62774 .44248 L p F P
0 g
s
.7 .159 0 r
.91564 .51371 m .94414 .53903 L .95106 .53941 L p F P
0 g
s
.456 .545 .858 r
.39175 .37159 m .4073 .36727 L .41176 .37504 L p F P
0 g
s
.426 .536 .866 r
.4073 .36727 m .39175 .37159 L .38774 .36362 L p F P
0 g
s
.359 .664 .972 r
.81408 .45566 m .78926 .44977 L .78173 .44277 L p F P
0 g
s
.41 .716 .987 r
.75755 .44036 m .78173 .44277 L .78926 .44977 L p F P
0 g
s
.672 .732 .895 r
.57102 .44146 m .54936 .44842 L .54365 .44074 L p F P
0 g
s
.673 .713 .878 r
.52245 .44763 m .54365 .44074 L .54936 .44842 L p F P
0 g
s
.661 .706 .881 r
.54365 .44074 m .52245 .44763 L .51705 .43964 L p F P
0 g
s
.563 .603 .852 r
.42937 .40781 m .44736 .40246 L .45214 .41072 L p F P
0 g
s
.543 .599 .859 r
.44736 .40246 m .42937 .40781 L .42499 .39941 L p F P
0 g
s
.615 .644 .856 r
.46164 .42751 m .48106 .42152 L .48617 .42978 L p F P
0 g
s
.599 .64 .863 r
.48106 .42152 m .46164 .42751 L .4569 .41908 L p F P
0 g
s
.426 .536 .866 r
.38774 .36362 m .40283 .3597 L .4073 .36727 L p F P
0 g
s
.391 .526 .873 r
.40283 .3597 m .38774 .36362 L .3837 .35583 L p F P
0 g
s
.646 .679 .867 r
.49126 .43806 m .51162 .43159 L .51705 .43964 L p F P
0 g
s
.632 .674 .871 r
.51162 .43159 m .49126 .43806 L .48617 .42978 L p F P
0 g
s
.672 .765 .921 r
.62125 .43558 m .59906 .44196 L .59279 .43472 L p F P
0 g
s
.679 .756 .909 r
.57102 .44146 m .59279 .43472 L .59906 .44196 L p F P
0 g
s
0 .341 .757 r
.84716 .47172 m .87338 .48529 L .88101 .49107 L p F P
0 g
s
.649 .778 .942 r
.67305 .43195 m .65032 .43679 L .64358 .42974 L p F P
0 g
s
.665 .781 .936 r
.62125 .43558 m .64358 .42974 L .65032 .43679 L p F P
0 g
s
.595 .766 .961 r
.72646 .43324 m .7031 .43526 L .69595 .4281 L p F P
0 g
s
.62 .784 .96 r
.67305 .43195 m .69595 .4281 L .7031 .43526 L p F P
0 g
s
.543 .599 .859 r
.42499 .39941 m .44256 .39434 L .44736 .40246 L p F P
0 g
s
.521 .593 .867 r
.44256 .39434 m .42499 .39941 L .4206 .39113 L p F P
0 g
s
.492 .715 .97 r
.78173 .44277 m .75755 .44036 L .75006 .4328 L p F P
0 g
s
.528 .753 .978 r
.72646 .43324 m .75006 .4328 L .75755 .44036 L p F P
0 g
s
.391 .526 .873 r
.3837 .35583 m .39832 .35237 L .40283 .3597 L p F P
0 g
s
.351 .514 .879 r
.39832 .35237 m .3837 .35583 L .37965 .34823 L p F P
0 g
s
.67 .746 .908 r
.59279 .43472 m .57102 .44146 L .56499 .43392 L p F P
0 g
s
.672 .732 .895 r
.54365 .44074 m .56499 .43392 L .57102 .44146 L p F P
0 g
s
.661 .706 .881 r
.51705 .43964 m .53791 .43293 L .54365 .44074 L p F P
0 g
s
.648 .701 .885 r
.53791 .43293 m .51705 .43964 L .51162 .43159 L p F P
0 g
s
.599 .64 .863 r
.4569 .41908 m .47593 .41332 L .48106 .42152 L p F P
0 g
s
.582 .636 .87 r
.47593 .41332 m .4569 .41908 L .45214 .41072 L p F P
0 g
s
.661 .725 .896 r
.56499 .43392 m .54365 .44074 L .53791 .43293 L p F P
0 g
s
.086 .482 .895 r
.87338 .48529 m .84716 .47172 L .8394 .46444 L p F P
0 g
s
.137 .552 .924 r
.81408 .45566 m .8394 .46444 L .84716 .47172 L p F P
0 g
s
.521 .593 .867 r
.4206 .39113 m .43774 .38637 L .44256 .39434 L p F P
0 g
s
.497 .588 .876 r
.43774 .38637 m .4206 .39113 L .41619 .383 L p F P
0 g
s
.632 .674 .871 r
.48617 .42978 m .50616 .42351 L .51162 .43159 L p F P
0 g
s
.618 .67 .877 r
.50616 .42351 m .48617 .42978 L .48106 .42152 L p F P
0 g
s
.351 .514 .879 r
.37965 .34823 m .39379 .3453 L .39832 .35237 L p F P
0 g
s
.304 .5 .884 r
.39379 .3453 m .37965 .34823 L .37558 .34083 L p F P
0 g
s
.663 .769 .928 r
.64358 .42974 m .62125 .43558 L .6147 .42827 L p F P
0 g
s
.672 .765 .921 r
.59279 .43472 m .6147 .42827 L .62125 .43558 L p F P
0 g
s
.633 .768 .945 r
.69595 .4281 m .67305 .43195 L .66605 .42455 L p F P
0 g
s
.649 .778 .942 r
.64358 .42974 m .66605 .42455 L .67305 .43195 L p F P
0 g
s
.314 .607 .951 r
.8394 .46444 m .81408 .45566 L .80629 .44748 L p F P
0 g
s
.359 .664 .972 r
.78173 .44277 m .80629 .44748 L .81408 .45566 L p F P
0 g
s
.582 .636 .87 r
.45214 .41072 m .47076 .40522 L .47593 .41332 L p F P
0 g
s
.563 .632 .878 r
.47076 .40522 m .45214 .41072 L .44736 .40246 L p F P
0 g
s
.569 .74 .956 r
.75006 .4328 m .72646 .43324 L .71906 .42539 L p F P
0 g
s
.595 .766 .961 r
.69595 .4281 m .71906 .42539 L .72646 .43324 L p F P
0 g
s
.497 .588 .876 r
.41619 .383 m .43288 .3786 L .43774 .38637 L p F P
0 g
s
.469 .582 .885 r
.43288 .3786 m .41619 .383 L .41176 .37504 L p F P
0 g
s
.304 .5 .884 r
.37558 .34083 m .38922 .3385 L .39379 .3453 L p F P
0 g
s
.648 .701 .885 r
.51162 .43159 m .53214 .42505 L .53791 .43293 L p F P
0 g
s
.635 .696 .89 r
.53214 .42505 m .51162 .43159 L .50616 .42351 L p F P
0 g
s
.665 .756 .918 r
.6147 .42827 m .59279 .43472 L .58647 .4272 L p F P
0 g
s
.67 .746 .908 r
.56499 .43392 m .58647 .4272 L .59279 .43472 L p F P
0 g
s
.618 .67 .877 r
.48106 .42152 m .50067 .41547 L .50616 .42351 L p F P
0 g
s
.602 .666 .885 r
.50067 .41547 m .48106 .42152 L .47593 .41332 L p F P
0 g
s
.661 .725 .896 r
.53791 .43293 m .55893 .42621 L .56499 .43392 L p F P
0 g
s
.65 .72 .899 r
.55893 .42621 m .53791 .43293 L .53214 .42505 L p F P
0 g
s
.661 .74 .908 r
.58647 .4272 m .56499 .43392 L .55893 .42621 L p F P
0 g
s
.457 .672 .956 r
.80629 .44748 m .78173 .44277 L .77397 .43412 L p F P
0 g
s
.492 .715 .97 r
.75006 .4328 m .77397 .43412 L .78173 .44277 L p F P
0 g
s
.563 .632 .878 r
.44736 .40246 m .46558 .39724 L .47076 .40522 L p F P
0 g
s
.541 .628 .887 r
.46558 .39724 m .44736 .40246 L .44256 .39434 L p F P
0 g
s
.652 .766 .932 r
.66605 .42455 m .64358 .42974 L .63675 .4222 L p F P
0 g
s
.663 .769 .928 r
.6147 .42827 m .63675 .4222 L .64358 .42974 L p F P
0 g
s
.469 .582 .885 r
.41176 .37504 m .42801 .37104 L .43288 .3786 L p F P
0 g
s
.436 .575 .894 r
.42801 .37104 m .41176 .37504 L .4073 .36727 L p F P
0 g
s
.615 .751 .943 r
.71906 .42539 m .69595 .4281 L .68869 .42014 L p F P
0 g
s
.633 .768 .945 r
.66605 .42455 m .68869 .42014 L .69595 .4281 L p F P
0 g
s
.635 .696 .89 r
.50616 .42351 m .52632 .41714 L .53214 .42505 L p F P
0 g
s
.621 .693 .896 r
.52632 .41714 m .50616 .42351 L .50067 .41547 L p F P
0 g
s
.602 .666 .885 r
.47593 .41332 m .49515 .4075 L .50067 .41547 L p F P
0 g
s
.584 .664 .893 r
.49515 .4075 m .47593 .41332 L .47076 .40522 L p F P
0 g
s
.66 .759 .923 r
.63675 .4222 m .6147 .42827 L .60809 .42064 L p F P
0 g
s
.665 .756 .918 r
.58647 .4272 m .60809 .42064 L .6147 .42827 L p F P
0 g
s
.436 .575 .894 r
.4073 .36727 m .4231 .36373 L .42801 .37104 L p F P
0 g
s
.398 .566 .903 r
.4231 .36373 m .4073 .36727 L .40283 .3597 L p F P
0 g
s
.541 .628 .887 r
.44256 .39434 m .46036 .38944 L .46558 .39724 L p F P
0 g
s
.517 .625 .897 r
.46036 .38944 m .44256 .39434 L .43774 .38637 L p F P
0 g
s
.544 .707 .947 r
.77397 .43412 m .75006 .4328 L .7424 .42398 L p F P
0 g
s
.569 .74 .956 r
.71906 .42539 m .7424 .42398 L .75006 .4328 L p F P
0 g
s
.65 .72 .899 r
.53214 .42505 m .55282 .41842 L .55893 .42621 L p F P
0 g
s
.638 .716 .904 r
.55282 .41842 m .53214 .42505 L .52632 .41714 L p F P
0 g
s
.659 .749 .917 r
.60809 .42064 m .58647 .4272 L .58009 .41949 L p F P
0 g
s
.661 .74 .908 r
.55893 .42621 m .58009 .41949 L .58647 .4272 L p F P
0 g
s
.641 .756 .932 r
.68869 .42014 m .66605 .42455 L .65895 .41659 L p F P
0 g
s
.652 .766 .932 r
.63675 .4222 m .65895 .41659 L .66605 .42455 L p F P
0 g
s
0 .27 .729 r
.87338 .48529 m .90037 .5028 L .90828 .51016 L p F P
0 g
s
.651 .735 .911 r
.58009 .41949 m .55893 .42621 L .55282 .41842 L p F P
0 g
s
.049 .417 .864 r
.90037 .5028 m .87338 .48529 L .86533 .47643 L p F P
0 g
s
.086 .482 .895 r
.8394 .46444 m .86533 .47643 L .87338 .48529 L p F P
0 g
s
.398 .566 .903 r
.40283 .3597 m .41816 .35671 L .4231 .36373 L p F P
0 g
s
.353 .555 .91 r
.41816 .35671 m .40283 .3597 L .39832 .35237 L p F P
0 g
s
.277 .549 .925 r
.86533 .47643 m .8394 .46444 L .83132 .45474 L p F P
0 g
s
.314 .607 .951 r
.80629 .44748 m .83132 .45474 L .8394 .46444 L p F P
0 g
s
.584 .664 .893 r
.47076 .40522 m .4896 .39965 L .49515 .4075 L p F P
0 g
s
.565 .661 .902 r
.4896 .39965 m .47076 .40522 L .46558 .39724 L p F P
0 g
s
.517 .625 .897 r
.43774 .38637 m .45511 .38184 L .46036 .38944 L p F P
0 g
s
.489 .621 .907 r
.45511 .38184 m .43774 .38637 L .43288 .3786 L p F P
0 g
s
.597 .728 .936 r
.7424 .42398 m .71906 .42539 L .71153 .41661 L p F P
0 g
s
.615 .751 .943 r
.68869 .42014 m .71153 .41661 L .71906 .42539 L p F P
0 g
s
.621 .693 .896 r
.50067 .41547 m .52048 .40927 L .52632 .41714 L p F P
0 g
s
.606 .692 .903 r
.52048 .40927 m .50067 .41547 L .49515 .4075 L p F P
0 g
s
.654 .757 .925 r
.65895 .41659 m .63675 .4222 L .62985 .41429 L p F P
0 g
s
.66 .759 .923 r
.60809 .42064 m .62985 .41429 L .63675 .4222 L p F P
0 g
s
.426 .625 .936 r
.83132 .45474 m .80629 .44748 L .79825 .43741 L p F P
0 g
s
.457 .672 .956 r
.77397 .43412 m .79825 .43741 L .80629 .44748 L p F P
0 g
s
.353 .555 .91 r
.39832 .35237 m .41318 .34998 L .41816 .35671 L p F P
0 g
s
.3 .541 .914 r
.41318 .34998 m .39832 .35237 L .39379 .3453 L p F P
0 g
s
.638 .716 .904 r
.52632 .41714 m .54667 .4106 L .55282 .41842 L p F P
0 g
s
.625 .715 .91 r
.54667 .4106 m .52632 .41714 L .52048 .40927 L p F P
0 g
s
.657 .753 .921 r
.62985 .41429 m .60809 .42064 L .60141 .41279 L p F P
0 g
s
.659 .749 .917 r
.58009 .41949 m .60141 .41279 L .60809 .42064 L p F P
0 g
s
.489 .621 .907 r
.43288 .3786 m .44983 .37449 L .45511 .38184 L p F P
0 g
s
.457 .616 .918 r
.44983 .37449 m .43288 .3786 L .42801 .37104 L p F P
0 g
s
.63 .741 .928 r
.71153 .41661 m .68869 .42014 L .68133 .41152 L p F P
0 g
s
.641 .756 .932 r
.65895 .41659 m .68133 .41152 L .68869 .42014 L p F P
0 g
s
.52 .67 .932 r
.79825 .43741 m .77397 .43412 L .76603 .42403 L p F P
0 g
s
.544 .707 .947 r
.7424 .42398 m .76603 .42403 L .77397 .43412 L p F P
0 g
s
.565 .661 .902 r
.46558 .39724 m .48402 .39197 L .4896 .39965 L p F P
0 g
s
.542 .66 .913 r
.48402 .39197 m .46558 .39724 L .46036 .38944 L p F P
0 g
s
.651 .735 .911 r
.55282 .41842 m .57366 .41168 L .58009 .41949 L p F P
0 g
s
.642 .733 .915 r
.57366 .41168 m .55282 .41842 L .54667 .4106 L p F P
0 g
s
.653 .745 .918 r
.60141 .41279 m .58009 .41949 L .57366 .41168 L p F P
0 g
s
.606 .692 .903 r
.49515 .4075 m .51459 .4015 L .52048 .40927 L p F P
0 g
s
.589 .691 .913 r
.51459 .4015 m .49515 .4075 L .4896 .39965 L p F P
0 g
s
.3 .541 .914 r
.39379 .3453 m .40816 .3436 L .41318 .34998 L p F P
0 g
s
.237 .521 .914 r
.40816 .3436 m .39379 .3453 L .38922 .3385 L p F P
0 g
s
.58 .7 .924 r
.76603 .42403 m .7424 .42398 L .73459 .4141 L p F P
0 g
s
.597 .728 .936 r
.71153 .41661 m .73459 .4141 L .7424 .42398 L p F P
0 g
s
.648 .749 .923 r
.68133 .41152 m .65895 .41659 L .65177 .4082 L p F P
0 g
s
.654 .757 .925 r
.62985 .41429 m .65177 .4082 L .65895 .41659 L p F P
0 g
s
.457 .616 .918 r
.42801 .37104 m .44451 .36743 L .44983 .37449 L p F P
0 g
s
.418 .61 .928 r
.44451 .36743 m .42801 .37104 L .4231 .36373 L p F P
0 g
s
.542 .66 .913 r
.46036 .38944 m .4784 .38451 L .48402 .39197 L p F P
0 g
s
.516 .658 .924 r
.4784 .38451 m .46036 .38944 L .45511 .38184 L p F P
0 g
s
.625 .715 .91 r
.52048 .40927 m .54047 .40284 L .54667 .4106 L p F P
0 g
s
.611 .715 .918 r
.54047 .40284 m .52048 .40927 L .51459 .4015 L p F P
0 g
s
.655 .752 .921 r
.65177 .4082 m .62985 .41429 L .62288 .40613 L p F P
0 g
s
.657 .753 .921 r
.60141 .41279 m .62288 .40613 L .62985 .41429 L p F P
0 g
s
.237 .521 .914 r
.38922 .3385 m .40311 .33759 L .40816 .3436 L p F P
0 g
s
.618 .72 .919 r
.73459 .4141 m .71153 .41661 L .70388 .40709 L p F P
0 g
s
.63 .741 .928 r
.68133 .41152 m .70388 .40709 L .71153 .41661 L p F P
0 g
s
.589 .691 .913 r
.4896 .39965 m .50866 .39388 L .51459 .4015 L p F P
0 g
s
.569 .691 .923 r
.50866 .39388 m .4896 .39965 L .48402 .39197 L p F P
0 g
s
.642 .733 .915 r
.54667 .4106 m .56719 .40385 L .57366 .41168 L p F P
0 g
s
.631 .733 .921 r
.56719 .40385 m .54667 .4106 L .54047 .40284 L p F P
0 g
s
.654 .751 .921 r
.62288 .40613 m .60141 .41279 L .59467 .40483 L p F P
0 g
s
.653 .745 .918 r
.57366 .41168 m .59467 .40483 L .60141 .41279 L p F P
0 g
s
.049 .417 .864 r
.86533 .47643 m .89197 .49197 L .90037 .5028 L p F P
0 g
s
.249 .494 .894 r
.89197 .49197 m .86533 .47643 L .8569 .46482 L p F P
0 g
s
.277 .549 .925 r
.83132 .45474 m .8569 .46482 L .86533 .47643 L p F P
0 g
s
.399 .577 .911 r
.8569 .46482 m .83132 .45474 L .82294 .44289 L p F P
0 g
s
.426 .625 .936 r
.79825 .43741 m .82294 .44289 L .83132 .45474 L p F P
0 g
s
.418 .61 .928 r
.4231 .36373 m .43915 .36069 L .44451 .36743 L p F P
0 g
s
.371 .601 .937 r
.43915 .36069 m .4231 .36373 L .41816 .35671 L p F P
0 g
s
.646 .744 .921 r
.59467 .40483 m .57366 .41168 L .56719 .40385 L p F P
0 g
s
.497 .631 .911 r
.82294 .44289 m .79825 .43741 L .78998 .42571 L p F P
0 g
s
.52 .67 .932 r
.76603 .42403 m .78998 .42571 L .79825 .43741 L p F P
0 g
s
0 .21 .705 r
.90037 .5028 m .92827 .52469 L .93653 .53401 L p F P
0 g
s
.027 .36 .833 r
.92827 .52469 m .90037 .5028 L .89197 .49197 L p F P
0 g
s
.641 .735 .917 r
.70388 .40709 m .68133 .41152 L .67386 .40242 L p F P
0 g
s
.648 .749 .923 r
.65177 .4082 m .67386 .40242 L .68133 .41152 L p F P
0 g
s
.516 .658 .924 r
.45511 .38184 m .47274 .37732 L .4784 .38451 L p F P
0 g
s
.485 .656 .936 r
.47274 .37732 m .45511 .38184 L .44983 .37449 L p F P
0 g
s
.563 .667 .908 r
.78998 .42571 m .76603 .42403 L .75791 .41273 L p F P
0 g
s
.58 .7 .924 r
.73459 .4141 m .75791 .41273 L .76603 .42403 L p F P
0 g
s
.611 .715 .918 r
.51459 .4015 m .53423 .3952 L .54047 .40284 L p F P
0 g
s
.596 .716 .928 r
.53423 .3952 m .51459 .4015 L .50866 .39388 L p F P
0 g
s
.569 .691 .923 r
.48402 .39197 m .5027 .38648 L .50866 .39388 L p F P
0 g
s
.546 .692 .935 r
.5027 .38648 m .48402 .39197 L .4784 .38451 L p F P
0 g
s
.653 .745 .917 r
.67386 .40242 m .65177 .4082 L .64452 .39952 L p F P
0 g
s
.655 .752 .921 r
.62288 .40613 m .64452 .39952 L .65177 .4082 L p F P
0 g
s
.371 .601 .937 r
.41816 .35671 m .43376 .3543 L .43915 .36069 L p F P
0 g
s
.314 .588 .941 r
.43376 .3543 m .41816 .35671 L .41318 .34998 L p F P
0 g
s
.606 .695 .906 r
.75791 .41273 m .73459 .4141 L .72665 .40337 L p F P
0 g
s
.618 .72 .919 r
.70388 .40709 m .72665 .40337 L .73459 .4141 L p F P
0 g
s
.631 .733 .921 r
.54047 .40284 m .56066 .39609 L .56719 .40385 L p F P
0 g
s
.619 .734 .929 r
.56066 .39609 m .54047 .40284 L .53423 .3952 L p F P
0 g
s
.485 .656 .936 r
.44983 .37449 m .46704 .37044 L .47274 .37732 L p F P
0 g
s
.448 .654 .948 r
.46704 .37044 m .44983 .37449 L .44451 .36743 L p F P
0 g
s
.656 .75 .919 r
.64452 .39952 m .62288 .40613 L .61585 .39783 L p F P
0 g
s
.654 .751 .921 r
.59467 .40483 m .61585 .39783 L .62288 .40613 L p F P
0 g
s
.646 .744 .921 r
.56719 .40385 m .58788 .39684 L .59467 .40483 L p F P
0 g
s
.638 .746 .927 r
.58788 .39684 m .56719 .40385 L .56066 .39609 L p F P
0 g
s
.651 .751 .923 r
.61585 .39783 m .59467 .40483 L .58788 .39684 L p F P
0 g
s
.635 .716 .906 r
.72665 .40337 m .70388 .40709 L .69613 .397 L p F P
0 g
s
.641 .735 .917 r
.67386 .40242 m .69613 .397 L .70388 .40709 L p F P
0 g
s
.314 .588 .941 r
.41318 .34998 m .42831 .34832 L .43376 .3543 L p F P
0 g
s
.245 .569 .939 r
.42831 .34832 m .41318 .34998 L .40816 .3436 L p F P
0 g
s
.596 .716 .928 r
.50866 .39388 m .52795 .38775 L .53423 .3952 L p F P
0 g
s
.577 .719 .939 r
.52795 .38775 m .50866 .39388 L .5027 .38648 L p F P
0 g
s
.546 .692 .935 r
.4784 .38451 m .49669 .37935 L .5027 .38648 L p F P
0 g
s
.519 .693 .947 r
.49669 .37935 m .4784 .38451 L .47274 .37732 L p F P
0 g
s
.399 .577 .911 r
.82294 .44289 m .84814 .45078 L .8569 .46482 L p F P
0 g
s
.477 .59 .888 r
.84814 .45078 m .82294 .44289 L .81432 .42918 L p F P
0 g
s
.497 .631 .911 r
.78998 .42571 m .81432 .42918 L .82294 .44289 L p F P
0 g
s
.651 .733 .909 r
.69613 .397 m .67386 .40242 L .66632 .39298 L p F P
0 g
s
.653 .745 .917 r
.64452 .39952 m .66632 .39298 L .67386 .40242 L p F P
0 g
s
.546 .633 .888 r
.81432 .42918 m .78998 .42571 L .78153 .41263 L p F P
0 g
s
.563 .667 .908 r
.75791 .41273 m .78153 .41263 L .78998 .42571 L p F P
0 g
s
.448 .654 .948 r
.44451 .36743 m .46129 .36391 L .46704 .37044 L p F P
0 g
s
.403 .649 .957 r
.46129 .36391 m .44451 .36743 L .43915 .36069 L p F P
0 g
s
.249 .494 .894 r
.8569 .46482 m .88313 .47802 L .89197 .49197 L p F P
0 g
s
.376 .53 .883 r
.88313 .47802 m .8569 .46482 L .84814 .45078 L p F P
0 g
s
.594 .666 .889 r
.78153 .41263 m .75791 .41273 L .74965 .40046 L p F P
0 g
s
.606 .695 .906 r
.72665 .40337 m .74965 .40046 L .75791 .41273 L p F P
0 g
s
.619 .734 .929 r
.53423 .3952 m .55408 .38848 L .56066 .39609 L p F P
0 g
s
.606 .738 .939 r
.55408 .38848 m .53423 .3952 L .52795 .38775 L p F P
0 g
s
.658 .745 .914 r
.66632 .39298 m .64452 .39952 L .63719 .39068 L p F P
0 g
s
.656 .75 .919 r
.61585 .39783 m .63719 .39068 L .64452 .39952 L p F P
0 g
s
.027 .36 .833 r
.89197 .49197 m .91945 .51143 L .92827 .52469 L p F P
0 g
s
.228 .443 .862 r
.91945 .51143 m .89197 .49197 L .88313 .47802 L p F P
0 g
s
.245 .569 .939 r
.40816 .3436 m .42282 .34277 L .42831 .34832 L p F P
0 g
s
.162 .541 .925 r
.42282 .34277 m .40816 .3436 L .40311 .33759 L p F P
0 g
s
.657 .752 .92 r
.63719 .39068 m .61585 .39783 L .60875 .38952 L p F P
0 g
s
.651 .751 .923 r
.58788 .39684 m .60875 .38952 L .61585 .39783 L p F P
0 g
s
.638 .746 .927 r
.56066 .39609 m .58103 .38895 L .58788 .39684 L p F P
0 g
s
.63 .75 .934 r
.58103 .38895 m .56066 .39609 L .55408 .38848 L p F P
0 g
s
.519 .693 .947 r
.47274 .37732 m .49063 .37255 L .49669 .37935 L p F P
0 g
s
.487 .694 .96 r
.49063 .37255 m .47274 .37732 L .46704 .37044 L p F P
0 g
s
.628 .693 .891 r
.74965 .40046 m .72665 .40337 L .71859 .39199 L p F P
0 g
s
.635 .716 .906 r
.69613 .397 m .71859 .39199 L .72665 .40337 L p F P
0 g
s
.577 .719 .939 r
.5027 .38648 m .52161 .38057 L .52795 .38775 L p F P
0 g
s
.556 .723 .952 r
.52161 .38057 m .5027 .38648 L .49669 .37935 L p F P
0 g
s
.647 .754 .928 r
.60875 .38952 m .58788 .39684 L .58103 .38895 L p F P
0 g
s
.403 .649 .957 r
.43915 .36069 m .4555 .35781 L .46129 .36391 L p F P
0 g
s
.346 .64 .963 r
.4555 .35781 m .43915 .36069 L .43376 .3543 L p F P
0 g
s
.649 .716 .897 r
.71859 .39199 m .69613 .397 L .68829 .38652 L p F P
0 g
s
.651 .733 .909 r
.66632 .39298 m .68829 .38652 L .69613 .397 L p F P
0 g
s
.162 .541 .925 r
.40311 .33759 m .41727 .33771 L .42282 .34277 L p F P
0 g
s
.606 .738 .939 r
.52795 .38775 m .54745 .38111 L .55408 .38848 L p F P
0 g
s
.59 .745 .95 r
.54745 .38111 m .52795 .38775 L .52161 .38057 L p F P
0 g
s
.661 .734 .904 r
.68829 .38652 m .66632 .39298 L .65869 .38336 L p F P
0 g
s
.658 .745 .914 r
.63719 .39068 m .65869 .38336 L .66632 .39298 L p F P
0 g
s
.487 .694 .96 r
.46704 .37044 m .48453 .36615 L .49063 .37255 L p F P
0 g
s
.446 .694 .971 r
.48453 .36615 m .46704 .37044 L .46129 .36391 L p F P
0 g
s
.477 .59 .888 r
.81432 .42918 m .8391 .43464 L .84814 .45078 L p F P
0 g
s
.531 .597 .865 r
.8391 .43464 m .81432 .42918 L .80548 .41392 L p F P
0 g
s
.546 .633 .888 r
.78153 .41263 m .80548 .41392 L .81432 .42918 L p F P
0 g
s
.583 .635 .869 r
.80548 .41392 m .78153 .41263 L .77291 .39844 L p F P
0 g
s
.594 .666 .889 r
.74965 .40046 m .77291 .39844 L .78153 .41263 L p F P
0 g
s
.556 .723 .952 r
.49669 .37935 m .51523 .37373 L .52161 .38057 L p F P
0 g
s
.529 .728 .965 r
.51523 .37373 m .49669 .37935 L .49063 .37255 L p F P
0 g
s
.663 .748 .914 r
.65869 .38336 m .63719 .39068 L .62979 .38183 L p F P
0 g
s
.657 .752 .92 r
.60875 .38952 m .62979 .38183 L .63719 .39068 L p F P
0 g
s
.376 .53 .883 r
.84814 .45078 m .87392 .46132 L .88313 .47802 L p F P
0 g
s
.459 .55 .861 r
.87392 .46132 m .84814 .45078 L .8391 .43464 L p F P
0 g
s
.346 .64 .963 r
.43376 .3543 m .44966 .35216 L .4555 .35781 L p F P
0 g
s
.276 .624 .96 r
.44966 .35216 m .43376 .3543 L .42831 .34832 L p F P
0 g
s
.63 .75 .934 r
.55408 .38848 m .57413 .38123 L .58103 .38895 L p F P
0 g
s
.62 .757 .944 r
.57413 .38123 m .55408 .38848 L .54745 .38111 L p F P
0 g
s
.62 .667 .874 r
.77291 .39844 m .74965 .40046 L .74126 .38744 L p F P
0 g
s
.628 .693 .891 r
.71859 .39199 m .74126 .38744 L .74965 .40046 L p F P
0 g
s
.657 .758 .924 r
.62979 .38183 m .60875 .38952 L .60159 .38131 L p F P
0 g
s
.647 .754 .928 r
.58103 .38895 m .60159 .38131 L .60875 .38952 L p F P
0 g
s
.642 .761 .935 r
.60159 .38131 m .58103 .38895 L .57413 .38123 L p F P
0 g
s
.646 .695 .881 r
.74126 .38744 m .71859 .39199 L .71043 .38017 L p F P
0 g
s
.649 .716 .897 r
.68829 .38652 m .71043 .38017 L .71859 .39199 L p F P
0 g
s
.228 .443 .862 r
.88313 .47802 m .91012 .49466 L .91945 .51143 L p F P
0 g
s
.358 .487 .853 r
.91012 .49466 m .88313 .47802 L .87392 .46132 L p F P
0 g
s
.59 .745 .95 r
.52161 .38057 m .54076 .37407 L .54745 .38111 L p F P
0 g
s
.571 .752 .963 r
.54076 .37407 m .52161 .38057 L .51523 .37373 L p F P
0 g
s
.662 .719 .891 r
.71043 .38017 m .68829 .38652 L .68035 .37584 L p F P
0 g
s
.661 .734 .904 r
.65869 .38336 m .68035 .37584 L .68829 .38652 L p F P
0 g
s
.446 .694 .971 r
.46129 .36391 m .47837 .3602 L .48453 .36615 L p F P
0 g
s
.394 .69 .979 r
.47837 .3602 m .46129 .36391 L .4555 .35781 L p F P
0 g
s
.276 .624 .96 r
.42831 .34832 m .44375 .34702 L .44966 .35216 L p F P
0 g
s
.19 .597 .944 r
.44375 .34702 m .42831 .34832 L .42282 .34277 L p F P
0 g
s
.529 .728 .965 r
.49063 .37255 m .50879 .3673 L .51523 .37373 L p F P
0 g
s
.496 .733 .978 r
.50879 .3673 m .49063 .37255 L .48453 .36615 L p F P
0 g
s
.669 .739 .903 r
.68035 .37584 m .65869 .38336 L .65099 .37373 L p F P
0 g
s
.663 .748 .914 r
.62979 .38183 m .65099 .37373 L .65869 .38336 L p F P
0 g
s
.62 .757 .944 r
.54745 .38111 m .56716 .37381 L .57413 .38123 L p F P
0 g
s
.607 .767 .956 r
.56716 .37381 m .54745 .38111 L .54076 .37407 L p F P
0 g
s
.531 .597 .865 r
.80548 .41392 m .82981 .41675 L .8391 .43464 L p F P
0 g
s
.571 .604 .846 r
.82981 .41675 m .80548 .41392 L .79645 .39741 L p F P
0 g
s
.583 .635 .869 r
.77291 .39844 m .79645 .39741 L .80548 .41392 L p F P
0 g
s
.612 .639 .853 r
.79645 .39741 m .77291 .39844 L .76415 .38342 L p F P
0 g
s
.62 .667 .874 r
.74126 .38744 m .76415 .38342 L .77291 .39844 L p F P
0 g
s
.668 .756 .916 r
.65099 .37373 m .62979 .38183 L .62232 .37311 L p F P
0 g
s
.657 .758 .924 r
.60159 .38131 m .62232 .37311 L .62979 .38183 L p F P
0 g
s
.459 .55 .861 r
.8391 .43464 m .86438 .44228 L .87392 .46132 L p F P
0 g
s
.517 .562 .841 r
.86438 .44228 m .8391 .43464 L .82981 .41675 L p F P
0 g
s
.642 .761 .935 r
.57413 .38123 m .59437 .37333 L .60159 .38131 L p F P
0 g
s
.637 .771 .944 r
.59437 .37333 m .57413 .38123 L .56716 .37381 L p F P
0 g
s
.642 .671 .863 r
.76415 .38342 m .74126 .38744 L .73276 .37393 L p F P
0 g
s
.646 .695 .881 r
.71043 .38017 m .73276 .37393 L .74126 .38744 L p F P
0 g
s
.657 .767 .931 r
.62232 .37311 m .60159 .38131 L .59437 .37333 L p F P
0 g
s
.394 .69 .979 r
.4555 .35781 m .47215 .35477 L .47837 .3602 L p F P
0 g
s
.329 .68 .978 r
.47215 .35477 m .4555 .35781 L .44966 .35216 L p F P
0 g
s
.19 .597 .944 r
.42282 .34277 m .43779 .34244 L .44375 .34702 L p F P
0 g
s
.087 .556 .905 r
.43779 .34244 m .42282 .34277 L .41727 .33771 L p F P
0 g
s
.662 .7 .874 r
.73276 .37393 m .71043 .38017 L .70218 .36812 L p F P
0 g
s
.662 .719 .891 r
.68035 .37584 m .70218 .36812 L .71043 .38017 L p F P
0 g
s
.571 .752 .963 r
.51523 .37373 m .53402 .36744 L .54076 .37407 L p F P
0 g
s
.546 .761 .977 r
.53402 .36744 m .51523 .37373 L .50879 .3673 L p F P
0 g
s
.358 .487 .853 r
.87392 .46132 m .90037 .4748 L .91012 .49466 L p F P
0 g
s
.444 .512 .834 r
.90037 .4748 m .87392 .46132 L .86438 .44228 L p F P
0 g
s
.496 .733 .978 r
.48453 .36615 m .5023 .36136 L .50879 .3673 L p F P
0 g
s
.453 .735 .988 r
.5023 .36136 m .48453 .36615 L .47837 .3602 L p F P
0 g
s
.675 .726 .888 r
.70218 .36812 m .68035 .37584 L .67234 .36515 L p F P
0 g
s
.669 .739 .903 r
.65099 .37373 m .67234 .36515 L .68035 .37584 L p F P
0 g
s
.607 .767 .956 r
.54076 .37407 m .56014 .36678 L .56716 .37381 L p F P
0 g
s
.592 .779 .969 r
.56014 .36678 m .54076 .37407 L .53402 .36744 L p F P
0 g
s
.678 .749 .904 r
.67234 .36515 m .65099 .37373 L .64322 .36424 L p F P
0 g
s
.668 .756 .916 r
.62232 .37311 m .64322 .36424 L .65099 .37373 L p F P
0 g
s
.571 .604 .846 r
.79645 .39741 m .82032 .39747 L .82981 .41675 L p F P
0 g
s
.604 .611 .832 r
.82032 .39747 m .79645 .39741 L .78728 .37996 L p F P
0 g
s
.612 .639 .853 r
.76415 .38342 m .78728 .37996 L .79645 .39741 L p F P
0 g
s
.637 .646 .842 r
.78728 .37996 m .76415 .38342 L .75527 .36783 L p F P
0 g
s
.642 .671 .863 r
.73276 .37393 m .75527 .36783 L .76415 .38342 L p F P
0 g
s
.329 .68 .978 r
.44966 .35216 m .46587 .34992 L .47215 .35477 L p F P
0 g
s
.246 .659 .962 r
.46587 .34992 m .44966 .35216 L .44375 .34702 L p F P
0 g
s
.672 .767 .922 r
.64322 .36424 m .62232 .37311 L .61479 .36464 L p F P
0 g
s
.657 .767 .931 r
.59437 .37333 m .61479 .36464 L .62232 .37311 L p F P
0 g
s
.637 .771 .944 r
.56716 .37381 m .58708 .36569 L .59437 .37333 L p F P
0 g
s
.629 .784 .956 r
.58708 .36569 m .56716 .37381 L .56014 .36678 L p F P
0 g
s
.087 .556 .905 r
.41727 .33771 m .43176 .33848 L .43779 .34244 L p F P
0 g
s
.517 .562 .841 r
.82981 .41675 m .85457 .42127 L .86438 .44228 L p F P
0 g
s
.56 .573 .823 r
.85457 .42127 m .82981 .41675 L .82032 .39747 L p F P
0 g
s
.656 .78 .94 r
.61479 .36464 m .59437 .37333 L .58708 .36569 L p F P
0 g
s
.662 .678 .855 r
.75527 .36783 m .73276 .37393 L .72416 .36016 L p F P
0 g
s
.662 .7 .874 r
.70218 .36812 m .72416 .36016 L .73276 .37393 L p F P
0 g
s
.546 .761 .977 r
.50879 .3673 m .52722 .36131 L .53402 .36744 L p F P
0 g
s
.514 .77 .989 r
.52722 .36131 m .50879 .3673 L .5023 .36136 L p F P
0 g
s
.453 .735 .988 r
.47837 .3602 m .49574 .35598 L .5023 .36136 L p F P
0 g
s
.397 .733 .991 r
.49574 .35598 m .47837 .3602 L .47215 .35477 L p F P
0 g
s
.679 .708 .87 r
.72416 .36016 m .70218 .36812 L .69385 .35605 L p F P
0 g
s
.675 .726 .888 r
.67234 .36515 m .69385 .35605 L .70218 .36812 L p F P
0 g
s
.444 .512 .834 r
.86438 .44228 m .89025 .45231 L .90037 .4748 L p F P
0 g
s
.505 .529 .816 r
.89025 .45231 m .86438 .44228 L .85457 .42127 L p F P
0 g
s
.687 .737 .889 r
.69385 .35605 m .67234 .36515 L .66426 .35462 L p F P
0 g
s
.678 .749 .904 r
.64322 .36424 m .66426 .35462 L .67234 .36515 L p F P
0 g
s
.592 .779 .969 r
.53402 .36744 m .55306 .36025 L .56014 .36678 L p F P
0 g
s
.571 .792 .983 r
.55306 .36025 m .53402 .36744 L .52722 .36131 L p F P
0 g
s
.246 .659 .962 r
.44375 .34702 m .45952 .34571 L .46587 .34992 L p F P
0 g
s
.145 .621 .923 r
.45952 .34571 m .44375 .34702 L .43779 .34244 L p F P
0 g
s
.604 .611 .832 r
.78728 .37996 m .81067 .37714 L .82032 .39747 L p F P
0 g
s
.631 .62 .82 r
.81067 .37714 m .78728 .37996 L .77799 .36189 L p F P
0 g
s
.637 .646 .842 r
.75527 .36783 m .77799 .36189 L .78728 .37996 L p F P
0 g
s
.687 .762 .909 r
.66426 .35462 m .64322 .36424 L .63538 .35506 L p F P
0 g
s
.672 .767 .922 r
.61479 .36464 m .63538 .35506 L .64322 .36424 L p F P
0 g
s
.659 .655 .834 r
.77799 .36189 m .75527 .36783 L .7463 .35196 L p F P
0 g
s
.662 .678 .855 r
.72416 .36016 m .7463 .35196 L .75527 .36783 L p F P
0 g
s
.56 .573 .823 r
.82032 .39747 m .84455 .39871 L .85457 .42127 L p F P
0 g
s
.595 .583 .809 r
.84455 .39871 m .82032 .39747 L .81067 .37714 L p F P
0 g
s
.629 .784 .956 r
.56014 .36678 m .57974 .35852 L .58708 .36569 L p F P
0 g
s
.619 .801 .969 r
.57974 .35852 m .56014 .36678 L .55306 .36025 L p F P
0 g
s
.676 .783 .93 r
.63538 .35506 m .61479 .36464 L .60719 .35659 L p F P
0 g
s
.656 .78 .94 r
.58708 .36569 m .60719 .35659 L .61479 .36464 L p F P
0 g
s
.514 .77 .989 r
.5023 .36136 m .52035 .35578 L .52722 .36131 L p F P
0 g
s
.471 .777 .997 r
.52035 .35578 m .5023 .36136 L .49574 .35598 L p F P
0 g
s
.654 .796 .951 r
.60719 .35659 m .58708 .36569 L .57974 .35852 L p F P
0 g
s
.397 .733 .991 r
.47215 .35477 m .48912 .35124 L .49574 .35598 L p F P
0 g
s
.324 .722 .981 r
.48912 .35124 m .47215 .35477 L .46587 .34992 L p F P
0 g
s
.681 .688 .85 r
.7463 .35196 m .72416 .36016 L .71549 .34637 L p F P
0 g
s
.679 .708 .87 r
.69385 .35605 m .71549 .34637 L .72416 .36016 L p F P
0 g
s
.505 .529 .816 r
.85457 .42127 m .87983 .42764 L .89025 .45231 L p F P
0 g
s
.55 .543 .8 r
.87983 .42764 m .85457 .42127 L .84455 .39871 L p F P
0 g
s
.695 .721 .87 r
.71549 .34637 m .69385 .35605 L .68545 .34418 L p F P
0 g
s
.687 .737 .889 r
.66426 .35462 m .68545 .34418 L .69385 .35605 L p F P
0 g
s
.145 .621 .923 r
.43779 .34244 m .4531 .34221 L .45952 .34571 L p F P
0 g
s
.027 .562 .851 r
.4531 .34221 m .43779 .34244 L .43176 .33848 L p F P
0 g
s
.571 .792 .983 r
.52722 .36131 m .54591 .35433 L .55306 .36025 L p F P
0 g
s
.543 .806 .994 r
.54591 .35433 m .52722 .36131 L .52035 .35578 L p F P
0 g
s
.7 .752 .892 r
.68545 .34418 m .66426 .35462 L .65612 .34446 L p F P
0 g
s
.687 .762 .909 r
.63538 .35506 m .65612 .34446 L .66426 .35462 L p F P
0 g
s
.631 .62 .82 r
.77799 .36189 m .8009 .35611 L .81067 .37714 L p F P
0 g
s
.656 .63 .812 r
.8009 .35611 m .77799 .36189 L .76859 .34349 L p F P
0 g
s
.659 .655 .834 r
.7463 .35196 m .76859 .34349 L .77799 .36189 L p F P
0 g
s
.595 .583 .809 r
.81067 .37714 m .83435 .375 L .84455 .39871 L p F P
0 g
s
.625 .594 .799 r
.83435 .375 m .81067 .37714 L .8009 .35611 L p F P
0 g
s
.681 .666 .829 r
.76859 .34349 m .7463 .35196 L .73725 .33607 L p F P
0 g
s
.681 .688 .85 r
.71549 .34637 m .73725 .33607 L .7463 .35196 L p F P
0 g
s
.696 .78 .916 r
.65612 .34446 m .63538 .35506 L .62747 .34636 L p F P
0 g
s
.676 .783 .93 r
.60719 .35659 m .62747 .34636 L .63538 .35506 L p F P
0 g
s
.619 .801 .969 r
.55306 .36025 m .57232 .35194 L .57974 .35852 L p F P
0 g
s
.604 .819 .983 r
.57232 .35194 m .55306 .36025 L .54591 .35433 L p F P
0 g
s
.324 .722 .981 r
.46587 .34992 m .48242 .34722 L .48912 .35124 L p F P
0 g
s
.231 .693 .947 r
.48242 .34722 m .46587 .34992 L .45952 .34571 L p F P
0 g
s
.471 .777 .997 r
.49574 .35598 m .51341 .35093 L .52035 .35578 L p F P
0 g
s
.414 .777 .995 r
.51341 .35093 m .49574 .35598 L .48912 .35124 L p F P
0 g
s
.55 .543 .8 r
.84455 .39871 m .86918 .40125 L .87983 .42764 L p F P
0 g
s
.587 .556 .787 r
.86918 .40125 m .84455 .39871 L .83435 .375 L p F P
0 g
s
.68 .803 .94 r
.62747 .34636 m .60719 .35659 L .59953 .34909 L p F P
0 g
s
.654 .796 .951 r
.57974 .35852 m .59953 .34909 L .60719 .35659 L p F P
0 g
s
.65 .817 .964 r
.59953 .34909 m .57974 .35852 L .57232 .35194 L p F P
0 g
s
.7 .702 .849 r
.73725 .33607 m .71549 .34637 L .70675 .33281 L p F P
0 g
s
.695 .721 .87 r
.68545 .34418 m .70675 .33281 L .71549 .34637 L p F P
0 g
s
.027 .562 .851 r
.43176 .33848 m .44659 .33949 L .4531 .34221 L p F P
0 g
s
.711 .737 .872 r
.70675 .33281 m .68545 .34418 L .67698 .33272 L p F P
0 g
s
.7 .752 .892 r
.65612 .34446 m .67698 .33272 L .68545 .34418 L p F P
0 g
s
.625 .594 .799 r
.8009 .35611 m .82403 .35053 L .83435 .375 L p F P
0 g
s
.652 .607 .791 r
.82403 .35053 m .8009 .35611 L .79103 .33475 L p F P
0 g
s
.656 .63 .812 r
.76859 .34349 m .79103 .33475 L .8009 .35611 L p F P
0 g
s
.543 .806 .994 r
.52035 .35578 m .53868 .34912 L .54591 .35433 L p F P
0 g
s
.503 .818 1 r
.53868 .34912 m .52035 .35578 L .51341 .35093 L p F P
0 g
s
.68 .644 .807 r
.79103 .33475 m .76859 .34349 L .75913 .32509 L p F P
0 g
s
.681 .666 .829 r
.73725 .33607 m .75913 .32509 L .76859 .34349 L p F P
0 g
s
.587 .556 .787 r
.83435 .375 m .85834 .3736 L .86918 .40125 L p F P
0 g
s
.619 .57 .777 r
.85834 .3736 m .83435 .375 L .82403 .35053 L p F P
0 g
s
.714 .772 .897 r
.67698 .33272 m .65612 .34446 L .6479 .33484 L p F P
0 g
s
.696 .78 .916 r
.62747 .34636 m .6479 .33484 L .65612 .34446 L p F P
0 g
s
.703 .681 .827 r
.75913 .32509 m .73725 .33607 L .72814 .32044 L p F P
0 g
s
.7 .702 .849 r
.70675 .33281 m .72814 .32044 L .73725 .33607 L p F P
0 g
s
.231 .693 .947 r
.45952 .34571 m .47564 .344 L .48242 .34722 L p F P
0 g
s
.118 .641 .88 r
.47564 .344 m .45952 .34571 L .4531 .34221 L p F P
0 g
s
.414 .777 .995 r
.48912 .35124 m .5064 .34687 L .51341 .35093 L p F P
0 g
s
.336 .763 .973 r
.5064 .34687 m .48912 .35124 L .48242 .34722 L p F P
0 g
s
.604 .819 .983 r
.54591 .35433 m .56484 .34609 L .57232 .35194 L p F P
0 g
s
.581 .839 .994 r
.56484 .34609 m .54591 .35433 L .53868 .34912 L p F P
0 g
s
.706 .802 .925 r
.6479 .33484 m .62747 .34636 L .6195 .3383 L p F P
0 g
s
.68 .803 .94 r
.59953 .34909 m .6195 .3383 L .62747 .34636 L p F P
0 g
s
.719 .72 .85 r
.72814 .32044 m .70675 .33281 L .69794 .31971 L p F P
0 g
s
.711 .737 .872 r
.67698 .33272 m .69794 .31971 L .70675 .33281 L p F P
0 g
s
.683 .827 .953 r
.6195 .3383 m .59953 .34909 L .5918 .34228 L p F P
0 g
s
.65 .817 .964 r
.57232 .35194 m .5918 .34228 L .59953 .34909 L p F P
0 g
s
.642 .841 .977 r
.5918 .34228 m .57232 .35194 L .56484 .34609 L p F P
0 g
s
.652 .607 .791 r
.79103 .33475 m .81362 .3257 L .82403 .35053 L p F P
0 g
s
.677 .621 .785 r
.81362 .3257 m .79103 .33475 L .7811 .31338 L p F P
0 g
s
.68 .644 .807 r
.75913 .32509 m .7811 .31338 L .79103 .33475 L p F P
0 g
s
.619 .57 .777 r
.82403 .35053 m .84738 .34515 L .85834 .3736 L p F P
0 g
s
.647 .584 .77 r
.84738 .34515 m .82403 .35053 L .81362 .3257 L p F P
0 g
s
.703 .66 .804 r
.7811 .31338 m .75913 .32509 L .74961 .30698 L p F P
0 g
s
.703 .681 .827 r
.72814 .32044 m .74961 .30698 L .75913 .32509 L p F P
0 g
s
.729 .758 .876 r
.69794 .31971 m .67698 .33272 L .66845 .32188 L p F P
0 g
s
.714 .772 .897 r
.6479 .33484 m .66845 .32188 L .67698 .33272 L p F P
0 g
s
.503 .818 1 r
.51341 .35093 m .53138 .34474 L .53868 .34912 L p F P
0 g
s
.446 .821 .992 r
.53138 .34474 m .51341 .35093 L .5064 .34687 L p F P
0 g
s
.725 .7 .826 r
.74961 .30698 m .72814 .32044 L .71898 .30534 L p F P
0 g
s
.719 .72 .85 r
.69794 .31971 m .71898 .30534 L .72814 .32044 L p F P
0 g
s
.118 .641 .88 r
.4531 .34221 m .46877 .34166 L .47564 .344 L p F P
0 g
s
0 .563 .775 r
.46877 .34166 m .4531 .34221 L .44659 .33949 L p F P
0 g
s
.729 .796 .906 r
.66845 .32188 m .6479 .33484 L .63963 .32596 L p F P
0 g
s
.706 .802 .925 r
.6195 .3383 m .63963 .32596 L .6479 .33484 L p F P
0 g
s
.336 .763 .973 r
.48242 .34722 m .4993 .34369 L .5064 .34687 L p F P
0 g
s
.235 .727 .919 r
.4993 .34369 m .48242 .34722 L .47564 .344 L p F P
0 g
s
.647 .584 .77 r
.81362 .3257 m .83634 .31633 L .84738 .34515 L p F P
0 g
s
.674 .6 .764 r
.83634 .31633 m .81362 .3257 L .80315 .30089 L p F P
0 g
s
.677 .621 .785 r
.7811 .31338 m .80315 .30089 L .81362 .3257 L p F P
0 g
s
.581 .839 .994 r
.53868 .34912 m .55728 .34109 L .56484 .34609 L p F P
0 g
s
.547 .856 .997 r
.55728 .34109 m .53868 .34912 L .53138 .34474 L p F P
0 g
s
.702 .638 .782 r
.80315 .30089 m .7811 .31338 L .77113 .29236 L p F P
0 g
s
.703 .66 .804 r
.74961 .30698 m .77113 .29236 L .7811 .31338 L p F P
0 g
s
.715 .83 .936 r
.63963 .32596 m .6195 .3383 L .61147 .33105 L p F P
0 g
s
.683 .827 .953 r
.5918 .34228 m .61147 .33105 L .6195 .3383 L p F P
0 g
s
.74 .742 .853 r
.71898 .30534 m .69794 .31971 L .68909 .30733 L p F P
0 g
s
.729 .758 .876 r
.66845 .32188 m .68909 .30733 L .69794 .31971 L p F P
0 g
s
.642 .841 .977 r
.56484 .34609 m .584 .33633 L .5918 .34228 L p F P
0 g
s
.627 .867 .987 r
.584 .33633 m .56484 .34609 L .55728 .34109 L p F P
0 g
s
.682 .856 .965 r
.61147 .33105 m .5918 .34228 L .584 .33633 L p F P
0 g
s
.727 .679 .803 r
.77113 .29236 m .74961 .30698 L .74006 .28948 L p F P
0 g
s
.725 .7 .826 r
.71898 .30534 m .74006 .28948 L .74961 .30698 L p F P
0 g
s
.748 .784 .883 r
.68909 .30733 m .66845 .32188 L .65987 .31189 L p F P
0 g
s
.729 .796 .906 r
.63963 .32596 m .65987 .31189 L .66845 .32188 L p F P
0 g
s
.446 .821 .992 r
.5064 .34687 m .524 .34131 L .53138 .34474 L p F P
0 g
s
.367 .806 .958 r
.524 .34131 m .5064 .34687 L .4993 .34369 L p F P
0 g
s
.674 .6 .764 r
.80315 .30089 m .82527 .28758 L .83634 .31633 L p F P
0 g
s
.7 .617 .761 r
.82527 .28758 m .80315 .30089 L .79267 .2765 L p F P
0 g
s
.702 .638 .782 r
.77113 .29236 m .79267 .2765 L .80315 .30089 L p F P
0 g
s
0 .563 .775 r
.44659 .33949 m .4618 .3403 L .46877 .34166 L p F P
0 g
s
.748 .722 .828 r
.74006 .28948 m .71898 .30534 L .70978 .29104 L p F P
0 g
s
.74 .742 .853 r
.68909 .30733 m .70978 .29104 L .71898 .30534 L p F P
0 g
s
.728 .658 .78 r
.79267 .2765 m .77113 .29236 L .76114 .27203 L p F P
0 g
s
.727 .679 .803 r
.74006 .28948 m .76114 .27203 L .77113 .29236 L p F P
0 g
s
.235 .727 .919 r
.47564 .344 m .49211 .34149 L .4993 .34369 L p F P
0 g
s
.116 .662 .826 r
.49211 .34149 m .47564 .344 L .46877 .34166 L p F P
0 g
s
.743 .826 .915 r
.65987 .31189 m .63963 .32596 L .63129 .31803 L p F P
0 g
s
.715 .83 .936 r
.61147 .33105 m .63129 .31803 L .63963 .32596 L p F P
0 g
s
.547 .856 .997 r
.53138 .34474 m .54963 .33707 L .55728 .34109 L p F P
0 g
s
.495 .864 .985 r
.54963 .33707 m .53138 .34474 L .524 .34131 L p F P
0 g
s
.7 .617 .761 r
.79267 .2765 m .81419 .25932 L .82527 .28758 L p F P
0 g
s
.722 .863 .948 r
.63129 .31803 m .61147 .33105 L .60336 .3248 L p F P
0 g
s
.682 .856 .965 r
.584 .33633 m .60336 .3248 L .61147 .33105 L p F P
0 g
s
.762 .768 .858 r
.70978 .29104 m .68909 .30733 L .68019 .29591 L p F P
0 g
s
.748 .784 .883 r
.65987 .31189 m .68019 .29591 L .68909 .30733 L p F P
0 g
s
.753 .702 .804 r
.76114 .27203 m .74006 .28948 L .73048 .27288 L p F P
0 g
s
.748 .722 .828 r
.70978 .29104 m .73048 .27288 L .74006 .28948 L p F P
0 g
s
.727 .637 .758 r
.81419 .25932 m .79267 .2765 L .78218 .25288 L p F P
0 g
s
.728 .658 .78 r
.76114 .27203 m .78218 .25288 L .79267 .2765 L p F P
0 g
s
.627 .867 .987 r
.55728 .34109 m .57612 .33138 L .584 .33633 L p F P
0 g
s
.601 .89 .99 r
.57612 .33138 m .55728 .34109 L .54963 .33707 L p F P
0 g
s
.676 .887 .975 r
.60336 .3248 m .584 .33633 L .57612 .33138 L p F P
0 g
s
.727 .637 .758 r
.78218 .25288 m .80315 .23195 L .81419 .25932 L p F P
0 g
s
.367 .806 .958 r
.4993 .34369 m .51652 .33894 L .524 .34131 L p F P
0 g
s
.263 .763 .887 r
.51652 .33894 m .4993 .34369 L .49211 .34149 L p F P
0 g
s
.755 .681 .78 r
.78218 .25288 m .76114 .27203 L .75114 .25271 L p F P
0 g
s
.753 .702 .804 r
.73048 .27288 m .75114 .25271 L .76114 .27203 L p F P
0 g
s
.767 .816 .891 r
.68019 .29591 m .65987 .31189 L .65123 .30298 L p F P
0 g
s
.743 .826 .915 r
.63129 .31803 m .65123 .30298 L .65987 .31189 L p F P
0 g
s
.773 .749 .832 r
.73048 .27288 m .70978 .29104 L .70054 .27783 L p F P
0 g
s
.762 .768 .858 r
.68019 .29591 m .70054 .27783 L .70978 .29104 L p F P
0 g
s
.116 .662 .826 r
.46877 .34166 m .48481 .34038 L .49211 .34149 L p F P
0 g
s
.012 0 0 r
.48481 .34038 m .46877 .34166 L .4618 .3403 L p F P
0 g
s
.755 .661 .757 r
.80315 .23195 m .78218 .25288 L .77172 .23042 L p F P
0 g
s
.755 .681 .78 r
.75114 .25271 m .77172 .23042 L .78218 .25288 L p F P
0 g
s
.758 .861 .926 r
.65123 .30298 m .63129 .31803 L .62288 .31122 L p F P
0 g
s
.722 .863 .948 r
.60336 .3248 m .62288 .31122 L .63129 .31803 L p F P
0 g
s
.495 .864 .985 r
.524 .34131 m .5419 .33419 L .54963 .33707 L p F P
0 g
s
.418 .85 .942 r
.5419 .33419 m .524 .34131 L .51652 .33894 L p F P
0 g
s
.755 .661 .757 r
.77172 .23042 m .79216 .20588 L .80315 .23195 L p F P
0 g
s
.779 .729 .806 r
.75114 .25271 m .73048 .27288 L .72088 .2575 L p F P
0 g
s
.773 .749 .832 r
.70054 .27783 m .72088 .2575 L .73048 .27288 L p F P
0 g
s
.786 .8 .864 r
.70054 .27783 m .68019 .29591 L .67124 .2857 L p F P
0 g
s
.767 .816 .891 r
.65123 .30298 m .67124 .2857 L .68019 .29591 L p F P
0 g
s
.725 .899 .957 r
.62288 .31122 m .60336 .3248 L .59517 .31971 L p F P
0 g
s
.676 .887 .975 r
.57612 .33138 m .59517 .31971 L .60336 .3248 L p F P
0 g
s
.601 .89 .99 r
.54963 .33707 m .56815 .3276 L .57612 .33138 L p F P
0 g
s
.556 .904 .974 r
.56815 .3276 m .54963 .33707 L .5419 .33419 L p F P
0 g
s
.66 .917 .977 r
.59517 .31971 m .57612 .33138 L .56815 .3276 L p F P
0 g
s
.783 .708 .781 r
.77172 .23042 m .75114 .25271 L .74116 .23476 L p F P
0 g
s
.779 .729 .806 r
.72088 .2575 m .74116 .23476 L .75114 .25271 L p F P
0 g
s
.263 .763 .887 r
.49211 .34149 m .50893 .33776 L .51652 .33894 L p F P
0 g
s
.14 .686 .773 r
.50893 .33776 m .49211 .34149 L .48481 .34038 L p F P
0 g
s
.784 .687 .757 r
.79216 .20588 m .77172 .23042 L .7613 .20947 L p F P
0 g
s
.783 .708 .781 r
.74116 .23476 m .7613 .20947 L .77172 .23042 L p F P
0 g
s
.799 .781 .836 r
.72088 .2575 m .70054 .27783 L .69127 .26598 L p F P
0 g
s
.786 .8 .864 r
.67124 .2857 m .69127 .26598 L .70054 .27783 L p F P
0 g
s
.787 .853 .9 r
.67124 .2857 m .65123 .30298 L .64252 .29536 L p F P
0 g
s
.758 .861 .926 r
.62288 .31122 m .64252 .29536 L .65123 .30298 L p F P
0 g
s
.784 .687 .757 r
.7613 .20947 m .78125 .18151 L .79216 .20588 L p F P
0 g
s
.012 0 0 r
.4618 .3403 m .4774 .34046 L .48481 .34038 L p F P
0 g
s
.808 .761 .809 r
.74116 .23476 m .72088 .2575 L .71128 .24364 L p F P
0 g
s
.799 .781 .836 r
.69127 .26598 m .71128 .24364 L .72088 .2575 L p F P
0 g
s
.769 .901 .934 r
.64252 .29536 m .62288 .31122 L .61439 .30577 L p F P
0 g
s
.725 .899 .957 r
.59517 .31971 m .61439 .30577 L .62288 .31122 L p F P
0 g
s
.418 .85 .942 r
.51652 .33894 m .53406 .33258 L .5419 .33419 L p F P
0 g
s
.314 .803 .858 r
.53406 .33258 m .51652 .33894 L .50893 .33776 L p F P
0 g
s
.811 .838 .871 r
.69127 .26598 m .67124 .2857 L .66224 .27696 L p F P
0 g
s
.787 .853 .9 r
.64252 .29536 m .66224 .27696 L .67124 .2857 L p F P
0 g
s
.813 .739 .782 r
.7613 .20947 m .74116 .23476 L .73118 .2185 L p F P
0 g
s
.808 .761 .809 r
.71128 .24364 m .73118 .2185 L .74116 .23476 L p F P
0 g
s
.719 .935 .959 r
.61439 .30577 m .59517 .31971 L .58689 .31597 L p F P
0 g
s
.66 .917 .977 r
.56815 .3276 m .58689 .31597 L .59517 .31971 L p F P
0 g
s
.815 .717 .757 r
.78125 .18151 m .7613 .20947 L .75093 .19041 L p F P
0 g
s
.815 .717 .757 r
.75093 .19041 m .77044 .15923 L .78125 .18151 L p F P
0 g
s
.813 .739 .782 r
.73118 .2185 m .75093 .19041 L .7613 .20947 L p F P
0 g
s
.556 .904 .974 r
.5419 .33419 m .56008 .32514 L .56815 .3276 L p F P
0 g
s
.485 .894 .926 r
.56008 .32514 m .5419 .33419 L .53406 .33258 L p F P
0 g
s
.626 .938 .96 r
.58689 .31597 m .56815 .3276 L .56008 .32514 L p F P
0 g
s
.14 .686 .773 r
.48481 .34038 m .50123 .33791 L p .4974 .33901 L F P
0 g
s
0 0 0 r
.50123 .33791 m .48481 .34038 L .4774 .34046 L p F P
0 g
s
0 0 0 r
.4774 .34046 m .4934 .3395 L .50123 .33791 L p F P
0 g
s
0 0 0 r
.50123 .33791 m .4934 .3395 L p .50514 .33678 L F P
0 g
s
0 0 0 r
.51803 .33378 m .50123 .33791 L p .50514 .33678 L F P
0 g
s
.14 .686 .773 r
.50123 .33791 m .50893 .33776 L p .4974 .33901 L F P
0 g
s
.827 .819 .841 r
.71128 .24364 m .69127 .26598 L .68197 .25578 L p F P
0 g
s
.811 .838 .871 r
.66224 .27696 m .68197 .25578 L .69127 .26598 L p F P
0 g
s
.806 .894 .906 r
.66224 .27696 m .64252 .29536 L .63375 .28928 L p F P
0 g
s
.769 .901 .934 r
.61439 .30577 m .63375 .28928 L .64252 .29536 L p F P
0 g
s
.838 .797 .811 r
.73118 .2185 m .71128 .24364 L .70166 .23163 L p F P
0 g
s
.827 .819 .841 r
.68197 .25578 m .70166 .23163 L .71128 .24364 L p F P
0 g
s
.848 .752 .757 r
.77044 .15923 m .75093 .19041 L .74061 .17361 L p F P
0 g
s
.848 .752 .757 r
.74061 .17361 m .75972 .13945 L .77044 .15923 L p F P
0 g
s
.314 .803 .858 r
.50893 .33776 m .52611 .33238 L .53406 .33258 L p F P
0 g
s
.189 .717 .729 r
.52611 .33238 m .50893 .33776 L .50123 .33791 L p F P
0 g
s
.774 .942 .935 r
.63375 .28928 m .61439 .30577 L .60583 .30187 L p F P
0 g
s
.719 .935 .959 r
.58689 .31597 m .60583 .30187 L .61439 .30577 L p F P
0 g
s
.845 .774 .783 r
.75093 .19041 m .73118 .2185 L .72124 .20429 L p F P
0 g
s
.838 .797 .811 r
.70166 .23163 m .72124 .20429 L .73118 .2185 L p F P
0 g
s
.845 .774 .783 r
.72124 .20429 m .74061 .17361 L .75093 .19041 L p F P
0 g
s
.835 .88 .875 r
.68197 .25578 m .66224 .27696 L .65319 .26995 L p F P
0 g
s
.806 .894 .906 r
.63375 .28928 m .65319 .26995 L .66224 .27696 L p F P
0 g
s
.697 .962 .942 r
.60583 .30187 m .58689 .31597 L .57852 .31379 L p F P
0 g
s
.626 .938 .96 r
.56008 .32514 m .57852 .31379 L .58689 .31597 L p F P
0 g
s
.485 .894 .926 r
.53406 .33258 m .55191 .32418 L .56008 .32514 L p F P
0 g
s
.383 .846 .833 r
.55191 .32418 m .53406 .33258 L .52611 .33238 L p F P
0 g
s
.564 .934 .91 r
.57852 .31379 m .56008 .32514 L .55191 .32418 L p F P
0 g
s
.856 .861 .844 r
.70166 .23163 m .68197 .25578 L .67264 .24753 L p F P
0 g
s
.835 .88 .875 r
.65319 .26995 m .67264 .24753 L .68197 .25578 L p F P
0 g
s
.82 .938 .906 r
.65319 .26995 m .63375 .28928 L .62491 .28497 L p F P
0 g
s
.774 .942 .935 r
.60583 .30187 m .62491 .28497 L .63375 .28928 L p F P
0 g
s
.882 .79 .754 r
.75972 .13945 m .74061 .17361 L .73036 .15946 L p F P
0 g
s
.882 .79 .754 r
.73036 .15946 m .74911 .12257 L .75972 .13945 L p F P
0 g
s
.87 .838 .812 r
.72124 .20429 m .70166 .23163 L .69204 .22178 L p F P
0 g
s
.856 .861 .844 r
.67264 .24753 m .69204 .22178 L .70166 .23163 L p F P
0 g
s
.878 .814 .782 r
.74061 .17361 m .72124 .20429 L .71131 .19249 L p F P
0 g
s
.878 .814 .782 r
.71131 .19249 m .73036 .15946 L .74061 .17361 L p F P
0 g
s
.87 .838 .812 r
.69204 .22178 m .71131 .19249 L .72124 .20429 L p F P
0 g
s
.189 .717 .729 r
.51803 .33378 m .52611 .33238 L p .51469 .33492 L F P
0 g
s
.258 .756 .696 r
.54362 .32491 m .52611 .33238 L .51803 .33378 L p F P
0 g
s
0 0 0 r
.51803 .33378 m .50981 .33692 L p .52144 .33261 L F P
0 g
s
.258 .756 .696 r
.53519 .32752 m .54362 .32491 L p .53212 .3289 L F P
0 g
s
.258 .756 .696 r
.51803 .33378 m .53519 .32752 L p .53212 .3289 L F P
0 g
s
.383 .846 .833 r
.52611 .33238 m .54362 .32491 L .55191 .32418 L p F P
0 g
s
.344 .8 .674 r
.56143 .31489 m .54362 .32491 L .53519 .32752 L p F P
0 g
s
0 0 0 r
.53519 .32752 m .5266 .33221 L p .53832 .32611 L F P
0 g
s
.344 .8 .674 r
.55268 .31864 m .56143 .31489 L p .54974 .32052 L F P
0 g
s
.344 .8 .674 r
.53519 .32752 m .55268 .31864 L p .54974 .32052 L F P
0 g
s
.44 .846 .66 r
.5795 .30188 m .56143 .31489 L .55268 .31864 L p F P
0 g
s
.44 .846 .66 r
.57047 .30664 m .5795 .30188 L p .56756 .30934 L F P
0 g
s
.44 .846 .66 r
.55268 .31864 m .57047 .30664 L p .56756 .30934 L F P
0 g
s
0 0 0 r
.57047 .30664 m .55268 .31864 L p .55568 .31671 L F P
0 g
s
.468 .89 .814 r
.54362 .32491 m .56143 .31489 L .57004 .31336 L p F P
0 g
s
0 0 0 r
.54376 .32483 m .56126 .31425 L .57047 .30664 L p F P
0 g
s
0 0 0 r
.57047 .30664 m .56126 .31425 L p .57343 .30388 L F P
0 g
s
0 0 0 r
.5885 .29105 m .57047 .30664 L p .57343 .30388 L F P
0 g
s
0 0 0 r
.55268 .31864 m .54376 .32483 L p .55568 .31671 L F P
0 g
s
0 0 0 r
.55268 .31864 m .53519 .32752 L p .53832 .32611 L F P
0 g
s
0 0 0 r
.53519 .32752 m .51803 .33378 L p .52144 .33261 L F P
0 g
s
.189 .717 .729 r
.50123 .33791 m .51803 .33378 L p .51469 .33492 L F P
0 g
s
.763 .976 .919 r
.62491 .28497 m .60583 .30187 L .59717 .29977 L p F P
0 g
s
.697 .962 .942 r
.57852 .31379 m .59717 .29977 L .60583 .30187 L p F P
0 g
s
.856 .925 .874 r
.67264 .24753 m .65319 .26995 L .64407 .26496 L p F P
0 g
s
.82 .938 .906 r
.62491 .28497 m .64407 .26496 L .65319 .26995 L p F P
0 g
s
.647 .967 .893 r
.59717 .29977 m .57852 .31379 L .57004 .31336 L p F P
0 g
s
.564 .934 .91 r
.55191 .32418 m .57004 .31336 L .57852 .31379 L p F P
0 g
s
.468 .89 .814 r
.57004 .31336 m .55191 .32418 L .54362 .32491 L p F P
0 g
s
.882 .906 .841 r
.69204 .22178 m .67264 .24753 L .66326 .24155 L p F P
0 g
s
.856 .925 .874 r
.64407 .26496 m .66326 .24155 L .67264 .24753 L p F P
0 g
s
.916 .832 .747 r
.74911 .12257 m .73036 .15946 L .72016 .14837 L p F P
0 g
s
.916 .832 .747 r
.72016 .14837 m .7386 .10902 L .74911 .12257 L p F P
0 g
s
.821 .977 .891 r
.64407 .26496 m .62491 .28497 L .61598 .28271 L p F P
0 g
s
.763 .976 .919 r
.59717 .29977 m .61598 .28271 L .62491 .28497 L p F P
0 g
s
.9 .883 .808 r
.71131 .19249 m .69204 .22178 L .6824 .21446 L p F P
0 g
s
.882 .906 .841 r
.66326 .24155 m .6824 .21446 L .69204 .22178 L p F P
0 g
s
.911 .858 .777 r
.73036 .15946 m .71131 .19249 L .70139 .18346 L p F P
0 g
s
.911 .858 .777 r
.70139 .18346 m .72016 .14837 L .73036 .15946 L p F P
0 g
s
.9 .883 .808 r
.6824 .21446 m .70139 .18346 L .71131 .19249 L p F P
0 g
s
0 0 0 r
.4934 .3395 m .50981 .33692 L .51803 .33378 L p F P
0 g
s
.727 .989 .873 r
.61598 .28271 m .59717 .29977 L .5884 .29969 L p F P
0 g
s
.647 .967 .893 r
.57004 .31336 m .5884 .29969 L .59717 .29977 L p F P
0 g
s
.866 .968 .86 r
.66326 .24155 m .64407 .26496 L .63489 .26228 L p F P
0 g
s
.821 .977 .891 r
.61598 .28271 m .63489 .26228 L .64407 .26496 L p F P
0 g
s
.56 .93 .799 r
.5884 .29969 m .57004 .31336 L .56143 .31489 L p F P
0 g
s
.9 .95 .827 r
.6824 .21446 m .66326 .24155 L .65383 .23815 L p F P
0 g
s
.866 .968 .86 r
.63489 .26228 m .65383 .23815 L .66326 .24155 L p F P
0 g
s
.947 .874 .733 r
.7386 .10902 m .72016 .14837 L .71001 .14076 L p F P
0 g
s
.947 .874 .733 r
.71001 .14076 m .72819 .09927 L .7386 .10902 L p F P
0 g
s
.798 .998 .849 r
.63489 .26228 m .61598 .28271 L .60694 .28277 L p F P
0 g
s
.727 .989 .873 r
.5884 .29969 m .60694 .28277 L .61598 .28271 L p F P
0 g
s
.923 .927 .794 r
.70139 .18346 m .6824 .21446 L .67273 .21001 L p F P
0 g
s
.9 .95 .827 r
.65383 .23815 m .67273 .21001 L .6824 .21446 L p F P
0 g
s
.938 .901 .762 r
.72016 .14837 m .70139 .18346 L .69148 .17762 L p F P
0 g
s
.938 .901 .762 r
.69148 .17762 m .71001 .14076 L .72016 .14837 L p F P
0 g
s
.923 .927 .794 r
.67273 .21001 m .69148 .17762 L .70139 .18346 L p F P
0 g
s
.652 .963 .784 r
.60694 .28277 m .5884 .29969 L .5795 .30188 L p F P
0 g
s
.56 .93 .799 r
.56143 .31489 m .5795 .30188 L .5884 .29969 L p F P
0 g
s
.856 .995 .821 r
.65383 .23815 m .63489 .26228 L .62561 .26223 L p F P
0 g
s
.798 .998 .849 r
.60694 .28277 m .62561 .26223 L .63489 .26228 L p F P
0 g
s
0 0 0 r
.50981 .33692 m .5266 .33221 L .53519 .32752 L p F P
0 g
s
.9 .982 .792 r
.67273 .21001 m .65383 .23815 L .64433 .23769 L p F P
0 g
s
.856 .995 .821 r
.62561 .26223 m .64433 .23769 L .65383 .23815 L p F P
0 g
s
.967 .912 .704 r
.72819 .09927 m .71001 .14076 L .69989 .1371 L p F P
0 g
s
.967 .912 .704 r
.69989 .1371 m .71787 .09381 L .72819 .09927 L p F P
0 g
s
.738 .984 .767 r
.62561 .26223 m .60694 .28277 L .59779 .28544 L p F P
0 g
s
.652 .963 .784 r
.5795 .30188 m .59779 .28544 L .60694 .28277 L p F P
0 g
s
.932 .962 .761 r
.69148 .17762 m .67273 .21001 L .66301 .20884 L p F P
0 g
s
.9 .982 .792 r
.64433 .23769 m .66301 .20884 L .67273 .21001 L p F P
0 g
s
.954 .938 .732 r
.71001 .14076 m .69148 .17762 L .68157 .17539 L p F P
0 g
s
.954 .938 .732 r
.68157 .17539 m .69989 .1371 L .71001 .14076 L p F P
0 g
s
.932 .962 .761 r
.66301 .20884 m .68157 .17539 L .69148 .17762 L p F P
0 g
s
.54 .887 .65 r
.59779 .28544 m .5795 .30188 L .57047 .30664 L p F P
0 g
s
.811 .992 .747 r
.64433 .23769 m .62561 .26223 L .61623 .26514 L p F P
0 g
s
.738 .984 .767 r
.59779 .28544 m .61623 .26514 L .62561 .26223 L p F P
0 g
s
0 0 0 r
.5266 .33221 m .54376 .32483 L .55268 .31864 L p F P
0 g
s
.87 .989 .726 r
.66301 .20884 m .64433 .23769 L .63474 .24057 L p F P
0 g
s
.811 .992 .747 r
.61623 .26514 m .63474 .24057 L .64433 .23769 L p F P
0 g
s
.968 .936 .656 r
.71787 .09381 m .69989 .1371 L .68979 .13792 L p F P
0 g
s
.968 .936 .656 r
.68979 .13792 m .70761 .0932 L .71787 .09381 L p F P
0 g
s
.637 .921 .643 r
.61623 .26514 m .59779 .28544 L .5885 .29105 L p F P
0 g
s
.54 .887 .65 r
.57047 .30664 m .5885 .29105 L p .58555 .29494 L F P
0 g
s
0 0 0 r
.56126 .31425 m .57904 .29995 L .5885 .29105 L p F P
0 g
s
0 0 0 r
.5885 .29105 m .57904 .29995 L p .59151 .28708 L F P
0 g
s
0 0 0 r
.60672 .27139 m .5885 .29105 L p .59151 .28708 L F P
0 g
s
.54 .887 .65 r
.5885 .29105 m .59779 .28544 L p .58555 .29494 L F P
0 g
s
.914 .977 .703 r
.68157 .17539 m .66301 .20884 L .65324 .21138 L p F P
0 g
s
.87 .989 .726 r
.63474 .24057 m .65324 .21138 L .66301 .20884 L p F P
0 g
s
.946 .958 .679 r
.69989 .1371 m .68157 .17539 L .67162 .17725 L p F P
0 g
s
.946 .958 .679 r
.67162 .17725 m .68979 .13792 L .69989 .1371 L p F P
0 g
s
.914 .977 .703 r
.65324 .21138 m .67162 .17725 L .68157 .17539 L p F P
0 g
s
.724 .944 .634 r
.63474 .24057 m .61623 .26514 L .60672 .27139 L p F P
0 g
s
.637 .921 .643 r
.5885 .29105 m .60672 .27139 L .61623 .26514 L p F P
0 g
s
.799 .955 .624 r
.65324 .21138 m .63474 .24057 L .62504 .24721 L p F P
0 g
s
.724 .944 .634 r
.60672 .27139 m .62504 .24721 L .63474 .24057 L p F P
0 g
s
.938 .935 .583 r
.70761 .0932 m .68979 .13792 L .67967 .14379 L p F P
0 g
s
.938 .935 .583 r
.67967 .14379 m .6974 .09808 L .70761 .0932 L p F P
0 g
s
.858 .956 .611 r
.67162 .17725 m .65324 .21138 L .64337 .21811 L p F P
0 g
s
.799 .955 .624 r
.62504 .24721 m .64337 .21811 L .65324 .21138 L p F P
0 g
s
.904 .948 .598 r
.68979 .13792 m .67162 .17725 L .66162 .18373 L p F P
0 g
s
.904 .948 .598 r
.66162 .18373 m .67967 .14379 L .68979 .13792 L p F P
0 g
s
.858 .956 .611 r
.64337 .21811 m .66162 .18373 L .67162 .17725 L p F P
0 g
s
0 0 0 r
.57904 .29995 m .59704 .28138 L .60672 .27139 L p F P
0 g
s
.603 .852 .492 r
.62504 .24721 m .60672 .27139 L .59704 .28138 L p F P
0 g
s
.689 .878 .493 r
.64337 .21811 m .62504 .24721 L .61519 .25808 L p F P
0 g
s
.603 .852 .492 r
.59704 .28138 m .61519 .25808 L .62504 .24721 L p F P
0 g
s
.763 .895 .492 r
.66162 .18373 m .64337 .21811 L .63339 .22956 L p F P
0 g
s
.689 .878 .493 r
.61519 .25808 m .63339 .22956 L .64337 .21811 L p F P
0 g
s
.872 .901 .486 r
.6974 .09808 m .67967 .14379 L .66952 .1554 L p F P
0 g
s
.872 .901 .486 r
.66952 .1554 m .6872 .10918 L .6974 .09808 L p F P
0 g
s
.824 .902 .49 r
.67967 .14379 m .66162 .18373 L .65154 .19545 L p F P
0 g
s
.763 .895 .492 r
.63339 .22956 m .65154 .19545 L .66162 .18373 L p F P
0 g
s
.824 .902 .49 r
.65154 .19545 m .66952 .1554 L .67967 .14379 L p F P
0 g
s
.25 Mabswid
.69167 0 m
.97681 .43105 L
s
.97681 .43105 m
1 .60069 L
s
1 .60069 m
.70245 .18561 L
s
.70245 .18561 m
.69167 0 L
s
.02811 .25642 m
0 .43378 L
s
0 .43378 m
.70245 .18561 L
s
.70245 .18561 m
.69167 0 L
s
.69167 0 m
.02811 .25642 L
s
.02811 .25642 m
.69167 0 L
s
.04211 .25101 m
.04692 .25547 L
s
[(-2)] .03249 .24209 1 .92762 Mshowa
.23653 .17588 m
.24103 .18065 L
s
[(-1)] .22754 .16633 .94257 1 Mshowa
.44647 .09475 m
.45059 .09986 L
s
[(0)] .43823 .08455 .80711 1 Mshowa
.67386 .00689 m
.67751 .01233 L
s
[(1)] .66654 -0.004 .67166 1 Mshowa
.125 Mabswid
.07984 .23643 m
.08269 .23914 L
s
.11813 .22163 m
.12095 .22438 L
s
.157 .20661 m
.15978 .2094 L
s
.19646 .19136 m
.1992 .19418 L
s
.27722 .16015 m
.27988 .16306 L
s
.31854 .14419 m
.32116 .14713 L
s
.36052 .12797 m
.36308 .13095 L
s
.40315 .11149 m
.40567 .11451 L
s
.49048 .07774 m
.4929 .08085 L
s
.53521 .06046 m
.53758 .0636 L
s
.58067 .04289 m
.58298 .04608 L
s
.62688 .02504 m
.62913 .02826 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{283.188, 215.625},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 282.188}, {214.625, 0}} -> {-0.101408, 0.0311816, \
0.00373653, 0.00373653}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics3D", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", " ", 
  RowBox[{
  "\"\</local/constant/ElasticaBook/C07_EnergyVariational/EPS/C07_triangle_\
wrapping.eps\>\"", ",", " ", "%135"}], "]"}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/C07_EnergyVariational/EPS/C07_\
triangle_wrapping.eps\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigsig", " ", "=", 
  RowBox[{"Eigenvalues", "[", "sig", "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["x", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"]}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["x", "3"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["x", "4"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["y", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"]}], "-", 
      RowBox[{"12", " ", "a", " ", 
       SuperscriptBox["c", "2"], " ", "x", " ", 
       SuperscriptBox["y", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["x", "2"], " ", 
       SuperscriptBox["y", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["y", "4"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"]}]}]]}], ",", 
   RowBox[{"3", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["x", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"]}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["x", "3"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["x", "4"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["y", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"]}], "-", 
      RowBox[{"12", " ", "a", " ", 
       SuperscriptBox["c", "2"], " ", "x", " ", 
       SuperscriptBox["y", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["x", "2"], " ", 
       SuperscriptBox["y", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["y", "4"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"]}]}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Tresca", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"eigsig", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], " ", "/.", " ", "wsol"}], " ", "/.",
        " ", 
       RowBox[{"z", " ", "\[Rule]", " ", "L"}]}], " ", "/.", " ", 
      RowBox[{"a", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
     RowBox[{"L", " ", "\[Rule]", " ", "1"}]}], " ", "/.", " ", 
    RowBox[{"\[Alpha]", " ", "\[Rule]", " ", 
     RowBox[{"5.", " ", 
      RowBox[{"Pi", " ", "/", " ", "180."}]}]}]}], "  ", "/.", " ", 
   RowBox[{"\[Mu]", " ", "\[Rule]", " ", "1."}]}]}], "\[IndentingNewLine]", 
 RowBox[{"forplot", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", " ", "Tresca"}], " ", "}"}], " ", "/.", " ", 
    
    RowBox[{"y", " ", "\[Rule]", " ", 
     RowBox[{"(", " ", 
      RowBox[{"yy", " ", 
       RowBox[{
        RowBox[{"Sqrt", "[", "3", "]"}], "/", "3"}], 
       RowBox[{"(", " ", 
        RowBox[{"2", "  ", "+", " ", "x"}], ")"}]}], ")"}]}]}], " ", "/.", 
   " ", 
   RowBox[{"x", " ", "\[Rule]", " ", "xx"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"6", " ", 
  SqrtBox[
   RowBox[{
    RowBox[{"0.0008461594994075238`", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"0.0008461594994075238`", " ", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{"0.00021153987485188094`", " ", 
     SuperscriptBox["x", "4"]}], "+", 
    RowBox[{"0.0008461594994075238`", " ", 
     SuperscriptBox["y", "2"]}], "-", 
    RowBox[{"0.002538478498222571`", " ", "x", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"0.0004230797497037619`", " ", 
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"0.00021153987485188094`", " ", 
     SuperscriptBox["y", "4"]}]}]]}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"xx", ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", "xx"}], ")"}], " ", "yy"}], 
    SqrtBox["3"]], ",", 
   RowBox[{"6", " ", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.0008461594994075238`", " ", 
        SuperscriptBox["xx", "2"]}], "+", 
       RowBox[{"0.0008461594994075238`", " ", 
        SuperscriptBox["xx", "3"]}], "+", 
       RowBox[{"0.00021153987485188094`", " ", 
        SuperscriptBox["xx", "4"]}], "+", 
       RowBox[{"0.0002820531664691746`", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"2", "+", "xx"}], ")"}], "2"], " ", 
        SuperscriptBox["yy", "2"]}], "-", 
       RowBox[{"0.0008461594994075237`", " ", "xx", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"2", "+", "xx"}], ")"}], "2"], " ", 
        SuperscriptBox["yy", "2"]}], "+", 
       RowBox[{"0.0001410265832345873`", " ", 
        SuperscriptBox["xx", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"2", "+", "xx"}], ")"}], "2"], " ", 
        SuperscriptBox["yy", "2"]}], "+", 
       RowBox[{"0.00002350443053909788`", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"2", "+", "xx"}], ")"}], "4"], " ", 
        SuperscriptBox["yy", "4"]}]}], ")"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", " ", 
  RowBox[{"forplot", " ", ",", " ", 
   RowBox[{"{", 
    RowBox[{"xx", ",", 
     RowBox[{"-", "2"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"yy", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", " ", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "50"}], ",", " ", 
   RowBox[{"BoxRatios", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "0.5"}], "}"}]}], ",", 
   RowBox[{"ViewPoint", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"20", ",", "20", ",", "30"}], "}"}]}], ",", " ", 
   RowBox[{"ViewVertical", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"10.", " ", ",", " ", "10.", ",", " ", "40."}], "}"}]}]}], 
  "]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .96591 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.87838e-17 1 -0.0134915 1 [
[.99408 .35036 0 -7.75075 ]
[.99408 .35036 12 1.24925 ]
[.83789 .23491 0 -7.77484 ]
[.83789 .23491 12 1.22516 ]
[.68053 .11859 0 -7.79928 ]
[.68053 .11859 6 1.20072 ]
[.52199 .0014 0 -7.8241 ]
[.52199 .0014 6 1.1759 ]
[.10481 .27727 -12 -7.76598 ]
[.10481 .27727 0 1.23402 ]
[.24064 .17686 -6 -7.78701 ]
[.24064 .17686 0 1.21299 ]
[.37736 .0758 -6 -7.80832 ]
[.37736 .0758 0 1.19168 ]
[-0.00585 .36469 -6 -7.74835 ]
[-0.00585 .36469 0 1.25165 ]
[-0.00745 .45213 -18 -7.73904 ]
[-0.00745 .45213 0 1.26096 ]
[-0.00906 .54013 -18 -7.72967 ]
[-0.00906 .54013 0 1.27033 ]
[ 0 0 0 0 ]
[ 1 .96591 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.99561 .36631 m
.5 0 L
s
.98394 .35768 m
.97888 .36134 L
s
[(-2)] .99408 .35036 -1 .72239 Mshowa
.82778 .24227 m
.82273 .24594 L
s
[(-1)] .83789 .23491 -1 .72774 Mshowa
.67045 .12598 m
.66541 .12968 L
s
[(0)] .68053 .11859 -1 .73317 Mshowa
.51194 .00882 m
.50691 .01254 L
s
[(1)] .52199 .0014 -1 .73869 Mshowa
.125 Mabswid
.9528 .33467 m
.94977 .33687 L
s
.92162 .31162 m
.91858 .31382 L
s
.89039 .28854 m
.88735 .29074 L
s
.85911 .26542 m
.85607 .26762 L
s
.79641 .21908 m
.79338 .22129 L
s
.76499 .19586 m
.76196 .19807 L
s
.73352 .1726 m
.7305 .17481 L
s
.70201 .14931 m
.69899 .15152 L
s
.63884 .10262 m
.63582 .10484 L
s
.60719 .07922 m
.60417 .08144 L
s
.57549 .05579 m
.57247 .05802 L
s
.54373 .03232 m
.54072 .03455 L
s
.25 Mabswid
.00439 .36631 m
.5 0 L
s
.11492 .28461 m
.11998 .28828 L
s
[(-1)] .10481 .27727 1 .72577 Mshowa
.25074 .18423 m
.25578 .18792 L
s
[(0)] .24064 .17686 1 .73045 Mshowa
.38743 .0832 m
.39247 .0869 L
s
[(1)] .37736 .0758 1 .73518 Mshowa
.125 Mabswid
.14202 .26459 m
.14505 .26679 L
s
.16914 .24454 m
.17218 .24674 L
s
.19631 .22446 m
.19934 .22667 L
s
.2235 .20436 m
.22653 .20657 L
s
.278 .16408 m
.28103 .16629 L
s
.30531 .1439 m
.30833 .14611 L
s
.33265 .12369 m
.33567 .12591 L
s
.36002 .10346 m
.36304 .10568 L
s
.08787 .30461 m
.0909 .30681 L
s
.06084 .32458 m
.06388 .32678 L
s
.03386 .34453 m
.0369 .34673 L
s
.0069 .36445 m
.00994 .36664 L
s
.41488 .06291 m
.4179 .06514 L
s
.44236 .0426 m
.44538 .04483 L
s
.46988 .02227 m
.47289 .02449 L
s
.49743 .0019 m
.50044 .00413 L
s
.25 Mabswid
.00439 .36631 m
0 .60778 L
s
.00429 .37201 m
.00936 .37566 L
s
[(0)] -0.00585 .36469 1 .72186 Mshowa
.0027 .45943 m
.00777 .46308 L
s
[(0.1)] -0.00745 .45213 1 .71979 Mshowa
.0011 .54742 m
.00618 .55106 L
s
[(0.2)] -0.00906 .54013 1 .71771 Mshowa
.125 Mabswid
.00397 .38945 m
.00701 .39164 L
s
.00365 .40691 m
.0067 .4091 L
s
.00334 .42439 m
.00638 .42659 L
s
.00302 .4419 m
.00606 .44409 L
s
.00238 .47698 m
.00542 .47917 L
s
.00206 .49456 m
.0051 .49674 L
s
.00174 .51215 m
.00478 .51434 L
s
.00142 .52977 m
.00446 .53196 L
s
.00078 .56508 m
.00382 .56727 L
s
.00045 .58277 m
.0035 .58495 L
s
.00013 .60048 m
.00318 .60266 L
s
.25 Mabswid
.5 .72413 m
.5 .96591 L
s
.5 .96591 m
1 .60778 L
s
1 .60778 m
.99561 .36631 L
s
.99561 .36631 m
.5 .72413 L
s
.00439 .36631 m
.5 0 L
s
.5 0 m
.5 .24107 L
s
.5 .24107 m
0 .60778 L
s
0 .60778 m
.00439 .36631 L
s
.5 .72413 m
.5 .96591 L
s
.5 .96591 m
0 .60778 L
s
0 .60778 m
.00439 .36631 L
s
.00439 .36631 m
.5 .72413 L
s
.99561 .36631 m
.5 0 L
s
.5 0 m
.5 .24107 L
s
.5 .24107 m
1 .60778 L
s
1 .60778 m
.99561 .36631 L
s
0 0 m
1 0 L
1 .96591 L
0 .96591 L
closepath
clip
newpath
.5 Mabswid
.737 .565 .66 r
.73474 .54344 m .72998 .55085 L .73018 .55127 L closepath p F P
0 g
s
.736 .565 .66 r
.73474 .54344 m .72978 .55044 L .72998 .55085 L closepath p F P
0 g
s
.736 .564 .66 r
.73474 .54344 m .72958 .55003 L .72978 .55044 L closepath p F P
0 g
s
.736 .563 .659 r
.73474 .54344 m .72938 .54963 L .72958 .55003 L closepath p F P
0 g
s
.735 .563 .659 r
.73474 .54344 m .72918 .54925 L .72938 .54963 L closepath p F P
0 g
s
.729 .591 .702 r
.73474 .54344 m .72093 .55683 L .72112 .55614 L closepath p F P
0 g
s
.729 .591 .702 r
.73474 .54344 m .72074 .55753 L .72093 .55683 L closepath p F P
0 g
s
.728 .591 .702 r
.73474 .54344 m .72054 .55823 L .72074 .55753 L closepath p F P
0 g
s
.735 .562 .659 r
.73474 .54344 m .72898 .54886 L .72918 .54925 L closepath p F P
0 g
s
.729 .592 .703 r
.73474 .54344 m .7215 .55479 L .7217 .55412 L closepath p F P
0 g
s
.729 .592 .702 r
.73474 .54344 m .72131 .55546 L .7215 .55479 L closepath p F P
0 g
s
.729 .591 .702 r
.73474 .54344 m .72112 .55614 L .72131 .55546 L closepath p F P
0 g
s
.734 .561 .658 r
.73474 .54344 m .72878 .54849 L .72898 .54886 L closepath p F P
0 g
s
.73 .593 .703 r
.73474 .54344 m .72189 .55347 L .72208 .55282 L closepath p F P
0 g
s
.73 .593 .703 r
.73474 .54344 m .7217 .55412 L .72189 .55347 L closepath p F P
0 g
s
.734 .56 .657 r
.73474 .54344 m .72857 .54814 L .72878 .54849 L closepath p F P
0 g
s
.73 .594 .704 r
.73474 .54344 m .72228 .55219 L .72247 .55158 L closepath p F P
0 g
s
.73 .594 .704 r
.73474 .54344 m .72208 .55282 L .72228 .55219 L closepath p F P
0 g
s
.733 .559 .657 r
.73474 .54344 m .72837 .54779 L .72857 .54814 L closepath p F P
0 g
s
.731 .596 .705 r
.73474 .54344 m .72266 .55098 L .72285 .55039 L closepath p F P
0 g
s
.731 .595 .704 r
.73474 .54344 m .72247 .55158 L .72266 .55098 L closepath p F P
0 g
s
.732 .558 .656 r
.73474 .54344 m .72817 .54746 L .72837 .54779 L closepath p F P
0 g
s
.731 .596 .706 r
.73474 .54344 m .72285 .55039 L .72305 .54983 L closepath p F P
0 g
s
.732 .556 .655 r
.73474 .54344 m .72797 .54714 L .72817 .54746 L closepath p F P
0 g
s
.732 .599 .708 r
.73474 .54344 m .72324 .54928 L .72343 .54876 L closepath p F P
0 g
s
.732 .598 .707 r
.73474 .54344 m .72305 .54983 L .72324 .54928 L closepath p F P
0 g
s
.731 .555 .653 r
.73474 .54344 m .72777 .54684 L .72797 .54714 L closepath p F P
0 g
s
.733 .6 .709 r
.73474 .54344 m .72343 .54876 L .72363 .54827 L closepath p F P
0 g
s
.73 .553 .651 r
.73474 .54344 m .72757 .54656 L .72777 .54684 L closepath p F P
0 g
s
.734 .604 .712 r
.73474 .54344 m .72382 .54781 L .72402 .54737 L closepath p F P
0 g
s
.734 .602 .71 r
.73474 .54344 m .72363 .54827 L .72382 .54781 L closepath p F P
0 g
s
.729 .55 .649 r
.73474 .54344 m .72737 .5463 L .72757 .54656 L closepath p F P
0 g
s
.735 .607 .715 r
.73474 .54344 m .72402 .54737 L .72421 .54698 L closepath p F P
0 g
s
.728 .547 .646 r
.73474 .54344 m .72717 .54607 L .72737 .5463 L closepath p F P
0 g
s
.736 .611 .718 r
.73474 .54344 m .72421 .54698 L .72441 .54662 L closepath p F P
0 g
s
.726 .542 .642 r
.73474 .54344 m .72697 .54586 L .72717 .54607 L closepath p F P
0 g
s
.737 .615 .722 r
.73474 .54344 m .72441 .54662 L .7246 .5463 L closepath p F P
0 g
s
.724 .536 .637 r
.73474 .54344 m .72677 .54568 L .72697 .54586 L closepath p F P
0 g
s
.739 .622 .729 r
.73474 .54344 m .7246 .5463 L .7248 .54602 L closepath p F P
0 g
s
.721 .528 .628 r
.73474 .54344 m .72657 .54553 L .72677 .54568 L closepath p F P
0 g
s
.741 .632 .738 r
.73474 .54344 m .7248 .54602 L .72499 .54578 L closepath p F P
0 g
s
.717 .515 .615 r
.73474 .54344 m .72637 .54541 L .72657 .54553 L closepath p F P
0 g
s
.744 .647 .753 r
.73474 .54344 m .72499 .54578 L .72519 .54559 L closepath p F P
0 g
s
.709 .492 .592 r
.73474 .54344 m .72618 .54534 L .72637 .54541 L closepath p F P
0 g
s
.747 .676 .781 r
.73474 .54344 m .72519 .54559 L .72539 .54545 L closepath p F P
0 g
s
.692 .443 .542 r
.73474 .54344 m .72598 .5453 L .72618 .54534 L closepath p F P
0 g
s
.51 .894 .957 r
.73474 .54344 m .72558 .54536 L .72578 .54531 L closepath p F P
0 g
s
.749 .743 .847 r
.73474 .54344 m .72539 .54545 L .72558 .54536 L closepath p F P
0 g
s
.616 .271 .362 r
.73474 .54344 m .72578 .54531 L .72598 .5453 L closepath p F P
0 g
s
.738 .627 .735 r
.71523 .54756 m .72499 .54578 L .7248 .54602 L p F P
0 g
s
.738 .627 .735 r
.7248 .54602 m .71483 .54802 L .71523 .54756 L p F P
0 g
s
.737 .618 .727 r
.71483 .54802 m .7248 .54602 L .7246 .5463 L p F P
0 g
s
.737 .618 .727 r
.7246 .5463 m .71444 .54858 L .71483 .54802 L p F P
0 g
s
.735 .613 .721 r
.71444 .54858 m .7246 .5463 L .72441 .54662 L p F P
0 g
s
.74 .64 .749 r
.71562 .54718 m .72519 .54559 L .72499 .54578 L p F P
0 g
s
.74 .64 .749 r
.72499 .54578 m .71523 .54756 L .71562 .54718 L p F P
0 g
s
.735 .613 .721 r
.72441 .54662 m .71405 .54922 L .71444 .54858 L p F P
0 g
s
.734 .608 .717 r
.71405 .54922 m .72441 .54662 L .72421 .54698 L p F P
0 g
s
.741 .662 .772 r
.71601 .54689 m .72539 .54545 L .72519 .54559 L p F P
0 g
s
.741 .662 .772 r
.72519 .54559 m .71562 .54718 L .71601 .54689 L p F P
0 g
s
.734 .608 .717 r
.72421 .54698 m .71366 .54994 L .71405 .54922 L p F P
0 g
s
.734 .605 .714 r
.71366 .54994 m .72421 .54698 L .72402 .54737 L p F P
0 g
s
.741 .711 .823 r
.71641 .5467 m .72558 .54536 L .72539 .54545 L p F P
0 g
s
.741 .711 .823 r
.72539 .54545 m .71601 .54689 L .71641 .5467 L p F P
0 g
s
.734 .605 .714 r
.72402 .54737 m .71327 .55073 L .71366 .54994 L p F P
0 g
s
.733 .603 .712 r
.71327 .55073 m .72402 .54737 L .72382 .54781 L p F P
0 g
s
.672 .857 .97 r
.7168 .5466 m .72578 .54531 L .72558 .54536 L p F P
0 g
s
.672 .857 .97 r
.72558 .54536 m .71641 .5467 L .7168 .5466 L p F P
0 g
s
.733 .603 .712 r
.72382 .54781 m .71288 .55159 L .71327 .55073 L p F P
0 g
s
.732 .601 .71 r
.71288 .55159 m .72382 .54781 L .72363 .54827 L p F P
0 g
s
.55 .122 .182 r
.7172 .54659 m .72598 .5453 L .72578 .54531 L p F P
0 g
s
.55 .122 .182 r
.72578 .54531 m .7168 .5466 L .7172 .54659 L p F P
0 g
s
.732 .601 .71 r
.72363 .54827 m .7125 .55252 L .71288 .55159 L p F P
0 g
s
.732 .599 .708 r
.7125 .55252 m .72363 .54827 L .72343 .54876 L p F P
0 g
s
.732 .599 .708 r
.72343 .54876 m .71211 .5535 L .7125 .55252 L p F P
0 g
s
.731 .598 .707 r
.71211 .5535 m .72343 .54876 L .72324 .54928 L p F P
0 g
s
.69 .42 .509 r
.71759 .54666 m .72618 .54534 L .72598 .5453 L p F P
0 g
s
.69 .42 .509 r
.72598 .5453 m .7172 .54659 L .71759 .54666 L p F P
0 g
s
.731 .598 .707 r
.72324 .54928 m .71172 .55453 L .71211 .5535 L p F P
0 g
s
.731 .596 .706 r
.71172 .55453 m .72324 .54928 L .72305 .54983 L p F P
0 g
s
.711 .484 .579 r
.71799 .54681 m .72637 .54541 L .72618 .54534 L p F P
0 g
s
.711 .484 .579 r
.72618 .54534 m .71759 .54666 L .71799 .54681 L p F P
0 g
s
.731 .596 .706 r
.72305 .54983 m .71133 .55562 L .71172 .55453 L p F P
0 g
s
.73 .595 .706 r
.71133 .55562 m .72305 .54983 L .72285 .55039 L p F P
0 g
s
.719 .511 .607 r
.71839 .54704 m .72657 .54553 L .72637 .54541 L p F P
0 g
s
.719 .511 .607 r
.72637 .54541 m .71799 .54681 L .71839 .54704 L p F P
0 g
s
.73 .595 .706 r
.72285 .55039 m .71095 .55674 L .71133 .55562 L p F P
0 g
s
.73 .595 .705 r
.71095 .55674 m .72285 .55039 L .72266 .55098 L p F P
0 g
s
.724 .526 .623 r
.71879 .54733 m .72677 .54568 L .72657 .54553 L p F P
0 g
s
.724 .526 .623 r
.72657 .54553 m .71839 .54704 L .71879 .54733 L p F P
0 g
s
.73 .595 .705 r
.72266 .55098 m .71056 .5579 L .71095 .55674 L p F P
0 g
s
.73 .594 .704 r
.71056 .5579 m .72266 .55098 L .72247 .55158 L p F P
0 g
s
.73 .594 .704 r
.72247 .55158 m .71017 .55909 L .71056 .5579 L p F P
0 g
s
.73 .593 .704 r
.71017 .55909 m .72247 .55158 L .72228 .55219 L p F P
0 g
s
.726 .535 .632 r
.71919 .54769 m .72697 .54586 L .72677 .54568 L p F P
0 g
s
.726 .535 .632 r
.72677 .54568 m .71879 .54733 L .71919 .54769 L p F P
0 g
s
.73 .593 .704 r
.72228 .55219 m .70979 .56031 L .71017 .55909 L p F P
0 g
s
.729 .593 .703 r
.70979 .56031 m .72228 .55219 L .72208 .55282 L p F P
0 g
s
.728 .542 .639 r
.71958 .5481 m .72717 .54607 L .72697 .54586 L p F P
0 g
s
.728 .542 .639 r
.72697 .54586 m .71919 .54769 L .71958 .5481 L p F P
0 g
s
.729 .593 .703 r
.72208 .55282 m .7094 .56157 L .70979 .56031 L p F P
0 g
s
.729 .592 .703 r
.7094 .56157 m .72208 .55282 L .72189 .55347 L p F P
0 g
s
.73 .546 .643 r
.71998 .54856 m .72737 .5463 L .72717 .54607 L p F P
0 g
s
.73 .546 .643 r
.72717 .54607 m .71958 .5481 L .71998 .54856 L p F P
0 g
s
.729 .592 .703 r
.72189 .55347 m .70901 .56284 L .7094 .56157 L p F P
0 g
s
.729 .592 .703 r
.70901 .56284 m .72189 .55347 L .7217 .55412 L p F P
0 g
s
.731 .55 .647 r
.72038 .54908 m .72757 .54656 L .72737 .5463 L p F P
0 g
s
.731 .55 .647 r
.72737 .5463 m .71998 .54856 L .72038 .54908 L p F P
0 g
s
.729 .592 .703 r
.7217 .55412 m .70863 .56414 L .70901 .56284 L p F P
0 g
s
.729 .591 .703 r
.70863 .56414 m .7217 .55412 L .7215 .55479 L p F P
0 g
s
.729 .591 .703 r
.7215 .55479 m .70824 .56546 L .70863 .56414 L p F P
0 g
s
.728 .591 .702 r
.70824 .56546 m .7215 .55479 L .72131 .55546 L p F P
0 g
s
.732 .552 .649 r
.72079 .54963 m .72777 .54684 L .72757 .54656 L p F P
0 g
s
.732 .552 .649 r
.72757 .54656 m .72038 .54908 L .72079 .54963 L p F P
0 g
s
.728 .591 .702 r
.72131 .55546 m .70786 .56679 L .70824 .56546 L p F P
0 g
s
.728 .591 .702 r
.70786 .56679 m .72131 .55546 L .72112 .55614 L p F P
0 g
s
.733 .555 .651 r
.72119 .55022 m .72797 .54714 L .72777 .54684 L p F P
0 g
s
.733 .555 .651 r
.72777 .54684 m .72079 .54963 L .72119 .55022 L p F P
0 g
s
.728 .591 .702 r
.72112 .55614 m .70747 .56814 L .70786 .56679 L p F P
0 g
s
.728 .59 .702 r
.70747 .56814 m .72112 .55614 L .72093 .55683 L p F P
0 g
s
.734 .557 .653 r
.72159 .55085 m .72817 .54746 L .72797 .54714 L p F P
0 g
s
.734 .557 .653 r
.72797 .54714 m .72119 .55022 L .72159 .55085 L p F P
0 g
s
.728 .59 .702 r
.72093 .55683 m .70709 .56951 L .70747 .56814 L p F P
0 g
s
.728 .59 .702 r
.70709 .56951 m .72093 .55683 L .72074 .55753 L p F P
0 g
s
.728 .59 .702 r
.72074 .55753 m .7067 .57089 L .70709 .56951 L p F P
0 g
s
.728 .59 .702 r
.7067 .57089 m .72074 .55753 L .72054 .55823 L p F P
0 g
s
.734 .558 .654 r
.72199 .5515 m .72837 .54779 L .72817 .54746 L p F P
0 g
s
.734 .558 .654 r
.72817 .54746 m .72159 .55085 L .72199 .5515 L p F P
0 g
s
.728 .59 .702 r
.72054 .55823 m .70632 .57228 L .7067 .57089 L p F P
0 g
s
.735 .559 .655 r
.72239 .55218 m .72857 .54814 L .72837 .54779 L p F P
0 g
s
.735 .559 .655 r
.72837 .54779 m .72199 .5515 L .72239 .55218 L p F P
0 g
s
.735 .56 .656 r
.72279 .55289 m .72878 .54849 L .72857 .54814 L p F P
0 g
s
.735 .56 .656 r
.72857 .54814 m .72239 .55218 L .72279 .55289 L p F P
0 g
s
.736 .561 .656 r
.72319 .55362 m .72898 .54886 L .72878 .54849 L p F P
0 g
s
.736 .561 .656 r
.72878 .54849 m .72279 .55289 L .72319 .55362 L p F P
0 g
s
.736 .562 .657 r
.7236 .55437 m .72918 .54925 L .72898 .54886 L p F P
0 g
s
.736 .562 .657 r
.72898 .54886 m .72319 .55362 L .7236 .55437 L p F P
0 g
s
.737 .563 .657 r
.724 .55514 m .72938 .54963 L .72918 .54925 L p F P
0 g
s
.737 .563 .657 r
.72918 .54925 m .7236 .55437 L .724 .55514 L p F P
0 g
s
.737 .564 .658 r
.7244 .55592 m .72958 .55003 L .72938 .54963 L p F P
0 g
s
.737 .564 .658 r
.72938 .54963 m .724 .55514 L .7244 .55592 L p F P
0 g
s
.738 .564 .658 r
.7248 .55672 m .72978 .55044 L .72958 .55003 L p F P
0 g
s
.738 .564 .658 r
.72958 .55003 m .7244 .55592 L .7248 .55672 L p F P
0 g
s
.738 .565 .658 r
.72521 .55753 m .72998 .55085 L .72978 .55044 L p F P
0 g
s
.738 .565 .658 r
.72978 .55044 m .7248 .55672 L .72521 .55753 L p F P
0 g
s
.739 .565 .659 r
.72561 .55835 m .73018 .55127 L .72998 .55085 L p F P
0 g
s
.739 .565 .659 r
.72998 .55085 m .72521 .55753 L .72561 .55835 L p F P
0 g
s
.735 .622 .733 r
.70545 .54876 m .71523 .54756 L .71483 .54802 L p F P
0 g
s
.735 .622 .733 r
.71483 .54802 m .70486 .54946 L .70545 .54876 L p F P
0 g
s
.734 .615 .725 r
.70486 .54946 m .71483 .54802 L .71444 .54858 L p F P
0 g
s
.734 .615 .725 r
.71444 .54858 m .70427 .55029 L .70486 .54946 L p F P
0 g
s
.733 .61 .72 r
.70427 .55029 m .71444 .54858 L .71405 .54922 L p F P
0 g
s
.736 .633 .745 r
.70604 .54819 m .71562 .54718 L .71523 .54756 L p F P
0 g
s
.736 .633 .745 r
.71523 .54756 m .70545 .54876 L .70604 .54819 L p F P
0 g
s
.733 .61 .72 r
.71405 .54922 m .70368 .55125 L .70427 .55029 L p F P
0 g
s
.733 .606 .716 r
.70368 .55125 m .71405 .54922 L .71366 .54994 L p F P
0 g
s
.736 .651 .765 r
.70663 .54777 m .71601 .54689 L .71562 .54718 L p F P
0 g
s
.736 .651 .765 r
.71562 .54718 m .70604 .54819 L .70663 .54777 L p F P
0 g
s
.733 .606 .716 r
.71366 .54994 m .7031 .55233 L .70368 .55125 L p F P
0 g
s
.732 .603 .713 r
.7031 .55233 m .71366 .54994 L .71327 .55073 L p F P
0 g
s
.735 .688 .805 r
.70722 .54748 m .71641 .5467 L .71601 .54689 L p F P
0 g
s
.735 .688 .805 r
.71601 .54689 m .70663 .54777 L .70722 .54748 L p F P
0 g
s
.732 .603 .713 r
.71327 .55073 m .70251 .55351 L .7031 .55233 L p F P
0 g
s
.732 .601 .711 r
.70251 .55351 m .71327 .55073 L .71288 .55159 L p F P
0 g
s
.705 .786 .915 r
.70781 .54732 m .7168 .5466 L .71641 .5467 L p F P
0 g
s
.705 .786 .915 r
.71641 .5467 m .70722 .54748 L .70781 .54732 L p F P
0 g
s
.732 .601 .711 r
.71288 .55159 m .70193 .5548 L .70251 .55351 L p F P
0 g
s
.731 .599 .71 r
.70193 .5548 m .71288 .55159 L .7125 .55252 L p F P
0 g
s
.731 .599 .71 r
.7125 .55252 m .70135 .55618 L .70193 .5548 L p F P
0 g
s
.731 .598 .708 r
.70135 .55618 m .7125 .55252 L .71211 .5535 L p F P
0 g
s
.333 0 0 r
.7084 .5473 m .7172 .54659 L .7168 .5466 L p F P
0 g
s
.333 0 0 r
.7168 .5466 m .70781 .54732 L .7084 .5473 L p F P
0 g
s
.731 .598 .708 r
.71211 .5535 m .70076 .55765 L .70135 .55618 L p F P
0 g
s
.73 .597 .707 r
.70076 .55765 m .71211 .5535 L .71172 .55453 L p F P
0 g
s
.685 .385 .46 r
.709 .54741 m .71759 .54666 L .7172 .54659 L p F P
0 g
s
.685 .385 .46 r
.7172 .54659 m .7084 .5473 L .709 .54741 L p F P
0 g
s
.73 .597 .707 r
.71172 .55453 m .70018 .55919 L .70076 .55765 L p F P
0 g
s
.73 .595 .706 r
.70018 .55919 m .71172 .55453 L .71133 .55562 L p F P
0 g
s
.714 .474 .561 r
.70959 .54763 m .71799 .54681 L .71759 .54666 L p F P
0 g
s
.714 .474 .561 r
.71759 .54666 m .709 .54741 L .70959 .54763 L p F P
0 g
s
.73 .595 .706 r
.71133 .55562 m .6996 .5608 L .70018 .55919 L p F P
0 g
s
.73 .595 .705 r
.6996 .5608 m .71133 .55562 L .71095 .55674 L p F P
0 g
s
.722 .507 .598 r
.71019 .54797 m .71839 .54704 L .71799 .54681 L p F P
0 g
s
.722 .507 .598 r
.71799 .54681 m .70959 .54763 L .71019 .54797 L p F P
0 g
s
.73 .595 .705 r
.71095 .55674 m .69902 .56248 L .6996 .5608 L p F P
0 g
s
.729 .594 .705 r
.69902 .56248 m .71095 .55674 L .71056 .5579 L p F P
0 g
s
.726 .524 .616 r
.71079 .5484 m .71879 .54733 L .71839 .54704 L p F P
0 g
s
.726 .524 .616 r
.71839 .54704 m .71019 .54797 L .71079 .5484 L p F P
0 g
s
.729 .594 .705 r
.71056 .5579 m .69844 .5642 L .69902 .56248 L p F P
0 g
s
.729 .593 .704 r
.69844 .5642 m .71056 .5579 L .71017 .55909 L p F P
0 g
s
.729 .593 .704 r
.71017 .55909 m .69786 .56598 L .69844 .5642 L p F P
0 g
s
.729 .592 .704 r
.69786 .56598 m .71017 .55909 L .70979 .56031 L p F P
0 g
s
.729 .534 .628 r
.71139 .54893 m .71919 .54769 L .71879 .54733 L p F P
0 g
s
.729 .534 .628 r
.71879 .54733 m .71079 .5484 L .71139 .54893 L p F P
0 g
s
.729 .592 .704 r
.70979 .56031 m .69728 .5678 L .69786 .56598 L p F P
0 g
s
.728 .592 .703 r
.69728 .5678 m .70979 .56031 L .7094 .56157 L p F P
0 g
s
.731 .541 .635 r
.71198 .54954 m .71958 .5481 L .71919 .54769 L p F P
0 g
s
.731 .541 .635 r
.71919 .54769 m .71139 .54893 L .71198 .54954 L p F P
0 g
s
.728 .592 .703 r
.7094 .56157 m .6967 .56967 L .69728 .5678 L p F P
0 g
s
.728 .591 .703 r
.6967 .56967 m .7094 .56157 L .70901 .56284 L p F P
0 g
s
.732 .546 .64 r
.71258 .55023 m .71998 .54856 L .71958 .5481 L p F P
0 g
s
.732 .546 .64 r
.71958 .5481 m .71198 .54954 L .71258 .55023 L p F P
0 g
s
.728 .591 .703 r
.70901 .56284 m .69612 .57156 L .6967 .56967 L p F P
0 g
s
.728 .591 .703 r
.69612 .57156 m .70901 .56284 L .70863 .56414 L p F P
0 g
s
.728 .591 .703 r
.70863 .56414 m .69554 .57349 L .69612 .57156 L p F P
0 g
s
.728 .591 .702 r
.69554 .57349 m .70863 .56414 L .70824 .56546 L p F P
0 g
s
.733 .549 .644 r
.71318 .55099 m .72038 .54908 L .71998 .54856 L p F P
0 g
s
.733 .549 .644 r
.71998 .54856 m .71258 .55023 L .71318 .55099 L p F P
0 g
s
.728 .591 .702 r
.70824 .56546 m .69496 .57545 L .69554 .57349 L p F P
0 g
s
.728 .59 .702 r
.69496 .57545 m .70824 .56546 L .70786 .56679 L p F P
0 g
s
.734 .552 .647 r
.71378 .55181 m .72079 .54963 L .72038 .54908 L p F P
0 g
s
.734 .552 .647 r
.72038 .54908 m .71318 .55099 L .71378 .55181 L p F P
0 g
s
.728 .59 .702 r
.70786 .56679 m .69438 .57744 L .69496 .57545 L p F P
0 g
s
.727 .59 .702 r
.69438 .57744 m .70786 .56679 L .70747 .56814 L p F P
0 g
s
.735 .555 .649 r
.71438 .55268 m .72119 .55022 L .72079 .54963 L p F P
0 g
s
.735 .555 .649 r
.72079 .54963 m .71378 .55181 L .71438 .55268 L p F P
0 g
s
.727 .59 .702 r
.70747 .56814 m .6938 .57944 L .69438 .57744 L p F P
0 g
s
.727 .59 .702 r
.6938 .57944 m .70747 .56814 L .70709 .56951 L p F P
0 g
s
.727 .59 .702 r
.70709 .56951 m .69322 .58147 L .6938 .57944 L p F P
0 g
s
.727 .589 .702 r
.69322 .58147 m .70709 .56951 L .7067 .57089 L p F P
0 g
s
.736 .557 .65 r
.71499 .55361 m .72159 .55085 L .72119 .55022 L p F P
0 g
s
.736 .557 .65 r
.72119 .55022 m .71438 .55268 L .71499 .55361 L p F P
0 g
s
.727 .589 .702 r
.7067 .57089 m .69264 .58352 L .69322 .58147 L p F P
0 g
s
.727 .589 .702 r
.69264 .58352 m .7067 .57089 L .70632 .57228 L p F P
0 g
s
.736 .558 .652 r
.71559 .55458 m .72199 .5515 L .72159 .55085 L p F P
0 g
s
.736 .558 .652 r
.72159 .55085 m .71499 .55361 L .71559 .55458 L p F P
0 g
s
.727 .589 .702 r
.70632 .57228 m .69206 .58559 L .69264 .58352 L p F P
0 g
s
.737 .559 .653 r
.71619 .55559 m .72239 .55218 L .72199 .5515 L p F P
0 g
s
.737 .559 .653 r
.72199 .5515 m .71559 .55458 L .71619 .55559 L p F P
0 g
s
.732 .618 .731 r
.69565 .54939 m .70545 .54876 L .70486 .54946 L p F P
0 g
s
.732 .618 .731 r
.70486 .54946 m .69487 .55032 L .69565 .54939 L p F P
0 g
s
.732 .612 .724 r
.69487 .55032 m .70486 .54946 L .70427 .55029 L p F P
0 g
s
.732 .612 .724 r
.70427 .55029 m .69408 .55143 L .69487 .55032 L p F P
0 g
s
.732 .608 .719 r
.69408 .55143 m .70427 .55029 L .70368 .55125 L p F P
0 g
s
.733 .627 .742 r
.69644 .54864 m .70604 .54819 L .70545 .54876 L p F P
0 g
s
.733 .627 .742 r
.70545 .54876 m .69565 .54939 L .69644 .54864 L p F P
0 g
s
.732 .608 .719 r
.70368 .55125 m .6933 .55271 L .69408 .55143 L p F P
0 g
s
.731 .604 .716 r
.6933 .55271 m .70368 .55125 L .7031 .55233 L p F P
0 g
s
.732 .642 .759 r
.69722 .54807 m .70663 .54777 L .70604 .54819 L p F P
0 g
s
.732 .642 .759 r
.70604 .54819 m .69644 .54864 L .69722 .54807 L p F P
0 g
s
.737 .561 .654 r
.71679 .55663 m .72279 .55289 L .72239 .55218 L p F P
0 g
s
.737 .561 .654 r
.72239 .55218 m .71619 .55559 L .71679 .55663 L p F P
0 g
s
.731 .604 .716 r
.7031 .55233 m .69252 .55414 L .6933 .55271 L p F P
0 g
s
.731 .602 .713 r
.69252 .55414 m .7031 .55233 L .70251 .55351 L p F P
0 g
s
.729 .67 .792 r
.69801 .54768 m .70722 .54748 L .70663 .54777 L p F P
0 g
s
.729 .67 .792 r
.70663 .54777 m .69722 .54807 L .69801 .54768 L p F P
0 g
s
.731 .602 .713 r
.70251 .55351 m .69174 .55572 L .69252 .55414 L p F P
0 g
s
.73 .6 .711 r
.69174 .55572 m .70251 .55351 L .70193 .5548 L p F P
0 g
s
.71 .736 .871 r
.6988 .54748 m .70781 .54732 L .70722 .54748 L p F P
0 g
s
.71 .736 .871 r
.70722 .54748 m .69801 .54768 L .6988 .54748 L p F P
0 g
s
.73 .6 .711 r
.70193 .5548 m .69096 .55743 L .69174 .55572 L p F P
0 g
s
.73 .598 .709 r
.69096 .55743 m .70193 .5548 L .70135 .55618 L p F P
0 g
s
.738 .562 .654 r
.7174 .55771 m .72319 .55362 L .72279 .55289 L p F P
0 g
s
.738 .562 .654 r
.72279 .55289 m .71679 .55663 L .7174 .55771 L p F P
0 g
s
.73 .598 .709 r
.70135 .55618 m .69018 .55927 L .69096 .55743 L p F P
0 g
s
.73 .597 .708 r
.69018 .55927 m .70135 .55618 L .70076 .55765 L p F P
0 g
s
.208 .726 .87 r
.6996 .54745 m .7084 .5473 L .70781 .54732 L p F P
0 g
s
.208 .726 .87 r
.70781 .54732 m .6988 .54748 L .6996 .54745 L p F P
0 g
s
.73 .597 .708 r
.70076 .55765 m .6894 .56121 L .69018 .55927 L p F P
0 g
s
.729 .595 .707 r
.6894 .56121 m .70076 .55765 L .70018 .55919 L p F P
0 g
s
.673 .324 .375 r
.70039 .54758 m .709 .54741 L .7084 .5473 L p F P
0 g
s
.673 .324 .375 r
.7084 .5473 m .6996 .54745 L .70039 .54758 L p F P
0 g
s
.738 .562 .655 r
.718 .55881 m .7236 .55437 L .72319 .55362 L p F P
0 g
s
.738 .562 .655 r
.72319 .55362 m .7174 .55771 L .718 .55881 L p F P
0 g
s
.729 .595 .707 r
.70018 .55919 m .68863 .56326 L .6894 .56121 L p F P
0 g
s
.729 .594 .706 r
.68863 .56326 m .70018 .55919 L .6996 .5608 L p F P
0 g
s
.716 .459 .536 r
.70118 .54788 m .70959 .54763 L .709 .54741 L p F P
0 g
s
.716 .459 .536 r
.709 .54741 m .70039 .54758 L .70118 .54788 L p F P
0 g
s
.729 .594 .706 r
.6996 .5608 m .68785 .56539 L .68863 .56326 L p F P
0 g
s
.729 .594 .705 r
.68785 .56539 m .6996 .5608 L .69902 .56248 L p F P
0 g
s
.739 .563 .655 r
.7186 .55994 m .724 .55514 L .7236 .55437 L p F P
0 g
s
.739 .563 .655 r
.7236 .55437 m .718 .55881 L .7186 .55994 L p F P
0 g
s
.726 .501 .585 r
.70198 .54832 m .71019 .54797 L .70959 .54763 L p F P
0 g
s
.726 .501 .585 r
.70959 .54763 m .70118 .54788 L .70198 .54832 L p F P
0 g
s
.729 .594 .705 r
.69902 .56248 m .68707 .56761 L .68785 .56539 L p F P
0 g
s
.728 .593 .705 r
.68707 .56761 m .69902 .56248 L .69844 .5642 L p F P
0 g
s
.739 .564 .656 r
.71921 .5611 m .7244 .55592 L .724 .55514 L p F P
0 g
s
.739 .564 .656 r
.724 .55514 m .7186 .55994 L .71921 .5611 L p F P
0 g
s
.73 .521 .609 r
.70277 .54889 m .71079 .5484 L .71019 .54797 L p F P
0 g
s
.73 .521 .609 r
.71019 .54797 m .70198 .54832 L .70277 .54889 L p F P
0 g
s
.728 .593 .705 r
.69844 .5642 m .6863 .5699 L .68707 .56761 L p F P
0 g
s
.728 .592 .704 r
.6863 .5699 m .69844 .5642 L .69786 .56598 L p F P
0 g
s
.728 .592 .704 r
.69786 .56598 m .68552 .57225 L .6863 .5699 L p F P
0 g
s
.728 .592 .704 r
.68552 .57225 m .69786 .56598 L .69728 .5678 L p F P
0 g
s
.74 .565 .656 r
.71981 .56227 m .7248 .55672 L .7244 .55592 L p F P
0 g
s
.74 .565 .656 r
.7244 .55592 m .71921 .5611 L .71981 .56227 L p F P
0 g
s
.732 .532 .622 r
.70357 .54959 m .71139 .54893 L .71079 .5484 L p F P
0 g
s
.732 .532 .622 r
.71079 .5484 m .70277 .54889 L .70357 .54959 L p F P
0 g
s
.728 .592 .704 r
.69728 .5678 m .68475 .57466 L .68552 .57225 L p F P
0 g
s
.728 .591 .703 r
.68475 .57466 m .69728 .5678 L .6967 .56967 L p F P
0 g
s
.74 .565 .656 r
.72042 .56347 m .72521 .55753 L .7248 .55672 L p F P
0 g
s
.74 .565 .656 r
.7248 .55672 m .71981 .56227 L .72042 .56347 L p F P
0 g
s
.734 .54 .63 r
.70437 .5504 m .71198 .54954 L .71139 .54893 L p F P
0 g
s
.734 .54 .63 r
.71139 .54893 m .70357 .54959 L .70437 .5504 L p F P
0 g
s
.728 .591 .703 r
.6967 .56967 m .68397 .57712 L .68475 .57466 L p F P
0 g
s
.727 .591 .703 r
.68397 .57712 m .6967 .56967 L .69612 .57156 L p F P
0 g
s
.741 .566 .657 r
.72102 .56468 m .72561 .55835 L .72521 .55753 L p F P
0 g
s
.741 .566 .657 r
.72521 .55753 m .72042 .56347 L .72102 .56468 L p F P
0 g
s
.735 .545 .636 r
.70517 .5513 m .71258 .55023 L .71198 .54954 L p F P
0 g
s
.735 .545 .636 r
.71198 .54954 m .70437 .5504 L .70517 .5513 L p F P
0 g
s
.727 .591 .703 r
.69612 .57156 m .6832 .57963 L .68397 .57712 L p F P
0 g
s
.727 .59 .703 r
.6832 .57963 m .69612 .57156 L .69554 .57349 L p F P
0 g
s
.727 .59 .703 r
.69554 .57349 m .68242 .58218 L .6832 .57963 L p F P
0 g
s
.727 .59 .702 r
.68242 .58218 m .69554 .57349 L .69496 .57545 L p F P
0 g
s
.736 .549 .64 r
.70597 .5523 m .71318 .55099 L .71258 .55023 L p F P
0 g
s
.736 .549 .64 r
.71258 .55023 m .70517 .5513 L .70597 .5523 L p F P
0 g
s
.727 .59 .702 r
.69496 .57545 m .68165 .58477 L .68242 .58218 L p F P
0 g
s
.727 .59 .702 r
.68165 .58477 m .69496 .57545 L .69438 .57744 L p F P
0 g
s
.737 .552 .644 r
.70677 .55338 m .71378 .55181 L .71318 .55099 L p F P
0 g
s
.737 .552 .644 r
.71318 .55099 m .70597 .5523 L .70677 .55338 L p F P
0 g
s
.73 .615 .729 r
.68584 .54945 m .69565 .54939 L .69487 .55032 L p F P
0 g
s
.73 .615 .729 r
.69487 .55032 m .68486 .55061 L .68584 .54945 L p F P
0 g
s
.73 .609 .723 r
.68486 .55061 m .69487 .55032 L .69408 .55143 L p F P
0 g
s
.73 .609 .723 r
.69408 .55143 m .68388 .552 L .68486 .55061 L p F P
0 g
s
.73 .605 .718 r
.68388 .552 m .69408 .55143 L .6933 .55271 L p F P
0 g
s
.727 .59 .702 r
.69438 .57744 m .68087 .58739 L .68165 .58477 L p F P
0 g
s
.727 .589 .702 r
.68087 .58739 m .69438 .57744 L .6938 .57944 L p F P
0 g
s
.73 .622 .739 r
.68683 .54851 m .69644 .54864 L .69565 .54939 L p F P
0 g
s
.73 .622 .739 r
.69565 .54939 m .68584 .54945 L .68683 .54851 L p F P
0 g
s
.73 .605 .718 r
.6933 .55271 m .6829 .55359 L .68388 .552 L p F P
0 g
s
.73 .602 .715 r
.6829 .55359 m .6933 .55271 L .69252 .55414 L p F P
0 g
s
.729 .635 .754 r
.68781 .5478 m .69722 .54807 L .69644 .54864 L p F P
0 g
s
.729 .635 .754 r
.69644 .54864 m .68683 .54851 L .68781 .5478 L p F P
0 g
s
.73 .602 .715 r
.69252 .55414 m .68193 .55538 L .6829 .55359 L p F P
0 g
s
.729 .6 .712 r
.68193 .55538 m .69252 .55414 L .69174 .55572 L p F P
0 g
s
.725 .656 .781 r
.6888 .54731 m .69801 .54768 L .69722 .54807 L p F P
0 g
s
.725 .656 .781 r
.69722 .54807 m .68781 .5478 L .6888 .54731 L p F P
0 g
s
.737 .555 .646 r
.70757 .55453 m .71438 .55268 L .71378 .55181 L p F P
0 g
s
.737 .555 .646 r
.71378 .55181 m .70677 .55338 L .70757 .55453 L p F P
0 g
s
.729 .6 .712 r
.69174 .55572 m .68095 .55735 L .68193 .55538 L p F P
0 g
s
.729 .598 .71 r
.68095 .55735 m .69174 .55572 L .69096 .55743 L p F P
0 g
s
.727 .589 .702 r
.6938 .57944 m .6801 .59004 L .68087 .58739 L p F P
0 g
s
.727 .589 .702 r
.6801 .59004 m .6938 .57944 L .69322 .58147 L p F P
0 g
s
.71 .702 .84 r
.68978 .54706 m .6988 .54748 L .69801 .54768 L p F P
0 g
s
.71 .702 .84 r
.69801 .54768 m .6888 .54731 L .68978 .54706 L p F P
0 g
s
.729 .598 .71 r
.69096 .55743 m .67997 .55948 L .68095 .55735 L p F P
0 g
s
.729 .597 .709 r
.67997 .55948 m .69096 .55743 L .69018 .55927 L p F P
0 g
s
.727 .589 .702 r
.69322 .58147 m .67933 .59272 L .6801 .59004 L p F P
0 g
s
.726 .589 .702 r
.67933 .59272 m .69322 .58147 L .69264 .58352 L p F P
0 g
s
.729 .597 .709 r
.69018 .55927 m .679 .56176 L .67997 .55948 L p F P
0 g
s
.729 .595 .708 r
.679 .56176 m .69018 .55927 L .6894 .56121 L p F P
0 g
s
.543 .813 .996 r
.69077 .54702 m .6996 .54745 L .6988 .54748 L p F P
0 g
s
.632 .759 .939 r
.68194 .54601 m .69077 .54702 L .68978 .54706 L p F P
0 g
s
.482 0 0 r
.68313 .54621 m .68843 .54681 L p .69077 .54702 L F P
0 g
s
.543 .813 .996 r
.6928 .5472 m .68978 .54706 L .69077 .54702 L p F P
0 g
s
.482 0 0 r
.68843 .54681 m .69177 .54719 L .69077 .54702 L p F P
0 g
s
.543 .813 .996 r
.6988 .54748 m .6928 .5472 L p .69077 .54702 L F P
0 g
s
.738 .557 .648 r
.70837 .55574 m .71499 .55361 L .71438 .55268 L p F P
0 g
s
.738 .557 .648 r
.71438 .55268 m .70757 .55453 L .70837 .55574 L p F P
0 g
s
.729 .595 .708 r
.6894 .56121 m .67803 .56419 L .679 .56176 L p F P
0 g
s
.728 .594 .707 r
.67803 .56419 m .6894 .56121 L .68863 .56326 L p F P
0 g
s
.635 .205 .209 r
.69177 .54719 m .70039 .54758 L .6996 .54745 L p F P
0 g
s
.635 .205 .209 r
.6996 .54745 m .69077 .54702 L .69177 .54719 L p F P
0 g
s
.726 .589 .702 r
.69264 .58352 m .67855 .59542 L .67933 .59272 L p F P
0 g
s
.726 .589 .701 r
.67855 .59542 m .69264 .58352 L .69206 .58559 L p F P
0 g
s
.728 .594 .707 r
.68863 .56326 m .67705 .56673 L .67803 .56419 L p F P
0 g
s
.728 .593 .706 r
.67705 .56673 m .68863 .56326 L .68785 .56539 L p F P
0 g
s
.739 .558 .649 r
.70917 .55702 m .71559 .55458 L .71499 .55361 L p F P
0 g
s
.739 .558 .649 r
.71499 .55361 m .70837 .55574 L .70917 .55702 L p F P
0 g
s
.719 .438 .5 r
.69276 .54755 m .70118 .54788 L .70039 .54758 L p F P
0 g
s
.719 .438 .5 r
.70039 .54758 m .69177 .54719 L .69276 .54755 L p F P
0 g
s
.726 .589 .701 r
.69206 .58559 m .67778 .59815 L .67855 .59542 L p F P
0 g
s
.728 .593 .706 r
.68785 .56539 m .67608 .56938 L .67705 .56673 L p F P
0 g
s
.728 .593 .705 r
.67608 .56938 m .68785 .56539 L .68707 .56761 L p F P
0 g
s
.73 .493 .569 r
.69375 .54809 m .70198 .54832 L .70118 .54788 L p F P
0 g
s
.73 .493 .569 r
.70118 .54788 m .69276 .54755 L .69375 .54809 L p F P
0 g
s
.739 .56 .65 r
.70998 .55834 m .71619 .55559 L .71559 .55458 L p F P
0 g
s
.739 .56 .65 r
.71559 .55458 m .70917 .55702 L .70998 .55834 L p F P
0 g
s
.728 .593 .705 r
.68707 .56761 m .67511 .57213 L .67608 .56938 L p F P
0 g
s
.727 .592 .704 r
.67511 .57213 m .68707 .56761 L .6863 .5699 L p F P
0 g
s
.734 .517 .599 r
.69475 .5488 m .70277 .54889 L .70198 .54832 L p F P
0 g
s
.734 .517 .599 r
.70198 .54832 m .69375 .54809 L .69475 .5488 L p F P
0 g
s
.727 .592 .704 r
.6863 .5699 m .67414 .57497 L .67511 .57213 L p F P
0 g
s
.727 .591 .704 r
.67414 .57497 m .6863 .5699 L .68552 .57225 L p F P
0 g
s
.74 .561 .651 r
.71078 .55971 m .71679 .55663 L .71619 .55559 L p F P
0 g
s
.74 .561 .651 r
.71619 .55559 m .70998 .55834 L .71078 .55971 L p F P
0 g
s
.727 .591 .704 r
.68552 .57225 m .67317 .57789 L .67414 .57497 L p F P
0 g
s
.727 .591 .703 r
.67317 .57789 m .68552 .57225 L .68475 .57466 L p F P
0 g
s
.736 .53 .615 r
.69574 .54966 m .70357 .54959 L .70277 .54889 L p F P
0 g
s
.736 .53 .615 r
.70277 .54889 m .69475 .5488 L .69574 .54966 L p F P
0 g
s
.74 .562 .652 r
.71158 .56112 m .7174 .55771 L .71679 .55663 L p F P
0 g
s
.74 .562 .652 r
.71679 .55663 m .71078 .55971 L .71158 .56112 L p F P
0 g
s
.727 .591 .703 r
.68475 .57466 m .6722 .58088 L .67317 .57789 L p F P
0 g
s
.727 .59 .703 r
.6722 .58088 m .68475 .57466 L .68397 .57712 L p F P
0 g
s
.737 .539 .625 r
.69674 .55066 m .70437 .5504 L .70357 .54959 L p F P
0 g
s
.737 .539 .625 r
.70357 .54959 m .69574 .54966 L .69674 .55066 L p F P
0 g
s
.727 .59 .703 r
.68397 .57712 m .67123 .58393 L .6722 .58088 L p F P
0 g
s
.727 .59 .703 r
.67123 .58393 m .68397 .57712 L .6832 .57963 L p F P
0 g
s
.741 .563 .653 r
.71239 .56257 m .718 .55881 L .7174 .55771 L p F P
0 g
s
.741 .563 .653 r
.7174 .55771 m .71158 .56112 L .71239 .56257 L p F P
0 g
s
.728 .611 .727 r
.67602 .54894 m .68584 .54945 L .68486 .55061 L p F P
0 g
s
.728 .611 .727 r
.68486 .55061 m .67484 .55033 L .67602 .54894 L p F P
0 g
s
.728 .607 .721 r
.67484 .55033 m .68486 .55061 L .68388 .552 L p F P
0 g
s
.728 .607 .721 r
.68388 .552 m .67367 .55199 L .67484 .55033 L p F P
0 g
s
.728 .603 .717 r
.67367 .55199 m .68388 .552 L .6829 .55359 L p F P
0 g
s
.727 .618 .736 r
.6772 .54781 m .68683 .54851 L .68584 .54945 L p F P
0 g
s
.727 .618 .736 r
.68584 .54945 m .67602 .54894 L .6772 .54781 L p F P
0 g
s
.738 .545 .632 r
.69774 .55178 m .70517 .5513 L .70437 .5504 L p F P
0 g
s
.738 .545 .632 r
.70437 .5504 m .69674 .55066 L .69774 .55178 L p F P
0 g
s
.728 .603 .717 r
.6829 .55359 m .67249 .5539 L .67367 .55199 L p F P
0 g
s
.728 .601 .714 r
.67249 .5539 m .6829 .55359 L .68193 .55538 L p F P
0 g
s
.727 .59 .703 r
.6832 .57963 m .67026 .58704 L .67123 .58393 L p F P
0 g
s
.726 .59 .703 r
.67026 .58704 m .6832 .57963 L .68242 .58218 L p F P
0 g
s
.725 .628 .749 r
.67838 .54695 m .68781 .5478 L .68683 .54851 L p F P
0 g
s
.725 .628 .749 r
.68683 .54851 m .6772 .54781 L .67838 .54695 L p F P
0 g
s
.728 .601 .714 r
.68193 .55538 m .67132 .55604 L .67249 .5539 L p F P
0 g
s
.728 .599 .712 r
.67132 .55604 m .68193 .55538 L .68095 .55735 L p F P
0 g
s
.741 .563 .653 r
.71319 .56405 m .7186 .55994 L .718 .55881 L p F P
0 g
s
.741 .563 .653 r
.718 .55881 m .71239 .56257 L .71319 .56405 L p F P
0 g
s
.721 .645 .772 r
.67957 .54637 m .6888 .54731 L .68781 .5478 L p F P
0 g
s
.721 .645 .772 r
.68781 .5478 m .67838 .54695 L .67957 .54637 L p F P
0 g
s
.728 .599 .712 r
.68095 .55735 m .67015 .5584 L .67132 .55604 L p F P
0 g
s
.728 .597 .71 r
.67015 .5584 m .68095 .55735 L .67997 .55948 L p F P
0 g
s
.726 .59 .703 r
.68242 .58218 m .66929 .5902 L .67026 .58704 L p F P
0 g
s
.726 .589 .702 r
.66929 .5902 m .68242 .58218 L .68165 .58477 L p F P
0 g
s
.709 .677 .818 r
.68075 .54606 m .68978 .54706 L .6888 .54731 L p F P
0 g
s
.709 .677 .818 r
.6888 .54731 m .67957 .54637 L .68075 .54606 L p F P
0 g
s
.728 .597 .71 r
.67997 .55948 m .66898 .56095 L .67015 .5584 L p F P
0 g
s
.728 .595 .708 r
.66898 .56095 m .67997 .55948 L .679 .56176 L p F P
0 g
s
.739 .549 .637 r
.69874 .55301 m .70597 .5523 L .70517 .5513 L p F P
0 g
s
.739 .549 .637 r
.70517 .5513 m .69774 .55178 L .69874 .55301 L p F P
0 g
s
.742 .564 .654 r
.714 .56556 m .71921 .5611 L .7186 .55994 L p F P
0 g
s
.742 .564 .654 r
.7186 .55994 m .71319 .56405 L .714 .56556 L p F P
0 g
s
.728 .595 .708 r
.679 .56176 m .66781 .56368 L .66898 .56095 L p F P
0 g
s
.727 .594 .707 r
.66781 .56368 m .679 .56176 L .67803 .56419 L p F P
0 g
s
.632 .759 .939 r
.68978 .54706 m .68075 .54606 L .68194 .54601 L p F P
0 g
s
.726 .589 .702 r
.68165 .58477 m .66832 .5934 L .66929 .5902 L p F P
0 g
s
.726 .589 .702 r
.66832 .5934 m .68165 .58477 L .68087 .58739 L p F P
0 g
s
.727 .594 .707 r
.67803 .56419 m .66664 .56657 L .66781 .56368 L p F P
0 g
s
.727 .593 .706 r
.66664 .56657 m .67803 .56419 L .67705 .56673 L p F P
0 g
s
.739 .552 .64 r
.69974 .55434 m .70677 .55338 L .70597 .5523 L p F P
0 g
s
.739 .552 .64 r
.70597 .5523 m .69874 .55301 L .69974 .55434 L p F P
0 g
s
.482 0 0 r
.69077 .54702 m .68194 .54601 L .68313 .54621 L p F P
0 g
s
.742 .565 .654 r
.7148 .5671 m .71981 .56227 L .71921 .5611 L p F P
0 g
s
.742 .565 .654 r
.71921 .5611 m .714 .56556 L .7148 .5671 L p F P
0 g
s
.726 .589 .702 r
.68087 .58739 m .66735 .59665 L .66832 .5934 L p F P
0 g
s
.726 .589 .702 r
.66735 .59665 m .68087 .58739 L .6801 .59004 L p F P
0 g
s
.727 .593 .706 r
.67705 .56673 m .66547 .56961 L .66664 .56657 L p F P
0 g
s
.727 .593 .705 r
.66547 .56961 m .67705 .56673 L .67608 .56938 L p F P
0 g
s
.72 .405 .444 r
.68432 .54664 m .69276 .54755 L .69177 .54719 L p F P
0 g
s
.72 .405 .444 r
.69177 .54719 m .68313 .54621 L .68432 .54664 L p F P
0 g
s
.74 .555 .643 r
.70074 .55576 m .70757 .55453 L .70677 .55338 L p F P
0 g
s
.74 .555 .643 r
.70677 .55338 m .69974 .55434 L .70074 .55576 L p F P
0 g
s
.726 .589 .702 r
.6801 .59004 m .66638 .59993 L .66735 .59665 L p F P
0 g
s
.726 .588 .702 r
.66638 .59993 m .6801 .59004 L .67933 .59272 L p F P
0 g
s
.727 .593 .705 r
.67608 .56938 m .6643 .57277 L .66547 .56961 L p F P
0 g
s
.727 .592 .705 r
.6643 .57277 m .67608 .56938 L .67511 .57213 L p F P
0 g
s
.742 .565 .654 r
.71561 .56867 m .72042 .56347 L .71981 .56227 L p F P
0 g
s
.742 .565 .654 r
.71981 .56227 m .7148 .5671 L .71561 .56867 L p F P
0 g
s
.735 .483 .548 r
.68551 .54729 m .69375 .54809 L .69276 .54755 L p F P
0 g
s
.735 .483 .548 r
.69276 .54755 m .68432 .54664 L .68551 .54729 L p F P
0 g
s
.726 .588 .702 r
.67933 .59272 m .66541 .60324 L .66638 .59993 L p F P
0 g
s
.726 .588 .702 r
.66541 .60324 m .67933 .59272 L .67855 .59542 L p F P
0 g
s
.727 .592 .705 r
.67511 .57213 m .66313 .57605 L .6643 .57277 L p F P
0 g
s
.727 .591 .704 r
.66313 .57605 m .67511 .57213 L .67414 .57497 L p F P
0 g
s
.741 .557 .645 r
.70174 .55725 m .70837 .55574 L .70757 .55453 L p F P
0 g
s
.741 .557 .645 r
.70757 .55453 m .70074 .55576 L .70174 .55725 L p F P
0 g
s
.743 .566 .655 r
.71642 .57026 m .72102 .56468 L .72042 .56347 L p F P
0 g
s
.743 .566 .655 r
.72042 .56347 m .71561 .56867 L .71642 .57026 L p F P
0 g
s
.727 .591 .704 r
.67414 .57497 m .66197 .57944 L .66313 .57605 L p F P
0 g
s
.726 .591 .704 r
.66197 .57944 m .67414 .57497 L .67317 .57789 L p F P
0 g
s
.739 .513 .587 r
.68671 .54813 m .69475 .5488 L .69375 .54809 L p F P
0 g
s
.739 .513 .587 r
.69375 .54809 m .68551 .54729 L .68671 .54813 L p F P
0 g
s
.726 .588 .702 r
.67855 .59542 m .66444 .60659 L .66541 .60324 L p F P
0 g
s
.726 .588 .701 r
.66444 .60659 m .67855 .59542 L .67778 .59815 L p F P
0 g
s
.741 .558 .646 r
.70274 .55882 m .70917 .55702 L .70837 .55574 L p F P
0 g
s
.741 .558 .646 r
.70837 .55574 m .70174 .55725 L .70274 .55882 L p F P
0 g
s
.726 .591 .704 r
.67317 .57789 m .6608 .58291 L .66197 .57944 L p F P
0 g
s
.726 .59 .703 r
.6608 .58291 m .67317 .57789 L .6722 .58088 L p F P
0 g
s
.726 .588 .701 r
.67778 .59815 m .66347 .60996 L .66444 .60659 L p F P
0 g
s
.74 .528 .607 r
.6879 .54915 m .69574 .54966 L .69475 .5488 L p F P
0 g
s
.74 .528 .607 r
.69475 .5488 m .68671 .54813 L .6879 .54915 L p F P
0 g
s
.726 .608 .726 r
.66619 .54785 m .67602 .54894 L .67484 .55033 L p F P
0 g
s
.726 .608 .726 r
.67484 .55033 m .66481 .54948 L .66619 .54785 L p F P
0 g
s
.727 .604 .72 r
.66481 .54948 m .67484 .55033 L .67367 .55199 L p F P
0 g
s
.727 .604 .72 r
.67367 .55199 m .66344 .55142 L .66481 .54948 L p F P
0 g
s
.727 .601 .716 r
.66344 .55142 m .67367 .55199 L .67249 .5539 L p F P
0 g
s
.725 .614 .733 r
.66757 .54653 m .6772 .54781 L .67602 .54894 L p F P
0 g
s
.725 .614 .733 r
.67602 .54894 m .66619 .54785 L .66757 .54653 L p F P
0 g
s
.727 .601 .716 r
.67249 .5539 m .66207 .55364 L .66344 .55142 L p F P
0 g
s
.727 .599 .713 r
.66207 .55364 m .67249 .5539 L .67132 .55604 L p F P
0 g
s
.726 .59 .703 r
.6722 .58088 m .65963 .58647 L .6608 .58291 L p F P
0 g
s
.726 .59 .703 r
.65963 .58647 m .6722 .58088 L .67123 .58393 L p F P
0 g
s
.723 .622 .745 r
.66894 .54553 m .67838 .54695 L .6772 .54781 L p F P
0 g
s
.723 .622 .745 r
.6772 .54781 m .66757 .54653 L .66894 .54553 L p F P
0 g
s
.727 .599 .713 r
.67132 .55604 m .6607 .55613 L .66207 .55364 L p F P
0 g
s
.727 .597 .711 r
.6607 .55613 m .67132 .55604 L .67015 .5584 L p F P
0 g
s
.742 .56 .648 r
.70375 .56044 m .70998 .55834 L .70917 .55702 L p F P
0 g
s
.742 .56 .648 r
.70917 .55702 m .70274 .55882 L .70375 .56044 L p F P
0 g
s
.718 .635 .764 r
.67033 .54486 m .67957 .54637 L .67838 .54695 L p F P
0 g
s
.718 .635 .764 r
.67838 .54695 m .66894 .54553 L .67033 .54486 L p F P
0 g
s
.727 .597 .711 r
.67015 .5584 m .65933 .55887 L .6607 .55613 L p F P
0 g
s
.727 .596 .709 r
.65933 .55887 m .67015 .5584 L .66898 .56095 L p F P
0 g
s
.741 .537 .619 r
.6891 .55033 m .69674 .55066 L .69574 .54966 L p F P
0 g
s
.741 .537 .619 r
.69574 .54966 m .6879 .54915 L .6891 .55033 L p F P
0 g
s
.726 .59 .703 r
.67123 .58393 m .65847 .5901 L .65963 .58647 L p F P
0 g
s
.726 .589 .703 r
.65847 .5901 m .67123 .58393 L .67026 .58704 L p F P
0 g
s
.707 .659 .801 r
.67171 .54449 m .68075 .54606 L .67957 .54637 L p F P
0 g
s
.707 .659 .801 r
.67957 .54637 m .67033 .54486 L .67171 .54449 L p F P
0 g
s
.727 .596 .709 r
.66898 .56095 m .65796 .56184 L .65933 .55887 L p F P
0 g
s
.727 .594 .708 r
.65796 .56184 m .66898 .56095 L .66781 .56368 L p F P
0 g
s
.742 .561 .649 r
.70475 .56213 m .71078 .55971 L .70998 .55834 L p F P
0 g
s
.742 .561 .649 r
.70998 .55834 m .70375 .56044 L .70475 .56213 L p F P
0 g
s
.727 .594 .708 r
.66781 .56368 m .6566 .56501 L .65796 .56184 L p F P
0 g
s
.727 .593 .707 r
.6566 .56501 m .66781 .56368 L .66664 .56657 L p F P
0 g
s
.661 .713 .887 r
.67309 .54443 m .68194 .54601 L .68075 .54606 L p F P
0 g
s
.661 .713 .887 r
.68075 .54606 m .67171 .54449 L .67309 .54443 L p F P
0 g
s
.726 .589 .703 r
.67026 .58704 m .6573 .5938 L .65847 .5901 L p F P
0 g
s
.726 .589 .702 r
.6573 .5938 m .67026 .58704 L .66929 .5902 L p F P
0 g
s
.741 .544 .627 r
.6903 .55166 m .69774 .55178 L .69674 .55066 L p F P
0 g
s
.741 .544 .627 r
.69674 .55066 m .6891 .55033 L .6903 .55166 L p F P
0 g
s
.727 .593 .707 r
.66664 .56657 m .65523 .56837 L .6566 .56501 L p F P
0 g
s
.726 .592 .706 r
.65523 .56837 m .66664 .56657 L .66547 .56961 L p F P
0 g
s
.011 .568 .814 r
.67448 .54466 m .68313 .54621 L .68194 .54601 L p F P
0 g
s
.011 .568 .814 r
.68194 .54601 m .67309 .54443 L .67448 .54466 L p F P
0 g
s
.726 .589 .702 r
.66929 .5902 m .65614 .59755 L .6573 .5938 L p F P
0 g
s
.726 .589 .702 r
.65614 .59755 m .66929 .5902 L .66832 .5934 L p F P
0 g
s
.743 .562 .65 r
.70576 .56386 m .71158 .56112 L .71078 .55971 L p F P
0 g
s
.743 .562 .65 r
.71078 .55971 m .70475 .56213 L .70576 .56386 L p F P
0 g
s
.726 .592 .706 r
.66547 .56961 m .65387 .57189 L .65523 .56837 L p F P
0 g
s
.726 .592 .705 r
.65387 .57189 m .66547 .56961 L .6643 .57277 L p F P
0 g
s
.742 .548 .632 r
.6915 .55312 m .69874 .55301 L .69774 .55178 L p F P
0 g
s
.742 .548 .632 r
.69774 .55178 m .6903 .55166 L .6915 .55312 L p F P
0 g
s
.716 .345 .346 r
.67587 .54516 m .68432 .54664 L .68313 .54621 L p F P
0 g
s
.716 .345 .346 r
.68313 .54621 m .67448 .54466 L .67587 .54516 L p F P
0 g
s
.726 .589 .702 r
.66832 .5934 m .65497 .60136 L .65614 .59755 L p F P
0 g
s
.725 .588 .702 r
.65497 .60136 m .66832 .5934 L .66735 .59665 L p F P
0 g
s
.726 .592 .705 r
.6643 .57277 m .6525 .57556 L .65387 .57189 L p F P
0 g
s
.726 .591 .705 r
.6525 .57556 m .6643 .57277 L .66313 .57605 L p F P
0 g
s
.743 .563 .65 r
.70676 .56564 m .71239 .56257 L .71158 .56112 L p F P
0 g
s
.743 .563 .65 r
.71158 .56112 m .70576 .56386 L .70676 .56564 L p F P
0 g
s
.743 .552 .636 r
.6927 .55469 m .69974 .55434 L .69874 .55301 L p F P
0 g
s
.743 .552 .636 r
.69874 .55301 m .6915 .55312 L .6927 .55469 L p F P
0 g
s
.741 .468 .517 r
.67726 .5459 m .68551 .54729 L .68432 .54664 L p F P
0 g
s
.741 .468 .517 r
.68432 .54664 m .67587 .54516 L .67726 .5459 L p F P
0 g
s
.725 .588 .702 r
.66735 .59665 m .65381 .60521 L .65497 .60136 L p F P
0 g
s
.725 .588 .702 r
.65381 .60521 m .66735 .59665 L .66638 .59993 L p F P
0 g
s
.726 .591 .705 r
.66313 .57605 m .65114 .57936 L .6525 .57556 L p F P
0 g
s
.726 .59 .704 r
.65114 .57936 m .66313 .57605 L .66197 .57944 L p F P
0 g
s
.744 .564 .651 r
.70777 .56746 m .71319 .56405 L .71239 .56257 L p F P
0 g
s
.744 .564 .651 r
.71239 .56257 m .70676 .56564 L .70777 .56746 L p F P
0 g
s
.726 .59 .704 r
.66197 .57944 m .64978 .58328 L .65114 .57936 L p F P
0 g
s
.726 .59 .704 r
.64978 .58328 m .66197 .57944 L .6608 .58291 L p F P
0 g
s
.725 .588 .702 r
.66638 .59993 m .65264 .60911 L .65381 .60521 L p F P
0 g
s
.725 .588 .702 r
.65264 .60911 m .66638 .59993 L .66541 .60324 L p F P
0 g
s
.744 .507 .571 r
.67865 .54688 m .68671 .54813 L .68551 .54729 L p F P
0 g
s
.744 .507 .571 r
.68551 .54729 m .67726 .5459 L .67865 .54688 L p F P
0 g
s
.724 .606 .724 r
.65634 .54619 m .66619 .54785 L .66481 .54948 L p F P
0 g
s
.724 .606 .724 r
.66481 .54948 m .65477 .54805 L .65634 .54619 L p F P
0 g
s
.725 .602 .719 r
.65477 .54805 m .66481 .54948 L .66344 .55142 L p F P
0 g
s
.743 .554 .639 r
.6939 .55636 m .70074 .55576 L .69974 .55434 L p F P
0 g
s
.743 .554 .639 r
.69974 .55434 m .6927 .55469 L .6939 .55636 L p F P
0 g
s
.725 .602 .719 r
.66344 .55142 m .6532 .55026 L .65477 .54805 L p F P
0 g
s
.725 .599 .716 r
.6532 .55026 m .66344 .55142 L .66207 .55364 L p F P
0 g
s
.723 .61 .731 r
.65792 .54468 m .66757 .54653 L .66619 .54785 L p F P
0 g
s
.723 .61 .731 r
.66619 .54785 m .65634 .54619 L .65792 .54468 L p F P
0 g
s
.725 .599 .716 r
.66207 .55364 m .65163 .5528 L .6532 .55026 L p F P
0 g
s
.726 .597 .713 r
.65163 .5528 m .66207 .55364 L .6607 .55613 L p F P
0 g
s
.72 .617 .742 r
.65949 .54354 m .66894 .54553 L .66757 .54653 L p F P
0 g
s
.72 .617 .742 r
.66757 .54653 m .65792 .54468 L .65949 .54354 L p F P
0 g
s
.726 .597 .713 r
.6607 .55613 m .65007 .55565 L .65163 .5528 L p F P
0 g
s
.726 .596 .711 r
.65007 .55565 m .6607 .55613 L .65933 .55887 L p F P
0 g
s
.726 .59 .704 r
.6608 .58291 m .64841 .5873 L .64978 .58328 L p F P
0 g
s
.725 .589 .703 r
.64841 .5873 m .6608 .58291 L .65963 .58647 L p F P
0 g
s
.725 .588 .702 r
.66541 .60324 m .65148 .61305 L .65264 .60911 L p F P
0 g
s
.725 .588 .701 r
.65148 .61305 m .66541 .60324 L .66444 .60659 L p F P
0 g
s
.715 .628 .758 r
.66107 .54277 m .67033 .54486 L .66894 .54553 L p F P
0 g
s
.715 .628 .758 r
.66894 .54553 m .65949 .54354 L .66107 .54277 L p F P
0 g
s
.744 .565 .651 r
.70877 .56932 m .714 .56556 L .71319 .56405 L p F P
0 g
s
.744 .565 .651 r
.71319 .56405 m .70777 .56746 L .70877 .56932 L p F P
0 g
s
.726 .596 .711 r
.65933 .55887 m .6485 .55877 L .65007 .55565 L p F P
0 g
s
.726 .594 .709 r
.6485 .55877 m .65933 .55887 L .65796 .56184 L p F P
0 g
s
.745 .525 .596 r
.68005 .54805 m .6879 .54915 L .68671 .54813 L p F P
0 g
s
.745 .525 .596 r
.68671 .54813 m .67865 .54688 L .68005 .54805 L p F P
0 g
s
.744 .557 .641 r
.6951 .55813 m .70174 .55725 L .70074 .55576 L p F P
0 g
s
.744 .557 .641 r
.70074 .55576 m .6939 .55636 L .6951 .55813 L p F P
0 g
s
.726 .594 .709 r
.65796 .56184 m .64694 .56215 L .6485 .55877 L p F P
0 g
s
.726 .593 .708 r
.64694 .56215 m .65796 .56184 L .6566 .56501 L p F P
0 g
s
.705 .646 .788 r
.66265 .54235 m .67171 .54449 L .67033 .54486 L p F P
0 g
s
.705 .646 .788 r
.67033 .54486 m .66107 .54277 L .66265 .54235 L p F P
0 g
s
.725 .589 .703 r
.65963 .58647 m .64705 .59142 L .64841 .5873 L p F P
0 g
s
.725 .589 .703 r
.64705 .59142 m .65963 .58647 L .65847 .5901 L p F P
0 g
s
.725 .588 .701 r
.66444 .60659 m .65031 .61702 L .65148 .61305 L p F P
0 g
s
.725 .587 .701 r
.65031 .61702 m .66444 .60659 L .66347 .60996 L p F P
0 g
s
.726 .593 .708 r
.6566 .56501 m .64538 .56576 L .64694 .56215 L p F P
0 g
s
.726 .592 .707 r
.64538 .56576 m .6566 .56501 L .65523 .56837 L p F P
0 g
s
.745 .565 .652 r
.70978 .57121 m .7148 .5671 L .714 .56556 L p F P
0 g
s
.745 .565 .652 r
.714 .56556 m .70877 .56932 L .70978 .57121 L p F P
0 g
s
.672 .682 .851 r
.66424 .54228 m .67309 .54443 L .67171 .54449 L p F P
0 g
s
.672 .682 .851 r
.67171 .54449 m .66265 .54235 L .66424 .54228 L p F P
0 g
s
.745 .536 .611 r
.68144 .54942 m .6891 .55033 L .6879 .54915 L p F P
0 g
s
.745 .536 .611 r
.6879 .54915 m .68005 .54805 L .68144 .54942 L p F P
0 g
s
.725 .589 .703 r
.65847 .5901 m .64569 .59562 L .64705 .59142 L p F P
0 g
s
.725 .589 .703 r
.64569 .59562 m .65847 .5901 L .6573 .5938 L p F P
0 g
s
.744 .558 .643 r
.6963 .55998 m .70274 .55882 L .70174 .55725 L p F P
0 g
s
.744 .558 .643 r
.70174 .55725 m .6951 .55813 L .6963 .55998 L p F P
0 g
s
.726 .592 .707 r
.65523 .56837 m .64381 .56958 L .64538 .56576 L p F P
0 g
s
.725 .591 .706 r
.64381 .56958 m .65523 .56837 L .65387 .57189 L p F P
0 g
s
.725 .587 .701 r
.66347 .60996 m .64915 .62103 L .65031 .61702 L p F P
0 g
s
.423 .729 .989 r
.66582 .54254 m .67448 .54466 L .67309 .54443 L p F P
0 g
s
.559 .707 .94 r
.65715 .53984 m .66582 .54254 L .66424 .54228 L p F P
0 g
s
.501 0 0 r
.65894 .54046 m .66267 .54162 L p .66582 .54254 L F P
0 g
s
.423 .729 .989 r
.66859 .54334 m .66424 .54228 L .66582 .54254 L p F P
0 g
s
.501 0 0 r
.66267 .54162 m .66741 .5431 L .66582 .54254 L p F P
0 g
s
.423 .729 .989 r
.67309 .54443 m .66859 .54334 L p .66582 .54254 L F P
0 g
s
.745 .566 .652 r
.71079 .57313 m .71561 .56867 L .7148 .5671 L p F P
0 g
s
.745 .566 .652 r
.7148 .5671 m .70978 .57121 L .71079 .57313 L p F P
0 g
s
.725 .591 .706 r
.65387 .57189 m .64225 .57358 L .64381 .56958 L p F P
0 g
s
.725 .591 .705 r
.64225 .57358 m .65387 .57189 L .6525 .57556 L p F P
0 g
s
.725 .589 .703 r
.6573 .5938 m .64433 .59989 L .64569 .59562 L p F P
0 g
s
.725 .588 .702 r
.64433 .59989 m .6573 .5938 L .65614 .59755 L p F P
0 g
s
.746 .543 .62 r
.68284 .55094 m .6903 .55166 L .6891 .55033 L p F P
0 g
s
.746 .543 .62 r
.6891 .55033 m .68144 .54942 L .68284 .55094 L p F P
0 g
s
.682 .219 .147 r
.66741 .5431 m .67587 .54516 L .67448 .54466 L p F P
0 g
s
.682 .219 .147 r
.67448 .54466 m .66582 .54254 L .66741 .5431 L p F P
0 g
s
.745 .56 .645 r
.69751 .5619 m .70375 .56044 L .70274 .55882 L p F P
0 g
s
.745 .56 .645 r
.70274 .55882 m .6963 .55998 L .69751 .5619 L p F P
0 g
s
.725 .591 .705 r
.6525 .57556 m .64069 .57775 L .64225 .57358 L p F P
0 g
s
.725 .59 .704 r
.64069 .57775 m .6525 .57556 L .65114 .57936 L p F P
0 g
s
.745 .566 .652 r
.7118 .57508 m .71642 .57026 L .71561 .56867 L p F P
0 g
s
.745 .566 .652 r
.71561 .56867 m .71079 .57313 L .7118 .57508 L p F P
0 g
s
.725 .588 .702 r
.65614 .59755 m .64297 .60423 L .64433 .59989 L p F P
0 g
s
.725 .588 .702 r
.64297 .60423 m .65614 .59755 L .65497 .60136 L p F P
0 g
s
.746 .548 .627 r
.68424 .55262 m .6915 .55312 L .6903 .55166 L p F P
0 g
s
.746 .548 .627 r
.6903 .55166 m .68284 .55094 L .68424 .55262 L p F P
0 g
s
.748 .445 .47 r
.669 .54394 m .67726 .5459 L .67587 .54516 L p F P
0 g
s
.748 .445 .47 r
.67587 .54516 m .66741 .5431 L .669 .54394 L p F P
0 g
s
.725 .59 .704 r
.65114 .57936 m .63913 .58206 L .64069 .57775 L p F P
0 g
s
.725 .59 .704 r
.63913 .58206 m .65114 .57936 L .64978 .58328 L p F P
0 g
s
.722 .603 .723 r
.64649 .54396 m .65634 .54619 L .65477 .54805 L p F P
0 g
s
.722 .603 .723 r
.65477 .54805 m .64472 .54605 L .64649 .54396 L p F P
0 g
s
.723 .6 .718 r
.64472 .54605 m .65477 .54805 L .6532 .55026 L p F P
0 g
s
.723 .6 .718 r
.6532 .55026 m .64295 .54854 L .64472 .54605 L p F P
0 g
s
.724 .598 .715 r
.64295 .54854 m .6532 .55026 L .65163 .5528 L p F P
0 g
s
.721 .607 .729 r
.64826 .54226 m .65792 .54468 L .65634 .54619 L p F P
0 g
s
.721 .607 .729 r
.65634 .54619 m .64649 .54396 L .64826 .54226 L p F P
0 g
s
.745 .561 .646 r
.69871 .56388 m .70475 .56213 L .70375 .56044 L p F P
0 g
s
.745 .561 .646 r
.70375 .56044 m .69751 .5619 L .69871 .56388 L p F P
0 g
s
.724 .598 .715 r
.65163 .5528 m .64119 .55139 L .64295 .54854 L p F P
0 g
s
.724 .596 .712 r
.64119 .55139 m .65163 .5528 L .65007 .55565 L p F P
0 g
s
.725 .588 .702 r
.65497 .60136 m .6416 .60863 L .64297 .60423 L p F P
0 g
s
.725 .588 .702 r
.6416 .60863 m .65497 .60136 L .65381 .60521 L p F P
0 g
s
.718 .613 .739 r
.65003 .54098 m .65949 .54354 L .65792 .54468 L p F P
0 g
s
.718 .613 .739 r
.65792 .54468 m .64826 .54226 L .65003 .54098 L p F P
0 g
s
.724 .596 .712 r
.65007 .55565 m .63942 .55458 L .64119 .55139 L p F P
0 g
s
.725 .594 .71 r
.63942 .55458 m .65007 .55565 L .6485 .55877 L p F P
0 g
s
.725 .59 .704 r
.64978 .58328 m .63757 .58651 L .63913 .58206 L p F P
0 g
s
.725 .589 .704 r
.63757 .58651 m .64978 .58328 L .64841 .5873 L p F P
0 g
s
.713 .621 .753 r
.65181 .5401 m .66107 .54277 L .65949 .54354 L p F P
0 g
s
.713 .621 .753 r
.65949 .54354 m .65003 .54098 L .65181 .5401 L p F P
0 g
s
.725 .594 .71 r
.6485 .55877 m .63766 .55809 L .63942 .55458 L p F P
0 g
s
.725 .593 .709 r
.63766 .55809 m .6485 .55877 L .64694 .56215 L p F P
0 g
s
.751 .498 .549 r
.67059 .54504 m .67865 .54688 L .67726 .5459 L p F P
0 g
s
.751 .498 .549 r
.67726 .5459 m .669 .54394 L .67059 .54504 L p F P
0 g
s
.746 .551 .631 r
.68564 .55442 m .6927 .55469 L .6915 .55312 L p F P
0 g
s
.746 .551 .631 r
.6915 .55312 m .68424 .55262 L .68564 .55442 L p F P
0 g
s
.725 .588 .702 r
.65381 .60521 m .64024 .61308 L .6416 .60863 L p F P
0 g
s
.725 .587 .702 r
.64024 .61308 m .65381 .60521 L .65264 .60911 L p F P
0 g
s
.725 .593 .709 r
.64694 .56215 m .6359 .56188 L .63766 .55809 L p F P
0 g
s
.725 .592 .707 r
.6359 .56188 m .64694 .56215 L .64538 .56576 L p F P
0 g
s
.703 .635 .778 r
.65359 .53964 m .66265 .54235 L .66107 .54277 L p F P
0 g
s
.703 .635 .778 r
.66107 .54277 m .65181 .5401 L .65359 .53964 L p F P
0 g
s
.746 .562 .647 r
.69992 .56593 m .70576 .56386 L .70475 .56213 L p F P
0 g
s
.746 .562 .647 r
.70475 .56213 m .69871 .56388 L .69992 .56593 L p F P
0 g
s
.725 .589 .704 r
.64841 .5873 m .63601 .59107 L .63757 .58651 L p F P
0 g
s
.725 .589 .703 r
.63601 .59107 m .64841 .5873 L .64705 .59142 L p F P
0 g
s
.725 .592 .707 r
.64538 .56576 m .63414 .56593 L .6359 .56188 L p F P
0 g
s
.725 .591 .706 r
.63414 .56593 m .64538 .56576 L .64381 .56958 L p F P
0 g
s
.677 .66 .826 r
.65537 .53955 m .66424 .54228 L .66265 .54235 L p F P
0 g
s
.677 .66 .826 r
.66265 .54235 m .65359 .53964 L .65537 .53955 L p F P
0 g
s
.751 .521 .583 r
.67218 .54637 m .68005 .54805 L .67865 .54688 L p F P
0 g
s
.751 .521 .583 r
.67865 .54688 m .67059 .54504 L .67218 .54637 L p F P
0 g
s
.725 .587 .702 r
.65264 .60911 m .63888 .61759 L .64024 .61308 L p F P
0 g
s
.724 .587 .702 r
.63888 .61759 m .65264 .60911 L .65148 .61305 L p F P
0 g
s
.747 .554 .635 r
.68704 .55635 m .6939 .55636 L .6927 .55469 L p F P
0 g
s
.747 .554 .635 r
.6927 .55469 m .68564 .55442 L .68704 .55635 L p F P
0 g
s
.725 .589 .703 r
.64705 .59142 m .63445 .59574 L .63601 .59107 L p F P
0 g
s
.725 .588 .703 r
.63445 .59574 m .64705 .59142 L .64569 .59562 L p F P
0 g
s
.725 .591 .706 r
.64381 .56958 m .63238 .5702 L .63414 .56593 L p F P
0 g
s
.725 .591 .706 r
.63238 .5702 m .64381 .56958 L .64225 .57358 L p F P
0 g
s
.746 .563 .647 r
.70112 .56803 m .70676 .56564 L .70576 .56386 L p F P
0 g
s
.746 .563 .647 r
.70576 .56386 m .69992 .56593 L .70112 .56803 L p F P
0 g
s
.559 .707 .94 r
.66424 .54228 m .65537 .53955 L .65715 .53984 L p F P
0 g
s
.724 .587 .702 r
.65148 .61305 m .63752 .62213 L .63888 .61759 L p F P
0 g
s
.724 .587 .701 r
.63752 .62213 m .65148 .61305 L .65031 .61702 L p F P
0 g
s
.751 .534 .601 r
.67378 .54791 m .68144 .54942 L .68005 .54805 L p F P
0 g
s
.751 .534 .601 r
.68005 .54805 m .67218 .54637 L .67378 .54791 L p F P
0 g
s
.725 .591 .706 r
.64225 .57358 m .63062 .57468 L .63238 .5702 L p F P
0 g
s
.724 .59 .705 r
.63062 .57468 m .64225 .57358 L .64069 .57775 L p F P
0 g
s
.725 .588 .703 r
.64569 .59562 m .6329 .60049 L .63445 .59574 L p F P
0 g
s
.724 .588 .703 r
.6329 .60049 m .64569 .59562 L .64433 .59989 L p F P
0 g
s
.747 .557 .637 r
.68844 .55838 m .6951 .55813 L .6939 .55636 L p F P
0 g
s
.747 .557 .637 r
.6939 .55636 m .68704 .55635 L .68844 .55838 L p F P
0 g
s
.501 0 0 r
.66582 .54254 m .65715 .53984 L .65894 .54046 L p F P
0 g
s
.747 .564 .648 r
.70233 .57017 m .70777 .56746 L .70676 .56564 L p F P
0 g
s
.747 .564 .648 r
.70676 .56564 m .70112 .56803 L .70233 .57017 L p F P
0 g
s
.724 .587 .701 r
.65031 .61702 m .63616 .62672 L .63752 .62213 L p F P
0 g
s
.724 .587 .701 r
.63616 .62672 m .65031 .61702 L .64915 .62103 L p F P
0 g
s
.724 .59 .705 r
.64069 .57775 m .62887 .57934 L .63062 .57468 L p F P
0 g
s
.724 .589 .704 r
.62887 .57934 m .64069 .57775 L .63913 .58206 L p F P
0 g
s
.721 .601 .722 r
.63662 .54115 m .64649 .54396 L .64472 .54605 L p F P
0 g
s
.721 .601 .722 r
.64472 .54605 m .63466 .54348 L .63662 .54115 L p F P
0 g
s
.722 .598 .717 r
.63466 .54348 m .64472 .54605 L .64295 .54854 L p F P
0 g
s
.722 .598 .717 r
.64295 .54854 m .63269 .54624 L .63466 .54348 L p F P
0 g
s
.723 .596 .714 r
.63269 .54624 m .64295 .54854 L .64119 .55139 L p F P
0 g
s
.719 .604 .727 r
.63859 .53926 m .64826 .54226 L .64649 .54396 L p F P
0 g
s
.719 .604 .727 r
.64649 .54396 m .63662 .54115 L .63859 .53926 L p F P
0 g
s
.724 .588 .703 r
.64433 .59989 m .63134 .60533 L .6329 .60049 L p F P
0 g
s
.724 .588 .702 r
.63134 .60533 m .64433 .59989 L .64297 .60423 L p F P
0 g
s
.723 .596 .714 r
.64119 .55139 m .63073 .54941 L .63269 .54624 L p F P
0 g
s
.723 .594 .712 r
.63073 .54941 m .64119 .55139 L .63942 .55458 L p F P
0 g
s
.75 .542 .613 r
.67538 .54963 m .68284 .55094 L .68144 .54942 L p F P
0 g
s
.75 .542 .613 r
.68144 .54942 m .67378 .54791 L .67538 .54963 L p F P
0 g
s
.716 .609 .736 r
.64056 .53784 m .65003 .54098 L .64826 .54226 L p F P
0 g
s
.716 .609 .736 r
.64826 .54226 m .63859 .53926 L .64056 .53784 L p F P
0 g
s
.723 .594 .712 r
.63942 .55458 m .62877 .55295 L .63073 .54941 L p F P
0 g
s
.724 .593 .71 r
.62877 .55295 m .63942 .55458 L .63766 .55809 L p F P
0 g
s
.724 .587 .701 r
.64915 .62103 m .6348 .63134 L .63616 .62672 L p F P
0 g
s
.754 .406 .393 r
.66072 .5414 m .669 .54394 L .66741 .5431 L p F P
0 g
s
.754 .406 .393 r
.66741 .5431 m .65894 .54046 L .66072 .5414 L p F P
0 g
s
.724 .589 .704 r
.63913 .58206 m .62711 .58416 L .62887 .57934 L p F P
0 g
s
.724 .589 .704 r
.62711 .58416 m .63913 .58206 L .63757 .58651 L p F P
0 g
s
.747 .558 .639 r
.68985 .5605 m .6963 .55998 L .6951 .55813 L p F P
0 g
s
.747 .558 .639 r
.6951 .55813 m .68844 .55838 L .68985 .5605 L p F P
0 g
s
.711 .616 .749 r
.64253 .53687 m .65181 .5401 L .65003 .54098 L p F P
0 g
s
.711 .616 .749 r
.65003 .54098 m .64056 .53784 L .64253 .53687 L p F P
0 g
s
.747 .565 .648 r
.70354 .57236 m .70877 .56932 L .70777 .56746 L p F P
0 g
s
.747 .565 .648 r
.70777 .56746 m .70233 .57017 L .70354 .57236 L p F P
0 g
s
.724 .593 .71 r
.63766 .55809 m .62681 .55683 L .62877 .55295 L p F P
0 g
s
.724 .592 .708 r
.62681 .55683 m .63766 .55809 L .6359 .56188 L p F P
0 g
s
.724 .588 .702 r
.64297 .60423 m .62978 .61024 L .63134 .60533 L p F P
0 g
s
.724 .587 .702 r
.62978 .61024 m .64297 .60423 L .6416 .60863 L p F P
0 g
s
.724 .592 .708 r
.6359 .56188 m .62485 .56103 L .62681 .55683 L p F P
0 g
s
.724 .591 .707 r
.62485 .56103 m .6359 .56188 L .63414 .56593 L p F P
0 g
s
.702 .626 .769 r
.64451 .53634 m .65359 .53964 L .65181 .5401 L p F P
0 g
s
.702 .626 .769 r
.65181 .5401 m .64253 .53687 L .64451 .53634 L p F P
0 g
s
.724 .589 .704 r
.63757 .58651 m .62535 .58912 L .62711 .58416 L p F P
0 g
s
.724 .588 .703 r
.62535 .58912 m .63757 .58651 L .63601 .59107 L p F P
0 g
s
.75 .547 .62 r
.67697 .55152 m .68424 .55262 L .68284 .55094 L p F P
0 g
s
.75 .547 .62 r
.68284 .55094 m .67538 .54963 L .67697 .55152 L p F P
0 g
s
.76 .486 .519 r
.66251 .54262 m .67059 .54504 L .669 .54394 L p F P
0 g
s
.76 .486 .519 r
.669 .54394 m .66072 .5414 L .66251 .54262 L p F P
0 g
s
.724 .591 .707 r
.63414 .56593 m .6229 .56551 L .62485 .56103 L p F P
0 g
s
.724 .59 .706 r
.6229 .56551 m .63414 .56593 L .63238 .5702 L p F P
0 g
s
.724 .587 .702 r
.6416 .60863 m .62822 .61522 L .62978 .61024 L p F P
0 g
s
.724 .587 .702 r
.62822 .61522 m .6416 .60863 L .64024 .61308 L p F P
0 g
s
.748 .56 .641 r
.69125 .5627 m .69751 .5619 L .6963 .55998 L p F P
0 g
s
.748 .56 .641 r
.6963 .55998 m .68985 .5605 L .69125 .5627 L p F P
0 g
s
.747 .566 .649 r
.70474 .57459 m .70978 .57121 L .70877 .56932 L p F P
0 g
s
.747 .566 .649 r
.70877 .56932 m .70354 .57236 L .70474 .57459 L p F P
0 g
s
.68 .644 .807 r
.64649 .53625 m .65537 .53955 L .65359 .53964 L p F P
0 g
s
.68 .644 .807 r
.65359 .53964 m .64451 .53634 L .64649 .53625 L p F P
0 g
s
.724 .588 .703 r
.63601 .59107 m .6236 .59421 L .62535 .58912 L p F P
0 g
s
.724 .588 .703 r
.6236 .59421 m .63601 .59107 L .63445 .59574 L p F P
0 g
s
.724 .59 .706 r
.63238 .5702 m .62094 .57024 L .6229 .56551 L p F P
0 g
s
.724 .59 .705 r
.62094 .57024 m .63238 .5702 L .63062 .57468 L p F P
0 g
s
.724 .587 .702 r
.64024 .61308 m .62666 .62026 L .62822 .61522 L p F P
0 g
s
.724 .587 .702 r
.62666 .62026 m .64024 .61308 L .63888 .61759 L p F P
0 g
s
.75 .551 .626 r
.67857 .55355 m .68564 .55442 L .68424 .55262 L p F P
0 g
s
.75 .551 .626 r
.68424 .55262 m .67697 .55152 L .67857 .55355 L p F P
0 g
s
.759 .516 .566 r
.66431 .5441 m .67218 .54637 L .67059 .54504 L p F P
0 g
s
.759 .516 .566 r
.67059 .54504 m .66251 .54262 L .66431 .5441 L p F P
0 g
s
.609 .676 .889 r
.64847 .53656 m .65715 .53984 L .65537 .53955 L p F P
0 g
s
.609 .676 .889 r
.65537 .53955 m .64649 .53625 L .64847 .53656 L p F P
0 g
s
.748 .566 .649 r
.70595 .57685 m .71079 .57313 L .70978 .57121 L p F P
0 g
s
.748 .566 .649 r
.70978 .57121 m .70474 .57459 L .70595 .57685 L p F P
0 g
s
.748 .561 .642 r
.69266 .56498 m .69871 .56388 L .69751 .5619 L p F P
0 g
s
.748 .561 .642 r
.69751 .5619 m .69125 .5627 L .69266 .56498 L p F P
0 g
s
.724 .588 .703 r
.63445 .59574 m .62184 .59941 L .6236 .59421 L p F P
0 g
s
.724 .588 .703 r
.62184 .59941 m .63445 .59574 L .6329 .60049 L p F P
0 g
s
.724 .59 .705 r
.63062 .57468 m .61898 .57518 L .62094 .57024 L p F P
0 g
s
.724 .589 .705 r
.61898 .57518 m .63062 .57468 L .62887 .57934 L p F P
0 g
s
.72 .599 .72 r
.62674 .53776 m .63662 .54115 L .63466 .54348 L p F P
0 g
s
.72 .599 .72 r
.63466 .54348 m .62458 .54033 L .62674 .53776 L p F P
0 g
s
.721 .596 .716 r
.62458 .54033 m .63466 .54348 L .63269 .54624 L p F P
0 g
s
.721 .596 .716 r
.63269 .54624 m .62242 .54337 L .62458 .54033 L p F P
0 g
s
.722 .595 .713 r
.62242 .54337 m .63269 .54624 L .63073 .54941 L p F P
0 g
s
.718 .601 .726 r
.62891 .53569 m .63859 .53926 L .63662 .54115 L p F P
0 g
s
.718 .601 .726 r
.63662 .54115 m .62674 .53776 L .62891 .53569 L p F P
0 g
s
.722 .595 .713 r
.63073 .54941 m .62026 .54685 L .62242 .54337 L p F P
0 g
s
.722 .593 .711 r
.62026 .54685 m .63073 .54941 L .62877 .55295 L p F P
0 g
s
.724 .587 .702 r
.63888 .61759 m .6251 .62535 L .62666 .62026 L p F P
0 g
s
.724 .587 .702 r
.6251 .62535 m .63888 .61759 L .63752 .62213 L p F P
0 g
s
.021 .525 .87 r
.65045 .53725 m .65894 .54046 L .65715 .53984 L p F P
0 g
s
.383 .65 .963 r
.64196 .53346 m .65045 .53725 L .64847 .53656 L p F P
0 g
s
.671 .134 0 r
.64415 .53459 m .6473 .53599 L p .65045 .53725 L F P
0 g
s
.021 .525 .87 r
.65326 .53837 m .64847 .53656 L .65045 .53725 L p F P
0 g
s
.671 .134 0 r
.6473 .53599 m .65244 .53828 L .65045 .53725 L p F P
0 g
s
.021 .525 .87 r
.65715 .53984 m .65326 .53837 L p .65045 .53725 L F P
0 g
s
.714 .605 .733 r
.63108 .53412 m .64056 .53784 L .63859 .53926 L p F P
0 g
s
.714 .605 .733 r
.63859 .53926 m .62891 .53569 L .63108 .53412 L p F P
0 g
s
.722 .593 .711 r
.62877 .55295 m .6181 .55074 L .62026 .54685 L p F P
0 g
s
.723 .592 .709 r
.6181 .55074 m .62877 .55295 L .62681 .55683 L p F P
0 g
s
.724 .589 .705 r
.62887 .57934 m .61703 .58033 L .61898 .57518 L p F P
0 g
s
.724 .589 .704 r
.61703 .58033 m .62887 .57934 L .62711 .58416 L p F P
0 g
s
.757 .531 .589 r
.6661 .54581 m .67378 .54791 L .67218 .54637 L p F P
0 g
s
.757 .531 .589 r
.67218 .54637 m .66431 .5441 L .6661 .54581 L p F P
0 g
s
.751 .554 .63 r
.68017 .55571 m .68704 .55635 L .68564 .55442 L p F P
0 g
s
.751 .554 .63 r
.68564 .55442 m .67857 .55355 L .68017 .55571 L p F P
0 g
s
.724 .588 .703 r
.6329 .60049 m .62008 .60472 L .62184 .59941 L p F P
0 g
s
.724 .587 .702 r
.62008 .60472 m .6329 .60049 L .63134 .60533 L p F P
0 g
s
.748 .567 .649 r
.70716 .57915 m .7118 .57508 L .71079 .57313 L p F P
0 g
s
.748 .567 .649 r
.71079 .57313 m .70595 .57685 L .70716 .57915 L p F P
0 g
s
.709 .611 .745 r
.63325 .53305 m .64253 .53687 L .64056 .53784 L p F P
0 g
s
.709 .611 .745 r
.64056 .53784 m .63108 .53412 L .63325 .53305 L p F P
0 g
s
.723 .592 .709 r
.62681 .55683 m .61595 .555 L .6181 .55074 L p F P
0 g
s
.723 .591 .708 r
.61595 .555 m .62681 .55683 L .62485 .56103 L p F P
0 g
s
.749 .562 .643 r
.69406 .56732 m .69992 .56593 L .69871 .56388 L p F P
0 g
s
.749 .562 .643 r
.69871 .56388 m .69266 .56498 L .69406 .56732 L p F P
0 g
s
.724 .587 .702 r
.63752 .62213 m .62354 .63049 L .6251 .62535 L p F P
0 g
s
.724 .586 .701 r
.62354 .63049 m .63752 .62213 L .63616 .62672 L p F P
0 g
s
.724 .589 .704 r
.62711 .58416 m .61508 .58565 L .61703 .58033 L p F P
0 g
s
.723 .588 .704 r
.61508 .58565 m .62711 .58416 L .62535 .58912 L p F P
0 g
s
.748 .326 .246 r
.65244 .53828 m .66072 .5414 L .65894 .54046 L p F P
0 g
s
.748 .326 .246 r
.65894 .54046 m .65045 .53725 L .65244 .53828 L p F P
0 g
s
.723 .591 .708 r
.62485 .56103 m .61379 .55961 L .61595 .555 L p F P
0 g
s
.723 .59 .707 r
.61379 .55961 m .62485 .56103 L .6229 .56551 L p F P
0 g
s
.7 .619 .762 r
.63542 .53248 m .64451 .53634 L .64253 .53687 L p F P
0 g
s
.7 .619 .762 r
.64253 .53687 m .63325 .53305 L .63542 .53248 L p F P
0 g
s
.724 .587 .702 r
.63134 .60533 m .61833 .61011 L .62008 .60472 L p F P
0 g
s
.724 .587 .702 r
.61833 .61011 m .63134 .60533 L .62978 .61024 L p F P
0 g
s
.756 .54 .604 r
.6679 .54772 m .67538 .54963 L .67378 .54791 L p F P
0 g
s
.756 .54 .604 r
.67378 .54791 m .6661 .54581 L .6679 .54772 L p F P
0 g
s
.751 .557 .633 r
.68178 .55799 m .68844 .55838 L .68704 .55635 L p F P
0 g
s
.751 .557 .633 r
.68704 .55635 m .68017 .55571 L .68178 .55799 L p F P
0 g
s
.723 .59 .707 r
.6229 .56551 m .61164 .56451 L .61379 .55961 L p F P
0 g
s
.723 .589 .706 r
.61164 .56451 m .6229 .56551 L .62094 .57024 L p F P
0 g
s
.724 .586 .701 r
.63616 .62672 m .62198 .63567 L .62354 .63049 L p F P
0 g
s
.723 .586 .701 r
.62198 .63567 m .63616 .62672 L .6348 .63134 L p F P
0 g
s
.749 .564 .644 r
.69547 .56972 m .70112 .56803 L .69992 .56593 L p F P
0 g
s
.749 .564 .644 r
.69992 .56593 m .69406 .56732 L .69547 .56972 L p F P
0 g
s
.723 .588 .704 r
.62535 .58912 m .61312 .59112 L .61508 .58565 L p F P
0 g
s
.723 .588 .703 r
.61312 .59112 m .62535 .58912 L .6236 .59421 L p F P
0 g
s
.682 .631 .793 r
.6376 .53237 m .64649 .53625 L .64451 .53634 L p F P
0 g
s
.682 .631 .793 r
.64451 .53634 m .63542 .53248 L .6376 .53237 L p F P
0 g
s
.724 .587 .702 r
.62978 .61024 m .61657 .61558 L .61833 .61011 L p F P
0 g
s
.723 .587 .702 r
.61657 .61558 m .62978 .61024 L .62822 .61522 L p F P
0 g
s
.771 .467 .472 r
.65443 .53963 m .66251 .54262 L .66072 .5414 L p F P
0 g
s
.771 .467 .472 r
.66072 .5414 m .65244 .53828 L .65443 .53963 L p F P
0 g
s
.723 .589 .706 r
.62094 .57024 m .60949 .56969 L .61164 .56451 L p F P
0 g
s
.723 .589 .705 r
.60949 .56969 m .62094 .57024 L .61898 .57518 L p F P
0 g
s
.723 .586 .701 r
.6348 .63134 m .62042 .64089 L .62198 .63567 L p F P
0 g
s
.632 .653 .852 r
.63978 .53271 m .64847 .53656 L .64649 .53625 L p F P
0 g
s
.632 .653 .852 r
.64649 .53625 m .6376 .53237 L .63978 .53271 L p F P
0 g
s
.723 .588 .703 r
.6236 .59421 m .61117 .59673 L .61312 .59112 L p F P
0 g
s
.723 .587 .703 r
.61117 .59673 m .6236 .59421 L .62184 .59941 L p F P
0 g
s
.756 .546 .613 r
.66969 .54981 m .67697 .55152 L .67538 .54963 L p F P
0 g
s
.756 .546 .613 r
.67538 .54963 m .6679 .54772 L .66969 .54981 L p F P
0 g
s
.751 .558 .635 r
.68338 .56038 m .68985 .5605 L .68844 .55838 L p F P
0 g
s
.751 .558 .635 r
.68844 .55838 m .68178 .55799 L .68338 .56038 L p F P
0 g
s
.718 .596 .719 r
.61686 .5338 m .62674 .53776 L .62458 .54033 L p F P
0 g
s
.718 .596 .719 r
.62458 .54033 m .6145 .5366 L .61686 .5338 L p F P
0 g
s
.72 .595 .716 r
.6145 .5366 m .62458 .54033 L .62242 .54337 L p F P
0 g
s
.72 .595 .716 r
.62242 .54337 m .61214 .53992 L .6145 .5366 L p F P
0 g
s
.721 .593 .713 r
.61214 .53992 m .62242 .54337 L .62026 .54685 L p F P
0 g
s
.716 .599 .724 r
.61922 .53154 m .62891 .53569 L .62674 .53776 L p F P
0 g
s
.716 .599 .724 r
.62674 .53776 m .61686 .5338 L .61922 .53154 L p F P
0 g
s
.723 .587 .702 r
.62822 .61522 m .61482 .62112 L .61657 .61558 L p F P
0 g
s
.723 .586 .702 r
.61482 .62112 m .62822 .61522 L .62666 .62026 L p F P
0 g
s
.75 .564 .645 r
.69688 .57218 m .70233 .57017 L .70112 .56803 L p F P
0 g
s
.75 .564 .645 r
.70112 .56803 m .69547 .56972 L .69688 .57218 L p F P
0 g
s
.721 .593 .713 r
.62026 .54685 m .60978 .54371 L .61214 .53992 L p F P
0 g
s
.721 .592 .711 r
.60978 .54371 m .62026 .54685 L .6181 .55074 L p F P
0 g
s
.723 .589 .705 r
.61898 .57518 m .60733 .5751 L .60949 .56969 L p F P
0 g
s
.723 .588 .705 r
.60733 .5751 m .61898 .57518 L .61703 .58033 L p F P
0 g
s
.713 .602 .731 r
.62159 .52983 m .63108 .53412 L .62891 .53569 L p F P
0 g
s
.713 .602 .731 r
.62891 .53569 m .61922 .53154 L .62159 .52983 L p F P
0 g
s
.768 .508 .541 r
.65642 .54125 m .66431 .5441 L .66251 .54262 L p F P
0 g
s
.768 .508 .541 r
.66251 .54262 m .65443 .53963 L .65642 .54125 L p F P
0 g
s
.721 .592 .711 r
.6181 .55074 m .60743 .54795 L .60978 .54371 L p F P
0 g
s
.722 .591 .709 r
.60743 .54795 m .6181 .55074 L .61595 .555 L p F P
0 g
s
.723 .587 .703 r
.62184 .59941 m .60921 .60245 L .61117 .59673 L p F P
0 g
s
.723 .587 .703 r
.60921 .60245 m .62184 .59941 L .62008 .60472 L p F P
0 g
s
.383 .65 .963 r
.64847 .53656 m .63978 .53271 L .64196 .53346 L p F P
0 g
s
.708 .606 .741 r
.62396 .52866 m .63325 .53305 L .63108 .53412 L p F P
0 g
s
.708 .606 .741 r
.63108 .53412 m .62159 .52983 L .62396 .52866 L p F P
0 g
s
.722 .591 .709 r
.61595 .555 m .60508 .5526 L .60743 .54795 L p F P
0 g
s
.722 .59 .708 r
.60508 .5526 m .61595 .555 L .61379 .55961 L p F P
0 g
s
.723 .588 .705 r
.61703 .58033 m .60518 .58072 L .60733 .5751 L p F P
0 g
s
.723 .588 .704 r
.60518 .58072 m .61703 .58033 L .61508 .58565 L p F P
0 g
s
.723 .586 .702 r
.62666 .62026 m .61306 .62673 L .61482 .62112 L p F P
0 g
s
.723 .586 .702 r
.61306 .62673 m .62666 .62026 L .6251 .62535 L p F P
0 g
s
.755 .55 .619 r
.67149 .55206 m .67857 .55355 L .67697 .55152 L p F P
0 g
s
.755 .55 .619 r
.67697 .55152 m .66969 .54981 L .67149 .55206 L p F P
0 g
s
.752 .56 .637 r
.68498 .56285 m .69125 .5627 L .68985 .5605 L p F P
0 g
s
.752 .56 .637 r
.68985 .5605 m .68338 .56038 L .68498 .56285 L p F P
0 g
s
.75 .565 .645 r
.69829 .57469 m .70354 .57236 L .70233 .57017 L p F P
0 g
s
.75 .565 .645 r
.70233 .57017 m .69688 .57218 L .69829 .57469 L p F P
0 g
s
.722 .59 .708 r
.61379 .55961 m .60272 .5576 L .60508 .5526 L p F P
0 g
s
.722 .589 .707 r
.60272 .5576 m .61379 .55961 L .61164 .56451 L p F P
0 g
s
.699 .613 .757 r
.62633 .52804 m .63542 .53248 L .63325 .53305 L p F P
0 g
s
.699 .613 .757 r
.63325 .53305 m .62396 .52866 L .62633 .52804 L p F P
0 g
s
.723 .587 .703 r
.62008 .60472 m .60726 .60829 L .60921 .60245 L p F P
0 g
s
.723 .587 .702 r
.60726 .60829 m .62008 .60472 L .61833 .61011 L p F P
0 g
s
.765 .527 .573 r
.65841 .54312 m .6661 .54581 L .66431 .5441 L p F P
0 g
s
.765 .527 .573 r
.66431 .5441 m .65642 .54125 L .65841 .54312 L p F P
0 g
s
.723 .588 .704 r
.61508 .58565 m .60303 .58653 L .60518 .58072 L p F P
0 g
s
.723 .587 .704 r
.60303 .58653 m .61508 .58565 L .61312 .59112 L p F P
0 g
s
.671 .134 0 r
.65045 .53725 m .64196 .53346 L .64415 .53459 L p F P
0 g
s
.723 .586 .702 r
.6251 .62535 m .6113 .63239 L .61306 .62673 L p F P
0 g
s
.723 .586 .701 r
.6113 .63239 m .6251 .62535 L .62354 .63049 L p F P
0 g
s
.722 .589 .707 r
.61164 .56451 m .60037 .56293 L .60272 .5576 L p F P
0 g
s
.722 .589 .706 r
.60037 .56293 m .61164 .56451 L .60949 .56969 L p F P
0 g
s
.683 .622 .781 r
.6287 .52792 m .6376 .53237 L .63542 .53248 L p F P
0 g
s
.683 .622 .781 r
.63542 .53248 m .62633 .52804 L .6287 .52792 L p F P
0 g
s
.755 .554 .624 r
.67329 .55446 m .68017 .55571 L .67857 .55355 L p F P
0 g
s
.755 .554 .624 r
.67857 .55355 m .67149 .55206 L .67329 .55446 L p F P
0 g
s
.752 .562 .638 r
.68659 .56541 m .69266 .56498 L .69125 .5627 L p F P
0 g
s
.752 .562 .638 r
.69125 .5627 m .68498 .56285 L .68659 .56541 L p F P
0 g
s
.751 .566 .646 r
.6997 .57724 m .70474 .57459 L .70354 .57236 L p F P
0 g
s
.751 .566 .646 r
.70354 .57236 m .69829 .57469 L .6997 .57724 L p F P
0 g
s
.723 .587 .702 r
.61833 .61011 m .60531 .61422 L .60726 .60829 L p F P
0 g
s
.723 .586 .702 r
.60531 .61422 m .61833 .61011 L .61657 .61558 L p F P
0 g
s
.723 .587 .704 r
.61312 .59112 m .60088 .5925 L .60303 .58653 L p F P
0 g
s
.723 .587 .703 r
.60088 .5925 m .61312 .59112 L .61117 .59673 L p F P
0 g
s
.722 .589 .706 r
.60949 .56969 m .59802 .56855 L .60037 .56293 L p F P
0 g
s
.722 .588 .705 r
.59802 .56855 m .60949 .56969 L .60733 .5751 L p F P
0 g
s
.717 .595 .718 r
.60697 .52927 m .61686 .5338 L .6145 .5366 L p F P
0 g
s
.717 .595 .718 r
.6145 .5366 m .60441 .53231 L .60697 .52927 L p F P
0 g
s
.718 .593 .715 r
.60441 .53231 m .6145 .5366 L .61214 .53992 L p F P
0 g
s
.718 .593 .715 r
.61214 .53992 m .60185 .5359 L .60441 .53231 L p F P
0 g
s
.719 .592 .712 r
.60185 .5359 m .61214 .53992 L .60978 .54371 L p F P
0 g
s
.723 .586 .701 r
.62354 .63049 m .60955 .63811 L .6113 .63239 L p F P
0 g
s
.723 .586 .701 r
.60955 .63811 m .62354 .63049 L .62198 .63567 L p F P
0 g
s
.715 .597 .723 r
.60953 .52682 m .61922 .53154 L .61686 .5338 L p F P
0 g
s
.715 .597 .723 r
.61686 .5338 m .60697 .52927 L .60953 .52682 L p F P
0 g
s
.719 .592 .712 r
.60978 .54371 m .5993 .54001 L .60185 .5359 L p F P
0 g
s
.72 .591 .71 r
.5993 .54001 m .60978 .54371 L .60743 .54795 L p F P
0 g
s
.763 .538 .592 r
.66041 .54522 m .6679 .54772 L .6661 .54581 L p F P
0 g
s
.763 .538 .592 r
.6661 .54581 m .65841 .54312 L .66041 .54522 L p F P
0 g
s
.782 .433 .396 r
.64633 .53605 m .65443 .53963 L .65244 .53828 L p F P
0 g
s
.782 .433 .396 r
.65244 .53828 m .64415 .53459 L .64633 .53605 L p F P
0 g
s
.645 .636 .827 r
.63108 .52829 m .63978 .53271 L .6376 .53237 L p F P
0 g
s
.645 .636 .827 r
.6376 .53237 m .6287 .52792 L .63108 .52829 L p F P
0 g
s
.711 .599 .729 r
.61209 .52496 m .62159 .52983 L .61922 .53154 L p F P
0 g
s
.711 .599 .729 r
.61922 .53154 m .60953 .52682 L .61209 .52496 L p F P
0 g
s
.72 .591 .71 r
.60743 .54795 m .59674 .5446 L .5993 .54001 L p F P
0 g
s
.721 .59 .709 r
.59674 .5446 m .60743 .54795 L .60508 .5526 L p F P
0 g
s
.722 .588 .705 r
.60733 .5751 m .59567 .57442 L .59802 .56855 L p F P
0 g
s
.722 .587 .704 r
.59567 .57442 m .60733 .5751 L .60518 .58072 L p F P
0 g
s
.723 .586 .702 r
.61657 .61558 m .60335 .62024 L .60531 .61422 L p F P
0 g
s
.723 .586 .702 r
.60335 .62024 m .61657 .61558 L .61482 .62112 L p F P
0 g
s
.723 .587 .703 r
.61117 .59673 m .59872 .59861 L .60088 .5925 L p F P
0 g
s
.722 .587 .703 r
.59872 .59861 m .61117 .59673 L .60921 .60245 L p F P
0 g
s
.706 .603 .738 r
.61465 .5237 m .62396 .52866 L .62159 .52983 L p F P
0 g
s
.706 .603 .738 r
.62159 .52983 m .61209 .52496 L .61465 .5237 L p F P
0 g
s
.721 .59 .709 r
.60508 .5526 m .59419 .54962 L .59674 .5446 L p F P
0 g
s
.721 .589 .707 r
.59419 .54962 m .60508 .5526 L .60272 .5576 L p F P
0 g
s
.751 .567 .646 r
.70111 .57983 m .70595 .57685 L .70474 .57459 L p F P
0 g
s
.751 .567 .646 r
.70474 .57459 m .6997 .57724 L .70111 .57983 L p F P
0 g
s
.752 .563 .639 r
.6882 .56804 m .69406 .56732 L .69266 .56498 L p F P
0 g
s
.752 .563 .639 r
.69266 .56498 m .68659 .56541 L .6882 .56804 L p F P
0 g
s
.723 .586 .701 r
.62198 .63567 m .60779 .64388 L .60955 .63811 L p F P
0 g
s
.723 .585 .701 r
.60779 .64388 m .62198 .63567 L .62042 .64089 L p F P
0 g
s
.755 .556 .627 r
.6751 .55698 m .68178 .55799 L .68017 .55571 L p F P
0 g
s
.755 .556 .627 r
.68017 .55571 m .67329 .55446 L .6751 .55698 L p F P
0 g
s
.515 .648 .917 r
.63346 .5291 m .64196 .53346 L .63978 .53271 L p F P
0 g
s
.515 .648 .917 r
.63978 .53271 m .63108 .52829 L .63346 .5291 L p F P
0 g
s
.721 .589 .707 r
.60272 .5576 m .59164 .55503 L .59419 .54962 L p F P
0 g
s
.721 .588 .706 r
.59164 .55503 m .60272 .5576 L .60037 .56293 L p F P
0 g
s
.722 .587 .704 r
.60518 .58072 m .59332 .58051 L .59567 .57442 L p F P
0 g
s
.722 .587 .704 r
.59332 .58051 m .60518 .58072 L .60303 .58653 L p F P
0 g
s
.779 .496 .506 r
.64852 .53781 m .65642 .54125 L .65443 .53963 L p F P
0 g
s
.779 .496 .506 r
.65443 .53963 m .64633 .53605 L .64852 .53781 L p F P
0 g
s
.698 .607 .752 r
.61722 .52302 m .62633 .52804 L .62396 .52866 L p F P
0 g
s
.698 .607 .752 r
.62396 .52866 m .61465 .5237 L .61722 .52302 L p F P
0 g
s
.762 .545 .603 r
.6624 .54751 m .66969 .54981 L .6679 .54772 L p F P
0 g
s
.762 .545 .603 r
.6679 .54772 m .66041 .54522 L .6624 .54751 L p F P
0 g
s
.723 .586 .702 r
.61482 .62112 m .6014 .62634 L .60335 .62024 L p F P
0 g
s
.723 .586 .702 r
.6014 .62634 m .61482 .62112 L .61306 .62673 L p F P
0 g
s
.722 .587 .703 r
.60921 .60245 m .59657 .60486 L .59872 .59861 L p F P
0 g
s
.722 .586 .703 r
.59657 .60486 m .60921 .60245 L .60726 .60829 L p F P
0 g
s
.723 .585 .701 r
.62042 .64089 m .60603 .64969 L .60779 .64388 L p F P
0 g
s
.721 .588 .706 r
.60037 .56293 m .58909 .56078 L .59164 .55503 L p F P
0 g
s
.721 .588 .705 r
.58909 .56078 m .60037 .56293 L .59802 .56855 L p F P
0 g
s
.752 .567 .646 r
.70252 .58245 m .70716 .57915 L .70595 .57685 L p F P
0 g
s
.752 .567 .646 r
.70595 .57685 m .70111 .57983 L .70252 .58245 L p F P
0 g
s
.753 .564 .64 r
.6898 .57073 m .69547 .56972 L .69406 .56732 L p F P
0 g
s
.753 .564 .64 r
.69406 .56732 m .6882 .56804 L .6898 .57073 L p F P
0 g
s
.722 .587 .704 r
.60303 .58653 m .59097 .5868 L .59332 .58051 L p F P
0 g
s
.722 .587 .703 r
.59097 .5868 m .60303 .58653 L .60088 .5925 L p F P
0 g
s
.683 .614 .772 r
.61979 .52289 m .6287 .52792 L .62633 .52804 L p F P
0 g
s
.683 .614 .772 r
.62633 .52804 m .61722 .52302 L .61979 .52289 L p F P
0 g
s
.756 .558 .63 r
.6769 .55961 m .68338 .56038 L .68178 .55799 L p F P
0 g
s
.756 .558 .63 r
.68178 .55799 m .6751 .55698 L .6769 .55961 L p F P
0 g
s
0 .269 .652 r
.64196 .53346 m .63346 .5291 L .63584 .53032 L p F P
0 g
s
0 .269 .652 r
.63584 .53032 m .64415 .53459 L .64196 .53346 L p F P
0 g
s
.716 .593 .717 r
.59706 .52416 m .60697 .52927 L .60441 .53231 L p F P
0 g
s
.716 .593 .717 r
.60441 .53231 m .59431 .52743 L .59706 .52416 L p F P
0 g
s
.717 .591 .714 r
.59431 .52743 m .60441 .53231 L .60185 .5359 L p F P
0 g
s
.717 .591 .714 r
.60185 .5359 m .59155 .53131 L .59431 .52743 L p F P
0 g
s
.719 .59 .712 r
.59155 .53131 m .60185 .5359 L .5993 .54001 L p F P
0 g
s
.723 .586 .702 r
.61306 .62673 m .59944 .6325 L .6014 .62634 L p F P
0 g
s
.722 .586 .702 r
.59944 .6325 m .61306 .62673 L .6113 .63239 L p F P
0 g
s
.722 .586 .703 r
.60726 .60829 m .59442 .61122 L .59657 .60486 L p F P
0 g
s
.722 .586 .702 r
.59442 .61122 m .60726 .60829 L .60531 .61422 L p F P
0 g
s
.713 .595 .722 r
.59982 .52152 m .60953 .52682 L .60697 .52927 L p F P
0 g
s
.713 .595 .722 r
.60697 .52927 m .59706 .52416 L .59982 .52152 L p F P
0 g
s
.719 .59 .712 r
.5993 .54001 m .5888 .53573 L .59155 .53131 L p F P
0 g
s
.719 .589 .71 r
.5888 .53573 m .5993 .54001 L .59674 .5446 L p F P
0 g
s
.53 .505 .773 r
.04209 .39378 m .02789 .37201 L .03711 .38322 L p F P
0 g
s
.775 .521 .552 r
.65071 .53985 m .65841 .54312 L .65642 .54125 L p F P
0 g
s
.775 .521 .552 r
.65642 .54125 m .64852 .53781 L .65071 .53985 L p F P
0 g
s
.721 .588 .705 r
.59802 .56855 m .58655 .56683 L .58909 .56078 L p F P
0 g
s
.721 .587 .705 r
.58655 .56683 m .59802 .56855 L .59567 .57442 L p F P
0 g
s
.761 .55 .611 r
.6644 .54997 m .67149 .55206 L .66969 .54981 L p F P
0 g
s
.761 .55 .611 r
.66969 .54981 m .6624 .54751 L .6644 .54997 L p F P
0 g
s
.71 .597 .727 r
.60258 .51951 m .61209 .52496 L .60953 .52682 L p F P
0 g
s
.71 .597 .727 r
.60953 .52682 m .59982 .52152 L .60258 .51951 L p F P
0 g
s
.719 .589 .71 r
.59674 .5446 m .58605 .54067 L .5888 .53573 L p F P
0 g
s
.72 .589 .708 r
.58605 .54067 m .59674 .5446 L .59419 .54962 L p F P
0 g
s
.722 .587 .703 r
.60088 .5925 m .58862 .59326 L .59097 .5868 L p F P
0 g
s
.722 .586 .703 r
.58862 .59326 m .60088 .5925 L .59872 .59861 L p F P
0 g
s
.653 .623 .808 r
.62237 .52329 m .63108 .52829 L .6287 .52792 L p F P
0 g
s
.653 .623 .808 r
.6287 .52792 m .61979 .52289 L .62237 .52329 L p F P
0 g
s
.705 .599 .736 r
.60534 .51816 m .61465 .5237 L .61209 .52496 L p F P
0 g
s
.705 .599 .736 r
.61209 .52496 m .60258 .51951 L .60534 .51816 L p F P
0 g
s
.72 .589 .708 r
.59419 .54962 m .5833 .54607 L .58605 .54067 L p F P
0 g
s
.72 .588 .707 r
.5833 .54607 m .59419 .54962 L .59164 .55503 L p F P
0 g
s
.721 .587 .705 r
.59567 .57442 m .584 .57316 L .58655 .56683 L p F P
0 g
s
.721 .587 .704 r
.584 .57316 m .59567 .57442 L .59332 .58051 L p F P
0 g
s
.722 .586 .702 r
.6113 .63239 m .59749 .63873 L .59944 .6325 L p F P
0 g
s
.722 .585 .701 r
.59749 .63873 m .6113 .63239 L .60955 .63811 L p F P
0 g
s
.753 .565 .641 r
.69141 .57349 m .69688 .57218 L .69547 .56972 L p F P
0 g
s
.753 .565 .641 r
.69547 .56972 m .6898 .57073 L .69141 .57349 L p F P
0 g
s
.722 .586 .702 r
.60531 .61422 m .59227 .61768 L .59442 .61122 L p F P
0 g
s
.722 .586 .702 r
.59227 .61768 m .60531 .61422 L .60335 .62024 L p F P
0 g
s
.783 .363 .25 r
.63823 .53189 m .64633 .53605 L .64415 .53459 L p F P
0 g
s
.783 .363 .25 r
.64415 .53459 m .63584 .53032 L .63823 .53189 L p F P
0 g
s
.756 .56 .632 r
.6787 .56235 m .68498 .56285 L .68338 .56038 L p F P
0 g
s
.756 .56 .632 r
.68338 .56038 m .6769 .55961 L .6787 .56235 L p F P
0 g
s
.72 .588 .707 r
.59164 .55503 m .58056 .55188 L .5833 .54607 L p F P
0 g
s
.72 .587 .706 r
.58056 .55188 m .59164 .55503 L .58909 .56078 L p F P
0 g
s
.697 .603 .747 r
.60811 .51743 m .61722 .52302 L .61465 .5237 L p F P
0 g
s
.697 .603 .747 r
.61465 .5237 m .60534 .51816 L .60811 .51743 L p F P
0 g
s
.722 .586 .703 r
.59872 .59861 m .58627 .59988 L .58862 .59326 L p F P
0 g
s
.722 .586 .703 r
.58627 .59988 m .59872 .59861 L .59657 .60486 L p F P
0 g
s
.772 .535 .576 r
.65291 .54212 m .66041 .54522 L .65841 .54312 L p F P
0 g
s
.772 .535 .576 r
.65841 .54312 m .65071 .53985 L .65291 .54212 L p F P
0 g
s
.761 .553 .616 r
.6664 .55259 m .67329 .55446 L .67149 .55206 L p F P
0 g
s
.761 .553 .616 r
.67149 .55206 m .6644 .54997 L .6664 .55259 L p F P
0 g
s
.572 .633 .874 r
.62495 .52416 m .63346 .5291 L .63108 .52829 L p F P
0 g
s
.572 .633 .874 r
.63108 .52829 m .62237 .52329 L .62495 .52416 L p F P
0 g
s
.721 .587 .704 r
.59332 .58051 m .58145 .57971 L .584 .57316 L p F P
0 g
s
.721 .586 .704 r
.58145 .57971 m .59332 .58051 L .59097 .5868 L p F P
0 g
s
.722 .585 .701 r
.60955 .63811 m .59553 .64501 L .59749 .63873 L p F P
0 g
s
.722 .585 .701 r
.59553 .64501 m .60955 .63811 L .60779 .64388 L p F P
0 g
s
.722 .586 .702 r
.60335 .62024 m .59012 .62423 L .59227 .61768 L p F P
0 g
s
.722 .585 .702 r
.59012 .62423 m .60335 .62024 L .6014 .62634 L p F P
0 g
s
.72 .587 .706 r
.58909 .56078 m .57781 .55805 L .58056 .55188 L p F P
0 g
s
.721 .587 .705 r
.57781 .55805 m .58909 .56078 L .58655 .56683 L p F P
0 g
s
.715 .591 .716 r
.58715 .51848 m .59706 .52416 L .59431 .52743 L p F P
0 g
s
.715 .591 .716 r
.59431 .52743 m .5842 .52199 L .58715 .51848 L p F P
0 g
s
.716 .59 .713 r
.5842 .52199 m .59431 .52743 L .59155 .53131 L p F P
0 g
s
.716 .59 .713 r
.59155 .53131 m .58125 .52614 L .5842 .52199 L p F P
0 g
s
.718 .589 .711 r
.58125 .52614 m .59155 .53131 L .5888 .53573 L p F P
0 g
s
.754 .566 .641 r
.69302 .5763 m .69829 .57469 L .69688 .57218 L p F P
0 g
s
.754 .566 .641 r
.69688 .57218 m .69141 .57349 L .69302 .5763 L p F P
0 g
s
.712 .593 .72 r
.59011 .51564 m .59982 .52152 L .59706 .52416 L p F P
0 g
s
.712 .593 .72 r
.59706 .52416 m .58715 .51848 L .59011 .51564 L p F P
0 g
s
.683 .608 .765 r
.61088 .5173 m .61979 .52289 L .61722 .52302 L p F P
0 g
s
.683 .608 .765 r
.61722 .52302 m .60811 .51743 L .61088 .5173 L p F P
0 g
s
.793 .476 .452 r
.64061 .5338 m .64852 .53781 L .64633 .53605 L p F P
0 g
s
.793 .476 .452 r
.64633 .53605 m .63823 .53189 L .64061 .5338 L p F P
0 g
s
.718 .589 .711 r
.5888 .53573 m .5783 .53089 L .58125 .52614 L p F P
0 g
s
.718 .588 .709 r
.5783 .53089 m .5888 .53573 L .58605 .54067 L p F P
0 g
s
.722 .586 .703 r
.59657 .60486 m .58392 .60663 L .58627 .59988 L p F P
0 g
s
.722 .586 .702 r
.58392 .60663 m .59657 .60486 L .59442 .61122 L p F P
0 g
s
.756 .562 .633 r
.68051 .56517 m .68659 .56541 L .68498 .56285 L p F P
0 g
s
.756 .562 .633 r
.68498 .56285 m .6787 .56235 L .68051 .56517 L p F P
0 g
s
.709 .594 .726 r
.59307 .51349 m .60258 .51951 L .59982 .52152 L p F P
0 g
s
.709 .594 .726 r
.59982 .52152 m .59011 .51564 L .59307 .51349 L p F P
0 g
s
.721 .586 .704 r
.59097 .5868 m .5789 .58647 L .58145 .57971 L p F P
0 g
s
.721 .586 .703 r
.5789 .58647 m .59097 .5868 L .58862 .59326 L p F P
0 g
s
.718 .588 .709 r
.58605 .54067 m .57535 .53618 L .5783 .53089 L p F P
0 g
s
.719 .588 .708 r
.57535 .53618 m .58605 .54067 L .5833 .54607 L p F P
0 g
s
.721 .587 .705 r
.58655 .56683 m .57506 .56454 L .57781 .55805 L p F P
0 g
s
.721 .586 .705 r
.57506 .56454 m .58655 .56683 L .584 .57316 L p F P
0 g
s
.192 .544 .929 r
.62753 .52547 m .63584 .53032 L .63346 .5291 L p F P
0 g
s
.192 .544 .929 r
.63346 .5291 m .62495 .52416 L .62753 .52547 L p F P
0 g
s
.722 .585 .701 r
.60779 .64388 m .59358 .65135 L .59553 .64501 L p F P
0 g
s
.722 .585 .701 r
.59358 .65135 m .60779 .64388 L .60603 .64969 L p F P
0 g
s
.769 .543 .591 r
.6551 .5446 m .6624 .54751 L .66041 .54522 L p F P
0 g
s
.769 .543 .591 r
.66041 .54522 m .65291 .54212 L .6551 .5446 L p F P
0 g
s
.722 .585 .702 r
.6014 .62634 m .58796 .63086 L .59012 .62423 L p F P
0 g
s
.722 .585 .702 r
.58796 .63086 m .6014 .62634 L .59944 .6325 L p F P
0 g
s
.761 .556 .62 r
.6684 .55534 m .6751 .55698 L .67329 .55446 L p F P
0 g
s
.761 .556 .62 r
.67329 .55446 m .6664 .55259 L .6684 .55534 L p F P
0 g
s
.704 .596 .733 r
.59603 .51204 m .60534 .51816 L .60258 .51951 L p F P
0 g
s
.704 .596 .733 r
.60258 .51951 m .59307 .51349 L .59603 .51204 L p F P
0 g
s
.719 .588 .708 r
.5833 .54607 m .57241 .54196 L .57535 .53618 L p F P
0 g
s
.719 .587 .707 r
.57241 .54196 m .5833 .54607 L .58056 .55188 L p F P
0 g
s
.658 .614 .793 r
.61365 .51772 m .62237 .52329 L .61979 .52289 L p F P
0 g
s
.658 .614 .793 r
.61979 .52289 m .61088 .5173 L .61365 .51772 L p F P
0 g
s
.722 .586 .702 r
.59442 .61122 m .58157 .6135 L .58392 .60663 L p F P
0 g
s
.722 .585 .702 r
.58157 .6135 m .59442 .61122 L .59227 .61768 L p F P
0 g
s
.754 .566 .642 r
.69463 .57915 m .6997 .57724 L .69829 .57469 L p F P
0 g
s
.754 .566 .642 r
.69829 .57469 m .69302 .5763 L .69463 .57915 L p F P
0 g
s
.721 .586 .703 r
.58862 .59326 m .57635 .59341 L .5789 .58647 L p F P
0 g
s
.721 .586 .703 r
.57635 .59341 m .58862 .59326 L .58627 .59988 L p F P
0 g
s
.721 .586 .705 r
.584 .57316 m .57232 .5713 L .57506 .56454 L p F P
0 g
s
.721 .586 .704 r
.57232 .5713 m .584 .57316 L .58145 .57971 L p F P
0 g
s
.787 .512 .521 r
.643 .53598 m .65071 .53985 L .64852 .53781 L p F P
0 g
s
.787 .512 .521 r
.64852 .53781 m .64061 .5338 L .643 .53598 L p F P
0 g
s
.719 .587 .707 r
.58056 .55188 m .56946 .54816 L .57241 .54196 L p F P
0 g
s
.72 .587 .706 r
.56946 .54816 m .58056 .55188 L .57781 .55805 L p F P
0 g
s
.757 .563 .635 r
.68232 .56807 m .6882 .56804 L .68659 .56541 L p F P
0 g
s
.757 .563 .635 r
.68659 .56541 m .68051 .56517 L .68232 .56807 L p F P
0 g
s
.696 .599 .744 r
.59899 .51126 m .60811 .51743 L .60534 .51816 L p F P
0 g
s
.696 .599 .744 r
.60534 .51816 m .59603 .51204 L .59899 .51126 L p F P
0 g
s
.722 .585 .701 r
.60603 .64969 m .59162 .65773 L .59358 .65135 L p F P
0 g
s
.722 .585 .702 r
.59944 .6325 m .58581 .63757 L .58796 .63086 L p F P
0 g
s
.722 .585 .702 r
.58581 .63757 m .59944 .6325 L .59749 .63873 L p F P
0 g
s
.718 .191 0 r
.63011 .52716 m .63823 .53189 L .63584 .53032 L p F P
0 g
s
.718 .191 0 r
.63584 .53032 m .62753 .52547 L .63011 .52716 L p F P
0 g
s
.714 .59 .715 r
.57724 .51222 m .58715 .51848 L .5842 .52199 L p F P
0 g
s
.714 .59 .715 r
.5842 .52199 m .57409 .51597 L .57724 .51222 L p F P
0 g
s
.715 .589 .713 r
.57409 .51597 m .5842 .52199 L .58125 .52614 L p F P
0 g
s
.715 .589 .713 r
.58125 .52614 m .57094 .52041 L .57409 .51597 L p F P
0 g
s
.717 .588 .71 r
.57094 .52041 m .58125 .52614 L .5783 .53089 L p F P
0 g
s
.768 .548 .6 r
.6573 .54726 m .6644 .54997 L .6624 .54751 L p F P
0 g
s
.768 .548 .6 r
.6624 .54751 m .6551 .5446 L .6573 .54726 L p F P
0 g
s
.711 .591 .719 r
.58039 .50919 m .59011 .51564 L .58715 .51848 L p F P
0 g
s
.711 .591 .719 r
.58715 .51848 m .57724 .51222 L .58039 .50919 L p F P
0 g
s
.601 .62 .842 r
.61643 .51866 m .62495 .52416 L .62237 .52329 L p F P
0 g
s
.601 .62 .842 r
.62237 .52329 m .61365 .51772 L .61643 .51866 L p F P
0 g
s
.72 .587 .706 r
.57781 .55805 m .56652 .55475 L .56946 .54816 L p F P
0 g
s
.72 .586 .705 r
.56652 .55475 m .57781 .55805 L .57506 .56454 L p F P
0 g
s
.722 .585 .702 r
.59227 .61768 m .57922 .62047 L .58157 .6135 L p F P
0 g
s
.721 .585 .702 r
.57922 .62047 m .59227 .61768 L .59012 .62423 L p F P
0 g
s
.717 .588 .71 r
.5783 .53089 m .56779 .52548 L .57094 .52041 L p F P
0 g
s
.718 .587 .709 r
.56779 .52548 m .5783 .53089 L .57535 .53618 L p F P
0 g
s
.761 .558 .623 r
.67041 .55821 m .6769 .55961 L .6751 .55698 L p F P
0 g
s
.761 .558 .623 r
.6751 .55698 m .6684 .55534 L .67041 .55821 L p F P
0 g
s
.721 .586 .704 r
.58145 .57971 m .56957 .57832 L .57232 .5713 L p F P
0 g
s
.721 .586 .704 r
.56957 .57832 m .58145 .57971 L .5789 .58647 L p F P
0 g
s
.53 .505 .773 r
.03711 .38322 m .05145 .38596 L .04209 .39378 L p F P
0 g
s
.694 .564 .703 r
.05632 .41482 m .04209 .39378 L .05145 .38596 L p F P
0 g
s
.721 .586 .703 r
.58627 .59988 m .5738 .60052 L .57635 .59341 L p F P
0 g
s
.721 .585 .703 r
.5738 .60052 m .58627 .59988 L .58392 .60663 L p F P
0 g
s
.708 .592 .724 r
.58354 .5069 m .59307 .51349 L .59011 .51564 L p F P
0 g
s
.708 .592 .724 r
.59011 .51564 m .58039 .50919 L .58354 .5069 L p F P
0 g
s
.683 .602 .759 r
.60196 .51112 m .61088 .5173 L .60811 .51743 L p F P
0 g
s
.683 .602 .759 r
.60811 .51743 m .59899 .51126 L .60196 .51112 L p F P
0 g
s
.755 .567 .642 r
.69624 .58205 m .70111 .57983 L .6997 .57724 L p F P
0 g
s
.755 .567 .642 r
.6997 .57724 m .69463 .57915 L .69624 .58205 L p F P
0 g
s
.718 .587 .709 r
.57535 .53618 m .56465 .53112 L .56779 .52548 L p F P
0 g
s
.718 .587 .707 r
.56465 .53112 m .57535 .53618 L .57241 .54196 L p F P
0 g
s
.722 .585 .702 r
.59749 .63873 m .58366 .64435 L .58581 .63757 L p F P
0 g
s
.722 .585 .701 r
.58366 .64435 m .59749 .63873 L .59553 .64501 L p F P
0 g
s
.782 .53 .555 r
.6454 .53842 m .65291 .54212 L .65071 .53985 L p F P
0 g
s
.782 .53 .555 r
.65071 .53985 m .643 .53598 L .6454 .53842 L p F P
0 g
s
.757 .564 .635 r
.68412 .57105 m .6898 .57073 L .6882 .56804 L p F P
0 g
s
.757 .564 .635 r
.6882 .56804 m .68232 .56807 L .68412 .57105 L p F P
0 g
s
.72 .586 .705 r
.57506 .56454 m .56357 .56166 L .56652 .55475 L p F P
0 g
s
.72 .586 .704 r
.56357 .56166 m .57506 .56454 L .57232 .5713 L p F P
0 g
s
.703 .594 .731 r
.5867 .50535 m .59603 .51204 L .59307 .51349 L p F P
0 g
s
.703 .594 .731 r
.59307 .51349 m .58354 .5069 L .5867 .50535 L p F P
0 g
s
.718 .587 .707 r
.57241 .54196 m .5615 .53727 L .56465 .53112 L p F P
0 g
s
.719 .586 .706 r
.5615 .53727 m .57241 .54196 L .56946 .54816 L p F P
0 g
s
.721 .586 .704 r
.5789 .58647 m .56682 .58554 L .56957 .57832 L p F P
0 g
s
.721 .585 .703 r
.56682 .58554 m .5789 .58647 L .57635 .59341 L p F P
0 g
s
.721 .585 .702 r
.59012 .62423 m .57687 .62754 L .57922 .62047 L p F P
0 g
s
.721 .585 .702 r
.57687 .62754 m .59012 .62423 L .58796 .63086 L p F P
0 g
s
.807 .437 .357 r
.6327 .5292 m .64061 .5338 L .63823 .53189 L p F P
0 g
s
.807 .437 .357 r
.63823 .53189 m .63011 .52716 L .6327 .5292 L p F P
0 g
s
.721 .585 .703 r
.58392 .60663 m .57125 .60776 L .5738 .60052 L p F P
0 g
s
.721 .585 .702 r
.57125 .60776 m .58392 .60663 L .58157 .6135 L p F P
0 g
s
.416 .598 .92 r
.6192 .52005 m .62753 .52547 L .62495 .52416 L p F P
0 g
s
.416 .598 .92 r
.62495 .52416 m .61643 .51866 L .6192 .52005 L p F P
0 g
s
.662 .606 .782 r
.60493 .51158 m .61365 .51772 L .61088 .5173 L p F P
0 g
s
.662 .606 .782 r
.61088 .5173 m .60196 .51112 L .60493 .51158 L p F P
0 g
s
.767 .552 .607 r
.6595 .55009 m .6664 .55259 L .6644 .54997 L p F P
0 g
s
.767 .552 .607 r
.6644 .54997 m .6573 .54726 L .6595 .55009 L p F P
0 g
s
.719 .586 .706 r
.56946 .54816 m .55836 .54388 L .5615 .53727 L p F P
0 g
s
.719 .586 .705 r
.55836 .54388 m .56946 .54816 L .56652 .55475 L p F P
0 g
s
.761 .56 .626 r
.67241 .56119 m .6787 .56235 L .6769 .55961 L p F P
0 g
s
.761 .56 .626 r
.6769 .55961 m .67041 .55821 L .67241 .56119 L p F P
0 g
s
.722 .585 .701 r
.59553 .64501 m .5815 .65118 L .58366 .64435 L p F P
0 g
s
.721 .584 .701 r
.5815 .65118 m .59553 .64501 L .59358 .65135 L p F P
0 g
s
.695 .596 .74 r
.58986 .50452 m .59899 .51126 L .59603 .51204 L p F P
0 g
s
.695 .596 .74 r
.59603 .51204 m .5867 .50535 L .58986 .50452 L p F P
0 g
s
.648 .561 .743 r
.06557 .40202 m .05145 .38596 L .06061 .39081 L p F P
0 g
s
.694 .564 .703 r
.05145 .38596 m .06557 .40202 L .05632 .41482 L p F P
0 g
s
.721 .543 .65 r
.04636 .3937 m .06061 .39081 L .05145 .38596 L p F P
0 g
s
.721 .543 .65 r
.05145 .38596 m .03711 .38322 L .04636 .3937 L p F P
0 g
s
.72 .586 .704 r
.57232 .5713 m .56062 .56887 L .56357 .56166 L p F P
0 g
s
.72 .585 .704 r
.56062 .56887 m .57232 .5713 L .56957 .57832 L p F P
0 g
s
.756 .568 .642 r
.69786 .585 m .70252 .58245 L .70111 .57983 L p F P
0 g
s
.756 .568 .642 r
.70111 .57983 m .69624 .58205 L .69786 .585 L p F P
0 g
s
.713 .588 .715 r
.56731 .50538 m .57724 .51222 L .57409 .51597 L p F P
0 g
s
.713 .588 .715 r
.57409 .51597 m .56397 .50938 L .56731 .50538 L p F P
0 g
s
.715 .587 .712 r
.56397 .50938 m .57409 .51597 L .57094 .52041 L p F P
0 g
s
.715 .587 .712 r
.57094 .52041 m .56062 .51411 L .56397 .50938 L p F P
0 g
s
.716 .587 .71 r
.56062 .51411 m .57094 .52041 L .56779 .52548 L p F P
0 g
s
.71 .589 .718 r
.57066 .50216 m .58039 .50919 L .57724 .51222 L p F P
0 g
s
.71 .589 .718 r
.57724 .51222 m .56731 .50538 L .57066 .50216 L p F P
0 g
s
.716 .587 .71 r
.56779 .52548 m .55728 .5195 L .56062 .51411 L p F P
0 g
s
.717 .586 .708 r
.55728 .5195 m .56779 .52548 L .56465 .53112 L p F P
0 g
s
.721 .585 .703 r
.57635 .59341 m .56407 .59295 L .56682 .58554 L p F P
0 g
s
.72 .585 .703 r
.56407 .59295 m .57635 .59341 L .5738 .60052 L p F P
0 g
s
.721 .585 .702 r
.58796 .63086 m .57452 .6347 L .57687 .62754 L p F P
0 g
s
.721 .585 .702 r
.57452 .6347 m .58796 .63086 L .58581 .63757 L p F P
0 g
s
.758 .565 .636 r
.68593 .57409 m .69141 .57349 L .6898 .57073 L p F P
0 g
s
.758 .565 .636 r
.6898 .57073 m .68412 .57105 L .68593 .57409 L p F P
0 g
s
.721 .585 .702 r
.58157 .6135 m .56871 .61513 L .57125 .60776 L p F P
0 g
s
.721 .585 .702 r
.56871 .61513 m .58157 .6135 L .57922 .62047 L p F P
0 g
s
.719 .586 .705 r
.56652 .55475 m .55521 .55087 L .55836 .54388 L p F P
0 g
s
.719 .585 .705 r
.55521 .55087 m .56652 .55475 L .56357 .56166 L p F P
0 g
s
.707 .59 .723 r
.57402 .49972 m .58354 .5069 L .58039 .50919 L p F P
0 g
s
.707 .59 .723 r
.58039 .50919 m .57066 .50216 L .57402 .49972 L p F P
0 g
s
.779 .54 .574 r
.64779 .54109 m .6551 .5446 L .65291 .54212 L p F P
0 g
s
.779 .54 .574 r
.65291 .54212 m .6454 .53842 L .64779 .54109 L p F P
0 g
s
.717 .586 .708 r
.56465 .53112 m .55393 .5255 L .55728 .5195 L p F P
0 g
s
.717 .586 .707 r
.55393 .5255 m .56465 .53112 L .5615 .53727 L p F P
0 g
s
.683 .598 .754 r
.59303 .50438 m .60196 .51112 L .59899 .51126 L p F P
0 g
s
.683 .598 .754 r
.59899 .51126 m .58986 .50452 L .59303 .50438 L p F P
0 g
s
.618 .609 .82 r
.6079 .51258 m .61643 .51866 L .61365 .51772 L p F P
0 g
s
.618 .609 .82 r
.61365 .51772 m .60493 .51158 L .6079 .51258 L p F P
0 g
s
.72 .585 .704 r
.56957 .57832 m .55768 .57633 L .56062 .56887 L p F P
0 g
s
.72 .585 .703 r
.55768 .57633 m .56957 .57832 L .56682 .58554 L p F P
0 g
s
.721 .584 .701 r
.59358 .65135 m .57935 .65807 L .5815 .65118 L p F P
0 g
s
.721 .584 .701 r
.57935 .65807 m .59358 .65135 L .59162 .65773 L p F P
0 g
s
.802 .498 .474 r
.63528 .53154 m .643 .53598 L .64061 .5338 L p F P
0 g
s
.802 .498 .474 r
.64061 .5338 m .6327 .5292 L .63528 .53154 L p F P
0 g
s
0 .182 .609 r
.62199 .52186 m .63011 .52716 L .62753 .52547 L p F P
0 g
s
.122 .472 .894 r
.61385 .51598 m .62199 .52186 L .6192 .52005 L p F P
0 g
s
.671 .123 0 r
.61684 .51827 m .61988 .52048 L p .62199 .52186 L F P
0 g
s
0 .182 .609 r
.62392 .52312 m .6192 .52005 L .62199 .52186 L p F P
0 g
s
.671 .123 0 r
.61988 .52048 m .62477 .52402 L .62199 .52186 L p F P
0 g
s
0 .182 .609 r
.62753 .52547 m .62392 .52312 L p .62199 .52186 L F P
0 g
s
.702 .591 .729 r
.57737 .49808 m .5867 .50535 L .58354 .5069 L p F P
0 g
s
.702 .591 .729 r
.58354 .5069 m .57402 .49972 L .57737 .49808 L p F P
0 g
s
.717 .586 .707 r
.5615 .53727 m .55059 .53203 L .55393 .5255 L p F P
0 g
s
.718 .585 .706 r
.55059 .53203 m .5615 .53727 L .55836 .54388 L p F P
0 g
s
.767 .556 .612 r
.6617 .55307 m .6684 .55534 L .6664 .55259 L p F P
0 g
s
.767 .556 .612 r
.6664 .55259 m .6595 .55009 L .6617 .55307 L p F P
0 g
s
.761 .562 .627 r
.67442 .56427 m .68051 .56517 L .6787 .56235 L p F P
0 g
s
.761 .562 .627 r
.6787 .56235 m .67241 .56119 L .67442 .56427 L p F P
0 g
s
.72 .585 .703 r
.5738 .60052 m .56133 .60053 L .56407 .59295 L p F P
0 g
s
.72 .585 .703 r
.56133 .60053 m .5738 .60052 L .57125 .60776 L p F P
0 g
s
.719 .585 .705 r
.56357 .56166 m .55207 .55822 L .55521 .55087 L p F P
0 g
s
.719 .585 .704 r
.55207 .55822 m .56357 .56166 L .56062 .56887 L p F P
0 g
s
.721 .585 .702 r
.58581 .63757 m .57216 .64194 L .57452 .6347 L p F P
0 g
s
.721 .584 .701 r
.57216 .64194 m .58581 .63757 L .58366 .64435 L p F P
0 g
s
.721 .585 .702 r
.57922 .62047 m .56616 .6226 L .56871 .61513 L p F P
0 g
s
.721 .584 .702 r
.56616 .6226 m .57922 .62047 L .57687 .62754 L p F P
0 g
s
.712 .587 .714 r
.55739 .49798 m .56731 .50538 L .56397 .50938 L p F P
0 g
s
.712 .587 .714 r
.56397 .50938 m .55384 .50222 L .55739 .49798 L p F P
0 g
s
.714 .586 .711 r
.55384 .50222 m .56397 .50938 L .56062 .51411 L p F P
0 g
s
.714 .586 .711 r
.56062 .51411 m .5503 .50724 L .55384 .50222 L p F P
0 g
s
.715 .586 .709 r
.5503 .50724 m .56062 .51411 L .55728 .5195 L p F P
0 g
s
.718 .585 .706 r
.55836 .54388 m .54725 .53903 L .55059 .53203 L p F P
0 g
s
.718 .585 .705 r
.54725 .53903 m .55836 .54388 L .55521 .55087 L p F P
0 g
s
.72 .585 .703 r
.56682 .58554 m .55473 .58401 L .55768 .57633 L p F P
0 g
s
.72 .585 .703 r
.55473 .58401 m .56682 .58554 L .56407 .59295 L p F P
0 g
s
.709 .587 .717 r
.56093 .49455 m .57066 .50216 L .56731 .50538 L p F P
0 g
s
.709 .587 .717 r
.56731 .50538 m .55739 .49798 L .56093 .49455 L p F P
0 g
s
.758 .566 .637 r
.68774 .57718 m .69302 .5763 L .69141 .57349 L p F P
0 g
s
.758 .566 .637 r
.69141 .57349 m .68593 .57409 L .68774 .57718 L p F P
0 g
s
.694 .592 .738 r
.58073 .49721 m .58986 .50452 L .5867 .50535 L p F P
0 g
s
.694 .592 .738 r
.5867 .50535 m .57737 .49808 L .58073 .49721 L p F P
0 g
s
.721 .584 .701 r
.59162 .65773 m .57719 .66501 L .57935 .65807 L p F P
0 g
s
.715 .586 .709 r
.55728 .5195 m .54676 .51296 L .5503 .50724 L p F P
0 g
s
.716 .585 .708 r
.54676 .51296 m .55728 .5195 L .55393 .5255 L p F P
0 g
s
.664 .6 .773 r
.59619 .50487 m .60493 .51158 L .60196 .51112 L p F P
0 g
s
.664 .6 .773 r
.60196 .51112 m .59303 .50438 L .59619 .50487 L p F P
0 g
s
.777 .547 .587 r
.65019 .54395 m .6573 .54726 L .6551 .5446 L p F P
0 g
s
.777 .547 .587 r
.6551 .5446 m .64779 .54109 L .65019 .54395 L p F P
0 g
s
.511 .601 .88 r
.61087 .51406 m .6192 .52005 L .61643 .51866 L p F P
0 g
s
.511 .601 .88 r
.61643 .51866 m .6079 .51258 L .61087 .51406 L p F P
0 g
s
.719 .585 .704 r
.56062 .56887 m .54893 .56585 L .55207 .55822 L p F P
0 g
s
.719 .585 .704 r
.54893 .56585 m .56062 .56887 L .55768 .57633 L p F P
0 g
s
.706 .588 .722 r
.56448 .49197 m .57402 .49972 L .57066 .50216 L p F P
0 g
s
.706 .588 .722 r
.57066 .50216 m .56093 .49455 L .56448 .49197 L p F P
0 g
s
.716 .585 .708 r
.55393 .5255 m .54321 .51932 L .54676 .51296 L p F P
0 g
s
.717 .585 .707 r
.54321 .51932 m .55393 .5255 L .55059 .53203 L p F P
0 g
s
.72 .585 .703 r
.57125 .60776 m .55858 .60825 L .56133 .60053 L p F P
0 g
s
.72 .584 .702 r
.55858 .60825 m .57125 .60776 L .56871 .61513 L p F P
0 g
s
.802 .35 .168 r
.62477 .52402 m .6327 .5292 L .63011 .52716 L p F P
0 g
s
.802 .35 .168 r
.63011 .52716 m .62199 .52186 L .62477 .52402 L p F P
0 g
s
.795 .522 .524 r
.63788 .53414 m .6454 .53842 L .643 .53598 L p F P
0 g
s
.795 .522 .524 r
.643 .53598 m .63528 .53154 L .63788 .53414 L p F P
0 g
s
.718 .585 .705 r
.55521 .55087 m .54391 .54644 L .54725 .53903 L p F P
0 g
s
.718 .585 .705 r
.54391 .54644 m .55521 .55087 L .55207 .55822 L p F P
0 g
s
.721 .584 .701 r
.58366 .64435 m .56981 .64924 L .57216 .64194 L p F P
0 g
s
.721 .584 .701 r
.56981 .64924 m .58366 .64435 L .5815 .65118 L p F P
0 g
s
.648 .561 .743 r
.06061 .39081 m .07469 .39771 L .06557 .40202 L p F P
0 g
s
.691 .564 .708 r
.07966 .42076 m .06557 .40202 L .07469 .39771 L p F P
0 g
s
.699 .565 .701 r
.06557 .40202 m .07966 .42076 L .07057 .43511 L p F P
0 g
s
.699 .565 .701 r
.07057 .43511 m .05632 .41482 L .06557 .40202 L p F P
0 g
s
.721 .584 .702 r
.57687 .62754 m .56361 .63018 L .56616 .6226 L p F P
0 g
s
.721 .584 .702 r
.56361 .63018 m .57687 .62754 L .57452 .6347 L p F P
0 g
s
.762 .563 .629 r
.67642 .56743 m .68232 .56807 L .68051 .56517 L p F P
0 g
s
.762 .563 .629 r
.68051 .56517 m .67442 .56427 L .67642 .56743 L p F P
0 g
s
.767 .558 .615 r
.6639 .55617 m .67041 .55821 L .6684 .55534 L p F P
0 g
s
.767 .558 .615 r
.6684 .55534 m .6617 .55307 L .6639 .55617 L p F P
0 g
s
.701 .589 .727 r
.56803 .49024 m .57737 .49808 L .57402 .49972 L p F P
0 g
s
.701 .589 .727 r
.57402 .49972 m .56448 .49197 L .56803 .49024 L p F P
0 g
s
.72 .585 .703 r
.56407 .59295 m .55179 .59188 L .55473 .58401 L p F P
0 g
s
.72 .584 .703 r
.55179 .59188 m .56407 .59295 L .56133 .60053 L p F P
0 g
s
.683 .594 .749 r
.58409 .49707 m .59303 .50438 L .58986 .50452 L p F P
0 g
s
.683 .594 .749 r
.58986 .50452 m .58073 .49721 L .58409 .49707 L p F P
0 g
s
.717 .585 .707 r
.55059 .53203 m .53967 .52623 L .54321 .51932 L p F P
0 g
s
.717 .584 .706 r
.53967 .52623 m .55059 .53203 L .54725 .53903 L p F P
0 g
s
.719 .585 .704 r
.55768 .57633 m .54578 .57375 L .54893 .56585 L p F P
0 g
s
.719 .584 .703 r
.54578 .57375 m .55768 .57633 L .55473 .58401 L p F P
0 g
s
.711 .586 .713 r
.54745 .48999 m .55739 .49798 L .55384 .50222 L p F P
0 g
s
.711 .586 .713 r
.55384 .50222 m .54371 .49449 L .54745 .48999 L p F P
0 g
s
.713 .585 .711 r
.54371 .49449 m .55384 .50222 L .5503 .50724 L p F P
0 g
s
.63 .601 .803 r
.59936 .50594 m .6079 .51258 L .60493 .51158 L p F P
0 g
s
.63 .601 .803 r
.60493 .51158 m .59619 .50487 L .59936 .50594 L p F P
0 g
s
.713 .585 .711 r
.5503 .50724 m .53997 .49981 L .54371 .49449 L p F P
0 g
s
.714 .585 .709 r
.53997 .49981 m .5503 .50724 L .54676 .51296 L p F P
0 g
s
.759 .567 .637 r
.68956 .58033 m .69463 .57915 L .69302 .5763 L p F P
0 g
s
.759 .567 .637 r
.69302 .5763 m .68774 .57718 L .68956 .58033 L p F P
0 g
s
.718 .585 .705 r
.55207 .55822 m .54056 .5542 L .54391 .54644 L p F P
0 g
s
.718 .584 .704 r
.54056 .5542 m .55207 .55822 L .54893 .56585 L p F P
0 g
s
.709 .586 .716 r
.5512 .48637 m .56093 .49455 L .55739 .49798 L p F P
0 g
s
.709 .586 .716 r
.55739 .49798 m .54745 .48999 L .5512 .48637 L p F P
0 g
s
.72 .584 .702 r
.56871 .61513 m .55583 .61611 L .55858 .60825 L p F P
0 g
s
.72 .584 .702 r
.55583 .61611 m .56871 .61513 L .56616 .6226 L p F P
0 g
s
.714 .585 .709 r
.54676 .51296 m .53623 .50587 L .53997 .49981 L p F P
0 g
s
.715 .584 .707 r
.53623 .50587 m .54676 .51296 L .54321 .51932 L p F P
0 g
s
.717 .584 .706 r
.54725 .53903 m .53613 .53363 L .53967 .52623 L p F P
0 g
s
.717 .584 .705 r
.53613 .53363 m .54725 .53903 L .54391 .54644 L p F P
0 g
s
.721 .584 .701 r
.5815 .65118 m .56746 .65662 L .56981 .64924 L p F P
0 g
s
.721 .584 .701 r
.56746 .65662 m .5815 .65118 L .57935 .65807 L p F P
0 g
s
.122 .472 .894 r
.6192 .52005 m .61087 .51406 L .61385 .51598 L p F P
0 g
s
.775 .551 .595 r
.65259 .54698 m .6595 .55009 L .6573 .54726 L p F P
0 g
s
.775 .551 .595 r
.6573 .54726 m .65019 .54395 L .65259 .54698 L p F P
0 g
s
.694 .59 .735 r
.57159 .48933 m .58073 .49721 L .57737 .49808 L p F P
0 g
s
.694 .59 .735 r
.57737 .49808 m .56803 .49024 L .57159 .48933 L p F P
0 g
s
.721 .584 .702 r
.57452 .6347 m .56105 .63785 L .56361 .63018 L p F P
0 g
s
.721 .584 .702 r
.56105 .63785 m .57452 .6347 L .57216 .64194 L p F P
0 g
s
.705 .586 .72 r
.55494 .48364 m .56448 .49197 L .56093 .49455 L p F P
0 g
s
.705 .586 .72 r
.56093 .49455 m .5512 .48637 L .55494 .48364 L p F P
0 g
s
.715 .584 .707 r
.54321 .51932 m .53249 .51259 L .53623 .50587 L p F P
0 g
s
.716 .584 .706 r
.53249 .51259 m .54321 .51932 L .53967 .52623 L p F P
0 g
s
.72 .584 .703 r
.56133 .60053 m .54884 .59992 L .55179 .59188 L p F P
0 g
s
.72 .584 .702 r
.54884 .59992 m .56133 .60053 L .55858 .60825 L p F P
0 g
s
.819 .47 .394 r
.62756 .52651 m .63528 .53154 L .6327 .5292 L p F P
0 g
s
.819 .47 .394 r
.6327 .5292 m .62477 .52402 L .62756 .52651 L p F P
0 g
s
.791 .536 .552 r
.64047 .53698 m .64779 .54109 L .6454 .53842 L p F P
0 g
s
.791 .536 .552 r
.6454 .53842 m .63788 .53414 L .64047 .53698 L p F P
0 g
s
.666 .595 .766 r
.58745 .4976 m .59619 .50487 L .59303 .50438 L p F P
0 g
s
.666 .595 .766 r
.59303 .50438 m .58409 .49707 L .58745 .4976 L p F P
0 g
s
.719 .584 .703 r
.55473 .58401 m .54264 .58188 L .54578 .57375 L p F P
0 g
s
.719 .584 .703 r
.54264 .58188 m .55473 .58401 L .55179 .59188 L p F P
0 g
s
.762 .564 .63 r
.67843 .57067 m .68412 .57105 L .68232 .56807 L p F P
0 g
s
.762 .564 .63 r
.68232 .56807 m .67642 .56743 L .67843 .57067 L p F P
0 g
s
.718 .584 .704 r
.54893 .56585 m .53722 .56226 L .54056 .5542 L p F P
0 g
s
.719 .584 .704 r
.53722 .56226 m .54893 .56585 L .54578 .57375 L p F P
0 g
s
.717 .584 .705 r
.54391 .54644 m .53259 .54144 L .53613 .53363 L p F P
0 g
s
.718 .584 .704 r
.53259 .54144 m .54391 .54644 L .54056 .5542 L p F P
0 g
s
.767 .56 .618 r
.66611 .55939 m .67241 .56119 L .67041 .55821 L p F P
0 g
s
.767 .56 .618 r
.67041 .55821 m .6639 .55617 L .66611 .55939 L p F P
0 g
s
.7 .587 .726 r
.55869 .48183 m .56803 .49024 L .56448 .49197 L p F P
0 g
s
.7 .587 .726 r
.56448 .49197 m .55494 .48364 L .55869 .48183 L p F P
0 g
s
.716 .584 .706 r
.53967 .52623 m .52875 .51988 L .53249 .51259 L p F P
0 g
s
.717 .584 .705 r
.52875 .51988 m .53967 .52623 L .53613 .53363 L p F P
0 g
s
.72 .584 .702 r
.56616 .6226 m .55308 .62408 L .55583 .61611 L p F P
0 g
s
.72 .584 .702 r
.55308 .62408 m .56616 .6226 L .56361 .63018 L p F P
0 g
s
.71 .584 .712 r
.53752 .48144 m .54745 .48999 L .54371 .49449 L p F P
0 g
s
.71 .584 .712 r
.54371 .49449 m .53358 .4862 L .53752 .48144 L p F P
0 g
s
.712 .584 .71 r
.53358 .4862 m .54371 .49449 L .53997 .49981 L p F P
0 g
s
.712 .584 .71 r
.53997 .49981 m .52964 .49182 L .53358 .4862 L p F P
0 g
s
.714 .584 .708 r
.52964 .49182 m .53997 .49981 L .53623 .50587 L p F P
0 g
s
.558 .596 .848 r
.60254 .50751 m .61087 .51406 L .6079 .51258 L p F P
0 g
s
.558 .596 .848 r
.6079 .51258 m .59936 .50594 L .60254 .50751 L p F P
0 g
s
.759 .568 .638 r
.69137 .58353 m .69624 .58205 L .69463 .57915 L p F P
0 g
s
.759 .568 .638 r
.69463 .57915 m .68956 .58033 L .69137 .58353 L p F P
0 g
s
.721 .584 .701 r
.57935 .65807 m .5651 .66404 L .56746 .65662 L p F P
0 g
s
.721 .584 .701 r
.5651 .66404 m .57935 .65807 L .57719 .66501 L p F P
0 g
s
.683 .59 .746 r
.57515 .48919 m .58409 .49707 L .58073 .49721 L p F P
0 g
s
.683 .59 .746 r
.58073 .49721 m .57159 .48933 L .57515 .48919 L p F P
0 g
s
.708 .585 .715 r
.54146 .47761 m .5512 .48637 L .54745 .48999 L p F P
0 g
s
.708 .585 .715 r
.54745 .48999 m .53752 .48144 L .54146 .47761 L p F P
0 g
s
.721 .584 .702 r
.57216 .64194 m .5585 .6456 L .56105 .63785 L p F P
0 g
s
.72 .584 .701 r
.5585 .6456 m .57216 .64194 L .56981 .64924 L p F P
0 g
s
.714 .584 .708 r
.53623 .50587 m .5257 .49822 L .52964 .49182 L p F P
0 g
s
.715 .584 .707 r
.5257 .49822 m .53623 .50587 L .53249 .51259 L p F P
0 g
s
.671 .57 .733 r
.08867 .41146 m .07469 .39771 L .08372 .3996 L p F P
0 g
s
.691 .564 .708 r
.07469 .39771 m .08867 .41146 L .07966 .42076 L p F P
0 g
s
.753 .517 .575 r
.06974 .39838 m .08372 .3996 L .07469 .39771 L p F P
0 g
s
.753 .517 .575 r
.07469 .39771 m .06061 .39081 L .06974 .39838 L p F P
0 g
s
.709 .541 .659 r
.05564 .40343 m .06974 .39838 L .06061 .39081 L p F P
0 g
s
.709 .541 .659 r
.06061 .39081 m .04636 .3937 L .05564 .40343 L p F P
0 g
s
.72 .584 .702 r
.55858 .60825 m .54589 .60812 L .54884 .59992 L p F P
0 g
s
.72 .584 .702 r
.54589 .60812 m .55858 .60825 L .55583 .61611 L p F P
0 g
s
.704 .585 .719 r
.5454 .47474 m .55494 .48364 L .5512 .48637 L p F P
0 g
s
.704 .585 .719 r
.5512 .48637 m .54146 .47761 L .5454 .47474 L p F P
0 g
s
.717 .584 .705 r
.53613 .53363 m .52501 .52767 L .52875 .51988 L p F P
0 g
s
.717 .583 .705 r
.52501 .52767 m .53613 .53363 L .53259 .54144 L p F P
0 g
s
.671 .123 0 r
.62199 .52186 m .61385 .51598 L .61684 .51827 L p F P
0 g
s
.718 .584 .704 r
.54056 .5542 m .52905 .54961 L .53259 .54144 L p F P
0 g
s
.718 .583 .704 r
.52905 .54961 m .54056 .5542 L .53722 .56226 L p F P
0 g
s
.719 .584 .703 r
.55179 .59188 m .53949 .5902 L .54264 .58188 L p F P
0 g
s
.719 .584 .703 r
.53949 .5902 m .55179 .59188 L .54884 .59992 L p F P
0 g
s
.719 .584 .704 r
.54578 .57375 m .53388 .57059 L .53722 .56226 L p F P
0 g
s
.719 .584 .703 r
.53388 .57059 m .54578 .57375 L .54264 .58188 L p F P
0 g
s
.775 .555 .601 r
.65499 .55016 m .6617 .55307 L .6595 .55009 L p F P
0 g
s
.775 .555 .601 r
.6595 .55009 m .65259 .54698 L .65499 .55016 L p F P
0 g
s
.693 .587 .733 r
.56244 .48088 m .57159 .48933 L .56803 .49024 L p F P
0 g
s
.693 .587 .733 r
.56803 .49024 m .55869 .48183 L .56244 .48088 L p F P
0 g
s
.715 .584 .707 r
.53249 .51259 m .52176 .50531 L .5257 .49822 L p F P
0 g
s
.715 .583 .706 r
.52176 .50531 m .53249 .51259 L .52875 .51988 L p F P
0 g
s
.638 .595 .79 r
.59082 .49873 m .59936 .50594 L .59619 .50487 L p F P
0 g
s
.638 .595 .79 r
.59619 .50487 m .58745 .4976 L .59082 .49873 L p F P
0 g
s
.812 .509 .477 r
.63035 .52927 m .63788 .53414 L .63528 .53154 L p F P
0 g
s
.812 .509 .477 r
.63528 .53154 m .62756 .52651 L .63035 .52927 L p F P
0 g
s
.72 .584 .702 r
.56361 .63018 m .55033 .63215 L .55308 .62408 L p F P
0 g
s
.72 .584 .702 r
.55033 .63215 m .56361 .63018 L .56105 .63785 L p F P
0 g
s
.787 .544 .568 r
.64306 .54003 m .65019 .54395 L .64779 .54109 L p F P
0 g
s
.787 .544 .568 r
.64779 .54109 m .64047 .53698 L .64306 .54003 L p F P
0 g
s
.71 .583 .712 r
.52757 .47232 m .53752 .48144 L .53358 .4862 L p F P
0 g
s
.71 .583 .712 r
.53358 .4862 m .52344 .47734 L .52757 .47232 L p F P
0 g
s
.712 .583 .71 r
.52344 .47734 m .53358 .4862 L .52964 .49182 L p F P
0 g
s
.763 .565 .631 r
.68044 .57398 m .68593 .57409 L .68412 .57105 L p F P
0 g
s
.763 .565 .631 r
.68412 .57105 m .67843 .57067 L .68044 .57398 L p F P
0 g
s
.721 .584 .701 r
.57719 .66501 m .56275 .67153 L .5651 .66404 L p F P
0 g
s
.712 .583 .71 r
.52964 .49182 m .5193 .48328 L .52344 .47734 L p F P
0 g
s
.713 .583 .708 r
.5193 .48328 m .52964 .49182 L .5257 .49822 L p F P
0 g
s
.699 .585 .724 r
.54934 .47284 m .55869 .48183 L .55494 .48364 L p F P
0 g
s
.699 .585 .724 r
.55494 .48364 m .5454 .47474 L .54934 .47284 L p F P
0 g
s
.697 .566 .703 r
.09376 .43961 m .07966 .42076 L .08867 .41146 L p F P
0 g
s
.7 .566 .7 r
.07966 .42076 m .09376 .43961 L .08485 .45466 L p F P
0 g
s
.7 .566 .7 r
.08485 .45466 m .07057 .43511 L .07966 .42076 L p F P
0 g
s
.715 .583 .706 r
.52875 .51988 m .51783 .51299 L .52176 .50531 L p F P
0 g
s
.716 .583 .705 r
.51783 .51299 m .52875 .51988 L .52501 .52767 L p F P
0 g
s
.767 .562 .62 r
.66831 .5627 m .67442 .56427 L .67241 .56119 L p F P
0 g
s
.767 .562 .62 r
.67241 .56119 m .66611 .55939 L .66831 .5627 L p F P
0 g
s
.72 .584 .701 r
.56981 .64924 m .55595 .65343 L .5585 .6456 L p F P
0 g
s
.72 .583 .701 r
.55595 .65343 m .56981 .64924 L .56746 .65662 L p F P
0 g
s
.707 .583 .714 r
.53171 .46828 m .54146 .47761 L .53752 .48144 L p F P
0 g
s
.707 .583 .714 r
.53752 .48144 m .52757 .47232 L .53171 .46828 L p F P
0 g
s
.667 .591 .76 r
.57871 .48976 m .58745 .4976 L .58409 .49707 L p F P
0 g
s
.667 .591 .76 r
.58409 .49707 m .57515 .48919 L .57871 .48976 L p F P
0 g
s
.717 .583 .705 r
.53259 .54144 m .52127 .53589 L .52501 .52767 L p F P
0 g
s
.717 .583 .704 r
.52127 .53589 m .53259 .54144 L .52905 .54961 L p F P
0 g
s
.76 .568 .638 r
.69318 .58678 m .69786 .585 L .69624 .58205 L p F P
0 g
s
.76 .568 .638 r
.69624 .58205 m .69137 .58353 L .69318 .58678 L p F P
0 g
s
.713 .583 .708 r
.5257 .49822 m .51517 .49003 L .5193 .48328 L p F P
0 g
s
.714 .583 .707 r
.51517 .49003 m .5257 .49822 L .52176 .50531 L p F P
0 g
s
.72 .584 .702 r
.55583 .61611 m .54295 .61644 L .54589 .60812 L p F P
0 g
s
.72 .583 .702 r
.54295 .61644 m .55583 .61611 L .55308 .62408 L p F P
0 g
s
.367 .552 .903 r
.60571 .50953 m .61385 .51598 L .61087 .51406 L p F P
0 g
s
.367 .552 .903 r
.61087 .51406 m .60254 .50751 L .60571 .50953 L p F P
0 g
s
.718 .583 .704 r
.53722 .56226 m .52551 .5581 L .52905 .54961 L p F P
0 g
s
.718 .583 .703 r
.52551 .5581 m .53722 .56226 L .53388 .57059 L p F P
0 g
s
.719 .584 .703 r
.54264 .58188 m .53053 .57915 L .53388 .57059 L p F P
0 g
s
.719 .583 .703 r
.53053 .57915 m .54264 .58188 L .53949 .5902 L p F P
0 g
s
.719 .584 .703 r
.54884 .59992 m .53635 .59869 L .53949 .5902 L p F P
0 g
s
.719 .583 .702 r
.53635 .59869 m .54884 .59992 L .54589 .60812 L p F P
0 g
s
.703 .583 .718 r
.53585 .46526 m .5454 .47474 L .54146 .47761 L p F P
0 g
s
.703 .583 .718 r
.54146 .47761 m .53171 .46828 L .53585 .46526 L p F P
0 g
s
.683 .587 .742 r
.5662 .48075 m .57515 .48919 L .57159 .48933 L p F P
0 g
s
.683 .587 .742 r
.57159 .48933 m .56244 .48088 L .5662 .48075 L p F P
0 g
s
.714 .583 .707 r
.52176 .50531 m .51103 .49749 L .51517 .49003 L p F P
0 g
s
.715 .582 .706 r
.51103 .49749 m .52176 .50531 L .51783 .51299 L p F P
0 g
s
.716 .583 .705 r
.52501 .52767 m .51389 .52117 L .51783 .51299 L p F P
0 g
s
.716 .583 .704 r
.51389 .52117 m .52501 .52767 L .52127 .53589 L p F P
0 g
s
.671 .57 .733 r
.08372 .3996 m .09761 .40741 L .08867 .41146 L p F P
0 g
s
.691 .567 .71 r
.10262 .42783 m .08867 .41146 L .09761 .40741 L p F P
0 g
s
.697 .566 .703 r
.08867 .41146 m .10262 .42783 L .09376 .43961 L p F P
0 g
s
.692 .585 .731 r
.55329 .47186 m .56244 .48088 L .55869 .48183 L p F P
0 g
s
.692 .585 .731 r
.55869 .48183 m .54934 .47284 L .55329 .47186 L p F P
0 g
s
.72 .584 .702 r
.56105 .63785 m .54758 .64031 L .55033 .63215 L p F P
0 g
s
.72 .583 .702 r
.54758 .64031 m .56105 .63785 L .5585 .6456 L p F P
0 g
s
.709 .582 .711 r
.51763 .46262 m .52757 .47232 L .52344 .47734 L p F P
0 g
s
.709 .582 .711 r
.52344 .47734 m .5133 .46793 L .51763 .46262 L p F P
0 g
s
.711 .582 .709 r
.5133 .46793 m .52344 .47734 L .5193 .48328 L p F P
0 g
s
.711 .582 .709 r
.5193 .48328 m .50896 .47419 L .5133 .46793 L p F P
0 g
s
.713 .582 .707 r
.50896 .47419 m .5193 .48328 L .51517 .49003 L p F P
0 g
s
.827 .407 .242 r
.61982 .5209 m .62756 .52651 L .62477 .52402 L p F P
0 g
s
.827 .407 .242 r
.62477 .52402 m .61684 .51827 L .61982 .5209 L p F P
0 g
s
.585 .591 .824 r
.59419 .50039 m .60254 .50751 L .59936 .50594 L p F P
0 g
s
.585 .591 .824 r
.59936 .50594 m .59082 .49873 L .59419 .50039 L p F P
0 g
s
.717 .583 .704 r
.52905 .54961 m .51753 .54447 L .52127 .53589 L p F P
0 g
s
.717 .583 .704 r
.51753 .54447 m .52905 .54961 L .52551 .5581 L p F P
0 g
s
.774 .558 .605 r
.65739 .55348 m .6639 .55617 L .6617 .55307 L p F P
0 g
s
.774 .558 .605 r
.6617 .55307 m .65499 .55016 L .65739 .55348 L p F P
0 g
s
.706 .582 .714 r
.52196 .45837 m .53171 .46828 L .52757 .47232 L p F P
0 g
s
.706 .582 .714 r
.52757 .47232 m .51763 .46262 L .52196 .45837 L p F P
0 g
s
.72 .583 .701 r
.56746 .65662 m .5534 .66132 L .55595 .65343 L p F P
0 g
s
.72 .583 .701 r
.5534 .66132 m .56746 .65662 L .5651 .66404 L p F P
0 g
s
.698 .583 .723 r
.53999 .46328 m .54934 .47284 L .5454 .47474 L p F P
0 g
s
.698 .583 .723 r
.5454 .47474 m .53585 .46526 L .53999 .46328 L p F P
0 g
s
.713 .582 .707 r
.51517 .49003 m .50463 .48131 L .50896 .47419 L p F P
0 g
s
.714 .582 .706 r
.50463 .48131 m .51517 .49003 L .51103 .49749 L p F P
0 g
s
.715 .582 .706 r
.51783 .51299 m .50689 .50556 L .51103 .49749 L p F P
0 g
s
.715 .582 .705 r
.50689 .50556 m .51783 .51299 L .51389 .52117 L p F P
0 g
s
.718 .583 .703 r
.53388 .57059 m .52197 .56685 L .52551 .5581 L p F P
0 g
s
.718 .583 .703 r
.52197 .56685 m .53388 .57059 L .53053 .57915 L p F P
0 g
s
.763 .566 .631 r
.68245 .57735 m .68774 .57718 L .68593 .57409 L p F P
0 g
s
.763 .566 .631 r
.68593 .57409 m .68044 .57398 L .68245 .57735 L p F P
0 g
s
.72 .583 .702 r
.55308 .62408 m .54 .62488 L .54295 .61644 L p F P
0 g
s
.719 .583 .702 r
.54 .62488 m .55308 .62408 L .55033 .63215 L p F P
0 g
s
.805 .528 .519 r
.63314 .53228 m .64047 .53698 L .63788 .53414 L p F P
0 g
s
.805 .528 .519 r
.63788 .53414 m .63035 .52927 L .63314 .53228 L p F P
0 g
s
.785 .549 .579 r
.64566 .54325 m .65259 .54698 L .65019 .54395 L p F P
0 g
s
.785 .549 .579 r
.65019 .54395 m .64306 .54003 L .64566 .54325 L p F P
0 g
s
.643 .59 .779 r
.58227 .49096 m .59082 .49873 L .58745 .4976 L p F P
0 g
s
.643 .59 .779 r
.58745 .4976 m .57871 .48976 L .58227 .49096 L p F P
0 g
s
.719 .583 .703 r
.53949 .5902 m .52719 .58791 L .53053 .57915 L p F P
0 g
s
.718 .583 .703 r
.52719 .58791 m .53949 .5902 L .53635 .59869 L p F P
0 g
s
.703 .582 .717 r
.5263 .45521 m .53585 .46526 L .53171 .46828 L p F P
0 g
s
.703 .582 .717 r
.53171 .46828 m .52196 .45837 L .5263 .45521 L p F P
0 g
s
.719 .583 .702 r
.54589 .60812 m .5332 .60734 L .53635 .59869 L p F P
0 g
s
.719 .583 .702 r
.5332 .60734 m .54589 .60812 L .54295 .61644 L p F P
0 g
s
.716 .583 .704 r
.52127 .53589 m .50995 .52979 L .51389 .52117 L p F P
0 g
s
.716 .582 .704 r
.50995 .52979 m .52127 .53589 L .51753 .54447 L p F P
0 g
s
.768 .563 .622 r
.67052 .56611 m .67642 .56743 L .67442 .56427 L p F P
0 g
s
.768 .563 .622 r
.67442 .56427 m .66831 .5627 L .67052 .56611 L p F P
0 g
s
.714 .582 .706 r
.51103 .49749 m .5003 .48915 L .50463 .48131 L p F P
0 g
s
.714 .582 .705 r
.5003 .48915 m .51103 .49749 L .50689 .50556 L p F P
0 g
s
.709 .581 .71 r
.50768 .45236 m .51763 .46262 L .5133 .46793 L p F P
0 g
s
.709 .581 .71 r
.5133 .46793 m .50315 .45796 L .50768 .45236 L p F P
0 g
s
.711 .581 .708 r
.50315 .45796 m .5133 .46793 L .50896 .47419 L p F P
0 g
s
.668 .587 .755 r
.56996 .48137 m .57871 .48976 L .57515 .48919 L p F P
0 g
s
.668 .587 .755 r
.57515 .48919 m .5662 .48075 L .56996 .48137 L p F P
0 g
s
.711 .581 .708 r
.50896 .47419 m .49862 .46457 L .50315 .45796 L p F P
0 g
s
.712 .581 .707 r
.49862 .46457 m .50896 .47419 L .50463 .48131 L p F P
0 g
s
0 .262 .738 r
.60889 .51195 m .61684 .51827 L .61385 .51598 L p F P
0 g
s
0 .117 .603 r
.60432 .50795 m .60773 .51092 L p .60889 .51195 L F P
0 g
s
0 .262 .738 r
.61385 .51598 m .60998 .51291 L p .60889 .51195 L F P
0 g
s
.758 .242 0 r
.61684 .51827 m .60889 .51195 L .61207 .51471 L p F P
0 g
s
0 .117 .603 r
.60773 .51092 m .61207 .51471 L .60889 .51195 L p F P
0 g
s
0 .262 .738 r
.60998 .51291 m .60571 .50953 L .60889 .51195 L p F P
0 g
s
.706 .581 .713 r
.51221 .44789 m .52196 .45837 L .51763 .46262 L p F P
0 g
s
.706 .581 .713 r
.51763 .46262 m .50768 .45236 L .51221 .44789 L p F P
0 g
s
.717 .583 .704 r
.52551 .5581 m .51379 .55337 L .51753 .54447 L p F P
0 g
s
.717 .583 .703 r
.51379 .55337 m .52551 .5581 L .52197 .56685 L p F P
0 g
s
.683 .585 .74 r
.55724 .47175 m .5662 .48075 L .56244 .48088 L p F P
0 g
s
.683 .585 .74 r
.56244 .48088 m .55329 .47186 L .55724 .47175 L p F P
0 g
s
.715 .582 .705 r
.51389 .52117 m .50276 .51414 L .50689 .50556 L p F P
0 g
s
.716 .582 .704 r
.50276 .51414 m .51389 .52117 L .50995 .52979 L p F P
0 g
s
.72 .583 .702 r
.5585 .6456 m .54483 .64856 L .54758 .64031 L p F P
0 g
s
.72 .583 .701 r
.54483 .64856 m .5585 .6456 L .55595 .65343 L p F P
0 g
s
.691 .583 .729 r
.54414 .46228 m .55329 .47186 L .54934 .47284 L p F P
0 g
s
.691 .583 .729 r
.54934 .47284 m .53999 .46328 L .54414 .46228 L p F P
0 g
s
.712 .581 .707 r
.50463 .48131 m .49409 .47206 L .49862 .46457 L p F P
0 g
s
.713 .581 .706 r
.49409 .47206 m .50463 .48131 L .5003 .48915 L p F P
0 g
s
.698 .582 .722 r
.53064 .45315 m .53999 .46328 L .53585 .46526 L p F P
0 g
s
.698 .582 .722 r
.53585 .46526 m .5263 .45521 L .53064 .45315 L p F P
0 g
s
.72 .583 .701 r
.5651 .66404 m .55085 .66927 L .5534 .66132 L p F P
0 g
s
.72 .583 .701 r
.55085 .66927 m .5651 .66404 L .56275 .67153 L p F P
0 g
s
.718 .583 .703 r
.53053 .57915 m .51842 .57584 L .52197 .56685 L p F P
0 g
s
.718 .583 .703 r
.51842 .57584 m .53053 .57915 L .52719 .58791 L p F P
0 g
s
.714 .582 .705 r
.50689 .50556 m .49596 .49761 L .5003 .48915 L p F P
0 g
s
.715 .582 .705 r
.49596 .49761 m .50689 .50556 L .50276 .51414 L p F P
0 g
s
.702 .581 .716 r
.51675 .44458 m .5263 .45521 L .52196 .45837 L p F P
0 g
s
.702 .581 .716 r
.52196 .45837 m .51221 .44789 L .51675 .44458 L p F P
0 g
s
.708 .58 .71 r
.49773 .44154 m .50768 .45236 L .50315 .45796 L p F P
0 g
s
.708 .58 .71 r
.50315 .45796 m .49301 .44745 L .49773 .44154 L p F P
0 g
s
.71 .58 .708 r
.49301 .44745 m .50315 .45796 L .49862 .46457 L p F P
0 g
s
.716 .582 .704 r
.51753 .54447 m .50601 .53878 L .50995 .52979 L p F P
0 g
s
.717 .582 .704 r
.50601 .53878 m .51753 .54447 L .51379 .55337 L p F P
0 g
s
.719 .583 .702 r
.55033 .63215 m .53705 .63343 L .54 .62488 L p F P
0 g
s
.719 .583 .702 r
.53705 .63343 m .55033 .63215 L .54758 .64031 L p F P
0 g
s
.71 .58 .708 r
.49862 .46457 m .48828 .45442 L .49301 .44745 L p F P
0 g
s
.712 .581 .707 r
.48828 .45442 m .49862 .46457 L .49409 .47206 L p F P
0 g
s
.476 .569 .87 r
.59757 .50252 m .60571 .50953 L .60254 .50751 L p F P
0 g
s
.476 .569 .87 r
.60254 .50751 m .59419 .50039 L .59757 .50252 L p F P
0 g
s
.718 .583 .703 r
.53635 .59869 m .52384 .59685 L .52719 .58791 L p F P
0 g
s
.718 .583 .702 r
.52384 .59685 m .53635 .59869 L .5332 .60734 L p F P
0 g
s
.705 .58 .712 r
.50246 .43683 m .51221 .44789 L .50768 .45236 L p F P
0 g
s
.705 .58 .712 r
.50768 .45236 m .49773 .44154 L .50246 .43683 L p F P
0 g
s
.831 .484 .398 r
.62281 .52381 m .63035 .52927 L .62756 .52651 L p F P
0 g
s
.831 .484 .398 r
.62756 .52651 m .61982 .5209 L .62281 .52381 L p F P
0 g
s
.713 .581 .706 r
.5003 .48915 m .48956 .48029 L .49409 .47206 L p F P
0 g
s
.714 .581 .705 r
.48956 .48029 m .5003 .48915 L .49596 .49761 L p F P
0 g
s
.774 .56 .609 r
.65979 .55692 m .66611 .55939 L .6639 .55617 L p F P
0 g
s
.774 .56 .609 r
.6639 .55617 m .65739 .55348 L .65979 .55692 L p F P
0 g
s
.719 .583 .702 r
.54295 .61644 m .53005 .61613 L .5332 .60734 L p F P
0 g
s
.719 .583 .702 r
.53005 .61613 m .54295 .61644 L .54 .62488 L p F P
0 g
s
.703 .583 .718 r
.42118 .31441 m .43074 .32397 L .42445 .32858 L p F P
0 g
s
.703 .583 .718 r
.42445 .32858 m .41469 .31916 L .42118 .31441 L p F P
0 g
s
.698 .573 .711 r
.4342 .34367 m .42445 .32858 L .43074 .32397 L p F P
0 g
s
.714 .584 .708 r
.41469 .31916 m .42445 .32858 L .41814 .33878 L p F P
0 g
s
.709 .578 .706 r
.42445 .32858 m .4342 .34367 L .42809 .35171 L p F P
0 g
s
.709 .578 .706 r
.42809 .35171 m .41814 .33878 L .42445 .32858 L p F P
0 g
s
.764 .567 .632 r
.68447 .58078 m .68956 .58033 L .68774 .57718 L p F P
0 g
s
.764 .567 .632 r
.68774 .57718 m .68245 .57735 L .68447 .58078 L p F P
0 g
s
.716 .582 .704 r
.50995 .52979 m .49862 .52316 L .50276 .51414 L p F P
0 g
s
.716 .582 .704 r
.49862 .52316 m .50995 .52979 L .50601 .53878 L p F P
0 g
s
.712 .581 .707 r
.49409 .47206 m .48355 .4623 L .48828 .45442 L p F P
0 g
s
.713 .581 .706 r
.48355 .4623 m .49409 .47206 L .48956 .48029 L p F P
0 g
s
.289 .575 .938 r
.09761 .40741 m .08372 .3996 L .09272 .40411 L p F P
0 g
s
.718 .533 .639 r
.07887 .40611 m .09272 .40411 L .08372 .3996 L p F P
0 g
s
.718 .533 .639 r
.08372 .3996 m .06974 .39838 L .07887 .40611 L p F P
0 g
s
.603 .585 .806 r
.58584 .49271 m .59419 .50039 L .59082 .49873 L p F P
0 g
s
.603 .585 .806 r
.59082 .49873 m .58227 .49096 L .58584 .49271 L p F P
0 g
s
.717 .583 .703 r
.52197 .56685 m .51005 .56253 L .51379 .55337 L p F P
0 g
s
.717 .582 .703 r
.51005 .56253 m .52197 .56685 L .51842 .57584 L p F P
0 g
s
.708 .579 .709 r
.48778 .43016 m .49773 .44154 L .49301 .44745 L p F P
0 g
s
.708 .579 .709 r
.49301 .44745 m .48286 .43641 L .48778 .43016 L p F P
0 g
s
.71 .58 .707 r
.48286 .43641 m .49301 .44745 L .48828 .45442 L p F P
0 g
s
.701 .58 .715 r
.50719 .43338 m .51675 .44458 L .51221 .44789 L p F P
0 g
s
.701 .58 .715 r
.51221 .44789 m .50246 .43683 L .50719 .43338 L p F P
0 g
s
.289 .575 .938 r
.09272 .40411 m .10649 .40726 L .09761 .40741 L p F P
0 g
s
.682 .573 .727 r
.11143 .41975 m .09761 .40741 L .10649 .40726 L p F P
0 g
s
.691 .567 .71 r
.09761 .40741 m .11143 .41975 L .10262 .42783 L p F P
0 g
s
.801 .539 .542 r
.63593 .5355 m .64306 .54003 L .64047 .53698 L p F P
0 g
s
.801 .539 .542 r
.64047 .53698 m .63314 .53228 L .63593 .5355 L p F P
0 g
s
.784 .554 .587 r
.64826 .54663 m .65499 .55016 L .65259 .54698 L p F P
0 g
s
.784 .554 .587 r
.65259 .54698 m .64566 .54325 L .64826 .54663 L p F P
0 g
s
.697 .58 .721 r
.52128 .44246 m .53064 .45315 L .5263 .45521 L p F P
0 g
s
.697 .58 .721 r
.5263 .45521 m .51675 .44458 L .52128 .44246 L p F P
0 g
s
.71 .58 .707 r
.48828 .45442 m .47793 .44377 L .48286 .43641 L p F P
0 g
s
.711 .58 .706 r
.47793 .44377 m .48828 .45442 L .48355 .4623 L p F P
0 g
s
.715 .582 .705 r
.50276 .51414 m .49163 .50659 L .49596 .49761 L p F P
0 g
s
.715 .581 .704 r
.49163 .50659 m .50276 .51414 L .49862 .52316 L p F P
0 g
s
.768 .565 .623 r
.67273 .5696 m .67843 .57067 L .67642 .56743 L p F P
0 g
s
.768 .565 .623 r
.67642 .56743 m .67052 .56611 L .67273 .5696 L p F P
0 g
s
.705 .579 .711 r
.49271 .4252 m .50246 .43683 L .49773 .44154 L p F P
0 g
s
.705 .579 .711 r
.49773 .44154 m .48778 .43016 L .49271 .4252 L p F P
0 g
s
.72 .583 .701 r
.55595 .65343 m .54208 .65689 L .54483 .64856 L p F P
0 g
s
.72 .583 .701 r
.54208 .65689 m .55595 .65343 L .5534 .66132 L p F P
0 g
s
.699 .567 .702 r
.10788 .45804 m .09376 .43961 L .10262 .42783 L p F P
0 g
s
.701 .567 .7 r
.09376 .43961 m .10788 .45804 L .09915 .47347 L p F P
0 g
s
.701 .567 .7 r
.09915 .47347 m .08485 .45466 L .09376 .43961 L p F P
0 g
s
.714 .584 .708 r
.41814 .33878 m .40818 .33021 L .41469 .31916 L p F P
0 g
s
.715 .583 .707 r
.40818 .33021 m .41814 .33878 L .41183 .35028 L p F P
0 g
s
.711 .579 .705 r
.41814 .33878 m .42809 .35171 L .42198 .36181 L p F P
0 g
s
.711 .579 .705 r
.42198 .36181 m .41183 .35028 L .41814 .33878 L p F P
0 g
s
.706 .576 .707 r
.43804 .36558 m .42809 .35171 L .4342 .34367 L p F P
0 g
s
.709 .578 .705 r
.42809 .35171 m .43804 .36558 L .43212 .37454 L p F P
0 g
s
.709 .578 .705 r
.43212 .37454 m .42198 .36181 L .42809 .35171 L p F P
0 g
s
.691 .581 .728 r
.53498 .45215 m .54414 .46228 L .53999 .46328 L p F P
0 g
s
.691 .581 .728 r
.53999 .46328 m .53064 .45315 L .53498 .45215 L p F P
0 g
s
.647 .585 .771 r
.57372 .48264 m .58227 .49096 L .57871 .48976 L p F P
0 g
s
.647 .585 .771 r
.57871 .48976 m .56996 .48137 L .57372 .48264 L p F P
0 g
s
.697 .567 .705 r
.11657 .44489 m .10262 .42783 L .11143 .41975 L p F P
0 g
s
.699 .567 .702 r
.10262 .42783 m .11657 .44489 L .10788 .45804 L p F P
0 g
s
.682 .582 .737 r
.54829 .4622 m .55724 .47175 L .55329 .47186 L p F P
0 g
s
.682 .582 .737 r
.55329 .47186 m .54414 .46228 L .54829 .4622 L p F P
0 g
s
.698 .573 .711 r
.43074 .32397 m .4403 .33921 L .4342 .34367 L p F P
0 g
s
.698 .573 .711 r
.44395 .35859 m .4342 .34367 L .4403 .33921 L p F P
0 g
s
.706 .576 .707 r
.4342 .34367 m .44395 .35859 L .43804 .36558 L p F P
0 g
s
.714 .581 .705 r
.49596 .49761 m .48503 .48915 L .48956 .48029 L p F P
0 g
s
.714 .581 .704 r
.48503 .48915 m .49596 .49761 L .49163 .50659 L p F P
0 g
s
.669 .584 .751 r
.5612 .47242 m .56996 .48137 L .5662 .48075 L p F P
0 g
s
.669 .584 .751 r
.5662 .48075 m .55724 .47175 L .5612 .47242 L p F P
0 g
s
.72 .583 .701 r
.56275 .67153 m .54829 .67728 L .55085 .66927 L p F P
0 g
s
.707 .579 .708 r
.47783 .41824 m .48778 .43016 L .48286 .43641 L p F P
0 g
s
.707 .579 .708 r
.48286 .43641 m .47271 .42485 L .47783 .41824 L p F P
0 g
s
.709 .579 .707 r
.47271 .42485 m .48286 .43641 L .47793 .44377 L p F P
0 g
s
.713 .581 .706 r
.48956 .48029 m .47882 .47095 L .48355 .4623 L p F P
0 g
s
.713 .58 .705 r
.47882 .47095 m .48956 .48029 L .48503 .48915 L p F P
0 g
s
.718 .583 .703 r
.52719 .58791 m .51488 .58502 L .51842 .57584 L p F P
0 g
s
.718 .582 .702 r
.51488 .58502 m .52719 .58791 L .52384 .59685 L p F P
0 g
s
.704 .576 .708 r
.44798 .37937 m .43804 .36558 L .44395 .35859 L p F P
0 g
s
.708 .577 .706 r
.43804 .36558 m .44798 .37937 L .44227 .38752 L p F P
0 g
s
.708 .577 .706 r
.44227 .38752 m .43212 .37454 L .43804 .36558 L p F P
0 g
s
.717 .582 .704 r
.51379 .55337 m .50207 .54808 L .50601 .53878 L p F P
0 g
s
.717 .582 .703 r
.50207 .54808 m .51379 .55337 L .51005 .56253 L p F P
0 g
s
.711 .58 .706 r
.48355 .4623 m .47301 .45207 L .47793 .44377 L p F P
0 g
s
.712 .58 .705 r
.47301 .45207 m .48355 .4623 L .47882 .47095 L p F P
0 g
s
.704 .578 .711 r
.48296 .413 m .49271 .4252 L .48778 .43016 L p F P
0 g
s
.704 .578 .711 r
.48778 .43016 m .47783 .41824 L .48296 .413 L p F P
0 g
s
.709 .579 .707 r
.47793 .44377 m .46759 .43264 L .47271 .42485 L p F P
0 g
s
.711 .579 .706 r
.46759 .43264 m .47793 .44377 L .47301 .45207 L p F P
0 g
s
.758 .242 0 r
.61207 .51471 m .61982 .5209 L .61684 .51827 L p F P
0 g
s
.701 .578 .715 r
.49764 .42161 m .50719 .43338 L .50246 .43683 L p F P
0 g
s
.701 .578 .715 r
.50246 .43683 m .49271 .4252 L .49764 .42161 L p F P
0 g
s
.719 .583 .702 r
.54758 .64031 m .5341 .64208 L .53705 .63343 L p F P
0 g
s
.719 .583 .701 r
.5341 .64208 m .54758 .64031 L .54483 .64856 L p F P
0 g
s
.712 .58 .705 r
.41183 .35028 m .42198 .36181 L .41586 .3729 L p F P
0 g
s
.711 .578 .705 r
.42198 .36181 m .43212 .37454 L .42621 .38476 L p F P
0 g
s
.711 .578 .705 r
.42621 .38476 m .41586 .3729 L .42198 .36181 L p F P
0 g
s
.707 .578 .708 r
.46788 .40578 m .47783 .41824 L .47271 .42485 L p F P
0 g
s
.707 .578 .708 r
.47271 .42485 m .46256 .41281 L .46788 .40578 L p F P
0 g
s
.709 .579 .706 r
.46256 .41281 m .47271 .42485 L .46759 .43264 L p F P
0 g
s
.71 .578 .705 r
.43212 .37454 m .44227 .38752 L .43655 .39697 L p F P
0 g
s
.71 .578 .705 r
.43655 .39697 m .42621 .38476 L .43212 .37454 L p F P
0 g
s
.704 .576 .708 r
.44395 .35859 m .4537 .37302 L .44798 .37937 L p F P
0 g
s
.704 .576 .709 r
.45793 .39281 m .44798 .37937 L .4537 .37302 L p F P
0 g
s
.707 .577 .707 r
.44798 .37937 m .45793 .39281 L .45242 .40033 L p F P
0 g
s
.707 .577 .707 r
.45242 .40033 m .44227 .38752 L .44798 .37937 L p F P
0 g
s
.718 .583 .702 r
.5332 .60734 m .5205 .60594 L .52384 .59685 L p F P
0 g
s
.718 .583 .702 r
.5205 .60594 m .5332 .60734 L .53005 .61613 L p F P
0 g
s
.741 .662 .772 r
.41157 .31589 m .42118 .31441 L .41469 .31916 L p F P
0 g
s
.741 .662 .772 r
.41469 .31916 m .40488 .32079 L .41157 .31589 L p F P
0 g
s
.724 .606 .725 r
.40488 .32079 m .41469 .31916 L .40818 .33021 L p F P
0 g
s
.698 .573 .711 r
.4403 .33921 m .44985 .35427 L .44395 .35859 L p F P
0 g
s
.698 .574 .711 r
.4537 .37302 m .44395 .35859 L .44985 .35427 L p F P
0 g
s
.704 .577 .71 r
.4732 .40024 m .48296 .413 L .47783 .41824 L p F P
0 g
s
.704 .577 .71 r
.47783 .41824 m .46788 .40578 L .4732 .40024 L p F P
0 g
s
.709 .578 .705 r
.44227 .38752 m .45242 .40033 L .4469 .40915 L p F P
0 g
s
.709 .578 .705 r
.4469 .40915 m .43655 .39697 L .44227 .38752 L p F P
0 g
s
.716 .582 .704 r
.50601 .53878 m .49448 .53254 L .49862 .52316 L p F P
0 g
s
.716 .582 .703 r
.49448 .53254 m .50601 .53878 L .50207 .54808 L p F P
0 g
s
.707 .577 .707 r
.45793 .39281 m .46788 .40578 L .46256 .41281 L p F P
0 g
s
.707 .577 .707 r
.46256 .41281 m .45242 .40033 L .45793 .39281 L p F P
0 g
s
.709 .578 .706 r
.45242 .40033 m .46256 .41281 L .45724 .42107 L p F P
0 g
s
.709 .579 .706 r
.46759 .43264 m .45724 .42107 L .46256 .41281 L p F P
0 g
s
.719 .583 .702 r
.54 .62488 m .5269 .62503 L .53005 .61613 L p F P
0 g
s
.719 .583 .702 r
.5269 .62503 m .54 .62488 L .53705 .63343 L p F P
0 g
s
.696 .579 .72 r
.51192 .4312 m .52128 .44246 L .51675 .44458 L p F P
0 g
s
.696 .579 .72 r
.51675 .44458 m .50719 .43338 L .51192 .4312 L p F P
0 g
s
.664 .581 .752 r
.42765 .31593 m .43703 .32494 L .43074 .32397 L p F P
0 g
s
.664 .581 .752 r
.43074 .32397 m .42118 .31441 L .42765 .31593 L p F P
0 g
s
.676 .566 .723 r
.4403 .33921 m .43074 .32397 L .43703 .32494 L p F P
0 g
s
.709 .578 .706 r
.45724 .42107 m .4469 .40915 L .45242 .40033 L p F P
0 g
s
.704 .576 .709 r
.4537 .37302 m .46345 .38691 L .45793 .39281 L p F P
0 g
s
.704 .577 .709 r
.46788 .40578 m .45793 .39281 L .46345 .38691 L p F P
0 g
s
.711 .579 .705 r
.45724 .42107 m .46759 .43264 L .46246 .44139 L p F P
0 g
s
.711 .579 .706 r
.47301 .45207 m .46246 .44139 L .46759 .43264 L p F P
0 g
s
.704 .577 .709 r
.46345 .38691 m .4732 .40024 L .46788 .40578 L p F P
0 g
s
.715 .583 .707 r
.41183 .35028 m .40167 .34183 L .40818 .33021 L p F P
0 g
s
.714 .583 .707 r
.40167 .34183 m .41183 .35028 L .40551 .36212 L p F P
0 g
s
.712 .58 .705 r
.41586 .3729 m .40551 .36212 L .41183 .35028 L p F P
0 g
s
.712 .579 .705 r
.46246 .44139 m .47301 .45207 L .46808 .46113 L p F P
0 g
s
.712 .58 .705 r
.47882 .47095 m .46808 .46113 L .47301 .45207 L p F P
0 g
s
.715 .581 .704 r
.49862 .52316 m .48729 .516 L .49163 .50659 L p F P
0 g
s
.715 .581 .704 r
.48729 .516 m .49862 .52316 L .49448 .53254 L p F P
0 g
s
.7 .577 .714 r
.48808 .40927 m .49764 .42161 L .49271 .4252 L p F P
0 g
s
.7 .577 .714 r
.49271 .4252 m .48296 .413 L .48808 .40927 L p F P
0 g
s
.713 .58 .705 r
.46808 .46113 m .47882 .47095 L .47409 .48021 L p F P
0 g
s
.713 .58 .705 r
.48503 .48915 m .47409 .48021 L .47882 .47095 L p F P
0 g
s
.717 .582 .703 r
.51842 .57584 m .50631 .57193 L .51005 .56253 L p F P
0 g
s
.717 .582 .703 r
.50631 .57193 m .51842 .57584 L .51488 .58502 L p F P
0 g
s
.711 .578 .705 r
.4469 .40915 m .45724 .42107 L .45192 .43031 L p F P
0 g
s
.711 .579 .705 r
.46246 .44139 m .45192 .43031 L .45724 .42107 L p F P
0 g
s
.714 .581 .704 r
.49163 .50659 m .48049 .49853 L .48503 .48915 L p F P
0 g
s
.714 .581 .704 r
.48049 .49853 m .49163 .50659 L .48729 .516 L p F P
0 g
s
.714 .58 .704 r
.47409 .48021 m .48503 .48915 L .48049 .49853 L p F P
0 g
s
.698 .574 .711 r
.44985 .35427 m .4594 .36885 L .4537 .37302 L p F P
0 g
s
.699 .574 .712 r
.46345 .38691 m .4537 .37302 L .4594 .36885 L p F P
0 g
s
.69 .579 .726 r
.52582 .44145 m .53498 .45215 L .53064 .45315 L p F P
0 g
s
.69 .579 .726 r
.53064 .45315 m .52128 .44246 L .52582 .44145 L p F P
0 g
s
.711 .578 .705 r
.43655 .39697 m .4469 .40915 L .44138 .41891 L p F P
0 g
s
.711 .578 .705 r
.45192 .43031 m .44138 .41891 L .4469 .40915 L p F P
0 g
s
.711 .578 .704 r
.42621 .38476 m .43655 .39697 L .43083 .40732 L p F P
0 g
s
.711 .578 .705 r
.44138 .41891 m .43083 .40732 L .43655 .39697 L p F P
0 g
s
.199 .471 .888 r
.60094 .50506 m .60889 .51195 L .60571 .50953 L p F P
0 g
s
.199 .471 .888 r
.60571 .50953 m .59757 .50252 L .60094 .50506 L p F P
0 g
s
.711 .579 .704 r
.41586 .3729 m .42621 .38476 L .42029 .39573 L p F P
0 g
s
.711 .578 .704 r
.43083 .40732 m .42029 .39573 L .42621 .38476 L p F P
0 g
s
.7 .576 .713 r
.47852 .39636 m .48808 .40927 L .48296 .413 L p F P
0 g
s
.7 .576 .713 r
.48296 .413 m .4732 .40024 L .47852 .39636 L p F P
0 g
s
.775 .562 .611 r
.6622 .56047 m .66831 .5627 L .66611 .55939 L p F P
0 g
s
.775 .562 .611 r
.66611 .55939 m .65979 .55692 L .6622 .56047 L p F P
0 g
s
.765 .568 .632 r
.68648 .58426 m .69137 .58353 L .68956 .58033 L p F P
0 g
s
.765 .568 .632 r
.68956 .58033 m .68447 .58078 L .68648 .58426 L p F P
0 g
s
.72 .583 .701 r
.5534 .66132 m .53933 .66528 L .54208 .65689 L p F P
0 g
s
.72 .583 .701 r
.53933 .66528 m .5534 .66132 L .55085 .66927 L p F P
0 g
s
.699 .574 .712 r
.4594 .36885 m .46896 .38288 L .46345 .38691 L p F P
0 g
s
.699 .575 .712 r
.4732 .40024 m .46345 .38691 L .46896 .38288 L p F P
0 g
s
.724 .606 .725 r
.40818 .33021 m .39818 .32857 L .40488 .32079 L p F P
0 g
s
.72 .594 .715 r
.39818 .32857 m .40818 .33021 L .40167 .34183 L p F P
0 g
s
.712 .579 .705 r
.45192 .43031 m .46246 .44139 L .45734 .45089 L p F P
0 g
s
.712 .579 .705 r
.46808 .46113 m .45734 .45089 L .46246 .44139 L p F P
0 g
s
.676 .566 .723 r
.43703 .32494 m .44639 .33831 L .4403 .33921 L p F P
0 g
s
.686 .569 .718 r
.44985 .35427 m .4403 .33921 L .44639 .33831 L p F P
0 g
s
.824 .515 .466 r
.6258 .52698 m .63314 .53228 L .63035 .52927 L p F P
0 g
s
.824 .515 .466 r
.63035 .52927 m .62281 .52381 L .6258 .52698 L p F P
0 g
s
.699 .575 .712 r
.46896 .38288 m .47852 .39636 L .4732 .40024 L p F P
0 g
s
.682 .573 .727 r
.10649 .40726 m .12019 .41519 L .11143 .41975 L p F P
0 g
s
.693 .569 .711 r
.12522 .43434 m .11143 .41975 L .12019 .41519 L p F P
0 g
s
.697 .567 .705 r
.11143 .41975 m .12522 .43434 L .11657 .44489 L p F P
0 g
s
.712 .58 .705 r
.40551 .36212 m .41586 .3729 L .40974 .38448 L p F P
0 g
s
.711 .579 .704 r
.42029 .39573 m .40974 .38448 L .41586 .3729 L p F P
0 g
s
.695 .577 .719 r
.50256 .41939 m .51192 .4312 L .50719 .43338 L p F P
0 g
s
.695 .577 .719 r
.50719 .43338 m .49764 .42161 L .50256 .41939 L p F P
0 g
s
.682 .58 .735 r
.53933 .4521 m .54829 .4622 L .54414 .46228 L p F P
0 g
s
.682 .58 .735 r
.54414 .46228 m .53498 .45215 L .53933 .4521 L p F P
0 g
s
.717 .582 .703 r
.51005 .56253 m .49813 .55765 L .50207 .54808 L p F P
0 g
s
.717 .582 .703 r
.49813 .55765 m .51005 .56253 L .50631 .57193 L p F P
0 g
s
.712 .579 .704 r
.45734 .45089 m .46808 .46113 L .46315 .47082 L p F P
0 g
s
.713 .58 .705 r
.47409 .48021 m .46315 .47082 L .46808 .46113 L p F P
0 g
s
.718 .582 .702 r
.52384 .59685 m .51133 .59439 L .51488 .58502 L p F P
0 g
s
.718 .582 .702 r
.51133 .59439 m .52384 .59685 L .5205 .60594 L p F P
0 g
s
.711 .579 .704 r
.44138 .41891 m .45192 .43031 L .44659 .44028 L p F P
0 g
s
.712 .579 .705 r
.45734 .45089 m .44659 .44028 L .45192 .43031 L p F P
0 g
s
.706 .539 .661 r
.06494 .41241 m .07887 .40611 L .06974 .39838 L p F P
0 g
s
.706 .539 .661 r
.06974 .39838 m .05564 .40343 L .06494 .41241 L p F P
0 g
s
.531 .572 .841 r
.58941 .49495 m .59757 .50252 L .59419 .50039 L p F P
0 g
s
.531 .572 .841 r
.59419 .50039 m .58584 .49271 L .58941 .49495 L p F P
0 g
s
.67 .581 .747 r
.55244 .46293 m .5612 .47242 L .55724 .47175 L p F P
0 g
s
.67 .581 .747 r
.55724 .47175 m .54829 .4622 L .55244 .46293 L p F P
0 g
s
.769 .566 .624 r
.67494 .57317 m .68044 .57398 L .67843 .57067 L p F P
0 g
s
.769 .566 .624 r
.67843 .57067 m .67273 .5696 L .67494 .57317 L p F P
0 g
s
.711 .578 .704 r
.43083 .40732 m .44138 .41891 L .43585 .42936 L p F P
0 g
s
.711 .579 .704 r
.44659 .44028 m .43585 .42936 L .44138 .41891 L p F P
0 g
s
.714 .583 .707 r
.40551 .36212 m .39515 .35359 L .40167 .34183 L p F P
0 g
s
.714 .582 .706 r
.39515 .35359 m .40551 .36212 L .39919 .37411 L p F P
0 g
s
.712 .58 .705 r
.40974 .38448 m .39919 .37411 L .40551 .36212 L p F P
0 g
s
.686 .569 .718 r
.44639 .33831 m .45575 .35262 L .44985 .35427 L p F P
0 g
s
.69 .571 .717 r
.4594 .36885 m .44985 .35427 L .45575 .35262 L p F P
0 g
s
.713 .58 .704 r
.46315 .47082 m .47409 .48021 L .46935 .48999 L p F P
0 g
s
.714 .58 .704 r
.48049 .49853 m .46935 .48999 L .47409 .48021 L p F P
0 g
s
.784 .557 .592 r
.65086 .55016 m .65739 .55348 L .65499 .55016 L p F P
0 g
s
.784 .557 .592 r
.65499 .55016 m .64826 .54663 L .65086 .55016 L p F P
0 g
s
.798 .546 .557 r
.63873 .5389 m .64566 .54325 L .64306 .54003 L p F P
0 g
s
.798 .546 .557 r
.64306 .54003 m .63593 .5355 L .63873 .5389 L p F P
0 g
s
.716 .582 .703 r
.50207 .54808 m .49034 .54224 L .49448 .53254 L p F P
0 g
s
.716 .581 .703 r
.49034 .54224 m .50207 .54808 L .49813 .55765 L p F P
0 g
s
.719 .583 .701 r
.54483 .64856 m .53115 .65082 L .5341 .64208 L p F P
0 g
s
.719 .583 .701 r
.53115 .65082 m .54483 .64856 L .54208 .65689 L p F P
0 g
s
.615 .581 .793 r
.57748 .48449 m .58584 .49271 L .58227 .49096 L p F P
0 g
s
.615 .581 .793 r
.58227 .49096 m .57372 .48264 L .57748 .48449 L p F P
0 g
s
.65 .582 .765 r
.56516 .47377 m .57372 .48264 L .56996 .48137 L p F P
0 g
s
.65 .582 .765 r
.56996 .48137 m .5612 .47242 L .56516 .47377 L p F P
0 g
s
.695 .576 .718 r
.4932 .40703 m .50256 .41939 L .49764 .42161 L p F P
0 g
s
.695 .576 .718 r
.49764 .42161 m .48808 .40927 L .4932 .40703 L p F P
0 g
s
.712 .817 .931 r
.42118 .31441 m .41157 .31589 L .41825 .31385 L p F P
0 g
s
.712 .817 .931 r
.41825 .31385 m .42765 .31593 L .42118 .31441 L p F P
0 g
s
.711 .578 .704 r
.42029 .39573 m .43083 .40732 L .42511 .41827 L p F P
0 g
s
.711 .578 .704 r
.43585 .42936 m .42511 .41827 L .43083 .40732 L p F P
0 g
s
.718 .583 .702 r
.53005 .61613 m .51715 .61517 L .5205 .60594 L p F P
0 g
s
.718 .582 .702 r
.51715 .61517 m .53005 .61613 L .5269 .62503 L p F P
0 g
s
.689 .578 .725 r
.51666 .43022 m .52582 .44145 L .52128 .44246 L p F P
0 g
s
.689 .578 .725 r
.52128 .44246 m .51192 .4312 L .51666 .43022 L p F P
0 g
s
.714 .58 .704 r
.46935 .48999 m .48049 .49853 L .47596 .50834 L p F P
0 g
s
.714 .581 .704 r
.48729 .516 m .47596 .50834 L .48049 .49853 L p F P
0 g
s
.715 .581 .704 r
.49448 .53254 m .48295 .52578 L .48729 .516 L p F P
0 g
s
.715 .581 .703 r
.48295 .52578 m .49448 .53254 L .49034 .54224 L p F P
0 g
s
.712 .579 .704 r
.44659 .44028 m .45734 .45089 L .45221 .461 L p F P
0 g
s
.712 .579 .704 r
.46315 .47082 m .45221 .461 L .45734 .45089 L p F P
0 g
s
.712 .579 .704 r
.40974 .38448 m .42029 .39573 L .41437 .40717 L p F P
0 g
s
.711 .578 .704 r
.42511 .41827 m .41437 .40717 L .42029 .39573 L p F P
0 g
s
.715 .581 .703 r
.47596 .50834 m .48729 .516 L .48295 .52578 L p F P
0 g
s
.719 .583 .702 r
.53705 .63343 m .52375 .63405 L .5269 .62503 L p F P
0 g
s
.719 .582 .702 r
.52375 .63405 m .53705 .63343 L .5341 .64208 L p F P
0 g
s
.72 .594 .715 r
.40167 .34183 m .39148 .33807 L .39818 .32857 L p F P
0 g
s
.717 .589 .712 r
.39148 .33807 m .40167 .34183 L .39515 .35359 L p F P
0 g
s
.69 .571 .717 r
.45575 .35262 m .46511 .36685 L .4594 .36885 L p F P
0 g
s
.692 .573 .717 r
.46896 .38288 m .4594 .36885 L .46511 .36685 L p F P
0 g
s
.694 .575 .717 r
.48384 .39413 m .4932 .40703 L .48808 .40927 L p F P
0 g
s
.694 .575 .717 r
.48808 .40927 m .47852 .39636 L .48384 .39413 L p F P
0 g
s
.717 .582 .703 r
.51488 .58502 m .50256 .58154 L .50631 .57193 L p F P
0 g
s
.717 .582 .702 r
.50256 .58154 m .51488 .58502 L .51133 .59439 L p F P
0 g
s
.712 .579 .705 r
.39919 .37411 m .40974 .38448 L .40362 .39635 L p F P
0 g
s
.712 .579 .704 r
.41437 .40717 m .40362 .39635 L .40974 .38448 L p F P
0 g
s
.692 .573 .717 r
.46511 .36685 m .47447 .38072 L .46896 .38288 L p F P
0 g
s
.693 .574 .717 r
.47852 .39636 m .46896 .38288 L .47447 .38072 L p F P
0 g
s
.693 .574 .717 r
.47447 .38072 m .48384 .39413 L .47852 .39636 L p F P
0 g
s
.712 .579 .704 r
.43585 .42936 m .44659 .44028 L .44127 .45081 L p F P
0 g
s
.712 .579 .704 r
.45221 .461 m .44127 .45081 L .44659 .44028 L p F P
0 g
s
.842 .425 .245 r
.61526 .51777 m .62281 .52381 L .61982 .5209 L p F P
0 g
s
.842 .425 .245 r
.61982 .5209 m .61207 .51471 L .61526 .51777 L p F P
0 g
s
.713 .579 .704 r
.45221 .461 m .46315 .47082 L .45822 .48099 L p F P
0 g
s
.713 .58 .704 r
.46935 .48999 m .45822 .48099 L .46315 .47082 L p F P
0 g
s
.681 .578 .733 r
.53036 .44146 m .53933 .4521 L .53498 .45215 L p F P
0 g
s
.681 .578 .733 r
.53498 .45215 m .52582 .44145 L .53036 .44146 L p F P
0 g
s
.72 .583 .701 r
.55085 .66927 m .53657 .67374 L .53933 .66528 L p F P
0 g
s
.719 .582 .701 r
.53657 .67374 m .55085 .66927 L .54829 .67728 L p F P
0 g
s
.712 .578 .704 r
.42511 .41827 m .43585 .42936 L .43032 .44033 L p F P
0 g
s
.712 .579 .704 r
.44127 .45081 m .43032 .44033 L .43585 .42936 L p F P
0 g
s
.688 .576 .724 r
.50749 .41845 m .51666 .43022 L .51192 .4312 L p F P
0 g
s
.688 .576 .724 r
.51192 .4312 m .50256 .41939 L .50749 .41845 L p F P
0 g
s
.714 .58 .704 r
.45822 .48099 m .46935 .48999 L .46462 .50018 L p F P
0 g
s
.714 .58 .704 r
.47596 .50834 m .46462 .50018 L .46935 .48999 L p F P
0 g
s
.717 .582 .703 r
.50631 .57193 m .49418 .56745 L .49813 .55765 L p F P
0 g
s
.717 .581 .703 r
.49418 .56745 m .50631 .57193 L .50256 .58154 L p F P
0 g
s
.714 .582 .706 r
.39919 .37411 m .38864 .36543 L .39515 .35359 L p F P
0 g
s
.713 .581 .706 r
.38864 .36543 m .39919 .37411 L .39287 .38621 L p F P
0 g
s
.712 .579 .705 r
.40362 .39635 m .39287 .38621 L .39919 .37411 L p F P
0 g
s
.712 .578 .704 r
.41437 .40717 m .42511 .41827 L .41938 .42965 L p F P
0 g
s
.712 .578 .704 r
.43032 .44033 m .41938 .42965 L .42511 .41827 L p F P
0 g
s
.718 .582 .702 r
.5205 .60594 m .50779 .60391 L .51133 .59439 L p F P
0 g
s
.718 .582 .702 r
.50779 .60391 m .5205 .60594 L .51715 .61517 L p F P
0 g
s
.765 .569 .632 r
.6885 .58779 m .69318 .58678 L .69137 .58353 L p F P
0 g
s
.765 .569 .632 r
.69137 .58353 m .68648 .58426 L .6885 .58779 L p F P
0 g
s
.717 .589 .712 r
.39515 .35359 m .38477 .34844 L .39148 .33807 L p F P
0 g
s
.716 .587 .71 r
.38477 .34844 m .39515 .35359 L .38864 .36543 L p F P
0 g
s
.712 .579 .704 r
.44127 .45081 m .45221 .461 L .44708 .47157 L p F P
0 g
s
.713 .579 .704 r
.45822 .48099 m .44708 .47157 L .45221 .461 L p F P
0 g
s
.714 .58 .703 r
.46462 .50018 m .47596 .50834 L .47142 .5185 L p F P
0 g
s
.715 .581 .703 r
.48295 .52578 m .47142 .5185 L .47596 .50834 L p F P
0 g
s
.712 .579 .704 r
.40362 .39635 m .41437 .40717 L .40844 .41894 L p F P
0 g
s
.712 .578 .704 r
.41938 .42965 m .40844 .41894 L .41437 .40717 L p F P
0 g
s
.699 .568 .703 r
.13053 .46191 m .11657 .44489 L .12522 .43434 L p F P
0 g
s
.701 .567 .701 r
.11657 .44489 m .13053 .46191 L .12202 .47588 L p F P
0 g
s
.701 .567 .701 r
.12202 .47588 m .10788 .45804 L .11657 .44489 L p F P
0 g
s
.716 .581 .703 r
.49813 .55765 m .4862 .5522 L .49034 .54224 L p F P
0 g
s
.716 .581 .703 r
.4862 .5522 m .49813 .55765 L .49418 .56745 L p F P
0 g
s
.67 .579 .744 r
.54367 .4529 m .55244 .46293 L .54829 .4622 L p F P
0 g
s
.67 .579 .744 r
.54829 .4622 m .53933 .4521 L .54367 .4529 L p F P
0 g
s
.775 .563 .613 r
.66461 .56411 m .67052 .56611 L .66831 .5627 L p F P
0 g
s
.775 .563 .613 r
.66831 .5627 m .6622 .56047 L .66461 .56411 L p F P
0 g
s
0 .098 .6 r
.60014 .50395 m .60412 .50774 L p .60432 .50795 L F P
0 g
s
0 .117 .603 r
.60889 .51195 m .60451 .50816 L p .60432 .50795 L F P
0 g
s
.771 .262 0 r
.61207 .51471 m .60432 .50795 L .60771 .51115 L p F P
0 g
s
0 .098 .6 r
.60412 .50774 m .60771 .51115 L .60432 .50795 L p F P
0 g
s
0 .117 .603 r
.60451 .50816 m .60094 .50506 L .60432 .50795 L p F P
0 g
s
.715 .58 .703 r
.47142 .5185 m .48295 .52578 L .47861 .53586 L p F P
0 g
s
.715 .581 .703 r
.49034 .54224 m .47861 .53586 L .48295 .52578 L p F P
0 g
s
.719 .583 .701 r
.54208 .65689 m .52819 .65963 L .53115 .65082 L p F P
0 g
s
.719 .582 .701 r
.52819 .65963 m .54208 .65689 L .53933 .66528 L p F P
0 g
s
.715 .581 .703 r
.47861 .53586 m .49034 .54224 L .4862 .5522 L p F P
0 g
s
.687 .575 .723 r
.49832 .40616 m .50749 .41845 L .50256 .41939 L p F P
0 g
s
.687 .575 .723 r
.50256 .41939 m .4932 .40703 L .49832 .40616 L p F P
0 g
s
.718 .582 .702 r
.5269 .62503 m .5138 .62452 L .51715 .61517 L p F P
0 g
s
.718 .582 .702 r
.5138 .62452 m .5269 .62503 L .52375 .63405 L p F P
0 g
s
.712 .579 .704 r
.39287 .38621 m .40362 .39635 L .3975 .40842 L p F P
0 g
s
.712 .579 .704 r
.40844 .41894 m .3975 .40842 L .40362 .39635 L p F P
0 g
s
.712 .579 .704 r
.43032 .44033 m .44127 .45081 L .43594 .46177 L p F P
0 g
s
.712 .579 .704 r
.44708 .47157 m .43594 .46177 L .44127 .45081 L p F P
0 g
s
.818 .531 .503 r
.62879 .53036 m .63593 .5355 L .63314 .53228 L p F P
0 g
s
.818 .531 .503 r
.63314 .53228 m .6258 .52698 L .62879 .53036 L p F P
0 g
s
.719 .582 .702 r
.5341 .64208 m .5206 .64316 L .52375 .63405 L p F P
0 g
s
.719 .582 .701 r
.5206 .64316 m .5341 .64208 L .53115 .65082 L p F P
0 g
s
.702 .567 .7 r
.10788 .45804 m .12202 .47588 L .11348 .49152 L p F P
0 g
s
.702 .567 .7 r
.11348 .49152 m .09915 .47347 L .10788 .45804 L p F P
0 g
s
.713 .579 .703 r
.44708 .47157 m .45822 .48099 L .45328 .49156 L p F P
0 g
s
.714 .58 .704 r
.46462 .50018 m .45328 .49156 L .45822 .48099 L p F P
0 g
s
.693 .569 .711 r
.12019 .41519 m .13384 .42651 L .12522 .43434 L p F P
0 g
s
.698 .569 .706 r
.13901 .44982 m .12522 .43434 L .13384 .42651 L p F P
0 g
s
.699 .568 .703 r
.12522 .43434 m .13901 .44982 L .13053 .46191 L p F P
0 g
s
.769 .567 .624 r
.67715 .5768 m .68245 .57735 L .68044 .57398 L p F P
0 g
s
.769 .567 .624 r
.68044 .57398 m .67494 .57317 L .67715 .5768 L p F P
0 g
s
.653 .579 .759 r
.55659 .46436 m .56516 .47377 L .5612 .47242 L p F P
0 g
s
.653 .579 .759 r
.5612 .47242 m .55244 .46293 L .55659 .46436 L p F P
0 g
s
.681 .576 .732 r
.52139 .43029 m .53036 .44146 L .52582 .44145 L p F P
0 g
s
.681 .576 .732 r
.52582 .44145 m .51666 .43022 L .52139 .43029 L p F P
0 g
s
.662 .566 .735 r
.44331 .32722 m .45248 .33949 L .44639 .33831 L p F P
0 g
s
.662 .566 .735 r
.44639 .33831 m .43703 .32494 L .44331 .32722 L p F P
0 g
s
.673 .567 .727 r
.45575 .35262 m .44639 .33831 L .45248 .33949 L p F P
0 g
s
.651 .601 .784 r
.12019 .41519 m .10649 .40726 L .11535 .40931 L p F P
0 g
s
.729 .5 .58 r
.10173 .40941 m .11535 .40931 L .10649 .40726 L p F P
0 g
s
.729 .5 .58 r
.10649 .40726 m .09272 .40411 L .10173 .40941 L p F P
0 g
s
.651 .601 .784 r
.11535 .40931 m .12891 .4134 L .12019 .41519 L p F P
0 g
s
.688 .575 .723 r
.13384 .42651 m .12019 .41519 L .12891 .4134 L p F P
0 g
s
.717 .582 .702 r
.51133 .59439 m .49882 .59131 L .50256 .58154 L p F P
0 g
s
.717 .582 .702 r
.49882 .59131 m .51133 .59439 L .50779 .60391 L p F P
0 g
s
.712 .578 .703 r
.41938 .42965 m .43032 .44033 L .4248 .45167 L p F P
0 g
s
.712 .579 .704 r
.43594 .46177 m .4248 .45167 L .43032 .44033 L p F P
0 g
s
.651 .583 .765 r
.43413 .31804 m .44331 .32722 L .43703 .32494 L p F P
0 g
s
.651 .583 .765 r
.43703 .32494 m .42765 .31593 L .43413 .31804 L p F P
0 g
s
.686 .573 .723 r
.48916 .3934 m .49832 .40616 L .4932 .40703 L p F P
0 g
s
.686 .573 .723 r
.4932 .40703 m .48384 .39413 L .48916 .3934 L p F P
0 g
s
.389 .531 .878 r
.59299 .49761 m .60094 .50506 L .59757 .50252 L p F P
0 g
s
.389 .531 .878 r
.59757 .50252 m .58941 .49495 L .59299 .49761 L p F P
0 g
s
.673 .567 .727 r
.45248 .33949 m .46165 .35295 L .45575 .35262 L p F P
0 g
s
.679 .569 .723 r
.46511 .36685 m .45575 .35262 L .46165 .35295 L p F P
0 g
s
.624 .578 .782 r
.56912 .47571 m .57748 .48449 L .57372 .48264 L p F P
0 g
s
.624 .578 .782 r
.57372 .48264 m .56516 .47377 L .56912 .47571 L p F P
0 g
s
.783 .559 .596 r
.65347 .55381 m .65979 .55692 L .65739 .55348 L p F P
0 g
s
.783 .559 .596 r
.65739 .55348 m .65086 .55016 L .65347 .55381 L p F P
0 g
s
.716 .587 .71 r
.38864 .36543 m .37806 .35928 L .38477 .34844 L p F P
0 g
s
.714 .584 .708 r
.37806 .35928 m .38864 .36543 L .38212 .37734 L p F P
0 g
s
.713 .581 .706 r
.39287 .38621 m .38212 .37734 L .38864 .36543 L p F P
0 g
s
.713 .58 .705 r
.38212 .37734 m .39287 .38621 L .38655 .3984 L p F P
0 g
s
.712 .579 .704 r
.3975 .40842 m .38655 .3984 L .39287 .38621 L p F P
0 g
s
.564 .572 .819 r
.58125 .48683 m .58941 .49495 L .58584 .49271 L p F P
0 g
s
.564 .572 .819 r
.58584 .49271 m .57748 .48449 L .58125 .48683 L p F P
0 g
s
.796 .551 .567 r
.64153 .54248 m .64826 .54663 L .64566 .54325 L p F P
0 g
s
.796 .551 .567 r
.64566 .54325 m .63873 .5389 L .64153 .54248 L p F P
0 g
s
.714 .58 .703 r
.45328 .49156 m .46462 .50018 L .45988 .51072 L p F P
0 g
s
.714 .58 .703 r
.47142 .5185 m .45988 .51072 L .46462 .50018 L p F P
0 g
s
.685 .572 .722 r
.47999 .38019 m .48916 .3934 L .48384 .39413 L p F P
0 g
s
.685 .572 .722 r
.48384 .39413 m .47447 .38072 L .47999 .38019 L p F P
0 g
s
.712 .578 .704 r
.40844 .41894 m .41938 .42965 L .41365 .44135 L p F P
0 g
s
.712 .578 .703 r
.4248 .45167 m .41365 .44135 L .41938 .42965 L p F P
0 g
s
.719 .582 .701 r
.54829 .67728 m .53382 .68227 L .53657 .67374 L p F P
0 g
s
.679 .569 .723 r
.46165 .35295 m .47082 .36665 L .46511 .36685 L p F P
0 g
s
.683 .57 .722 r
.47447 .38072 m .46511 .36685 L .47082 .36665 L p F P
0 g
s
.683 .57 .722 r
.47082 .36665 m .47999 .38019 L .47447 .38072 L p F P
0 g
s
.713 .579 .703 r
.43594 .46177 m .44708 .47157 L .44194 .48252 L p F P
0 g
s
.713 .579 .703 r
.45328 .49156 m .44194 .48252 L .44708 .47157 L p F P
0 g
s
.717 .581 .703 r
.50256 .58154 m .49024 .57745 L .49418 .56745 L p F P
0 g
s
.717 .581 .702 r
.49024 .57745 m .50256 .58154 L .49882 .59131 L p F P
0 g
s
.712 .578 .704 r
.3975 .40842 m .40844 .41894 L .40251 .43095 L p F P
0 g
s
.712 .578 .704 r
.41365 .44135 m .40251 .43095 L .40844 .41894 L p F P
0 g
s
.714 .58 .703 r
.45988 .51072 m .47142 .5185 L .46688 .52896 L p F P
0 g
s
.715 .58 .703 r
.47861 .53586 m .46688 .52896 L .47142 .5185 L p F P
0 g
s
.718 .582 .702 r
.51715 .61517 m .50424 .61357 L .50779 .60391 L p F P
0 g
s
.718 .582 .702 r
.50424 .61357 m .51715 .61517 L .5138 .62452 L p F P
0 g
s
.67 .576 .741 r
.5349 .44234 m .54367 .4529 L .53933 .4521 L p F P
0 g
s
.67 .576 .741 r
.53933 .4521 m .53036 .44146 L .5349 .44234 L p F P
0 g
s
.68 .575 .73 r
.51242 .41862 m .52139 .43029 L .51666 .43022 L p F P
0 g
s
.68 .575 .73 r
.51666 .43022 m .50749 .41845 L .51242 .41862 L p F P
0 g
s
.716 .581 .703 r
.49418 .56745 m .48206 .56239 L .4862 .5522 L p F P
0 g
s
.716 .581 .702 r
.48206 .56239 m .49418 .56745 L .49024 .57745 L p F P
0 g
s
.715 .58 .703 r
.46688 .52896 m .47861 .53586 L .47427 .5462 L p F P
0 g
s
.715 .581 .703 r
.4862 .5522 m .47427 .5462 L .47861 .53586 L p F P
0 g
s
.712 .578 .703 r
.4248 .45167 m .43594 .46177 L .4306 .47308 L p F P
0 g
s
.713 .579 .703 r
.44194 .48252 m .4306 .47308 L .43594 .46177 L p F P
0 g
s
.712 .579 .704 r
.38655 .3984 m .3975 .40842 L .39137 .42064 L p F P
0 g
s
.712 .578 .704 r
.40251 .43095 m .39137 .42064 L .3975 .40842 L p F P
0 g
s
.715 .581 .703 r
.47427 .5462 m .4862 .5522 L .48206 .56239 L p F P
0 g
s
.845 .486 .375 r
.61845 .52109 m .6258 .52698 L .62281 .52381 L p F P
0 g
s
.845 .486 .375 r
.62281 .52381 m .61526 .51777 L .61845 .52109 L p F P
0 g
s
.719 .582 .701 r
.53933 .66528 m .52524 .66851 L .52819 .65963 L p F P
0 g
s
.719 .582 .701 r
.52524 .66851 m .53933 .66528 L .53657 .67374 L p F P
0 g
s
.713 .579 .703 r
.44194 .48252 m .45328 .49156 L .44835 .50246 L p F P
0 g
s
.714 .58 .703 r
.45988 .51072 m .44835 .50246 L .45328 .49156 L p F P
0 g
s
.74 .642 .751 r
.39506 .32395 m .40488 .32079 L .39818 .32857 L p F P
0 g
s
.74 .642 .751 r
.39818 .32857 m .38817 .33042 L .39506 .32395 L p F P
0 g
s
.729 .615 .731 r
.38817 .33042 m .39818 .32857 L .39148 .33807 L p F P
0 g
s
.688 .575 .723 r
.12891 .4134 m .14242 .42121 L .13384 .42651 L p F P
0 g
s
.696 .571 .711 r
.14747 .43975 m .13384 .42651 L .14242 .42121 L p F P
0 g
s
.698 .569 .706 r
.13384 .42651 m .14747 .43975 L .13901 .44982 L p F P
0 g
s
.714 .584 .708 r
.38212 .37734 m .37135 .37041 L .37806 .35928 L p F P
0 g
s
.713 .583 .707 r
.37135 .37041 m .38212 .37734 L .3756 .38934 L p F P
0 g
s
.713 .58 .705 r
.38655 .3984 m .3756 .38934 L .38212 .37734 L p F P
0 g
s
.718 .582 .702 r
.52375 .63405 m .51045 .63399 L .5138 .62452 L p F P
0 g
s
.718 .582 .702 r
.51045 .63399 m .52375 .63405 L .5206 .64316 L p F P
0 g
s
.729 .615 .731 r
.39148 .33807 m .38127 .33812 L .38817 .33042 L p F P
0 g
s
.723 .602 .722 r
.38127 .33812 m .39148 .33807 L .38477 .34844 L p F P
0 g
s
.712 .578 .703 r
.41365 .44135 m .4248 .45167 L .41926 .46331 L p F P
0 g
s
.712 .578 .703 r
.4306 .47308 m .41926 .46331 L .4248 .45167 L p F P
0 g
s
.719 .582 .701 r
.53115 .65082 m .51745 .65236 L .5206 .64316 L p F P
0 g
s
.718 .582 .701 r
.51745 .65236 m .53115 .65082 L .52819 .65963 L p F P
0 g
s
.712 .58 .705 r
.3756 .38934 m .38655 .3984 L .38023 .41068 L p F P
0 g
s
.712 .579 .704 r
.39137 .42064 m .38023 .41068 L .38655 .3984 L p F P
0 g
s
.709 .533 .649 r
.08803 .41343 m .10173 .40941 L .09272 .40411 L p F P
0 g
s
.709 .533 .649 r
.09272 .40411 m .07887 .40611 L .08803 .41343 L p F P
0 g
s
.679 .573 .729 r
.50345 .40648 m .51242 .41862 L .50749 .41845 L p F P
0 g
s
.679 .573 .729 r
.50749 .41845 m .49832 .40616 L .50345 .40648 L p F P
0 g
s
.717 .582 .702 r
.50779 .60391 m .49507 .60125 L .49882 .59131 L p F P
0 g
s
.717 .581 .702 r
.49507 .60125 m .50779 .60391 L .50424 .61357 L p F P
0 g
s
.775 .565 .614 r
.66702 .56784 m .67273 .5696 L .67052 .56611 L p F P
0 g
s
.775 .565 .614 r
.67052 .56611 m .66461 .56411 L .66702 .56784 L p F P
0 g
s
.655 .576 .754 r
.54802 .45442 m .55659 .46436 L .55244 .46293 L p F P
0 g
s
.655 .576 .754 r
.55244 .46293 m .54367 .4529 L .54802 .45442 L p F P
0 g
s
.712 .578 .703 r
.40251 .43095 m .41365 .44135 L .40792 .4533 L p F P
0 g
s
.712 .578 .703 r
.41926 .46331 m .40792 .4533 L .41365 .44135 L p F P
0 g
s
.67 .687 .857 r
.42493 .31355 m .43413 .31804 L .42765 .31593 L p F P
0 g
s
.67 .687 .857 r
.42765 .31593 m .41825 .31385 L .42493 .31355 L p F P
0 g
s
.714 .579 .703 r
.44835 .50246 m .45988 .51072 L .45514 .52154 L p F P
0 g
s
.714 .58 .703 r
.46688 .52896 m .45514 .52154 L .45988 .51072 L p F P
0 g
s
.759 .702 .798 r
.40195 .3189 m .41157 .31589 L .40488 .32079 L p F P
0 g
s
.759 .702 .798 r
.40488 .32079 m .39506 .32395 L .40195 .3189 L p F P
0 g
s
.723 .602 .722 r
.38477 .34844 m .37438 .34675 L .38127 .33812 L p F P
0 g
s
.719 .595 .716 r
.37438 .34675 m .38477 .34844 L .37806 .35928 L p F P
0 g
s
.713 .579 .703 r
.4306 .47308 m .44194 .48252 L .43681 .49376 L p F P
0 g
s
.713 .579 .703 r
.44835 .50246 m .43681 .49376 L .44194 .48252 L p F P
0 g
s
.712 .578 .704 r
.39137 .42064 m .40251 .43095 L .39658 .44314 L p F P
0 g
s
.712 .578 .703 r
.40792 .4533 m .39658 .44314 L .40251 .43095 L p F P
0 g
s
.771 .262 0 r
.60771 .51115 m .61526 .51777 L .61207 .51471 L p F P
0 g
s
.77 .568 .625 r
.67937 .58049 m .68447 .58078 L .68245 .57735 L p F P
0 g
s
.77 .568 .625 r
.68245 .57735 m .67715 .5768 L .67937 .58049 L p F P
0 g
s
.67 .574 .739 r
.52613 .43128 m .5349 .44234 L .53036 .44146 L p F P
0 g
s
.67 .574 .739 r
.53036 .44146 m .52139 .43029 L .52613 .43128 L p F P
0 g
s
.814 .541 .525 r
.63178 .53394 m .63873 .5389 L .63593 .5355 L p F P
0 g
s
.814 .541 .525 r
.63593 .5355 m .62879 .53036 L .63178 .53394 L p F P
0 g
s
.714 .58 .703 r
.45514 .52154 m .46688 .52896 L .46234 .53967 L p F P
0 g
s
.715 .58 .703 r
.47427 .5462 m .46234 .53967 L .46688 .52896 L p F P
0 g
s
.717 .581 .702 r
.49882 .59131 m .4863 .58763 L .49024 .57745 L p F P
0 g
s
.717 .581 .702 r
.4863 .58763 m .49882 .59131 L .49507 .60125 L p F P
0 g
s
.677 .571 .729 r
.49448 .3939 m .50345 .40648 L .49832 .40616 L p F P
0 g
s
.677 .571 .729 r
.49832 .40616 m .48916 .3934 L .49448 .3939 L p F P
0 g
s
.63 .575 .773 r
.56075 .4664 m .56912 .47571 L .56516 .47377 L p F P
0 g
s
.63 .575 .773 r
.56516 .47377 m .55659 .46436 L .56075 .4664 L p F P
0 g
s
.712 .578 .704 r
.38023 .41068 m .39137 .42064 L .38524 .43299 L p F P
0 g
s
.712 .578 .704 r
.39658 .44314 m .38524 .43299 L .39137 .42064 L p F P
0 g
s
.719 .595 .716 r
.37806 .35928 m .36747 .35608 L .37438 .34675 L p F P
0 g
s
.717 .59 .713 r
.36747 .35608 m .37806 .35928 L .37135 .37041 L p F P
0 g
s
.713 .583 .707 r
.3756 .38934 m .36464 .38176 L .37135 .37041 L p F P
0 g
s
.713 .581 .707 r
.36464 .38176 m .3756 .38934 L .36908 .40142 L p F P
0 g
s
.712 .58 .705 r
.38023 .41068 m .36908 .40142 L .3756 .38934 L p F P
0 g
s
.712 .578 .703 r
.41926 .46331 m .4306 .47308 L .42527 .48466 L p F P
0 g
s
.713 .579 .703 r
.43681 .49376 m .42527 .48466 L .4306 .47308 L p F P
0 g
s
.718 .582 .702 r
.5138 .62452 m .50069 .62335 L .50424 .61357 L p F P
0 g
s
.718 .581 .702 r
.50069 .62335 m .5138 .62452 L .51045 .63399 L p F P
0 g
s
.715 .58 .703 r
.46234 .53967 m .47427 .5462 L .46993 .55677 L p F P
0 g
s
.715 .581 .703 r
.48206 .56239 m .46993 .55677 L .47427 .5462 L p F P
0 g
s
.716 .581 .702 r
.49024 .57745 m .47791 .57278 L .48206 .56239 L p F P
0 g
s
.716 .581 .702 r
.47791 .57278 m .49024 .57745 L .4863 .58763 L p F P
0 g
s
.783 .561 .599 r
.65607 .55757 m .6622 .56047 L .65979 .55692 L p F P
0 g
s
.783 .561 .599 r
.65979 .55692 m .65347 .55381 L .65607 .55757 L p F P
0 g
s
.088 .4 .855 r
.59656 .50063 m .60432 .50795 L .60094 .50506 L p F P
0 g
s
.088 .4 .855 r
.60094 .50506 m .59299 .49761 L .59656 .50063 L p F P
0 g
s
.713 .579 .703 r
.43681 .49376 m .44835 .50246 L .44341 .51363 L p F P
0 g
s
.714 .579 .703 r
.45514 .52154 m .44341 .51363 L .44835 .50246 L p F P
0 g
s
.715 .58 .702 r
.46993 .55677 m .48206 .56239 L .47791 .57278 L p F P
0 g
s
.675 .57 .728 r
.4855 .38095 m .49448 .3939 L .48916 .3934 L p F P
0 g
s
.675 .57 .728 r
.48916 .3934 m .47999 .38019 L .4855 .38095 L p F P
0 g
s
.585 .57 .803 r
.57308 .47816 m .58125 .48683 L .57748 .48449 L p F P
0 g
s
.585 .57 .803 r
.57748 .48449 m .56912 .47571 L .57308 .47816 L p F P
0 g
s
.7 .569 .704 r
.1528 .46549 m .13901 .44982 L .14747 .43975 L p F P
0 g
s
.701 .568 .702 r
.13901 .44982 m .1528 .46549 L .1445 .47857 L p F P
0 g
s
.701 .568 .702 r
.1445 .47857 m .13053 .46191 L .13901 .44982 L p F P
0 g
s
.795 .555 .575 r
.64433 .5462 m .65086 .55016 L .64826 .54663 L p F P
0 g
s
.795 .555 .575 r
.64826 .54663 m .64153 .54248 L .64433 .5462 L p F P
0 g
s
.719 .582 .701 r
.53657 .67374 m .52229 .67747 L .52524 .66851 L p F P
0 g
s
.719 .582 .701 r
.52229 .67747 m .53657 .67374 L .53382 .68227 L p F P
0 g
s
.479 .549 .85 r
.58502 .4896 m .59299 .49761 L .58941 .49495 L p F P
0 g
s
.479 .549 .85 r
.58941 .49495 m .58125 .48683 L .58502 .4896 L p F P
0 g
s
.712 .579 .705 r
.36908 .40142 m .38023 .41068 L .3739 .42306 L p F P
0 g
s
.712 .578 .704 r
.38524 .43299 m .3739 .42306 L .38023 .41068 L p F P
0 g
s
.712 .578 .703 r
.40792 .4533 m .41926 .46331 L .41373 .4752 L p F P
0 g
s
.712 .578 .703 r
.42527 .48466 m .41373 .4752 L .41926 .46331 L p F P
0 g
s
.702 .568 .701 r
.13053 .46191 m .1445 .47857 L .13617 .49306 L p F P
0 g
s
.702 .568 .701 r
.13617 .49306 m .12202 .47588 L .13053 .46191 L p F P
0 g
s
.673 .568 .729 r
.47653 .36776 m .4855 .38095 L .47999 .38019 L p F P
0 g
s
.673 .568 .729 r
.47999 .38019 m .47082 .36665 L .47653 .36776 L p F P
0 g
s
.718 .582 .702 r
.5206 .64316 m .5071 .64355 L .51045 .63399 L p F P
0 g
s
.718 .582 .701 r
.5071 .64355 m .5206 .64316 L .51745 .65236 L p F P
0 g
s
.717 .59 .713 r
.37135 .37041 m .36057 .36593 L .36747 .35608 L p F P
0 g
s
.715 .587 .711 r
.36057 .36593 m .37135 .37041 L .36464 .38176 L p F P
0 g
s
.669 .567 .731 r
.46755 .35452 m .47653 .36776 L .47082 .36665 L p F P
0 g
s
.669 .567 .731 r
.47082 .36665 m .46165 .35295 L .46755 .35452 L p F P
0 g
s
.718 .582 .701 r
.52819 .65963 m .5143 .66165 L .51745 .65236 L p F P
0 g
s
.718 .582 .701 r
.5143 .66165 m .52819 .65963 L .52524 .66851 L p F P
0 g
s
.712 .578 .703 r
.39658 .44314 m .40792 .4533 L .40219 .46545 L p F P
0 g
s
.712 .578 .703 r
.41373 .4752 m .40219 .46545 L .40792 .4533 L p F P
0 g
s
.663 .566 .734 r
.45858 .34164 m .46755 .35452 L .46165 .35295 L p F P
0 g
s
.663 .566 .734 r
.46165 .35295 m .45248 .33949 L .45858 .34164 L p F P
0 g
s
.669 .572 .737 r
.51736 .41974 m .52613 .43128 L .52139 .43029 L p F P
0 g
s
.669 .572 .737 r
.52139 .43029 m .51242 .41862 L .51736 .41974 L p F P
0 g
s
.696 .571 .711 r
.14242 .42121 m .1559 .43173 L .14747 .43975 L p F P
0 g
s
.699 .57 .707 r
.16109 .45392 m .14747 .43975 L .1559 .43173 L p F P
0 g
s
.7 .569 .704 r
.14747 .43975 m .16109 .45392 L .1528 .46549 L p F P
0 g
s
.656 .574 .751 r
.53945 .44398 m .54802 .45442 L .54367 .4529 L p F P
0 g
s
.656 .574 .751 r
.54367 .4529 m .5349 .44234 L .53945 .44398 L p F P
0 g
s
.714 .579 .703 r
.44341 .51363 m .45514 .52154 L .4504 .5326 L p F P
0 g
s
.714 .58 .703 r
.46234 .53967 m .4504 .5326 L .45514 .52154 L p F P
0 g
s
.764 .792 .876 r
.40883 .31527 m .41825 .31385 L .41157 .31589 L p F P
0 g
s
.764 .792 .876 r
.41157 .31589 m .40195 .3189 L .40883 .31527 L p F P
0 g
s
.713 .579 .703 r
.42527 .48466 m .43681 .49376 L .43167 .50526 L p F P
0 g
s
.713 .579 .703 r
.44341 .51363 m .43167 .50526 L .43681 .49376 L p F P
0 g
s
.717 .581 .702 r
.50424 .61357 m .49132 .61132 L .49507 .60125 L p F P
0 g
s
.717 .581 .702 r
.49132 .61132 m .50424 .61357 L .50069 .62335 L p F P
0 g
s
.655 .567 .743 r
.4496 .32984 m .45858 .34164 L .45248 .33949 L p F P
0 g
s
.655 .567 .743 r
.45248 .33949 m .44331 .32722 L .4496 .32984 L p F P
0 g
s
.711 .578 .703 r
.38524 .43299 m .39658 .44314 L .39065 .4555 L p F P
0 g
s
.712 .578 .703 r
.40219 .46545 m .39065 .4555 L .39658 .44314 L p F P
0 g
s
.713 .581 .707 r
.36908 .40142 m .35792 .3933 L .36464 .38176 L p F P
0 g
s
.712 .58 .706 r
.35792 .3933 m .36908 .40142 L .36256 .41361 L p F P
0 g
s
.712 .579 .705 r
.3739 .42306 m .36256 .41361 L .36908 .40142 L p F P
0 g
s
.839 .514 .438 r
.62164 .52463 m .62879 .53036 L .6258 .52698 L p F P
0 g
s
.839 .514 .438 r
.6258 .52698 m .61845 .52109 L .62164 .52463 L p F P
0 g
s
.68 .591 .75 r
.13763 .41342 m .15099 .418 L .14242 .42121 L p F P
0 g
s
.68 .591 .75 r
.14242 .42121 m .12891 .4134 L .13763 .41342 L p F P
0 g
s
.693 .577 .72 r
.1559 .43173 m .14242 .42121 L .15099 .418 L p F P
0 g
s
.702 .568 .7 r
.12202 .47588 m .13617 .49306 L .12783 .50883 L p F P
0 g
s
.702 .568 .7 r
.12783 .50883 m .11348 .49152 L .12202 .47588 L p F P
0 g
s
.591 .041 0 r
.12891 .4134 m .11535 .40931 L .12421 .41235 L p F P
0 g
s
.591 .041 0 r
.12421 .41235 m .13763 .41342 L .12891 .4134 L p F P
0 g
s
.711 .578 .704 r
.3739 .42306 m .38524 .43299 L .37911 .44547 L p F P
0 g
s
.711 .578 .703 r
.39065 .4555 m .37911 .44547 L .38524 .43299 L p F P
0 g
s
.715 .587 .711 r
.36464 .38176 m .35366 .37618 L .36057 .36593 L p F P
0 g
s
.713 .584 .709 r
.35366 .37618 m .36464 .38176 L .35792 .3933 L p F P
0 g
s
.714 .58 .702 r
.4504 .5326 m .46234 .53967 L .4578 .5506 L p F P
0 g
s
.715 .58 .703 r
.46993 .55677 m .4578 .5506 L .46234 .53967 L p F P
0 g
s
.712 .578 .703 r
.41373 .4752 m .42527 .48466 L .41993 .49647 L p F P
0 g
s
.713 .579 .703 r
.43167 .50526 m .41993 .49647 L .42527 .48466 L p F P
0 g
s
.717 .581 .702 r
.49507 .60125 m .48235 .59797 L .4863 .58763 L p F P
0 g
s
.716 .581 .702 r
.48235 .59797 m .49507 .60125 L .49132 .61132 L p F P
0 g
s
.776 .566 .615 r
.66943 .57165 m .67494 .57317 L .67273 .5696 L p F P
0 g
s
.776 .566 .615 r
.67273 .5696 m .66702 .56784 L .66943 .57165 L p F P
0 g
s
.649 .581 .765 r
.44061 .32028 m .4496 .32984 L .44331 .32722 L p F P
0 g
s
.649 .581 .765 r
.44331 .32722 m .43413 .31804 L .44061 .32028 L p F P
0 g
s
.711 .578 .704 r
.36256 .41361 m .3739 .42306 L .36757 .43553 L p F P
0 g
s
.711 .578 .704 r
.37911 .44547 m .36757 .43553 L .3739 .42306 L p F P
0 g
s
.668 .571 .736 r
.50858 .40775 m .51736 .41974 L .51242 .41862 L p F P
0 g
s
.668 .571 .736 r
.51242 .41862 m .50345 .40648 L .50858 .40775 L p F P
0 g
s
.715 .58 .702 r
.4578 .5506 m .46993 .55677 L .46559 .56753 L p F P
0 g
s
.715 .58 .702 r
.47791 .57278 m .46559 .56753 L .46993 .55677 L p F P
0 g
s
.713 .579 .703 r
.43167 .50526 m .44341 .51363 L .43847 .52503 L p F P
0 g
s
.714 .579 .703 r
.4504 .5326 m .43847 .52503 L .44341 .51363 L p F P
0 g
s
.718 .581 .702 r
.51045 .63399 m .49714 .63325 L .50069 .62335 L p F P
0 g
s
.717 .581 .701 r
.49714 .63325 m .51045 .63399 L .5071 .64355 L p F P
0 g
s
.635 .572 .767 r
.55238 .45657 m .56075 .4664 L .55659 .46436 L p F P
0 g
s
.635 .572 .767 r
.55659 .46436 m .54802 .45442 L .55238 .45657 L p F P
0 g
s
.771 .569 .625 r
.68158 .58424 m .68648 .58426 L .68447 .58078 L p F P
0 g
s
.771 .569 .625 r
.68447 .58078 m .67937 .58049 L .68158 .58424 L p F P
0 g
s
.716 .581 .702 r
.4863 .58763 m .47377 .58335 L .47791 .57278 L p F P
0 g
s
.716 .58 .702 r
.47377 .58335 m .4863 .58763 L .48235 .59797 L p F P
0 g
s
.715 .58 .702 r
.46559 .56753 m .47791 .57278 L .47377 .58335 L p F P
0 g
s
.712 .578 .703 r
.40219 .46545 m .41373 .4752 L .40819 .48728 L p F P
0 g
s
.712 .578 .703 r
.41993 .49647 m .40819 .48728 L .41373 .4752 L p F P
0 g
s
.719 .582 .701 r
.53382 .68227 m .51933 .68648 L .52229 .67747 L p F P
0 g
s
.693 .577 .72 r
.15099 .418 m .16431 .42561 L .1559 .43173 L p F P
0 g
s
.698 .573 .711 r
.16936 .44392 m .1559 .43173 L .16431 .42561 L p F P
0 g
s
.699 .57 .707 r
.1559 .43173 m .16936 .44392 L .16109 .45392 L p F P
0 g
s
.713 .584 .709 r
.35792 .3933 m .34675 .38676 L .35366 .37618 L p F P
0 g
s
.712 .582 .708 r
.34675 .38676 m .35792 .3933 L .3512 .405 L p F P
0 g
s
.712 .58 .706 r
.36256 .41361 m .3512 .405 L .35792 .3933 L p F P
0 g
s
.849 .414 .19 r
.61109 .51461 m .61845 .52109 L .61526 .51777 L p F P
0 g
s
.849 .414 .19 r
.61526 .51777 m .60771 .51115 L .61109 .51461 L p F P
0 g
s
.711 .579 .705 r
.3512 .405 m .36256 .41361 L .35603 .4259 L p F P
0 g
s
.711 .578 .704 r
.36757 .43553 m .35603 .4259 L .36256 .41361 L p F P
0 g
s
.657 .572 .748 r
.53087 .43303 m .53945 .44398 L .5349 .44234 L p F P
0 g
s
.657 .572 .748 r
.5349 .44234 m .52613 .43128 L .53087 .43303 L p F P
0 g
s
.712 .578 .703 r
.39065 .4555 m .40219 .46545 L .39646 .47776 L p F P
0 g
s
.712 .578 .703 r
.40819 .48728 m .39646 .47776 L .40219 .46545 L p F P
0 g
s
.718 .582 .701 r
.51745 .65236 m .50375 .6532 L .5071 .64355 L p F P
0 g
s
.718 .581 .701 r
.50375 .6532 m .51745 .65236 L .5143 .66165 L p F P
0 g
s
.811 .547 .539 r
.63478 .53769 m .64153 .54248 L .63873 .5389 L p F P
0 g
s
.811 .547 .539 r
.63873 .5389 m .63178 .53394 L .63478 .53769 L p F P
0 g
s
.718 .582 .701 r
.52524 .66851 m .51115 .67101 L .5143 .66165 L p F P
0 g
s
.718 .582 .701 r
.51115 .67101 m .52524 .66851 L .52229 .67747 L p F P
0 g
s
.667 .569 .735 r
.4998 .39536 m .50858 .40775 L .50345 .40648 L p F P
0 g
s
.667 .569 .735 r
.50345 .40648 m .49448 .3939 L .4998 .39536 L p F P
0 g
s
.714 .579 .702 r
.43847 .52503 m .4504 .5326 L .44566 .54388 L p F P
0 g
s
.714 .58 .702 r
.4578 .5506 m .44566 .54388 L .4504 .5326 L p F P
0 g
s
.6 .568 .79 r
.56491 .46896 m .57308 .47816 L .56912 .47571 L p F P
0 g
s
.6 .568 .79 r
.56912 .47571 m .56075 .4664 L .56491 .46896 L p F P
0 g
s
.713 .578 .703 r
.41993 .49647 m .43167 .50526 L .42653 .51698 L p F P
0 g
s
.713 .579 .703 r
.43847 .52503 m .42653 .51698 L .43167 .50526 L p F P
0 g
s
.711 .577 .703 r
.37911 .44547 m .39065 .4555 L .38472 .46799 L p F P
0 g
s
.712 .578 .703 r
.39646 .47776 m .38472 .46799 L .39065 .4555 L p F P
0 g
s
.784 .563 .601 r
.65868 .56143 m .66461 .56411 L .6622 .56047 L p F P
0 g
s
.784 .563 .601 r
.6622 .56047 m .65607 .55757 L .65868 .56143 L p F P
0 g
s
.704 .538 .661 r
.07428 .42065 m .08803 .41343 L .07887 .40611 L p F P
0 g
s
.704 .538 .661 r
.07887 .40611 m .06494 .41241 L .07428 .42065 L p F P
0 g
s
.717 .581 .702 r
.50069 .62335 m .48757 .62152 L .49132 .61132 L p F P
0 g
s
.717 .581 .702 r
.48757 .62152 m .50069 .62335 L .49714 .63325 L p F P
0 g
s
.713 .518 .624 r
.11074 .41475 m .12421 .41235 L .11535 .40931 L p F P
0 g
s
.713 .518 .624 r
.11535 .40931 m .10173 .40941 L .11074 .41475 L p F P
0 g
s
.711 .577 .703 r
.36757 .43553 m .37911 .44547 L .37298 .45806 L p F P
0 g
s
.711 .577 .703 r
.38472 .46799 m .37298 .45806 L .37911 .44547 L p F P
0 g
s
.794 .558 .58 r
.64713 .55004 m .65347 .55381 L .65086 .55016 L p F P
0 g
s
.794 .558 .58 r
.65086 .55016 m .64433 .5462 L .64713 .55004 L p F P
0 g
s
0 .179 .696 r
.59636 .49991 m .60083 .50455 L p .60014 .50395 L F P
0 g
s
0 .098 .6 r
.60432 .50795 m .59948 .50338 L p .60014 .50395 L F P
0 g
s
.721 .205 0 r
.60771 .51115 m .6025 .50619 L p .60373 .50755 L F P
0 g
s
.721 .205 0 r
.6025 .50619 m .60014 .50395 L .60373 .50755 L p F P
0 g
s
0 .179 .696 r
.60083 .50455 m .60373 .50755 L .60014 .50395 L p F P
0 g
s
.548 .048 0 r
.60014 .50386 m .605 .50895 L p .60373 .50755 L F P
0 g
s
.548 .048 0 r
.605 .50895 m .60731 .51137 L .60373 .50755 L p F P
0 g
s
0 .098 .6 r
.59948 .50338 m .59656 .50063 L .60014 .50395 L p F P
0 g
s
.529 .555 .826 r
.57705 .48105 m .58502 .4896 L .58125 .48683 L p F P
0 g
s
.529 .555 .826 r
.58125 .48683 m .57308 .47816 L .57705 .48105 L p F P
0 g
s
.666 .567 .735 r
.49102 .38266 m .4998 .39536 L .49448 .3939 L p F P
0 g
s
.666 .567 .735 r
.49448 .3939 m .4855 .38095 L .49102 .38266 L p F P
0 g
s
.711 .578 .704 r
.35603 .4259 m .36757 .43553 L .36124 .44811 L p F P
0 g
s
.711 .577 .703 r
.37298 .45806 m .36124 .44811 L .36757 .43553 L p F P
0 g
s
.714 .579 .702 r
.44566 .54388 m .4578 .5506 L .45325 .56171 L p F P
0 g
s
.715 .58 .702 r
.46559 .56753 m .45325 .56171 L .4578 .5506 L p F P
0 g
s
.333 .497 .872 r
.5888 .49274 m .59656 .50063 L .59299 .49761 L p F P
0 g
s
.333 .497 .872 r
.59299 .49761 m .58502 .4896 L .5888 .49274 L p F P
0 g
s
.712 .578 .703 r
.40819 .48728 m .41993 .49647 L .41459 .50847 L p F P
0 g
s
.713 .578 .703 r
.42653 .51698 m .41459 .50847 L .41993 .49647 L p F P
0 g
s
.712 .582 .708 r
.3512 .405 m .33984 .39764 L .34675 .38676 L p F P
0 g
s
.711 .581 .707 r
.33984 .39764 m .3512 .405 L .34448 .41687 L p F P
0 g
s
.711 .579 .705 r
.35603 .4259 m .34448 .41687 L .3512 .405 L p F P
0 g
s
.725 .61 .728 r
.36396 .34768 m .37438 .34675 L .36747 .35608 L p F P
0 g
s
.725 .61 .728 r
.36747 .35608 m .35686 .35557 L .36396 .34768 L p F P
0 g
s
.721 .601 .722 r
.35686 .35557 m .36747 .35608 L .36057 .36593 L p F P
0 g
s
.701 .57 .704 r
.17472 .46839 m .16109 .45392 L .16936 .44392 L p F P
0 g
s
.701 .569 .703 r
.16109 .45392 m .17472 .46839 L .16661 .48099 L p F P
0 g
s
.701 .569 .703 r
.16661 .48099 m .1528 .46549 L .16109 .45392 L p F P
0 g
s
.732 .623 .737 r
.37105 .34038 m .38127 .33812 L .37438 .34675 L p F P
0 g
s
.732 .623 .737 r
.37438 .34675 m .36396 .34768 L .37105 .34038 L p F P
0 g
s
.702 .569 .701 r
.1528 .46549 m .16661 .48099 L .15849 .49473 L p F P
0 g
s
.702 .569 .701 r
.15849 .49473 m .1445 .47857 L .1528 .46549 L p F P
0 g
s
.721 .601 .722 r
.36057 .36593 m .34977 .36399 L .35686 .35557 L p F P
0 g
s
.718 .594 .717 r
.34977 .36399 m .36057 .36593 L .35366 .37618 L p F P
0 g
s
.662 .631 .809 r
.43162 .31411 m .44061 .32028 L .43413 .31804 L p F P
0 g
s
.662 .631 .809 r
.43413 .31804 m .42493 .31355 L .43162 .31411 L p F P
0 g
s
.716 .581 .702 r
.49132 .61132 m .4784 .60844 L .48235 .59797 L p F P
0 g
s
.716 .581 .702 r
.4784 .60844 m .49132 .61132 L .48757 .62152 L p F P
0 g
s
.713 .579 .702 r
.42653 .51698 m .43847 .52503 L .43353 .53663 L p F P
0 g
s
.714 .579 .702 r
.44566 .54388 m .43353 .53663 L .43847 .52503 L p F P
0 g
s
.711 .578 .705 r
.34448 .41687 m .35603 .4259 L .3495 .43832 L p F P
0 g
s
.711 .578 .704 r
.36124 .44811 m .3495 .43832 L .35603 .4259 L p F P
0 g
s
.715 .58 .702 r
.45325 .56171 m .46559 .56753 L .46124 .57847 L p F P
0 g
s
.715 .58 .702 r
.47377 .58335 m .46124 .57847 L .46559 .56753 L p F P
0 g
s
.728 .781 .894 r
.41572 .31286 m .42493 .31355 L .41825 .31385 L p F P
0 g
s
.728 .781 .894 r
.41825 .31385 m .40883 .31527 L .41572 .31286 L p F P
0 g
s
.742 .645 .753 r
.37814 .33374 m .38817 .33042 L .38127 .33812 L p F P
0 g
s
.742 .645 .753 r
.38127 .33812 m .37105 .34038 L .37814 .33374 L p F P
0 g
s
.657 .57 .745 r
.5223 .42162 m .53087 .43303 L .52613 .43128 L p F P
0 g
s
.657 .57 .745 r
.52613 .43128 m .51736 .41974 L .5223 .42162 L p F P
0 g
s
.718 .594 .717 r
.35366 .37618 m .34267 .37289 L .34977 .36399 L p F P
0 g
s
.715 .59 .714 r
.34267 .37289 m .35366 .37618 L .34675 .38676 L p F P
0 g
s
.663 .566 .735 r
.48224 .36975 m .49102 .38266 L .4855 .38095 L p F P
0 g
s
.663 .566 .735 r
.4855 .38095 m .47653 .36776 L .48224 .36975 L p F P
0 g
s
.639 .57 .761 r
.544 .44623 m .55238 .45657 L .54802 .45442 L p F P
0 g
s
.639 .57 .761 r
.54802 .45442 m .53945 .44398 L .544 .44623 L p F P
0 g
s
.712 .578 .703 r
.39646 .47776 m .40819 .48728 L .40265 .49953 L p F P
0 g
s
.712 .578 .703 r
.41459 .50847 m .40265 .49953 L .40819 .48728 L p F P
0 g
s
.717 .581 .701 r
.5071 .64355 m .49359 .64325 L .49714 .63325 L p F P
0 g
s
.717 .581 .701 r
.49359 .64325 m .5071 .64355 L .50375 .6532 L p F P
0 g
s
.716 .58 .702 r
.48235 .59797 m .46962 .59407 L .47377 .58335 L p F P
0 g
s
.716 .58 .702 r
.46962 .59407 m .48235 .59797 L .4784 .60844 L p F P
0 g
s
.715 .58 .702 r
.46124 .57847 m .47377 .58335 L .46962 .59407 L p F P
0 g
s
.698 .573 .711 r
.16431 .42561 m .1776 .43549 L .16936 .44392 L p F P
0 g
s
.7 .572 .707 r
.18281 .457 m .16936 .44392 L .1776 .43549 L p F P
0 g
s
.701 .57 .704 r
.16936 .44392 m .18281 .457 L .17472 .46839 L p F P
0 g
s
.702 .568 .701 r
.1445 .47857 m .15849 .49473 L .15035 .50955 L p F P
0 g
s
.702 .568 .701 r
.15035 .50955 m .13617 .49306 L .1445 .47857 L p F P
0 g
s
.777 .567 .616 r
.67184 .57552 m .67715 .5768 L .67494 .57317 L p F P
0 g
s
.777 .567 .616 r
.67494 .57317 m .66943 .57165 L .67184 .57552 L p F P
0 g
s
.711 .577 .703 r
.38472 .46799 m .39646 .47776 L .39072 .49023 L p F P
0 g
s
.712 .578 .703 r
.40265 .49953 m .39072 .49023 L .39646 .47776 L p F P
0 g
s
.834 .529 .473 r
.62483 .52837 m .63178 .53394 L .62879 .53036 L p F P
0 g
s
.834 .529 .473 r
.62879 .53036 m .62164 .52463 L .62483 .52837 L p F P
0 g
s
.66 .565 .737 r
.47346 .35685 m .48224 .36975 L .47653 .36776 L p F P
0 g
s
.66 .565 .737 r
.47653 .36776 m .46755 .35452 L .47346 .35685 L p F P
0 g
s
.715 .59 .714 r
.34675 .38676 m .33557 .38221 L .34267 .37289 L p F P
0 g
s
.713 .586 .712 r
.33557 .38221 m .34675 .38676 L .33984 .39764 L p F P
0 g
s
.772 .57 .625 r
.6838 .58804 m .6885 .58779 L .68648 .58426 L p F P
0 g
s
.772 .57 .625 r
.68648 .58426 m .68158 .58424 L .6838 .58804 L p F P
0 g
s
.711 .581 .707 r
.34448 .41687 m .33293 .40879 L .33984 .39764 L p F P
0 g
s
.711 .579 .706 r
.33293 .40879 m .34448 .41687 L .33776 .42891 L p F P
0 g
s
.711 .578 .705 r
.3495 .43832 m .33776 .42891 L .34448 .41687 L p F P
0 g
s
.718 .581 .701 r
.5143 .66165 m .50039 .66295 L .50375 .6532 L p F P
0 g
s
.718 .581 .701 r
.50039 .66295 m .5143 .66165 L .51115 .67101 L p F P
0 g
s
.711 .577 .703 r
.37298 .45806 m .38472 .46799 L .37878 .48062 L p F P
0 g
s
.711 .577 .703 r
.39072 .49023 m .37878 .48062 L .38472 .46799 L p F P
0 g
s
.755 .68 .778 r
.38522 .3278 m .39506 .32395 L .38817 .33042 L p F P
0 g
s
.755 .68 .778 r
.38817 .33042 m .37814 .33374 L .38522 .3278 L p F P
0 g
s
.69 .588 .736 r
.15954 .41629 m .1727 .42112 L .16431 .42561 L p F P
0 g
s
.69 .588 .736 r
.16431 .42561 m .15099 .418 L .15954 .41629 L p F P
0 g
s
.697 .578 .717 r
.1776 .43549 m .16431 .42561 L .1727 .42112 L p F P
0 g
s
.718 .582 .701 r
.52229 .67747 m .50799 .68044 L .51115 .67101 L p F P
0 g
s
.718 .581 .701 r
.50799 .68044 m .52229 .67747 L .51933 .68648 L p F P
0 g
s
.713 .578 .702 r
.41459 .50847 m .42653 .51698 L .42139 .52887 L p F P
0 g
s
.713 .579 .702 r
.43353 .53663 m .42139 .52887 L .42653 .51698 L p F P
0 g
s
.714 .579 .702 r
.43353 .53663 m .44566 .54388 L .44092 .55533 L p F P
0 g
s
.714 .579 .702 r
.45325 .56171 m .44092 .55533 L .44566 .54388 L p F P
0 g
s
.656 .565 .74 r
.46468 .34429 m .47346 .35685 L .46755 .35452 L p F P
0 g
s
.656 .565 .74 r
.46755 .35452 m .45858 .34164 L .46468 .34429 L p F P
0 g
s
.711 .577 .703 r
.36124 .44811 m .37298 .45806 L .36684 .47077 L p F P
0 g
s
.711 .577 .703 r
.37878 .48062 m .36684 .47077 L .37298 .45806 L p F P
0 g
s
.647 .645 .834 r
.14633 .41446 m .15954 .41629 L .15099 .418 L p F P
0 g
s
.647 .645 .834 r
.15099 .418 m .13763 .41342 L .14633 .41446 L p F P
0 g
s
.713 .586 .712 r
.33984 .39764 m .32847 .39195 L .33557 .38221 L p F P
0 g
s
.712 .583 .71 r
.32847 .39195 m .33984 .39764 L .33293 .40879 L p F P
0 g
s
.717 .581 .702 r
.49714 .63325 m .48382 .63184 L .48757 .62152 L p F P
0 g
s
.717 .581 .701 r
.48382 .63184 m .49714 .63325 L .49359 .64325 L p F P
0 g
s
.71 .577 .704 r
.3495 .43832 m .36124 .44811 L .35491 .46081 L p F P
0 g
s
.711 .577 .703 r
.36684 .47077 m .35491 .46081 L .36124 .44811 L p F P
0 g
s
.657 .568 .743 r
.51371 .40978 m .5223 .42162 L .51736 .41974 L p F P
0 g
s
.657 .568 .743 r
.51736 .41974 m .50858 .40775 L .51371 .40978 L p F P
0 g
s
.611 .566 .78 r
.55674 .45924 m .56491 .46896 L .56075 .4664 L p F P
0 g
s
.611 .566 .78 r
.56075 .4664 m .55238 .45657 L .55674 .45924 L p F P
0 g
s
.71 .577 .704 r
.33776 .42891 m .3495 .43832 L .34297 .45086 L p F P
0 g
s
.71 .577 .704 r
.35491 .46081 m .34297 .45086 L .3495 .43832 L p F P
0 g
s
.697 .578 .717 r
.1727 .42112 m .18584 .42853 L .1776 .43549 L p F P
0 g
s
.7 .574 .71 r
.19088 .44684 m .1776 .43549 L .18584 .42853 L p F P
0 g
s
.7 .572 .707 r
.1776 .43549 m .19088 .44684 L .18281 .457 L p F P
0 g
s
.652 .568 .747 r
.45589 .33261 m .46468 .34429 L .45858 .34164 L p F P
0 g
s
.652 .568 .747 r
.45858 .34164 m .4496 .32984 L .45589 .33261 L p F P
0 g
s
.712 .578 .702 r
.40265 .49953 m .41459 .50847 L .40925 .52064 L p F P
0 g
s
.713 .578 .702 r
.42139 .52887 m .40925 .52064 L .41459 .50847 L p F P
0 g
s
.714 .579 .702 r
.44092 .55533 m .45325 .56171 L .44871 .573 L p F P
0 g
s
.715 .58 .702 r
.46124 .57847 m .44871 .573 L .45325 .56171 L p F P
0 g
s
.703 .568 .7 r
.13617 .49306 m .15035 .50955 L .1422 .52538 L p F P
0 g
s
.703 .568 .7 r
.1422 .52538 m .12783 .50883 L .13617 .49306 L p F P
0 g
s
.81 .552 .549 r
.63778 .54159 m .64433 .5462 L .64153 .54248 L p F P
0 g
s
.81 .552 .549 r
.64153 .54248 m .63478 .53769 L .63778 .54159 L p F P
0 g
s
.859 .474 .315 r
.61448 .5183 m .62164 .52463 L .61845 .52109 L p F P
0 g
s
.859 .474 .315 r
.61845 .52109 m .61109 .51461 L .61448 .5183 L p F P
0 g
s
.712 .583 .71 r
.33293 .40879 m .32136 .40206 L .32847 .39195 L p F P
0 g
s
.711 .581 .708 r
.32136 .40206 m .33293 .40879 L .32601 .4202 L p F P
0 g
s
.711 .579 .706 r
.33776 .42891 m .32601 .4202 L .33293 .40879 L p F P
0 g
s
.784 .565 .603 r
.66129 .56538 m .66702 .56784 L .66461 .56411 L p F P
0 g
s
.784 .565 .603 r
.66461 .56411 m .65868 .56143 L .66129 .56538 L p F P
0 g
s
.716 .581 .702 r
.48757 .62152 m .47445 .61904 L .4784 .60844 L p F P
0 g
s
.716 .58 .702 r
.47445 .61904 m .48757 .62152 L .48382 .63184 L p F P
0 g
s
.71 .578 .705 r
.32601 .4202 m .33776 .42891 L .33104 .44113 L p F P
0 g
s
.71 .577 .704 r
.34297 .45086 m .33104 .44113 L .33776 .42891 L p F P
0 g
s
.642 .568 .756 r
.53562 .4354 m .544 .44623 L .53945 .44398 L p F P
0 g
s
.642 .568 .756 r
.53945 .44398 m .53087 .43303 L .53562 .4354 L p F P
0 g
s
.713 .578 .702 r
.42139 .52887 m .43353 .53663 L .42858 .5484 L p F P
0 g
s
.714 .579 .702 r
.44092 .55533 m .42858 .5484 L .43353 .53663 L p F P
0 g
s
.771 .731 .816 r
.39231 .32261 m .40195 .3189 L .39506 .32395 L p F P
0 g
s
.771 .731 .816 r
.39506 .32395 m .38522 .3278 L .39231 .32261 L p F P
0 g
s
.712 .577 .702 r
.39072 .49023 m .40265 .49953 L .39711 .51194 L p F P
0 g
s
.712 .578 .702 r
.40925 .52064 m .39711 .51194 L .40265 .49953 L p F P
0 g
s
.715 .579 .702 r
.44871 .573 m .46124 .57847 L .45689 .58955 L p F P
0 g
s
.715 .58 .702 r
.46962 .59407 m .45689 .58955 L .46124 .57847 L p F P
0 g
s
.56 .558 .808 r
.56908 .47195 m .57705 .48105 L .57308 .47816 L p F P
0 g
s
.56 .558 .808 r
.57308 .47816 m .56491 .46896 L .56908 .47195 L p F P
0 g
s
.717 .581 .701 r
.50375 .6532 m .49004 .65334 L .49359 .64325 L p F P
0 g
s
.717 .581 .701 r
.49004 .65334 m .50375 .6532 L .50039 .66295 L p F P
0 g
s
.794 .561 .583 r
.64994 .55401 m .65607 .55757 L .65347 .55381 L p F P
0 g
s
.794 .561 .583 r
.65347 .55381 m .64713 .55004 L .64994 .55401 L p F P
0 g
s
.716 .58 .702 r
.4784 .60844 m .46547 .60492 L .46962 .59407 L p F P
0 g
s
.716 .58 .702 r
.46547 .60492 m .4784 .60844 L .47445 .61904 L p F P
0 g
s
.715 .58 .702 r
.45689 .58955 m .46962 .59407 L .46547 .60492 L p F P
0 g
s
.657 .566 .741 r
.50513 .39757 m .51371 .40978 L .50858 .40775 L p F P
0 g
s
.657 .566 .741 r
.50858 .40775 m .4998 .39536 L .50513 .39757 L p F P
0 g
s
.702 .571 .705 r
.19626 .47045 m .18281 .457 L .19088 .44684 L p F P
0 g
s
.702 .57 .703 r
.18281 .457 m .19626 .47045 L .18835 .48282 L p F P
0 g
s
.702 .57 .703 r
.18835 .48282 m .17472 .46839 L .18281 .457 L p F P
0 g
s
.711 .577 .702 r
.37878 .48062 m .39072 .49023 L .38498 .50284 L p F P
0 g
s
.712 .577 .702 r
.39711 .51194 m .38498 .50284 L .39072 .49023 L p F P
0 g
s
.703 .569 .702 r
.17472 .46839 m .18835 .48282 L .18043 .49612 L p F P
0 g
s
.703 .569 .702 r
.18043 .49612 m .16661 .48099 L .17472 .46839 L p F P
0 g
s
.65 .579 .761 r
.4471 .32261 m .45589 .33261 L .4496 .32984 L p F P
0 g
s
.65 .579 .761 r
.4496 .32984 m .44061 .32028 L .4471 .32261 L p F P
0 g
s
.705 .532 .652 r
.09721 .42019 m .11074 .41475 L .10173 .40941 L p F P
0 g
s
.705 .532 .652 r
.10173 .40941 m .08803 .41343 L .09721 .42019 L p F P
0 g
s
.721 .205 0 r
.60373 .50755 m .61109 .51461 L .60771 .51115 L p F P
0 g
s
.714 .469 .554 r
.13308 .4157 m .14633 .41446 L .13763 .41342 L p F P
0 g
s
.714 .469 .554 r
.13763 .41342 m .12421 .41235 L .13308 .4157 L p F P
0 g
s
.711 .581 .708 r
.32601 .4202 m .31426 .41253 L .32136 .40206 L p F P
0 g
s
.71 .579 .707 r
.31426 .41253 m .32601 .4202 L .31909 .43186 L p F P
0 g
s
.71 .578 .705 r
.33104 .44113 m .31909 .43186 L .32601 .4202 L p F P
0 g
s
.711 .577 .703 r
.36684 .47077 m .37878 .48062 L .37284 .49337 L p F P
0 g
s
.711 .577 .702 r
.38498 .50284 m .37284 .49337 L .37878 .48062 L p F P
0 g
s
.447 .529 .848 r
.58102 .4843 m .5888 .49274 L .58502 .4896 L p F P
0 g
s
.447 .529 .848 r
.58502 .4896 m .57705 .48105 L .58102 .4843 L p F P
0 g
s
.7 .574 .71 r
.18584 .42853 m .19895 .4379 L .19088 .44684 L p F P
0 g
s
.702 .573 .707 r
.20416 .45903 m .19088 .44684 L .19895 .4379 L p F P
0 g
s
.702 .571 .705 r
.19088 .44684 m .20416 .45903 L .19626 .47045 L p F P
0 g
s
.71 .577 .703 r
.35491 .46081 m .36684 .47077 L .36071 .4836 L p F P
0 g
s
.711 .577 .703 r
.37284 .49337 m .36071 .4836 L .36684 .47077 L p F P
0 g
s
.718 .581 .701 r
.51115 .67101 m .49704 .67276 L .50039 .66295 L p F P
0 g
s
.718 .581 .701 r
.49704 .67276 m .51115 .67101 L .50799 .68044 L p F P
0 g
s
.086 .382 .843 r
.59257 .49619 m .60014 .50395 L .59656 .50063 L p F P
0 g
s
.086 .382 .843 r
.59656 .50063 m .5888 .49274 L .59257 .49619 L p F P
0 g
s
.718 .581 .701 r
.51933 .68648 m .50483 .68994 L .50799 .68044 L p F P
0 g
s
.71 .577 .703 r
.34297 .45086 m .35491 .46081 L .34857 .47362 L p F P
0 g
s
.71 .577 .703 r
.36071 .4836 m .34857 .47362 L .35491 .46081 L p F P
0 g
s
.713 .578 .702 r
.40925 .52064 m .42139 .52887 L .41624 .54094 L p F P
0 g
s
.713 .578 .702 r
.42858 .5484 m .41624 .54094 L .42139 .52887 L p F P
0 g
s
.714 .579 .702 r
.42858 .5484 m .44092 .55533 L .43617 .56694 L p F P
0 g
s
.714 .579 .702 r
.44871 .573 m .43617 .56694 L .44092 .55533 L p F P
0 g
s
.71 .577 .704 r
.33104 .44113 m .34297 .45086 L .33644 .46355 L p F P
0 g
s
.71 .577 .703 r
.34857 .47362 m .33644 .46355 L .34297 .45086 L p F P
0 g
s
.703 .569 .701 r
.16661 .48099 m .18043 .49612 L .17249 .5103 L p F P
0 g
s
.703 .569 .701 r
.17249 .5103 m .15849 .49473 L .16661 .48099 L p F P
0 g
s
.709 .577 .705 r
.31909 .43186 m .33104 .44113 L .32431 .45354 L p F P
0 g
s
.71 .577 .704 r
.33644 .46355 m .32431 .45354 L .33104 .44113 L p F P
0 g
s
.656 .565 .741 r
.49655 .38505 m .50513 .39757 L .4998 .39536 L p F P
0 g
s
.656 .565 .741 r
.4998 .39536 m .49102 .38266 L .49655 .38505 L p F P
0 g
s
.778 .568 .616 r
.67425 .57946 m .67937 .58049 L .67715 .5768 L p F P
0 g
s
.778 .568 .616 r
.67715 .5768 m .67184 .57552 L .67425 .57946 L p F P
0 g
s
.717 .581 .701 r
.49359 .64325 m .48007 .64226 L .48382 .63184 L p F P
0 g
s
.717 .58 .701 r
.48007 .64226 m .49359 .64325 L .49004 .65334 L p F P
0 g
s
.696 .586 .728 r
.18109 .41789 m .19406 .42288 L .18584 .42853 L p F P
0 g
s
.696 .586 .728 r
.18584 .42853 m .1727 .42112 L .18109 .41789 L p F P
0 g
s
.7 .578 .715 r
.19895 .4379 m .18584 .42853 L .19406 .42288 L p F P
0 g
s
.715 .593 .718 r
.32437 .37983 m .33557 .38221 L .32847 .39195 L p F P
0 g
s
.715 .593 .718 r
.32847 .39195 m .31708 .38821 L .32437 .37983 L p F P
0 g
s
.713 .588 .714 r
.31708 .38821 m .32847 .39195 L .32136 .40206 L p F P
0 g
s
.718 .599 .722 r
.33166 .37187 m .34267 .37289 L .33557 .38221 L p F P
0 g
s
.718 .599 .722 r
.33557 .38221 m .32437 .37983 L .33166 .37187 L p F P
0 g
s
.713 .588 .714 r
.32136 .40206 m .30978 .39702 L .31708 .38821 L p F P
0 g
s
.711 .584 .712 r
.30978 .39702 m .32136 .40206 L .31426 .41253 L p F P
0 g
s
.619 .565 .772 r
.54856 .449 m .55674 .45924 L .55238 .45657 L p F P
0 g
s
.619 .565 .772 r
.55238 .45657 m .544 .44623 L .54856 .449 L p F P
0 g
s
.644 .566 .753 r
.52724 .42412 m .53562 .4354 L .53087 .43303 L p F P
0 g
s
.644 .566 .753 r
.53087 .43303 m .5223 .42162 L .52724 .42412 L p F P
0 g
s
.722 .607 .728 r
.33894 .36432 m .34977 .36399 L .34267 .37289 L p F P
0 g
s
.722 .607 .728 r
.34267 .37289 m .33166 .37187 L .33894 .36432 L p F P
0 g
s
.71 .579 .707 r
.31909 .43186 m .30715 .42336 L .31426 .41253 L p F P
0 g
s
.709 .578 .706 r
.30715 .42336 m .31909 .43186 L .31217 .44378 L p F P
0 g
s
.709 .577 .705 r
.32431 .45354 m .31217 .44378 L .31909 .43186 L p F P
0 g
s
.712 .577 .702 r
.39711 .51194 m .40925 .52064 L .40391 .53296 L p F P
0 g
s
.713 .578 .702 r
.41624 .54094 m .40391 .53296 L .40925 .52064 L p F P
0 g
s
.7 .578 .715 r
.19406 .42288 m .207 .43012 L .19895 .4379 L p F P
0 g
s
.702 .575 .71 r
.21204 .44858 m .19895 .4379 L .207 .43012 L p F P
0 g
s
.702 .573 .707 r
.19895 .4379 m .21204 .44858 L .20416 .45903 L p F P
0 g
s
.831 .539 .496 r
.62803 .53229 m .63478 .53769 L .63178 .53394 L p F P
0 g
s
.831 .539 .496 r
.63178 .53394 m .62483 .52837 L .62803 .53229 L p F P
0 g
s
.714 .579 .702 r
.43617 .56694 m .44871 .573 L .44416 .58443 L p F P
0 g
s
.715 .579 .702 r
.45689 .58955 m .44416 .58443 L .44871 .573 L p F P
0 g
s
.702 .705 .85 r
.4226 .31139 m .43162 .31411 L .42493 .31355 L p F P
0 g
s
.702 .705 .85 r
.42493 .31355 m .41572 .31286 L .4226 .31139 L p F P
0 g
s
.711 .584 .712 r
.31426 .41253 m .30249 .40628 L .30978 .39702 L p F P
0 g
s
.71 .582 .71 r
.30249 .40628 m .31426 .41253 L .30715 .42336 L p F P
0 g
s
.686 .612 .768 r
.16808 .41554 m .18109 .41789 L .1727 .42112 L p F P
0 g
s
.686 .612 .768 r
.1727 .42112 m .15954 .41629 L .16808 .41554 L p F P
0 g
s
.728 .618 .735 r
.34623 .35717 m .35686 .35557 L .34977 .36399 L p F P
0 g
s
.728 .618 .735 r
.34977 .36399 m .33894 .36432 L .34623 .35717 L p F P
0 g
s
.777 .782 .857 r
.3994 .31815 m .40883 .31527 L .40195 .3189 L p F P
0 g
s
.777 .782 .857 r
.40195 .3189 m .39231 .32261 L .3994 .31815 L p F P
0 g
s
.655 .564 .741 r
.48796 .37236 m .49655 .38505 L .49102 .38266 L p F P
0 g
s
.655 .564 .741 r
.49102 .38266 m .48224 .36975 L .48796 .37236 L p F P
0 g
s
.716 .58 .702 r
.48382 .63184 m .4705 .62976 L .47445 .61904 L p F P
0 g
s
.716 .58 .701 r
.4705 .62976 m .48382 .63184 L .48007 .64226 L p F P
0 g
s
.713 .578 .702 r
.41624 .54094 m .42858 .5484 L .42363 .56032 L p F P
0 g
s
.714 .579 .702 r
.43617 .56694 m .42363 .56032 L .42858 .5484 L p F P
0 g
s
.712 .577 .702 r
.38498 .50284 m .39711 .51194 L .39157 .5245 L p F P
0 g
s
.712 .577 .702 r
.40391 .53296 m .39157 .5245 L .39711 .51194 L p F P
0 g
s
.703 .569 .7 r
.15849 .49473 m .17249 .5103 L .16455 .52533 L p F P
0 g
s
.703 .569 .7 r
.16455 .52533 m .15035 .50955 L .15849 .49473 L p F P
0 g
s
.715 .579 .702 r
.44416 .58443 m .45689 .58955 L .45254 .60077 L p F P
0 g
s
.715 .58 .702 r
.46547 .60492 m .45254 .60077 L .45689 .58955 L p F P
0 g
s
.71 .582 .71 r
.30715 .42336 m .29519 .41599 L .30249 .40628 L p F P
0 g
s
.709 .579 .708 r
.29519 .41599 m .30715 .42336 L .30003 .43454 L p F P
0 g
s
.709 .578 .706 r
.31217 .44378 m .30003 .43454 L .30715 .42336 L p F P
0 g
s
.717 .581 .701 r
.50039 .66295 m .48648 .66352 L .49004 .65334 L p F P
0 g
s
.717 .581 .701 r
.48648 .66352 m .50039 .66295 L .49704 .67276 L p F P
0 g
s
.703 .572 .705 r
.21743 .47161 m .20416 .45903 L .21204 .44858 L p F P
0 g
s
.703 .571 .704 r
.20416 .45903 m .21743 .47161 L .20971 .48393 L p F P
0 g
s
.703 .571 .704 r
.20971 .48393 m .19626 .47045 L .20416 .45903 L p F P
0 g
s
.711 .577 .702 r
.37284 .49337 m .38498 .50284 L .37923 .51558 L p F P
0 g
s
.712 .577 .702 r
.39157 .5245 m .37923 .51558 L .38498 .50284 L p F P
0 g
s
.716 .58 .702 r
.47445 .61904 m .46132 .61591 L .46547 .60492 L p F P
0 g
s
.716 .58 .701 r
.46132 .61591 m .47445 .61904 L .4705 .62976 L p F P
0 g
s
.735 .633 .746 r
.35352 .35041 m .36396 .34768 L .35686 .35557 L p F P
0 g
s
.735 .633 .746 r
.35686 .35557 m .34623 .35717 L .35352 .35041 L p F P
0 g
s
.715 .579 .702 r
.45254 .60077 m .46547 .60492 L .46132 .61591 L p F P
0 g
s
.709 .576 .704 r
.31217 .44378 m .32431 .45354 L .31758 .46613 L p F P
0 g
s
.709 .576 .703 r
.32431 .45354 m .33644 .46355 L .32991 .47639 L p F P
0 g
s
.709 .576 .703 r
.32991 .47639 m .31758 .46613 L .32431 .45354 L p F P
0 g
s
.661 .607 .784 r
.4383 .31514 m .4471 .32261 L .44061 .32028 L p F P
0 g
s
.661 .607 .784 r
.44061 .32028 m .43162 .31411 L .4383 .31514 L p F P
0 g
s
.71 .576 .703 r
.33644 .46355 m .34857 .47362 L .34224 .48658 L p F P
0 g
s
.71 .576 .703 r
.34224 .48658 m .32991 .47639 L .33644 .46355 L p F P
0 g
s
.708 .577 .705 r
.30003 .43454 m .31217 .44378 L .30525 .45595 L p F P
0 g
s
.709 .576 .704 r
.31758 .46613 m .30525 .45595 L .31217 .44378 L p F P
0 g
s
.702 .575 .71 r
.207 .43012 m .21992 .43909 L .21204 .44858 L p F P
0 g
s
.703 .574 .707 r
.22513 .46005 m .21204 .44858 L .21992 .43909 L p F P
0 g
s
.703 .572 .705 r
.21204 .44858 m .22513 .46005 L .21743 .47161 L p F P
0 g
s
.711 .576 .702 r
.36071 .4836 m .37284 .49337 L .3669 .50625 L p F P
0 g
s
.711 .577 .702 r
.37923 .51558 m .3669 .50625 L .37284 .49337 L p F P
0 g
s
.71 .576 .703 r
.34857 .47362 m .36071 .4836 L .35457 .49656 L p F P
0 g
s
.71 .576 .703 r
.35457 .49656 m .34224 .48658 L .34857 .47362 L p F P
0 g
s
.703 .57 .702 r
.19626 .47045 m .20971 .48393 L .20199 .49698 L p F P
0 g
s
.703 .57 .702 r
.20199 .49698 m .18835 .48282 L .19626 .47045 L p F P
0 g
s
.711 .576 .702 r
.3669 .50625 m .35457 .49656 L .36071 .4836 L p F P
0 g
s
.653 .563 .741 r
.47937 .35966 m .48796 .37236 L .48224 .36975 L p F P
0 g
s
.653 .563 .741 r
.48224 .36975 m .47346 .35685 L .47937 .35966 L p F P
0 g
s
.581 .558 .794 r
.5611 .46233 m .56908 .47195 L .56491 .46896 L p F P
0 g
s
.581 .558 .794 r
.56491 .46896 m .55674 .45924 L .5611 .46233 L p F P
0 g
s
.785 .566 .604 r
.6639 .56942 m .66943 .57165 L .66702 .56784 L p F P
0 g
s
.785 .566 .604 r
.66702 .56784 m .66129 .56538 L .6639 .56942 L p F P
0 g
s
.709 .579 .708 r
.30003 .43454 m .28789 .42615 L .29519 .41599 L p F P
0 g
s
.708 .578 .707 r
.28789 .42615 m .30003 .43454 L .29292 .44608 L p F P
0 g
s
.708 .577 .705 r
.30525 .45595 m .29292 .44608 L .30003 .43454 L p F P
0 g
s
.809 .556 .556 r
.64079 .54562 m .64713 .55004 L .64433 .5462 L p F P
0 g
s
.809 .556 .556 r
.64433 .5462 m .63778 .54159 L .64079 .54562 L p F P
0 g
s
.718 .581 .701 r
.50799 .68044 m .49368 .68266 L .49704 .67276 L p F P
0 g
s
.717 .581 .701 r
.49368 .68266 m .50799 .68044 L .50483 .68994 L p F P
0 g
s
.645 .565 .75 r
.51885 .41241 m .52724 .42412 L .5223 .42162 L p F P
0 g
s
.645 .565 .75 r
.5223 .42162 m .51371 .40978 L .51885 .41241 L p F P
0 g
s
.713 .578 .702 r
.40391 .53296 m .41624 .54094 L .4111 .55314 L p F P
0 g
s
.713 .578 .702 r
.42363 .56032 m .4111 .55314 L .41624 .54094 L p F P
0 g
s
.7 .585 .722 r
.20227 .4183 m .21504 .42341 L .207 .43012 L p F P
0 g
s
.7 .585 .722 r
.207 .43012 m .19406 .42288 L .20227 .4183 L p F P
0 g
s
.702 .579 .713 r
.21992 .43909 m .207 .43012 L .21504 .42341 L p F P
0 g
s
.858 .504 .381 r
.61787 .52219 m .62483 .52837 L .62164 .52463 L p F P
0 g
s
.858 .504 .381 r
.62164 .52463 m .61448 .5183 L .61787 .52219 L p F P
0 g
s
.714 .578 .702 r
.42363 .56032 m .43617 .56694 L .43142 .5787 L p F P
0 g
s
.714 .579 .702 r
.44416 .58443 m .43142 .5787 L .43617 .56694 L p F P
0 g
s
.702 .579 .713 r
.21504 .42341 m .22779 .43053 L .21992 .43909 L p F P
0 g
s
.704 .576 .709 r
.23283 .44924 m .21992 .43909 L .22779 .43053 L p F P
0 g
s
.703 .574 .707 r
.21992 .43909 m .23283 .44924 L .22513 .46005 L p F P
0 g
s
.745 .655 .761 r
.3608 .34401 m .37105 .34038 L .36396 .34768 L p F P
0 g
s
.745 .655 .761 r
.36396 .34768 m .35352 .35041 L .3608 .34401 L p F P
0 g
s
.703 .57 .702 r
.18835 .48282 m .20199 .49698 L .19426 .51076 L p F P
0 g
s
.703 .57 .702 r
.19426 .51076 m .18043 .49612 L .18835 .48282 L p F P
0 g
s
.795 .563 .586 r
.65274 .55807 m .65868 .56143 L .65607 .55757 L p F P
0 g
s
.795 .563 .586 r
.65607 .55757 m .64994 .55401 L .65274 .55807 L p F P
0 g
s
.651 .564 .744 r
.47078 .34723 m .47937 .35966 L .47346 .35685 L p F P
0 g
s
.651 .564 .744 r
.47346 .35685 m .46468 .34429 L .47078 .34723 L p F P
0 g
s
.46 0 0 r
.15954 .41629 m .14633 .41446 L .15504 .41596 L p F P
0 g
s
.46 0 0 r
.15504 .41596 m .16808 .41554 L .15954 .41629 L p F P
0 g
s
.71 .586 .714 r
.2907 .40178 m .30249 .40628 L .29519 .41599 L p F P
0 g
s
.71 .586 .714 r
.29519 .41599 m .28322 .41012 L .2907 .40178 L p F P
0 g
s
.709 .582 .711 r
.28322 .41012 m .29519 .41599 L .28789 .42615 L p F P
0 g
s
.709 .582 .711 r
.28789 .42615 m .27573 .41897 L .28322 .41012 L p F P
0 g
s
.708 .579 .709 r
.27573 .41897 m .28789 .42615 L .28058 .43677 L p F P
0 g
s
.708 .578 .707 r
.29292 .44608 m .28058 .43677 L .28789 .42615 L p F P
0 g
s
.625 .563 .765 r
.54037 .43829 m .54856 .449 L .544 .44623 L p F P
0 g
s
.625 .563 .765 r
.544 .44623 m .53562 .4354 L .54037 .43829 L p F P
0 g
s
.717 .58 .701 r
.49004 .65334 m .47632 .65277 L .48007 .64226 L p F P
0 g
s
.717 .58 .701 r
.47632 .65277 m .49004 .65334 L .48648 .66352 L p F P
0 g
s
.712 .59 .718 r
.29818 .39394 m .30978 .39702 L .30249 .40628 L p F P
0 g
s
.712 .59 .718 r
.30249 .40628 m .2907 .40178 L .29818 .39394 L p F P
0 g
s
.707 .576 .706 r
.28058 .43677 m .29292 .44608 L .2858 .45796 L p F P
0 g
s
.708 .576 .704 r
.29292 .44608 m .30525 .45595 L .29832 .46839 L p F P
0 g
s
.708 .576 .704 r
.29832 .46839 m .2858 .45796 L .29292 .44608 L p F P
0 g
s
.706 .521 .636 r
.11977 .41979 m .13308 .4157 L .12421 .41235 L p F P
0 g
s
.706 .521 .636 r
.12421 .41235 m .11074 .41475 L .11977 .41979 L p F P
0 g
s
.712 .577 .702 r
.39157 .5245 m .40391 .53296 L .39856 .54543 L p F P
0 g
s
.713 .578 .702 r
.4111 .55314 m .39856 .54543 L .40391 .53296 L p F P
0 g
s
.708 .575 .704 r
.30525 .45595 m .31758 .46613 L .31084 .47893 L p F P
0 g
s
.708 .575 .704 r
.31084 .47893 m .29832 .46839 L .30525 .45595 L p F P
0 g
s
.509 .542 .825 r
.57325 .47531 m .58102 .4843 L .57705 .48105 L p F P
0 g
s
.509 .542 .825 r
.57705 .48105 m .56908 .47195 L .57325 .47531 L p F P
0 g
s
.704 .576 .709 r
.22779 .43053 m .24052 .4392 L .23283 .44924 L p F P
0 g
s
.705 .575 .706 r
.24574 .46013 m .23283 .44924 L .24052 .4392 L p F P
0 g
s
.705 .573 .705 r
.23283 .44924 m .24574 .46013 L .23822 .47191 L p F P
0 g
s
.705 .573 .705 r
.23822 .47191 m .22513 .46005 L .23283 .44924 L p F P
0 g
s
.708 .579 .709 r
.28058 .43677 m .26824 .42839 L .27573 .41897 L p F P
0 g
s
.707 .577 .707 r
.26824 .42839 m .28058 .43677 L .27327 .44785 L p F P
0 g
s
.707 .576 .706 r
.2858 .45796 m .27327 .44785 L .28058 .43677 L p F P
0 g
s
.696 .6 .745 r
.18947 .41557 m .20227 .4183 L .19406 .42288 L p F P
0 g
s
.696 .6 .745 r
.19406 .42288 m .18109 .41789 L .18947 .41557 L p F P
0 g
s
.703 .568 .7 r
.15035 .50955 m .16455 .52533 L .15659 .54117 L p F P
0 g
s
.703 .568 .7 r
.15659 .54117 m .1422 .52538 L .15035 .50955 L p F P
0 g
s
.704 .572 .704 r
.22513 .46005 m .23822 .47191 L .23071 .48427 L p F P
0 g
s
.704 .572 .704 r
.23071 .48427 m .21743 .47161 L .22513 .46005 L p F P
0 g
s
.715 .596 .722 r
.30566 .38655 m .31708 .38821 L .30978 .39702 L p F P
0 g
s
.715 .596 .722 r
.30978 .39702 m .29818 .39394 L .30566 .38655 L p F P
0 g
s
.714 .579 .702 r
.43142 .5787 m .44416 .58443 L .43961 .596 L p F P
0 g
s
.715 .579 .702 r
.45254 .60077 m .43961 .596 L .44416 .58443 L p F P
0 g
s
.709 .575 .703 r
.31758 .46613 m .32991 .47639 L .32337 .4894 L p F P
0 g
s
.709 .575 .703 r
.32337 .4894 m .31084 .47893 L .31758 .46613 L p F P
0 g
s
.704 .579 .712 r
.23565 .42284 m .24821 .4299 L .24052 .4392 L p F P
0 g
s
.704 .579 .712 r
.24052 .4392 m .22779 .43053 L .23565 .42284 L p F P
0 g
s
.705 .577 .708 r
.25324 .44896 m .24052 .4392 L .24821 .4299 L p F P
0 g
s
.705 .575 .706 r
.24052 .4392 m .25324 .44896 L .24574 .46013 L p F P
0 g
s
.832 .36 .052 r
.60731 .51137 m .61448 .5183 L .61109 .51461 L p F P
0 g
s
.832 .36 .052 r
.61109 .51461 m .60373 .50755 L .60731 .51137 L p F P
0 g
s
.778 .569 .617 r
.67667 .58346 m .68158 .58424 L .67937 .58049 L p F P
0 g
s
.778 .569 .617 r
.67937 .58049 m .67425 .57946 L .67667 .58346 L p F P
0 g
s
.706 .579 .71 r
.25588 .42131 m .26824 .42839 L .26074 .43838 L p F P
0 g
s
.706 .579 .71 r
.26074 .43838 m .24821 .4299 L .25588 .42131 L p F P
0 g
s
.707 .577 .707 r
.27327 .44785 m .26074 .43838 L .26824 .42839 L p F P
0 g
s
.705 .577 .708 r
.24821 .4299 m .26074 .43838 L .25324 .44896 L p F P
0 g
s
.706 .576 .706 r
.26074 .43838 m .27327 .44785 L .26596 .4594 L p F P
0 g
s
.706 .576 .706 r
.26596 .4594 m .25324 .44896 L .26074 .43838 L p F P
0 g
s
.703 .584 .719 r
.22308 .41761 m .23565 .42284 L .22779 .43053 L p F P
0 g
s
.703 .584 .719 r
.22779 .43053 m .21504 .42341 L .22308 .41761 L p F P
0 g
s
.707 .575 .705 r
.27327 .44785 m .2858 .45796 L .27867 .47019 L p F P
0 g
s
.707 .575 .705 r
.27867 .47019 m .26596 .4594 L .27327 .44785 L p F P
0 g
s
.65 .567 .749 r
.46219 .33548 m .47078 .34723 L .46468 .34429 L p F P
0 g
s
.65 .567 .749 r
.46468 .34429 m .45589 .33261 L .46219 .33548 L p F P
0 g
s
.712 .577 .702 r
.37923 .51558 m .39157 .5245 L .38602 .53719 L p F P
0 g
s
.712 .577 .702 r
.39856 .54543 m .38602 .53719 L .39157 .5245 L p F P
0 g
s
.646 .564 .747 r
.51046 .40033 m .51885 .41241 L .51371 .40978 L p F P
0 g
s
.646 .564 .747 r
.51371 .40978 m .50513 .39757 L .51046 .40033 L p F P
0 g
s
.709 .576 .703 r
.32991 .47639 m .34224 .48658 L .33589 .49967 L p F P
0 g
s
.709 .576 .703 r
.33589 .49967 m .32337 .4894 L .32991 .47639 L p F P
0 g
s
.33 .483 .861 r
.585 .48786 m .59257 .49619 L .5888 .49274 L p F P
0 g
s
.33 .483 .861 r
.5888 .49274 m .58102 .4843 L .585 .48786 L p F P
0 g
s
.706 .574 .705 r
.25324 .44896 m .26596 .4594 L .25864 .4714 L p F P
0 g
s
.706 .574 .705 r
.25864 .4714 m .24574 .46013 L .25324 .44896 L p F P
0 g
s
.704 .571 .703 r
.21743 .47161 m .23071 .48427 L .22318 .49722 L p F P
0 g
s
.704 .571 .703 r
.22318 .49722 m .20971 .48393 L .21743 .47161 L p F P
0 g
s
.713 .578 .702 r
.4111 .55314 m .42363 .56032 L .41869 .57239 L p F P
0 g
s
.714 .578 .702 r
.43142 .5787 m .41869 .57239 L .42363 .56032 L p F P
0 g
s
.707 .583 .713 r
.26356 .41338 m .27573 .41897 L .26824 .42839 L p F P
0 g
s
.707 .583 .713 r
.26824 .42839 m .25588 .42131 L .26356 .41338 L p F P
0 g
s
.716 .58 .701 r
.48007 .64226 m .46655 .64058 L .4705 .62976 L p F P
0 g
s
.716 .58 .701 r
.46655 .64058 m .48007 .64226 L .47632 .65277 L p F P
0 g
s
.758 .685 .781 r
.36809 .33797 m .37814 .33374 L .37105 .34038 L p F P
0 g
s
.758 .685 .781 r
.37105 .34038 m .3608 .34401 L .36809 .33797 L p F P
0 g
s
0 .179 .696 r
.60014 .50395 m .59257 .49619 L .59636 .49991 L p F P
0 g
s
.704 .569 .701 r
.18043 .49612 m .19426 .51076 L .18652 .52523 L p F P
0 g
s
.704 .569 .701 r
.18652 .52523 m .17249 .5103 L .18043 .49612 L p F P
0 g
s
.718 .604 .728 r
.31314 .37954 m .32437 .37983 L .31708 .38821 L p F P
0 g
s
.718 .604 .728 r
.31708 .38821 m .30566 .38655 L .31314 .37954 L p F P
0 g
s
.763 .788 .873 r
.40649 .3144 m .41572 .31286 L .40883 .31527 L p F P
0 g
s
.763 .788 .873 r
.40883 .31527 m .3994 .31815 L .40649 .3144 L p F P
0 g
s
.71 .576 .702 r
.34224 .48658 m .35457 .49656 L .34842 .50965 L p F P
0 g
s
.71 .576 .702 r
.34842 .50965 m .33589 .49967 L .34224 .48658 L p F P
0 g
s
.715 .579 .702 r
.43961 .596 m .45254 .60077 L .44819 .61212 L p F P
0 g
s
.715 .579 .702 r
.46132 .61591 m .44819 .61212 L .45254 .60077 L p F P
0 g
s
.711 .576 .702 r
.3669 .50625 m .37923 .51558 L .37349 .52845 L p F P
0 g
s
.712 .577 .702 r
.38602 .53719 m .37349 .52845 L .37923 .51558 L p F P
0 g
s
.707 .575 .704 r
.2858 .45796 m .29832 .46839 L .29139 .4811 L p F P
0 g
s
.707 .575 .704 r
.29139 .4811 m .27867 .47019 L .2858 .45796 L p F P
0 g
s
.706 .583 .716 r
.24351 .41593 m .25588 .42131 L .24821 .4299 L p F P
0 g
s
.706 .583 .716 r
.24821 .4299 m .23565 .42284 L .24351 .41593 L p F P
0 g
s
.717 .581 .701 r
.49704 .67276 m .48293 .67378 L .48648 .66352 L p F P
0 g
s
.717 .58 .701 r
.48293 .67378 m .49704 .67276 L .49368 .68266 L p F P
0 g
s
.71 .576 .702 r
.35457 .49656 m .3669 .50625 L .36095 .51926 L p F P
0 g
s
.71 .576 .702 r
.36095 .51926 m .34842 .50965 L .35457 .49656 L p F P
0 g
s
.705 .573 .704 r
.24574 .46013 m .25864 .4714 L .25132 .48387 L p F P
0 g
s
.705 .573 .704 r
.25132 .48387 m .23822 .47191 L .24574 .46013 L p F P
0 g
s
.711 .576 .702 r
.37349 .52845 m .36095 .51926 L .3669 .50625 L p F P
0 g
s
.709 .587 .717 r
.27123 .40606 m .28322 .41012 L .27573 .41897 L p F P
0 g
s
.709 .587 .717 r
.27573 .41897 m .26356 .41338 L .27123 .40606 L p F P
0 g
s
.716 .58 .701 r
.4705 .62976 m .45717 .627 L .46132 .61591 L p F P
0 g
s
.716 .58 .701 r
.45717 .627 m .4705 .62976 L .46655 .64058 L p F P
0 g
s
.715 .579 .701 r
.44819 .61212 m .46132 .61591 L .45717 .627 L p F P
0 g
s
.706 .574 .704 r
.26596 .4594 m .27867 .47019 L .27155 .48278 L p F P
0 g
s
.706 .574 .704 r
.27155 .48278 m .25864 .4714 L .26596 .4594 L p F P
0 g
s
.708 .575 .703 r
.29832 .46839 m .31084 .47893 L .30411 .49194 L p F P
0 g
s
.708 .575 .703 r
.30411 .49194 m .29139 .4811 L .29832 .46839 L p F P
0 g
s
.702 .595 .733 r
.21048 .41455 m .22308 .41761 L .21504 .42341 L p F P
0 g
s
.702 .595 .733 r
.21504 .42341 m .20227 .4183 L .21048 .41455 L p F P
0 g
s
.704 .571 .702 r
.20971 .48393 m .22318 .49722 L .21565 .51075 L p F P
0 g
s
.704 .571 .702 r
.21565 .51075 m .20199 .49698 L .20971 .48393 L p F P
0 g
s
.829 .546 .51 r
.63123 .53635 m .63778 .54159 L .63478 .53769 L p F P
0 g
s
.829 .546 .51 r
.63478 .53769 m .62803 .53229 L .63123 .53635 L p F P
0 g
s
.717 .581 .701 r
.50483 .68994 m .49033 .69262 L .49368 .68266 L p F P
0 g
s
.723 .614 .735 r
.32062 .37288 m .33166 .37187 L .32437 .37983 L p F P
0 g
s
.723 .614 .735 r
.32437 .37983 m .31314 .37954 L .32062 .37288 L p F P
0 g
s
.596 .558 .782 r
.55311 .4522 m .5611 .46233 L .55674 .45924 L p F P
0 g
s
.596 .558 .782 r
.55674 .45924 m .54856 .449 L .55311 .4522 L p F P
0 g
s
.712 .577 .702 r
.39856 .54543 m .4111 .55314 L .40595 .56549 L p F P
0 g
s
.713 .578 .702 r
.41869 .57239 m .40595 .56549 L .4111 .55314 L p F P
0 g
s
.705 .572 .703 r
.23822 .47191 m .25132 .48387 L .24399 .49679 L p F P
0 g
s
.705 .572 .703 r
.24399 .49679 m .23071 .48427 L .23822 .47191 L p F P
0 g
s
.711 .593 .722 r
.2789 .39925 m .2907 .40178 L .28322 .41012 L p F P
0 g
s
.711 .593 .722 r
.28322 .41012 m .27123 .40606 L .2789 .39925 L p F P
0 g
s
.647 .563 .746 r
.50207 .38796 m .51046 .40033 L .50513 .39757 L p F P
0 g
s
.647 .563 .746 r
.50513 .39757 m .49655 .38505 L .50207 .38796 L p F P
0 g
s
.63 .562 .76 r
.53218 .42711 m .54037 .43829 L .53562 .4354 L p F P
0 g
s
.63 .562 .76 r
.53562 .4354 m .52724 .42412 L .53218 .42711 L p F P
0 g
s
.714 .578 .702 r
.41869 .57239 m .43142 .5787 L .42667 .5906 L p F P
0 g
s
.714 .579 .702 r
.43961 .596 m .42667 .5906 L .43142 .5787 L p F P
0 g
s
.707 .589 .721 r
.25136 .40969 m .26356 .41338 L .25588 .42131 L p F P
0 g
s
.707 .589 .721 r
.25588 .42131 m .24351 .41593 L .25136 .40969 L p F P
0 g
s
.667 .678 .85 r
.17663 .41534 m .18947 .41557 L .18109 .41789 L p F P
0 g
s
.667 .678 .85 r
.18109 .41789 m .16808 .41554 L .17663 .41534 L p F P
0 g
s
.652 .576 .757 r
.4536 .32501 m .46219 .33548 L .45589 .33261 L p F P
0 g
s
.652 .576 .757 r
.45589 .33261 m .4471 .32261 L .4536 .32501 L p F P
0 g
s
.709 .575 .703 r
.31084 .47893 m .32337 .4894 L .31683 .50257 L p F P
0 g
s
.709 .575 .703 r
.31683 .50257 m .30411 .49194 L .31084 .47893 L p F P
0 g
s
.705 .591 .726 r
.23111 .41256 m .24351 .41593 L .23565 .42284 L p F P
0 g
s
.705 .591 .726 r
.23565 .42284 m .22308 .41761 L .23111 .41256 L p F P
0 g
s
.707 .574 .703 r
.27867 .47019 m .29139 .4811 L .28445 .49408 L p F P
0 g
s
.707 .574 .703 r
.28445 .49408 m .27155 .48278 L .27867 .47019 L p F P
0 g
s
.702 .536 .66 r
.08364 .42813 m .09721 .42019 L .08803 .41343 L p F P
0 g
s
.702 .536 .66 r
.08803 .41343 m .07428 .42065 L .08364 .42813 L p F P
0 g
s
.772 .724 .808 r
.37537 .33228 m .38522 .3278 L .37814 .33374 L p F P
0 g
s
.772 .724 .808 r
.37814 .33374 m .36809 .33797 L .37537 .33228 L p F P
0 g
s
.706 .573 .703 r
.25864 .4714 m .27155 .48278 L .26441 .49573 L p F P
0 g
s
.706 .573 .703 r
.26441 .49573 m .25132 .48387 L .25864 .4714 L p F P
0 g
s
.717 .58 .701 r
.48648 .66352 m .47256 .66337 L .47632 .65277 L p F P
0 g
s
.716 .58 .701 r
.47256 .66337 m .48648 .66352 L .48293 .67378 L p F P
0 g
s
.704 .569 .7 r
.17249 .5103 m .18652 .52523 L .17876 .54039 L p F P
0 g
s
.704 .569 .7 r
.17876 .54039 m .16455 .52533 L .17249 .5103 L p F P
0 g
s
.786 .568 .605 r
.66651 .57352 m .67184 .57552 L .66943 .57165 L p F P
0 g
s
.786 .568 .605 r
.66943 .57165 m .6639 .56942 L .66651 .57352 L p F P
0 g
s
.712 .577 .702 r
.38602 .53719 m .39856 .54543 L .39321 .55802 L p F P
0 g
s
.712 .577 .702 r
.40595 .56549 m .39321 .55802 L .39856 .54543 L p F P
0 g
s
.709 .575 .702 r
.32337 .4894 m .33589 .49967 L .32955 .51291 L p F P
0 g
s
.709 .575 .702 r
.32955 .51291 m .31683 .50257 L .32337 .4894 L p F P
0 g
s
.688 .652 .809 r
.42949 .31062 m .4383 .31514 L .43162 .31411 L p F P
0 g
s
.688 .652 .809 r
.43162 .31411 m .4226 .31139 L .42949 .31062 L p F P
0 g
s
.73 .628 .745 r
.3281 .3665 m .33894 .36432 L .33166 .37187 L p F P
0 g
s
.73 .628 .745 r
.33166 .37187 m .32062 .37288 L .3281 .3665 L p F P
0 g
s
.704 .57 .701 r
.20199 .49698 m .21565 .51075 L .2081 .52485 L p F P
0 g
s
.704 .57 .701 r
.2081 .52485 m .19426 .51076 L .20199 .49698 L p F P
0 g
s
.714 .601 .728 r
.28656 .39289 m .29818 .39394 L .2907 .40178 L p F P
0 g
s
.714 .601 .728 r
.2907 .40178 m .2789 .39925 L .28656 .39289 L p F P
0 g
s
.705 .572 .702 r
.23071 .48427 m .24399 .49679 L .23665 .51018 L p F P
0 g
s
.705 .572 .702 r
.23665 .51018 m .22318 .49722 L .23071 .48427 L p F P
0 g
s
.714 .578 .701 r
.42667 .5906 m .43961 .596 L .43506 .60769 L p F P
0 g
s
.715 .579 .702 r
.44819 .61212 m .43506 .60769 L .43961 .596 L p F P
0 g
s
.809 .559 .561 r
.64379 .54977 m .64994 .55401 L .64713 .55004 L p F P
0 g
s
.809 .559 .561 r
.64713 .55004 m .64079 .54562 L .64379 .54977 L p F P
0 g
s
.704 .495 .603 r
.14195 .41899 m .15504 .41596 L .14633 .41446 L p F P
0 g
s
.704 .495 .603 r
.14633 .41446 m .13308 .4157 L .14195 .41899 L p F P
0 g
s
.647 .562 .745 r
.49368 .37539 m .50207 .38796 L .49655 .38505 L p F P
0 g
s
.647 .562 .745 r
.49655 .38505 m .48796 .37236 L .49368 .37539 L p F P
0 g
s
.71 .575 .702 r
.33589 .49967 m .34842 .50965 L .34228 .52287 L p F P
0 g
s
.71 .575 .702 r
.34228 .52287 m .32955 .51291 L .33589 .49967 L p F P
0 g
s
.708 .574 .703 r
.29139 .4811 m .30411 .49194 L .29737 .50517 L p F P
0 g
s
.708 .574 .703 r
.29737 .50517 m .28445 .49408 L .29139 .4811 L p F P
0 g
s
.711 .577 .702 r
.37349 .52845 m .38602 .53719 L .38047 .55001 L p F P
0 g
s
.712 .577 .702 r
.39321 .55802 m .38047 .55001 L .38602 .53719 L p F P
0 g
s
.795 .564 .588 r
.65555 .56223 m .66129 .56538 L .65868 .56143 L p F P
0 g
s
.795 .564 .588 r
.65868 .56143 m .65274 .55807 L .65555 .56223 L p F P
0 g
s
.546 .547 .807 r
.56546 .46579 m .57325 .47531 L .56908 .47195 L p F P
0 g
s
.546 .547 .807 r
.56908 .47195 m .5611 .46233 L .56546 .46579 L p F P
0 g
s
.71 .596 .728 r
.25921 .404 m .27123 .40606 L .26356 .41338 L p F P
0 g
s
.71 .596 .728 r
.26356 .41338 m .25136 .40969 L .25921 .404 L p F P
0 g
s
.713 .578 .702 r
.40595 .56549 m .41869 .57239 L .41373 .58458 L p F P
0 g
s
.714 .578 .702 r
.42667 .5906 m .41373 .58458 L .41869 .57239 L p F P
0 g
s
.855 .521 .42 r
.62127 .52626 m .62803 .53229 L .62483 .52837 L p F P
0 g
s
.855 .521 .42 r
.62483 .52837 m .61787 .52219 L .62127 .52626 L p F P
0 g
s
.716 .58 .701 r
.47632 .65277 m .46259 .65149 L .46655 .64058 L p F P
0 g
s
.716 .58 .701 r
.46259 .65149 m .47632 .65277 L .47256 .66337 L p F P
0 g
s
.71 .576 .702 r
.34842 .50965 m .36095 .51926 L .35501 .5324 L p F P
0 g
s
.71 .576 .702 r
.35501 .5324 m .34228 .52287 L .34842 .50965 L p F P
0 g
s
.711 .576 .702 r
.36095 .51926 m .37349 .52845 L .36774 .54145 L p F P
0 g
s
.711 .577 .702 r
.38047 .55001 m .36774 .54145 L .37349 .52845 L p F P
0 g
s
.697 .628 .775 r
.19785 .41381 m .21048 .41455 L .20227 .4183 L p F P
0 g
s
.697 .628 .775 r
.20227 .4183 m .18947 .41557 L .19785 .41381 L p F P
0 g
s
.711 .576 .702 r
.36774 .54145 m .35501 .5324 L .36095 .51926 L p F P
0 g
s
.706 .573 .702 r
.25132 .48387 m .26441 .49573 L .25728 .50904 L p F P
0 g
s
.706 .573 .702 r
.25728 .50904 m .24399 .49679 L .25132 .48387 L p F P
0 g
s
.714 .579 .701 r
.43506 .60769 m .44819 .61212 L .44384 .62358 L p F P
0 g
s
.715 .579 .701 r
.45717 .627 m .44384 .62358 L .44819 .61212 L p F P
0 g
s
.707 .573 .703 r
.27155 .48278 m .28445 .49408 L .27751 .50735 L p F P
0 g
s
.707 .573 .703 r
.27751 .50735 m .26441 .49573 L .27155 .48278 L p F P
0 g
s
.717 .58 .701 r
.49368 .68266 m .47937 .68412 L .48293 .67378 L p F P
0 g
s
.717 .58 .701 r
.47937 .68412 m .49368 .68266 L .49033 .69262 L p F P
0 g
s
.633 .561 .756 r
.52399 .41551 m .53218 .42711 L .52724 .42412 L p F P
0 g
s
.633 .561 .756 r
.52724 .42412 m .51885 .41241 L .52399 .41551 L p F P
0 g
s
.779 .57 .617 r
.67909 .58751 m .6838 .58804 L .68158 .58424 L p F P
0 g
s
.779 .57 .617 r
.68158 .58424 m .67667 .58346 L .67909 .58751 L p F P
0 g
s
.716 .58 .701 r
.46655 .64058 m .45302 .63821 L .45717 .627 L p F P
0 g
s
.715 .579 .701 r
.45302 .63821 m .46655 .64058 L .46259 .65149 L p F P
0 g
s
.715 .579 .701 r
.44384 .62358 m .45717 .627 L .45302 .63821 L p F P
0 g
s
.708 .574 .702 r
.30411 .49194 m .31683 .50257 L .31028 .51593 L p F P
0 g
s
.708 .574 .702 r
.31028 .51593 m .29737 .50517 L .30411 .49194 L p F P
0 g
s
.739 .647 .758 r
.33558 .36036 m .34623 .35717 L .33894 .36432 L p F P
0 g
s
.739 .647 .758 r
.33894 .36432 m .3281 .3665 L .33558 .36036 L p F P
0 g
s
.647 .562 .745 r
.48529 .36278 m .49368 .37539 L .48796 .37236 L p F P
0 g
s
.647 .562 .745 r
.48796 .37236 m .47937 .35966 L .48529 .36278 L p F P
0 g
s
.719 .611 .736 r
.29423 .38688 m .30566 .38655 L .29818 .39394 L p F P
0 g
s
.719 .611 .736 r
.29818 .39394 m .28656 .39289 L .29423 .38688 L p F P
0 g
s
.708 .602 .736 r
.23914 .40807 m .25136 .40969 L .24351 .41593 L p F P
0 g
s
.708 .602 .736 r
.24351 .41593 m .23111 .41256 L .23914 .40807 L p F P
0 g
s
.705 .571 .702 r
.22318 .49722 m .23665 .51018 L .22931 .52403 L p F P
0 g
s
.705 .571 .702 r
.22931 .52403 m .21565 .51075 L .22318 .49722 L p F P
0 g
s
.704 .61 .749 r
.21869 .41137 m .23111 .41256 L .22308 .41761 L p F P
0 g
s
.704 .61 .749 r
.22308 .41761 m .21048 .41455 L .21869 .41137 L p F P
0 g
s
.784 .766 .837 r
.38266 .32693 m .39231 .32261 L .38522 .3278 L p F P
0 g
s
.784 .766 .837 r
.38522 .3278 m .37537 .33228 L .38266 .32693 L p F P
0 g
s
.607 .558 .774 r
.54512 .44158 m .55311 .4522 L .54856 .449 L p F P
0 g
s
.607 .558 .774 r
.54856 .449 m .54037 .43829 L .54512 .44158 L p F P
0 g
s
.661 .594 .769 r
.44499 .31646 m .4536 .32501 L .4471 .32261 L p F P
0 g
s
.661 .594 .769 r
.4471 .32261 m .4383 .31514 L .44499 .31646 L p F P
0 g
s
.445 .518 .84 r
.57742 .47898 m .585 .48786 L .58102 .4843 L p F P
0 g
s
.445 .518 .84 r
.58102 .4843 m .57325 .47531 L .57742 .47898 L p F P
0 g
s
.704 .57 .701 r
.19426 .51076 m .2081 .52485 L .20055 .53951 L p F P
0 g
s
.704 .57 .701 r
.20055 .53951 m .18652 .52523 L .19426 .51076 L p F P
0 g
s
.712 .577 .702 r
.39321 .55802 m .40595 .56549 L .4008 .57796 L p F P
0 g
s
.713 .578 .702 r
.41373 .58458 m .4008 .57796 L .40595 .56549 L p F P
0 g
s
.742 .745 .855 r
.41358 .3113 m .4226 .31139 L .41572 .31286 L p F P
0 g
s
.742 .745 .855 r
.41572 .31286 m .40649 .3144 L .41358 .3113 L p F P
0 g
s
.863 .433 .191 r
.61091 .5154 m .61787 .52219 L .61448 .5183 L p F P
0 g
s
.863 .433 .191 r
.61448 .5183 m .60731 .51137 L .61091 .5154 L p F P
0 g
s
.704 .569 .7 r
.16455 .52533 m .17876 .54039 L .171 .55621 L p F P
0 g
s
.704 .569 .7 r
.171 .55621 m .15659 .54117 L .16455 .52533 L p F P
0 g
s
.713 .578 .701 r
.41373 .58458 m .42667 .5906 L .42192 .60262 L p F P
0 g
s
.714 .578 .701 r
.43506 .60769 m .42192 .60262 L .42667 .5906 L p F P
0 g
s
.709 .575 .702 r
.31683 .50257 m .32955 .51291 L .3232 .52631 L p F P
0 g
s
.709 .575 .702 r
.3232 .52631 m .31028 .51593 L .31683 .50257 L p F P
0 g
s
.708 .574 .702 r
.28445 .49408 m .29737 .50517 L .29062 .51862 L p F P
0 g
s
.708 .574 .702 r
.29062 .51862 m .27751 .50735 L .28445 .49408 L p F P
0 g
s
.714 .607 .737 r
.26706 .39874 m .2789 .39925 L .27123 .40606 L p F P
0 g
s
.714 .607 .737 r
.27123 .40606 m .25921 .404 L .26706 .39874 L p F P
0 g
s
.17 .408 .849 r
.58898 .4917 m .59636 .49991 L .59257 .49619 L p F P
0 g
s
.17 .408 .849 r
.59257 .49619 m .585 .48786 L .58898 .4917 L p F P
0 g
s
.706 .572 .702 r
.24399 .49679 m .25728 .50904 L .25013 .52272 L p F P
0 g
s
.706 .572 .702 r
.25013 .52272 m .23665 .51018 L .24399 .49679 L p F P
0 g
s
.548 .048 0 r
.60373 .50755 m .59825 .50187 L p .60014 .50386 L F P
0 g
s
0 .182 .708 r
.59695 .50002 m .60209 .5059 L p .60014 .50386 L F P
0 g
s
.719 .214 0 r
.60731 .51137 m .60169 .50548 L p .60393 .50801 L F P
0 g
s
.719 .214 0 r
.60169 .50548 m .60014 .50386 L .60393 .50801 L p F P
0 g
s
.719 .214 0 r
.60393 .50801 m .61091 .5154 L .60731 .51137 L p F P
0 g
s
.8 .313 0 r
.61091 .5154 m .60393 .50801 L .60772 .51234 L p F P
0 g
s
0 .068 .603 r
.60094 .50447 m .60623 .51061 L p .60393 .50801 L F P
0 g
s
0 .068 .603 r
.60623 .51061 m .60772 .51234 L .60393 .50801 L p F P
0 g
s
0 .182 .708 r
.60209 .5059 m .60393 .50801 L .60014 .50386 L p F P
0 g
s
.548 .048 0 r
.59825 .50187 m .59636 .49991 L .60014 .50386 L p F P
0 g
s
.716 .58 .701 r
.48293 .67378 m .4688 .67406 L .47256 .66337 L p F P
0 g
s
.716 .58 .701 r
.4688 .67406 m .48293 .67378 L .47937 .68412 L p F P
0 g
s
.648 .563 .746 r
.47689 .35036 m .48529 .36278 L .47937 .35966 L p F P
0 g
s
.648 .563 .746 r
.47937 .35966 m .47078 .34723 L .47689 .35036 L p F P
0 g
s
.707 .573 .702 r
.26441 .49573 m .27751 .50735 L .27057 .5209 L p F P
0 g
s
.707 .573 .702 r
.27057 .5209 m .25728 .50904 L .26441 .49573 L p F P
0 g
s
.712 .577 .702 r
.38047 .55001 m .39321 .55802 L .38786 .57075 L p F P
0 g
s
.712 .577 .702 r
.4008 .57796 m .38786 .57075 L .39321 .55802 L p F P
0 g
s
.689 .41 .495 r
.16375 .41756 m .17663 .41534 L .16808 .41554 L p F P
0 g
s
.689 .41 .495 r
.16808 .41554 m .15504 .41596 L .16375 .41756 L p F P
0 g
s
.702 .53 .652 r
.10642 .4263 m .11977 .41979 L .11074 .41475 L p F P
0 g
s
.702 .53 .652 r
.11074 .41475 m .09721 .42019 L .10642 .4263 L p F P
0 g
s
.71 .575 .702 r
.32955 .51291 m .34228 .52287 L .33613 .53623 L p F P
0 g
s
.71 .575 .702 r
.33613 .53623 m .3232 .52631 L .32955 .51291 L p F P
0 g
s
.75 .672 .775 r
.34306 .35441 m .35352 .35041 L .34623 .35717 L p F P
0 g
s
.75 .672 .775 r
.34623 .35717 m .33558 .36036 L .34306 .35441 L p F P
0 g
s
.636 .561 .752 r
.5158 .40353 m .52399 .41551 L .51885 .41241 L p F P
0 g
s
.636 .561 .752 r
.51885 .41241 m .51046 .40033 L .5158 .40353 L p F P
0 g
s
.725 .625 .747 r
.30189 .38115 m .31314 .37954 L .30566 .38655 L p F P
0 g
s
.725 .625 .747 r
.30566 .38655 m .29423 .38688 L .30189 .38115 L p F P
0 g
s
.827 .551 .52 r
.63443 .54055 m .64079 .54562 L .63778 .54159 L p F P
0 g
s
.827 .551 .52 r
.63778 .54159 m .63123 .53635 L .63443 .54055 L p F P
0 g
s
.714 .578 .701 r
.42192 .60262 m .43506 .60769 L .4305 .6195 L p F P
0 g
s
.714 .579 .701 r
.44384 .62358 m .4305 .6195 L .43506 .60769 L p F P
0 g
s
.711 .576 .702 r
.36774 .54145 m .38047 .55001 L .37492 .56295 L p F P
0 g
s
.712 .577 .702 r
.38786 .57075 m .37492 .56295 L .38047 .55001 L p F P
0 g
s
.705 .571 .701 r
.21565 .51075 m .22931 .52403 L .22196 .53833 L p F P
0 g
s
.705 .571 .701 r
.22196 .53833 m .2081 .52485 L .21565 .51075 L p F P
0 g
s
.71 .575 .702 r
.34228 .52287 m .35501 .5324 L .34906 .54567 L p F P
0 g
s
.71 .575 .702 r
.34906 .54567 m .33613 .53623 L .34228 .52287 L p F P
0 g
s
.708 .574 .702 r
.29737 .50517 m .31028 .51593 L .30373 .52948 L p F P
0 g
s
.708 .574 .702 r
.30373 .52948 m .29062 .51862 L .29737 .50517 L p F P
0 g
s
.713 .577 .701 r
.4008 .57796 m .41373 .58458 L .40878 .5969 L p F P
0 g
s
.713 .578 .701 r
.42192 .60262 m .40878 .5969 L .41373 .58458 L p F P
0 g
s
.711 .576 .702 r
.35501 .5324 m .36774 .54145 L .36199 .55458 L p F P
0 g
s
.711 .576 .702 r
.37492 .56295 m .36199 .55458 L .36774 .54145 L p F P
0 g
s
.787 .569 .605 r
.66913 .57769 m .67425 .57946 L .67184 .57552 L p F P
0 g
s
.787 .569 .605 r
.67184 .57552 m .66651 .57352 L .66913 .57769 L p F P
0 g
s
.711 .576 .702 r
.36199 .55458 m .34906 .54567 L .35501 .5324 L p F P
0 g
s
.716 .58 .701 r
.47256 .66337 m .45863 .6625 L .46259 .65149 L p F P
0 g
s
.716 .58 .701 r
.45863 .6625 m .47256 .66337 L .4688 .67406 L p F P
0 g
s
.571 .55 .792 r
.55768 .45576 m .56546 .46579 L .5611 .46233 L p F P
0 g
s
.571 .55 .792 r
.5611 .46233 m .55311 .4522 L .55768 .45576 L p F P
0 g
s
.649 .566 .748 r
.4685 .33845 m .47689 .35036 L .47078 .34723 L p F P
0 g
s
.649 .566 .748 r
.47078 .34723 m .46219 .33548 L .4685 .33845 L p F P
0 g
s
.717 .58 .701 r
.49033 .69262 m .47581 .69453 L .47937 .68412 L p F P
0 g
s
.714 .579 .701 r
.4305 .6195 m .44384 .62358 L .43948 .63515 L p F P
0 g
s
.715 .579 .701 r
.45302 .63821 m .43948 .63515 L .44384 .62358 L p F P
0 g
s
.704 .57 .7 r
.18652 .52523 m .20055 .53951 L .193 .55472 L p F P
0 g
s
.704 .57 .7 r
.193 .55472 m .17876 .54039 L .18652 .52523 L p F P
0 g
s
.712 .618 .75 r
.24717 .40399 m .25921 .404 L .25136 .40969 L p F P
0 g
s
.712 .618 .75 r
.25136 .40969 m .23914 .40807 L .24717 .40399 L p F P
0 g
s
.788 .795 .858 r
.38995 .32193 m .3994 .31815 L .39231 .32261 L p F P
0 g
s
.788 .795 .858 r
.39231 .32261 m .38266 .32693 L .38995 .32193 L p F P
0 g
s
.715 .579 .701 r
.46259 .65149 m .44886 .64951 L .45302 .63821 L p F P
0 g
s
.715 .579 .701 r
.44886 .64951 m .46259 .65149 L .45863 .6625 L p F P
0 g
s
.615 .558 .767 r
.53713 .4305 m .54512 .44158 L .54037 .43829 L p F P
0 g
s
.615 .558 .767 r
.54037 .43829 m .53218 .42711 L .53713 .4305 L p F P
0 g
s
.715 .579 .701 r
.43948 .63515 m .45302 .63821 L .44886 .64951 L p F P
0 g
s
.706 .572 .701 r
.23665 .51018 m .25013 .52272 L .24299 .53676 L p F P
0 g
s
.706 .572 .701 r
.24299 .53676 m .22931 .52403 L .23665 .51018 L p F P
0 g
s
.176 .701 .867 r
.18518 .41537 m .19785 .41381 L .18947 .41557 L p F P
0 g
s
.176 .701 .867 r
.18947 .41557 m .17663 .41534 L .18518 .41537 L p F P
0 g
s
.707 .573 .702 r
.27751 .50735 m .29062 .51862 L .28387 .53232 L p F P
0 g
s
.707 .573 .702 r
.28387 .53232 m .27057 .5209 L .27751 .50735 L p F P
0 g
s
.809 .561 .564 r
.6468 .55403 m .65274 .55807 L .64994 .55401 L p F P
0 g
s
.809 .561 .564 r
.64994 .55401 m .64379 .54977 L .6468 .55403 L p F P
0 g
s
.719 .622 .749 r
.27492 .39378 m .28656 .39289 L .2789 .39925 L p F P
0 g
s
.719 .622 .749 r
.2789 .39925 m .26706 .39874 L .27492 .39378 L p F P
0 g
s
.639 .56 .75 r
.5076 .39124 m .5158 .40353 L .51046 .40033 L p F P
0 g
s
.639 .56 .75 r
.51046 .40033 m .50207 .38796 L .5076 .39124 L p F P
0 g
s
.709 .574 .702 r
.31028 .51593 m .3232 .52631 L .31685 .53987 L p F P
0 g
s
.709 .574 .702 r
.31685 .53987 m .30373 .52948 L .31028 .51593 L p F P
0 g
s
.707 .572 .702 r
.25728 .50904 m .27057 .5209 L .26362 .53476 L p F P
0 g
s
.707 .572 .702 r
.26362 .53476 m .25013 .52272 L .25728 .50904 L p F P
0 g
s
.796 .566 .589 r
.65837 .56647 m .6639 .56942 L .66129 .56538 L p F P
0 g
s
.796 .566 .589 r
.66129 .56538 m .65555 .56223 L .65837 .56647 L p F P
0 g
s
.763 .704 .796 r
.35054 .34861 m .3608 .34401 L .35352 .35041 L p F P
0 g
s
.763 .704 .796 r
.35352 .35041 m .34306 .35441 L .35054 .34861 L p F P
0 g
s
.712 .577 .701 r
.38786 .57075 m .4008 .57796 L .39564 .59056 L p F P
0 g
s
.713 .577 .701 r
.40878 .5969 m .39564 .59056 L .4008 .57796 L p F P
0 g
s
.733 .645 .761 r
.30956 .3756 m .32062 .37288 L .31314 .37954 L p F P
0 g
s
.733 .645 .761 r
.31314 .37954 m .30189 .38115 L .30956 .3756 L p F P
0 g
s
.709 .637 .775 r
.2269 .40855 m .23914 .40807 L .23111 .41256 L p F P
0 g
s
.709 .637 .775 r
.23111 .41256 m .21869 .41137 L .2269 .40855 L p F P
0 g
s
.695 .687 .838 r
.20623 .41236 m .21869 .41137 L .21048 .41455 L p F P
0 g
s
.695 .687 .838 r
.21048 .41455 m .19785 .41381 L .20623 .41236 L p F P
0 g
s
.713 .578 .701 r
.40878 .5969 m .42192 .60262 L .41716 .61475 L p F P
0 g
s
.714 .578 .701 r
.4305 .6195 m .41716 .61475 L .42192 .60262 L p F P
0 g
s
.852 .532 .444 r
.62467 .53048 m .63123 .53635 L .62803 .53229 L p F P
0 g
s
.852 .532 .444 r
.62803 .53229 m .62127 .52626 L .62467 .53048 L p F P
0 g
s
.705 .57 .701 r
.2081 .52485 m .22196 .53833 L .21461 .5531 L p F P
0 g
s
.705 .57 .701 r
.21461 .5531 m .20055 .53951 L .2081 .52485 L p F P
0 g
s
.709 .575 .702 r
.3232 .52631 m .33613 .53623 L .32998 .54975 L p F P
0 g
s
.709 .575 .702 r
.32998 .54975 m .31685 .53987 L .3232 .52631 L p F P
0 g
s
.507 .534 .818 r
.56983 .46956 m .57742 .47898 L .57325 .47531 L p F P
0 g
s
.507 .534 .818 r
.57325 .47531 m .56546 .46579 L .56983 .46956 L p F P
0 g
s
.716 .58 .701 r
.47937 .68412 m .46505 .68482 L .4688 .67406 L p F P
0 g
s
.716 .58 .701 r
.46505 .68482 m .47937 .68412 L .47581 .69453 L p F P
0 g
s
.653 .573 .753 r
.4601 .32748 m .4685 .33845 L .46219 .33548 L p F P
0 g
s
.653 .573 .753 r
.46219 .33548 m .4536 .32501 L .4601 .32748 L p F P
0 g
s
.681 .623 .784 r
.43638 .31036 m .44499 .31646 L .4383 .31514 L p F P
0 g
s
.681 .623 .784 r
.4383 .31514 m .42949 .31062 L .43638 .31036 L p F P
0 g
s
.712 .576 .701 r
.37492 .56295 m .38786 .57075 L .38251 .5836 L p F P
0 g
s
.712 .577 .701 r
.39564 .59056 m .38251 .5836 L .38786 .57075 L p F P
0 g
s
.702 .521 .64 r
.12882 .42437 m .14195 .41899 L .13308 .4157 L p F P
0 g
s
.702 .521 .64 r
.13308 .4157 m .11977 .41979 L .12882 .42437 L p F P
0 g
s
.708 .574 .702 r
.29062 .51862 m .30373 .52948 L .29718 .54323 L p F P
0 g
s
.708 .574 .702 r
.29718 .54323 m .28387 .53232 L .29062 .51862 L p F P
0 g
s
.71 .575 .702 r
.33613 .53623 m .34906 .54567 L .3431 .55908 L p F P
0 g
s
.71 .575 .702 r
.3431 .55908 m .32998 .54975 L .33613 .53623 L p F P
0 g
s
.641 .56 .748 r
.49941 .37874 m .5076 .39124 L .50207 .38796 L p F P
0 g
s
.641 .56 .748 r
.50207 .38796 m .49368 .37539 L .49941 .37874 L p F P
0 g
s
.714 .578 .701 r
.41716 .61475 m .4305 .6195 L .42595 .63141 L p F P
0 g
s
.714 .579 .701 r
.43948 .63515 m .42595 .63141 L .4305 .6195 L p F P
0 g
s
.711 .576 .701 r
.36199 .55458 m .37492 .56295 L .36937 .57602 L p F P
0 g
s
.712 .576 .701 r
.38251 .5836 m .36937 .57602 L .37492 .56295 L p F P
0 g
s
.722 .694 .823 r
.42067 .30879 m .42949 .31062 L .4226 .31139 L p F P
0 g
s
.722 .694 .823 r
.4226 .31139 m .41358 .3113 L .42067 .30879 L p F P
0 g
s
.706 .571 .701 r
.22931 .52403 m .24299 .53676 L .23583 .55119 L p F P
0 g
s
.706 .571 .701 r
.23583 .55119 m .22196 .53833 L .22931 .52403 L p F P
0 g
s
.711 .576 .701 r
.34906 .54567 m .36199 .55458 L .35623 .56784 L p F P
0 g
s
.711 .576 .701 r
.35623 .56784 m .3431 .55908 L .34906 .54567 L p F P
0 g
s
.705 .569 .7 r
.17876 .54039 m .193 .55472 L .18543 .57049 L p F P
0 g
s
.705 .569 .7 r
.18543 .57049 m .171 .55621 L .17876 .54039 L p F P
0 g
s
.711 .576 .701 r
.36937 .57602 m .35623 .56784 L .36199 .55458 L p F P
0 g
s
.622 .558 .761 r
.52914 .41898 m .53713 .4305 L .53218 .42711 L p F P
0 g
s
.622 .558 .761 r
.53218 .42711 m .52399 .41551 L .52914 .41898 L p F P
0 g
s
.872 .471 .269 r
.6145 .51961 m .62127 .52626 L .61787 .52219 L p F P
0 g
s
.872 .471 .269 r
.61787 .52219 m .61091 .5154 L .6145 .51961 L p F P
0 g
s
.707 .573 .701 r
.27057 .5209 m .28387 .53232 L .27712 .54626 L p F P
0 g
s
.707 .573 .701 r
.27712 .54626 m .26362 .53476 L .27057 .5209 L p F P
0 g
s
.713 .577 .701 r
.39564 .59056 m .40878 .5969 L .40383 .60934 L p F P
0 g
s
.713 .578 .701 r
.41716 .61475 m .40383 .60934 L .40878 .5969 L p F P
0 g
s
.716 .58 .701 r
.4688 .67406 m .45468 .6736 L .45863 .6625 L p F P
0 g
s
.716 .579 .701 r
.45468 .6736 m .4688 .67406 L .46505 .68482 L p F P
0 g
s
.368 .487 .848 r
.58159 .48292 m .58898 .4917 L .585 .48786 L p F P
0 g
s
.368 .487 .848 r
.585 .48786 m .57742 .47898 L .58159 .48292 L p F P
0 g
s
.778 .743 .821 r
.35802 .34293 m .36809 .33797 L .3608 .34401 L p F P
0 g
s
.778 .743 .821 r
.3608 .34401 m .35054 .34861 L .35802 .34293 L p F P
0 g
s
.706 .572 .701 r
.25013 .52272 m .26362 .53476 L .25667 .54892 L p F P
0 g
s
.706 .572 .701 r
.25667 .54892 m .24299 .53676 L .25013 .52272 L p F P
0 g
s
.727 .643 .765 r
.28277 .38903 m .29423 .38688 L .28656 .39289 L p F P
0 g
s
.727 .643 .765 r
.28656 .39289 m .27492 .39378 L .28277 .38903 L p F P
0 g
s
.719 .641 .77 r
.25521 .40016 m .26706 .39874 L .25921 .404 L p F P
0 g
s
.719 .641 .77 r
.25921 .404 m .24717 .40399 L .25521 .40016 L p F P
0 g
s
.589 .552 .781 r
.54988 .44522 m .55768 .45576 L .55311 .4522 L p F P
0 g
s
.589 .552 .781 r
.55311 .4522 m .54512 .44158 L .54988 .44522 L p F P
0 g
s
.744 .67 .779 r
.31723 .37016 m .3281 .3665 L .32062 .37288 L p F P
0 g
s
.744 .67 .779 r
.32062 .37288 m .30956 .3756 L .31723 .37016 L p F P
0 g
s
.714 .578 .701 r
.42595 .63141 m .43948 .63515 L .43512 .64683 L p F P
0 g
s
.715 .579 .701 r
.44886 .64951 m .43512 .64683 L .43948 .63515 L p F P
0 g
s
.781 .793 .863 r
.39724 .31728 m .40649 .3144 L .3994 .31815 L p F P
0 g
s
.781 .793 .863 r
.3994 .31815 m .38995 .32193 L .39724 .31728 L p F P
0 g
s
.709 .574 .701 r
.30373 .52948 m .31685 .53987 L .3105 .55361 L p F P
0 g
s
.709 .574 .701 r
.3105 .55361 m .29718 .54323 L .30373 .52948 L p F P
0 g
s
.715 .579 .701 r
.45863 .6625 m .4447 .66091 L .44886 .64951 L p F P
0 g
s
.715 .579 .701 r
.4447 .66091 m .45863 .6625 L .45468 .6736 L p F P
0 g
s
0 .303 .798 r
.59296 .49576 m .60014 .50386 L .59636 .49991 L p F P
0 g
s
0 .303 .798 r
.59636 .49991 m .58898 .4917 L .59296 .49576 L p F P
0 g
s
.715 .579 .701 r
.43512 .64683 m .44886 .64951 L .4447 .66091 L p F P
0 g
s
.643 .561 .747 r
.49121 .36615 m .49941 .37874 L .49368 .37539 L p F P
0 g
s
.643 .561 .747 r
.49368 .37539 m .48529 .36278 L .49121 .36615 L p F P
0 g
s
.827 .555 .527 r
.63763 .54488 m .64379 .54977 L .64079 .54562 L p F P
0 g
s
.827 .555 .527 r
.64079 .54562 m .63443 .54055 L .63763 .54488 L p F P
0 g
s
.788 .57 .605 r
.67175 .58193 m .67667 .58346 L .67425 .57946 L p F P
0 g
s
.788 .57 .605 r
.67425 .57946 m .66913 .57769 L .67175 .58193 L p F P
0 g
s
.705 .57 .7 r
.20055 .53951 m .21461 .5531 L .20724 .56832 L p F P
0 g
s
.705 .57 .7 r
.20724 .56832 m .193 .55472 L .20055 .53951 L p F P
0 g
s
.712 .577 .701 r
.38251 .5836 m .39564 .59056 L .39049 .60328 L p F P
0 g
s
.713 .577 .701 r
.40383 .60934 m .39049 .60328 L .39564 .59056 L p F P
0 g
s
.699 .502 .618 r
.15084 .42201 m .16375 .41756 L .15504 .41596 L p F P
0 g
s
.699 .502 .618 r
.15504 .41596 m .14195 .41899 L .15084 .42201 L p F P
0 g
s
.662 .586 .759 r
.45169 .318 m .4601 .32748 L .4536 .32501 L p F P
0 g
s
.662 .586 .759 r
.4536 .32501 m .44499 .31646 L .45169 .318 L p F P
0 g
s
.713 .577 .701 r
.40383 .60934 m .41716 .61475 L .41241 .62699 L p F P
0 g
s
.714 .578 .701 r
.42595 .63141 m .41241 .62699 L .41716 .61475 L p F P
0 g
s
.709 .574 .701 r
.31685 .53987 m .32998 .54975 L .32382 .56341 L p F P
0 g
s
.709 .574 .701 r
.32382 .56341 m .3105 .55361 L .31685 .53987 L p F P
0 g
s
.708 .573 .701 r
.28387 .53232 m .29718 .54323 L .29063 .5572 L p F P
0 g
s
.708 .573 .701 r
.29063 .5572 m .27712 .54626 L .28387 .53232 L p F P
0 g
s
.628 .558 .756 r
.52114 .40707 m .52914 .41898 L .52399 .41551 L p F P
0 g
s
.628 .558 .756 r
.52399 .41551 m .5158 .40353 L .52114 .40707 L p F P
0 g
s
.716 .58 .701 r
.47581 .69453 m .46129 .69566 L .46505 .68482 L p F P
0 g
s
.716 .685 .818 r
.23511 .40592 m .24717 .40399 L .23914 .40807 L p F P
0 g
s
.716 .685 .818 r
.23914 .40807 m .2269 .40855 L .23511 .40592 L p F P
0 g
s
.712 .576 .701 r
.36937 .57602 m .38251 .5836 L .37715 .59657 L p F P
0 g
s
.712 .577 .701 r
.39049 .60328 m .37715 .59657 L .38251 .5836 L p F P
0 g
s
.706 .571 .701 r
.22196 .53833 m .23583 .55119 L .22867 .56599 L p F P
0 g
s
.706 .571 .701 r
.22867 .56599 m .21461 .5531 L .22196 .53833 L p F P
0 g
s
.809 .563 .566 r
.64981 .55838 m .65555 .56223 L .65274 .55807 L p F P
0 g
s
.809 .563 .566 r
.65274 .55807 m .6468 .55403 L .64981 .55838 L p F P
0 g
s
.797 .568 .59 r
.66118 .57079 m .66651 .57352 L .6639 .56942 L p F P
0 g
s
.797 .568 .59 r
.6639 .56942 m .65837 .56647 L .66118 .57079 L p F P
0 g
s
.645 .562 .746 r
.48301 .35365 m .49121 .36615 L .48529 .36278 L p F P
0 g
s
.645 .562 .746 r
.48529 .36278 m .47689 .35036 L .48301 .35365 L p F P
0 g
s
.71 .575 .701 r
.32998 .54975 m .3431 .55908 L .33715 .57263 L p F P
0 g
s
.71 .575 .701 r
.33715 .57263 m .32382 .56341 L .32998 .54975 L p F P
0 g
s
.791 .782 .845 r
.36551 .33735 m .37537 .33228 L .36809 .33797 L p F P
0 g
s
.791 .782 .845 r
.36809 .33797 m .35802 .34293 L .36551 .33735 L p F P
0 g
s
.707 .572 .701 r
.26362 .53476 m .27712 .54626 L .27037 .56046 L p F P
0 g
s
.707 .572 .701 r
.27037 .56046 m .25667 .54892 L .26362 .53476 L p F P
0 g
s
.546 .541 .801 r
.56224 .45961 m .56983 .46956 L .56546 .46579 L p F P
0 g
s
.546 .541 .801 r
.56546 .46579 m .55768 .45576 L .56224 .45961 L p F P
0 g
s
.757 .704 .801 r
.3249 .36479 m .33558 .36036 L .3281 .3665 L p F P
0 g
s
.757 .704 .801 r
.3281 .3665 m .31723 .37016 L .3249 .36479 L p F P
0 g
s
.706 .572 .701 r
.24299 .53676 m .25667 .54892 L .24971 .56339 L p F P
0 g
s
.706 .572 .701 r
.24971 .56339 m .23583 .55119 L .24299 .53676 L p F P
0 g
s
.689 .458 .567 r
.17248 .41905 m .18518 .41537 L .17663 .41534 L p F P
0 g
s
.689 .458 .567 r
.17663 .41534 m .16375 .41756 L .17248 .41905 L p F P
0 g
s
.711 .576 .701 r
.35623 .56784 m .36937 .57602 L .36381 .58922 L p F P
0 g
s
.712 .576 .701 r
.37715 .59657 m .36381 .58922 L .36937 .57602 L p F P
0 g
s
.71 .575 .701 r
.3431 .55908 m .35623 .56784 L .35048 .58123 L p F P
0 g
s
.71 .575 .701 r
.35048 .58123 m .33715 .57263 L .3431 .55908 L p F P
0 g
s
.714 .578 .701 r
.41241 .62699 m .42595 .63141 L .42139 .64344 L p F P
0 g
s
.714 .578 .701 r
.43512 .64683 m .42139 .64344 L .42595 .63141 L p F P
0 g
s
.738 .673 .787 r
.29062 .38437 m .30189 .38115 L .29423 .38688 L p F P
0 g
s
.738 .673 .787 r
.29423 .38688 m .28277 .38903 L .29062 .38437 L p F P
0 g
s
.711 .576 .701 r
.36381 .58922 m .35048 .58123 L .35623 .56784 L p F P
0 g
s
.632 .835 .978 r
.21462 .41101 m .2269 .40855 L .21869 .41137 L p F P
0 g
s
.632 .835 .978 r
.21869 .41137 m .20638 .41235 L p .21462 .41101 L F P
0 g
s
.66 .417 .542 r
.21089 .41487 m .22287 .40967 L p .21462 .41101 L F P
0 g
s
.66 .417 .542 r
.22287 .40967 m .22301 .40961 L .21462 .41101 L p F P
0 g
s
.632 .835 .978 r
.20638 .41235 m .20623 .41236 L .21462 .41101 L p F P
0 g
s
.602 .553 .772 r
.54209 .43421 m .54988 .44522 L .54512 .44158 L p F P
0 g
s
.602 .553 .772 r
.54512 .44158 m .53713 .4305 L .54209 .43421 L p F P
0 g
s
.713 .577 .701 r
.39049 .60328 m .40383 .60934 L .39887 .62189 L p F P
0 g
s
.713 .577 .701 r
.41241 .62699 m .39887 .62189 L .40383 .60934 L p F P
0 g
s
.716 .579 .701 r
.46505 .68482 m .45072 .68477 L .45468 .6736 L p F P
0 g
s
.716 .579 .701 r
.45072 .68477 m .46505 .68482 L .46129 .69566 L p F P
0 g
s
.708 .574 .701 r
.29718 .54323 m .3105 .55361 L .30414 .56753 L p F P
0 g
s
.708 .574 .701 r
.30414 .56753 m .29063 .5572 L .29718 .54323 L p F P
0 g
s
.851 .539 .46 r
.62807 .53484 m .63443 .54055 L .63123 .53635 L p F P
0 g
s
.851 .539 .46 r
.63123 .53635 m .62467 .53048 L .62807 .53484 L p F P
0 g
s
.619 .263 .344 r
.19374 .41539 m .20623 .41236 L .19785 .41381 L p F P
0 g
s
.619 .263 .344 r
.19785 .41381 m .18518 .41537 L .19374 .41539 L p F P
0 g
s
.729 .678 .8 r
.26324 .39644 m .27492 .39378 L .26706 .39874 L p F P
0 g
s
.729 .678 .8 r
.26706 .39874 m .25521 .40016 L .26324 .39644 L p F P
0 g
s
.714 .578 .701 r
.42139 .64344 m .43512 .64683 L .43077 .65859 L p F P
0 g
s
.715 .579 .701 r
.4447 .66091 m .43077 .65859 L .43512 .64683 L p F P
0 g
s
.649 .565 .747 r
.47481 .3415 m .48301 .35365 L .47689 .35036 L p F P
0 g
s
.649 .565 .747 r
.47689 .35036 m .4685 .33845 L .47481 .3415 L p F P
0 g
s
.715 .579 .701 r
.45468 .6736 m .44054 .6724 L .4447 .66091 L p F P
0 g
s
.715 .579 .701 r
.44054 .6724 m .45468 .6736 L .45072 .68477 L p F P
0 g
s
.7 .534 .659 r
.09302 .43485 m .10642 .4263 L .09721 .42019 L p F P
0 g
s
.7 .534 .659 r
.09721 .42019 m .08364 .42813 L .09302 .43485 L p F P
0 g
s
.632 .558 .753 r
.51314 .39483 m .52114 .40707 L .5158 .40353 L p F P
0 g
s
.632 .558 .753 r
.5158 .40353 m .5076 .39124 L .51314 .39483 L p F P
0 g
s
.766 .762 .849 r
.40453 .31299 m .41358 .3113 L .40649 .3144 L p F P
0 g
s
.766 .762 .849 r
.40649 .3144 m .39724 .31728 L .40453 .31299 L p F P
0 g
s
.715 .578 .701 r
.43077 .65859 m .4447 .66091 L .44054 .6724 L p F P
0 g
s
.705 .57 .7 r
.193 .55472 m .20724 .56832 L .19987 .584 L p F P
0 g
s
.705 .57 .7 r
.19987 .584 m .18543 .57049 L .193 .55472 L p F P
0 g
s
.466 .517 .827 r
.57421 .47359 m .58159 .48292 L .57742 .47898 L p F P
0 g
s
.466 .517 .827 r
.57742 .47898 m .56983 .46956 L .57421 .47359 L p F P
0 g
s
.708 .573 .701 r
.27712 .54626 m .29063 .5572 L .28407 .57137 L p F P
0 g
s
.708 .573 .701 r
.28407 .57137 m .27037 .56046 L .27712 .54626 L p F P
0 g
s
.712 .576 .701 r
.37715 .59657 m .39049 .60328 L .38533 .61611 L p F P
0 g
s
.713 .577 .701 r
.39887 .62189 m .38533 .61611 L .39049 .60328 L p F P
0 g
s
.709 .574 .701 r
.3105 .55361 m .32382 .56341 L .31766 .57724 L p F P
0 g
s
.709 .574 .701 r
.31766 .57724 m .30414 .56753 L .3105 .55361 L p F P
0 g
s
.707 .655 .795 r
.42776 .30681 m .43638 .31036 L .42949 .31062 L p F P
0 g
s
.707 .655 .795 r
.42949 .31062 m .42067 .30879 L .42776 .30681 L p F P
0 g
s
.713 .577 .701 r
.39887 .62189 m .41241 .62699 L .40765 .63934 L p F P
0 g
s
.714 .578 .701 r
.42139 .64344 m .40765 .63934 L .41241 .62699 L p F P
0 g
s
.706 .571 .7 r
.21461 .5531 m .22867 .56599 L .2215 .58118 L p F P
0 g
s
.706 .571 .7 r
.2215 .58118 m .20724 .56832 L .21461 .5531 L p F P
0 g
s
.875 .494 .316 r
.61809 .52397 m .62467 .53048 L .62127 .52626 L p F P
0 g
s
.875 .494 .316 r
.62127 .52626 m .6145 .51961 L .61809 .52397 L p F P
0 g
s
.773 .745 .827 r
.33258 .35942 m .34306 .35441 L .33558 .36036 L p F P
0 g
s
.773 .745 .827 r
.33558 .36036 m .3249 .36479 L .33258 .35942 L p F P
0 g
s
.799 .812 .862 r
.373 .33186 m .38266 .32693 L .37537 .33228 L p F P
0 g
s
.799 .812 .862 r
.37537 .33228 m .36551 .33735 L .373 .33186 L p F P
0 g
s
.677 .605 .768 r
.44328 .31051 m .45169 .318 L .44499 .31646 L p F P
0 g
s
.677 .605 .768 r
.44499 .31646 m .43638 .31036 L .44328 .31051 L p F P
0 g
s
.789 .571 .605 r
.67437 .58622 m .67909 .58751 L .67667 .58346 L p F P
0 g
s
.789 .571 .605 r
.67667 .58346 m .67175 .58193 L .67437 .58622 L p F P
0 g
s
.707 .572 .701 r
.25667 .54892 m .27037 .56046 L .2636 .57492 L p F P
0 g
s
.707 .572 .701 r
.2636 .57492 m .24971 .56339 L .25667 .54892 L p F P
0 g
s
.706 .571 .701 r
.23583 .55119 m .24971 .56339 L .24275 .57818 L p F P
0 g
s
.706 .571 .701 r
.24275 .57818 m .22867 .56599 L .23583 .55119 L p F P
0 g
s
.71 .575 .701 r
.32382 .56341 m .33715 .57263 L .33119 .58632 L p F P
0 g
s
.71 .575 .701 r
.33119 .58632 m .31766 .57724 L .32382 .56341 L p F P
0 g
s
.711 .576 .701 r
.36381 .58922 m .37715 .59657 L .37179 .60966 L p F P
0 g
s
.712 .576 .701 r
.38533 .61611 m .37179 .60966 L .37715 .59657 L p F P
0 g
s
.283 .448 .848 r
.58577 .48708 m .59296 .49576 L .58898 .4917 L p F P
0 g
s
.283 .448 .848 r
.58898 .4917 m .58159 .48292 L .58577 .48708 L p F P
0 g
s
.752 .714 .816 r
.29848 .37972 m .30956 .3756 L .30189 .38115 L p F P
0 g
s
.752 .714 .816 r
.30189 .38115 m .29062 .38437 L .29848 .37972 L p F P
0 g
s
.827 .558 .531 r
.64084 .54931 m .6468 .55403 L .64379 .54977 L p F P
0 g
s
.827 .558 .531 r
.64379 .54977 m .63763 .54488 L .64084 .54931 L p F P
0 g
s
.654 .571 .749 r
.4666 .33005 m .47481 .3415 L .4685 .33845 L p F P
0 g
s
.654 .571 .749 r
.4685 .33845 m .4601 .32748 L .4666 .33005 L p F P
0 g
s
.636 .558 .75 r
.50514 .38234 m .51314 .39483 L .5076 .39124 L p F P
0 g
s
.636 .558 .75 r
.5076 .39124 m .49941 .37874 L .50514 .38234 L p F P
0 g
s
.612 .554 .765 r
.53429 .42275 m .54209 .43421 L .53713 .4305 L p F P
0 g
s
.612 .554 .765 r
.53713 .4305 m .52914 .41898 L .53429 .42275 L p F P
0 g
s
.8 .313 0 r
.60772 .51234 m .6145 .51961 L .61091 .5154 L p F P
0 g
s
.571 .546 .787 r
.55465 .44915 m .56224 .45961 L .55768 .45576 L p F P
0 g
s
.571 .546 .787 r
.55768 .45576 m .54988 .44522 L .55465 .44915 L p F P
0 g
s
.71 .575 .701 r
.33715 .57263 m .35048 .58123 L .34472 .59476 L p F P
0 g
s
.71 .575 .701 r
.34472 .59476 m .33119 .58632 L .33715 .57263 L p F P
0 g
s
.711 .575 .701 r
.35048 .58123 m .36381 .58922 L .35825 .60254 L p F P
0 g
s
.711 .576 .701 r
.37179 .60966 m .35825 .60254 L .36381 .58922 L p F P
0 g
s
0 .182 .708 r
.60014 .50386 m .59296 .49576 L .59695 .50002 L p F P
0 g
s
.711 .575 .701 r
.35825 .60254 m .34472 .59476 L .35048 .58123 L p F P
0 g
s
.721 .775 .896 r
.24332 .40332 m .25521 .40016 L .24717 .40399 L p F P
0 g
s
.721 .775 .896 r
.24717 .40399 m .23535 .40588 L p .24332 .40332 L F P
0 g
s
.639 .917 .979 r
.25521 .40016 m .24393 .40316 L p .25155 .40065 L F P
0 g
s
.639 .917 .979 r
.24393 .40316 m .24332 .40332 L .25155 .40065 L p F P
0 g
s
.639 .917 .979 r
.25155 .40065 m .26324 .39644 L .25521 .40016 L p F P
0 g
s
.604 .33 .475 r
.24824 .40408 m .25919 .39813 L p .25155 .40065 L F P
0 g
s
.604 .33 .475 r
.25919 .39813 m .25978 .39782 L .25155 .40065 L p F P
0 g
s
.593 .293 .43 r
.23982 .40622 m .25131 .40076 L p .24332 .40332 L F P
0 g
s
.593 .293 .43 r
.25131 .40076 m .25155 .40065 L .24332 .40332 L p F P
0 g
s
.721 .775 .896 r
.23535 .40588 m .23511 .40592 L .24332 .40332 L p F P
0 g
s
.714 .578 .701 r
.40765 .63934 m .42139 .64344 L .41683 .65556 L p F P
0 g
s
.714 .578 .701 r
.43077 .65859 m .41683 .65556 L .42139 .64344 L p F P
0 g
s
.708 .573 .701 r
.29063 .5572 m .30414 .56753 L .29778 .58164 L p F P
0 g
s
.708 .573 .701 r
.29778 .58164 m .28407 .57137 L .29063 .5572 L p F P
0 g
s
.7 .528 .652 r
.11564 .43174 m .12882 .42437 L .11977 .41979 L p F P
0 g
s
.7 .528 .652 r
.11977 .41979 m .10642 .4263 L .11564 .43174 L p F P
0 g
s
.716 .579 .701 r
.46129 .69566 m .44675 .69603 L .45072 .68477 L p F P
0 g
s
.712 .577 .701 r
.38533 .61611 m .39887 .62189 L .39391 .63455 L p F P
0 g
s
.713 .577 .701 r
.40765 .63934 m .39391 .63455 L .39887 .62189 L p F P
0 g
s
.798 .569 .59 r
.664 .57518 m .66913 .57769 L .66651 .57352 L p F P
0 g
s
.798 .569 .59 r
.66651 .57352 m .66118 .57079 L .664 .57518 L p F P
0 g
s
.81 .565 .568 r
.65282 .56282 m .65837 .56647 L .65555 .56223 L p F P
0 g
s
.81 .565 .568 r
.65555 .56223 m .64981 .55838 L .65282 .56282 L p F P
0 g
s
.743 .736 .845 r
.27128 .39274 m .28277 .38903 L .27492 .39378 L p F P
0 g
s
.743 .736 .845 r
.27492 .39378 m .2635 .39638 L p .27128 .39274 L F P
0 g
s
.756 .824 .905 r
.28277 .38903 m .27187 .39255 L p .27933 .38896 L F P
0 g
s
.756 .824 .905 r
.27187 .39255 m .27128 .39274 L .27933 .38896 L p F P
0 g
s
.756 .824 .905 r
.27933 .38896 m .29062 .38437 L .28277 .38903 L p F P
0 g
s
.733 .931 .955 r
.29062 .38437 m .28027 .38858 L p .28738 .38504 L F P
0 g
s
.733 .931 .955 r
.28027 .38858 m .27933 .38896 L .28738 .38504 L p F P
0 g
s
.733 .931 .955 r
.28738 .38504 m .29848 .37972 L .29062 .38437 L p F P
0 g
s
.59 .948 .875 r
.29848 .37972 m .28872 .3844 L p .29544 .38092 L F P
0 g
s
.59 .948 .875 r
.28872 .3844 m .28738 .38504 L .29544 .38092 L p F P
0 g
s
.769 .769 .852 r
.30956 .3756 m .29848 .37972 L .30634 .37503 L p F P
0 g
s
.59 .948 .875 r
.29544 .38092 m .30634 .37503 L .29848 .37972 L p F P
0 g
s
.444 .107 .298 r
.29277 .38366 m .30219 .37741 L p .29544 .38092 L F P
0 g
s
.357 .799 .643 r
.30634 .37503 m .29724 .37994 L p .3035 .37655 L F P
0 g
s
.357 .799 .643 r
.29724 .37994 m .29544 .38092 L .3035 .37655 L p F P
0 g
s
.769 .769 .852 r
.30634 .37503 m .31723 .37016 L .30956 .3756 L p F P
0 g
s
.785 .835 .891 r
.31723 .37016 m .30715 .37467 L p .31421 .37023 L F P
0 g
s
.785 .835 .891 r
.30715 .37467 m .30634 .37503 L .31421 .37023 L p F P
0 g
s
.785 .835 .891 r
.31421 .37023 m .3249 .36479 L .31723 .37016 L p F P
0 g
s
.791 .902 .919 r
.3249 .36479 m .3154 .36962 L p .32208 .36528 L F P
0 g
s
.791 .902 .919 r
.3154 .36962 m .31421 .37023 L .32208 .36528 L p F P
0 g
s
.791 .902 .919 r
.32208 .36528 m .33258 .35942 L .3249 .36479 L p F P
0 g
s
.785 .949 .927 r
.33258 .35942 m .32376 .36434 L p .32996 .36015 L F P
0 g
s
.785 .949 .927 r
.32376 .36434 m .32208 .36528 L .32996 .36015 L p F P
0 g
s
.785 .949 .927 r
.32996 .36015 m .34026 .35402 L .33258 .35942 L p F P
0 g
s
.779 .969 .92 r
.34026 .35402 m .32996 .36015 L .33784 .35481 L p F P
0 g
s
0 0 0 r
.32772 .36169 m .33621 .35592 L p .32996 .36015 L F P
0 g
s
0 0 0 r
.33621 .35592 m .33784 .35481 L .32996 .36015 L p F P
0 g
s
0 0 0 r
.31964 .36695 m .3288 .36091 L p .32208 .36528 L F P
0 g
s
0 0 0 r
.3288 .36091 m .32996 .36015 L .32208 .36528 L p F P
0 g
s
0 0 0 r
.31157 .3719 m .32131 .36577 L p .31421 .37023 L F P
0 g
s
0 0 0 r
.32131 .36577 m .32208 .36528 L .31421 .37023 L p F P
0 g
s
.415 .075 .278 r
.30103 .37923 m .30981 .37312 L p .3035 .37655 L F P
0 g
s
.415 .075 .278 r
.30981 .37312 m .31157 .3719 L .3035 .37655 L p F P
0 g
s
.444 .107 .298 r
.30219 .37741 m .3035 .37655 L .29544 .38092 L p F P
0 g
s
.449 .103 .285 r
.28451 .3877 m .29452 .38148 L p .28738 .38504 L F P
0 g
s
.449 .103 .285 r
.29452 .38148 m .29544 .38092 L .28738 .38504 L p F P
0 g
s
.422 .049 .222 r
.27626 .39139 m .28681 .38536 L p .27933 .38896 L F P
0 g
s
.422 .049 .222 r
.28681 .38536 m .28738 .38504 L .27933 .38896 L p F P
0 g
s
.319 0 .044 r
.26801 .39474 m .27908 .38909 L p .27128 .39274 L F P
0 g
s
.319 0 .044 r
.27908 .38909 m .27933 .38896 L .27128 .39274 L p F P
0 g
s
.743 .736 .845 r
.2635 .39638 m .26324 .39644 L .27128 .39274 L p F P
0 g
s
.714 .578 .701 r
.41683 .65556 m .43077 .65859 L .4264 .67045 L p F P
0 g
s
.715 .578 .701 r
.44054 .6724 m .4264 .67045 L .43077 .65859 L p F P
0 g
s
.715 .579 .701 r
.45072 .68477 m .43638 .68397 L .44054 .6724 L p F P
0 g
s
.715 .579 .701 r
.43638 .68397 m .45072 .68477 L .44675 .69603 L p F P
0 g
s
.714 .578 .701 r
.4264 .67045 m .44054 .6724 L .43638 .68397 L p F P
0 g
s
.708 .573 .701 r
.27037 .56046 m .28407 .57137 L .27751 .58578 L p F P
0 g
s
.708 .573 .701 r
.27751 .58578 m .2636 .57492 L .27037 .56046 L p F P
0 g
s
.64 .559 .748 r
.49713 .3697 m .50514 .38234 L .49941 .37874 L p F P
0 g
s
.64 .559 .748 r
.49941 .37874 m .49121 .36615 L .49713 .3697 L p F P
0 g
s
.709 .574 .701 r
.30414 .56753 m .31766 .57724 L .3115 .59124 L p F P
0 g
s
.709 .574 .701 r
.3115 .59124 m .29778 .58164 L .30414 .56753 L p F P
0 g
s
.789 .792 .854 r
.34026 .35402 m .35054 .34861 L .34306 .35441 L p F P
0 g
s
.789 .792 .854 r
.34306 .35441 m .33258 .35942 L .34026 .35402 L p F P
0 g
s
.8 .822 .869 r
.38048 .32645 m .38995 .32193 L .38266 .32693 L p F P
0 g
s
.8 .822 .869 r
.38266 .32693 m .373 .33186 L .38048 .32645 L p F P
0 g
s
.712 .576 .701 r
.37179 .60966 m .38533 .61611 L .38017 .62906 L p F P
0 g
s
.712 .577 .701 r
.39391 .63455 m .38017 .62906 L .38533 .61611 L p F P
0 g
s
.749 .72 .825 r
.41182 .30907 m .42067 .30879 L .41358 .3113 L p F P
0 g
s
.749 .72 .825 r
.41358 .3113 m .40453 .31299 L .41182 .30907 L p F P
0 g
s
.706 .57 .7 r
.20724 .56832 m .2215 .58118 L .21433 .59675 L p F P
0 g
s
.706 .57 .7 r
.21433 .59675 m .19987 .584 L .20724 .56832 L p F P
0 g
s
.707 .572 .701 r
.24971 .56339 m .2636 .57492 L .25684 .58966 L p F P
0 g
s
.707 .572 .701 r
.25684 .58966 m .24275 .57818 L .24971 .56339 L p F P
0 g
s
.662 .58 .752 r
.45839 .31972 m .4666 .33005 L .4601 .32748 L p F P
0 g
s
.662 .58 .752 r
.4601 .32748 m .45169 .318 L .45839 .31972 L p F P
0 g
s
.238 0 0 r
.2269 .40855 m .21462 .41101 L .22301 .40961 L p F P
0 g
s
.238 0 0 r
.22301 .40961 m .23511 .40592 L .2269 .40855 L p F P
0 g
s
.62 .555 .759 r
.52649 .41088 m .53429 .42275 L .52914 .41898 L p F P
0 g
s
.62 .555 .759 r
.52914 .41898 m .52114 .40707 L .52649 .41088 L p F P
0 g
s
.698 .519 .642 r
.13788 .42841 m .15084 .42201 L .14195 .41899 L p F P
0 g
s
.698 .519 .642 r
.14195 .41899 m .12882 .42437 L .13788 .42841 L p F P
0 g
s
.52 .531 .807 r
.56681 .46372 m .57421 .47359 L .56983 .46956 L p F P
0 g
s
.52 .531 .807 r
.56983 .46956 m .56224 .45961 L .56681 .46372 L p F P
0 g
s
.706 .571 .7 r
.22867 .56599 m .24275 .57818 L .23578 .59329 L p F P
0 g
s
.706 .571 .7 r
.23578 .59329 m .2215 .58118 L .22867 .56599 L p F P
0 g
s
.713 .577 .701 r
.39391 .63455 m .40765 .63934 L .40289 .6518 L p F P
0 g
s
.714 .578 .701 r
.41683 .65556 m .40289 .6518 L .40765 .63934 L p F P
0 g
s
.851 .545 .47 r
.63147 .53932 m .63763 .54488 L .63443 .54055 L p F P
0 g
s
.851 .545 .47 r
.63443 .54055 m .62807 .53484 L .63147 .53932 L p F P
0 g
s
.71 .574 .701 r
.31766 .57724 m .33119 .58632 L .32522 .60017 L p F P
0 g
s
.71 .574 .701 r
.32522 .60017 m .3115 .59124 L .31766 .57724 L p F P
0 g
s
.711 .576 .701 r
.35825 .60254 m .37179 .60966 L .36643 .62287 L p F P
0 g
s
.712 .576 .701 r
.38017 .62906 m .36643 .62287 L .37179 .60966 L p F P
0 g
s
.644 .561 .746 r
.48913 .35707 m .49713 .3697 L .49121 .36615 L p F P
0 g
s
.644 .561 .746 r
.49121 .36615 m .48301 .35365 L .48913 .35707 L p F P
0 g
s
.589 .548 .777 r
.54705 .43819 m .55465 .44915 L .54988 .44522 L p F P
0 g
s
.589 .548 .777 r
.54988 .44522 m .54209 .43421 L .54705 .43819 L p F P
0 g
s
.71 .575 .701 r
.33119 .58632 m .34472 .59476 L .33895 .60842 L p F P
0 g
s
.71 .575 .701 r
.33895 .60842 m .32522 .60017 L .33119 .58632 L p F P
0 g
s
.708 .573 .701 r
.28407 .57137 m .29778 .58164 L .29142 .59594 L p F P
0 g
s
.708 .573 .701 r
.29142 .59594 m .27751 .58578 L .28407 .57137 L p F P
0 g
s
.711 .575 .701 r
.34472 .59476 m .35825 .60254 L .35269 .61599 L p F P
0 g
s
.711 .576 .701 r
.36643 .62287 m .35269 .61599 L .35825 .60254 L p F P
0 g
s
.655 .384 .497 r
.20231 .41526 m .21462 .41101 L .20623 .41236 L p F P
0 g
s
.655 .384 .497 r
.20623 .41236 m .19374 .41539 L .20231 .41526 L p F P
0 g
s
.695 .504 .625 r
.15974 .42462 m .17248 .41905 L .16375 .41756 L p F P
0 g
s
.695 .504 .625 r
.16375 .41756 m .15084 .42201 L .15974 .42462 L p F P
0 g
s
.711 .575 .701 r
.35269 .61599 m .33895 .60842 L .34472 .59476 L p F P
0 g
s
.713 .577 .701 r
.40289 .6518 m .41683 .65556 L .41226 .66777 L p F P
0 g
s
.714 .578 .701 r
.4264 .67045 m .41226 .66777 L .41683 .65556 L p F P
0 g
s
.686 .472 .591 r
.18122 .42026 m .19374 .41539 L .18518 .41537 L p F P
0 g
s
.686 .472 .591 r
.18518 .41537 m .17248 .41905 L .18122 .42026 L p F P
0 g
s
.423 .499 .833 r
.57858 .47784 m .58577 .48708 L .58159 .48292 L p F P
0 g
s
.423 .499 .833 r
.58159 .48292 m .57421 .47359 L .57858 .47784 L p F P
0 g
s
.712 .577 .701 r
.38017 .62906 m .39391 .63455 L .38894 .64732 L p F P
0 g
s
.713 .577 .701 r
.40289 .6518 m .38894 .64732 L .39391 .63455 L p F P
0 g
s
.876 .508 .345 r
.62169 .52847 m .62807 .53484 L .62467 .53048 L p F P
0 g
s
.876 .508 .345 r
.62467 .53048 m .61809 .52397 L .62169 .52847 L p F P
0 g
s
.697 .628 .776 r
.43485 .30531 m .44328 .31051 L .43638 .31036 L p F P
0 g
s
.697 .628 .776 r
.43638 .31036 m .42776 .30681 L .43485 .30531 L p F P
0 g
s
.802 .836 .877 r
.34794 .34856 m .35802 .34293 L .35054 .34861 L p F P
0 g
s
.802 .836 .877 r
.35054 .34861 m .34026 .35402 L .34794 .34856 L p F P
0 g
s
.627 .556 .755 r
.51868 .39865 m .52649 .41088 L .52114 .40707 L p F P
0 g
s
.627 .556 .755 r
.52114 .40707 m .51314 .39483 L .51868 .39865 L p F P
0 g
s
.714 .578 .701 r
.41226 .66777 m .4264 .67045 L .42204 .68241 L p F P
0 g
s
.714 .578 .701 r
.43638 .68397 m .42204 .68241 L .4264 .67045 L p F P
0 g
s
.708 .572 .701 r
.2636 .57492 m .27751 .58578 L .27094 .60041 L p F P
0 g
s
.708 .572 .701 r
.27094 .60041 m .25684 .58966 L .2636 .57492 L p F P
0 g
s
.828 .56 .534 r
.64405 .55384 m .64981 .55838 L .6468 .55403 L p F P
0 g
s
.828 .56 .534 r
.6468 .55403 m .64084 .54931 L .64405 .55384 L p F P
0 g
s
.715 .579 .701 r
.44675 .69603 m .43222 .69562 L .43638 .68397 L p F P
0 g
s
.649 .564 .746 r
.48112 .34465 m .48913 .35707 L .48301 .35365 L p F P
0 g
s
.649 .564 .746 r
.48301 .35365 m .47481 .3415 L .48112 .34465 L p F P
0 g
s
.709 .574 .701 r
.29778 .58164 m .3115 .59124 L .30533 .6054 L p F P
0 g
s
.709 .574 .701 r
.30533 .6054 m .29142 .59594 L .29778 .58164 L p F P
0 g
s
.794 .808 .863 r
.38798 .32115 m .39724 .31728 L .38995 .32193 L p F P
0 g
s
.794 .808 .863 r
.38995 .32193 m .38048 .32645 L .38798 .32115 L p F P
0 g
s
.714 .578 .701 r
.42204 .68241 m .43638 .68397 L .43222 .69562 L p F P
0 g
s
.196 .404 .839 r
.58996 .49145 m .59695 .50002 L .59296 .49576 L p F P
0 g
s
.196 .404 .839 r
.59296 .49576 m .58577 .48708 L .58996 .49145 L p F P
0 g
s
.839 .371 .027 r
.61152 .51683 m .61809 .52397 L .6145 .51961 L p F P
0 g
s
.839 .371 .027 r
.6145 .51961 m .60772 .51234 L .61152 .51683 L p F P
0 g
s
.707 .572 .7 r
.24275 .57818 m .25684 .58966 L .25007 .60467 L p F P
0 g
s
.707 .572 .7 r
.25007 .60467 m .23578 .59329 L .24275 .57818 L p F P
0 g
s
.799 .57 .59 r
.66681 .57964 m .67175 .58193 L .66913 .57769 L p F P
0 g
s
.799 .57 .59 r
.66913 .57769 m .664 .57518 L .66681 .57964 L p F P
0 g
s
.712 .576 .701 r
.36643 .62287 m .38017 .62906 L .375 .64212 L p F P
0 g
s
.712 .577 .701 r
.38894 .64732 m .375 .64212 L .38017 .62906 L p F P
0 g
s
.674 .593 .757 r
.45018 .31099 m .45839 .31972 L .45169 .318 L p F P
0 g
s
.674 .593 .757 r
.45169 .318 m .44328 .31051 L .45018 .31099 L p F P
0 g
s
.706 .571 .7 r
.2215 .58118 m .23578 .59329 L .2288 .60874 L p F P
0 g
s
.706 .571 .7 r
.2288 .60874 m .21433 .59675 L .2215 .58118 L p F P
0 g
s
0 .068 .603 r
.60393 .50801 m .59695 .50002 L .60094 .50447 L p F P
0 g
s
.811 .567 .569 r
.65583 .56734 m .66118 .57079 L .65837 .56647 L p F P
0 g
s
.811 .567 .569 r
.65837 .56647 m .65282 .56282 L .65583 .56734 L p F P
0 g
s
.713 .577 .701 r
.38894 .64732 m .40289 .6518 L .39812 .66435 L p F P
0 g
s
.713 .577 .701 r
.41226 .66777 m .39812 .66435 L .40289 .6518 L p F P
0 g
s
.709 .574 .701 r
.3115 .59124 m .32522 .60017 L .31926 .61417 L p F P
0 g
s
.709 .574 .701 r
.31926 .61417 m .30533 .6054 L .3115 .59124 L p F P
0 g
s
.555 .539 .792 r
.55941 .45332 m .56681 .46372 L .56224 .45961 L p F P
0 g
s
.555 .539 .792 r
.56224 .45961 m .55465 .44915 L .55941 .45332 L p F P
0 g
s
.603 .55 .768 r
.53944 .42677 m .54705 .43819 L .54209 .43421 L p F P
0 g
s
.603 .55 .768 r
.54209 .43421 m .53429 .42275 L .53944 .42677 L p F P
0 g
s
.732 .682 .801 r
.41912 .30553 m .42776 .30681 L .42067 .30879 L p F P
0 g
s
.732 .682 .801 r
.42067 .30879 m .41182 .30907 L .41912 .30553 L p F P
0 g
s
.711 .576 .701 r
.35269 .61599 m .36643 .62287 L .36106 .6362 L p F P
0 g
s
.712 .576 .701 r
.375 .64212 m .36106 .6362 L .36643 .62287 L p F P
0 g
s
.633 .557 .751 r
.51087 .38613 m .51868 .39865 L .51314 .39483 L p F P
0 g
s
.633 .557 .751 r
.51314 .39483 m .50514 .38234 L .51087 .38613 L p F P
0 g
s
.708 .573 .701 r
.27751 .58578 m .29142 .59594 L .28505 .61044 L p F P
0 g
s
.708 .573 .701 r
.28505 .61044 m .27094 .60041 L .27751 .58578 L p F P
0 g
s
.71 .575 .701 r
.32522 .60017 m .33895 .60842 L .33319 .62222 L p F P
0 g
s
.71 .575 .701 r
.33319 .62222 m .31926 .61417 L .32522 .60017 L p F P
0 g
s
.654 .568 .746 r
.47311 .33271 m .48112 .34465 L .47481 .3415 L p F P
0 g
s
.654 .568 .746 r
.47481 .3415 m .4666 .33005 L .47311 .33271 L p F P
0 g
s
.711 .575 .701 r
.33895 .60842 m .35269 .61599 L .34712 .62957 L p F P
0 g
s
.711 .576 .701 r
.36106 .6362 m .34712 .62957 L .35269 .61599 L p F P
0 g
s
.711 .575 .701 r
.34712 .62957 m .33319 .62222 L .33895 .60842 L p F P
0 g
s
.809 .866 .89 r
.35562 .34301 m .36551 .33735 L .35802 .34293 L p F P
0 g
s
.809 .866 .89 r
.35802 .34293 m .34794 .34856 L .35562 .34301 L p F P
0 g
s
.713 .577 .701 r
.39812 .66435 m .41226 .66777 L .4077 .68009 L p F P
0 g
s
.714 .578 .701 r
.42204 .68241 m .4077 .68009 L .41226 .66777 L p F P
0 g
s
.546 .184 .305 r
.23141 .40804 m .24332 .40332 L .23511 .40592 L p F P
0 g
s
.546 .184 .305 r
.23511 .40592 m .22301 .40961 L .23141 .40804 L p F P
0 g
s
.851 .549 .477 r
.63488 .54391 m .64084 .54931 L .63763 .54488 L p F P
0 g
s
.851 .549 .477 r
.63763 .54488 m .63147 .53932 L .63488 .54391 L p F P
0 g
s
.712 .576 .701 r
.375 .64212 m .38894 .64732 L .38398 .66019 L p F P
0 g
s
.713 .577 .701 r
.39812 .66435 m .38398 .66019 L .38894 .64732 L p F P
0 g
s
.707 .572 .7 r
.25684 .58966 m .27094 .60041 L .26436 .61529 L p F P
0 g
s
.707 .572 .7 r
.26436 .61529 m .25007 .60467 L .25684 .58966 L p F P
0 g
s
.714 .577 .701 r
.4077 .68009 m .42204 .68241 L .41768 .69444 L p F P
0 g
s
.714 .578 .701 r
.43222 .69562 m .41768 .69444 L .42204 .68241 L p F P
0 g
s
.783 .776 .847 r
.39547 .31597 m .40453 .31299 L .39724 .31728 L p F P
0 g
s
.783 .776 .847 r
.39724 .31728 m .38798 .32115 L .39547 .31597 L p F P
0 g
s
.709 .573 .701 r
.29142 .59594 m .30533 .6054 L .29916 .61975 L p F P
0 g
s
.709 .573 .701 r
.29916 .61975 m .28505 .61044 L .29142 .59594 L p F P
0 g
s
.497 .521 .812 r
.57138 .46804 m .57858 .47784 L .57421 .47359 L p F P
0 g
s
.497 .521 .812 r
.57421 .47359 m .56681 .46372 L .57138 .46804 L p F P
0 g
s
.638 .558 .748 r
.50306 .37341 m .51087 .38613 L .50514 .38234 L p F P
0 g
s
.638 .558 .748 r
.50514 .38234 m .49713 .3697 L .50306 .37341 L p F P
0 g
s
.707 .571 .7 r
.23578 .59329 m .25007 .60467 L .24329 .61996 L p F P
0 g
s
.707 .571 .7 r
.24329 .61996 m .2288 .60874 L .23578 .59329 L p F P
0 g
s
.614 .552 .761 r
.53184 .41492 m .53944 .42677 L .53429 .42275 L p F P
0 g
s
.614 .552 .761 r
.53429 .42275 m .52649 .41088 L .53184 .41492 L p F P
0 g
s
0 0 0 r
.26324 .39644 m .25155 .40065 L .25978 .39782 L p F P
0 g
s
0 0 0 r
.25978 .39782 m .27128 .39274 L .26324 .39644 L p F P
0 g
s
.712 .576 .701 r
.36106 .6362 m .375 .64212 L .36983 .65529 L p F P
0 g
s
.712 .576 .701 r
.38398 .66019 m .36983 .65529 L .375 .64212 L p F P
0 g
s
.662 .575 .747 r
.4651 .32162 m .47311 .33271 L .4666 .33005 L p F P
0 g
s
.662 .575 .747 r
.4666 .33005 m .45839 .31972 L .4651 .32162 L p F P
0 g
s
.709 .574 .701 r
.30533 .6054 m .31926 .61417 L .31329 .62833 L p F P
0 g
s
.709 .574 .701 r
.31329 .62833 m .29916 .61975 L .30533 .6054 L p F P
0 g
s
.698 .531 .658 r
.10243 .44082 m .11564 .43174 L .10642 .4263 L p F P
0 g
s
.698 .531 .658 r
.10642 .4263 m .09302 .43485 L .10243 .44082 L p F P
0 g
s
.579 .544 .78 r
.55201 .4424 m .55941 .45332 L .55465 .44915 L p F P
0 g
s
.579 .544 .78 r
.55465 .44915 m .54705 .43819 L .55201 .4424 L p F P
0 g
s
.713 .577 .701 r
.38398 .66019 m .39812 .66435 L .39335 .67701 L p F P
0 g
s
.713 .577 .701 r
.4077 .68009 m .39335 .67701 L .39812 .66435 L p F P
0 g
s
.877 .518 .363 r
.6253 .53309 m .63147 .53932 L .62807 .53484 L p F P
0 g
s
.877 .518 .363 r
.62807 .53484 m .62169 .52847 L .6253 .53309 L p F P
0 g
s
.66 .417 .542 r
.21462 .41101 m .20231 .41526 L .21089 .41487 L p F P
0 g
s
.829 .562 .536 r
.64726 .55846 m .65282 .56282 L .64981 .55838 L p F P
0 g
s
.829 .562 .536 r
.64981 .55838 m .64405 .55384 L .64726 .55846 L p F P
0 g
s
.711 .575 .701 r
.34712 .62957 m .36106 .6362 L .35569 .64966 L p F P
0 g
s
.712 .576 .701 r
.36983 .65529 m .35569 .64966 L .36106 .6362 L p F P
0 g
s
.384 .481 .835 r
.58296 .48228 m .58996 .49145 L .58577 .48708 L p F P
0 g
s
.384 .481 .835 r
.58577 .48708 m .57858 .47784 L .58296 .48228 L p F P
0 g
s
.801 .571 .59 r
.66963 .58415 m .67437 .58622 L .67175 .58193 L p F P
0 g
s
.801 .571 .59 r
.67175 .58193 m .66681 .57964 L .66963 .58415 L p F P
0 g
s
.708 .573 .7 r
.27094 .60041 m .28505 .61044 L .27867 .62516 L p F P
0 g
s
.708 .573 .7 r
.27867 .62516 m .26436 .61529 L .27094 .60041 L p F P
0 g
s
.813 .876 .892 r
.36331 .33737 m .373 .33186 L .36551 .33735 L p F P
0 g
s
.813 .876 .892 r
.36551 .33735 m .35562 .34301 L .36331 .33737 L p F P
0 g
s
.691 .611 .762 r
.44195 .30424 m .45018 .31099 L .44328 .31051 L p F P
0 g
s
.691 .611 .762 r
.44328 .31051 m .43485 .30531 L .44195 .30424 L p F P
0 g
s
.643 .56 .746 r
.49525 .36061 m .50306 .37341 L .49713 .3697 L p F P
0 g
s
.643 .56 .746 r
.49713 .3697 m .48913 .35707 L .49525 .36061 L p F P
0 g
s
.71 .574 .701 r
.31926 .61417 m .33319 .62222 L .32742 .63617 L p F P
0 g
s
.71 .574 .701 r
.32742 .63617 m .31329 .62833 L .31926 .61417 L p F P
0 g
s
.71 .575 .701 r
.33319 .62222 m .34712 .62957 L .34155 .64328 L p F P
0 g
s
.711 .575 .701 r
.35569 .64966 m .34155 .64328 L .34712 .62957 L p F P
0 g
s
.71 .575 .701 r
.34155 .64328 m .32742 .63617 L .33319 .62222 L p F P
0 g
s
.813 .568 .569 r
.65885 .57193 m .664 .57518 L .66118 .57079 L p F P
0 g
s
.813 .568 .569 r
.66118 .57079 m .65583 .56734 L .65885 .57193 L p F P
0 g
s
.697 .526 .652 r
.12489 .43649 m .13788 .42841 L .12882 .42437 L p F P
0 g
s
.697 .526 .652 r
.12882 .42437 m .11564 .43174 L .12489 .43649 L p F P
0 g
s
.859 .406 .088 r
.61531 .52145 m .62169 .52847 L .61809 .52397 L p F P
0 g
s
.859 .406 .088 r
.61809 .52397 m .61152 .51683 L .61531 .52145 L p F P
0 g
s
.713 .577 .7 r
.39335 .67701 m .4077 .68009 L .40313 .69249 L p F P
0 g
s
.714 .577 .701 r
.41768 .69444 m .40313 .69249 L .4077 .68009 L p F P
0 g
s
.114 .359 .822 r
.59415 .49598 m .60094 .50447 L .59695 .50002 L p F P
0 g
s
.114 .359 .822 r
.59695 .50002 m .58996 .49145 L .59415 .49598 L p F P
0 g
s
.682 .476 .601 r
.18997 .4211 m .20231 .41526 L .19374 .41539 L p F P
0 g
s
.682 .476 .601 r
.19374 .41539 m .18122 .42026 L .18997 .4211 L p F P
0 g
s
.719 .652 .781 r
.42642 .30239 m .43485 .30531 L .42776 .30681 L p F P
0 g
s
.719 .652 .781 r
.42776 .30681 m .41912 .30553 L .42642 .30239 L p F P
0 g
s
.623 .553 .756 r
.52423 .40267 m .53184 .41492 L .52649 .41088 L p F P
0 g
s
.623 .553 .756 r
.52649 .41088 m .51868 .39865 L .52423 .40267 L p F P
0 g
s
0 0 .506 r
.60493 .50906 m .61152 .51683 L .60772 .51234 L p F P
0 g
s
0 0 .506 r
.60772 .51234 m .60094 .50447 L .60493 .50906 L p F P
0 g
s
.712 .576 .701 r
.36983 .65529 m .38398 .66019 L .37901 .67317 L p F P
0 g
s
.713 .577 .701 r
.39335 .67701 m .37901 .67317 L .38398 .66019 L p F P
0 g
s
.707 .572 .7 r
.25007 .60467 m .26436 .61529 L .25779 .63041 L p F P
0 g
s
.707 .572 .7 r
.25779 .63041 m .24329 .61996 L .25007 .60467 L p F P
0 g
s
.695 .517 .642 r
.14697 .43185 m .15974 .42462 L .15084 .42201 L p F P
0 g
s
.695 .517 .642 r
.15084 .42201 m .13788 .42841 L .14697 .43185 L p F P
0 g
s
.768 .738 .825 r
.40297 .31094 m .41182 .30907 L .40453 .31299 L p F P
0 g
s
.768 .738 .825 r
.40453 .31299 m .39547 .31597 L .40297 .31094 L p F P
0 g
s
.691 .503 .627 r
.16866 .42675 m .18122 .42026 L .17248 .41905 L p F P
0 g
s
.691 .503 .627 r
.17248 .41905 m .15974 .42462 L .16866 .42675 L p F P
0 g
s
.709 .573 .7 r
.28505 .61044 m .29916 .61975 L .29299 .63428 L p F P
0 g
s
.709 .573 .7 r
.29299 .63428 m .27867 .62516 L .28505 .61044 L p F P
0 g
s
.649 .563 .744 r
.48744 .34789 m .49525 .36061 L .48913 .35707 L p F P
0 g
s
.649 .563 .744 r
.48913 .35707 m .48112 .34465 L .48744 .34789 L p F P
0 g
s
.673 .585 .749 r
.45708 .31177 m .4651 .32162 L .45839 .31972 L p F P
0 g
s
.673 .585 .749 r
.45839 .31972 m .45018 .31099 L .45708 .31177 L p F P
0 g
s
.541 .533 .795 r
.56418 .45769 m .57138 .46804 L .56681 .46372 L p F P
0 g
s
.541 .533 .795 r
.56681 .46372 m .55941 .45332 L .56418 .45769 L p F P
0 g
s
.596 .547 .77 r
.5446 .431 m .55201 .4424 L .54705 .43819 L p F P
0 g
s
.596 .547 .77 r
.54705 .43819 m .53944 .42677 L .5446 .431 L p F P
0 g
s
.712 .576 .7 r
.35569 .64966 m .36983 .65529 L .36466 .66858 L p F P
0 g
s
.712 .576 .701 r
.37901 .67317 m .36466 .66858 L .36983 .65529 L p F P
0 g
s
.593 .293 .43 r
.24332 .40332 m .23141 .40804 L .23982 .40622 L p F P
0 g
s
.852 .552 .481 r
.63828 .5486 m .64405 .55384 L .64084 .54931 L p F P
0 g
s
.852 .552 .481 r
.64084 .54931 m .63488 .54391 L .63828 .5486 L p F P
0 g
s
.813 .863 .885 r
.371 .33164 m .38048 .32645 L .373 .33186 L p F P
0 g
s
.813 .863 .885 r
.373 .33186 m .36331 .33737 L .371 .33164 L p F P
0 g
s
.709 .574 .7 r
.29916 .61975 m .31329 .62833 L .30731 .64265 L p F P
0 g
s
.709 .574 .7 r
.30731 .64265 m .29299 .63428 L .29916 .61975 L p F P
0 g
s
.713 .576 .7 r
.37901 .67317 m .39335 .67701 L .38858 .68976 L p F P
0 g
s
.713 .577 .7 r
.40313 .69249 m .38858 .68976 L .39335 .67701 L p F P
0 g
s
.63 .555 .751 r
.51661 .39009 m .52423 .40267 L .51868 .39865 L p F P
0 g
s
.63 .555 .751 r
.51868 .39865 m .51087 .38613 L .51661 .39009 L p F P
0 g
s
.319 0 .044 r
.27128 .39274 m .25978 .39782 L .26801 .39474 L p F P
0 g
s
.708 .572 .7 r
.26436 .61529 m .27867 .62516 L .27229 .64009 L p F P
0 g
s
.708 .572 .7 r
.27229 .64009 m .25779 .63041 L .26436 .61529 L p F P
0 g
s
.711 .575 .7 r
.34155 .64328 m .35569 .64966 L .35032 .66323 L p F P
0 g
s
.712 .576 .7 r
.36466 .66858 m .35032 .66323 L .35569 .64966 L p F P
0 g
s
.71 .574 .7 r
.31329 .62833 m .32742 .63617 L .32165 .65027 L p F P
0 g
s
.71 .574 .7 r
.32165 .65027 m .30731 .64265 L .31329 .62833 L p F P
0 g
s
.655 .566 .743 r
.47963 .33549 m .48744 .34789 L .48112 .34465 L p F P
0 g
s
.655 .566 .743 r
.48112 .34465 m .47311 .33271 L .47963 .33549 L p F P
0 g
s
.71 .575 .7 r
.32742 .63617 m .34155 .64328 L .33598 .65713 L p F P
0 g
s
.711 .575 .7 r
.35032 .66323 m .33598 .65713 L .34155 .64328 L p F P
0 g
s
.71 .575 .7 r
.33598 .65713 m .32165 .65027 L .32742 .63617 L p F P
0 g
s
.476 .512 .815 r
.57596 .47255 m .58296 .48228 L .57858 .47784 L p F P
0 g
s
.476 .512 .815 r
.57858 .47784 m .57138 .46804 L .57596 .47255 L p F P
0 g
s
.83 .564 .537 r
.65048 .56316 m .65583 .56734 L .65282 .56282 L p F P
0 g
s
.83 .564 .537 r
.65282 .56282 m .64726 .55846 L .65048 .56316 L p F P
0 g
s
.712 .576 .7 r
.36466 .66858 m .37901 .67317 L .37404 .68626 L p F P
0 g
s
.713 .576 .7 r
.38858 .68976 m .37404 .68626 L .37901 .67317 L p F P
0 g
s
.878 .525 .374 r
.6289 .53783 m .63488 .54391 L .63147 .53932 L p F P
0 g
s
.878 .525 .374 r
.63147 .53932 m .6253 .53309 L .6289 .53783 L p F P
0 g
s
.779 .969 .92 r
.33784 .35481 m .34794 .34856 L .34026 .35402 L p F P
0 g
s
.709 .573 .7 r
.27867 .62516 m .29299 .63428 L .28681 .64901 L p F P
0 g
s
.709 .573 .7 r
.28681 .64901 m .27229 .64009 L .27867 .62516 L p F P
0 g
s
.753 .702 .804 r
.41047 .30609 m .41912 .30553 L .41182 .30907 L p F P
0 g
s
.753 .702 .804 r
.41182 .30907 m .40297 .31094 L .41047 .30609 L p F P
0 g
s
.637 .557 .748 r
.509 .37726 m .51661 .39009 L .51087 .38613 L p F P
0 g
s
.637 .557 .748 r
.51087 .38613 m .50306 .37341 L .509 .37726 L p F P
0 g
s
.609 .549 .763 r
.53719 .41915 m .5446 .431 L .53944 .42677 L p F P
0 g
s
.609 .549 .763 r
.53944 .42677 m .53184 .41492 L .53719 .41915 L p F P
0 g
s
.814 .57 .569 r
.66187 .57659 m .66681 .57964 L .664 .57518 L p F P
0 g
s
.814 .57 .569 r
.664 .57518 m .65885 .57193 L .66187 .57659 L p F P
0 g
s
.659 .429 .56 r
.21947 .41413 m .23141 .40804 L .22301 .40961 L p F P
0 g
s
.659 .429 .56 r
.22301 .40961 m .21089 .41487 L .21947 .41413 L p F P
0 g
s
.357 .799 .643 r
.3035 .37655 m .31421 .37023 L .30634 .37503 L p F P
0 g
s
.569 .539 .782 r
.55697 .44681 m .56418 .45769 L .55941 .45332 L p F P
0 g
s
.569 .539 .782 r
.55941 .45332 m .55201 .4424 L .55697 .44681 L p F P
0 g
s
.808 .834 .87 r
.3787 .32582 m .38798 .32115 L .38048 .32645 L p F P
0 g
s
.808 .834 .87 r
.38048 .32645 m .371 .33164 L .3787 .32582 L p F P
0 g
s
.348 .463 .835 r
.58735 .4869 m .59415 .49598 L .58996 .49145 L p F P
0 g
s
.348 .463 .835 r
.58996 .49145 m .58296 .48228 L .58735 .4869 L p F P
0 g
s
.709 .63 .766 r
.43372 .29965 m .44195 .30424 L .43485 .30531 L p F P
0 g
s
.709 .63 .766 r
.43485 .30531 m .42642 .30239 L .43372 .29965 L p F P
0 g
s
.662 .572 .743 r
.47181 .32368 m .47963 .33549 L .47311 .33271 L p F P
0 g
s
.662 .572 .743 r
.47311 .33271 m .4651 .32162 L .47181 .32368 L p F P
0 g
s
.686 .598 .752 r
.44906 .30358 m .45708 .31177 L .45018 .31099 L p F P
0 g
s
.686 .598 .752 r
.45018 .31099 m .44195 .30424 L .44906 .30358 L p F P
0 g
s
.711 .575 .7 r
.35032 .66323 m .36466 .66858 L .35949 .68199 L p F P
0 g
s
.712 .576 .7 r
.37404 .68626 m .35949 .68199 L .36466 .66858 L p F P
0 g
s
.87 .428 .125 r
.61911 .52621 m .6253 .53309 L .62169 .52847 L p F P
0 g
s
.87 .428 .125 r
.62169 .52847 m .61531 .52145 L .61911 .52621 L p F P
0 g
s
.709 .573 .7 r
.29299 .63428 m .30731 .64265 L .30134 .65715 L p F P
0 g
s
.709 .573 .7 r
.30134 .65715 m .28681 .64901 L .29299 .63428 L p F P
0 g
s
.045 .317 .803 r
.59834 .50067 m .60493 .50906 L .60094 .50447 L p F P
0 g
s
.045 .317 .803 r
.60094 .50447 m .59415 .49598 L .59834 .50067 L p F P
0 g
s
.565 .089 0 r
.60893 .5138 m .61531 .52145 L .61152 .51683 L p F P
0 g
s
.565 .089 0 r
.61152 .51683 m .60493 .50906 L .60893 .5138 L p F P
0 g
s
.643 .559 .745 r
.50138 .36426 m .509 .37726 L .50306 .37341 L p F P
0 g
s
.643 .559 .745 r
.50306 .37341 m .49525 .36061 L .50138 .36426 L p F P
0 g
s
.711 .575 .7 r
.33598 .65713 m .35032 .66323 L .34495 .67694 L p F P
0 g
s
.711 .575 .7 r
.35949 .68199 m .34495 .67694 L .35032 .66323 L p F P
0 g
s
.71 .574 .7 r
.30731 .64265 m .32165 .65027 L .31587 .66452 L p F P
0 g
s
.71 .574 .7 r
.31587 .66452 m .30134 .65715 L .30731 .64265 L p F P
0 g
s
.71 .574 .7 r
.32165 .65027 m .33598 .65713 L .33041 .67111 L p F P
0 g
s
.711 .575 .7 r
.34495 .67694 m .33041 .67111 L .33598 .65713 L p F P
0 g
s
.71 .574 .7 r
.33041 .67111 m .31587 .66452 L .32165 .65027 L p F P
0 g
s
.422 .049 .222 r
.27933 .38896 m .26801 .39474 L .27626 .39139 L p F P
0 g
s
.619 .551 .756 r
.52978 .40687 m .53719 .41915 L .53184 .41492 L p F P
0 g
s
.619 .551 .756 r
.53184 .41492 m .52423 .40267 L .52978 .40687 L p F P
0 g
s
.604 .33 .475 r
.25155 .40065 m .23982 .40622 L .24824 .40408 L p F P
0 g
s
.854 .555 .483 r
.6417 .55338 m .64726 .55846 L .64405 .55384 L p F P
0 g
s
.854 .555 .483 r
.64405 .55384 m .63828 .5486 L .6417 .55338 L p F P
0 g
s
.679 .477 .606 r
.19873 .42151 m .21089 .41487 L .20231 .41526 L p F P
0 g
s
.679 .477 .606 r
.20231 .41526 m .18997 .4211 L .19873 .42151 L p F P
0 g
s
.788 .971 .915 r
.34572 .34925 m .35562 .34301 L .34794 .34856 L p F P
0 g
s
.788 .971 .915 r
.34794 .34856 m .33784 .35481 L .34572 .34925 L p F P
0 g
s
.529 .527 .797 r
.56896 .46225 m .57596 .47255 L .57138 .46804 L p F P
0 g
s
.529 .527 .797 r
.57138 .46804 m .56418 .45769 L .56896 .46225 L p F P
0 g
s
.672 .579 .743 r
.46399 .31281 m .47181 .32368 L .4651 .32162 L p F P
0 g
s
.672 .579 .743 r
.4651 .32162 m .45708 .31177 L .46399 .31281 L p F P
0 g
s
.797 .795 .85 r
.3864 .31995 m .39547 .31597 L .38798 .32115 L p F P
0 g
s
.797 .795 .85 r
.38798 .32115 m .3787 .32582 L .3864 .31995 L p F P
0 g
s
.59 .544 .771 r
.54976 .43542 m .55697 .44681 L .55201 .4424 L p F P
0 g
s
.59 .544 .771 r
.55201 .4424 m .5446 .431 L .54976 .43542 L p F P
0 g
s
.649 .561 .742 r
.49377 .35125 m .50138 .36426 L .49525 .36061 L p F P
0 g
s
.649 .561 .742 r
.49525 .36061 m .48744 .34789 L .49377 .35125 L p F P
0 g
s
.739 .672 .785 r
.41797 .30148 m .42642 .30239 L .41912 .30553 L p F P
0 g
s
.739 .672 .785 r
.41912 .30553 m .41047 .30609 L .41797 .30148 L p F P
0 g
s
0 0 0 r
.31421 .37023 m .3035 .37655 L .31157 .3719 L p F P
0 g
s
.688 .5 .628 r
.1776 .42835 m .18997 .4211 L .18122 .42026 L p F P
0 g
s
.688 .5 .628 r
.18122 .42026 m .16866 .42675 L .1776 .42835 L p F P
0 g
s
.832 .566 .536 r
.65369 .56794 m .65885 .57193 L .65583 .56734 L p F P
0 g
s
.832 .566 .536 r
.65583 .56734 m .65048 .56316 L .65369 .56794 L p F P
0 g
s
.628 .553 .751 r
.52236 .39421 m .52978 .40687 L .52423 .40267 L p F P
0 g
s
.628 .553 .751 r
.52423 .40267 m .51661 .39009 L .52236 .39421 L p F P
0 g
s
.816 .571 .568 r
.66489 .58131 m .66963 .58415 L .66681 .57964 L p F P
0 g
s
.816 .571 .568 r
.66681 .57964 m .66187 .57659 L .66489 .58131 L p F P
0 g
s
.697 .529 .657 r
.11186 .44603 m .12489 .43649 L .11564 .43174 L p F P
0 g
s
.697 .529 .657 r
.11564 .43174 m .10243 .44082 L .11186 .44603 L p F P
0 g
s
.88 .529 .38 r
.63251 .54267 m .63828 .5486 L .63488 .54391 L p F P
0 g
s
.88 .529 .38 r
.63488 .54391 m .6289 .53783 L .63251 .54267 L p F P
0 g
s
.692 .514 .642 r
.15607 .43467 m .16866 .42675 L .15974 .42462 L p F P
0 g
s
.692 .514 .642 r
.15974 .42462 m .14697 .43185 L .15607 .43467 L p F P
0 g
s
.459 .503 .817 r
.58054 .47722 m .58735 .4869 L .58296 .48228 L p F P
0 g
s
.459 .503 .817 r
.58296 .48228 m .57596 .47255 L .58054 .47722 L p F P
0 g
s
.695 .523 .65 r
.13416 .44052 m .14697 .43185 L .13788 .42841 L p F P
0 g
s
.695 .523 .65 r
.13788 .42841 m .12489 .43649 L .13416 .44052 L p F P
0 g
s
.655 .564 .741 r
.48615 .33838 m .49377 .35125 L .48744 .34789 L p F P
0 g
s
.655 .564 .741 r
.48744 .34789 m .47963 .33549 L .48615 .33838 L p F P
0 g
s
.702 .613 .755 r
.44102 .29734 m .44906 .30358 L .44195 .30424 L p F P
0 g
s
.702 .613 .755 r
.44195 .30424 m .43372 .29965 L .44102 .29734 L p F P
0 g
s
.807 .955 .913 r
.35361 .34347 m .36331 .33737 L .35562 .34301 L p F P
0 g
s
.807 .955 .913 r
.35562 .34301 m .34572 .34925 L .35361 .34347 L p F P
0 g
s
.655 .432 .569 r
.22807 .41298 m .23982 .40622 L .23141 .40804 L p F P
0 g
s
.655 .432 .569 r
.23141 .40804 m .21947 .41413 L .22807 .41298 L p F P
0 g
s
.784 .756 .827 r
.3941 .31404 m .40297 .31094 L .39547 .31597 L p F P
0 g
s
.784 .756 .827 r
.39547 .31597 m .3864 .31995 L .3941 .31404 L p F P
0 g
s
.32 .447 .833 r
.59174 .49167 m .59834 .50067 L .59415 .49598 L p F P
0 g
s
.32 .447 .833 r
.59415 .49598 m .58735 .4869 L .59174 .49167 L p F P
0 g
s
.877 .442 .146 r
.62292 .53107 m .6289 .53783 L .6253 .53309 L p F P
0 g
s
.877 .442 .146 r
.6253 .53309 m .61911 .52621 L .62292 .53107 L p F P
0 g
s
.605 .547 .763 r
.54255 .42355 m .54976 .43542 L .5446 .431 L p F P
0 g
s
.605 .547 .763 r
.5446 .431 m .53719 .41915 L .54255 .42355 L p F P
0 g
s
.449 .103 .285 r
.28738 .38504 m .27626 .39139 L .28451 .3877 L p F P
0 g
s
.683 .589 .745 r
.45616 .30329 m .46399 .31281 L .45708 .31177 L p F P
0 g
s
.683 .589 .745 r
.45708 .31177 m .44906 .30358 L .45616 .30329 L p F P
0 g
s
.562 .536 .783 r
.56195 .45139 m .56896 .46225 L .56418 .45769 L p F P
0 g
s
.562 .536 .783 r
.56418 .45769 m .55697 .44681 L .56195 .45139 L p F P
0 g
s
.636 .555 .747 r
.51494 .38124 m .52236 .39421 L .51661 .39009 L p F P
0 g
s
.636 .555 .747 r
.51661 .39009 m .509 .37726 L .51494 .38124 L p F P
0 g
s
0 .283 .783 r
.60253 .5055 m .60893 .5138 L .60493 .50906 L p F P
0 g
s
0 .283 .783 r
.60493 .50906 m .59834 .50067 L .60253 .5055 L p F P
0 g
s
.612 .133 0 r
.61293 .51866 m .61911 .52621 L .61531 .52145 L p F P
0 g
s
.612 .133 0 r
.61531 .52145 m .60967 .51469 L p .61293 .51866 L F P
0 g
s
0 .241 .757 r
.61093 .51552 m .61622 .52268 L p .61293 .51866 L F P
0 g
s
.638 .159 0 r
.61911 .52621 m .61357 .51945 L p .61693 .52364 L F P
0 g
s
.638 .159 0 r
.61357 .51945 m .61293 .51866 L .61693 .52364 L p F P
0 g
s
.638 .159 0 r
.61693 .52364 m .62292 .53107 L .61911 .52621 L p F P
0 g
s
0 .232 .751 r
.61514 .5207 m .62033 .52787 L p .61693 .52364 L F P
0 g
s
.648 .173 0 r
.62292 .53107 m .61749 .52433 L p .62094 .52871 L F P
0 g
s
.648 .173 0 r
.61749 .52433 m .61693 .52364 L .62094 .52871 L p F P
0 g
s
.881 .451 .157 r
.6289 .53783 m .62292 .53107 L .62673 .53604 L p F P
0 g
s
.648 .173 0 r
.62094 .52871 m .62673 .53604 L .62292 .53107 L p F P
0 g
s
0 .23 .749 r
.61935 .52597 m .62442 .53314 L p .62094 .52871 L F P
0 g
s
.648 .176 0 r
.62673 .53604 m .62143 .52934 L p .62495 .53389 L F P
0 g
s
.648 .176 0 r
.62143 .52934 m .62094 .52871 L .62495 .53389 L p F P
0 g
s
.881 .451 .157 r
.62673 .53604 m .63251 .54267 L .6289 .53783 L p F P
0 g
s
.884 .456 .159 r
.63251 .54267 m .62673 .53604 L .63054 .5411 L p F P
0 g
s
.648 .176 0 r
.62495 .53389 m .63054 .5411 L .62673 .53604 L p F P
0 g
s
0 .233 .75 r
.62356 .53134 m .62849 .53849 L p .62495 .53389 L F P
0 g
s
.638 .171 0 r
.63054 .5411 m .62539 .53446 L p .62896 .53916 L F P
0 g
s
.638 .171 0 r
.62539 .53446 m .62495 .53389 L .62896 .53916 L p F P
0 g
s
.884 .456 .159 r
.63054 .5411 m .63612 .5476 L .63251 .54267 L p F P
0 g
s
.885 .457 .154 r
.63612 .5476 m .63054 .5411 L .63435 .54625 L p F P
0 g
s
.638 .171 0 r
.62896 .53916 m .63435 .54625 L .63054 .5411 L p F P
0 g
s
0 .239 .754 r
.62778 .5368 m .63256 .5439 L p .62896 .53916 L F P
0 g
s
.621 .16 0 r
.63435 .54625 m .62935 .53968 L p .63298 .54451 L F P
0 g
s
.621 .16 0 r
.62935 .53968 m .62896 .53916 L .63298 .54451 L p F P
0 g
s
.885 .457 .154 r
.63435 .54625 m .63974 .55262 L .63612 .5476 L p F P
0 g
s
.885 .456 .143 r
.63974 .55262 m .63435 .54625 L .63817 .55149 L p F P
0 g
s
.621 .16 0 r
.63298 .54451 m .63817 .55149 L .63435 .54625 L p F P
0 g
s
0 .248 .758 r
.632 .54234 m .63663 .54939 L p .63298 .54451 L F P
0 g
s
.596 .143 0 r
.63817 .55149 m .63298 .54451 L .637 .54995 L p F P
0 g
s
0 .248 .758 r
.63663 .54939 m .637 .54995 L .63298 .54451 L p F P
0 g
s
0 .239 .754 r
.63256 .5439 m .63298 .54451 L .62896 .53916 L p F P
0 g
s
0 .233 .75 r
.62849 .53849 m .62896 .53916 L .62495 .53389 L p F P
0 g
s
0 .23 .749 r
.62442 .53314 m .62495 .53389 L .62094 .52871 L p F P
0 g
s
0 .232 .751 r
.62033 .52787 m .62094 .52871 L .61693 .52364 L p F P
0 g
s
0 .241 .757 r
.61622 .52268 m .61693 .52364 L .61293 .51866 L p F P
0 g
s
.612 .133 0 r
.60967 .51469 m .60893 .5138 L .61293 .51866 L p F P
0 g
s
0 0 0 r
.32208 .36528 m .31157 .3719 L .31964 .36695 L p F P
0 g
s
.604 .342 .493 r
.25667 .40157 m .26801 .39474 L .25978 .39782 L p F P
0 g
s
.604 .342 .493 r
.25978 .39782 m .24824 .40408 L .25667 .40157 L p F P
0 g
s
.662 .569 .74 r
.47853 .3259 m .48615 .33838 L .47963 .33549 L p F P
0 g
s
.662 .569 .74 r
.47963 .33549 m .47181 .32368 L .47853 .3259 L p F P
0 g
s
.727 .648 .77 r
.42547 .29716 m .43372 .29965 L .42642 .30239 L p F P
0 g
s
.727 .648 .77 r
.42642 .30239 m .41797 .30148 L .42547 .29716 L p F P
0 g
s
.855 .557 .483 r
.64511 .55825 m .65048 .56316 L .64726 .55846 L p F P
0 g
s
.855 .557 .483 r
.64726 .55846 m .6417 .55338 L .64511 .55825 L p F P
0 g
s
.821 .92 .903 r
.36151 .33745 m .371 .33164 L .36331 .33737 L p F P
0 g
s
.821 .92 .903 r
.36331 .33737 m .35361 .34347 L .36151 .33745 L p F P
0 g
s
.642 .557 .743 r
.50752 .36804 m .51494 .38124 L .509 .37726 L p F P
0 g
s
.642 .557 .743 r
.509 .37726 m .50138 .36426 L .50752 .36804 L p F P
0 g
s
.617 .55 .756 r
.53533 .41121 m .54255 .42355 L .53719 .41915 L p F P
0 g
s
.617 .55 .756 r
.53719 .41915 m .52978 .40687 L .53533 .41121 L p F P
0 g
s
.519 .522 .798 r
.57374 .46696 m .58054 .47722 L .57596 .47255 L p F P
0 g
s
.519 .522 .798 r
.57596 .47255 m .56896 .46225 L .57374 .46696 L p F P
0 g
s
.674 .474 .607 r
.20751 .42142 m .21947 .41413 L .21089 .41487 L p F P
0 g
s
.674 .474 .607 r
.21089 .41487 m .19873 .42151 L .20751 .42142 L p F P
0 g
s
.834 .568 .536 r
.65691 .57278 m .66187 .57659 L .65885 .57193 L p F P
0 g
s
.834 .568 .536 r
.65885 .57193 m .65369 .56794 L .65691 .57278 L p F P
0 g
s
.769 .72 .806 r
.4018 .30813 m .41047 .30609 L .40297 .31094 L p F P
0 g
s
.769 .72 .806 r
.40297 .31094 m .3941 .31404 L .4018 .30813 L p F P
0 g
s
.67 .575 .739 r
.4709 .31412 m .47853 .3259 L .47181 .32368 L p F P
0 g
s
.67 .575 .739 r
.47181 .32368 m .46399 .31281 L .4709 .31412 L p F P
0 g
s
.585 .541 .772 r
.55493 .44 m .56195 .45139 L .55697 .44681 L p F P
0 g
s
.585 .541 .772 r
.55697 .44681 m .54976 .43542 L .55493 .44 L p F P
0 g
s
.882 .533 .383 r
.63612 .5476 m .6417 .55338 L .63828 .5486 L p F P
0 g
s
.882 .533 .383 r
.63828 .5486 m .63251 .54267 L .63612 .5476 L p F P
0 g
s
.649 .56 .741 r
.5001 .35471 m .50752 .36804 L .50138 .36426 L p F P
0 g
s
.649 .56 .741 r
.50138 .36426 m .49377 .35125 L .5001 .35471 L p F P
0 g
s
.444 .107 .298 r
.29544 .38092 m .28451 .3877 L .29277 .38366 L p F P
0 g
s
0 0 0 r
.32996 .36015 m .31964 .36695 L .32772 .36169 L p F P
0 g
s
.696 .601 .747 r
.44833 .29547 m .45616 .30329 L .44906 .30358 L p F P
0 g
s
.696 .601 .747 r
.44906 .30358 m .44102 .29734 L .44833 .29547 L p F P
0 g
s
.445 .495 .817 r
.58513 .48205 m .59174 .49167 L .58735 .4869 L p F P
0 g
s
.445 .495 .817 r
.58735 .4869 m .58054 .47722 L .58513 .48205 L p F P
0 g
s
.821 .872 .883 r
.3694 .33121 m .3787 .32582 L .371 .33164 L p F P
0 g
s
.821 .872 .883 r
.371 .33164 m .36151 .33745 L .3694 .33121 L p F P
0 g
s
.627 .552 .751 r
.52811 .39847 m .53533 .41121 L .52978 .40687 L p F P
0 g
s
.627 .552 .751 r
.52978 .40687 m .52236 .39421 L .52811 .39847 L p F P
0 g
s
.684 .497 .628 r
.18655 .42937 m .19873 .42151 L .18997 .4211 L p F P
0 g
s
.684 .497 .628 r
.18997 .4211 m .1776 .42835 L .18655 .42937 L p F P
0 g
s
.65 .43 .571 r
.23669 .41139 m .24824 .40408 L .23982 .40622 L p F P
0 g
s
.65 .43 .571 r
.23982 .40622 m .22807 .41298 L .23669 .41139 L p F P
0 g
s
.718 .629 .758 r
.43298 .29318 m .44102 .29734 L .43372 .29965 L p F P
0 g
s
.718 .629 .758 r
.43372 .29965 m .42547 .29716 L .43298 .29318 L p F P
0 g
s
.598 .341 .498 r
.26511 .39865 m .27626 .39139 L .26801 .39474 L p F P
0 g
s
.598 .341 .498 r
.26801 .39474 m .25667 .40157 L .26511 .39865 L p F P
0 g
s
.655 .563 .738 r
.49268 .34141 m .5001 .35471 L .49377 .35125 L p F P
0 g
s
.655 .563 .738 r
.49377 .35125 m .48615 .33838 L .49268 .34141 L p F P
0 g
s
.298 .434 .83 r
.59613 .49657 m .60253 .5055 L .59834 .50067 L p F P
0 g
s
.298 .434 .83 r
.59834 .50067 m .59174 .49167 L .59613 .49657 L p F P
0 g
s
.755 .689 .788 r
.40951 .30228 m .41797 .30148 L .41047 .30609 L p F P
0 g
s
.755 .689 .788 r
.41047 .30609 m .4018 .30813 L .40951 .30228 L p F P
0 g
s
.68 .583 .739 r
.46327 .30337 m .4709 .31412 L .46399 .31281 L p F P
0 g
s
.68 .583 .739 r
.46399 .31281 m .45616 .30329 L .46327 .30337 L p F P
0 g
s
.858 .559 .482 r
.64853 .5632 m .65369 .56794 L .65048 .56316 L p F P
0 g
s
.858 .559 .482 r
.65048 .56316 m .64511 .55825 L .64853 .5632 L p F P
0 g
s
0 .258 .768 r
.60673 .51046 m .61293 .51866 L .60893 .5138 L p F P
0 g
s
0 .258 .768 r
.60893 .5138 m .60253 .5055 L .60673 .51046 L p F P
0 g
s
.556 .532 .783 r
.56692 .45613 m .57374 .46696 L .56896 .46225 L p F P
0 g
s
.556 .532 .783 r
.56896 .46225 m .56195 .45139 L .56692 .45613 L p F P
0 g
s
.602 .545 .763 r
.54791 .4281 m .55493 .44 L .54976 .43542 L p F P
0 g
s
.602 .545 .763 r
.54976 .43542 m .54255 .42355 L .54791 .4281 L p F P
0 g
s
.689 .511 .64 r
.1652 .43684 m .1776 .42835 L .16866 .42675 L p F P
0 g
s
.689 .511 .64 r
.16866 .42675 m .15607 .43467 L .1652 .43684 L p F P
0 g
s
.635 .554 .746 r
.52089 .38535 m .52811 .39847 L .52236 .39421 L p F P
0 g
s
.635 .554 .746 r
.52236 .39421 m .51494 .38124 L .52089 .38535 L p F P
0 g
s
.507 .883 .685 r
.33581 .35609 m .34572 .34925 L .33784 .35481 L p F P
0 g
s
.507 .883 .685 r
.33784 .35481 m .33267 .35833 L p .33581 .35609 L F P
0 g
s
.695 .982 .836 r
.34572 .34925 m .33581 .35609 L .3439 .35015 L p F P
0 g
s
0 0 0 r
.33416 .35742 m .33903 .35379 L p .33581 .35609 L F P
0 g
s
0 0 0 r
.33903 .35379 m .3439 .35015 L .33581 .35609 L p F P
0 g
s
.507 .883 .685 r
.33267 .35833 m .32772 .36169 L .33581 .35609 L p F P
0 g
s
.812 .821 .857 r
.37731 .32477 m .3864 .31995 L .3787 .32582 L p F P
0 g
s
.812 .821 .857 r
.3787 .32582 m .3694 .33121 L .37731 .32477 L p F P
0 g
s
.837 .569 .534 r
.66014 .5777 m .66489 .58131 L .66187 .57659 L p F P
0 g
s
.837 .569 .534 r
.66187 .57659 m .65691 .57278 L .66014 .5777 L p F P
0 g
s
.662 .566 .737 r
.48525 .32831 m .49268 .34141 L .48615 .33838 L p F P
0 g
s
.662 .566 .737 r
.48615 .33838 m .47853 .3259 L .48525 .32831 L p F P
0 g
s
.415 .075 .278 r
.3035 .37655 m .29277 .38366 L .30103 .37923 L p F P
0 g
s
.693 .52 .649 r
.14345 .44385 m .15607 .43467 L .14697 .43185 L p F P
0 g
s
.693 .52 .649 r
.14697 .43185 m .13416 .44052 L .14345 .44385 L p F P
0 g
s
.695 .526 .655 r
.12132 .45048 m .13416 .44052 L .12489 .43649 L p F P
0 g
s
.695 .526 .655 r
.12489 .43649 m .11186 .44603 L .12132 .45048 L p F P
0 g
s
.512 .517 .798 r
.57852 .47182 m .58513 .48205 L .58054 .47722 L p F P
0 g
s
.512 .517 .798 r
.58054 .47722 m .57374 .46696 L .57852 .47182 L p F P
0 g
s
.885 .536 .382 r
.63974 .55262 m .64511 .55825 L .6417 .55338 L p F P
0 g
s
.885 .536 .382 r
.6417 .55338 m .63612 .5476 L .63974 .55262 L p F P
0 g
s
.67 .47 .606 r
.2163 .42082 m .22807 .41298 L .21947 .41413 L p F P
0 g
s
.67 .47 .606 r
.21947 .41413 m .20751 .42142 L .2163 .42082 L p F P
0 g
s
.642 .556 .742 r
.51366 .37193 m .52089 .38535 L .51494 .38124 L p F P
0 g
s
.642 .556 .742 r
.51494 .38124 m .50752 .36804 L .51366 .37193 L p F P
0 g
s
.743 .665 .773 r
.41721 .29655 m .42547 .29716 L .41797 .30148 L p F P
0 g
s
.743 .665 .773 r
.41797 .30148 m .40951 .30228 L .41721 .29655 L p F P
0 g
s
.615 .548 .756 r
.54089 .41571 m .54791 .4281 L .54255 .42355 L p F P
0 g
s
.615 .548 .756 r
.54255 .42355 m .53533 .41121 L .54089 .41571 L p F P
0 g
s
.71 .615 .749 r
.44049 .28959 m .44833 .29547 L .44102 .29734 L p F P
0 g
s
.71 .615 .749 r
.44102 .29734 m .43298 .29318 L .44049 .28959 L p F P
0 g
s
.691 .592 .74 r
.45564 .29403 m .46327 .30337 L .45616 .30329 L p F P
0 g
s
.691 .592 .74 r
.45616 .30329 m .44833 .29547 L .45564 .29403 L p F P
0 g
s
.669 .571 .736 r
.47782 .31567 m .48525 .32831 L .47853 .3259 L p F P
0 g
s
.669 .571 .736 r
.47853 .3259 m .4709 .31412 L .47782 .31567 L p F P
0 g
s
.582 .539 .772 r
.5601 .44473 m .56692 .45613 L .56195 .45139 L p F P
0 g
s
.582 .539 .772 r
.56195 .45139 m .55493 .44 L .5601 .44473 L p F P
0 g
s
.798 .776 .832 r
.38521 .31815 m .3941 .31404 L .3864 .31995 L p F P
0 g
s
.798 .776 .832 r
.3864 .31995 m .37731 .32477 L .38521 .31815 L p F P
0 g
s
.587 .329 .493 r
.27356 .39531 m .28451 .3877 L .27626 .39139 L p F P
0 g
s
.587 .329 .493 r
.27626 .39139 m .26511 .39865 L .27356 .39531 L p F P
0 g
s
.695 .982 .836 r
.3439 .35015 m .35361 .34347 L .34572 .34925 L p F P
0 g
s
.435 .489 .816 r
.58972 .48701 m .59613 .49657 L .59174 .49167 L p F P
0 g
s
.435 .489 .816 r
.59174 .49167 m .58513 .48205 L .58972 .48701 L p F P
0 g
s
.644 .423 .569 r
.24531 .40933 m .25667 .40157 L .24824 .40408 L p F P
0 g
s
.644 .423 .569 r
.24824 .40408 m .23669 .41139 L .24531 .40933 L p F P
0 g
s
.649 .558 .739 r
.50644 .3583 m .51366 .37193 L .50752 .36804 L p F P
0 g
s
.649 .558 .739 r
.50752 .36804 m .5001 .35471 L .50644 .3583 L p F P
0 g
s
.86 .561 .48 r
.65195 .56822 m .65691 .57278 L .65369 .56794 L p F P
0 g
s
.86 .561 .48 r
.65369 .56794 m .64853 .5632 L .65195 .56822 L p F P
0 g
s
.355 .002 .22 r
.30931 .3744 m .31964 .36695 L .31157 .3719 L p F P
0 g
s
.355 .002 .22 r
.31157 .3719 m .30103 .37923 L .30931 .3744 L p F P
0 g
s
.626 .55 .75 r
.53387 .40285 m .54089 .41571 L .53533 .41121 L p F P
0 g
s
.626 .55 .75 r
.53533 .41121 m .52811 .39847 L .53387 .40285 L p F P
0 g
s
.283 .424 .827 r
.60053 .5016 m .60673 .51046 L .60253 .5055 L p F P
0 g
s
.283 .424 .827 r
.60253 .5055 m .59613 .49657 L .60053 .5016 L p F P
0 g
s
0 .241 .757 r
.61293 .51866 m .60673 .51046 L .61093 .51552 L p F P
0 g
s
.68 .493 .626 r
.19552 .4298 m .20751 .42142 L .19873 .42151 L p F P
0 g
s
.68 .493 .626 r
.19873 .42151 m .18655 .42937 L .19552 .4298 L p F P
0 g
s
.678 .577 .735 r
.47039 .3038 m .47782 .31567 L .4709 .31412 L p F P
0 g
s
.678 .577 .735 r
.4709 .31412 m .46327 .30337 L .47039 .3038 L p F P
0 g
s
.733 .644 .761 r
.42492 .29101 m .43298 .29318 L .42547 .29716 L p F P
0 g
s
.733 .644 .761 r
.42547 .29716 m .41721 .29655 L .42492 .29101 L p F P
0 g
s
.655 .561 .737 r
.49921 .34457 m .50644 .3583 L .5001 .35471 L p F P
0 g
s
.655 .561 .737 r
.5001 .35471 m .49268 .34141 L .49921 .34457 L p F P
0 g
s
.552 .529 .783 r
.5719 .461 m .57852 .47182 L .57374 .46696 L p F P
0 g
s
.552 .529 .783 r
.57374 .46696 m .56692 .45613 L .5719 .461 L p F P
0 g
s
.784 .737 .81 r
.39312 .31137 m .4018 .30813 L .3941 .31404 L p F P
0 g
s
.784 .737 .81 r
.3941 .31404 m .38521 .31815 L .39312 .31137 L p F P
0 g
s
.6 .543 .762 r
.55328 .43279 m .5601 .44473 L .55493 .44 L p F P
0 g
s
.6 .543 .762 r
.55493 .44 m .54791 .4281 L .55328 .43279 L p F P
0 g
s
.801 .98 .899 r
.35199 .34388 m .36151 .33745 L .35361 .34347 L p F P
0 g
s
.801 .98 .899 r
.35361 .34347 m .3439 .35015 L .35199 .34388 L p F P
0 g
s
.634 .553 .745 r
.52684 .38958 m .53387 .40285 L .52811 .39847 L p F P
0 g
s
.634 .553 .745 r
.52811 .39847 m .52089 .38535 L .52684 .38958 L p F P
0 g
s
.887 .538 .379 r
.64335 .55772 m .64853 .5632 L .64511 .55825 L p F P
0 g
s
.887 .538 .379 r
.64511 .55825 m .63974 .55262 L .64335 .55772 L p F P
0 g
s
.703 .603 .741 r
.448 .28645 m .45564 .29403 L .44833 .29547 L p F P
0 g
s
.703 .603 .741 r
.44833 .29547 m .44049 .28959 L .448 .28645 L p F P
0 g
s
.662 .564 .735 r
.49198 .3309 m .49921 .34457 L .49268 .34141 L p F P
0 g
s
.662 .564 .735 r
.49268 .34141 m .48525 .32831 L .49198 .3309 L p F P
0 g
s
.57 .308 .48 r
.28201 .39151 m .29277 .38366 L .28451 .3877 L p F P
0 g
s
.57 .308 .48 r
.28451 .3877 m .27356 .39531 L .28201 .39151 L p F P
0 g
s
.686 .507 .638 r
.17434 .43834 m .18655 .42937 L .1776 .42835 L p F P
0 g
s
.686 .507 .638 r
.1776 .42835 m .1652 .43684 L .17434 .43834 L p F P
0 g
s
.507 .513 .798 r
.58331 .47682 m .58972 .48701 L .58513 .48205 L p F P
0 g
s
.507 .513 .798 r
.58513 .48205 m .57852 .47182 L .58331 .47682 L p F P
0 g
s
.246 0 .107 r
.31758 .36917 m .32772 .36169 L .31964 .36695 L p F P
0 g
s
.246 0 .107 r
.31964 .36695 m .30931 .3744 L .31758 .36917 L p F P
0 g
s
.664 .464 .603 r
.2251 .41967 m .23669 .41139 L .22807 .41298 L p F P
0 g
s
.664 .464 .603 r
.22807 .41298 m .2163 .42082 L .2251 .41967 L p F P
0 g
s
.687 .585 .735 r
.46296 .29305 m .47039 .3038 L .46327 .30337 L p F P
0 g
s
.687 .585 .735 r
.46327 .30337 m .45564 .29403 L .46296 .29305 L p F P
0 g
s
.77 .706 .791 r
.40103 .30449 m .40951 .30228 L .4018 .30813 L p F P
0 g
s
.77 .706 .791 r
.4018 .30813 m .39312 .31137 L .40103 .30449 L p F P
0 g
s
.831 .922 .895 r
.36009 .33728 m .3694 .33121 L .36151 .33745 L p F P
0 g
s
.831 .922 .895 r
.36151 .33745 m .35199 .34388 L .36009 .33728 L p F P
0 g
s
.635 .413 .564 r
.25394 .40676 m .26511 .39865 L .25667 .40157 L p F P
0 g
s
.635 .413 .564 r
.25667 .40157 m .24531 .40933 L .25394 .40676 L p F P
0 g
s
.614 .546 .755 r
.54646 .42033 m .55328 .43279 L .54791 .4281 L p F P
0 g
s
.614 .546 .755 r
.54791 .4281 m .54089 .41571 L .54646 .42033 L p F P
0 g
s
.642 .555 .741 r
.51981 .37595 m .52684 .38958 L .52089 .38535 L p F P
0 g
s
.642 .555 .741 r
.52089 .38535 m .51366 .37193 L .51981 .37595 L p F P
0 g
s
.724 .628 .751 r
.43264 .28574 m .44049 .28959 L .43298 .29318 L p F P
0 g
s
.724 .628 .751 r
.43298 .29318 m .42492 .29101 L .43264 .28574 L p F P
0 g
s
.668 .568 .733 r
.48475 .31748 m .49198 .3309 L .48525 .32831 L p F P
0 g
s
.668 .568 .733 r
.48525 .32831 m .47782 .31567 L .48475 .31748 L p F P
0 g
s
.579 .536 .771 r
.56528 .4496 m .5719 .461 L .56692 .45613 L p F P
0 g
s
.579 .536 .771 r
.56692 .45613 m .5601 .44473 L .56528 .4496 L p F P
0 g
s
.863 .563 .477 r
.65537 .57331 m .66014 .5777 L .65691 .57278 L p F P
0 g
s
.863 .563 .477 r
.65691 .57278 m .65195 .56822 L .65537 .57331 L p F P
0 g
s
.429 .483 .815 r
.59432 .49209 m .60053 .5016 L .59613 .49657 L p F P
0 g
s
.429 .483 .815 r
.59613 .49657 m .58972 .48701 L .59432 .49209 L p F P
0 g
s
.69 .516 .647 r
.15276 .44645 m .1652 .43684 L .15607 .43467 L p F P
0 g
s
.69 .516 .647 r
.15607 .43467 m .14345 .44385 L .15276 .44645 L p F P
0 g
s
.275 .417 .824 r
.60493 .50674 m .61093 .51552 L .60673 .51046 L p F P
0 g
s
.275 .417 .824 r
.60673 .51046 m .60053 .5016 L .60493 .50674 L p F P
0 g
s
.649 .557 .738 r
.51278 .36202 m .51981 .37595 L .51366 .37193 L p F P
0 g
s
.649 .557 .738 r
.51366 .37193 m .50644 .3583 L .51278 .36202 L p F P
0 g
s
0 .232 .751 r
.61693 .52364 m .61093 .51552 L .61514 .5207 L p F P
0 g
s
.692 .523 .653 r
.1308 .45416 m .14345 .44385 L .13416 .44052 L p F P
0 g
s
.692 .523 .653 r
.13416 .44052 m .12132 .45048 L .1308 .45416 L p F P
0 g
s
.758 .68 .776 r
.40894 .29756 m .41721 .29655 L .40951 .30228 L p F P
0 g
s
.758 .68 .776 r
.40951 .30228 m .40103 .30449 L .40894 .29756 L p F P
0 g
s
.042 0 0 r
.32587 .36351 m .33581 .35609 L .32772 .36169 L p F P
0 g
s
.042 0 0 r
.32772 .36169 m .31758 .36917 L .32587 .36351 L p F P
0 g
s
.827 .857 .869 r
.3682 .33036 m .37731 .32477 L .3694 .33121 L p F P
0 g
s
.827 .857 .869 r
.3694 .33121 m .36009 .33728 L .3682 .33036 L p F P
0 g
s
.676 .573 .732 r
.47751 .30458 m .48475 .31748 L .47782 .31567 L p F P
0 g
s
.676 .573 .732 r
.47782 .31567 m .47039 .3038 L .47751 .30458 L p F P
0 g
s
.625 .549 .749 r
.53963 .40737 m .54646 .42033 L .54089 .41571 L p F P
0 g
s
.625 .549 .749 r
.54089 .41571 m .53387 .40285 L .53963 .40737 L p F P
0 g
s
.544 .274 .456 r
.29048 .38724 m .30103 .37923 L .29277 .38366 L p F P
0 g
s
.544 .274 .456 r
.29277 .38366 m .28201 .39151 L .29048 .38724 L p F P
0 g
s
.676 .487 .623 r
.2045 .42962 m .2163 .42082 L .20751 .42142 L p F P
0 g
s
.676 .487 .623 r
.20751 .42142 m .19552 .4298 L .2045 .42962 L p F P
0 g
s
.549 .526 .782 r
.57689 .46601 m .58331 .47682 L .57852 .47182 L p F P
0 g
s
.549 .526 .782 r
.57852 .47182 m .5719 .461 L .57689 .46601 L p F P
0 g
s
.698 .594 .736 r
.45552 .28379 m .46296 .29305 L .45564 .29403 L p F P
0 g
s
.698 .594 .736 r
.45564 .29403 m .448 .28645 L .45552 .28379 L p F P
0 g
s
.655 .559 .735 r
.50575 .34789 m .51278 .36202 L .50644 .3583 L p F P
0 g
s
.655 .559 .735 r
.50644 .3583 m .49921 .34457 L .50575 .34789 L p F P
0 g
s
.89 .539 .373 r
.64697 .56289 m .65195 .56822 L .64853 .5632 L p F P
0 g
s
.89 .539 .373 r
.64853 .5632 m .64335 .55772 L .64697 .56289 L p F P
0 g
s
.598 .541 .762 r
.55866 .43762 m .56528 .4496 L .5601 .44473 L p F P
0 g
s
.598 .541 .762 r
.5601 .44473 m .55328 .43279 L .55866 .43762 L p F P
0 g
s
.716 .615 .743 r
.44035 .28083 m .448 .28645 L .44049 .28959 L p F P
0 g
s
.716 .615 .743 r
.44049 .28959 m .43264 .28574 L .44035 .28083 L p F P
0 g
s
.624 .399 .555 r
.26258 .40368 m .27356 .39531 L .26511 .39865 L p F P
0 g
s
.624 .399 .555 r
.26511 .39865 m .25394 .40676 L .26258 .40368 L p F P
0 g
s
.634 .551 .744 r
.5328 .39395 m .53963 .40737 L .53387 .40285 L p F P
0 g
s
.634 .551 .744 r
.53387 .40285 m .52684 .38958 L .5328 .39395 L p F P
0 g
s
.747 .659 .764 r
.41685 .29065 m .42492 .29101 L .41721 .29655 L p F P
0 g
s
.747 .659 .764 r
.41721 .29655 m .40894 .29756 L .41685 .29065 L p F P
0 g
s
.813 .801 .84 r
.37631 .32314 m .38521 .31815 L .37731 .32477 L p F P
0 g
s
.813 .801 .84 r
.37731 .32477 m .3682 .33036 L .37631 .32314 L p F P
0 g
s
.658 .456 .599 r
.23392 .41795 m .24531 .40933 L .23669 .41139 L p F P
0 g
s
.658 .456 .599 r
.23669 .41139 m .2251 .41967 L .23392 .41795 L p F P
0 g
s
.684 .579 .731 r
.47027 .29252 m .47751 .30458 L .47039 .3038 L p F P
0 g
s
.684 .579 .731 r
.47039 .3038 m .46296 .29305 L .47027 .29252 L p F P
0 g
s
.661 .562 .733 r
.49871 .33368 m .50575 .34789 L .49921 .34457 L p F P
0 g
s
.661 .562 .733 r
.49921 .34457 m .49198 .3309 L .49871 .33368 L p F P
0 g
s
.503 .51 .796 r
.5881 .48193 m .59432 .49209 L .58972 .48701 L p F P
0 g
s
.503 .51 .796 r
.58972 .48701 m .58331 .47682 L .5881 .48193 L p F P
0 g
s
0 0 0 r
.33581 .35609 m .32587 .36351 L .33416 .35742 L p F P
0 g
s
.885 .456 .143 r
.63817 .55149 m .64335 .55772 L .63974 .55262 L p F P
0 g
s
.683 .502 .636 r
.1835 .43918 m .19552 .4298 L .18655 .42937 L p F P
0 g
s
.683 .502 .636 r
.18655 .42937 m .17434 .43834 L .1835 .43918 L p F P
0 g
s
.505 .221 .416 r
.29895 .38249 m .30931 .3744 L .30103 .37923 L p F P
0 g
s
.505 .221 .416 r
.30103 .37923 m .29048 .38724 L .29895 .38249 L p F P
0 g
s
.613 .545 .754 r
.55203 .42509 m .55866 .43762 L .55328 .43279 L p F P
0 g
s
.613 .545 .754 r
.55328 .43279 m .54646 .42033 L .55203 .42509 L p F P
0 g
s
.425 .48 .813 r
.59891 .49729 m .60493 .50674 L .60053 .5016 L p F P
0 g
s
.425 .48 .813 r
.60053 .5016 m .59432 .49209 L .59891 .49729 L p F P
0 g
s
.577 .534 .77 r
.57046 .45459 m .57689 .46601 L .5719 .461 L p F P
0 g
s
.577 .534 .77 r
.5719 .461 m .56528 .4496 L .57046 .45459 L p F P
0 g
s
.642 .554 .74 r
.52596 .3801 m .5328 .39395 L .52684 .38958 L p F P
0 g
s
.642 .554 .74 r
.52684 .38958 m .51981 .37595 L .52596 .3801 L p F P
0 g
s
.667 .565 .731 r
.49168 .31955 m .49871 .33368 L .49198 .3309 L p F P
0 g
s
.667 .565 .731 r
.49198 .3309 m .48475 .31748 L .49168 .31955 L p F P
0 g
s
.798 .757 .816 r
.38442 .31563 m .39312 .31137 L .38521 .31815 L p F P
0 g
s
.798 .757 .816 r
.38521 .31815 m .37631 .32314 L .38442 .31563 L p F P
0 g
s
.272 .412 .821 r
.60933 .51199 m .61514 .5207 L .61093 .51552 L p F P
0 g
s
.272 .412 .821 r
.61093 .51552 m .60493 .50674 L .60933 .51199 L p F P
0 g
s
.737 .642 .753 r
.42477 .28384 m .43264 .28574 L .42492 .29101 L p F P
0 g
s
.737 .642 .753 r
.42492 .29101 m .41685 .29065 L .42477 .28384 L p F P
0 g
s
0 .23 .749 r
.62094 .52871 m .61514 .5207 L .61935 .52597 L p F P
0 g
s
.709 .604 .737 r
.44807 .27635 m .45552 .28379 L .448 .28645 L p F P
0 g
s
.709 .604 .737 r
.448 .28645 m .44035 .28083 L .44807 .27635 L p F P
0 g
s
.693 .587 .731 r
.46303 .28166 m .47027 .29252 L .46296 .29305 L p F P
0 g
s
.693 .587 .731 r
.46296 .29305 m .45552 .28379 L .46303 .28166 L p F P
0 g
s
.671 .969 .786 r
.34246 .35092 m .35199 .34388 L .3439 .35015 L p F P
0 g
s
.671 .969 .786 r
.3439 .35015 m .33416 .35742 L .34246 .35092 L p F P
0 g
s
.648 .556 .736 r
.51913 .36588 m .52596 .3801 L .51981 .37595 L p F P
0 g
s
.648 .556 .736 r
.51981 .37595 m .51278 .36202 L .51913 .36588 L p F P
0 g
s
.674 .569 .729 r
.48464 .30571 m .49168 .31955 L .48475 .31748 L p F P
0 g
s
.674 .569 .729 r
.48475 .31748 m .47751 .30458 L .48464 .30571 L p F P
0 g
s
.894 .539 .366 r
.6506 .56814 m .65537 .57331 L .65195 .56822 L p F P
0 g
s
.894 .539 .366 r
.65195 .56822 m .64697 .56289 L .6506 .56814 L p F P
0 g
s
.687 .513 .645 r
.1621 .44832 m .17434 .43834 L .1652 .43684 L p F P
0 g
s
.687 .513 .645 r
.1652 .43684 m .15276 .44645 L .1621 .44832 L p F P
0 g
s
.624 .548 .748 r
.5454 .41202 m .55203 .42509 L .54646 .42033 L p F P
0 g
s
.624 .548 .748 r
.54646 .42033 m .53963 .40737 L .5454 .41202 L p F P
0 g
s
.61 .379 .542 r
.27124 .40006 m .28201 .39151 L .27356 .39531 L p F P
0 g
s
.61 .379 .542 r
.27356 .39531 m .26258 .40368 L .27124 .40006 L p F P
0 g
s
.671 .481 .62 r
.2135 .42882 m .2251 .41967 L .2163 .42082 L p F P
0 g
s
.671 .481 .62 r
.2163 .42082 m .2045 .42962 L .2135 .42882 L p F P
0 g
s
.547 .524 .781 r
.58188 .47114 m .5881 .48193 L .58331 .47682 L p F P
0 g
s
.547 .524 .781 r
.58331 .47682 m .57689 .46601 L .58188 .47114 L p F P
0 g
s
.783 .723 .796 r
.39253 .30789 m .40103 .30449 L .39312 .31137 L p F P
0 g
s
.783 .723 .796 r
.39312 .31137 m .38442 .31563 L .39253 .30789 L p F P
0 g
s
.442 .136 .349 r
.30743 .37725 m .31758 .36917 L .30931 .3744 L p F P
0 g
s
.442 .136 .349 r
.30931 .3744 m .29895 .38249 L .30743 .37725 L p F P
0 g
s
.597 .54 .761 r
.56404 .44257 m .57046 .45459 L .56528 .4496 L p F P
0 g
s
.597 .54 .761 r
.56528 .4496 m .55866 .43762 L .56404 .44257 L p F P
0 g
s
.65 .445 .593 r
.24275 .41566 m .25394 .40676 L .24531 .40933 L p F P
0 g
s
.65 .445 .593 r
.24531 .40933 m .23392 .41795 L .24275 .41566 L p F P
0 g
s
.655 .558 .733 r
.51229 .35137 m .51913 .36588 L .51278 .36202 L p F P
0 g
s
.655 .558 .733 r
.51278 .36202 m .50575 .34789 L .51229 .35137 L p F P
0 g
s
.729 .627 .745 r
.43269 .27722 m .44035 .28083 L .43264 .28574 L p F P
0 g
s
.729 .627 .745 r
.43264 .28574 m .42477 .28384 L .43269 .27722 L p F P
0 g
s
.681 .574 .728 r
.4776 .29244 m .48464 .30571 L .47751 .30458 L p F P
0 g
s
.681 .574 .728 r
.47751 .30458 m .47027 .29252 L .4776 .29244 L p F P
0 g
s
.82 .978 .89 r
.35076 .34399 m .36009 .33728 L .35199 .34388 L p F P
0 g
s
.82 .978 .89 r
.35199 .34388 m .34246 .35092 L .35076 .34399 L p F P
0 g
s
.69 .52 .651 r
.1403 .45708 m .15276 .44645 L .14345 .44385 L p F P
0 g
s
.69 .52 .651 r
.14345 .44385 m .1308 .45416 L .1403 .45708 L p F P
0 g
s
.884 .452 .127 r
.64199 .5568 m .64697 .56289 L .64335 .55772 L p F P
0 g
s
.884 .452 .127 r
.64335 .55772 m .63817 .55149 L .64199 .5568 L p F P
0 g
s
.501 .507 .795 r
.5929 .48717 m .59891 .49729 L .59432 .49209 L p F P
0 g
s
.501 .507 .795 r
.59432 .49209 m .5881 .48193 L .5929 .48717 L p F P
0 g
s
.633 .55 .743 r
.53876 .39844 m .5454 .41202 L .53963 .40737 L p F P
0 g
s
.633 .55 .743 r
.53963 .40737 m .5328 .39395 L .53876 .39844 L p F P
0 g
s
.771 .695 .78 r
.40065 .29994 m .40894 .29756 L .40103 .30449 L p F P
0 g
s
.771 .695 .78 r
.40103 .30449 m .39253 .30789 L .40065 .29994 L p F P
0 g
s
.661 .56 .731 r
.50545 .33666 m .51229 .35137 L .50575 .34789 L p F P
0 g
s
.661 .56 .731 r
.50575 .34789 m .49871 .33368 L .50545 .33666 L p F P
0 g
s
.704 .595 .732 r
.45579 .27239 m .46303 .28166 L .45552 .28379 L p F P
0 g
s
.704 .595 .732 r
.45552 .28379 m .44807 .27635 L .45579 .27239 L p F P
0 g
s
.424 .477 .81 r
.60352 .50259 m .60933 .51199 L .60493 .50674 L p F P
0 g
s
.424 .477 .81 r
.60493 .50674 m .59891 .49729 L .60352 .50259 L p F P
0 g
s
.612 .544 .753 r
.5576 .42997 m .56404 .44257 L .55866 .43762 L p F P
0 g
s
.612 .544 .753 r
.55866 .43762 m .55203 .42509 L .5576 .42997 L p F P
0 g
s
.576 .532 .769 r
.57565 .45971 m .58188 .47114 L .57689 .46601 L p F P
0 g
s
.576 .532 .769 r
.57689 .46601 m .57046 .45459 L .57565 .45971 L p F P
0 g
s
.679 .497 .633 r
.19267 .43933 m .2045 .42962 L .19552 .4298 L p F P
0 g
s
.679 .497 .633 r
.19552 .4298 m .1835 .43918 L .19267 .43933 L p F P
0 g
s
.69 .58 .728 r
.47056 .28009 m .4776 .29244 L .47027 .29252 L p F P
0 g
s
.69 .58 .728 r
.47027 .29252 m .46303 .28166 L .47056 .28009 L p F P
0 g
s
.842 .904 .88 r
.35907 .33665 m .3682 .33036 L .36009 .33728 L p F P
0 g
s
.842 .904 .88 r
.36009 .33728 m .35076 .34399 L .35907 .33665 L p F P
0 g
s
.666 .563 .729 r
.49861 .32187 m .50545 .33666 L .49871 .33368 L p F P
0 g
s
.666 .563 .729 r
.49871 .33368 m .49168 .31955 L .49861 .32187 L p F P
0 g
s
0 .233 .75 r
.62495 .53389 m .61935 .52597 L .62356 .53134 L p F P
0 g
s
.273 .41 .818 r
.61374 .51734 m .61935 .52597 L .61514 .5207 L p F P
0 g
s
.273 .41 .818 r
.61514 .5207 m .60933 .51199 L .61374 .51734 L p F P
0 g
s
.329 0 .229 r
.31592 .37151 m .32587 .36351 L .31758 .36917 L p F P
0 g
s
.329 0 .229 r
.31758 .36917 m .30743 .37725 L .31592 .37151 L p F P
0 g
s
.59 .352 .523 r
.2799 .3959 m .29048 .38724 L .28201 .39151 L p F P
0 g
s
.59 .352 .523 r
.28201 .39151 m .27124 .40006 L .2799 .3959 L p F P
0 g
s
.641 .552 .739 r
.53212 .38438 m .53876 .39844 L .5328 .39395 L p F P
0 g
s
.641 .552 .739 r
.5328 .39395 m .52596 .3801 L .53212 .38438 L p F P
0 g
s
.721 .615 .738 r
.44061 .27091 m .44807 .27635 L .44035 .28083 L p F P
0 g
s
.721 .615 .738 r
.44035 .28083 m .43269 .27722 L .44061 .27091 L p F P
0 g
s
.76 .673 .767 r
.40877 .29185 m .41685 .29065 L .40894 .29756 L p F P
0 g
s
.76 .673 .767 r
.40894 .29756 m .40065 .29994 L .40877 .29185 L p F P
0 g
s
.673 .566 .727 r
.49177 .30719 m .49861 .32187 L .49168 .31955 L p F P
0 g
s
.673 .566 .727 r
.49168 .31955 m .48464 .30571 L .49177 .30719 L p F P
0 g
s
.665 .473 .615 r
.22251 .42738 m .23392 .41795 L .2251 .41967 L p F P
0 g
s
.665 .473 .615 r
.2251 .41967 m .2135 .42882 L .22251 .42738 L p F P
0 g
s
.641 .432 .585 r
.25159 .41277 m .26258 .40368 L .25394 .40676 L p F P
0 g
s
.641 .432 .585 r
.25394 .40676 m .24275 .41566 L .25159 .41277 L p F P
0 g
s
.648 .554 .735 r
.52548 .36989 m .53212 .38438 L .52596 .3801 L p F P
0 g
s
.648 .554 .735 r
.52596 .3801 m .51913 .36588 L .52548 .36989 L p F P
0 g
s
.546 .522 .78 r
.58687 .47638 m .5929 .48717 L .5881 .48193 L p F P
0 g
s
.546 .522 .78 r
.5881 .48193 m .58188 .47114 L .58687 .47638 L p F P
0 g
s
.83 .834 .851 r
.36739 .32892 m .37631 .32314 L .3682 .33036 L p F P
0 g
s
.83 .834 .851 r
.3682 .33036 m .35907 .33665 L .36739 .32892 L p F P
0 g
s
.624 .547 .747 r
.55117 .41679 m .5576 .42997 L .55203 .42509 L p F P
0 g
s
.624 .547 .747 r
.55203 .42509 m .5454 .41202 L .55117 .41679 L p F P
0 g
s
.75 .655 .756 r
.41689 .28369 m .42477 .28384 L .41685 .29065 L p F P
0 g
s
.75 .655 .756 r
.41685 .29065 m .40877 .29185 L .41689 .28369 L p F P
0 g
s
.699 .588 .728 r
.46351 .26904 m .47056 .28009 L .46303 .28166 L p F P
0 g
s
.699 .588 .728 r
.46303 .28166 m .45579 .27239 L .46351 .26904 L p F P
0 g
s
.881 .446 .107 r
.64581 .56219 m .6506 .56814 L .64697 .56289 L p F P
0 g
s
.881 .446 .107 r
.64697 .56289 m .64199 .5568 L .64581 .56219 L p F P
0 g
s
.104 0 0 r
.32441 .36528 m .33416 .35742 L .32587 .36351 L p F P
0 g
s
.104 0 0 r
.32587 .36351 m .31592 .37151 L .32441 .36528 L p F P
0 g
s
.684 .508 .642 r
.17145 .44947 m .1835 .43918 L .17434 .43834 L p F P
0 g
s
.684 .508 .642 r
.17434 .43834 m .1621 .44832 L .17145 .44947 L p F P
0 g
s
.596 .538 .76 r
.56942 .44765 m .57565 .45971 L .57046 .45459 L p F P
0 g
s
.596 .538 .76 r
.57046 .45459 m .56404 .44257 L .56942 .44765 L p F P
0 g
s
.679 .57 .726 r
.48493 .29283 m .49177 .30719 L .48464 .30571 L p F P
0 g
s
.679 .57 .726 r
.48464 .30571 m .4776 .29244 L .48493 .29283 L p F P
0 g
s
.715 .605 .733 r
.44853 .26502 m .45579 .27239 L .44807 .27635 L p F P
0 g
s
.715 .605 .733 r
.44807 .27635 m .44061 .27091 L .44853 .26502 L p F P
0 g
s
.654 .556 .732 r
.51884 .35502 m .52548 .36989 L .51913 .36588 L p F P
0 g
s
.654 .556 .732 r
.51913 .36588 m .51229 .35137 L .51884 .35502 L p F P
0 g
s
.501 .505 .793 r
.5977 .49251 m .60352 .50259 L .59891 .49729 L p F P
0 g
s
.501 .505 .793 r
.59891 .49729 m .5929 .48717 L .5977 .49251 L p F P
0 g
s
.563 .313 .495 r
.28857 .39119 m .29895 .38249 L .29048 .38724 L p F P
0 g
s
.563 .313 .495 r
.29048 .38724 m .2799 .3959 L .28857 .39119 L p F P
0 g
s
.813 .781 .823 r
.3757 .32079 m .38442 .31563 L .37631 .32314 L p F P
0 g
s
.813 .781 .823 r
.37631 .32314 m .36739 .32892 L .3757 .32079 L p F P
0 g
s
.741 .64 .748 r
.42502 .27553 m .43269 .27722 L .42477 .28384 L p F P
0 g
s
.741 .64 .748 r
.42477 .28384 m .41689 .28369 L .42502 .27553 L p F P
0 g
s
.596 .143 0 r
.637 .54995 m .64199 .5568 L .63817 .55149 L p F P
0 g
s
.633 .549 .742 r
.54473 .40306 m .55117 .41679 L .5454 .41202 L p F P
0 g
s
.633 .549 .742 r
.5454 .41202 m .53876 .39844 L .54473 .40306 L p F P
0 g
s
.66 .559 .73 r
.5122 .33985 m .51884 .35502 L .51229 .35137 L p F P
0 g
s
.66 .559 .73 r
.51229 .35137 m .50545 .33666 L .5122 .33985 L p F P
0 g
s
.686 .575 .725 r
.47808 .27909 m .48493 .29283 L .4776 .29244 L p F P
0 g
s
.686 .575 .725 r
.4776 .29244 m .47056 .28009 L .47808 .27909 L p F P
0 g
s
.424 .474 .808 r
.60812 .50801 m .61374 .51734 L .60933 .51199 L p F P
0 g
s
.424 .474 .808 r
.60933 .51199 m .60352 .50259 L .60812 .50801 L p F P
0 g
s
0 .239 .754 r
.62896 .53916 m .62356 .53134 L .62778 .5368 L p F P
0 g
s
.278 .409 .815 r
.61815 .52279 m .62356 .53134 L .61935 .52597 L p F P
0 g
s
.278 .409 .815 r
.61935 .52597 m .61374 .51734 L .61815 .52279 L p F P
0 g
s
.688 .516 .649 r
.14982 .45924 m .1621 .44832 L .15276 .44645 L p F P
0 g
s
.688 .516 .649 r
.15276 .44645 m .1403 .45708 L .14982 .45924 L p F P
0 g
s
0 0 0 r
.33291 .35856 m .34246 .35092 L .33416 .35742 L p F P
0 g
s
0 0 0 r
.33416 .35742 m .32441 .36528 L .33291 .35856 L p F P
0 g
s
.575 .531 .768 r
.58084 .46494 m .58687 .47638 L .58188 .47114 L p F P
0 g
s
.575 .531 .768 r
.58188 .47114 m .57565 .45971 L .58084 .46494 L p F P
0 g
s
.612 .542 .752 r
.56319 .43497 m .56942 .44765 L .56404 .44257 L p F P
0 g
s
.612 .542 .752 r
.56404 .44257 m .5576 .42997 L .56319 .43497 L p F P
0 g
s
.797 .742 .801 r
.38402 .31232 m .39253 .30789 L .38442 .31563 L p F P
0 g
s
.797 .742 .801 r
.38442 .31563 m .3757 .32079 L .38402 .31232 L p F P
0 g
s
.674 .491 .63 r
.20186 .4388 m .2135 .42882 L .2045 .42962 L p F P
0 g
s
.674 .491 .63 r
.2045 .42962 m .19267 .43933 L .20186 .4388 L p F P
0 g
s
.665 .561 .727 r
.50555 .32447 m .5122 .33985 L .50545 .33666 L p F P
0 g
s
.665 .561 .727 r
.50545 .33666 m .49861 .32187 L .50555 .32447 L p F P
0 g
s
.629 .415 .574 r
.26044 .40929 m .27124 .40006 L .26258 .40368 L p F P
0 g
s
.629 .415 .574 r
.26258 .40368 m .25159 .41277 L .26044 .40929 L p F P
0 g
s
.641 .551 .738 r
.53829 .38881 m .54473 .40306 L .53876 .39844 L p F P
0 g
s
.641 .551 .738 r
.53876 .39844 m .53212 .38438 L .53829 .38881 L p F P
0 g
s
.733 .627 .74 r
.43314 .2675 m .44061 .27091 L .43269 .27722 L p F P
0 g
s
.733 .627 .74 r
.43269 .27722 m .42502 .27553 L .43314 .2675 L p F P
0 g
s
.708 .596 .729 r
.45646 .25968 m .46351 .26904 L .45579 .27239 L p F P
0 g
s
.708 .596 .729 r
.45579 .27239 m .44853 .26502 L .45646 .25968 L p F P
0 g
s
.658 .463 .609 r
.23153 .4253 m .24275 .41566 L .23392 .41795 L p F P
0 g
s
.658 .463 .609 r
.23392 .41795 m .22251 .42738 L .23153 .4253 L p F P
0 g
s
.694 .581 .725 r
.47124 .26635 m .47808 .27909 L .47056 .28009 L p F P
0 g
s
.694 .581 .725 r
.47056 .28009 m .46351 .26904 L .47124 .26635 L p F P
0 g
s
.521 .255 .452 r
.29725 .38593 m .30743 .37725 L .29895 .38249 L p F P
0 g
s
.521 .255 .452 r
.29895 .38249 m .28857 .39119 L .29725 .38593 L p F P
0 g
s
.671 .564 .726 r
.49891 .30902 m .50555 .32447 L .49861 .32187 L p F P
0 g
s
.671 .564 .726 r
.49861 .32187 m .49177 .30719 L .49891 .30902 L p F P
0 g
s
.784 .712 .784 r
.39235 .30351 m .40065 .29994 L .39253 .30789 L p F P
0 g
s
.784 .712 .784 r
.39253 .30789 m .38402 .31232 L .39235 .30351 L p F P
0 g
s
.546 .52 .778 r
.59187 .48174 m .5977 .49251 L .5929 .48717 L p F P
0 g
s
.546 .52 .778 r
.5929 .48717 m .58687 .47638 L .59187 .48174 L p F P
0 g
s
.73 .988 .807 r
.34142 .35133 m .35076 .34399 L .34246 .35092 L p F P
0 g
s
.73 .988 .807 r
.34246 .35092 m .33291 .35856 L .34142 .35133 L p F P
0 g
s
.648 .553 .734 r
.53184 .37406 m .53829 .38881 L .53212 .38438 L p F P
0 g
s
.648 .553 .734 r
.53212 .38438 m .52548 .36989 L .53184 .37406 L p F P
0 g
s
.623 .545 .746 r
.55695 .42169 m .56319 .43497 L .5576 .42997 L p F P
0 g
s
.623 .545 .746 r
.5576 .42997 m .55117 .41679 L .55695 .42169 L p F P
0 g
s
.677 .567 .724 r
.49226 .29368 m .49891 .30902 L .49177 .30719 L p F P
0 g
s
.677 .567 .724 r
.49177 .30719 m .48493 .29283 L .49226 .29368 L p F P
0 g
s
.726 .616 .735 r
.44127 .25972 m .44853 .26502 L .44061 .27091 L p F P
0 g
s
.726 .616 .735 r
.44061 .27091 m .43314 .2675 L .44127 .25972 L p F P
0 g
s
.596 .537 .759 r
.57481 .45285 m .58084 .46494 L .57565 .45971 L p F P
0 g
s
.596 .537 .759 r
.57565 .45971 m .56942 .44765 L .57481 .45285 L p F P
0 g
s
.772 .688 .77 r
.40067 .29442 m .40877 .29185 L .40065 .29994 L p F P
0 g
s
.772 .688 .77 r
.40065 .29994 m .39235 .30351 L .40067 .29442 L p F P
0 g
s
.501 .503 .791 r
.6025 .49796 m .60812 .50801 L .60352 .50259 L p F P
0 g
s
.501 .503 .791 r
.60352 .50259 m .5977 .49251 L .6025 .49796 L p F P
0 g
s
0 0 .423 r
.64102 .55546 m .64581 .56219 L .64199 .5568 L p F P
0 g
s
0 0 .423 r
.64199 .5568 m .637 .54995 L .64102 .55546 L p F P
0 g
s
.68 .503 .64 r
.18081 .44988 m .19267 .43933 L .1835 .43918 L p F P
0 g
s
.68 .503 .64 r
.1835 .43918 m .17145 .44947 L .18081 .44988 L p F P
0 g
s
.654 .555 .731 r
.5254 .35886 m .53184 .37406 L .52548 .36989 L p F P
0 g
s
.654 .555 .731 r
.52548 .36989 m .51884 .35502 L .5254 .35886 L p F P
0 g
s
.683 .571 .723 r
.48561 .27868 m .49226 .29368 L .48493 .29283 L p F P
0 g
s
.683 .571 .723 r
.48493 .29283 m .47808 .27909 L .48561 .27868 L p F P
0 g
s
.703 .589 .725 r
.46438 .25502 m .47124 .26635 L .46351 .26904 L p F P
0 g
s
.703 .589 .725 r
.46351 .26904 m .45646 .25968 L .46438 .25502 L p F P
0 g
s
.845 .959 .883 r
.34993 .34362 m .35907 .33665 L .35076 .34399 L p F P
0 g
s
.845 .959 .883 r
.35076 .34399 m .34142 .35133 L .34993 .34362 L p F P
0 g
s
.613 .393 .559 r
.2693 .40521 m .2799 .3959 L .27124 .40006 L p F P
0 g
s
.613 .393 .559 r
.27124 .40006 m .26044 .40929 L .2693 .40521 L p F P
0 g
s
.452 .161 .38 r
.30594 .38011 m .31592 .37151 L .30743 .37725 L p F P
0 g
s
.452 .161 .38 r
.30743 .37725 m .29725 .38593 L .30594 .38011 L p F P
0 g
s
.426 .473 .805 r
.61274 .51351 m .61815 .52279 L .61374 .51734 L p F P
0 g
s
.426 .473 .805 r
.61374 .51734 m .60812 .50801 L .61274 .51351 L p F P
0 g
s
0 .248 .758 r
.63298 .54451 m .62778 .5368 L .632 .54234 L p F P
0 g
s
.762 .668 .759 r
.409 .28509 m .41689 .28369 L .40877 .29185 L p F P
0 g
s
.762 .668 .759 r
.40877 .29185 m .40067 .29442 L .409 .28509 L p F P
0 g
s
.633 .548 .741 r
.5507 .40782 m .55695 .42169 L .55117 .41679 L p F P
0 g
s
.633 .548 .741 r
.55117 .41679 m .54473 .40306 L .5507 .40782 L p F P
0 g
s
.285 .409 .813 r
.62257 .52833 m .62778 .5368 L .62356 .53134 L p F P
0 g
s
.285 .409 .813 r
.62356 .53134 m .61815 .52279 L .62257 .52833 L p F P
0 g
s
.659 .557 .728 r
.51895 .34326 m .5254 .35886 L .51884 .35502 L p F P
0 g
s
.659 .557 .728 r
.51884 .35502 m .5122 .33985 L .51895 .34326 L p F P
0 g
s
.719 .606 .73 r
.4494 .25233 m .45646 .25968 L .44853 .26502 L p F P
0 g
s
.719 .606 .73 r
.44853 .26502 m .44127 .25972 L .4494 .25233 L p F P
0 g
s
.575 .529 .767 r
.58604 .47029 m .59187 .48174 L .58687 .47638 L p F P
0 g
s
.575 .529 .767 r
.58687 .47638 m .58084 .46494 L .58604 .47029 L p F P
0 g
s
.669 .483 .625 r
.21107 .43757 m .22251 .42738 L .2135 .42882 L p F P
0 g
s
.669 .483 .625 r
.2135 .42882 m .20186 .4388 L .21107 .43757 L p F P
0 g
s
.69 .576 .722 r
.47897 .26437 m .48561 .27868 L .47808 .27909 L p F P
0 g
s
.69 .576 .722 r
.47808 .27909 m .47124 .26635 L .47897 .26437 L p F P
0 g
s
.65 .452 .602 r
.24057 .42257 m .25159 .41277 L .24275 .41566 L p F P
0 g
s
.65 .452 .602 r
.24275 .41566 m .23153 .4253 L .24057 .42257 L p F P
0 g
s
.611 .541 .751 r
.56877 .4401 m .57481 .45285 L .56942 .44765 L p F P
0 g
s
.611 .541 .751 r
.56942 .44765 m .56319 .43497 L .56877 .4401 L p F P
0 g
s
.752 .652 .75 r
.41733 .2756 m .42502 .27553 L .41689 .28369 L p F P
0 g
s
.752 .652 .75 r
.41689 .28369 m .409 .28509 L .41733 .2756 L p F P
0 g
s
.664 .559 .726 r
.5125 .32734 m .51895 .34326 L .5122 .33985 L p F P
0 g
s
.664 .559 .726 r
.5122 .33985 m .50555 .32447 L .5125 .32734 L p F P
0 g
s
.847 .877 .863 r
.35845 .33543 m .36739 .32892 L .35907 .33665 L p F P
0 g
s
.847 .877 .863 r
.35907 .33665 m .34993 .34362 L .35845 .33543 L p F P
0 g
s
.64 .55 .737 r
.54446 .39338 m .5507 .40782 L .54473 .40306 L p F P
0 g
s
.64 .55 .737 r
.54473 .40306 m .53829 .38881 L .54446 .39338 L p F P
0 g
s
.685 .512 .647 r
.15937 .46062 m .17145 .44947 L .1621 .44832 L p F P
0 g
s
.685 .512 .647 r
.1621 .44832 m .14982 .45924 L .15937 .46062 L p F P
0 g
s
.67 .562 .724 r
.50605 .3112 m .5125 .32734 L .50555 .32447 L p F P
0 g
s
.67 .562 .724 r
.50555 .32447 m .49891 .30902 L .50605 .3112 L p F P
0 g
s
.323 0 .245 r
.31464 .37373 m .32441 .36528 L .31592 .37151 L p F P
0 g
s
.323 0 .245 r
.31592 .37151 m .30594 .38011 L .31464 .37373 L p F P
0 g
s
.744 .639 .743 r
.42566 .26603 m .43314 .2675 L .42502 .27553 L p F P
0 g
s
.744 .639 .743 r
.42502 .27553 m .41733 .2756 L .42566 .26603 L p F P
0 g
s
.546 .519 .777 r
.59688 .48721 m .6025 .49796 L .5977 .49251 L p F P
0 g
s
.546 .519 .777 r
.5977 .49251 m .59187 .48174 L .59688 .48721 L p F P
0 g
s
.713 .597 .726 r
.45753 .24552 m .46438 .25502 L .45646 .25968 L p F P
0 g
s
.713 .597 .726 r
.45646 .25968 m .4494 .25233 L .45753 .24552 L p F P
0 g
s
.83 .812 .833 r
.36697 .32677 m .3757 .32079 L .36739 .32892 L p F P
0 g
s
.83 .812 .833 r
.36739 .32892 m .35845 .33543 L .36697 .32677 L p F P
0 g
s
.698 .582 .722 r
.47231 .25113 m .47897 .26437 L .47124 .26635 L p F P
0 g
s
.698 .582 .722 r
.47124 .26635 m .46438 .25502 L .47231 .25113 L p F P
0 g
s
.592 .363 .537 r
.27817 .40052 m .28857 .39119 L .2799 .3959 L p F P
0 g
s
.592 .363 .537 r
.2799 .3959 m .2693 .40521 L .27817 .40052 L p F P
0 g
s
.675 .564 .723 r
.4996 .29498 m .50605 .3112 L .49891 .30902 L p F P
0 g
s
.675 .564 .723 r
.49891 .30902 m .49226 .29368 L .4996 .29498 L p F P
0 g
s
.647 .552 .733 r
.53821 .37839 m .54446 .39338 L .53829 .38881 L p F P
0 g
s
.647 .552 .733 r
.53829 .38881 m .53184 .37406 L .53821 .37839 L p F P
0 g
s
.623 .544 .745 r
.56273 .42673 m .56877 .4401 L .56319 .43497 L p F P
0 g
s
.623 .544 .745 r
.56319 .43497 m .55695 .42169 L .56273 .42673 L p F P
0 g
s
.595 .535 .757 r
.58021 .45816 m .58604 .47029 L .58084 .46494 L p F P
0 g
s
.595 .535 .757 r
.58084 .46494 m .57481 .45285 L .58021 .45816 L p F P
0 g
s
.737 .627 .737 r
.43399 .2565 m .44127 .25972 L .43314 .2675 L p F P
0 g
s
.737 .627 .737 r
.43314 .2675 m .42566 .26603 L .43399 .2565 L p F P
0 g
s
.501 .502 .789 r
.60731 .50351 m .61274 .51351 L .60812 .50801 L p F P
0 g
s
.501 .502 .789 r
.60812 .50801 m .6025 .49796 L .60731 .50351 L p F P
0 g
s
.68 .568 .721 r
.49315 .27887 m .4996 .29498 L .49226 .29368 L p F P
0 g
s
.68 .568 .721 r
.49226 .29368 m .48561 .27868 L .49315 .27887 L p F P
0 g
s
.812 .765 .809 r
.3755 .31766 m .38402 .31232 L .3757 .32079 L p F P
0 g
s
.812 .765 .809 r
.3757 .32079 m .36697 .32677 L .3755 .31766 L p F P
0 g
s
.005 .259 .763 r
.63622 .54796 m .64102 .55546 L .637 .54995 L p F P
0 g
s
.005 .259 .763 r
.637 .54995 m .632 .54234 L .63622 .54796 L p F P
0 g
s
.676 .497 .636 r
.1902 .44956 m .20186 .4388 L .19267 .43933 L p F P
0 g
s
.676 .497 .636 r
.19267 .43933 m .18081 .44988 L .1902 .44956 L p F P
0 g
s
.653 .554 .73 r
.53196 .36288 m .53821 .37839 L .53184 .37406 L p F P
0 g
s
.653 .554 .73 r
.53184 .37406 m .5254 .35886 L .53196 .36288 L p F P
0 g
s
.048 0 0 r
.32334 .3668 m .33291 .35856 L .32441 .36528 L p F P
0 g
s
.048 0 0 r
.32441 .36528 m .31464 .37373 L .32334 .3668 L p F P
0 g
s
.429 .472 .803 r
.61735 .51912 m .62257 .52833 L .61815 .52279 L p F P
0 g
s
.429 .472 .803 r
.61815 .52279 m .61274 .51351 L .61735 .51912 L p F P
0 g
s
.293 .411 .811 r
.62699 .53396 m .632 .54234 L .62778 .5368 L p F P
0 g
s
.293 .411 .811 r
.62778 .5368 m .62257 .52833 L .62699 .53396 L p F P
0 g
s
.64 .437 .592 r
.24962 .41918 m .26044 .40929 L .25159 .41277 L p F P
0 g
s
.64 .437 .592 r
.25159 .41277 m .24057 .42257 L .24962 .41918 L p F P
0 g
s
.686 .572 .72 r
.4867 .26313 m .49315 .27887 L .48561 .27868 L p F P
0 g
s
.686 .572 .72 r
.48561 .27868 m .47897 .26437 L .4867 .26313 L p F P
0 g
s
.73 .616 .731 r
.44233 .24716 m .4494 .25233 L .44127 .25972 L p F P
0 g
s
.73 .616 .731 r
.44127 .25972 m .43399 .2565 L .44233 .24716 L p F P
0 g
s
.632 .547 .74 r
.55668 .41272 m .56273 .42673 L .55695 .42169 L p F P
0 g
s
.632 .547 .74 r
.55695 .42169 m .5507 .40782 L .55668 .41272 L p F P
0 g
s
.707 .59 .722 r
.46566 .23945 m .47231 .25113 L .46438 .25502 L p F P
0 g
s
.707 .59 .722 r
.46438 .25502 m .45753 .24552 L .46566 .23945 L p F P
0 g
s
.663 .475 .62 r
.22029 .43566 m .23153 .4253 L .22251 .42738 L p F P
0 g
s
.663 .475 .62 r
.22251 .42738 m .21107 .43757 L .22029 .43566 L p F P
0 g
s
.797 .73 .79 r
.38402 .30811 m .39235 .30351 L .38402 .31232 L p F P
0 g
s
.797 .73 .79 r
.38402 .31232 m .3755 .31766 L .38402 .30811 L p F P
0 g
s
.658 .556 .727 r
.52571 .3469 m .53196 .36288 L .5254 .35886 L p F P
0 g
s
.658 .556 .727 r
.5254 .35886 m .51895 .34326 L .52571 .3469 L p F P
0 g
s
.575 .528 .765 r
.59124 .47575 m .59688 .48721 L .59187 .48174 L p F P
0 g
s
.575 .528 .765 r
.59187 .48174 m .58604 .47029 L .59124 .47575 L p F P
0 g
s
.561 .319 .507 r
.28706 .39522 m .29725 .38593 L .28857 .39119 L p F P
0 g
s
.561 .319 .507 r
.28857 .39119 m .27817 .40052 L .28706 .39522 L p F P
0 g
s
.611 .54 .75 r
.57436 .44536 m .58021 .45816 L .57481 .45285 L p F P
0 g
s
.611 .54 .75 r
.57481 .45285 m .56877 .4401 L .57436 .44536 L p F P
0 g
s
.693 .577 .72 r
.48025 .24812 m .4867 .26313 L .47897 .26437 L p F P
0 g
s
.693 .577 .72 r
.47897 .26437 m .47231 .25113 L .48025 .24812 L p F P
0 g
s
.663 .557 .725 r
.51946 .3305 m .52571 .3469 L .51895 .34326 L p F P
0 g
s
.663 .557 .725 r
.51895 .34326 m .5125 .32734 L .51946 .3305 L p F P
0 g
s
.784 .703 .775 r
.39256 .29816 m .40067 .29442 L .39235 .30351 L p F P
0 g
s
.784 .703 .775 r
.39235 .30351 m .38402 .30811 L .39256 .29816 L p F P
0 g
s
0 0 0 r
.33205 .3593 m .34142 .35133 L .33291 .35856 L p F P
0 g
s
0 0 0 r
.33291 .35856 m .32334 .3668 L .33205 .3593 L p F P
0 g
s
.723 .607 .727 r
.45066 .23818 m .45753 .24552 L .4494 .25233 L p F P
0 g
s
.723 .607 .727 r
.4494 .25233 m .44233 .24716 L .45066 .23818 L p F P
0 g
s
.64 .549 .736 r
.55064 .39811 m .55668 .41272 L .5507 .40782 L p F P
0 g
s
.64 .549 .736 r
.5507 .40782 m .54446 .39338 L .55064 .39811 L p F P
0 g
s
.668 .559 .723 r
.5132 .31375 m .51946 .3305 L .5125 .32734 L p F P
0 g
s
.668 .559 .723 r
.5125 .32734 m .50605 .3112 L .5132 .31375 L p F P
0 g
s
.546 .517 .775 r
.60189 .49278 m .60731 .50351 L .6025 .49796 L p F P
0 g
s
.546 .517 .775 r
.6025 .49796 m .59688 .48721 L .60189 .49278 L p F P
0 g
s
.773 .682 .763 r
.40109 .28785 m .409 .28509 L .40067 .29442 L p F P
0 g
s
.773 .682 .763 r
.40067 .29442 m .39256 .29816 L .40109 .28785 L p F P
0 g
s
.681 .507 .644 r
.16893 .46124 m .18081 .44988 L .17145 .44947 L p F P
0 g
s
.681 .507 .644 r
.17145 .44947 m .15937 .46062 L .16893 .46124 L p F P
0 g
s
.673 .562 .721 r
.50695 .29675 m .5132 .31375 L .50605 .3112 L p F P
0 g
s
.673 .562 .721 r
.50605 .3112 m .4996 .29498 L .50695 .29675 L p F P
0 g
s
.701 .583 .72 r
.47379 .23429 m .48025 .24812 L .47231 .25113 L p F P
0 g
s
.701 .583 .72 r
.47231 .25113 m .46566 .23945 L .47379 .23429 L p F P
0 g
s
.764 .665 .754 r
.40963 .27721 m .41733 .2756 L .409 .28509 L p F P
0 g
s
.764 .665 .754 r
.409 .28509 m .40109 .28785 L .40963 .27721 L p F P
0 g
s
.804 .999 .841 r
.34077 .35125 m .34993 .34362 L .34142 .35133 L p F P
0 g
s
.804 .999 .841 r
.34142 .35133 m .33205 .3593 L .34077 .35125 L p F P
0 g
s
.627 .418 .58 r
.25868 .41515 m .2693 .40521 L .26044 .40929 L p F P
0 g
s
.627 .418 .58 r
.26044 .40929 m .24962 .41918 L .25868 .41515 L p F P
0 g
s
.622 .543 .744 r
.56852 .43189 m .57436 .44536 L .56877 .4401 L p F P
0 g
s
.622 .543 .744 r
.56877 .4401 m .56273 .42673 L .56852 .43189 L p F P
0 g
s
.716 .598 .723 r
.45899 .22977 m .46566 .23945 L .45753 .24552 L p F P
0 g
s
.716 .598 .723 r
.45753 .24552 m .45066 .23818 L .45899 .22977 L p F P
0 g
s
.647 .551 .732 r
.54459 .38289 m .55064 .39811 L .54446 .39338 L p F P
0 g
s
.647 .551 .732 r
.54446 .39338 m .53821 .37839 L .54459 .38289 L p F P
0 g
s
.502 .5 .787 r
.61213 .50916 m .61735 .51912 L .61274 .51351 L p F P
0 g
s
.502 .5 .787 r
.61274 .51351 m .60731 .50351 L .61213 .50916 L p F P
0 g
s
.514 .254 .458 r
.29595 .3893 m .30594 .38011 L .29725 .38593 L p F P
0 g
s
.514 .254 .458 r
.29725 .38593 m .28706 .39522 L .29595 .3893 L p F P
0 g
s
.678 .564 .72 r
.5007 .27965 m .50695 .29675 L .4996 .29498 L p F P
0 g
s
.678 .564 .72 r
.4996 .29498 m .49315 .27887 L .5007 .27965 L p F P
0 g
s
.595 .534 .756 r
.58561 .4636 m .59124 .47575 L .58604 .47029 L p F P
0 g
s
.595 .534 .756 r
.58604 .47029 m .58021 .45816 L .58561 .4636 L p F P
0 g
s
.755 .651 .746 r
.41817 .26632 m .42566 .26603 L .41733 .2756 L p F P
0 g
s
.755 .651 .746 r
.41733 .2756 m .40963 .27721 L .41817 .26632 L p F P
0 g
s
.432 .471 .8 r
.62197 .52482 m .62699 .53396 L .62257 .52833 L p F P
0 g
s
.432 .471 .8 r
.62257 .52833 m .61735 .51912 L .62197 .52482 L p F P
0 g
s
.303 .413 .808 r
.63141 .53968 m .63622 .54796 L .632 .54234 L p F P
0 g
s
.303 .413 .808 r
.632 .54234 m .62699 .53396 L .63141 .53968 L p F P
0 g
s
.683 .568 .719 r
.49444 .26265 m .5007 .27965 L .49315 .27887 L p F P
0 g
s
.683 .568 .719 r
.49315 .27887 m .4867 .26313 L .49444 .26265 L p F P
0 g
s
.672 .491 .632 r
.1996 .44851 m .21107 .43757 L .20186 .4388 L p F P
0 g
s
.672 .491 .632 r
.20186 .4388 m .1902 .44956 L .1996 .44851 L p F P
0 g
s
.656 .464 .613 r
.22952 .43304 m .24057 .42257 L .23153 .4253 L p F P
0 g
s
.656 .464 .613 r
.23153 .4253 m .22029 .43566 L .22952 .43304 L p F P
0 g
s
.652 .552 .729 r
.53853 .36711 m .54459 .38289 L .53821 .37839 L p F P
0 g
s
.652 .552 .729 r
.53821 .37839 m .53196 .36288 L .53853 .36711 L p F P
0 g
s
.748 .638 .739 r
.42671 .25527 m .43399 .2565 L .42566 .26603 L p F P
0 g
s
.748 .638 .739 r
.42566 .26603 m .41817 .26632 L .42671 .25527 L p F P
0 g
s
.86 .931 .87 r
.34949 .34265 m .35845 .33543 L .34993 .34362 L p F P
0 g
s
.86 .931 .87 r
.34993 .34362 m .34077 .35125 L .34949 .34265 L p F P
0 g
s
.689 .572 .718 r
.48818 .24603 m .49444 .26265 L .4867 .26313 L p F P
0 g
s
.689 .572 .718 r
.4867 .26313 m .48025 .24812 L .48818 .24603 L p F P
0 g
s
.632 .545 .739 r
.56267 .41777 m .56852 .43189 L .56273 .42673 L p F P
0 g
s
.632 .545 .739 r
.56273 .42673 m .55668 .41272 L .56267 .41777 L p F P
0 g
s
.71 .59 .72 r
.46733 .22218 m .47379 .23429 L .46566 .23945 L p F P
0 g
s
.71 .59 .72 r
.46566 .23945 m .45899 .22977 L .46733 .22218 L p F P
0 g
s
.74 .627 .733 r
.43524 .24416 m .44233 .24716 L .43399 .2565 L p F P
0 g
s
.74 .627 .733 r
.43399 .2565 m .42671 .25527 L .43524 .24416 L p F P
0 g
s
.575 .527 .764 r
.59645 .48133 m .60189 .49278 L .59688 .48721 L p F P
0 g
s
.575 .527 .764 r
.59688 .48721 m .59124 .47575 L .59645 .48133 L p F P
0 g
s
.657 .554 .726 r
.53248 .35078 m .53853 .36711 L .53196 .36288 L p F P
0 g
s
.657 .554 .726 r
.53196 .36288 m .52571 .3469 L .53248 .35078 L p F P
0 g
s
.433 .146 .375 r
.30485 .38277 m .31464 .37373 L .30594 .38011 L p F P
0 g
s
.433 .146 .375 r
.30594 .38011 m .29595 .3893 L .30485 .38277 L p F P
0 g
s
.61 .538 .749 r
.57996 .45074 m .58561 .4636 L .58021 .45816 L p F P
0 g
s
.61 .538 .749 r
.58021 .45816 m .57436 .44536 L .57996 .45074 L p F P
0 g
s
.696 .577 .717 r
.48193 .2302 m .48818 .24603 L .48025 .24812 L p F P
0 g
s
.696 .577 .717 r
.48025 .24812 m .47379 .23429 L .48193 .2302 L p F P
0 g
s
.848 .851 .845 r
.35822 .33351 m .36697 .32677 L .35845 .33543 L p F P
0 g
s
.848 .851 .845 r
.35845 .33543 m .34949 .34265 L .35822 .33351 L p F P
0 g
s
.733 .617 .729 r
.44378 .23315 m .45066 .23818 L .44233 .24716 L p F P
0 g
s
.733 .617 .729 r
.44233 .24716 m .43524 .24416 L .44378 .23315 L p F P
0 g
s
.662 .556 .724 r
.52642 .33394 m .53248 .35078 L .52571 .3469 L p F P
0 g
s
.662 .556 .724 r
.52571 .3469 m .51946 .3305 L .52642 .33394 L p F P
0 g
s
.609 .394 .563 r
.26775 .41045 m .27817 .40052 L .2693 .40521 L p F P
0 g
s
.609 .394 .563 r
.2693 .40521 m .25868 .41515 L .26775 .41045 L p F P
0 g
s
.546 .516 .773 r
.6069 .49846 m .61213 .50916 L .60731 .50351 L p F P
0 g
s
.546 .516 .773 r
.60731 .50351 m .60189 .49278 L .6069 .49846 L p F P
0 g
s
.639 .548 .735 r
.55682 .40299 m .56267 .41777 L .55668 .41272 L p F P
0 g
s
.639 .548 .735 r
.55668 .41272 m .55064 .39811 L .55682 .40299 L p F P
0 g
s
.667 .557 .722 r
.52036 .31665 m .52642 .33394 L .51946 .3305 L p F P
0 g
s
.667 .557 .722 r
.51946 .3305 m .5132 .31375 L .52036 .31665 L p F P
0 g
s
.727 .608 .724 r
.45232 .22245 m .45899 .22977 L .45066 .23818 L p F P
0 g
s
.727 .608 .724 r
.45066 .23818 m .44378 .23315 L .45232 .22245 L p F P
0 g
s
.829 .793 .818 r
.36695 .32384 m .3755 .31766 L .36697 .32677 L p F P
0 g
s
.829 .793 .818 r
.36697 .32677 m .35822 .33351 L .36695 .32384 L p F P
0 g
s
.671 .559 .72 r
.5143 .29898 m .52036 .31665 L .5132 .31375 L p F P
0 g
s
.671 .559 .72 r
.5132 .31375 m .50695 .29675 L .5143 .29898 L p F P
0 g
s
.704 .583 .717 r
.47567 .21567 m .48193 .2302 L .47379 .23429 L p F P
0 g
s
.704 .583 .717 r
.47379 .23429 m .46733 .22218 L .47567 .21567 L p F P
0 g
s
.678 .502 .641 r
.17851 .46108 m .1902 .44956 L .18081 .44988 L p F P
0 g
s
.678 .502 .641 r
.18081 .44988 m .16893 .46124 L .17851 .46108 L p F P
0 g
s
.504 .499 .785 r
.61695 .51492 m .62197 .52482 L .61735 .51912 L p F P
0 g
s
.504 .499 .785 r
.61735 .51912 m .61213 .50916 L .61695 .51492 L p F P
0 g
s
.271 0 .212 r
.31375 .37563 m .32334 .3668 L .31464 .37373 L p F P
0 g
s
.271 0 .212 r
.31464 .37373 m .30485 .38277 L .31375 .37563 L p F P
0 g
s
.675 .562 .719 r
.50824 .28102 m .5143 .29898 L .50695 .29675 L p F P
0 g
s
.675 .562 .719 r
.50695 .29675 m .5007 .27965 L .50824 .28102 L p F P
0 g
s
.647 .451 .605 r
.23877 .42973 m .24962 .41918 L .24057 .42257 L p F P
0 g
s
.647 .451 .605 r
.24057 .42257 m .22952 .43304 L .23877 .42973 L p F P
0 g
s
.622 .542 .743 r
.57432 .4372 m .57996 .45074 L .57436 .44536 L p F P
0 g
s
.622 .542 .743 r
.57436 .44536 m .56852 .43189 L .57432 .4372 L p F P
0 g
s
.595 .533 .755 r
.59101 .46915 m .59645 .48133 L .59124 .47575 L p F P
0 g
s
.595 .533 .755 r
.59124 .47575 m .58561 .4636 L .59101 .46915 L p F P
0 g
s
.811 .752 .797 r
.37569 .31365 m .38402 .30811 L .3755 .31766 L p F P
0 g
s
.811 .752 .797 r
.3755 .31766 m .36695 .32384 L .37569 .31365 L p F P
0 g
s
.72 .599 .721 r
.46086 .21233 m .46733 .22218 L .45899 .22977 L p F P
0 g
s
.72 .599 .721 r
.45899 .22977 m .45232 .22245 L .46086 .21233 L p F P
0 g
s
.646 .549 .731 r
.55097 .38758 m .55682 .40299 L .55064 .39811 L p F P
0 g
s
.646 .549 .731 r
.55064 .39811 m .54459 .38289 L .55097 .38758 L p F P
0 g
s
.436 .471 .798 r
.6266 .53061 m .63141 .53968 L .62699 .53396 L p F P
0 g
s
.436 .471 .798 r
.62699 .53396 m .62197 .52482 L .6266 .53061 L p F P
0 g
s
.68 .564 .717 r
.50219 .26293 m .50824 .28102 L .5007 .27965 L p F P
0 g
s
.68 .564 .717 r
.5007 .27965 m .49444 .26265 L .50219 .26293 L p F P
0 g
s
.666 .483 .627 r
.20902 .44672 m .22029 .43566 L .21107 .43757 L p F P
0 g
s
.666 .483 .627 r
.21107 .43757 m .1996 .44851 L .20902 .44672 L p F P
0 g
s
.685 .568 .716 r
.49613 .2449 m .50219 .26293 L .49444 .26265 L p F P
0 g
s
.685 .568 .716 r
.49444 .26265 m .48818 .24603 L .49613 .2449 L p F P
0 g
s
.797 .721 .781 r
.38443 .30296 m .39256 .29816 L .38402 .30811 L p F P
0 g
s
.797 .721 .781 r
.38402 .30811 m .37569 .31365 L .38443 .30296 L p F P
0 g
s
.585 .36 .54 r
.27684 .4051 m .28706 .39522 L .27817 .40052 L p F P
0 g
s
.585 .36 .54 r
.27817 .40052 m .26775 .41045 L .27684 .4051 L p F P
0 g
s
.691 .572 .716 r
.49007 .22726 m .49613 .2449 L .48818 .24603 L p F P
0 g
s
.691 .572 .716 r
.48818 .24603 m .48193 .2302 L .49007 .22726 L p F P
0 g
s
.651 .551 .728 r
.54511 .37154 m .55097 .38758 L .54459 .38289 L p F P
0 g
s
.651 .551 .728 r
.54459 .38289 m .53853 .36711 L .54511 .37154 L p F P
0 g
s
.785 .698 .768 r
.39317 .29179 m .40109 .28785 L .39256 .29816 L p F P
0 g
s
.785 .698 .768 r
.39256 .29816 m .38443 .30296 L .39317 .29179 L p F P
0 g
s
.713 .591 .718 r
.4694 .20309 m .47567 .21567 L .46733 .22218 L p F P
0 g
s
.713 .591 .718 r
.46733 .22218 m .46086 .21233 L .4694 .20309 L p F P
0 g
s
0 0 0 r
.32267 .36788 m .33205 .3593 L .32334 .3668 L p F P
0 g
s
0 0 0 r
.32334 .3668 m .31375 .37563 L .32267 .36788 L p F P
0 g
s
.575 .525 .762 r
.60166 .48702 m .6069 .49846 L .60189 .49278 L p F P
0 g
s
.575 .525 .762 r
.60189 .49278 m .59645 .48133 L .60166 .48702 L p F P
0 g
s
.631 .544 .738 r
.56866 .42296 m .57432 .4372 L .56852 .43189 L p F P
0 g
s
.631 .544 .738 r
.56852 .43189 m .56267 .41777 L .56866 .42296 L p F P
0 g
s
.698 .577 .715 r
.48401 .21046 m .49007 .22726 L .48193 .2302 L p F P
0 g
s
.698 .577 .715 r
.48193 .2302 m .47567 .21567 L .48401 .21046 L p F P
0 g
s
.775 .679 .757 r
.40191 .28019 m .40963 .27721 L .40109 .28785 L p F P
0 g
s
.775 .679 .757 r
.40109 .28785 m .39317 .29179 L .40191 .28019 L p F P
0 g
s
.656 .553 .726 r
.53925 .3549 m .54511 .37154 L .53853 .36711 L p F P
0 g
s
.656 .553 .726 r
.53853 .36711 m .53248 .35078 L .53925 .3549 L p F P
0 g
s
.766 .663 .749 r
.41066 .26817 m .41817 .26632 L .40963 .27721 L p F P
0 g
s
.766 .663 .749 r
.40963 .27721 m .40191 .28019 L .41066 .26817 L p F P
0 g
s
.61 .537 .748 r
.58557 .45626 m .59101 .46915 L .58561 .4636 L p F P
0 g
s
.61 .537 .748 r
.58561 .4636 m .57996 .45074 L .58557 .45626 L p F P
0 g
s
.758 .65 .742 r
.4194 .25582 m .42671 .25527 L .41817 .26632 L p F P
0 g
s
.758 .65 .742 r
.41817 .26632 m .41066 .26817 L .4194 .25582 L p F P
0 g
s
.751 .639 .736 r
.42815 .24319 m .43524 .24416 L .42671 .25527 L p F P
0 g
s
.751 .639 .736 r
.42671 .25527 m .4194 .25582 L .42815 .24319 L p F P
0 g
s
.661 .554 .723 r
.53339 .33768 m .53925 .3549 L .53248 .35078 L p F P
0 g
s
.661 .554 .723 r
.53248 .35078 m .52642 .33394 L .53339 .33768 L p F P
0 g
s
.547 .515 .771 r
.61192 .50425 m .61695 .51492 L .61213 .50916 L p F P
0 g
s
.547 .515 .771 r
.61213 .50916 m .6069 .49846 L .61192 .50425 L p F P
0 g
s
.744 .628 .731 r
.4369 .23042 m .44378 .23315 L .43524 .24416 L p F P
0 g
s
.744 .628 .731 r
.43524 .24416 m .42815 .24319 L .4369 .23042 L p F P
0 g
s
.627 .924 .66 r
.33159 .35952 m .34077 .35125 L .33205 .3593 L p F P
0 g
s
.627 .924 .66 r
.33205 .3593 m .32267 .36788 L .33159 .35952 L p F P
0 g
s
.635 .435 .595 r
.24804 .42572 m .25868 .41515 L .24962 .41918 L p F P
0 g
s
.635 .435 .595 r
.24962 .41918 m .23877 .42973 L .24804 .42572 L p F P
0 g
s
.707 .584 .715 r
.47794 .19513 m .48401 .21046 L .47567 .21567 L p F P
0 g
s
.707 .584 .715 r
.47567 .21567 m .4694 .20309 L .47794 .19513 L p F P
0 g
s
.737 .618 .726 r
.44564 .21764 m .45232 .22245 L .44378 .23315 L p F P
0 g
s
.737 .618 .726 r
.44378 .23315 m .4369 .23042 L .44564 .21764 L p F P
0 g
s
.55 .311 .505 r
.28593 .39908 m .29595 .3893 L .28706 .39522 L p F P
0 g
s
.55 .311 .505 r
.28706 .39522 m .27684 .4051 L .28593 .39908 L p F P
0 g
s
.639 .546 .734 r
.56301 .40804 m .56866 .42296 L .56267 .41777 L p F P
0 g
s
.639 .546 .734 r
.56267 .41777 m .55682 .40299 L .56301 .40804 L p F P
0 g
s
.665 .556 .721 r
.52753 .31992 m .53339 .33768 L .52642 .33394 L p F P
0 g
s
.665 .556 .721 r
.52642 .33394 m .52036 .31665 L .52753 .31992 L p F P
0 g
s
.73 .609 .722 r
.45439 .2051 m .46086 .21233 L .45232 .22245 L p F P
0 g
s
.73 .609 .722 r
.45232 .22245 m .44564 .21764 L .45439 .2051 L p F P
0 g
s
.505 .498 .783 r
.62177 .52077 m .6266 .53061 L .62197 .52482 L p F P
0 g
s
.505 .498 .783 r
.62197 .52482 m .61695 .51492 L .62177 .52077 L p F P
0 g
s
.669 .557 .719 r
.52166 .30166 m .52753 .31992 L .52036 .31665 L p F P
0 g
s
.669 .557 .719 r
.52036 .31665 m .5143 .29898 L .52166 .30166 L p F P
0 g
s
.673 .496 .637 r
.18811 .46016 m .1996 .44851 L .1902 .44956 L p F P
0 g
s
.673 .496 .637 r
.1902 .44956 m .17851 .46108 L .18811 .46016 L p F P
0 g
s
.673 .559 .718 r
.5158 .28298 m .52166 .30166 L .5143 .29898 L p F P
0 g
s
.673 .559 .718 r
.5143 .29898 m .50824 .28102 L .5158 .28298 L p F P
0 g
s
.659 .473 .621 r
.21846 .44419 m .22952 .43304 L .22029 .43566 L p F P
0 g
s
.659 .473 .621 r
.22029 .43566 m .20902 .44672 L .21846 .44419 L p F P
0 g
s
.724 .601 .719 r
.46313 .19309 m .4694 .20309 L .46086 .21233 L p F P
0 g
s
.724 .601 .719 r
.46086 .21233 m .45439 .2051 L .46313 .19309 L p F P
0 g
s
.677 .561 .717 r
.50994 .26396 m .5158 .28298 L .50824 .28102 L p F P
0 g
s
.677 .561 .717 r
.50824 .28102 m .50219 .26293 L .50994 .26396 L p F P
0 g
s
.682 .564 .715 r
.50407 .24474 m .50994 .26396 L .50219 .26293 L p F P
0 g
s
.682 .564 .715 r
.50219 .26293 m .49613 .2449 L .50407 .24474 L p F P
0 g
s
.595 .532 .754 r
.59642 .47483 m .60166 .48702 L .59645 .48133 L p F P
0 g
s
.595 .532 .754 r
.59645 .48133 m .59101 .46915 L .59642 .47483 L p F P
0 g
s
.852 .985 .855 r
.34052 .35055 m .34949 .34265 L .34077 .35125 L p F P
0 g
s
.852 .985 .855 r
.34077 .35125 m .33159 .35952 L .34052 .35055 L p F P
0 g
s
.621 .541 .742 r
.58012 .44264 m .58557 .45626 L .57996 .45074 L p F P
0 g
s
.621 .541 .742 r
.57996 .45074 m .57432 .4372 L .58012 .44264 L p F P
0 g
s
.687 .567 .714 r
.49821 .22555 m .50407 .24474 L .49613 .2449 L p F P
0 g
s
.687 .567 .714 r
.49613 .2449 m .49007 .22726 L .49821 .22555 L p F P
0 g
s
.645 .548 .73 r
.55735 .39245 m .56301 .40804 L .55682 .40299 L p F P
0 g
s
.645 .548 .73 r
.55682 .40299 m .55097 .38758 L .55735 .39245 L p F P
0 g
s
.693 .571 .714 r
.49235 .20673 m .49821 .22555 L .49007 .22726 L p F P
0 g
s
.693 .571 .714 r
.49007 .22726 m .48401 .21046 L .49235 .20673 L p F P
0 g
s
.716 .592 .716 r
.47188 .18205 m .47794 .19513 L .4694 .20309 L p F P
0 g
s
.716 .592 .716 r
.4694 .20309 m .46313 .19309 L .47188 .18205 L p F P
0 g
s
.7 .577 .714 r
.48649 .18879 m .49235 .20673 L .48401 .21046 L p F P
0 g
s
.7 .577 .714 r
.48401 .21046 m .47794 .19513 L .48649 .18879 L p F P
0 g
s
.494 .234 .45 r
.29503 .39241 m .30485 .38277 L .29595 .3893 L p F P
0 g
s
.494 .234 .45 r
.29595 .3893 m .28593 .39908 L .29503 .39241 L p F P
0 g
s
.867 .901 .855 r
.34945 .34097 m .35822 .33351 L .34949 .34265 L p F P
0 g
s
.867 .901 .855 r
.34949 .34265 m .34052 .35055 L .34945 .34097 L p F P
0 g
s
.651 .55 .727 r
.55169 .37619 m .55735 .39245 L .55097 .38758 L p F P
0 g
s
.651 .55 .727 r
.55097 .38758 m .54511 .37154 L .55169 .37619 L p F P
0 g
s
.575 .524 .761 r
.60688 .49282 m .61192 .50425 L .6069 .49846 L p F P
0 g
s
.575 .524 .761 r
.6069 .49846 m .60166 .48702 L .60688 .49282 L p F P
0 g
s
.621 .415 .581 r
.25731 .421 m .26775 .41045 L .25868 .41515 L p F P
0 g
s
.621 .415 .581 r
.25868 .41515 m .24804 .42572 L .25731 .421 L p F P
0 g
s
.63 .543 .737 r
.57466 .42831 m .58012 .44264 L .57432 .4372 L p F P
0 g
s
.63 .543 .737 r
.57432 .4372 m .56866 .42296 L .57466 .42831 L p F P
0 g
s
.709 .584 .714 r
.48062 .17251 m .48649 .18879 L .47794 .19513 L p F P
0 g
s
.709 .584 .714 r
.47794 .19513 m .47188 .18205 L .48062 .17251 L p F P
0 g
s
.848 .829 .829 r
.35839 .3308 m .36695 .32384 L .35822 .33351 L p F P
0 g
s
.848 .829 .829 r
.35822 .33351 m .34945 .34097 L .35839 .3308 L p F P
0 g
s
.655 .551 .725 r
.54603 .35928 m .55169 .37619 L .54511 .37154 L p F P
0 g
s
.655 .551 .725 r
.54511 .37154 m .53925 .3549 L .54603 .35928 L p F P
0 g
s
.609 .536 .747 r
.59118 .4619 m .59642 .47483 L .59101 .46915 L p F P
0 g
s
.609 .536 .747 r
.59101 .46915 m .58557 .45626 L .59118 .4619 L p F P
0 g
s
.547 .513 .77 r
.61694 .51014 m .62177 .52077 L .61695 .51492 L p F P
0 g
s
.547 .513 .77 r
.61695 .51492 m .61192 .50425 L .61694 .51014 L p F P
0 g
s
.828 .778 .805 r
.36733 .32005 m .37569 .31365 L .36695 .32384 L p F P
0 g
s
.828 .778 .805 r
.36695 .32384 m .35839 .3308 L .36733 .32005 L p F P
0 g
s
.66 .553 .723 r
.54036 .34173 m .54603 .35928 L .53925 .3549 L p F P
0 g
s
.66 .553 .723 r
.53925 .3549 m .53339 .33768 L .54036 .34173 L p F P
0 g
s
.392 .103 .35 r
.30415 .38507 m .31375 .37563 L .30485 .38277 L p F P
0 g
s
.392 .103 .35 r
.30485 .38277 m .29503 .39241 L .30415 .38507 L p F P
0 g
s
.652 .462 .614 r
.22791 .44092 m .23877 .42973 L .22952 .43304 L p F P
0 g
s
.652 .462 .614 r
.22952 .43304 m .21846 .44419 L .22791 .44092 L p F P
0 g
s
.735 .612 .721 r
.45686 .18608 m .46313 .19309 L .45439 .2051 L p F P
0 g
s
.735 .612 .721 r
.45439 .2051 m .4479 .20062 L .45686 .18608 L p F P
0 g
s
.741 .621 .725 r
.4479 .20062 m .45439 .2051 L .44564 .21764 L p F P
0 g
s
.727 .603 .718 r
.46581 .172 m .47188 .18205 L .46313 .19309 L p F P
0 g
s
.727 .603 .718 r
.46313 .19309 m .45686 .18608 L .46581 .172 L p F P
0 g
s
.638 .545 .733 r
.56921 .41327 m .57466 .42831 L .56866 .42296 L p F P
0 g
s
.638 .545 .733 r
.56866 .42296 m .56301 .40804 L .56921 .41327 L p F P
0 g
s
.664 .554 .721 r
.5347 .32356 m .54036 .34173 L .53339 .33768 L p F P
0 g
s
.664 .554 .721 r
.53339 .33768 m .52753 .31992 L .5347 .32356 L p F P
0 g
s
.694 .571 .712 r
.49503 .18435 m .5007 .20456 L .49235 .20673 L p F P
0 g
s
.694 .571 .712 r
.49235 .20673 m .48649 .18879 L .49503 .18435 L p F P
0 g
s
.688 .566 .713 r
.49821 .22555 m .49235 .20673 L .5007 .20456 L p F P
0 g
s
.668 .488 .633 r
.19773 .45846 m .20902 .44672 L .1996 .44851 L p F P
0 g
s
.668 .488 .633 r
.1996 .44851 m .18811 .46016 L .19773 .45846 L p F P
0 g
s
.688 .566 .713 r
.5007 .20456 m .50636 .22507 L .49821 .22555 L p F P
0 g
s
.683 .563 .714 r
.50407 .24474 m .49821 .22555 L .50636 .22507 L p F P
0 g
s
.811 .742 .787 r
.37628 .30871 m .38443 .30296 L .37569 .31365 L p F P
0 g
s
.811 .742 .787 r
.37569 .31365 m .36733 .32005 L .37628 .30871 L p F P
0 g
s
.741 .621 .725 r
.44564 .21764 m .43895 .21527 L .4479 .20062 L p F P
0 g
s
.748 .63 .729 r
.43895 .21527 m .44564 .21764 L .4369 .23042 L p F P
0 g
s
.683 .563 .714 r
.50636 .22507 m .51203 .24553 L .50407 .24474 L p F P
0 g
s
.679 .561 .715 r
.50994 .26396 m .50407 .24474 L .51203 .24553 L p F P
0 g
s
.72 .594 .715 r
.47475 .15894 m .48062 .17251 L .47188 .18205 L p F P
0 g
s
.72 .594 .715 r
.47188 .18205 m .46581 .172 L .47475 .15894 L p F P
0 g
s
.701 .577 .712 r
.48936 .16506 m .49503 .18435 L .48649 .18879 L p F P
0 g
s
.701 .577 .712 r
.48649 .18879 m .48062 .17251 L .48936 .16506 L p F P
0 g
s
.667 .555 .719 r
.52903 .30481 m .5347 .32356 L .52753 .31992 L p F P
0 g
s
.667 .555 .719 r
.52753 .31992 m .52166 .30166 L .52903 .30481 L p F P
0 g
s
.748 .63 .729 r
.4369 .23042 m .43 .2298 L .43895 .21527 L p F P
0 g
s
.755 .64 .734 r
.43 .2298 m .4369 .23042 L .42815 .24319 L p F P
0 g
s
.679 .561 .715 r
.51203 .24553 m .5177 .26572 L .50994 .26396 L p F P
0 g
s
.675 .559 .716 r
.5158 .28298 m .50994 .26396 L .5177 .26572 L p F P
0 g
s
.671 .557 .717 r
.52336 .28551 m .52903 .30481 L .52166 .30166 L p F P
0 g
s
.671 .557 .717 r
.52166 .30166 m .5158 .28298 L .52336 .28551 L p F P
0 g
s
.675 .559 .716 r
.5177 .26572 m .52336 .28551 L .5158 .28298 L p F P
0 g
s
.798 .715 .773 r
.38523 .29681 m .39317 .29179 L .38443 .30296 L p F P
0 g
s
.798 .715 .773 r
.38443 .30296 m .37628 .30871 L .38523 .29681 L p F P
0 g
s
.755 .64 .734 r
.42815 .24319 m .42104 .24406 L .43 .2298 L p F P
0 g
s
.762 .651 .739 r
.42104 .24406 m .42815 .24319 L .4194 .25582 L p F P
0 g
s
.601 .387 .563 r
.2666 .41558 m .27684 .4051 L .26775 .41045 L p F P
0 g
s
.601 .387 .563 r
.26775 .41045 m .25731 .421 L .2666 .41558 L p F P
0 g
s
.594 .53 .753 r
.60184 .48063 m .60688 .49282 L .60166 .48702 L p F P
0 g
s
.594 .53 .753 r
.60166 .48702 m .59642 .47483 L .60184 .48063 L p F P
0 g
s
.787 .694 .762 r
.39418 .28437 m .40191 .28019 L .39317 .29179 L p F P
0 g
s
.787 .694 .762 r
.39317 .29179 m .38523 .29681 L .39418 .28437 L p F P
0 g
s
.762 .651 .739 r
.4194 .25582 m .41209 .25795 L .42104 .24406 L p F P
0 g
s
.769 .663 .745 r
.41209 .25795 m .4194 .25582 L .41066 .26817 L p F P
0 g
s
.777 .677 .753 r
.40313 .2714 m .41066 .26817 L .40191 .28019 L p F P
0 g
s
.777 .677 .753 r
.40191 .28019 m .39418 .28437 L .40313 .2714 L p F P
0 g
s
.769 .663 .745 r
.41066 .26817 m .40313 .2714 L .41209 .25795 L p F P
0 g
s
.621 .539 .741 r
.58593 .44823 m .59118 .4619 L .58557 .45626 L p F P
0 g
s
.621 .539 .741 r
.58557 .45626 m .58012 .44264 L .58593 .44823 L p F P
0 g
s
.711 .585 .712 r
.4837 .14769 m .48936 .16506 L .48062 .17251 L p F P
0 g
s
.711 .585 .712 r
.48062 .17251 m .47475 .15894 L .4837 .14769 L p F P
0 g
s
.18 0 .141 r
.31327 .37707 m .32267 .36788 L .31375 .37563 L p F P
0 g
s
.18 0 .141 r
.31375 .37563 m .30415 .38507 L .31327 .37707 L p F P
0 g
s
.644 .547 .73 r
.56375 .39752 m .56921 .41327 L .56301 .40804 L p F P
0 g
s
.644 .547 .73 r
.56301 .40804 m .55735 .39245 L .56375 .39752 L p F P
0 g
s
.575 .523 .76 r
.61211 .49874 m .61694 .51014 L .61192 .50425 L p F P
0 g
s
.575 .523 .76 r
.61192 .50425 m .60688 .49282 L .61211 .49874 L p F P
0 g
s
.65 .548 .727 r
.55828 .38106 m .56375 .39752 L .55735 .39245 L p F P
0 g
s
.65 .548 .727 r
.55735 .39245 m .55169 .37619 L .55828 .38106 L p F P
0 g
s
.702 .576 .71 r
.49264 .13919 m .49811 .16013 L .48936 .16506 L p F P
0 g
s
.702 .576 .71 r
.48936 .16506 m .4837 .14769 L .49264 .13919 L p F P
0 g
s
.694 .569 .711 r
.49503 .18435 m .48936 .16506 L .49811 .16013 L p F P
0 g
s
.694 .569 .711 r
.49811 .16013 m .50358 .18196 L .49503 .18435 L p F P
0 g
s
.688 .565 .711 r
.5007 .20456 m .49503 .18435 L .50358 .18196 L p F P
0 g
s
0 0 0 r
.32239 .36842 m .33159 .35952 L .32267 .36788 L p F P
0 g
s
0 0 0 r
.32267 .36788 m .31327 .37707 L .32239 .36842 L p F P
0 g
s
.724 .596 .713 r
.47803 .13369 m .4837 .14769 L .47475 .15894 L p F P
0 g
s
.724 .596 .713 r
.47475 .15894 m .46888 .14907 L .47803 .13369 L p F P
0 g
s
.732 .606 .717 r
.46888 .14907 m .47475 .15894 L .46581 .172 L p F P
0 g
s
.642 .448 .605 r
.23737 .43691 m .24804 .42572 L .23877 .42973 L p F P
0 g
s
.642 .448 .605 r
.23877 .42973 m .22791 .44092 L .23737 .43691 L p F P
0 g
s
.63 .542 .737 r
.58067 .43382 m .58593 .44823 L .58012 .44264 L p F P
0 g
s
.63 .542 .737 r
.58012 .44264 m .57466 .42831 L .58067 .43382 L p F P
0 g
s
.732 .606 .717 r
.46581 .172 m .45972 .16545 L .46888 .14907 L p F P
0 g
s
.739 .615 .72 r
.45972 .16545 m .46581 .172 L .45686 .18608 L p F P
0 g
s
.574 .349 .536 r
.27589 .40946 m .28593 .39908 L .27684 .4051 L p F P
0 g
s
.574 .349 .536 r
.27684 .4051 m .2666 .41558 L .27589 .40946 L p F P
0 g
s
.688 .565 .711 r
.50358 .18196 m .50905 .20396 L .5007 .20456 L p F P
0 g
s
.683 .562 .712 r
.50636 .22507 m .5007 .20456 L .50905 .20396 L p F P
0 g
s
.714 .586 .711 r
.48717 .1205 m .49264 .13919 L .4837 .14769 L p F P
0 g
s
.714 .586 .711 r
.4837 .14769 m .47803 .13369 L .48717 .1205 L p F P
0 g
s
.609 .535 .746 r
.59679 .46768 m .60184 .48063 L .59642 .47483 L p F P
0 g
s
.609 .535 .746 r
.59642 .47483 m .59118 .4619 L .59679 .46768 L p F P
0 g
s
.654 .55 .724 r
.55282 .36392 m .55828 .38106 L .55169 .37619 L p F P
0 g
s
.654 .55 .724 r
.55169 .37619 m .54603 .35928 L .55282 .36392 L p F P
0 g
s
.683 .562 .712 r
.50905 .20396 m .51452 .22579 L .50636 .22507 L p F P
0 g
s
.679 .56 .713 r
.51203 .24553 m .50636 .22507 L .51452 .22579 L p F P
0 g
s
.739 .615 .72 r
.45686 .18608 m .45057 .18214 L .45972 .16545 L p F P
0 g
s
.746 .624 .724 r
.45057 .18214 m .45686 .18608 L .4479 .20062 L p F P
0 g
s
.662 .48 .628 r
.20736 .45599 m .21846 .44419 L .20902 .44672 L p F P
0 g
s
.662 .48 .628 r
.20902 .44672 m .19773 .45846 L .20736 .45599 L p F P
0 g
s
.658 .551 .722 r
.54735 .34608 m .55282 .36392 L .54603 .35928 L p F P
0 g
s
.658 .551 .722 r
.54603 .35928 m .54036 .34173 L .54735 .34608 L p F P
0 g
s
.762 .987 .757 r
.33153 .3591 m .34052 .35055 L .33159 .35952 L p F P
0 g
s
.762 .987 .757 r
.33159 .35952 m .32239 .36842 L .33153 .3591 L p F P
0 g
s
.679 .56 .713 r
.51452 .22579 m .51999 .24724 L .51203 .24553 L p F P
0 g
s
.675 .558 .714 r
.5177 .26572 m .51203 .24553 L .51999 .24724 L p F P
0 g
s
.746 .624 .724 r
.4479 .20062 m .44141 .19877 L .45057 .18214 L p F P
0 g
s
.753 .633 .728 r
.44141 .19877 m .4479 .20062 L .43895 .21527 L p F P
0 g
s
.702 .575 .709 r
.49632 .11121 m .50159 .13422 L .49264 .13919 L p F P
0 g
s
.702 .575 .709 r
.49264 .13919 m .48717 .1205 L .49632 .11121 L p F P
0 g
s
.693 .568 .709 r
.49811 .16013 m .49264 .13919 L .50159 .13422 L p F P
0 g
s
.637 .544 .733 r
.57541 .41867 m .58067 .43382 L .57466 .42831 L p F P
0 g
s
.637 .544 .733 r
.57466 .42831 m .56921 .41327 L .57541 .41867 L p F P
0 g
s
.675 .558 .714 r
.51999 .24724 m .52546 .26821 L .5177 .26572 L p F P
0 g
s
.672 .556 .715 r
.52336 .28551 m .5177 .26572 L .52546 .26821 L p F P
0 g
s
.662 .552 .72 r
.54188 .32758 m .54735 .34608 L .54036 .34173 L p F P
0 g
s
.662 .552 .72 r
.54036 .34173 m .5347 .32356 L .54188 .32758 L p F P
0 g
s
.717 .588 .71 r
.49105 .09081 m .49632 .11121 L .48717 .1205 L p F P
0 g
s
.717 .588 .71 r
.48717 .1205 m .4817 .10633 L .49105 .09081 L p F P
0 g
s
.729 .6 .713 r
.4817 .10633 m .48717 .1205 L .47803 .13369 L p F P
0 g
s
.672 .556 .715 r
.52546 .26821 m .53094 .28861 L .52336 .28551 L p F P
0 g
s
.669 .555 .717 r
.52903 .30481 m .52336 .28551 L .53094 .28861 L p F P
0 g
s
.666 .554 .718 r
.53641 .30841 m .54188 .32758 L .5347 .32356 L p F P
0 g
s
.666 .554 .718 r
.5347 .32356 m .52903 .30481 L .53641 .30841 L p F P
0 g
s
.729 .6 .713 r
.47803 .13369 m .47235 .12446 L .4817 .10633 L p F P
0 g
s
.738 .611 .716 r
.47235 .12446 m .47803 .13369 L .46888 .14907 L p F P
0 g
s
.669 .555 .717 r
.53094 .28861 m .53641 .30841 L .52903 .30481 L p F P
0 g
s
.737 .605 .71 r
.5 .02333 m .50487 .05235 L .49533 .05847 L p F P
0 g
s
.737 .605 .71 r
.49533 .05847 m .49025 .04875 L .5 .02333 L p F P
0 g
s
.693 .568 .709 r
.50159 .13422 m .50686 .15793 L .49811 .16013 L p F P
0 g
s
.687 .563 .71 r
.50358 .18196 m .49811 .16013 L .50686 .15793 L p F P
0 g
s
.594 .529 .751 r
.60726 .48656 m .61211 .49874 L .60688 .49282 L p F P
0 g
s
.594 .529 .751 r
.60688 .49282 m .60184 .48063 L .60726 .48656 L p F P
0 g
s
.876 .958 .853 r
.34067 .34913 m .34945 .34097 L .34052 .35055 L p F P
0 g
s
.876 .958 .853 r
.34052 .35055 m .33153 .3591 L .34067 .34913 L p F P
0 g
s
.753 .633 .728 r
.43895 .21527 m .43225 .21512 L .44141 .19877 L p F P
0 g
s
.759 .642 .732 r
.43225 .21512 m .43895 .21527 L .43 .2298 L p F P
0 g
s
.532 .292 .497 r
.2852 .40264 m .29503 .39241 L .28593 .39908 L p F P
0 g
s
.532 .292 .497 r
.28593 .39908 m .27589 .40946 L .2852 .40264 L p F P
0 g
s
.62 .538 .74 r
.59174 .45396 m .59679 .46768 L .59118 .4619 L p F P
0 g
s
.62 .538 .74 r
.59118 .4619 m .58593 .44823 L .59174 .45396 L p F P
0 g
s
.722 .592 .709 r
.49533 .05847 m .5004 .08148 L .49105 .09081 L p F P
0 g
s
.722 .592 .709 r
.49105 .09081 m .48578 .07724 L .49533 .05847 L p F P
0 g
s
.701 .573 .708 r
.49632 .11121 m .49105 .09081 L .5004 .08148 L p F P
0 g
s
.737 .607 .713 r
.48578 .07724 m .49105 .09081 L .4817 .10633 L p F P
0 g
s
.694 .567 .707 r
.5004 .08148 m .49533 .05847 L .50487 .05235 L p F P
0 g
s
.753 .624 .716 r
.49025 .04875 m .49533 .05847 L .48578 .07724 L p F P
0 g
s
.701 .573 .708 r
.5004 .08148 m .50547 .10716 L .49632 .11121 L p F P
0 g
s
.69 .564 .708 r
.50159 .13422 m .49632 .11121 L .50547 .10716 L p F P
0 g
s
.629 .43 .594 r
.24685 .43216 m .25731 .421 L .24804 .42572 L p F P
0 g
s
.629 .43 .594 r
.24804 .42572 m .23737 .43691 L .24685 .43216 L p F P
0 g
s
.738 .611 .716 r
.46888 .14907 m .46299 .14339 L .47235 .12446 L p F P
0 g
s
.746 .62 .72 r
.46299 .14339 m .46888 .14907 L .45972 .16545 L p F P
0 g
s
.687 .563 .71 r
.50686 .15793 m .51214 .18158 L .50358 .18196 L p F P
0 g
s
.682 .56 .71 r
.50905 .20396 m .50358 .18196 L .51214 .18158 L p F P
0 g
s
.643 .546 .729 r
.57015 .40278 m .57541 .41867 L .56921 .41327 L p F P
0 g
s
.643 .546 .729 r
.56921 .41327 m .56375 .39752 L .57015 .40278 L p F P
0 g
s
.759 .642 .732 r
.43 .2298 m .42308 .23107 L .43225 .21512 L p F P
0 g
s
.766 .653 .737 r
.42308 .23107 m .43 .2298 L .42104 .24406 L p F P
0 g
s
.868 .874 .839 r
.34981 .33851 m .35839 .3308 L .34945 .34097 L p F P
0 g
s
.868 .874 .839 r
.34945 .34097 m .34067 .34913 L .34981 .33851 L p F P
0 g
s
.737 .607 .713 r
.4817 .10633 m .47622 .09872 L .48578 .07724 L p F P
0 g
s
.747 .618 .717 r
.47622 .09872 m .4817 .10633 L .47235 .12446 L p F P
0 g
s
.766 .653 .737 r
.42104 .24406 m .41392 .24654 L .42308 .23107 L p F P
0 g
s
.773 .664 .743 r
.41392 .24654 m .42104 .24406 L .41209 .25795 L p F P
0 g
s
.694 .567 .707 r
.50487 .05235 m .50975 .08062 L .5004 .08148 L p F P
0 g
s
.683 .558 .707 r
.50547 .10716 m .5004 .08148 L .50975 .08062 L p F P
0 g
s
.682 .56 .71 r
.51214 .18158 m .51741 .20487 L .50905 .20396 L p F P
0 g
s
.679 .558 .711 r
.51452 .22579 m .50905 .20396 L .51741 .20487 L p F P
0 g
s
.847 .812 .815 r
.35896 .32725 m .36733 .32005 L .35839 .3308 L p F P
0 g
s
.847 .812 .815 r
.35839 .3308 m .34981 .33851 L .35896 .32725 L p F P
0 g
s
.69 .564 .708 r
.50547 .10716 m .51055 .13295 L .50159 .13422 L p F P
0 g
s
.684 .56 .709 r
.50686 .15793 m .50159 .13422 L .51055 .13295 L p F P
0 g
s
.648 .547 .726 r
.56488 .38617 m .57015 .40278 L .56375 .39752 L p F P
0 g
s
.648 .547 .726 r
.56375 .39752 m .55828 .38106 L .56488 .38617 L p F P
0 g
s
.746 .62 .72 r
.45972 .16545 m .45363 .16235 L .46299 .14339 L p F P
0 g
s
.752 .629 .723 r
.45363 .16235 m .45972 .16545 L .45057 .18214 L p F P
0 g
s
.773 .664 .743 r
.41209 .25795 m .40476 .26148 L .41392 .24654 L p F P
0 g
s
.781 .677 .749 r
.40476 .26148 m .41209 .25795 L .40313 .2714 L p F P
0 g
s
.462 .2 .43 r
.29452 .39511 m .30415 .38507 L .29503 .39241 L p F P
0 g
s
.462 .2 .43 r
.29503 .39241 m .2852 .40264 L .29452 .39511 L p F P
0 g
s
.655 .47 .621 r
.21701 .45274 m .22791 .44092 L .21846 .44419 L p F P
0 g
s
.655 .47 .621 r
.21846 .44419 m .20736 .45599 L .21701 .45274 L p F P
0 g
s
.629 .541 .736 r
.58668 .43949 m .59174 .45396 L .58593 .44823 L p F P
0 g
s
.629 .541 .736 r
.58593 .44823 m .58067 .43382 L .58668 .43949 L p F P
0 g
s
.828 .768 .795 r
.36812 .31534 m .37628 .30871 L .36733 .32005 L p F P
0 g
s
.828 .768 .795 r
.36733 .32005 m .35896 .32725 L .36812 .31534 L p F P
0 g
s
.753 .624 .716 r
.48578 .07724 m .4805 .07343 L .49025 .04875 L p F P
0 g
s
.762 .634 .72 r
.4805 .07343 m .48578 .07724 L .47622 .09872 L p F P
0 g
s
.781 .677 .749 r
.40313 .2714 m .39559 .27585 L .40476 .26148 L p F P
0 g
s
.789 .692 .757 r
.39559 .27585 m .40313 .2714 L .39418 .28437 L p F P
0 g
s
.608 .534 .745 r
.60241 .47359 m .60726 .48656 L .60184 .48063 L p F P
0 g
s
.608 .534 .745 r
.60184 .48063 m .59679 .46768 L .60241 .47359 L p F P
0 g
s
.679 .558 .711 r
.51741 .20487 m .52269 .22765 L .51452 .22579 L p F P
0 g
s
.675 .556 .712 r
.51999 .24724 m .51452 .22579 L .52269 .22765 L p F P
0 g
s
.812 .736 .78 r
.37727 .30279 m .38523 .29681 L .37628 .30871 L p F P
0 g
s
.812 .736 .78 r
.37628 .30871 m .36812 .31534 L .37727 .30279 L p F P
0 g
s
.789 .692 .757 r
.39418 .28437 m .38643 .28963 L .39559 .27585 L p F P
0 g
s
.8 .711 .767 r
.38643 .28963 m .39418 .28437 L .38523 .29681 L p F P
0 g
s
.8 .711 .767 r
.38523 .29681 m .37727 .30279 L .38643 .28963 L p F P
0 g
s
.653 .549 .724 r
.55961 .36882 m .56488 .38617 L .55828 .38106 L p F P
0 g
s
.653 .549 .724 r
.55828 .38106 m .55282 .36392 L .55961 .36882 L p F P
0 g
s
.747 .618 .717 r
.47235 .12446 m .46666 .12037 L .47622 .09872 L p F P
0 g
s
.754 .628 .72 r
.46666 .12037 m .47235 .12446 L .46299 .14339 L p F P
0 g
s
.684 .56 .709 r
.51055 .13295 m .51562 .15831 L .50686 .15793 L p F P
0 g
s
.68 .558 .709 r
.51214 .18158 m .50686 .15793 L .51562 .15831 L p F P
0 g
s
.675 .556 .712 r
.52269 .22765 m .52796 .24984 L .51999 .24724 L p F P
0 g
s
.673 .555 .714 r
.52546 .26821 m .51999 .24724 L .52796 .24984 L p F P
0 g
s
.752 .629 .723 r
.45057 .18214 m .44427 .18102 L .45363 .16235 L p F P
0 g
s
.758 .637 .727 r
.44427 .18102 m .45057 .18214 L .44141 .19877 L p F P
0 g
s
.613 .407 .579 r
.25633 .42667 m .2666 .41558 L .25731 .421 L p F P
0 g
s
.613 .407 .579 r
.25731 .421 m .24685 .43216 L .25633 .42667 L p F P
0 g
s
.683 .558 .707 r
.50975 .08062 m .51463 .10815 L .50547 .10716 L p F P
0 g
s
.679 .555 .708 r
.51055 .13295 m .50547 .10716 L .51463 .10815 L p F P
0 g
s
.657 .55 .722 r
.55434 .35076 m .55961 .36882 L .55282 .36392 L p F P
0 g
s
.657 .55 .722 r
.55282 .36392 m .54735 .34608 L .55434 .35076 L p F P
0 g
s
.673 .555 .714 r
.52796 .24984 m .53324 .27139 L .52546 .26821 L p F P
0 g
s
.67 .554 .715 r
.53094 .28861 m .52546 .26821 L .53324 .27139 L p F P
0 g
s
.331 .036 .305 r
.30384 .38688 m .31327 .37707 L .30415 .38507 L p F P
0 g
s
.331 .036 .305 r
.30415 .38507 m .29452 .39511 L .30384 .38688 L p F P
0 g
s
.636 .543 .732 r
.58162 .42425 m .58668 .43949 L .58067 .43382 L p F P
0 g
s
.636 .543 .732 r
.58067 .43382 m .57541 .41867 L .58162 .42425 L p F P
0 g
s
.66 .551 .72 r
.54907 .33197 m .55434 .35076 L .54735 .34608 L p F P
0 g
s
.66 .551 .72 r
.54735 .34608 m .54188 .32758 L .54907 .33197 L p F P
0 g
s
.67 .554 .715 r
.53324 .27139 m .53852 .29228 L .53094 .28861 L p F P
0 g
s
.667 .553 .716 r
.53641 .30841 m .53094 .28861 L .53852 .29228 L p F P
0 g
s
.664 .552 .718 r
.54379 .31247 m .54907 .33197 L .54188 .32758 L p F P
0 g
s
.664 .552 .718 r
.54188 .32758 m .53641 .30841 L .54379 .31247 L p F P
0 g
s
.667 .553 .716 r
.53852 .29228 m .54379 .31247 L .53641 .30841 L p F P
0 g
s
.68 .558 .709 r
.51562 .15831 m .5207 .18308 L .51214 .18158 L p F P
0 g
s
.677 .556 .71 r
.51741 .20487 m .51214 .18158 L .5207 .18308 L p F P
0 g
s
.758 .637 .727 r
.44141 .19877 m .4349 .19924 L .44427 .18102 L p F P
0 g
s
.765 .646 .731 r
.4349 .19924 m .44141 .19877 L .43225 .21512 L p F P
0 g
s
.619 .537 .74 r
.59756 .45985 m .60241 .47359 L .59679 .46768 L p F P
0 g
s
.619 .537 .74 r
.59679 .46768 m .59174 .45396 L .59756 .45985 L p F P
0 g
s
.754 .628 .72 r
.46299 .14339 m .4571 .14161 L .46666 .12037 L p F P
0 g
s
.76 .636 .724 r
.4571 .14161 m .46299 .14339 L .45363 .16235 L p F P
0 g
s
.762 .634 .72 r
.47622 .09872 m .47073 .09738 L .4805 .07343 L p F P
0 g
s
.767 .642 .723 r
.47073 .09738 m .47622 .09872 L .46666 .12037 L p F P
0 g
s
.642 .545 .729 r
.57655 .40826 m .58162 .42425 L .57541 .41867 L p F P
0 g
s
.642 .545 .729 r
.57541 .41867 m .57015 .40278 L .57655 .40826 L p F P
0 g
s
.044 0 .032 r
.31317 .37794 m .32239 .36842 L .31327 .37707 L p F P
0 g
s
.044 0 .032 r
.31327 .37707 m .30384 .38688 L .31317 .37794 L p F P
0 g
s
.646 .457 .614 r
.22668 .44872 m .23737 .43691 L .22791 .44092 L p F P
0 g
s
.646 .457 .614 r
.22791 .44092 m .21701 .45274 L .22668 .44872 L p F P
0 g
s
.679 .555 .708 r
.51463 .10815 m .51951 .13494 L .51055 .13295 L p F P
0 g
s
.676 .554 .708 r
.51562 .15831 m .51055 .13295 L .51951 .13494 L p F P
0 g
s
.677 .556 .71 r
.5207 .18308 m .52578 .20718 L .51741 .20487 L p F P
0 g
s
.675 .555 .711 r
.52269 .22765 m .51741 .20487 L .52578 .20718 L p F P
0 g
s
.59 .376 .558 r
.26583 .42043 m .27589 .40946 L .2666 .41558 L p F P
0 g
s
.59 .376 .558 r
.2666 .41558 m .25633 .42667 L .26583 .42043 L p F P
0 g
s
.765 .646 .731 r
.43225 .21512 m .42553 .21691 L .4349 .19924 L p F P
0 g
s
.771 .656 .736 r
.42553 .21691 m .43225 .21512 L .42308 .23107 L p F P
0 g
s
.647 .546 .726 r
.57149 .39151 m .57655 .40826 L .57015 .40278 L p F P
0 g
s
.647 .546 .726 r
.57015 .40278 m .56488 .38617 L .57149 .39151 L p F P
0 g
s
0 0 0 r
.32251 .36831 m .33153 .3591 L .32239 .36842 L p F P
0 g
s
0 0 0 r
.32239 .36842 m .31317 .37794 L .32251 .36831 L p F P
0 g
s
.628 .54 .735 r
.5927 .44533 m .59756 .45985 L .59174 .45396 L p F P
0 g
s
.628 .54 .735 r
.59174 .45396 m .58668 .43949 L .5927 .44533 L p F P
0 g
s
.675 .555 .711 r
.52578 .20718 m .53086 .23059 L .52269 .22765 L p F P
0 g
s
.672 .554 .712 r
.52796 .24984 m .52269 .22765 L .53086 .23059 L p F P
0 g
s
.771 .656 .736 r
.42308 .23107 m .41616 .23399 L .42553 .21691 L p F P
0 g
s
.777 .666 .741 r
.41616 .23399 m .42308 .23107 L .41392 .24654 L p F P
0 g
s
.76 .636 .724 r
.45363 .16235 m .44753 .16229 L .4571 .14161 L p F P
0 g
s
.766 .644 .727 r
.44753 .16229 m .45363 .16235 L .44427 .18102 L p F P
0 g
s
.676 .554 .708 r
.51951 .13494 m .52439 .16097 L .51562 .15831 L p F P
0 g
s
.674 .553 .709 r
.5207 .18308 m .51562 .15831 L .52439 .16097 L p F P
0 g
s
.652 .547 .723 r
.56641 .37401 m .57149 .39151 L .56488 .38617 L p F P
0 g
s
.652 .547 .723 r
.56488 .38617 m .55961 .36882 L .56641 .37401 L p F P
0 g
s
.672 .554 .712 r
.53086 .23059 m .53594 .25329 L .52796 .24984 L p F P
0 g
s
.67 .553 .713 r
.53324 .27139 m .52796 .24984 L .53594 .25329 L p F P
0 g
s
.842 .999 .804 r
.33186 .35797 m .34067 .34913 L .33153 .3591 L p F P
0 g
s
.842 .999 .804 r
.33153 .3591 m .32251 .36831 L .33186 .35797 L p F P
0 g
s
.767 .642 .723 r
.46666 .12037 m .46096 .12057 L .47073 .09738 L p F P
0 g
s
.772 .648 .726 r
.46096 .12057 m .46666 .12037 L .4571 .14161 L p F P
0 g
s
.777 .666 .741 r
.41392 .24654 m .40678 .25045 L .41616 .23399 L p F P
0 g
s
.785 .679 .747 r
.40678 .25045 m .41392 .24654 L .40476 .26148 L p F P
0 g
s
.557 .332 .529 r
.27534 .41346 m .2852 .40264 L .27589 .40946 L p F P
0 g
s
.557 .332 .529 r
.27589 .40946 m .26583 .42043 L .27534 .41346 L p F P
0 g
s
.655 .548 .721 r
.56134 .35575 m .56641 .37401 L .55961 .36882 L p F P
0 g
s
.655 .548 .721 r
.55961 .36882 m .55434 .35076 L .56134 .35575 L p F P
0 g
s
.67 .553 .713 r
.53594 .25329 m .54102 .27526 L .53324 .27139 L p F P
0 g
s
.667 .552 .715 r
.53852 .29228 m .53324 .27139 L .54102 .27526 L p F P
0 g
s
.635 .442 .604 r
.23636 .44393 m .24685 .43216 L .23737 .43691 L p F P
0 g
s
.635 .442 .604 r
.23737 .43691 m .22668 .44872 L .23636 .44393 L p F P
0 g
s
.635 .542 .731 r
.58784 .43003 m .5927 .44533 L .58668 .43949 L p F P
0 g
s
.635 .542 .731 r
.58668 .43949 m .58162 .42425 L .58784 .43003 L p F P
0 g
s
.886 .93 .844 r
.34121 .34694 m .34981 .33851 L .34067 .34913 L p F P
0 g
s
.886 .93 .844 r
.34067 .34913 m .33186 .35797 L .34121 .34694 L p F P
0 g
s
.659 .549 .719 r
.55626 .33675 m .56134 .35575 L .55434 .35076 L p F P
0 g
s
.659 .549 .719 r
.55434 .35076 m .54907 .33197 L .55626 .33675 L p F P
0 g
s
.785 .679 .747 r
.40476 .26148 m .39741 .26625 L .40678 .25045 L p F P
0 g
s
.793 .693 .754 r
.39741 .26625 m .40476 .26148 L .39559 .27585 L p F P
0 g
s
.667 .552 .715 r
.54102 .27526 m .5461 .2965 L .53852 .29228 L p F P
0 g
s
.665 .551 .716 r
.54379 .31247 m .53852 .29228 L .5461 .2965 L p F P
0 g
s
.674 .553 .709 r
.52439 .16097 m .52928 .18625 L .5207 .18308 L p F P
0 g
s
.673 .552 .71 r
.52578 .20718 m .5207 .18308 L .52928 .18625 L p F P
0 g
s
.766 .644 .727 r
.44427 .18102 m .43795 .18234 L .44753 .16229 L p F P
0 g
s
.771 .653 .731 r
.43795 .18234 m .44427 .18102 L .4349 .19924 L p F P
0 g
s
.662 .55 .718 r
.55118 .31699 m .55626 .33675 L .54907 .33197 L p F P
0 g
s
.662 .55 .718 r
.54907 .33197 m .54379 .31247 L .55118 .31699 L p F P
0 g
s
.665 .551 .716 r
.5461 .2965 m .55118 .31699 L .54379 .31247 L p F P
0 g
s
.868 .854 .825 r
.35057 .33521 m .35896 .32725 L .34981 .33851 L p F P
0 g
s
.868 .854 .825 r
.34981 .33851 m .34121 .34694 L .35057 .33521 L p F P
0 g
s
.793 .693 .754 r
.39559 .27585 m .38804 .2814 L .39741 .26625 L p F P
0 g
s
.803 .71 .763 r
.38804 .2814 m .39559 .27585 L .38643 .28963 L p F P
0 g
s
.847 .799 .804 r
.35993 .32279 m .36812 .31534 L .35896 .32725 L p F P
0 g
s
.847 .799 .804 r
.35896 .32725 m .35057 .33521 L .35993 .32279 L p F P
0 g
s
.803 .71 .763 r
.38643 .28963 m .37867 .29588 L .38804 .2814 L p F P
0 g
s
.814 .732 .774 r
.37867 .29588 m .38643 .28963 L .37727 .30279 L p F P
0 g
s
.829 .76 .787 r
.3693 .30968 m .37727 .30279 L .36812 .31534 L p F P
0 g
s
.829 .76 .787 r
.36812 .31534 m .35993 .32279 L .3693 .30968 L p F P
0 g
s
.814 .732 .774 r
.37727 .30279 m .3693 .30968 L .37867 .29588 L p F P
0 g
s
.507 .264 .482 r
.28487 .40575 m .29452 .39511 L .2852 .40264 L p F P
0 g
s
.507 .264 .482 r
.2852 .40264 m .27534 .41346 L .28487 .40575 L p F P
0 g
s
.641 .543 .728 r
.58297 .41396 m .58784 .43003 L .58162 .42425 L p F P
0 g
s
.641 .543 .728 r
.58162 .42425 m .57655 .40826 L .58297 .41396 L p F P
0 g
s
.673 .552 .71 r
.52928 .18625 m .53416 .21077 L .52578 .20718 L p F P
0 g
s
.671 .552 .711 r
.53086 .23059 m .52578 .20718 L .53416 .21077 L p F P
0 g
s
.772 .648 .726 r
.4571 .14161 m .45119 .14302 L .46096 .12057 L p F P
0 g
s
.776 .655 .729 r
.45119 .14302 m .4571 .14161 L .44753 .16229 L p F P
0 g
s
.771 .653 .731 r
.4349 .19924 m .42837 .2017 L .43795 .18234 L p F P
0 g
s
.777 .661 .735 r
.42837 .2017 m .4349 .19924 L .42553 .21691 L p F P
0 g
s
.621 .422 .591 r
.24605 .43836 m .25633 .42667 L .24685 .43216 L p F P
0 g
s
.621 .422 .591 r
.24685 .43216 m .23636 .44393 L .24605 .43836 L p F P
0 g
s
.646 .545 .725 r
.5781 .3971 m .58297 .41396 L .57655 .40826 L p F P
0 g
s
.646 .545 .725 r
.57655 .40826 m .57149 .39151 L .5781 .3971 L p F P
0 g
s
.671 .552 .711 r
.53416 .21077 m .53905 .23454 L .53086 .23059 L p F P
0 g
s
.669 .551 .712 r
.53594 .25329 m .53086 .23059 L .53905 .23454 L p F P
0 g
s
.419 .153 .401 r
.2944 .39729 m .30384 .38688 L .29452 .39511 L p F P
0 g
s
.419 .153 .401 r
.29452 .39511 m .28487 .40575 L .2944 .39729 L p F P
0 g
s
.65 .546 .723 r
.57322 .37948 m .5781 .3971 L .57149 .39151 L p F P
0 g
s
.65 .546 .723 r
.57149 .39151 m .56641 .37401 L .57322 .37948 L p F P
0 g
s
.777 .661 .735 r
.42553 .21691 m .41879 .22038 L .42837 .2017 L p F P
0 g
s
.783 .671 .74 r
.41879 .22038 m .42553 .21691 L .41616 .23399 L p F P
0 g
s
.669 .551 .712 r
.53905 .23454 m .54393 .25754 L .53594 .25329 L p F P
0 g
s
.667 .55 .713 r
.54102 .27526 m .53594 .25329 L .54393 .25754 L p F P
0 g
s
.654 .547 .721 r
.56835 .36108 m .57322 .37948 L .56641 .37401 L p F P
0 g
s
.654 .547 .721 r
.56641 .37401 m .56134 .35575 L .56835 .36108 L p F P
0 g
s
.776 .655 .729 r
.44753 .16229 m .44141 .16472 L .45119 .14302 L p F P
0 g
s
.781 .662 .732 r
.44141 .16472 m .44753 .16229 L .43795 .18234 L p F P
0 g
s
.667 .55 .713 r
.54393 .25754 m .54882 .27978 L .54102 .27526 L p F P
0 g
s
.665 .55 .714 r
.5461 .2965 m .54102 .27526 L .54882 .27978 L p F P
0 g
s
.245 0 .24 r
.30394 .38809 m .31317 .37794 L .30384 .38688 L p F P
0 g
s
.245 0 .24 r
.30384 .38688 m .2944 .39729 L .30394 .38809 L p F P
0 g
s
.657 .548 .719 r
.56347 .34191 m .56835 .36108 L .56134 .35575 L p F P
0 g
s
.657 .548 .719 r
.56134 .35575 m .55626 .33675 L .56347 .34191 L p F P
0 g
s
.665 .55 .714 r
.54882 .27978 m .5537 .30126 L .5461 .2965 L p F P
0 g
s
.663 .549 .716 r
.55118 .31699 m .5461 .2965 L .5537 .30126 L p F P
0 g
s
.602 .396 .575 r
.25575 .43201 m .26583 .42043 L .25633 .42667 L p F P
0 g
s
.602 .396 .575 r
.25633 .42667 m .24605 .43836 L .25575 .43201 L p F P
0 g
s
.783 .671 .74 r
.41616 .23399 m .40921 .23835 L .41879 .22038 L p F P
0 g
s
.79 .682 .745 r
.40921 .23835 m .41616 .23399 L .40678 .25045 L p F P
0 g
s
.66 .549 .717 r
.55859 .32197 m .56347 .34191 L .55626 .33675 L p F P
0 g
s
.66 .549 .717 r
.55626 .33675 m .55118 .31699 L .55859 .32197 L p F P
0 g
s
.663 .549 .716 r
.5537 .30126 m .55859 .32197 L .55118 .31699 L p F P
0 g
s
0 0 0 r
.31348 .37816 m .32251 .36831 L .31317 .37794 L p F P
0 g
s
0 0 0 r
.31317 .37794 m .30394 .38809 L .31348 .37816 L p F P
0 g
s
.79 .682 .745 r
.40678 .25045 m .39963 .25561 L .40921 .23835 L p F P
0 g
s
.798 .695 .752 r
.39963 .25561 m .40678 .25045 L .39741 .26625 L p F P
0 g
s
.781 .662 .732 r
.43795 .18234 m .43162 .18567 L .44141 .16472 L p F P
0 g
s
.785 .67 .736 r
.43162 .18567 m .43795 .18234 L .42837 .2017 L p F P
0 g
s
.674 .926 .621 r
.32304 .36748 m .33186 .35797 L .32251 .36831 L p F P
0 g
s
.674 .926 .621 r
.32251 .36831 m .31348 .37816 L .32304 .36748 L p F P
0 g
s
.798 .695 .752 r
.39741 .26625 m .39005 .27214 L .39963 .25561 L p F P
0 g
s
.807 .711 .76 r
.39005 .27214 m .39741 .26625 L .38804 .2814 L p F P
0 g
s
.576 .361 .552 r
.26547 .42489 m .27534 .41346 L .26583 .42043 L p F P
0 g
s
.576 .361 .552 r
.26583 .42043 m .25575 .43201 L .26547 .42489 L p F P
0 g
s
.881 .985 .82 r
.3326 .35606 m .34121 .34694 L .33186 .35797 L p F P
0 g
s
.881 .985 .82 r
.33186 .35797 m .32304 .36748 L .3326 .35606 L p F P
0 g
s
.807 .711 .76 r
.38804 .2814 m .38047 .28796 L .39005 .27214 L p F P
0 g
s
.818 .731 .769 r
.38047 .28796 m .38804 .2814 L .37867 .29588 L p F P
0 g
s
.89 .907 .832 r
.34216 .34391 m .35057 .33521 L .34121 .34694 L p F P
0 g
s
.89 .907 .832 r
.34121 .34694 m .3326 .35606 L .34216 .34391 L p F P
0 g
s
.818 .731 .769 r
.37867 .29588 m .37089 .30304 L .38047 .28796 L p F P
0 g
s
.831 .757 .781 r
.37089 .30304 m .37867 .29588 L .3693 .30968 L p F P
0 g
s
.869 .839 .814 r
.35173 .33102 m .35993 .32279 L .35057 .33521 L p F P
0 g
s
.869 .839 .814 r
.35057 .33521 m .34216 .34391 L .35173 .33102 L p F P
0 g
s
.831 .757 .781 r
.3693 .30968 m .36131 .3174 L .37089 .30304 L p F P
0 g
s
.848 .791 .796 r
.36131 .3174 m .3693 .30968 L .35993 .32279 L p F P
0 g
s
.785 .67 .736 r
.42837 .2017 m .42183 .20587 L .43162 .18567 L p F P
0 g
s
.791 .678 .74 r
.42183 .20587 m .42837 .2017 L .41879 .22038 L p F P
0 g
s
.848 .791 .796 r
.35993 .32279 m .35173 .33102 L .36131 .3174 L p F P
0 g
s
.537 .309 .517 r
.27519 .41699 m .28487 .40575 L .27534 .41346 L p F P
0 g
s
.537 .309 .517 r
.27534 .41346 m .26547 .42489 L .27519 .41699 L p F P
0 g
s
.791 .678 .74 r
.41879 .22038 m .41204 .2253 L .42183 .20587 L p F P
0 g
s
.797 .688 .745 r
.41204 .2253 m .41879 .22038 L .40921 .23835 L p F P
0 g
s
.474 .229 .461 r
.28493 .40831 m .2944 .39729 L .28487 .40575 L p F P
0 g
s
.474 .229 .461 r
.28487 .40575 m .27519 .41699 L .28493 .40831 L p F P
0 g
s
.797 .688 .745 r
.40921 .23835 m .40225 .24398 L .41204 .2253 L p F P
0 g
s
.804 .7 .751 r
.40225 .24398 m .40921 .23835 L .39963 .25561 L p F P
0 g
s
.362 .091 .361 r
.29468 .39886 m .30394 .38809 L .2944 .39729 L p F P
0 g
s
.362 .091 .361 r
.2944 .39729 m .28493 .40831 L .29468 .39886 L p F P
0 g
s
.804 .7 .751 r
.39963 .25561 m .39246 .2619 L .40225 .24398 L p F P
0 g
s
.812 .715 .758 r
.39246 .2619 m .39963 .25561 L .39005 .27214 L p F P
0 g
s
.133 0 .154 r
.30443 .38864 m .31348 .37816 L .30394 .38809 L p F P
0 g
s
.133 0 .154 r
.30394 .38809 m .29468 .39886 L .30443 .38864 L p F P
0 g
s
.812 .715 .758 r
.39005 .27214 m .38267 .27905 L .39246 .2619 L p F P
0 g
s
.822 .733 .766 r
.38267 .27905 m .39005 .27214 L .38047 .28796 L p F P
0 g
s
0 0 0 r
.31419 .37764 m .32304 .36748 L .31348 .37816 L p F P
0 g
s
0 0 0 r
.31348 .37816 m .30443 .38864 L .31419 .37764 L p F P
0 g
s
.822 .733 .766 r
.38047 .28796 m .37288 .29544 L .38267 .27905 L p F P
0 g
s
.835 .757 .776 r
.37288 .29544 m .38047 .28796 L .37089 .30304 L p F P
0 g
s
.788 .979 .705 r
.32396 .36587 m .3326 .35606 L .32304 .36748 L p F P
0 g
s
.788 .979 .705 r
.32304 .36748 m .31419 .37764 L .32396 .36587 L p F P
0 g
s
.835 .757 .776 r
.37089 .30304 m .36309 .31107 L .37288 .29544 L p F P
0 g
s
.851 .788 .789 r
.36309 .31107 m .37089 .30304 L .36131 .3174 L p F P
0 g
s
.899 .966 .82 r
.33374 .35332 m .34216 .34391 L .3326 .35606 L p F P
0 g
s
.899 .966 .82 r
.3326 .35606 m .32396 .36587 L .33374 .35332 L p F P
0 g
s
.851 .788 .789 r
.36131 .3174 m .3533 .32592 L .36309 .31107 L p F P
0 g
s
.87 .83 .805 r
.3533 .32592 m .36131 .3174 L .35173 .33102 L p F P
0 g
s
.892 .89 .821 r
.34351 .34001 m .35173 .33102 L .34216 .34391 L p F P
0 g
s
.892 .89 .821 r
.34216 .34391 m .33374 .35332 L .34351 .34001 L p F P
0 g
s
.87 .83 .805 r
.35173 .33102 m .34351 .34001 L .3533 .32592 L p F P
0 g
s
.25 Mabswid
.00439 .36631 m
.5 0 L
s
.5 0 m
.5 .24107 L
s
.5 .24107 m
0 .60778 L
s
0 .60778 m
.00439 .36631 L
s
.99561 .36631 m
.5 0 L
s
.5 0 m
.5 .24107 L
s
.5 .24107 m
1 .60778 L
s
1 .60778 m
.99561 .36631 L
s
.99561 .36631 m
.5 0 L
s
.98394 .35768 m
.97888 .36134 L
s
[(-2)] .99408 .35036 -1 .72239 Mshowa
.82778 .24227 m
.82273 .24594 L
s
[(-1)] .83789 .23491 -1 .72774 Mshowa
.67045 .12598 m
.66541 .12968 L
s
[(0)] .68053 .11859 -1 .73317 Mshowa
.51194 .00882 m
.50691 .01254 L
s
[(1)] .52199 .0014 -1 .73869 Mshowa
.125 Mabswid
.9528 .33467 m
.94977 .33687 L
s
.92162 .31162 m
.91858 .31382 L
s
.89039 .28854 m
.88735 .29074 L
s
.85911 .26542 m
.85607 .26762 L
s
.79641 .21908 m
.79338 .22129 L
s
.76499 .19586 m
.76196 .19807 L
s
.73352 .1726 m
.7305 .17481 L
s
.70201 .14931 m
.69899 .15152 L
s
.63884 .10262 m
.63582 .10484 L
s
.60719 .07922 m
.60417 .08144 L
s
.57549 .05579 m
.57247 .05802 L
s
.54373 .03232 m
.54072 .03455 L
s
.25 Mabswid
.00439 .36631 m
0 .60778 L
s
.00429 .37201 m
.00936 .37566 L
s
[(0)] -0.00585 .36469 1 .72186 Mshowa
.0027 .45943 m
.00777 .46308 L
s
[(0.1)] -0.00745 .45213 1 .71979 Mshowa
.0011 .54742 m
.00618 .55106 L
s
[(0.2)] -0.00906 .54013 1 .71771 Mshowa
.125 Mabswid
.00397 .38945 m
.00701 .39164 L
s
.00365 .40691 m
.0067 .4091 L
s
.00334 .42439 m
.00638 .42659 L
s
.00302 .4419 m
.00606 .44409 L
s
.00238 .47698 m
.00542 .47917 L
s
.00206 .49456 m
.0051 .49674 L
s
.00174 .51215 m
.00478 .51434 L
s
.00142 .52977 m
.00446 .53196 L
s
.00078 .56508 m
.00382 .56727 L
s
.00045 .58277 m
.0035 .58495 L
s
.00013 .60048 m
.00318 .60266 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{282.438, 272.812},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 281.438}, {271.812, 0}} -> {-0.0808789, -0.0606809, \
0.00398966, 0.00398966}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics3D", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Options", "[", "ParametricPlot3D", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", " ", 
  RowBox[{"forplot", " ", ",", " ", 
   RowBox[{"{", 
    RowBox[{"xx", ",", 
     RowBox[{"-", "2"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"yy", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", " ", 
   RowBox[{"BoxRatios", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "0.3"}], "}"}]}]}], "]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .76154 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.65087e-17 1.04933 -0.0923501 1.04933 [
[.03249 .24209 -12 -8.67431 ]
[.03249 .24209 0 .32569 ]
[.22754 .16633 -11.6554 -9 ]
[.22754 .16633 .34459 0 ]
[.43823 .08455 -5.42134 -9 ]
[.43823 .08455 .57866 0 ]
[.66654 -0.004 -5.01498 -9 ]
[.66654 -0.004 .98502 0 ]
[.77962 .10984 0 -6.12741 ]
[.77962 .10984 12 2.87259 ]
[.86209 .23465 0 -6.0092 ]
[.86209 .23465 6 2.9908 ]
[.9353 .34546 0 -5.90701 ]
[.9353 .34546 6 3.09299 ]
[.01523 .26514 -6 -2.76445 ]
[.01523 .26514 0 6.23555 ]
[.00528 .32753 -18 -2.81682 ]
[.00528 .32753 0 6.18318 ]
[-0.00508 .39246 -18 -2.87155 ]
[-0.00508 .39246 0 6.12845 ]
[ 0 0 0 0 ]
[ 1 .76154 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02811 .25642 m
.69167 0 L
s
.04211 .25101 m
.04692 .25547 L
s
[(-2)] .03249 .24209 1 .92762 Mshowa
.23653 .17588 m
.24103 .18065 L
s
[(-1)] .22754 .16633 .94257 1 Mshowa
.44647 .09475 m
.45059 .09986 L
s
[(0)] .43823 .08455 .80711 1 Mshowa
.67386 .00689 m
.67751 .01233 L
s
[(1)] .66654 -0.004 .67166 1 Mshowa
.125 Mabswid
.07984 .23643 m
.08269 .23914 L
s
.11813 .22163 m
.12095 .22438 L
s
.157 .20661 m
.15978 .2094 L
s
.19646 .19136 m
.1992 .19418 L
s
.27722 .16015 m
.27988 .16306 L
s
.31854 .14419 m
.32116 .14713 L
s
.36052 .12797 m
.36308 .13095 L
s
.40315 .11149 m
.40567 .11451 L
s
.49048 .07774 m
.4929 .08085 L
s
.53521 .06046 m
.53758 .0636 L
s
.58067 .04289 m
.58298 .04608 L
s
.62688 .02504 m
.62913 .02826 L
s
.25 Mabswid
.69167 0 m
.97681 .43105 L
s
.76728 .1143 m
.76112 .11653 L
s
[(-1)] .77962 .10984 -1 .36165 Mshowa
.84966 .23882 m
.84344 .24091 L
s
[(0)] .86209 .23465 -1 .33538 Mshowa
.92279 .34938 m
.91653 .35133 L
s
[(1)] .9353 .34546 -1 .31267 Mshowa
.125 Mabswid
.78458 .14045 m
.78087 .14177 L
s
.80145 .16595 m
.79774 .16725 L
s
.81791 .19083 m
.81419 .19212 L
s
.83397 .21512 m
.83025 .21639 L
s
.86497 .26197 m
.86123 .26321 L
s
.87993 .28459 m
.87619 .28581 L
s
.89454 .30668 m
.8908 .30788 L
s
.90882 .32827 m
.90507 .32946 L
s
.74954 .08748 m
.74585 .08884 L
s
.73134 .05997 m
.72766 .06134 L
s
.71266 .03173 m
.70899 .03313 L
s
.69349 .00274 m
.68982 .00416 L
s
.93644 .37001 m
.93268 .37117 L
s
.94979 .3902 m
.94603 .39135 L
s
.96285 .40995 m
.95908 .41108 L
s
.97563 .42927 m
.97186 .43039 L
s
.25 Mabswid
.02811 .25642 m
0 .43378 L
s
.02747 .26042 m
.03359 .25806 L
s
[(0)] .01523 .26514 1 -0.38568 Mshowa
.01757 .32293 m
.02371 .32064 L
s
[(0.1)] .00528 .32753 1 -0.37404 Mshowa
.00726 .38799 m
.01342 .38576 L
s
[(0.2)] -0.00508 .39246 1 -0.36188 Mshowa
.125 Mabswid
.02552 .27273 m
.0292 .27132 L
s
.02356 .28513 m
.02723 .28373 L
s
.02158 .29763 m
.02526 .29624 L
s
.01958 .31023 m
.02326 .30885 L
s
.01554 .33574 m
.01923 .33437 L
s
.01349 .34864 m
.01718 .34728 L
s
.01143 .36165 m
.01512 .3603 L
s
.00935 .37477 m
.01305 .37342 L
s
.00514 .40132 m
.00885 .39999 L
s
.00301 .41476 m
.00672 .41344 L
s
.00087 .42831 m
.00458 .427 L
s
.25 Mabswid
.02811 .25642 m
0 .43378 L
s
0 .43378 m
.39748 .76154 L
s
.39748 .76154 m
.40309 .60101 L
s
.40309 .60101 m
.02811 .25642 L
s
.69167 0 m
.97681 .43105 L
s
.97681 .43105 m
1 .60069 L
s
1 .60069 m
.70245 .18561 L
s
.70245 .18561 m
.69167 0 L
s
.02811 .25642 m
0 .43378 L
s
0 .43378 m
.70245 .18561 L
s
.70245 .18561 m
.69167 0 L
s
.69167 0 m
.02811 .25642 L
s
.40309 .60101 m
.97681 .43105 L
s
.97681 .43105 m
1 .60069 L
s
1 .60069 m
.39748 .76154 L
s
.39748 .76154 m
.40309 .60101 L
s
0 0 m
1 0 L
1 .76154 L
0 .76154 L
closepath
clip
newpath
.5 Mabswid
.566 .46 .693 r
.24658 .44481 m .26898 .4635 L .26931 .46496 L closepath p F P
0 g
s
.563 .46 .695 r
.24658 .44481 m .26864 .46206 L .26898 .4635 L closepath p F P
0 g
s
.56 .46 .698 r
.24658 .44481 m .2683 .46064 L .26864 .46206 L closepath p F P
0 g
s
.557 .461 .701 r
.24658 .44481 m .26796 .45925 L .2683 .46064 L closepath p F P
0 g
s
.553 .462 .706 r
.24658 .44481 m .26762 .4579 L .26796 .45925 L closepath p F P
0 g
s
.548 .463 .711 r
.24658 .44481 m .26727 .4566 L .26762 .4579 L closepath p F P
0 g
s
.543 .465 .718 r
.24658 .44481 m .26692 .45534 L .26727 .4566 L closepath p F P
0 g
s
.536 .468 .727 r
.24658 .44481 m .26657 .45415 L .26692 .45534 L closepath p F P
0 g
s
.527 .473 .739 r
.24658 .44481 m .26621 .45302 L .26657 .45415 L closepath p F P
0 g
s
.516 .48 .755 r
.24658 .44481 m .26584 .45199 L .26621 .45302 L closepath p F P
0 g
s
.502 .49 .776 r
.24658 .44481 m .26546 .45105 L .26584 .45199 L closepath p F P
0 g
s
.48 .506 .807 r
.24658 .44481 m .26508 .45024 L .26546 .45105 L closepath p F P
0 g
s
.447 .528 .848 r
.24658 .44481 m .26468 .44955 L .26508 .45024 L closepath p F P
0 g
s
.39 .559 .9 r
.24658 .44481 m .26428 .44901 L .26468 .44955 L closepath p F P
0 g
s
.283 .587 .945 r
.24658 .44481 m .26386 .44862 L .26428 .44901 L closepath p F P
0 g
s
.092 .568 .906 r
.24658 .44481 m .26343 .44839 L .26386 .44862 L closepath p F P
0 g
s
0 .447 .696 r
.24658 .44481 m .26299 .44829 L .26343 .44839 L closepath p F P
0 g
s
.31 0 0 r
.24658 .44481 m .26253 .44833 L .26299 .44829 L closepath p F P
0 g
s
.391 0 0 r
.24658 .44481 m .26207 .44848 L .26253 .44833 L closepath p F P
0 g
s
.427 0 0 r
.24658 .44481 m .2616 .44874 L .26207 .44848 L closepath p F P
0 g
s
.443 0 0 r
.24658 .44481 m .26112 .44908 L .2616 .44874 L closepath p F P
0 g
s
.45 0 .049 r
.24658 .44481 m .26064 .4495 L .26112 .44908 L closepath p F P
0 g
s
.452 0 .086 r
.24658 .44481 m .26015 .44998 L .26064 .4495 L closepath p F P
0 g
s
.452 .013 .112 r
.24658 .44481 m .25966 .45051 L .26015 .44998 L closepath p F P
0 g
s
.45 .021 .131 r
.24658 .44481 m .25916 .45108 L .25966 .45051 L closepath p F P
0 g
s
.448 .026 .145 r
.24658 .44481 m .25866 .45169 L .25916 .45108 L closepath p F P
0 g
s
.445 .03 .155 r
.24658 .44481 m .25815 .45233 L .25866 .45169 L closepath p F P
0 g
s
.443 .032 .163 r
.24658 .44481 m .25765 .453 L .25815 .45233 L closepath p F P
0 g
s
.44 .033 .17 r
.24658 .44481 m .25714 .45369 L .25765 .453 L closepath p F P
0 g
s
.549 .478 .728 r
.28759 .46479 m .26692 .45534 L .26657 .45415 L p F P
0 g
s
.549 .478 .728 r
.26657 .45415 m .28687 .46242 L .28759 .46479 L p F P
0 g
s
.542 .483 .739 r
.28687 .46242 m .26657 .45415 L .26621 .45302 L p F P
0 g
s
.542 .483 .739 r
.26621 .45302 m .28615 .46018 L .28687 .46242 L p F P
0 g
s
.533 .491 .755 r
.28615 .46018 m .26621 .45302 L .26584 .45199 L p F P
0 g
s
.555 .475 .719 r
.2883 .46729 m .26727 .4566 L .26692 .45534 L p F P
0 g
s
.555 .475 .719 r
.26692 .45534 m .28759 .46479 L .2883 .46729 L p F P
0 g
s
.533 .491 .755 r
.26584 .45199 m .28541 .45811 L .28615 .46018 L p F P
0 g
s
.521 .502 .776 r
.28541 .45811 m .26584 .45199 L .26546 .45105 L p F P
0 g
s
.56 .472 .712 r
.289 .46989 m .26762 .4579 L .26727 .4566 L p F P
0 g
s
.56 .472 .712 r
.26727 .4566 m .2883 .46729 L .289 .46989 L p F P
0 g
s
.521 .502 .776 r
.26546 .45105 m .28466 .45624 L .28541 .45811 L p F P
0 g
s
.504 .519 .806 r
.28466 .45624 m .26546 .45105 L .26508 .45024 L p F P
0 g
s
.564 .471 .707 r
.2897 .47257 m .26796 .45925 L .26762 .4579 L p F P
0 g
s
.564 .471 .707 r
.26762 .4579 m .289 .46989 L .2897 .47257 L p F P
0 g
s
.504 .519 .806 r
.26508 .45024 m .28388 .45461 L .28466 .45624 L p F P
0 g
s
.477 .545 .847 r
.28388 .45461 m .26508 .45024 L .26468 .44955 L p F P
0 g
s
.568 .47 .703 r
.29039 .47531 m .2683 .46064 L .26796 .45925 L p F P
0 g
s
.568 .47 .703 r
.26796 .45925 m .2897 .47257 L .29039 .47531 L p F P
0 g
s
.571 .469 .7 r
.29107 .47812 m .26864 .46206 L .2683 .46064 L p F P
0 g
s
.571 .469 .7 r
.2683 .46064 m .29039 .47531 L .29107 .47812 L p F P
0 g
s
.477 .545 .847 r
.26468 .44955 m .28309 .45324 L .28388 .45461 L p F P
0 g
s
.431 .58 .9 r
.28309 .45324 m .26468 .44955 L .26428 .44901 L p F P
0 g
s
.573 .469 .697 r
.29176 .48097 m .26898 .4635 L .26864 .46206 L p F P
0 g
s
.573 .469 .697 r
.26864 .46206 m .29107 .47812 L .29176 .48097 L p F P
0 g
s
.576 .469 .695 r
.29244 .48387 m .26931 .46496 L .26898 .4635 L p F P
0 g
s
.576 .469 .695 r
.26898 .4635 m .29176 .48097 L .29244 .48387 L p F P
0 g
s
.431 .58 .9 r
.26428 .44901 m .28228 .45216 L .28309 .45324 L p F P
0 g
s
.344 .619 .953 r
.28228 .45216 m .26428 .44901 L .26386 .44862 L p F P
0 g
s
.344 .619 .953 r
.26386 .44862 m .28145 .45137 L .28228 .45216 L p F P
0 g
s
.181 .624 .941 r
.28145 .45137 m .26386 .44862 L .26343 .44839 L p F P
0 g
s
.181 .624 .941 r
.26343 .44839 m .28059 .45089 L .28145 .45137 L p F P
0 g
s
0 .527 .765 r
.28059 .45089 m .26343 .44839 L .263 .44829 L p F P
0 g
s
0 .527 .765 r
.26321 .44832 m .28059 .45089 L .263 .44829 L F
.26299 .44829 m .27971 .4507 L .28059 .45089 L p F P
0 g
s
.233 0 0 r
.26253 .44833 m .27882 .45077 L .2797 .4507 L p F P
0 g
s
.233 0 0 r
.2797 .4507 m .27971 .4507 L p .27924 .45063 L F P
0 g
s
.233 0 0 r
.26253 .44833 m .2797 .4507 L .27924 .45063 L F
0 .527 .765 r
.263 .44829 m .26299 .44829 L p .26321 .44832 L F P
0 g
s
.233 0 0 r
.27971 .4507 m .26299 .44829 L .26253 .44833 L p F P
0 g
s
.332 0 0 r
.27882 .45077 m .26253 .44833 L .26207 .44848 L p F P
0 g
s
.522 .034 .039 r
.9567 .43111 m .93458 .45227 L .92671 .43945 L p F P
0 g
s
.522 .034 .039 r
.92671 .43945 m .95163 .44035 L .9567 .43111 L p F P
0 g
s
.332 0 0 r
.26207 .44848 m .2779 .45107 L .27882 .45077 L p F P
0 g
s
.379 0 0 r
.2779 .45107 m .26207 .44848 L .2616 .44874 L p F P
0 g
s
.379 0 0 r
.2616 .44874 m .27696 .45157 L .2779 .45107 L p F P
0 g
s
.402 0 0 r
.27696 .45157 m .2616 .44874 L .26112 .44908 L p F P
0 g
s
.402 0 0 r
.26112 .44908 m .27601 .45225 L .27696 .45157 L p F P
0 g
s
.413 0 .012 r
.27601 .45225 m .26112 .44908 L .26064 .4495 L p F P
0 g
s
.413 0 .012 r
.26064 .4495 m .27505 .45307 L .27601 .45225 L p F P
0 g
s
.417 0 .052 r
.27505 .45307 m .26064 .4495 L .26015 .44998 L p F P
0 g
s
.417 0 .052 r
.26015 .44998 m .27408 .45401 L .27505 .45307 L p F P
0 g
s
.419 0 .08 r
.27408 .45401 m .26015 .44998 L .25966 .45051 L p F P
0 g
s
.419 0 .08 r
.25966 .45051 m .2731 .45505 L .27408 .45401 L p F P
0 g
s
.418 0 .1 r
.2731 .45505 m .25966 .45051 L .25916 .45108 L p F P
0 g
s
.418 0 .1 r
.25916 .45108 m .27211 .45618 L .2731 .45505 L p F P
0 g
s
.417 0 .115 r
.27211 .45618 m .25916 .45108 L .25866 .45169 L p F P
0 g
s
.417 0 .115 r
.25866 .45169 m .27111 .45737 L .27211 .45618 L p F P
0 g
s
.415 0 .126 r
.27111 .45737 m .25866 .45169 L .25815 .45233 L p F P
0 g
s
.562 .487 .729 r
.30857 .47315 m .28759 .46479 L .28687 .46242 L p F P
0 g
s
.562 .487 .729 r
.28687 .46242 m .30749 .4696 L .30857 .47315 L p F P
0 g
s
.556 .493 .74 r
.30749 .4696 m .28687 .46242 L .28615 .46018 L p F P
0 g
s
.556 .493 .74 r
.28615 .46018 m .30639 .46625 L .30749 .4696 L p F P
0 g
s
.549 .501 .755 r
.30639 .46625 m .28615 .46018 L .28541 .45811 L p F P
0 g
s
.567 .484 .72 r
.30964 .47687 m .2883 .46729 L .28759 .46479 L p F P
0 g
s
.567 .484 .72 r
.28759 .46479 m .30857 .47315 L .30964 .47687 L p F P
0 g
s
.549 .501 .755 r
.28541 .45811 m .30528 .46316 L .30639 .46625 L p F P
0 g
s
.539 .514 .776 r
.30528 .46316 m .28541 .45811 L .28466 .45624 L p F P
0 g
s
.571 .481 .714 r
.31071 .48073 m .289 .46989 L .2883 .46729 L p F P
0 g
s
.571 .481 .714 r
.2883 .46729 m .30964 .47687 L .31071 .48073 L p F P
0 g
s
.539 .514 .776 r
.28466 .45624 m .30414 .46036 L .30528 .46316 L p F P
0 g
s
.525 .532 .805 r
.30414 .46036 m .28466 .45624 L .28388 .45461 L p F P
0 g
s
.575 .48 .709 r
.31177 .48471 m .2897 .47257 L .289 .46989 L p F P
0 g
s
.575 .48 .709 r
.289 .46989 m .31071 .48073 L .31177 .48471 L p F P
0 g
s
.415 0 .126 r
.25815 .45233 m .27011 .45863 L .27111 .45737 L p F P
0 g
s
.412 0 .134 r
.27011 .45863 m .25815 .45233 L .25765 .453 L p F P
0 g
s
.578 .478 .705 r
.31282 .4888 m .29039 .47531 L .2897 .47257 L p F P
0 g
s
.578 .478 .705 r
.2897 .47257 m .31177 .48471 L .31282 .4888 L p F P
0 g
s
.525 .532 .805 r
.28388 .45461 m .30298 .45791 L .30414 .46036 L p F P
0 g
s
.505 .56 .845 r
.30298 .45791 m .28388 .45461 L .28309 .45324 L p F P
0 g
s
.581 .478 .702 r
.31386 .49296 m .29107 .47812 L .29039 .47531 L p F P
0 g
s
.581 .478 .702 r
.29039 .47531 m .31282 .4888 L .31386 .49296 L p F P
0 g
s
.584 .477 .699 r
.31491 .4972 m .29176 .48097 L .29107 .47812 L p F P
0 g
s
.584 .477 .699 r
.29107 .47812 m .31386 .49296 L .31491 .4972 L p F P
0 g
s
.505 .56 .845 r
.28309 .45324 m .3018 .45585 L .30298 .45791 L p F P
0 g
s
.469 .599 .899 r
.3018 .45585 m .28309 .45324 L .28228 .45216 L p F P
0 g
s
.586 .477 .697 r
.31595 .50149 m .29244 .48387 L .29176 .48097 L p F P
0 g
s
.586 .477 .697 r
.29176 .48097 m .31491 .4972 L .31595 .50149 L p F P
0 g
s
.412 0 .134 r
.25765 .453 m .2691 .45994 L .27011 .45863 L p F P
0 g
s
.41 0 .14 r
.2691 .45994 m .25765 .453 L .25714 .45369 L p F P
0 g
s
.469 .599 .899 r
.28228 .45216 m .30059 .45422 L .3018 .45585 L p F P
0 g
s
.4 .647 .957 r
.30059 .45422 m .28228 .45216 L .28145 .45137 L p F P
0 g
s
.41 0 .14 r
.25714 .45369 m .26809 .46129 L .2691 .45994 L p F P
0 g
s
.4 .647 .957 r
.28145 .45137 m .29934 .45304 L .30059 .45422 L p F P
0 g
s
.263 .671 .967 r
.29934 .45304 m .28145 .45137 L .28059 .45089 L p F P
0 g
s
.263 .671 .967 r
.28059 .45089 m .29806 .45231 L .29934 .45304 L p F P
0 g
s
.049 .601 .826 r
.29806 .45231 m .28059 .45089 L .27974 .4507 L p F P
0 g
s
.049 .601 .826 r
.28001 .45072 m .29806 .45231 L .27974 .4507 L F
.29675 .45201 m .29806 .45231 L p .29329 .45189 L F P
0 g
s
.049 .601 .826 r
.27971 .4507 m .29675 .45201 L p .29329 .45189 L F P
0 g
s
.144 .669 .877 r
.31582 .45261 m .29806 .45231 L .29678 .45202 L p F P
0 g
s
.144 .669 .877 r
.29678 .45202 m .29675 .45201 L p .29707 .45202 L F P
0 g
s
.144 .669 .877 r
.29707 .45202 m .31582 .45261 L .29678 .45202 L F
.31409 .45221 m .31582 .45261 L p .30978 .45242 L F P
0 g
s
.144 .669 .877 r
.29675 .45201 m .31409 .45221 L p .30978 .45242 L F P
0 g
s
.235 .728 .918 r
.33171 .45127 m .33387 .45178 L p .32665 .45194 L F P
0 g
s
.235 .728 .918 r
.31409 .45221 m .33171 .45127 L p .32665 .45194 L F P
0 g
s
0 0 0 r
.33171 .45127 m .31409 .45221 L p .31843 .45199 L F P
0 g
s
.235 .728 .918 r
.33387 .45178 m .31582 .45261 L .31413 .45222 L p F P
0 g
s
.235 .728 .918 r
.31441 .4522 m .33387 .45178 L .31413 .45222 L F
.404 .744 .993 r
.31582 .45261 m .33387 .45178 L .33597 .45302 L p F P
0 g
s
.319 .778 .948 r
.35218 .44981 m .33387 .45178 L .33171 .45127 L p F P
0 g
s
.03 0 0 r
.32952 .4514 m .32728 .4521 L p .33378 .45118 L F P
0 g
s
0 0 0 r
.33169 .45127 m .33171 .45127 L p .33149 .45128 L F P
0 g
s
0 0 0 r
.31232 .45232 m .33169 .45127 L .33149 .45128 L F
.127 .676 .758 r
.33171 .45127 m .32952 .4514 L p .33681 .45059 L F P
0 g
s
.127 .676 .758 r
.34961 .44917 m .33171 .45127 L p .33681 .45059 L F P
0 g
s
.319 .778 .948 r
.33171 .45127 m .34961 .44917 L .35218 .44981 L p F P
0 g
s
.127 .676 .758 r
.347 .44931 m .34961 .44917 L p .34219 .45 L F P
0 g
s
.127 .676 .758 r
.32952 .4514 m .347 .44931 L p .34219 .45 L F P
0 g
s
.218 .741 .807 r
.36777 .44591 m .34961 .44917 L .34711 .44931 L p F P
0 g
s
.218 .741 .807 r
.34711 .44931 m .347 .44931 L p .34769 .4492 L F P
0 g
s
.218 .741 .807 r
.34769 .4492 m .36777 .44591 L .34711 .44931 L F
.36475 .44605 m .36777 .44591 L p .35943 .44728 L F P
0 g
s
.218 .741 .807 r
.347 .44931 m .36475 .44605 L p .35943 .44728 L F P
0 g
s
.303 .797 .847 r
.38618 .44147 m .36777 .44591 L .36475 .44605 L p F P
0 g
s
.303 .797 .847 r
.38276 .44161 m .38618 .44147 L p .37697 .44344 L F P
0 g
s
.303 .797 .847 r
.36475 .44605 m .38276 .44161 L p .37697 .44344 L F P
0 g
s
0 0 0 r
.38276 .44161 m .36475 .44605 L p .37012 .44482 L F P
0 g
s
0 0 0 r
.37929 .44261 m .38276 .44161 L p .37475 .44364 L F P
0 g
s
0 0 0 r
.36168 .44697 m .37929 .44261 L p .37475 .44364 L F P
0 g
s
.464 .851 .98 r
.36777 .44591 m .38618 .44147 L .38954 .44234 L p F P
0 g
s
0 0 0 r
.37929 .44261 m .37576 .44432 L p .38386 .44156 L F P
0 g
s
.23 .74 .702 r
.38276 .44161 m .37929 .44261 L p .3886 .43976 L F P
0 g
s
.23 .74 .702 r
.40101 .43597 m .38276 .44161 L p .3886 .43976 L F P
0 g
s
.382 .844 .876 r
.40482 .43583 m .38618 .44147 L .38276 .44161 L p F P
0 g
s
.382 .844 .876 r
.38276 .44161 m .40101 .43597 L .40482 .43583 L p F P
0 g
s
.23 .74 .702 r
.39715 .43704 m .40101 .43597 L p .3923 .43863 L F P
0 g
s
.23 .74 .702 r
.37929 .44261 m .39715 .43704 L p .3923 .43863 L F P
0 g
s
.312 .796 .743 r
.41949 .42913 m .40101 .43597 L .39715 .43704 L p F P
0 g
s
0 0 0 r
.39715 .43704 m .39322 .4389 L p .40203 .43545 L F P
0 g
s
.312 .796 .743 r
.41524 .43027 m .41949 .42913 L p .41013 .43244 L F P
0 g
s
.312 .796 .743 r
.39715 .43704 m .41524 .43027 L p .41013 .43244 L F P
0 g
s
.387 .843 .776 r
.43817 .42109 m .41949 .42913 L .41524 .43027 L p F P
0 g
s
.387 .843 .776 r
.43356 .4223 m .43817 .42109 L p .42822 .42508 L F P
0 g
s
.387 .843 .776 r
.41524 .43027 m .43356 .4223 L p .42822 .42508 L F P
0 g
s
0 0 0 r
.43356 .4223 m .41524 .43027 L p .4204 .42808 L F P
0 g
s
0 0 0 r
.42889 .42436 m .43356 .4223 L p .42522 .42596 L F P
0 g
s
0 0 0 r
.41094 .43224 m .42889 .42436 L p .42522 .42596 L F P
0 g
s
0 0 0 r
.42889 .42436 m .42415 .42711 L p .43259 .42275 L F P
0 g
s
.359 .812 .687 r
.43356 .4223 m .42889 .42436 L p .43895 .41949 L F P
0 g
s
.359 .812 .687 r
.44706 .41527 m .45209 .41313 L p .44335 .41736 L F P
0 g
s
.359 .812 .687 r
.42889 .42436 m .44706 .41527 L p .44335 .41736 L F P
0 g
s
0 0 0 r
.44706 .41527 m .42889 .42436 L p .43259 .42275 L F P
0 g
s
.359 .812 .687 r
.45209 .41313 m .43356 .4223 L p .43895 .41949 L F P
0 g
s
.454 .882 .801 r
.45705 .41188 m .43817 .42109 L .43356 .4223 L p F P
0 g
s
.454 .882 .801 r
.43356 .4223 m .45209 .41313 L .45705 .41188 L p F P
0 g
s
0 0 0 r
.44197 .41809 m .44706 .41527 L p .43995 .41894 L F P
0 g
s
0 0 0 r
.42415 .42711 m .44197 .41809 L p .43995 .41894 L F P
0 g
s
0 0 0 r
.44197 .41809 m .4368 .42146 L p .444 .41724 L F P
0 g
s
.373 .808 .644 r
.44706 .41527 m .44197 .41809 L p .45081 .41316 L F P
0 g
s
.373 .808 .644 r
.46544 .40498 m .44706 .41527 L p .45081 .41316 L F P
0 g
s
.43 .856 .722 r
.4708 .4028 m .45209 .41313 L .44706 .41527 L p F P
0 g
s
.43 .856 .722 r
.44706 .41527 m .46544 .40498 L .4708 .4028 L p F P
0 g
s
.373 .808 .644 r
.46 .40784 m .46544 .40498 L p .45813 .40906 L F P
0 g
s
.373 .808 .644 r
.44197 .41809 m .46 .40784 L p .45813 .40906 L F P
0 g
s
0 0 0 r
.46 .40784 m .44197 .41809 L p .444 .41724 L F P
0 g
s
0 0 0 r
.45448 .41123 m .46 .40784 L p .45415 .41127 L F P
0 g
s
0 0 0 r
.4368 .42146 m .45448 .41123 L p .45415 .41127 L F P
0 g
s
.401 .811 .606 r
.45448 .41123 m .4489 .41505 L p .45482 .41119 L F P
0 g
s
.418 .829 .64 r
.46 .40784 m .45448 .41123 L p .46188 .4066 L F P
0 g
s
.418 .829 .64 r
.45448 .41123 m .47238 .39972 L .47823 .39638 L p F P
0 g
s
.401 .811 .606 r
.47238 .39972 m .45448 .41123 L p .45482 .41119 L F P
0 g
s
.418 .829 .64 r
.47823 .39638 m .46 .40784 L p .46188 .4066 L F P
0 g
s
0 0 0 r
.41524 .43027 m .41094 .43224 L p .4204 .42808 L F P
0 g
s
0 0 0 r
.41524 .43027 m .39715 .43704 L p .40203 .43545 L F P
0 g
s
0 0 0 r
.39715 .43704 m .37929 .44261 L p .38386 .44156 L F P
0 g
s
0 0 0 r
.36475 .44605 m .36168 .44697 L p .37012 .44482 L F P
0 g
s
0 0 0 r
.34434 .45012 m .36168 .44697 L .3647 .44607 L p F P
0 g
s
0 0 0 r
.3647 .44607 m .36475 .44605 L p .36434 .44614 L F P
0 g
s
0 0 0 r
.34434 .45012 m .3647 .44607 L .36434 .44614 L F
.347 .44931 m .34434 .45012 L p .35184 .44863 L F P
0 g
s
0 0 0 r
.36475 .44605 m .347 .44931 L p .35184 .44863 L F P
0 g
s
.03 0 0 r
.347 .44931 m .32952 .4514 L p .33378 .45118 L F P
0 g
s
0 0 0 r
.32952 .4514 m .33169 .45127 L p .3253 .45162 L F P
0 g
s
0 0 0 r
.31232 .45232 m .32952 .4514 L p .3253 .45162 L F P
0 g
s
.235 .728 .918 r
.31413 .45222 m .31409 .45221 L p .31441 .4522 L F P
0 g
s
0 0 0 r
.31409 .45221 m .31232 .45232 L p .31843 .45199 L F P
0 g
s
.059 0 0 r
.29541 .45211 m .31232 .45232 L .31407 .45221 L p F P
0 g
s
.059 0 0 r
.31407 .45221 m .31409 .45221 L p .31382 .45221 L F P
0 g
s
.059 0 0 r
.29541 .45211 m .31407 .45221 L .31382 .45221 L F
.29675 .45201 m .29541 .45211 L p .30024 .45213 L F P
0 g
s
.059 0 0 r
.31409 .45221 m .29675 .45201 L p .30024 .45213 L F P
0 g
s
.148 0 0 r
.27882 .45077 m .29541 .45211 L .29673 .45201 L p F P
0 g
s
.148 0 0 r
.29673 .45201 m .29675 .45201 L p .29641 .45199 L F P
0 g
s
.148 0 0 r
.27882 .45077 m .29673 .45201 L .29641 .45199 L F
.049 .601 .826 r
.27974 .4507 m .27971 .4507 L p .28001 .45072 L F P
0 g
s
.826 .771 .8 r
.93458 .45227 m .91202 .47218 L .90357 .45379 L p F P
0 g
s
.826 .771 .8 r
.90357 .45379 m .92671 .43945 L .93458 .45227 L p F P
0 g
s
.148 0 0 r
.29675 .45201 m .27971 .4507 L .27882 .45077 L p F P
0 g
s
.266 0 0 r
.29541 .45211 m .27882 .45077 L .2779 .45107 L p F P
0 g
s
.266 0 0 r
.2779 .45107 m .29405 .45255 L .29541 .45211 L p F P
0 g
s
.326 0 0 r
.29405 .45255 m .2779 .45107 L .27696 .45157 L p F P
0 g
s
.326 0 0 r
.27696 .45157 m .29266 .45329 L .29405 .45255 L p F P
0 g
s
.356 0 0 r
.29266 .45329 m .27696 .45157 L .27601 .45225 L p F P
0 g
s
.575 .497 .729 r
.32985 .48037 m .30857 .47315 L .30749 .4696 L p F P
0 g
s
.575 .497 .729 r
.30749 .4696 m .32839 .47567 L .32985 .48037 L p F P
0 g
s
.57 .502 .74 r
.32839 .47567 m .30749 .4696 L .30639 .46625 L p F P
0 g
s
.57 .502 .74 r
.30639 .46625 m .32692 .47123 L .32839 .47567 L p F P
0 g
s
.564 .511 .755 r
.32692 .47123 m .30639 .46625 L .30528 .46316 L p F P
0 g
s
.579 .493 .721 r
.33129 .4853 m .30964 .47687 L .30857 .47315 L p F P
0 g
s
.579 .493 .721 r
.30857 .47315 m .32985 .48037 L .33129 .4853 L p F P
0 g
s
.564 .511 .755 r
.30528 .46316 m .32542 .46712 L .32692 .47123 L p F P
0 g
s
.556 .524 .775 r
.32542 .46712 m .30528 .46316 L .30414 .46036 L p F P
0 g
s
.582 .49 .715 r
.33272 .49041 m .31071 .48073 L .30964 .47687 L p F P
0 g
s
.582 .49 .715 r
.30964 .47687 m .33129 .4853 L .33272 .49041 L p F P
0 g
s
.586 .488 .71 r
.33415 .49567 m .31177 .48471 L .31071 .48073 L p F P
0 g
s
.586 .488 .71 r
.31071 .48073 m .33272 .49041 L .33415 .49567 L p F P
0 g
s
.556 .524 .775 r
.30414 .46036 m .32391 .46339 L .32542 .46712 L p F P
0 g
s
.546 .544 .803 r
.32391 .46339 m .30414 .46036 L .30298 .45791 L p F P
0 g
s
.589 .487 .706 r
.33557 .50105 m .31282 .4888 L .31177 .48471 L p F P
0 g
s
.589 .487 .706 r
.31177 .48471 m .33415 .49567 L .33557 .50105 L p F P
0 g
s
.356 0 0 r
.27601 .45225 m .29124 .45429 L .29266 .45329 L p F P
0 g
s
.371 0 0 r
.29124 .45429 m .27601 .45225 L .27505 .45307 L p F P
0 g
s
.546 .544 .803 r
.30298 .45791 m .32237 .46011 L .32391 .46339 L p F P
0 g
s
.53 .573 .843 r
.32237 .46011 m .30298 .45791 L .3018 .45585 L p F P
0 g
s
.591 .486 .703 r
.33698 .50654 m .31386 .49296 L .31282 .4888 L p F P
0 g
s
.591 .486 .703 r
.31282 .4888 m .33557 .50105 L .33698 .50654 L p F P
0 g
s
.594 .486 .701 r
.33839 .51212 m .31491 .4972 L .31386 .49296 L p F P
0 g
s
.594 .486 .701 r
.31386 .49296 m .33698 .50654 L .33839 .51212 L p F P
0 g
s
.53 .573 .843 r
.3018 .45585 m .32079 .45736 L .32237 .46011 L p F P
0 g
s
.503 .615 .896 r
.32079 .45736 m .3018 .45585 L .30059 .45422 L p F P
0 g
s
.596 .486 .699 r
.3398 .51778 m .31595 .50149 L .31491 .4972 L p F P
0 g
s
.596 .486 .699 r
.31491 .4972 m .33839 .51212 L .3398 .51778 L p F P
0 g
s
.371 0 0 r
.27505 .45307 m .28981 .45549 L .29124 .45429 L p F P
0 g
s
.379 0 .015 r
.28981 .45549 m .27505 .45307 L .27408 .45401 L p F P
0 g
s
.503 .615 .896 r
.30059 .45422 m .31917 .45517 L .32079 .45736 L p F P
0 g
s
.45 .67 .957 r
.31917 .45517 m .30059 .45422 L .29934 .45304 L p F P
0 g
s
.45 .67 .957 r
.29934 .45304 m .31752 .45359 L .31917 .45517 L p F P
0 g
s
.337 .711 .984 r
.31752 .45359 m .29934 .45304 L .29806 .45231 L p F P
0 g
s
.379 0 .015 r
.27408 .45401 m .28837 .45687 L .28981 .45549 L p F P
0 g
s
.382 0 .044 r
.28837 .45687 m .27408 .45401 L .2731 .45505 L p F P
0 g
s
.815 .699 .737 r
.91202 .47218 m .88903 .49079 L .88053 .4708 L p F P
0 g
s
.815 .699 .737 r
.88053 .4708 m .90357 .45379 L .91202 .47218 L p F P
0 g
s
0 0 0 r
.92671 .43945 m .90357 .45379 L .89604 .44403 L p F P
0 g
s
.609 .107 .033 r
.95163 .44035 m .92671 .43945 L .92042 .44049 L p F P
0 g
s
0 0 0 r
.89604 .44403 m .92042 .44049 L .92671 .43945 L p F P
0 g
s
.337 .711 .984 r
.29806 .45231 m .31582 .45261 L .31752 .45359 L p F P
0 g
s
.382 0 .044 r
.2731 .45505 m .28691 .4584 L .28837 .45687 L p F P
0 g
s
.382 0 .066 r
.28691 .4584 m .2731 .45505 L .27211 .45618 L p F P
0 g
s
.609 .107 .033 r
.92042 .44049 m .94624 .44832 L .95163 .44035 L p F P
0 g
s
.382 0 .066 r
.27211 .45618 m .28543 .46005 L .28691 .4584 L p F P
0 g
s
.382 0 .081 r
.28543 .46005 m .27211 .45618 L .27111 .45737 L p F P
0 g
s
.586 .505 .73 r
.35139 .48645 m .32985 .48037 L .32839 .47567 L p F P
0 g
s
.586 .505 .73 r
.32839 .47567 m .34956 .48061 L .35139 .48645 L p F P
0 g
s
.582 .511 .74 r
.34956 .48061 m .32839 .47567 L .32692 .47123 L p F P
0 g
s
.59 .501 .722 r
.35321 .49256 m .33129 .4853 L .32985 .48037 L p F P
0 g
s
.59 .501 .722 r
.32985 .48037 m .35139 .48645 L .35321 .49256 L p F P
0 g
s
.582 .511 .74 r
.32692 .47123 m .34771 .47509 L .34956 .48061 L p F P
0 g
s
.578 .521 .754 r
.34771 .47509 m .32692 .47123 L .32542 .46712 L p F P
0 g
s
.193 0 0 r
.31232 .45232 m .29541 .45211 L .29405 .45255 L p F P
0 g
s
.593 .498 .716 r
.35502 .49889 m .33272 .49041 L .33129 .4853 L p F P
0 g
s
.593 .498 .716 r
.33129 .4853 m .35321 .49256 L .35502 .49889 L p F P
0 g
s
.578 .521 .754 r
.32542 .46712 m .34584 .46996 L .34771 .47509 L p F P
0 g
s
.572 .534 .774 r
.34584 .46996 m .32542 .46712 L .32391 .46339 L p F P
0 g
s
.596 .497 .712 r
.35683 .50539 m .33415 .49567 L .33272 .49041 L p F P
0 g
s
.596 .497 .712 r
.33272 .49041 m .35502 .49889 L .35683 .50539 L p F P
0 g
s
.572 .534 .774 r
.32391 .46339 m .34394 .4653 L .34584 .46996 L p F P
0 g
s
.565 .554 .801 r
.34394 .4653 m .32391 .46339 L .32237 .46011 L p F P
0 g
s
.599 .495 .708 r
.35862 .51205 m .33557 .50105 L .33415 .49567 L p F P
0 g
s
.599 .495 .708 r
.33415 .49567 m .35683 .50539 L .35862 .51205 L p F P
0 g
s
.382 0 .081 r
.27111 .45737 m .28395 .46181 L .28543 .46005 L p F P
0 g
s
.38 0 .093 r
.28395 .46181 m .27111 .45737 L .27011 .45863 L p F P
0 g
s
.601 .495 .705 r
.36041 .51883 m .33698 .50654 L .33557 .50105 L p F P
0 g
s
.601 .495 .705 r
.33557 .50105 m .35862 .51205 L .36041 .51883 L p F P
0 g
s
.565 .554 .801 r
.32237 .46011 m .34201 .4612 L .34394 .4653 L p F P
0 g
s
.554 .585 .839 r
.34201 .4612 m .32237 .46011 L .32079 .45736 L p F P
0 g
s
.604 .494 .702 r
.3622 .52572 m .33839 .51212 L .33698 .50654 L p F P
0 g
s
.604 .494 .702 r
.33698 .50654 m .36041 .51883 L .3622 .52572 L p F P
0 g
s
.193 0 0 r
.29405 .45255 m .31051 .4529 L .31232 .45232 L p F P
0 g
s
.266 0 0 r
.31051 .4529 m .29405 .45255 L .29266 .45329 L p F P
0 g
s
.805 .813 .858 r
.90357 .45379 m .88053 .4708 L .87249 .4555 L p F P
0 g
s
.805 .813 .858 r
.87249 .4555 m .89604 .44403 L .90357 .45379 L p F P
0 g
s
.606 .494 .7 r
.36398 .5327 m .3398 .51778 L .33839 .51212 L p F P
0 g
s
.606 .494 .7 r
.33839 .51212 m .3622 .52572 L .36398 .5327 L p F P
0 g
s
.554 .585 .839 r
.32079 .45736 m .34004 .45775 L .34201 .4612 L p F P
0 g
s
.534 .629 .892 r
.34004 .45775 m .32079 .45736 L .31917 .45517 L p F P
0 g
s
.38 0 .093 r
.27011 .45863 m .28245 .46365 L .28395 .46181 L p F P
0 g
s
.378 0 .101 r
.28245 .46365 m .27011 .45863 L .2691 .45994 L p F P
0 g
s
.534 .629 .892 r
.31917 .45517 m .33803 .45501 L .34004 .45775 L p F P
0 g
s
.494 .689 .954 r
.33803 .45501 m .31917 .45517 L .31752 .45359 L p F P
0 g
s
.266 0 0 r
.29266 .45329 m .30867 .45387 L .31051 .4529 L p F P
0 g
s
.304 0 0 r
.30867 .45387 m .29266 .45329 L .29124 .45429 L p F P
0 g
s
.803 .677 .724 r
.88903 .49079 m .86566 .50806 L .85725 .48744 L p F P
0 g
s
.803 .677 .724 r
.85725 .48744 m .88053 .4708 L .88903 .49079 L p F P
0 g
s
.378 0 .101 r
.2691 .45994 m .28095 .46557 L .28245 .46365 L p F P
0 g
s
.375 0 .108 r
.28095 .46557 m .2691 .45994 L .26809 .46129 L p F P
0 g
s
.494 .689 .954 r
.31752 .45359 m .33597 .45302 L .33803 .45501 L p F P
0 g
s
.404 .744 .993 r
.33597 .45302 m .31752 .45359 L .31582 .45261 L p F P
0 g
s
.375 0 .108 r
.26809 .46129 m .27943 .46755 L .28095 .46557 L p F P
0 g
s
.304 0 0 r
.29124 .45429 m .30681 .45516 L .30867 .45387 L p F P
0 g
s
.324 0 0 r
.30681 .45516 m .29124 .45429 L .28981 .45549 L p F P
0 g
s
.598 .514 .73 r
.3732 .49137 m .35139 .48645 L .34956 .48061 L p F P
0 g
s
.598 .514 .73 r
.34956 .48061 m .37098 .48441 L .3732 .49137 L p F P
0 g
s
.595 .52 .74 r
.37098 .48441 m .34956 .48061 L .34771 .47509 L p F P
0 g
s
.601 .51 .723 r
.3754 .49863 m .35321 .49256 L .35139 .48645 L p F P
0 g
s
.601 .51 .723 r
.35139 .48645 m .3732 .49137 L .3754 .49863 L p F P
0 g
s
.595 .52 .74 r
.34771 .47509 m .36875 .47781 L .37098 .48441 L p F P
0 g
s
.591 .529 .754 r
.36875 .47781 m .34771 .47509 L .34584 .46996 L p F P
0 g
s
.604 .507 .717 r
.37759 .50615 m .35502 .49889 L .35321 .49256 L p F P
0 g
s
.604 .507 .717 r
.35321 .49256 m .3754 .49863 L .37759 .50615 L p F P
0 g
s
.591 .529 .754 r
.34584 .46996 m .3665 .47168 L .36875 .47781 L p F P
0 g
s
.587 .543 .772 r
.3665 .47168 m .34584 .46996 L .34394 .4653 L p F P
0 g
s
.606 .505 .713 r
.37977 .51386 m .35683 .50539 L .35502 .49889 L p F P
0 g
s
.606 .505 .713 r
.35502 .49889 m .37759 .50615 L .37977 .51386 L p F P
0 g
s
.609 .504 .709 r
.38195 .52175 m .35862 .51205 L .35683 .50539 L p F P
0 g
s
.609 .504 .709 r
.35683 .50539 m .37977 .51386 L .38195 .52175 L p F P
0 g
s
.587 .543 .772 r
.34394 .4653 m .36422 .46609 L .3665 .47168 L p F P
0 g
s
.583 .564 .799 r
.36422 .46609 m .34394 .4653 L .34201 .4612 L p F P
0 g
s
.324 0 0 r
.28981 .45549 m .30492 .45673 L .30681 .45516 L p F P
0 g
s
.335 0 0 r
.30492 .45673 m .28981 .45549 L .28837 .45687 L p F P
0 g
s
.611 .503 .706 r
.38412 .52979 m .36041 .51883 L .35862 .51205 L p F P
0 g
s
.611 .503 .706 r
.35862 .51205 m .38195 .52175 L .38412 .52979 L p F P
0 g
s
.805 .721 .772 r
.88053 .4708 m .85725 .48744 L .84908 .46963 L p F P
0 g
s
.805 .721 .772 r
.84908 .46963 m .87249 .4555 L .88053 .4708 L p F P
0 g
s
.583 .564 .799 r
.34201 .4612 m .3619 .46117 L .36422 .46609 L p F P
0 g
s
.575 .595 .836 r
.3619 .46117 m .34201 .4612 L .34004 .45775 L p F P
0 g
s
.613 .503 .704 r
.38629 .53794 m .3622 .52572 L .36041 .51883 L p F P
0 g
s
.613 .503 .704 r
.36041 .51883 m .38412 .52979 L .38629 .53794 L p F P
0 g
s
.615 .503 .702 r
.38846 .5462 m .36398 .5327 L .3622 .52572 L p F P
0 g
s
.615 .503 .702 r
.3622 .52572 m .38629 .53794 L .38846 .5462 L p F P
0 g
s
.575 .595 .836 r
.34004 .45775 m .35955 .45701 L .3619 .46117 L p F P
0 g
s
.562 .642 .887 r
.35955 .45701 m .34004 .45775 L .33803 .45501 L p F P
0 g
s
.335 0 0 r
.28837 .45687 m .303 .45853 L .30492 .45673 L p F P
0 g
s
.34 0 .005 r
.303 .45853 m .28837 .45687 L .28691 .4584 L p F P
0 g
s
.114 0 0 r
.32952 .4514 m .31232 .45232 L .31051 .4529 L p F P
0 g
s
.562 .642 .887 r
.33803 .45501 m .35714 .4537 L .35955 .45701 L p F P
0 g
s
.534 .705 .95 r
.35714 .4537 m .33803 .45501 L .33597 .45302 L p F P
0 g
s
.793 .663 .72 r
.86566 .50806 m .84192 .52395 L .83367 .5031 L p F P
0 g
s
.793 .663 .72 r
.83367 .5031 m .85725 .48744 L .86566 .50806 L p F P
0 g
s
.413 0 0 r
.92042 .44049 m .89604 .44403 L .88914 .4408 L p F P
0 g
s
.527 .883 .982 r
.89604 .44403 m .87249 .4555 L .8649 .44522 L p F P
0 g
s
.527 .883 .982 r
.8649 .44522 m .88914 .4408 L .89604 .44403 L p F P
0 g
s
.628 .11 0 r
.94624 .44832 m .92042 .44049 L .91431 .44426 L p F P
0 g
s
.413 0 0 r
.88914 .4408 m .91431 .44426 L .92042 .44049 L p F P
0 g
s
.34 0 .005 r
.28691 .4584 m .30107 .46052 L .303 .45853 L p F P
0 g
s
.342 0 .028 r
.30107 .46052 m .28691 .4584 L .28543 .46005 L p F P
0 g
s
.114 0 0 r
.31051 .4529 m .32728 .4521 L .32952 .4514 L p F P
0 g
s
.199 0 0 r
.32728 .4521 m .31051 .4529 L .30867 .45387 L p F P
0 g
s
.534 .705 .95 r
.33597 .45302 m .35469 .4513 L .35714 .4537 L p F P
0 g
s
.464 .771 .997 r
.35469 .4513 m .33597 .45302 L .33387 .45178 L p F P
0 g
s
.609 .522 .731 r
.39524 .4951 m .3732 .49137 L .37098 .48441 L p F P
0 g
s
.609 .522 .731 r
.37098 .48441 m .39264 .48704 L .39524 .4951 L p F P
0 g
s
.607 .528 .74 r
.39264 .48704 m .37098 .48441 L .36875 .47781 L p F P
0 g
s
.612 .518 .724 r
.39782 .5035 m .3754 .49863 L .3732 .49137 L p F P
0 g
s
.612 .518 .724 r
.3732 .49137 m .39524 .4951 L .39782 .5035 L p F P
0 g
s
.607 .528 .74 r
.36875 .47781 m .39002 .47939 L .39264 .48704 L p F P
0 g
s
.604 .538 .753 r
.39002 .47939 m .36875 .47781 L .3665 .47168 L p F P
0 g
s
.614 .515 .718 r
.4004 .51217 m .37759 .50615 L .3754 .49863 L p F P
0 g
s
.614 .515 .718 r
.3754 .49863 m .39782 .5035 L .4004 .51217 L p F P
0 g
s
.616 .513 .714 r
.40297 .52106 m .37977 .51386 L .37759 .50615 L p F P
0 g
s
.616 .513 .714 r
.37759 .50615 m .4004 .51217 L .40297 .52106 L p F P
0 g
s
.604 .538 .753 r
.3665 .47168 m .38739 .47226 L .39002 .47939 L p F P
0 g
s
.602 .552 .771 r
.38739 .47226 m .3665 .47168 L .36422 .46609 L p F P
0 g
s
.619 .512 .711 r
.40553 .53014 m .38195 .52175 L .37977 .51386 L p F P
0 g
s
.619 .512 .711 r
.37977 .51386 m .40297 .52106 L .40553 .53014 L p F P
0 g
s
.602 .552 .771 r
.36422 .46609 m .38473 .46575 L .38739 .47226 L p F P
0 g
s
.599 .573 .796 r
.38473 .46575 m .36422 .46609 L .3619 .46117 L p F P
0 g
s
.342 0 .028 r
.28543 .46005 m .29912 .46267 L .30107 .46052 L p F P
0 g
s
.342 0 .044 r
.29912 .46267 m .28543 .46005 L .28395 .46181 L p F P
0 g
s
.621 .511 .708 r
.40809 .53938 m .38412 .52979 L .38195 .52175 L p F P
0 g
s
.621 .511 .708 r
.38195 .52175 m .40553 .53014 L .40809 .53938 L p F P
0 g
s
.464 .771 .997 r
.33387 .45178 m .35218 .44981 L .35469 .4513 L p F P
0 g
s
.793 .685 .745 r
.85725 .48744 m .83367 .5031 L .82554 .48406 L p F P
0 g
s
.793 .685 .745 r
.82554 .48406 m .84908 .46963 L .85725 .48744 L p F P
0 g
s
.779 .791 .863 r
.87249 .4555 m .84908 .46963 L .84116 .45496 L p F P
0 g
s
.779 .791 .863 r
.84116 .45496 m .8649 .44522 L .87249 .4555 L p F P
0 g
s
.199 0 0 r
.30867 .45387 m .325 .45328 L .32728 .4521 L p F P
0 g
s
.246 0 0 r
.325 .45328 m .30867 .45387 L .30681 .45516 L p F P
0 g
s
.623 .511 .705 r
.41064 .54876 m .38629 .53794 L .38412 .52979 L p F P
0 g
s
.623 .511 .705 r
.38412 .52979 m .40809 .53938 L .41064 .54876 L p F P
0 g
s
.599 .573 .796 r
.3619 .46117 m .38203 .45999 L .38473 .46575 L p F P
0 g
s
.595 .605 .832 r
.38203 .45999 m .3619 .46117 L .35955 .45701 L p F P
0 g
s
.625 .511 .703 r
.4132 .55826 m .38846 .5462 L .38629 .53794 L p F P
0 g
s
.625 .511 .703 r
.38629 .53794 m .41064 .54876 L .4132 .55826 L p F P
0 g
s
.595 .605 .832 r
.35955 .45701 m .37928 .45512 L .38203 .45999 L p F P
0 g
s
.588 .653 .881 r
.37928 .45512 m .35955 .45701 L .35714 .4537 L p F P
0 g
s
.628 .11 0 r
.91431 .44426 m .94052 .45496 L .94624 .44832 L p F P
0 g
s
.342 0 .044 r
.28395 .46181 m .29716 .46495 L .29912 .46267 L p F P
0 g
s
.34 0 .056 r
.29716 .46495 m .28395 .46181 L .28245 .46365 L p F P
0 g
s
.783 .652 .718 r
.84192 .52395 m .81784 .53841 L .80978 .51754 L p F P
0 g
s
.783 .652 .718 r
.80978 .51754 m .83367 .5031 L .84192 .52395 L p F P
0 g
s
.246 0 0 r
.30681 .45516 m .32269 .45486 L .325 .45328 L p F P
0 g
s
.271 0 0 r
.32269 .45486 m .30681 .45516 L .30492 .45673 L p F P
0 g
s
.588 .653 .881 r
.35714 .4537 m .37649 .45124 L .37928 .45512 L p F P
0 g
s
.569 .719 .943 r
.37649 .45124 m .35714 .4537 L .35469 .4513 L p F P
0 g
s
.622 .526 .724 r
.42046 .50714 m .39782 .5035 L .39524 .4951 L p F P
0 g
s
.622 .526 .724 r
.39524 .4951 m .41749 .49764 L .42046 .50714 L p F P
0 g
s
.62 .53 .731 r
.41749 .49764 m .39524 .4951 L .39264 .48704 L p F P
0 g
s
.34 0 .056 r
.28245 .46365 m .29517 .46734 L .29716 .46495 L p F P
0 g
s
.338 0 .065 r
.29517 .46734 m .28245 .46365 L .28095 .46557 L p F P
0 g
s
.62 .53 .731 r
.39264 .48704 m .41451 .48851 L .41749 .49764 L p F P
0 g
s
.618 .536 .74 r
.41451 .48851 m .39264 .48704 L .39002 .47939 L p F P
0 g
s
.624 .523 .719 r
.42342 .51693 m .4004 .51217 L .39782 .5035 L p F P
0 g
s
.624 .523 .719 r
.39782 .5035 m .42046 .50714 L .42342 .51693 L p F P
0 g
s
.618 .536 .74 r
.39002 .47939 m .41151 .47982 L .41451 .48851 L p F P
0 g
s
.617 .546 .752 r
.41151 .47982 m .39002 .47939 L .38739 .47226 L p F P
0 g
s
.626 .521 .715 r
.42638 .52696 m .40297 .52106 L .4004 .51217 L p F P
0 g
s
.626 .521 .715 r
.4004 .51217 m .42342 .51693 L .42638 .52696 L p F P
0 g
s
.786 .716 .787 r
.84908 .46963 m .82554 .48406 L .81756 .467 L p F P
0 g
s
.786 .716 .787 r
.81756 .467 m .84116 .45496 L .84908 .46963 L p F P
0 g
s
.617 .546 .752 r
.38739 .47226 m .40849 .47169 L .41151 .47982 L p F P
0 g
s
.615 .56 .769 r
.40849 .47169 m .38739 .47226 L .38473 .46575 L p F P
0 g
s
.628 .52 .712 r
.42933 .53719 m .40553 .53014 L .40297 .52106 L p F P
0 g
s
.628 .52 .712 r
.40297 .52106 m .42638 .52696 L .42933 .53719 L p F P
0 g
s
.569 .719 .943 r
.35469 .4513 m .37365 .44842 L .37649 .45124 L p F P
0 g
s
.516 .792 .995 r
.37365 .44842 m .35469 .4513 L .35218 .44981 L p F P
0 g
s
.63 .519 .709 r
.43228 .54759 m .40809 .53938 L .40553 .53014 L p F P
0 g
s
.63 .519 .709 r
.40553 .53014 m .42933 .53719 L .43228 .54759 L p F P
0 g
s
.271 0 0 r
.30492 .45673 m .32035 .45677 L .32269 .45486 L p F P
0 g
s
.286 0 0 r
.32035 .45677 m .30492 .45673 L .303 .45853 L p F P
0 g
s
.782 .665 .734 r
.83367 .5031 m .80978 .51754 L .8018 .49792 L p F P
0 g
s
.782 .665 .734 r
.8018 .49792 m .82554 .48406 L .83367 .5031 L p F P
0 g
s
.615 .56 .769 r
.38473 .46575 m .40544 .46425 L .40849 .47169 L p F P
0 g
s
.615 .581 .793 r
.40544 .46425 m .38473 .46575 L .38203 .45999 L p F P
0 g
s
.632 .519 .707 r
.43523 .55814 m .41064 .54876 L .40809 .53938 L p F P
0 g
s
.632 .519 .707 r
.40809 .53938 m .43228 .54759 L .43523 .55814 L p F P
0 g
s
.635 .519 .705 r
.43817 .56882 m .4132 .55826 L .41064 .54876 L p F P
0 g
s
.635 .519 .705 r
.41064 .54876 m .43523 .55814 L .43817 .56882 L p F P
0 g
s
.338 0 .065 r
.28095 .46557 m .29318 .46984 L .29517 .46734 L p F P
0 g
s
.335 0 .071 r
.29318 .46984 m .28095 .46557 L .27943 .46755 L p F P
0 g
s
.615 .581 .793 r
.38203 .45999 m .40236 .45766 L .40544 .46425 L p F P
0 g
s
.614 .614 .827 r
.40236 .45766 m .38203 .45999 L .37928 .45512 L p F P
0 g
s
.03 0 0 r
.32728 .4521 m .34434 .45012 L .347 .44931 L p F P
0 g
s
.126 0 0 r
.34434 .45012 m .32728 .4521 L .325 .45328 L p F P
0 g
s
.516 .792 .995 r
.35218 .44981 m .37074 .44667 L .37365 .44842 L p F P
0 g
s
.396 .819 .968 r
.37074 .44667 m .35218 .44981 L .34961 .44917 L p F P
0 g
s
.614 .614 .827 r
.37928 .45512 m .39924 .45206 L .40236 .45766 L p F P
0 g
s
.611 .662 .875 r
.39924 .45206 m .37928 .45512 L .37649 .45124 L p F P
0 g
s
.773 .642 .717 r
.81784 .53841 m .79346 .5514 L .78563 .53067 L p F P
0 g
s
.773 .642 .717 r
.78563 .53067 m .80978 .51754 L .81784 .53841 L p F P
0 g
s
.286 0 0 r
.303 .45853 m .31798 .45896 L .32035 .45677 L p F P
0 g
s
.293 0 0 r
.31798 .45896 m .303 .45853 L .30107 .46052 L p F P
0 g
s
0 .561 .727 r
.88914 .4408 m .8649 .44522 L .85762 .43887 L p F P
0 g
s
.653 .85 .975 r
.8649 .44522 m .84116 .45496 L .83348 .44342 L p F P
0 g
s
.653 .85 .975 r
.83348 .44342 m .85762 .43887 L .8649 .44522 L p F P
0 g
s
0 .561 .727 r
.85762 .43887 m .88242 .44023 L .88914 .4408 L p F P
0 g
s
.504 0 0 r
.91431 .44426 m .88914 .4408 L .88242 .44023 L p F P
0 g
s
.335 0 .071 r
.27943 .46755 m .29117 .47242 L .29318 .46984 L p F P
0 g
s
.778 .681 .757 r
.82554 .48406 m .8018 .49792 L .7939 .47959 L p F P
0 g
s
.778 .681 .757 r
.7939 .47959 m .81756 .467 L .82554 .48406 L p F P
0 g
s
.632 .534 .725 r
.44329 .50955 m .42046 .50714 L .41749 .49764 L p F P
0 g
s
.632 .534 .725 r
.41749 .49764 m .43993 .49898 L .44329 .50955 L p F P
0 g
s
.63 .538 .731 r
.43993 .49898 m .41749 .49764 L .41451 .48851 L p F P
0 g
s
.63 .538 .731 r
.41451 .48851 m .43656 .4888 L .43993 .49898 L p F P
0 g
s
.629 .544 .74 r
.43656 .4888 m .41451 .48851 L .41151 .47982 L p F P
0 g
s
.634 .531 .72 r
.44664 .52042 m .42342 .51693 L .42046 .50714 L p F P
0 g
s
.634 .531 .72 r
.42046 .50714 m .44329 .50955 L .44664 .52042 L p F P
0 g
s
.636 .529 .716 r
.44999 .53154 m .42638 .52696 L .42342 .51693 L p F P
0 g
s
.636 .529 .716 r
.42342 .51693 m .44664 .52042 L .44999 .53154 L p F P
0 g
s
.629 .544 .74 r
.41151 .47982 m .43318 .47909 L .43656 .4888 L p F P
0 g
s
.628 .553 .751 r
.43318 .47909 m .41151 .47982 L .40849 .47169 L p F P
0 g
s
.611 .662 .875 r
.37649 .45124 m .39607 .44761 L .39924 .45206 L p F P
0 g
s
.6 .73 .936 r
.39607 .44761 m .37649 .45124 L .37365 .44842 L p F P
0 g
s
.638 .528 .713 r
.45333 .54288 m .42933 .53719 L .42638 .52696 L p F P
0 g
s
.638 .528 .713 r
.42638 .52696 m .44999 .53154 L .45333 .54288 L p F P
0 g
s
.628 .553 .751 r
.40849 .47169 m .42978 .46998 L .43318 .47909 L p F P
0 g
s
.628 .567 .767 r
.42978 .46998 m .40849 .47169 L .40544 .46425 L p F P
0 g
s
.396 .819 .968 r
.34961 .44917 m .36777 .44591 L .37074 .44667 L p F P
0 g
s
.64 .527 .71 r
.45667 .55439 m .43228 .54759 L .42933 .53719 L p F P
0 g
s
.64 .527 .71 r
.42933 .53719 m .45333 .54288 L .45667 .55439 L p F P
0 g
s
.772 .65 .728 r
.80978 .51754 m .78563 .53067 L .77784 .51082 L p F P
0 g
s
.772 .65 .728 r
.77784 .51082 m .8018 .49792 L .80978 .51754 L p F P
0 g
s
.126 0 0 r
.325 .45328 m .34163 .4515 L .34434 .45012 L p F P
0 g
s
.182 0 0 r
.34163 .4515 m .325 .45328 L .32269 .45486 L p F P
0 g
s
.758 .756 .85 r
.84116 .45496 m .81756 .467 L .80972 .45202 L p F P
0 g
s
.758 .756 .85 r
.80972 .45202 m .83348 .44342 L .84116 .45496 L p F P
0 g
s
.642 .527 .708 r
.46001 .56606 m .43523 .55814 L .43228 .54759 L p F P
0 g
s
.642 .527 .708 r
.43228 .54759 m .45667 .55439 L .46001 .56606 L p F P
0 g
s
.293 0 0 r
.30107 .46052 m .31559 .46137 L .31798 .45896 L p F P
0 g
s
.296 0 0 r
.31559 .46137 m .30107 .46052 L .29912 .46267 L p F P
0 g
s
.628 .567 .767 r
.40544 .46425 m .42635 .46161 L .42978 .46998 L p F P
0 g
s
.629 .589 .79 r
.42635 .46161 m .40544 .46425 L .40236 .45766 L p F P
0 g
s
.644 .527 .706 r
.46335 .57788 m .43817 .56882 L .43523 .55814 L p F P
0 g
s
.644 .527 .706 r
.43523 .55814 m .46001 .56606 L .46335 .57788 L p F P
0 g
s
.6 .73 .936 r
.37365 .44842 m .39283 .44437 L .39607 .44761 L p F P
0 g
s
.562 .809 .991 r
.39283 .44437 m .37365 .44842 L .37074 .44667 L p F P
0 g
s
.629 .589 .79 r
.40236 .45766 m .42289 .45417 L .42635 .46161 L p F P
0 g
s
.631 .621 .822 r
.42289 .45417 m .40236 .45766 L .39924 .45206 L p F P
0 g
s
.629 .095 0 r
.94052 .45496 m .91431 .44426 L .90803 .44772 L p F P
0 g
s
.504 0 0 r
.88242 .44023 m .90803 .44772 L .91431 .44426 L p F P
0 g
s
.764 .633 .716 r
.79346 .5514 m .76879 .5629 L .76121 .5424 L p F P
0 g
s
.764 .633 .716 r
.76121 .5424 m .78563 .53067 L .79346 .5514 L p F P
0 g
s
.768 .659 .742 r
.8018 .49792 m .77784 .51082 L .7701 .49186 L p F P
0 g
s
.768 .659 .742 r
.7701 .49186 m .7939 .47959 L .8018 .49792 L p F P
0 g
s
.182 0 0 r
.32269 .45486 m .33889 .45334 L .34163 .4515 L p F P
0 g
s
.213 0 0 r
.33889 .45334 m .32269 .45486 L .32035 .45677 L p F P
0 g
s
.631 .621 .822 r
.39924 .45206 m .41939 .44785 L .42289 .45417 L p F P
0 g
s
.632 .67 .868 r
.41939 .44785 m .39924 .45206 L .39607 .44761 L p F P
0 g
s
.766 .7 .789 r
.81756 .467 m .7939 .47959 L .78607 .4626 L p F P
0 g
s
.766 .7 .789 r
.78607 .4626 m .80972 .45202 L .81756 .467 L p F P
0 g
s
.296 0 0 r
.29912 .46267 m .31317 .46398 L .31559 .46137 L p F P
0 g
s
.297 0 .003 r
.31317 .46398 m .29912 .46267 L .29716 .46495 L p F P
0 g
s
.642 .541 .725 r
.46628 .51071 m .44329 .50955 L .43993 .49898 L p F P
0 g
s
.642 .541 .725 r
.43993 .49898 m .46254 .49912 L .46628 .51071 L p F P
0 g
s
.64 .545 .731 r
.46254 .49912 m .43993 .49898 L .43656 .4888 L p F P
0 g
s
.643 .539 .721 r
.47003 .52262 m .44664 .52042 L .44329 .50955 L p F P
0 g
s
.643 .539 .721 r
.44329 .50955 m .46628 .51071 L .47003 .52262 L p F P
0 g
s
.64 .545 .731 r
.43656 .4888 m .45879 .48792 L .46254 .49912 L p F P
0 g
s
.64 .551 .739 r
.45879 .48792 m .43656 .4888 L .43318 .47909 L p F P
0 g
s
.645 .537 .717 r
.47376 .53479 m .44999 .53154 L .44664 .52042 L p F P
0 g
s
.645 .537 .717 r
.44664 .52042 m .47003 .52262 L .47376 .53479 L p F P
0 g
s
.647 .536 .714 r
.4775 .54718 m .45333 .54288 L .44999 .53154 L p F P
0 g
s
.647 .536 .714 r
.44999 .53154 m .47376 .53479 L .4775 .54718 L p F P
0 g
s
.64 .551 .739 r
.43318 .47909 m .45502 .47721 L .45879 .48792 L p F P
0 g
s
.639 .561 .75 r
.45502 .47721 m .43318 .47909 L .42978 .46998 L p F P
0 g
s
.649 .535 .711 r
.48123 .55976 m .45667 .55439 L .45333 .54288 L p F P
0 g
s
.649 .535 .711 r
.45333 .54288 m .4775 .54718 L .48123 .55976 L p F P
0 g
s
.562 .809 .991 r
.37074 .44667 m .38954 .44234 L .39283 .44437 L p F P
0 g
s
.464 .851 .98 r
.38954 .44234 m .37074 .44667 L .36777 .44591 L p F P
0 g
s
.762 .638 .724 r
.78563 .53067 m .76121 .5424 L .75367 .52256 L p F P
0 g
s
.762 .638 .724 r
.75367 .52256 m .77784 .51082 L .78563 .53067 L p F P
0 g
s
.639 .561 .75 r
.42978 .46998 m .45124 .46712 L .45502 .47721 L p F P
0 g
s
.64 .574 .765 r
.45124 .46712 m .42978 .46998 L .42635 .46161 L p F P
0 g
s
.651 .535 .709 r
.48497 .5725 m .46001 .56606 L .45667 .55439 L p F P
0 g
s
.651 .535 .709 r
.45667 .55439 m .48123 .55976 L .48497 .5725 L p F P
0 g
s
.653 .535 .707 r
.4887 .58539 m .46335 .57788 L .46001 .56606 L p F P
0 g
s
.653 .535 .707 r
.46001 .56606 m .48497 .5725 L .4887 .58539 L p F P
0 g
s
.632 .67 .868 r
.39607 .44761 m .41584 .4428 L .41939 .44785 L p F P
0 g
s
.628 .74 .927 r
.41584 .4428 m .39607 .44761 L .39283 .44437 L p F P
0 g
s
.64 .574 .765 r
.42635 .46161 m .44744 .45782 L .45124 .46712 L p F P
0 g
s
.643 .595 .786 r
.44744 .45782 m .42635 .46161 L .42289 .45417 L p F P
0 g
s
.049 0 0 r
.36168 .44697 m .34434 .45012 L .34163 .4515 L p F P
0 g
s
.297 0 .003 r
.29716 .46495 m .31073 .46676 L .31317 .46398 L p F P
0 g
s
.296 0 .015 r
.31073 .46676 m .29716 .46495 L .29517 .46734 L p F P
0 g
s
.213 0 0 r
.32035 .45677 m .33611 .45557 L .33889 .45334 L p F P
0 g
s
.23 0 0 r
.33611 .45557 m .32035 .45677 L .31798 .45896 L p F P
0 g
s
.754 .624 .715 r
.76879 .5629 m .74388 .57288 L .73658 .55271 L p F P
0 g
s
.754 .624 .715 r
.73658 .55271 m .76121 .5424 L .76879 .5629 L p F P
0 g
s
.761 .669 .76 r
.7939 .47959 m .7701 .49186 L .7624 .47377 L p F P
0 g
s
.761 .669 .76 r
.7624 .47377 m .78607 .4626 L .7939 .47959 L p F P
0 g
s
.643 .595 .786 r
.42289 .45417 m .4436 .44953 L .44744 .45782 L p F P
0 g
s
.647 .628 .817 r
.4436 .44953 m .42289 .45417 L .41939 .44785 L p F P
0 g
s
.758 .644 .734 r
.77784 .51082 m .75367 .52256 L .74614 .50336 L p F P
0 g
s
.758 .644 .734 r
.74614 .50336 m .7701 .49186 L .77784 .51082 L p F P
0 g
s
.653 .547 .722 r
.49355 .52354 m .47003 .52262 L .46628 .51071 L p F P
0 g
s
.653 .547 .722 r
.46628 .51071 m .48943 .51064 L .49355 .52354 L p F P
0 g
s
.651 .549 .726 r
.48943 .51064 m .46628 .51071 L .46254 .49912 L p F P
0 g
s
.651 .549 .726 r
.46254 .49912 m .48529 .49806 L .48943 .51064 L p F P
0 g
s
.65 .553 .731 r
.48529 .49806 m .46254 .49912 L .45879 .48792 L p F P
0 g
s
.654 .545 .718 r
.49768 .53671 m .47376 .53479 L .47003 .52262 L p F P
0 g
s
.654 .545 .718 r
.47003 .52262 m .49355 .52354 L .49768 .53671 L p F P
0 g
s
.65 .553 .731 r
.45879 .48792 m .48116 .48587 L .48529 .49806 L p F P
0 g
s
.65 .559 .739 r
.48116 .48587 m .45879 .48792 L .45502 .47721 L p F P
0 g
s
.656 .544 .715 r
.50181 .55009 m .4775 .54718 L .47376 .53479 L p F P
0 g
s
.656 .544 .715 r
.47376 .53479 m .49768 .53671 L .50181 .55009 L p F P
0 g
s
.368 .777 .982 r
.85762 .43887 m .83348 .44342 L .82597 .43451 L p F P
0 g
s
.686 .789 .928 r
.83348 .44342 m .80972 .45202 L .80199 .4391 L p F P
0 g
s
.686 .789 .928 r
.80199 .4391 m .82597 .43451 L .83348 .44342 L p F P
0 g
s
.628 .74 .927 r
.39283 .44437 m .41223 .43912 L .41584 .4428 L p F P
0 g
s
.602 .822 .984 r
.41223 .43912 m .39283 .44437 L .38954 .44234 L p F P
0 g
s
.658 .543 .713 r
.50593 .56367 m .48123 .55976 L .4775 .54718 L p F P
0 g
s
.658 .543 .713 r
.4775 .54718 m .50181 .55009 L .50593 .56367 L p F P
0 g
s
.65 .559 .739 r
.45502 .47721 m .47701 .47417 L .48116 .48587 L p F P
0 g
s
.65 .567 .748 r
.47701 .47417 m .45502 .47721 L .45124 .46712 L p F P
0 g
s
.752 .628 .722 r
.76121 .5424 m .73658 .55271 L .7293 .53305 L p F P
0 g
s
.752 .628 .722 r
.7293 .53305 m .75367 .52256 L .76121 .5424 L p F P
0 g
s
.661 .543 .71 r
.51006 .57742 m .48497 .5725 L .48123 .55976 L p F P
0 g
s
.661 .543 .71 r
.48123 .55976 m .50593 .56367 L .51006 .57742 L p F P
0 g
s
.261 0 0 r
.88242 .44023 m .85762 .43887 L .85046 .4347 L p F P
0 g
s
.368 .777 .982 r
.82597 .43451 m .85046 .4347 L .85762 .43887 L p F P
0 g
s
.647 .628 .817 r
.41939 .44785 m .43973 .44245 L .4436 .44953 L p F P
0 g
s
.652 .677 .861 r
.43973 .44245 m .41939 .44785 L .41584 .4428 L p F P
0 g
s
.629 .095 0 r
.90803 .44772 m .93446 .4602 L .94052 .45496 L p F P
0 g
s
.65 .567 .748 r
.45124 .46712 m .47285 .46312 L .47701 .47417 L p F P
0 g
s
.652 .581 .762 r
.47285 .46312 m .45124 .46712 L .44744 .45782 L p F P
0 g
s
.742 .72 .832 r
.80972 .45202 m .78607 .4626 L .7783 .44698 L p F P
0 g
s
.742 .72 .832 r
.7783 .44698 m .80199 .4391 L .80972 .45202 L p F P
0 g
s
.663 .543 .708 r
.51419 .59133 m .4887 .58539 L .48497 .5725 L p F P
0 g
s
.663 .543 .708 r
.48497 .5725 m .51006 .57742 L .51419 .59133 L p F P
0 g
s
.296 0 .015 r
.29517 .46734 m .30827 .46967 L .31073 .46676 L p F P
0 g
s
.293 0 .024 r
.30827 .46967 m .29517 .46734 L .29318 .46984 L p F P
0 g
s
.753 .649 .746 r
.7701 .49186 m .74614 .50336 L .73864 .48475 L p F P
0 g
s
.753 .649 .746 r
.73864 .48475 m .7624 .47377 L .7701 .49186 L p F P
0 g
s
.049 0 0 r
.34163 .4515 m .35856 .44852 L .36168 .44697 L p F P
0 g
s
.111 0 0 r
.35856 .44852 m .34163 .4515 L .33889 .45334 L p F P
0 g
s
.23 0 0 r
.31798 .45896 m .33329 .45812 L .33611 .45557 L p F P
0 g
s
.24 0 0 r
.33329 .45812 m .31798 .45896 L .31559 .46137 L p F P
0 g
s
.652 .581 .762 r
.44744 .45782 m .46867 .45289 L .47285 .46312 L p F P
0 g
s
.655 .601 .782 r
.46867 .45289 m .44744 .45782 L .4436 .44953 L p F P
0 g
s
.745 .616 .715 r
.74388 .57288 m .71875 .58131 L .71175 .56155 L p F P
0 g
s
.745 .616 .715 r
.71175 .56155 m .73658 .55271 L .74388 .57288 L p F P
0 g
s
.749 .631 .729 r
.75367 .52256 m .7293 .53305 L .72203 .51385 L p F P
0 g
s
.749 .631 .729 r
.72203 .51385 m .74614 .50336 L .75367 .52256 L p F P
0 g
s
.749 .679 .784 r
.78607 .4626 m .7624 .47377 L .75472 .45657 L p F P
0 g
s
.749 .679 .784 r
.75472 .45657 m .7783 .44698 L .78607 .4626 L p F P
0 g
s
.652 .677 .861 r
.41584 .4428 m .43581 .4368 L .43973 .44245 L p F P
0 g
s
.654 .747 .919 r
.43581 .4368 m .41584 .4428 L .41223 .43912 L p F P
0 g
s
.662 .554 .722 r
.5172 .52317 m .49355 .52354 L .48943 .51064 L p F P
0 g
s
.662 .554 .722 r
.48943 .51064 m .51269 .50933 L .5172 .52317 L p F P
0 g
s
.66 .557 .726 r
.51269 .50933 m .48943 .51064 L .48529 .49806 L p F P
0 g
s
.664 .553 .719 r
.52171 .53728 m .49768 .53671 L .49355 .52354 L p F P
0 g
s
.664 .553 .719 r
.49355 .52354 m .5172 .52317 L .52171 .53728 L p F P
0 g
s
.602 .822 .984 r
.38954 .44234 m .40856 .43683 L .41223 .43912 L p F P
0 g
s
.523 .877 .985 r
.40856 .43683 m .38954 .44234 L .38618 .44147 L p F P
0 g
s
.666 .552 .716 r
.52623 .5516 m .50181 .55009 L .49768 .53671 L p F P
0 g
s
.666 .552 .716 r
.49768 .53671 m .52171 .53728 L .52623 .5516 L p F P
0 g
s
.66 .557 .726 r
.48529 .49806 m .50817 .4958 L .51269 .50933 L p F P
0 g
s
.659 .56 .732 r
.50817 .4958 m .48529 .49806 L .48116 .48587 L p F P
0 g
s
.668 .551 .714 r
.53074 .56613 m .50593 .56367 L .50181 .55009 L p F P
0 g
s
.668 .551 .714 r
.50181 .55009 m .52623 .5516 L .53074 .56613 L p F P
0 g
s
.655 .601 .782 r
.4436 .44953 m .46446 .44373 L .46867 .45289 L p F P
0 g
s
.661 .633 .812 r
.46446 .44373 m .4436 .44953 L .43973 .44245 L p F P
0 g
s
.743 .618 .72 r
.73658 .55271 m .71175 .56155 L .70476 .54219 L p F P
0 g
s
.743 .618 .72 r
.70476 .54219 m .7293 .53305 L .73658 .55271 L p F P
0 g
s
.659 .56 .732 r
.48116 .48587 m .50365 .48266 L .50817 .4958 L p F P
0 g
s
.659 .565 .738 r
.50365 .48266 m .48116 .48587 L .47701 .47417 L p F P
0 g
s
.67 .551 .711 r
.53526 .58083 m .51006 .57742 L .50593 .56367 L p F P
0 g
s
.67 .551 .711 r
.50593 .56367 m .53074 .56613 L .53526 .58083 L p F P
0 g
s
.528 0 0 r
.90803 .44772 m .88242 .44023 L .87562 .44014 L p F P
0 g
s
.261 0 0 r
.85046 .4347 m .87562 .44014 L .88242 .44023 L p F P
0 g
s
.659 .565 .738 r
.47701 .47417 m .49912 .47001 L .50365 .48266 L p F P
0 g
s
.66 .574 .747 r
.49912 .47001 m .47701 .47417 L .47285 .46312 L p F P
0 g
s
.672 .551 .709 r
.53977 .59569 m .51419 .59133 L .51006 .57742 L p F P
0 g
s
.672 .551 .709 r
.51006 .57742 m .53526 .58083 L .53977 .59569 L p F P
0 g
s
.293 0 .024 r
.29318 .46984 m .30579 .4727 L .30827 .46967 L p F P
0 g
s
.29 0 .031 r
.30579 .4727 m .29318 .46984 L .29117 .47242 L p F P
0 g
s
.745 .634 .737 r
.74614 .50336 m .72203 .51385 L .71477 .4951 L p F P
0 g
s
.745 .634 .737 r
.71477 .4951 m .73864 .48475 L .74614 .50336 L p F P
0 g
s
.66 .574 .747 r
.47285 .46312 m .49459 .458 L .49912 .47001 L p F P
0 g
s
.662 .586 .76 r
.49459 .458 m .47285 .46312 L .46867 .45289 L p F P
0 g
s
.736 .607 .714 r
.71875 .58131 m .69345 .58817 L .68676 .5689 L p F P
0 g
s
.736 .607 .714 r
.68676 .5689 m .71175 .56155 L .71875 .58131 L p F P
0 g
s
.745 .654 .759 r
.7624 .47377 m .73864 .48475 L .73115 .46673 L p F P
0 g
s
.745 .654 .759 r
.73115 .46673 m .75472 .45657 L .7624 .47377 L p F P
0 g
s
.74 .62 .726 r
.7293 .53305 m .70476 .54219 L .69778 .5232 L p F P
0 g
s
.74 .62 .726 r
.69778 .5232 m .72203 .51385 L .7293 .53305 L p F P
0 g
s
.661 .633 .812 r
.43973 .44245 m .46022 .43588 L .46446 .44373 L p F P
0 g
s
.669 .683 .854 r
.46022 .43588 m .43973 .44245 L .43581 .4368 L p F P
0 g
s
.24 0 0 r
.31559 .46137 m .33045 .46093 L .33329 .45812 L p F P
0 g
s
.245 0 0 r
.33045 .46093 m .31559 .46137 L .31317 .46398 L p F P
0 g
s
.111 0 0 r
.33889 .45334 m .35539 .4506 L .35856 .44852 L p F P
0 g
s
.148 0 0 r
.35539 .4506 m .33889 .45334 L .33611 .45557 L p F P
0 g
s
.654 .747 .919 r
.41223 .43912 m .43182 .43269 L .43581 .4368 L p F P
0 g
s
.638 .833 .976 r
.43182 .43269 m .41223 .43912 L .40856 .43683 L p F P
0 g
s
.662 .586 .76 r
.46867 .45289 m .49003 .44684 L .49459 .458 L p F P
0 g
s
.667 .606 .778 r
.49003 .44684 m .46867 .45289 L .46446 .44373 L p F P
0 g
s
.673 .561 .72 r
.54583 .5365 m .52171 .53728 L .5172 .52317 L p F P
0 g
s
.673 .561 .72 r
.5172 .52317 m .54094 .52152 L .54583 .5365 L p F P
0 g
s
.671 .562 .723 r
.54094 .52152 m .5172 .52317 L .51269 .50933 L p F P
0 g
s
.675 .56 .717 r
.55073 .5517 m .52623 .5516 L .52171 .53728 L p F P
0 g
s
.675 .56 .717 r
.52171 .53728 m .54583 .5365 L .55073 .5517 L p F P
0 g
s
.734 .609 .719 r
.71175 .56155 m .68676 .5689 L .68008 .54995 L p F P
0 g
s
.734 .609 .719 r
.68008 .54995 m .70476 .54219 L .71175 .56155 L p F P
0 g
s
.677 .559 .715 r
.55562 .56711 m .53074 .56613 L .52623 .5516 L p F P
0 g
s
.677 .559 .715 r
.52623 .5516 m .55073 .5517 L .55562 .56711 L p F P
0 g
s
.671 .562 .723 r
.51269 .50933 m .53604 .5068 L .54094 .52152 L p F P
0 g
s
.669 .564 .727 r
.53604 .5068 m .51269 .50933 L .50817 .4958 L p F P
0 g
s
.679 .559 .713 r
.56052 .5827 m .53526 .58083 L .53074 .56613 L p F P
0 g
s
.679 .559 .713 r
.53074 .56613 m .55562 .56711 L .56052 .5827 L p F P
0 g
s
.669 .564 .727 r
.50817 .4958 m .53114 .49237 L .53604 .5068 L p F P
0 g
s
.668 .567 .732 r
.53114 .49237 m .50817 .4958 L .50365 .48266 L p F P
0 g
s
.681 .559 .71 r
.56543 .59846 m .53977 .59569 L .53526 .58083 L p F P
0 g
s
.681 .559 .71 r
.53526 .58083 m .56052 .5827 L .56543 .59846 L p F P
0 g
s
.668 .567 .732 r
.50365 .48266 m .52624 .47832 L .53114 .49237 L p F P
0 g
s
.668 .572 .738 r
.52624 .47832 m .50365 .48266 L .49912 .47001 L p F P
0 g
s
.523 .877 .985 r
.38618 .44147 m .40482 .43583 L .40856 .43683 L p F P
0 g
s
.736 .622 .731 r
.72203 .51385 m .69778 .5232 L .6908 .50455 L p F P
0 g
s
.736 .622 .731 r
.6908 .50455 m .71477 .4951 L .72203 .51385 L p F P
0 g
s
0 0 0 r
.37929 .44261 m .36168 .44697 L .35856 .44852 L p F P
0 g
s
.739 .637 .746 r
.73864 .48475 m .71477 .4951 L .70752 .47676 L p F P
0 g
s
.739 .637 .746 r
.70752 .47676 m .73115 .46673 L .73864 .48475 L p F P
0 g
s
.727 .599 .714 r
.69345 .58817 m .668 .59344 L .66164 .57473 L p F P
0 g
s
.727 .599 .714 r
.66164 .57473 m .68676 .5689 L .69345 .58817 L p F P
0 g
s
.731 .61 .723 r
.70476 .54219 m .68008 .54995 L .67341 .53131 L p F P
0 g
s
.731 .61 .723 r
.67341 .53131 m .69778 .5232 L .70476 .54219 L p F P
0 g
s
.668 .572 .738 r
.49912 .47001 m .52134 .46475 L .52624 .47832 L p F P
0 g
s
.669 .58 .746 r
.52134 .46475 m .49912 .47001 L .49459 .458 L p F P
0 g
s
.546 .781 .986 r
.82597 .43451 m .80199 .4391 L .79435 .42799 L p F P
0 g
s
.694 .737 .884 r
.80199 .4391 m .7783 .44698 L .77059 .43272 L p F P
0 g
s
.694 .737 .884 r
.77059 .43272 m .79435 .42799 L .80199 .4391 L p F P
0 g
s
.29 0 .031 r
.29117 .47242 m .3033 .47583 L .30579 .4727 L p F P
0 g
s
.667 .606 .778 r
.46446 .44373 m .48546 .43678 L .49003 .44684 L p F P
0 g
s
.674 .638 .806 r
.48546 .43678 m .46446 .44373 L .46022 .43588 L p F P
0 g
s
.728 .689 .813 r
.7783 .44698 m .75472 .45657 L .74708 .44025 L p F P
0 g
s
.728 .689 .813 r
.74708 .44025 m .77059 .43272 L .7783 .44698 L p F P
0 g
s
.724 .6 .718 r
.68676 .5689 m .66164 .57473 L .65529 .5563 L p F P
0 g
s
.724 .6 .718 r
.65529 .5563 m .68008 .54995 L .68676 .5689 L p F P
0 g
s
.669 .683 .854 r
.43581 .4368 m .45594 .4296 L .46022 .43588 L p F P
0 g
s
.676 .754 .91 r
.45594 .4296 m .43581 .4368 L .43182 .43269 L p F P
0 g
s
.686 .568 .716 r
.58055 .56661 m .55562 .56711 L .55073 .5517 L p F P
0 g
s
.686 .568 .716 r
.55073 .5517 m .57528 .5504 L .58055 .56661 L p F P
0 g
s
.684 .568 .719 r
.57528 .5504 m .55073 .5517 L .54583 .5365 L p F P
0 g
s
.684 .568 .719 r
.54583 .5365 m .57001 .53439 L .57528 .5504 L p F P
0 g
s
.682 .569 .721 r
.57001 .53439 m .54583 .5365 L .54094 .52152 L p F P
0 g
s
.688 .567 .714 r
.58583 .58302 m .56052 .5827 L .55562 .56711 L p F P
0 g
s
.688 .567 .714 r
.55562 .56711 m .58055 .56661 L .58583 .58302 L p F P
0 g
s
.669 .58 .746 r
.49459 .458 m .51643 .4518 L .52134 .46475 L p F P
0 g
s
.672 .592 .757 r
.51643 .4518 m .49459 .458 L .49003 .44684 L p F P
0 g
s
.69 .567 .711 r
.59111 .59962 m .56543 .59846 L .56052 .5827 L p F P
0 g
s
.69 .567 .711 r
.56052 .5827 m .58583 .58302 L .59111 .59962 L p F P
0 g
s
.682 .569 .721 r
.54094 .52152 m .56474 .5186 L .57001 .53439 L p F P
0 g
s
.68 .57 .724 r
.56474 .5186 m .54094 .52152 L .53604 .5068 L p F P
0 g
s
.68 .57 .724 r
.53604 .5068 m .55946 .50306 L .56474 .5186 L p F P
0 g
s
.678 .571 .728 r
.55946 .50306 m .53604 .5068 L .53114 .49237 L p F P
0 g
s
.09 .612 .879 r
.85046 .4347 m .82597 .43451 L .81853 .42736 L p F P
0 g
s
.546 .781 .986 r
.79435 .42799 m .81853 .42736 L .82597 .43451 L p F P
0 g
s
.728 .611 .728 r
.69778 .5232 m .67341 .53131 L .66674 .51295 L p F P
0 g
s
.728 .611 .728 r
.66674 .51295 m .6908 .50455 L .69778 .5232 L p F P
0 g
s
.734 .658 .775 r
.75472 .45657 m .73115 .46673 L .72366 .44927 L p F P
0 g
s
.734 .658 .775 r
.72366 .44927 m .74708 .44025 L .75472 .45657 L p F P
0 g
s
.718 .591 .713 r
.668 .59344 m .64243 .59711 L .63642 .57904 L p F P
0 g
s
.718 .591 .713 r
.63642 .57904 m .66164 .57473 L .668 .59344 L p F P
0 g
s
.732 .623 .737 r
.71477 .4951 m .6908 .50455 L .68383 .48621 L p F P
0 g
s
.732 .623 .737 r
.68383 .48621 m .70752 .47676 L .71477 .4951 L p F P
0 g
s
.722 .601 .721 r
.68008 .54995 m .65529 .5563 L .64895 .53812 L p F P
0 g
s
.722 .601 .721 r
.64895 .53812 m .67341 .53131 L .68008 .54995 L p F P
0 g
s
.678 .571 .728 r
.53114 .49237 m .55419 .4878 L .55946 .50306 L p F P
0 g
s
.677 .574 .732 r
.55419 .4878 m .53114 .49237 L .52624 .47832 L p F P
0 g
s
.245 0 0 r
.31317 .46398 m .32757 .46396 L .33045 .46093 L p F P
0 g
s
.246 0 0 r
.32757 .46396 m .31317 .46398 L .31073 .46676 L p F P
0 g
s
.715 .592 .716 r
.66164 .57473 m .63642 .57904 L .63042 .5612 L p F P
0 g
s
.715 .592 .716 r
.63042 .5612 m .65529 .5563 L .66164 .57473 L p F P
0 g
s
.638 .833 .976 r
.40856 .43683 m .42778 .43013 L .43182 .43269 L p F P
0 g
s
.575 .897 .985 r
.42778 .43013 m .40856 .43683 L .40482 .43583 L p F P
0 g
s
.677 .574 .732 r
.52624 .47832 m .54892 .47289 L .55419 .4878 L p F P
0 g
s
.677 .578 .737 r
.54892 .47289 m .52624 .47832 L .52134 .46475 L p F P
0 g
s
.672 .592 .757 r
.49003 .44684 m .51151 .43968 L .51643 .4518 L p F P
0 g
s
.677 .611 .774 r
.51151 .43968 m .49003 .44684 L .48546 .43678 L p F P
0 g
s
.699 .575 .712 r
.61679 .59917 m .59111 .59962 L .58583 .58302 L p F P
0 g
s
.699 .575 .712 r
.58583 .58302 m .61114 .5818 L .61679 .59917 L p F P
0 g
s
.697 .575 .715 r
.61114 .5818 m .58583 .58302 L .58055 .56661 L p F P
0 g
s
.621 .07 0 r
.93446 .4602 m .90803 .44772 L .90149 .45021 L p F P
0 g
s
.528 0 0 r
.87562 .44014 m .90149 .45021 L .90803 .44772 L p F P
0 g
s
.697 .575 .715 r
.58055 .56661 m .6055 .56464 L .61114 .5818 L p F P
0 g
s
.695 .576 .717 r
.6055 .56464 m .58055 .56661 L .57528 .5504 L p F P
0 g
s
.148 0 0 r
.33611 .45557 m .35218 .45311 L .35539 .4506 L p F P
0 g
s
.169 0 0 r
.35218 .45311 m .33611 .45557 L .33329 .45812 L p F P
0 g
s
.695 .576 .717 r
.57528 .5504 m .59985 .54769 L .6055 .56464 L p F P
0 g
s
.693 .576 .72 r
.59985 .54769 m .57528 .5504 L .57001 .53439 L p F P
0 g
s
.709 .583 .713 r
.64243 .59711 m .61679 .59917 L .61114 .5818 L p F P
0 g
s
.709 .583 .713 r
.61114 .5818 m .63642 .57904 L .64243 .59711 L p F P
0 g
s
.674 .638 .806 r
.46022 .43588 m .48086 .42813 L .48546 .43678 L p F P
0 g
s
.685 .687 .846 r
.48086 .42813 m .46022 .43588 L .45594 .4296 L p F P
0 g
s
.693 .576 .72 r
.57001 .53439 m .59421 .53095 L .59985 .54769 L p F P
0 g
s
.69 .577 .723 r
.59421 .53095 m .57001 .53439 L .56474 .5186 L p F P
0 g
s
.732 .638 .755 r
.73115 .46673 m .70752 .47676 L .70027 .45878 L p F P
0 g
s
.732 .638 .755 r
.70027 .45878 m .72366 .44927 L .73115 .46673 L p F P
0 g
s
.719 .602 .725 r
.67341 .53131 m .64895 .53812 L .64261 .52019 L p F P
0 g
s
.719 .602 .725 r
.64261 .52019 m .66674 .51295 L .67341 .53131 L p F P
0 g
s
.713 .592 .72 r
.65529 .5563 m .63042 .5612 L .62442 .54359 L p F P
0 g
s
.713 .592 .72 r
.62442 .54359 m .64895 .53812 L .65529 .5563 L p F P
0 g
s
.706 .584 .715 r
.63642 .57904 m .61114 .5818 L .6055 .56464 L p F P
0 g
s
.706 .584 .715 r
.6055 .56464 m .63042 .5612 L .63642 .57904 L p F P
0 g
s
.69 .577 .723 r
.56474 .5186 m .58857 .51443 L .59421 .53095 L p F P
0 g
s
.688 .577 .726 r
.58857 .51443 m .56474 .5186 L .55946 .50306 L p F P
0 g
s
.677 .578 .737 r
.52134 .46475 m .54364 .45842 L .54892 .47289 L p F P
0 g
s
.678 .585 .744 r
.54364 .45842 m .52134 .46475 L .51643 .4518 L p F P
0 g
s
.724 .612 .732 r
.6908 .50455 m .66674 .51295 L .66007 .49485 L p F P
0 g
s
.724 .612 .732 r
.66007 .49485 m .68383 .48621 L .6908 .50455 L p F P
0 g
s
.704 .584 .718 r
.63042 .5612 m .6055 .56464 L .59985 .54769 L p F P
0 g
s
.704 .584 .718 r
.59985 .54769 m .62442 .54359 L .63042 .5612 L p F P
0 g
s
.688 .577 .726 r
.55946 .50306 m .58293 .49815 L .58857 .51443 L p F P
0 g
s
.686 .579 .729 r
.58293 .49815 m .55946 .50306 L .55419 .4878 L p F P
0 g
s
.701 .584 .721 r
.62442 .54359 m .59985 .54769 L .59421 .53095 L p F P
0 g
s
.71 .593 .723 r
.64895 .53812 m .62442 .54359 L .61842 .52621 L p F P
0 g
s
.71 .593 .723 r
.61842 .52621 m .64261 .52019 L .64895 .53812 L p F P
0 g
s
.701 .584 .721 r
.59421 .53095 m .61842 .52621 L .62442 .54359 L p F P
0 g
s
.699 .585 .724 r
.61842 .52621 m .59421 .53095 L .58857 .51443 L p F P
0 g
s
.726 .624 .744 r
.70752 .47676 m .68383 .48621 L .67685 .46815 L p F P
0 g
s
.726 .624 .744 r
.67685 .46815 m .70027 .45878 L .70752 .47676 L p F P
0 g
s
.686 .579 .729 r
.55419 .4878 m .57729 .48213 L .58293 .49815 L p F P
0 g
s
.685 .581 .733 r
.57729 .48213 m .55419 .4878 L .54892 .47289 L p F P
0 g
s
.716 .602 .729 r
.66674 .51295 m .64261 .52019 L .63626 .50249 L p F P
0 g
s
.716 .602 .729 r
.63626 .50249 m .66007 .49485 L .66674 .51295 L p F P
0 g
s
0 0 0 r
.35856 .44852 m .37576 .44432 L .37929 .44261 L p F P
0 g
s
.036 0 0 r
.37576 .44432 m .35856 .44852 L .35539 .4506 L p F P
0 g
s
.678 .585 .744 r
.51643 .4518 m .53837 .44455 L .54364 .45842 L p F P
0 g
s
.681 .596 .754 r
.53837 .44455 m .51643 .4518 L .51151 .43968 L p F P
0 g
s
.677 .611 .774 r
.48546 .43678 m .50658 .4287 L .51151 .43968 L p F P
0 g
s
.686 .642 .8 r
.50658 .4287 m .48546 .43678 L .48086 .42813 L p F P
0 g
s
.676 .754 .91 r
.43182 .43269 m .45159 .42505 L .45594 .4296 L p F P
0 g
s
.669 .842 .966 r
.45159 .42505 m .43182 .43269 L .42778 .43013 L p F P
0 g
s
.699 .585 .724 r
.58857 .51443 m .61242 .50904 L .61842 .52621 L p F P
0 g
s
.697 .585 .727 r
.61242 .50904 m .58857 .51443 L .58293 .49815 L p F P
0 g
s
.707 .593 .726 r
.64261 .52019 m .61842 .52621 L .61242 .50904 L p F P
0 g
s
.707 .593 .726 r
.61242 .50904 m .63626 .50249 L .64261 .52019 L p F P
0 g
s
.685 .581 .733 r
.54892 .47289 m .57165 .46642 L .57729 .48213 L p F P
0 g
s
.685 .585 .737 r
.57165 .46642 m .54892 .47289 L .54364 .45842 L p F P
0 g
s
.345 0 0 r
.87562 .44014 m .85046 .4347 L .84327 .43134 L p F P
0 g
s
.09 .612 .879 r
.81853 .42736 m .84327 .43134 L .85046 .4347 L p F P
0 g
s
.72 .613 .737 r
.68383 .48621 m .66007 .49485 L .6534 .47698 L p F P
0 g
s
.72 .613 .737 r
.6534 .47698 m .67685 .46815 L .68383 .48621 L p F P
0 g
s
.697 .585 .727 r
.58293 .49815 m .60643 .49211 L .61242 .50904 L p F P
0 g
s
.694 .586 .73 r
.60643 .49211 m .58293 .49815 L .57729 .48213 L p F P
0 g
s
.705 .594 .729 r
.63626 .50249 m .61242 .50904 L .60643 .49211 L p F P
0 g
s
.712 .603 .732 r
.66007 .49485 m .63626 .50249 L .62992 .48502 L p F P
0 g
s
.712 .603 .732 r
.62992 .48502 m .6534 .47698 L .66007 .49485 L p F P
0 g
s
.681 .596 .754 r
.51151 .43968 m .53308 .43148 L .53837 .44455 L p F P
0 g
s
.687 .614 .77 r
.53308 .43148 m .51151 .43968 L .50658 .4287 L p F P
0 g
s
.685 .687 .846 r
.45594 .4296 m .47622 .42121 L .48086 .42813 L p F P
0 g
s
.696 .76 .901 r
.47622 .42121 m .45594 .4296 L .45159 .42505 L p F P
0 g
s
.705 .594 .729 r
.60643 .49211 m .62992 .48502 L .63626 .50249 L p F P
0 g
s
.685 .585 .737 r
.54364 .45842 m .56601 .45111 L .57165 .46642 L p F P
0 g
s
.686 .59 .743 r
.56601 .45111 m .54364 .45842 L .53837 .44455 L p F P
0 g
s
.246 0 0 r
.31073 .46676 m .32467 .46718 L .32757 .46396 L p F P
0 g
s
.245 0 0 r
.32467 .46718 m .31073 .46676 L .30827 .46967 L p F P
0 g
s
.694 .696 .847 r
.77059 .43272 m .74708 .44025 L .73945 .4248 L p F P
0 g
s
.717 .662 .794 r
.74708 .44025 m .72366 .44927 L .71618 .43234 L p F P
0 g
s
.717 .662 .794 r
.71618 .43234 m .73945 .4248 L .74708 .44025 L p F P
0 g
s
.694 .586 .73 r
.57729 .48213 m .60043 .47542 L .60643 .49211 L p F P
0 g
s
.693 .588 .734 r
.60043 .47542 m .57729 .48213 L .57165 .46642 L p F P
0 g
s
.722 .64 .766 r
.72366 .44927 m .70027 .45878 L .69301 .44115 L p F P
0 g
s
.722 .64 .766 r
.69301 .44115 m .71618 .43234 L .72366 .44927 L p F P
0 g
s
.702 .594 .733 r
.62992 .48502 m .60643 .49211 L .60043 .47542 L p F P
0 g
s
.613 .738 .934 r
.79435 .42799 m .77059 .43272 L .76292 .41973 L p F P
0 g
s
.694 .696 .847 r
.73945 .4248 m .76292 .41973 L .77059 .43272 L p F P
0 g
s
.72 .624 .75 r
.70027 .45878 m .67685 .46815 L .66987 .45034 L p F P
0 g
s
.72 .624 .75 r
.66987 .45034 m .69301 .44115 L .70027 .45878 L p F P
0 g
s
.575 .897 .985 r
.40482 .43583 m .42367 .42901 L .42778 .43013 L p F P
0 g
s
.452 .882 .897 r
.42367 .42901 m .40482 .43583 L .40101 .43597 L p F P
0 g
s
.686 .642 .8 r
.48086 .42813 m .50162 .41922 L .50658 .4287 L p F P
0 g
s
.7 .691 .838 r
.50162 .41922 m .48086 .42813 L .47622 .42121 L p F P
0 g
s
.693 .588 .734 r
.57165 .46642 m .59443 .459 L .60043 .47542 L p F P
0 g
s
.692 .591 .738 r
.59443 .459 m .57165 .46642 L .56601 .45111 L p F P
0 g
s
.169 0 0 r
.33329 .45812 m .34893 .45598 L .35218 .45311 L p F P
0 g
s
.181 0 0 r
.34893 .45598 m .33329 .45812 L .33045 .46093 L p F P
0 g
s
.709 .603 .736 r
.6534 .47698 m .62992 .48502 L .62358 .46777 L p F P
0 g
s
.702 .594 .733 r
.60043 .47542 m .62358 .46777 L .62992 .48502 L p F P
0 g
s
.686 .59 .743 r
.53837 .44455 m .56037 .43633 L .56601 .45111 L p F P
0 g
s
.689 .6 .752 r
.56037 .43633 m .53837 .44455 L .53308 .43148 L p F P
0 g
s
.715 .613 .741 r
.67685 .46815 m .6534 .47698 L .64672 .45933 L p F P
0 g
s
.715 .613 .741 r
.64672 .45933 m .66987 .45034 L .67685 .46815 L p F P
0 g
s
.709 .603 .736 r
.62358 .46777 m .64672 .45933 L .6534 .47698 L p F P
0 g
s
.7 .596 .736 r
.62358 .46777 m .60043 .47542 L .59443 .459 L p F P
0 g
s
.687 .614 .77 r
.50658 .4287 m .52778 .41954 L .53308 .43148 L p F P
0 g
s
.697 .644 .793 r
.52778 .41954 m .50658 .4287 L .50162 .41922 L p F P
0 g
s
.692 .591 .738 r
.56601 .45111 m .58843 .44292 L .59443 .459 L p F P
0 g
s
.692 .595 .743 r
.58843 .44292 m .56601 .45111 L .56037 .43633 L p F P
0 g
s
.362 .714 .987 r
.81853 .42736 m .79435 .42799 L .78676 .4183 L p F P
0 g
s
.613 .738 .934 r
.76292 .41973 m .78676 .4183 L .79435 .42799 L p F P
0 g
s
.706 .603 .74 r
.64672 .45933 m .62358 .46777 L .61723 .45076 L p F P
0 g
s
.7 .596 .736 r
.59443 .459 m .61723 .45076 L .62358 .46777 L p F P
0 g
s
.698 .597 .739 r
.61723 .45076 m .59443 .459 L .58843 .44292 L p F P
0 g
s
.689 .6 .752 r
.53308 .43148 m .55472 .4223 L .56037 .43633 L p F P
0 g
s
.695 .617 .765 r
.55472 .4223 m .53308 .43148 L .52778 .41954 L p F P
0 g
s
.669 .842 .966 r
.42778 .43013 m .44719 .42222 L .45159 .42505 L p F P
0 g
s
.619 .912 .981 r
.44719 .42222 m .42778 .43013 L .42367 .42901 L p F P
0 g
s
.71 .613 .746 r
.66987 .45034 m .64672 .45933 L .64004 .4419 L p F P
0 g
s
.706 .603 .74 r
.61723 .45076 m .64004 .4419 L .64672 .45933 L p F P
0 g
s
.036 0 0 r
.35539 .4506 m .37218 .44662 L .37576 .44432 L p F P
0 g
s
.077 0 0 r
.37218 .44662 m .35539 .4506 L .35218 .45311 L p F P
0 g
s
.712 .624 .757 r
.69301 .44115 m .66987 .45034 L .66287 .43274 L p F P
0 g
s
.71 .613 .746 r
.64004 .4419 m .66287 .43274 L .66987 .45034 L p F P
0 g
s
.692 .595 .743 r
.56037 .43633 m .58242 .42728 L .58843 .44292 L p F P
0 g
s
.695 .603 .75 r
.58242 .42728 m .56037 .43633 L .55472 .4223 L p F P
0 g
s
.709 .64 .778 r
.71618 .43234 m .69301 .44115 L .68574 .42381 L p F P
0 g
s
.712 .624 .757 r
.66287 .43274 m .68574 .42381 L .69301 .44115 L p F P
0 g
s
.703 .604 .743 r
.64004 .4419 m .61723 .45076 L .61088 .43401 L p F P
0 g
s
.698 .597 .739 r
.58843 .44292 m .61088 .43401 L .61723 .45076 L p F P
0 g
s
.696 .76 .901 r
.45159 .42505 m .47152 .4162 L .47622 .42121 L p F P
0 g
s
.696 .85 .956 r
.47152 .4162 m .45159 .42505 L .44719 .42222 L p F P
0 g
s
.698 .6 .743 r
.61088 .43401 m .58843 .44292 L .58242 .42728 L p F P
0 g
s
.693 .663 .817 r
.73945 .4248 m .71618 .43234 L .70869 .41592 L p F P
0 g
s
.709 .64 .778 r
.68574 .42381 m .70869 .41592 L .71618 .43234 L p F P
0 g
s
.245 0 0 r
.30827 .46967 m .32174 .47057 L .32467 .46718 L p F P
0 g
s
.243 0 0 r
.32174 .47057 m .30827 .46967 L .30579 .4727 L p F P
0 g
s
.7 .691 .838 r
.47622 .42121 m .49662 .41162 L .50162 .41922 L p F P
0 g
s
.715 .764 .891 r
.49662 .41162 m .47622 .42121 L .47152 .4162 L p F P
0 g
s
.697 .644 .793 r
.50162 .41922 m .52247 .40917 L .52778 .41954 L p F P
0 g
s
.712 .693 .83 r
.52247 .40917 m .50162 .41922 L .49662 .41162 L p F P
0 g
s
.706 .612 .75 r
.66287 .43274 m .64004 .4419 L .63335 .42466 L p F P
0 g
s
.703 .604 .743 r
.61088 .43401 m .63335 .42466 L .64004 .4419 L p F P
0 g
s
.695 .617 .765 r
.52778 .41954 m .54907 .40935 L .55472 .4223 L p F P
0 g
s
.706 .645 .786 r
.54907 .40935 m .52778 .41954 L .52247 .40917 L p F P
0 g
s
.526 0 0 r
.90149 .45021 m .87562 .44014 L .86864 .43961 L p F P
0 g
s
.345 0 0 r
.84327 .43134 m .86864 .43961 L .87562 .44014 L p F P
0 g
s
.642 .695 .884 r
.76292 .41973 m .73945 .4248 L .73183 .41021 L p F P
0 g
s
.693 .663 .817 r
.70869 .41592 m .73183 .41021 L .73945 .4248 L p F P
0 g
s
.621 .07 0 r
.90149 .45021 m .92807 .46399 L .93446 .4602 L p F P
0 g
s
.695 .603 .75 r
.55472 .4223 m .57642 .41228 L .58242 .42728 L p F P
0 g
s
.701 .618 .76 r
.57642 .41228 m .55472 .4223 L .54907 .40935 L p F P
0 g
s
.701 .605 .746 r
.63335 .42466 m .61088 .43401 L .60452 .4176 L p F P
0 g
s
.698 .6 .743 r
.58242 .42728 m .60452 .4176 L .61088 .43401 L p F P
0 g
s
.7 .606 .748 r
.60452 .4176 m .58242 .42728 L .57642 .41228 L p F P
0 g
s
.704 .623 .764 r
.68574 .42381 m .66287 .43274 L .65587 .41532 L p F P
0 g
s
.706 .612 .75 r
.63335 .42466 m .65587 .41532 L .66287 .43274 L p F P
0 g
s
.181 0 0 r
.33045 .46093 m .34564 .45915 L .34893 .45598 L p F P
0 g
s
.186 0 0 r
.34564 .45915 m .33045 .46093 L .32757 .46396 L p F P
0 g
s
.452 .882 .897 r
.40101 .43597 m .41949 .42913 L .42367 .42901 L p F P
0 g
s
0 .487 .798 r
.84327 .43134 m .81853 .42736 L .81108 .42111 L p F P
0 g
s
.362 .714 .987 r
.78676 .4183 m .81108 .42111 L .81853 .42736 L p F P
0 g
s
.692 .639 .791 r
.70869 .41592 m .68574 .42381 L .67846 .40674 L p F P
0 g
s
.704 .623 .764 r
.65587 .41532 m .67846 .40674 L .68574 .42381 L p F P
0 g
s
.701 .612 .754 r
.65587 .41532 m .63335 .42466 L .62666 .40764 L p F P
0 g
s
.701 .605 .746 r
.60452 .4176 m .62666 .40764 L .63335 .42466 L p F P
0 g
s
.701 .608 .75 r
.62666 .40764 m .60452 .4176 L .59816 .40166 L p F P
0 g
s
.7 .606 .748 r
.57642 .41228 m .59816 .40166 L .60452 .4176 L p F P
0 g
s
.501 .712 .965 r
.78676 .4183 m .76292 .41973 L .75527 .40786 L p F P
0 g
s
.642 .695 .884 r
.73183 .41021 m .75527 .40786 L .76292 .41973 L p F P
0 g
s
.705 .617 .756 r
.59816 .40166 m .57642 .41228 L .57041 .39825 L p F P
0 g
s
.701 .618 .76 r
.54907 .40935 m .57041 .39825 L .57642 .41228 L p F P
0 g
s
.713 .643 .778 r
.57041 .39825 m .54907 .40935 L .54341 .398 L p F P
0 g
s
.706 .645 .786 r
.52247 .40917 m .54341 .398 L .54907 .40935 L p F P
0 g
s
.619 .912 .981 r
.42367 .42901 m .44271 .42098 L .44719 .42222 L p F P
0 g
s
.513 .911 .909 r
.44271 .42098 m .42367 .42901 L .41949 .42913 L p F P
0 g
s
.724 .694 .821 r
.54341 .398 m .52247 .40917 L .51714 .40084 L p F P
0 g
s
.712 .693 .83 r
.49662 .41162 m .51714 .40084 L .52247 .40917 L p F P
0 g
s
.658 .661 .842 r
.73183 .41021 m .70869 .41592 L .7012 .40003 L p F P
0 g
s
.692 .639 .791 r
.67846 .40674 m .7012 .40003 L .70869 .41592 L p F P
0 g
s
.693 .621 .771 r
.67846 .40674 m .65587 .41532 L .64885 .39806 L p F P
0 g
s
.701 .612 .754 r
.62666 .40764 m .64885 .39806 L .65587 .41532 L p F P
0 g
s
0 0 0 r
.37576 .44432 m .39322 .4389 L .39715 .43704 L p F P
0 g
s
0 0 0 r
.39322 .4389 m .37576 .44432 L .37218 .44662 L p F P
0 g
s
.077 0 0 r
.35218 .45311 m .36855 .44938 L .37218 .44662 L p F P
0 g
s
.101 0 0 r
.36855 .44938 m .35218 .45311 L .34893 .45598 L p F P
0 g
s
.243 0 0 r
.30579 .4727 m .31879 .47409 L .32174 .47057 L p F P
0 g
s
.239 0 0 r
.31879 .47409 m .30579 .4727 L .3033 .47583 L p F P
0 g
s
.732 .768 .882 r
.51714 .40084 m .49662 .41162 L .49158 .40615 L p F P
0 g
s
.715 .764 .891 r
.47152 .4162 m .49158 .40615 L .49662 .41162 L p F P
0 g
s
.696 .85 .956 r
.44719 .42222 m .46676 .41312 L .47152 .4162 L p F P
0 g
s
.657 .924 .975 r
.46676 .41312 m .44719 .42222 L .44271 .42098 L p F P
0 g
s
.72 .857 .947 r
.49158 .40615 m .47152 .4162 L .46676 .41312 L p F P
0 g
s
.697 .611 .757 r
.64885 .39806 m .62666 .40764 L .61995 .3909 L p F P
0 g
s
.701 .608 .75 r
.59816 .40166 m .61995 .3909 L .62666 .40764 L p F P
0 g
s
.705 .615 .754 r
.61995 .3909 m .59816 .40166 L .5918 .38648 L p F P
0 g
s
.705 .617 .756 r
.57041 .39825 m .5918 .38648 L .59816 .40166 L p F P
0 g
s
.669 .635 .807 r
.7012 .40003 m .67846 .40674 L .67117 .38991 L p F P
0 g
s
.693 .621 .771 r
.64885 .39806 m .67117 .38991 L .67846 .40674 L p F P
0 g
s
.717 .639 .769 r
.5918 .38648 m .57041 .39825 L .56441 .38578 L p F P
0 g
s
.713 .643 .778 r
.54341 .398 m .56441 .38578 L .57041 .39825 L p F P
0 g
s
.186 0 0 r
.32757 .46396 m .34232 .46257 L .34564 .45915 L p F P
0 g
s
.188 0 0 r
.34232 .46257 m .32757 .46396 L .32467 .46718 L p F P
0 g
s
.569 .683 .917 r
.75527 .40786 m .73183 .41021 L .72421 .39646 L p F P
0 g
s
.658 .661 .842 r
.7012 .40003 m .72421 .39646 L .73183 .41021 L p F P
0 g
s
.681 .618 .779 r
.67117 .38991 m .64885 .39806 L .64182 .38091 L p F P
0 g
s
.697 .611 .757 r
.61995 .3909 m .64182 .38091 L .64885 .39806 L p F P
0 g
s
.733 .692 .811 r
.56441 .38578 m .54341 .398 L .53774 .38887 L p F P
0 g
s
.724 .694 .821 r
.51714 .40084 m .53774 .38887 L .54341 .398 L p F P
0 g
s
.696 .613 .759 r
.64182 .38091 m .61995 .3909 L .61324 .37459 L p F P
0 g
s
.705 .615 .754 r
.5918 .38648 m .61324 .37459 L .61995 .3909 L p F P
0 g
s
.2 .623 .949 r
.81108 .42111 m .78676 .4183 L .77915 .40953 L p F P
0 g
s
.501 .712 .965 r
.75527 .40786 m .77915 .40953 L .78676 .4183 L p F P
0 g
s
.715 .63 .761 r
.61324 .37459 m .5918 .38648 L .58545 .3727 L p F P
0 g
s
.717 .639 .769 r
.56441 .38578 m .58545 .3727 L .5918 .38648 L p F P
0 g
s
.747 .772 .873 r
.53774 .38887 m .51714 .40084 L .51176 .3949 L p F P
0 g
s
.732 .768 .882 r
.49158 .40615 m .51176 .3949 L .51714 .40084 L p F P
0 g
s
.366 0 0 r
.86864 .43961 m .84327 .43134 L .83597 .42794 L p F P
0 g
s
0 .487 .798 r
.81108 .42111 m .83597 .42794 L .84327 .43134 L p F P
0 g
s
.608 .653 .869 r
.72421 .39646 m .7012 .40003 L .6937 .38467 L p F P
0 g
s
.669 .635 .807 r
.67117 .38991 m .6937 .38467 L .7012 .40003 L p F P
0 g
s
.239 0 0 r
.3033 .47583 m .31581 .47774 L .31879 .47409 L p F P
0 g
s
.739 .685 .799 r
.58545 .3727 m .56441 .38578 L .5584 .37572 L p F P
0 g
s
.733 .692 .811 r
.53774 .38887 m .5584 .37572 L .56441 .38578 L p F P
0 g
s
.637 .629 .826 r
.6937 .38467 m .67117 .38991 L .66385 .37331 L p F P
0 g
s
.681 .618 .779 r
.64182 .38091 m .66385 .37331 L .67117 .38991 L p F P
0 g
s
.742 .864 .937 r
.51176 .3949 m .49158 .40615 L .48649 .40283 L p F P
0 g
s
.72 .857 .947 r
.46676 .41312 m .48649 .40283 L .49158 .40615 L p F P
0 g
s
.666 .614 .787 r
.66385 .37331 m .64182 .38091 L .63477 .36387 L p F P
0 g
s
.696 .613 .759 r
.61324 .37459 m .63477 .36387 L .64182 .38091 L p F P
0 g
s
.604 .038 0 r
.92807 .46399 m .90149 .45021 L .89466 .45146 L p F P
0 g
s
.526 0 0 r
.86864 .43961 m .89466 .45146 L .90149 .45021 L p F P
0 g
s
.702 .617 .759 r
.63477 .36387 m .61324 .37459 L .60653 .35919 L p F P
0 g
s
.715 .63 .761 r
.58545 .3727 m .60653 .35919 L .61324 .37459 L p F P
0 g
s
.101 0 0 r
.34893 .45598 m .36488 .45254 L .36855 .44938 L p F P
0 g
s
.114 0 0 r
.36488 .45254 m .34893 .45598 L .34564 .45915 L p F P
0 g
s
.513 .911 .909 r
.41949 .42913 m .43817 .42109 L .44271 .42098 L p F P
0 g
s
0 0 0 r
.37218 .44662 m .38924 .44138 L .39322 .4389 L p F P
0 g
s
0 0 0 r
.38924 .44138 m .37218 .44662 L .36855 .44938 L p F P
0 g
s
.689 .934 .966 r
.48649 .40283 m .46676 .41312 L .46194 .41178 L p F P
0 g
s
.657 .924 .975 r
.44271 .42098 m .46194 .41178 L .46676 .41312 L p F P
0 g
s
.566 .934 .915 r
.46194 .41178 m .44271 .42098 L .43817 .42109 L p F P
0 g
s
.377 .661 .969 r
.77915 .40953 m .75527 .40786 L .74762 .39687 L p F P
0 g
s
.569 .683 .917 r
.72421 .39646 m .74762 .39687 L .75527 .40786 L p F P
0 g
s
.739 .669 .782 r
.60653 .35919 m .58545 .3727 L .57912 .36144 L p F P
0 g
s
.739 .685 .799 r
.5584 .37572 m .57912 .36144 L .58545 .3727 L p F P
0 g
s
.761 .775 .865 r
.5584 .37572 m .53774 .38887 L .53204 .38245 L p F P
0 g
s
.747 .772 .873 r
.51176 .3949 m .53204 .38245 L .53774 .38887 L p F P
0 g
s
.188 0 0 r
.32467 .46718 m .33897 .46619 L .34232 .46257 L p F P
0 g
s
.188 0 0 r
.33897 .46619 m .32467 .46718 L .32174 .47057 L p F P
0 g
s
.666 .614 .787 r
.63477 .36387 m .65652 .35697 L .66385 .37331 L p F P
0 g
s
.646 .611 .8 r
.65652 .35697 m .63477 .36387 L .6277 .34697 L p F P
0 g
s
.702 .617 .759 r
.60653 .35919 m .6277 .34697 L .63477 .36387 L p F P
0 g
s
.724 .634 .758 r
.6277 .34697 m .60653 .35919 L .59985 .34614 L p F P
0 g
s
.739 .669 .782 r
.57912 .36144 m .59985 .34614 L .60653 .35919 L p F P
0 g
s
.478 .654 .937 r
.74762 .39687 m .72421 .39646 L .71659 .3835 L p F P
0 g
s
.608 .653 .869 r
.6937 .38467 m .71659 .3835 L .72421 .39646 L p F P
0 g
s
.637 .629 .826 r
.66385 .37331 m .68619 .36992 L .6937 .38467 L p F P
0 g
s
.588 .618 .85 r
.68619 .36992 m .66385 .37331 L .65652 .35697 L p F P
0 g
s
.54 .636 .894 r
.71659 .3835 m .6937 .38467 L .68619 .36992 L p F P
0 g
s
.761 .872 .929 r
.53204 .38245 m .51176 .3949 L .50634 .39136 L p F P
0 g
s
.742 .864 .937 r
.48649 .40283 m .50634 .39136 L .51176 .3949 L p F P
0 g
s
0 .418 .764 r
.83597 .42794 m .81108 .42111 L .80354 .4151 L p F P
0 g
s
.2 .623 .949 r
.77915 .40953 m .80354 .4151 L .81108 .42111 L p F P
0 g
s
.773 .777 .856 r
.57912 .36144 m .5584 .37572 L .55239 .36882 L p F P
0 g
s
.761 .775 .865 r
.53204 .38245 m .55239 .36882 L .5584 .37572 L p F P
0 g
s
0 0 0 r
.39322 .4389 m .41094 .43224 L .41524 .43027 L p F P
0 g
s
0 0 0 r
.41094 .43224 m .39322 .4389 L .38924 .44138 L p F P
0 g
s
.646 .611 .8 r
.6277 .34697 m .64918 .3411 L .65652 .35697 L p F P
0 g
s
.611 .616 .831 r
.64918 .3411 m .6277 .34697 L .62063 .33068 L p F P
0 g
s
.724 .634 .758 r
.59985 .34614 m .62063 .33068 L .6277 .34697 L p F P
0 g
s
.114 0 0 r
.34564 .45915 m .36116 .45602 L .36488 .45254 L p F P
0 g
s
.121 0 0 r
.36116 .45602 m .34564 .45915 L .34232 .46257 L p F P
0 g
s
.716 .943 .956 r
.50634 .39136 m .48649 .40283 L .48133 .4014 L p F P
0 g
s
.689 .934 .966 r
.46194 .41178 m .48133 .4014 L .48649 .40283 L p F P
0 g
s
.783 .779 .849 r
.59985 .34614 m .57912 .36144 L .5728 .35404 L p F P
0 g
s
.773 .777 .856 r
.55239 .36882 m .5728 .35404 L .57912 .36144 L p F P
0 g
s
0 0 0 r
.36855 .44938 m .38521 .44436 L .38924 .44138 L p F P
0 g
s
.027 0 0 r
.38521 .44436 m .36855 .44938 L .36488 .45254 L p F P
0 g
s
.506 0 0 r
.89466 .45146 m .86864 .43961 L .86145 .43821 L p F P
0 g
s
.366 0 0 r
.83597 .42794 m .86145 .43821 L .86864 .43961 L p F P
0 g
s
.588 .618 .85 r
.65652 .35697 m .67868 .35595 L .68619 .36992 L p F P
0 g
s
.509 .599 .879 r
.67868 .35595 m .65652 .35697 L .64918 .3411 L p F P
0 g
s
.188 0 0 r
.32174 .47057 m .33558 .47 L .33897 .46619 L p F P
0 g
s
.185 0 0 r
.33558 .47 m .32174 .47057 L .31879 .47409 L p F P
0 g
s
.611 .951 .916 r
.48133 .4014 m .46194 .41178 L .45705 .41188 L p F P
0 g
s
.566 .934 .915 r
.43817 .42109 m .45705 .41188 L .46194 .41178 L p F P
0 g
s
.778 .883 .922 r
.55239 .36882 m .53204 .38245 L .52631 .37875 L p F P
0 g
s
.761 .872 .929 r
.50634 .39136 m .52631 .37875 L .53204 .38245 L p F P
0 g
s
.785 .779 .848 r
.62063 .33068 m .59985 .34614 L .59325 .33822 L p F P
0 g
s
.783 .779 .849 r
.5728 .35404 m .59325 .33822 L .59985 .34614 L p F P
0 g
s
.095 .546 .909 r
.80354 .4151 m .77915 .40953 L .7715 .4012 L p F P
0 g
s
.377 .661 .969 r
.74762 .39687 m .7715 .4012 L .77915 .40953 L p F P
0 g
s
.611 .616 .831 r
.62063 .33068 m .64186 .3268 L .64918 .3411 L p F P
0 g
s
.601 .721 .929 r
.64186 .3268 m .62063 .33068 L .61374 .32225 L p F P
0 g
s
.785 .779 .848 r
.59325 .33822 m .61374 .32225 L .62063 .33068 L p F P
0 g
s
.54 .636 .894 r
.68619 .36992 m .70896 .37129 L .71659 .3835 L p F P
0 g
s
.455 .608 .912 r
.70896 .37129 m .68619 .36992 L .67868 .35595 L p F P
0 g
s
.27 .602 .952 r
.7715 .4012 m .74762 .39687 L .73993 .38649 L p F P
0 g
s
.478 .654 .937 r
.71659 .3835 m .73993 .38649 L .74762 .39687 L p F P
0 g
s
.382 .613 .941 r
.73993 .38649 m .71659 .3835 L .70896 .37129 L p F P
0 g
s
.792 .901 .919 r
.5728 .35404 m .55239 .36882 L .54636 .36507 L p F P
0 g
s
.778 .883 .922 r
.52631 .37875 m .54636 .36507 L .55239 .36882 L p F P
0 g
s
.604 .038 0 r
.89466 .45146 m .92134 .46628 L .92807 .46399 L p F P
0 g
s
.738 .952 .946 r
.52631 .37875 m .50634 .39136 L .50086 .38989 L p F P
0 g
s
.716 .943 .956 r
.48133 .4014 m .50086 .38989 L .50634 .39136 L p F P
0 g
s
0 0 0 r
.38924 .44138 m .40657 .43487 L .41094 .43224 L p F P
0 g
s
0 0 0 r
.40657 .43487 m .38924 .44138 L .38521 .44436 L p F P
0 g
s
.509 .599 .879 r
.64918 .3411 m .67116 .34307 L .67868 .35595 L p F P
0 g
s
.389 .567 .907 r
.67116 .34307 m .64918 .3411 L .64186 .3268 L p F P
0 g
s
.121 0 0 r
.34232 .46257 m .35741 .45976 L .36116 .45602 L p F P
0 g
s
.124 0 0 r
.35741 .45976 m .34232 .46257 L .33897 .46619 L p F P
0 g
s
.355 0 0 r
.86145 .43821 m .83597 .42794 L .82849 .42401 L p F P
0 g
s
0 .418 .764 r
.80354 .4151 m .82849 .42401 L .83597 .42794 L p F P
0 g
s
.185 0 0 r
.31879 .47409 m .33216 .47397 L .33558 .47 L p F P
0 g
s
.181 0 0 r
.33216 .47397 m .31879 .47409 L .31581 .47774 L p F P
0 g
s
.796 .934 .922 r
.59325 .33822 m .5728 .35404 L .56649 .35049 L p F P
0 g
s
.792 .901 .919 r
.54636 .36507 m .56649 .35049 L .5728 .35404 L p F P
0 g
s
.027 0 0 r
.36488 .45254 m .38113 .44776 L .38521 .44436 L p F P
0 g
s
.042 0 0 r
.38113 .44776 m .36488 .45254 L .36116 .45602 L p F P
0 g
s
.647 .964 .912 r
.50086 .38989 m .48133 .4014 L .4761 .40151 L p F P
0 g
s
.611 .951 .916 r
.45705 .41188 m .4761 .40151 L .48133 .4014 L p F P
0 g
s
0 0 0 r
.42889 .42436 m .41094 .43224 L .40657 .43487 L p F P
0 g
s
.725 .98 .913 r
.61374 .32225 m .59325 .33822 L .5867 .33546 L p F P
0 g
s
.796 .934 .922 r
.56649 .35049 m .5867 .33546 L .59325 .33822 L p F P
0 g
s
.513 .912 .819 r
.4761 .40151 m .45705 .41188 L .45209 .41313 L p F P
0 g
s
.753 .962 .935 r
.54636 .36507 m .52631 .37875 L .52052 .37731 L p F P
0 g
s
.738 .952 .946 r
.50086 .38989 m .52052 .37731 L .52631 .37875 L p F P
0 g
s
.455 .608 .912 r
.67868 .35595 m .7013 .35973 L .70896 .37129 L p F P
0 g
s
.363 .573 .92 r
.7013 .35973 m .67868 .35595 L .67116 .34307 L p F P
0 g
s
0 .387 .764 r
.82849 .42401 m .80354 .4151 L .79589 .40886 L p F P
0 g
s
.095 .546 .909 r
.7715 .4012 m .79589 .40886 L .80354 .4151 L p F P
0 g
s
.389 .567 .907 r
.64186 .3268 m .66366 .3317 L .67116 .34307 L p F P
0 g
s
.334 .587 .936 r
.66366 .3317 m .64186 .3268 L .63468 .31786 L p F P
0 g
s
.601 .721 .929 r
.61374 .32225 m .63468 .31786 L .64186 .3268 L p F P
0 g
s
.608 .887 .99 r
.63468 .31786 m .61374 .32225 L .607 .32171 L p F P
0 g
s
.725 .98 .913 r
.5867 .33546 m .607 .32171 L .61374 .32225 L p F P
0 g
s
.577 0 0 r
.92134 .46628 m .89466 .45146 L .88754 .45136 L p F P
0 g
s
.506 0 0 r
.86145 .43821 m .88754 .45136 L .89466 .45146 L p F P
0 g
s
.382 .613 .941 r
.70896 .37129 m .73219 .37646 L .73993 .38649 L p F P
0 g
s
.299 .57 .934 r
.73219 .37646 m .70896 .37129 L .7013 .35973 L p F P
0 g
s
.124 0 0 r
.33897 .46619 m .35361 .46374 L .35741 .45976 L p F P
0 g
s
.123 0 0 r
.35361 .46374 m .33897 .46619 L .33558 .47 L p F P
0 g
s
0 0 0 r
.38521 .44436 m .40215 .43803 L .40657 .43487 L p F P
0 g
s
0 0 0 r
.40215 .43803 m .38521 .44436 L .38113 .44776 L p F P
0 g
s
.181 0 0 r
.31581 .47774 m .32871 .47809 L .33216 .47397 L p F P
0 g
s
.04 .495 .885 r
.79589 .40886 m .7715 .4012 L .76376 .39293 L p F P
0 g
s
.27 .602 .952 r
.73993 .38649 m .76376 .39293 L .7715 .4012 L p F P
0 g
s
.757 .974 .923 r
.56649 .35049 m .54636 .36507 L .54028 .36377 L p F P
0 g
s
.753 .962 .935 r
.52052 .37731 m .54028 .36377 L .54636 .36507 L p F P
0 g
s
.675 .973 .905 r
.52052 .37731 m .50086 .38989 L .49531 .39003 L p F P
0 g
s
.647 .964 .912 r
.4761 .40151 m .49531 .39003 L .50086 .38989 L p F P
0 g
s
.195 .55 .931 r
.76376 .39293 m .73993 .38649 L .73219 .37646 L p F P
0 g
s
.042 0 0 r
.36116 .45602 m .377 .4515 L .38113 .44776 L p F P
0 g
s
.049 0 0 r
.377 .4515 m .36116 .45602 L .35741 .45976 L p F P
0 g
s
.563 .935 .83 r
.49531 .39003 m .4761 .40151 L .4708 .4028 L p F P
0 g
s
.513 .912 .819 r
.45209 .41313 m .4708 .4028 L .4761 .40151 L p F P
0 g
s
0 0 0 r
.40657 .43487 m .42415 .42711 L .42889 .42436 L p F P
0 g
s
0 0 0 r
.42415 .42711 m .40657 .43487 L .40215 .43803 L p F P
0 g
s
.363 .573 .92 r
.67116 .34307 m .69361 .34877 L .7013 .35973 L p F P
0 g
s
.292 .547 .92 r
.69361 .34877 m .67116 .34307 L .66366 .3317 L p F P
0 g
s
.74 .983 .907 r
.5867 .33546 m .56649 .35049 L .56015 .34953 L p F P
0 g
s
.757 .974 .923 r
.54028 .36377 m .56015 .34953 L .56649 .35049 L p F P
0 g
s
.472 0 0 r
.88754 .45136 m .86145 .43821 L .85401 .43571 L p F P
0 g
s
.355 0 0 r
.82849 .42401 m .85401 .43571 L p .85004 .43329 L F P
0 g
s
.323 0 0 r
.85401 .43571 m .82849 .42401 L .82082 .41925 L p F P
0 g
s
.425 0 0 r
.85401 .43571 m .84631 .43198 L p .85804 .43817 L F P
0 g
s
.425 0 0 r
.88012 .44982 m .85401 .43571 L p .85804 .43817 L F P
0 g
s
.355 0 0 r
.85401 .43571 m .86145 .43821 L p .85004 .43329 L F P
0 g
s
.694 .979 .895 r
.54028 .36377 m .52052 .37731 L .51466 .37751 L p F P
0 g
s
.675 .973 .905 r
.49531 .39003 m .51466 .37751 L .52052 .37731 L p F P
0 g
s
.123 0 0 r
.33558 .47 m .34978 .46793 L .35361 .46374 L p F P
0 g
s
.12 0 0 r
.34978 .46793 m .33558 .47 L .33216 .47397 L p F P
0 g
s
.334 .587 .936 r
.63468 .31786 m .65618 .32227 L .66366 .3317 L p F P
0 g
s
.408 .686 .975 r
.65618 .32227 m .63468 .31786 L .62761 .31431 L p F P
0 g
s
.608 .887 .99 r
.607 .32171 m .62761 .31431 L .63468 .31786 L p F P
0 g
s
.682 .977 .894 r
.607 .32171 m .5867 .33546 L .5801 .33511 L p F P
0 g
s
.74 .983 .907 r
.56015 .34953 m .5801 .33511 L .5867 .33546 L p F P
0 g
s
.299 .57 .934 r
.7013 .35973 m .72438 .36653 L .73219 .37646 L p F P
0 g
s
.242 .536 .922 r
.72438 .36653 m .7013 .35973 L .69361 .34877 L p F P
0 g
s
0 0 0 r
.38113 .44776 m .39767 .44163 L .40215 .43803 L p F P
0 g
s
0 0 0 r
.39767 .44163 m .38113 .44776 L .377 .4515 L p F P
0 g
s
.049 0 0 r
.35741 .45976 m .37282 .45553 L .377 .4515 L p F P
0 g
s
.052 0 0 r
.37282 .45553 m .35741 .45976 L .35361 .46374 L p F P
0 g
s
0 .387 .764 r
.79589 .40886 m .82082 .41925 L .82849 .42401 L p F P
0 g
s
.604 .952 .837 r
.51466 .37751 m .49531 .39003 L .48969 .39135 L p F P
0 g
s
.563 .935 .83 r
.4708 .4028 m .48969 .39135 L .49531 .39003 L p F P
0 g
s
.195 .55 .931 r
.73219 .37646 m .75591 .38442 L .76376 .39293 L p F P
0 g
s
.153 .514 .914 r
.75591 .38442 m .73219 .37646 L .72438 .36653 L p F P
0 g
s
.702 .983 .884 r
.56015 .34953 m .54028 .36377 L .53414 .36409 L p F P
0 g
s
.694 .979 .895 r
.51466 .37751 m .53414 .36409 L .54028 .36377 L p F P
0 g
s
.624 .933 .965 r
.62761 .31431 m .607 .32171 L .60019 .32184 L p F P
0 g
s
.682 .977 .894 r
.5801 .33511 m .60019 .32184 L .607 .32171 L p F P
0 g
s
0 .378 .78 r
.82082 .41925 m .79589 .40886 L .78809 .40209 L p F P
0 g
s
.04 .495 .885 r
.76376 .39293 m .78809 .40209 L .79589 .40886 L p F P
0 g
s
.292 .547 .92 r
.66366 .3317 m .68587 .33834 L .69361 .34877 L p F P
0 g
s
.271 .549 .926 r
.68587 .33834 m .66366 .3317 L .65618 .32227 L p F P
0 g
s
.022 .465 .875 r
.78809 .40209 m .76376 .39293 L .75591 .38442 L p F P
0 g
s
0 0 0 r
.40215 .43803 m .41935 .4304 L .42415 .42711 L p F P
0 g
s
0 0 0 r
.41935 .4304 m .40215 .43803 L .39767 .44163 L p F P
0 g
s
.577 0 0 r
.88754 .45136 m .91427 .46701 L .92134 .46628 L p F P
0 g
s
.494 .893 .75 r
.48969 .39135 m .4708 .4028 L .46544 .40498 L p F P
0 g
s
.12 0 0 r
.33216 .47397 m .3459 .47229 L .34978 .46793 L p F P
0 g
s
.116 0 0 r
.3459 .47229 m .33216 .47397 L .32871 .47809 L p F P
0 g
s
0 0 0 r
.44197 .41809 m .42415 .42711 L .41935 .4304 L p F P
0 g
s
.696 .982 .875 r
.5801 .33511 m .56015 .34953 L .55373 .35001 L p F P
0 g
s
.702 .983 .884 r
.53414 .36409 m .55373 .35001 L .56015 .34953 L p F P
0 g
s
0 0 0 r
.377 .4515 m .39314 .44557 L .39767 .44163 L p F P
0 g
s
0 0 0 r
.39314 .44557 m .377 .4515 L .37282 .45553 L p F P
0 g
s
.637 .964 .84 r
.53414 .36409 m .51466 .37751 L .50874 .37886 L p F P
0 g
s
.604 .952 .837 r
.48969 .39135 m .50874 .37886 L .51466 .37751 L p F P
0 g
s
.052 0 0 r
.35361 .46374 m .36859 .45981 L .37282 .45553 L p F P
0 g
s
.051 0 0 r
.36859 .45981 m .35361 .46374 L .34978 .46793 L p F P
0 g
s
.242 .536 .922 r
.69361 .34877 m .71649 .35654 L .72438 .36653 L p F P
0 g
s
.216 .518 .915 r
.71649 .35654 m .69361 .34877 L .68587 .33834 L p F P
0 g
s
.54 0 0 r
.91427 .46701 m .88754 .45136 L .88012 .44982 L p F P
0 g
s
.472 0 0 r
.85401 .43571 m .88012 .44982 L .88754 .45136 L p F P
0 g
s
.408 .686 .975 r
.62761 .31431 m .6487 .31477 L .65618 .32227 L p F P
0 g
s
.505 .785 .995 r
.6487 .31477 m .62761 .31431 L .6205 .31238 L p F P
0 g
s
.624 .933 .965 r
.60019 .32184 m .6205 .31238 L .62761 .31431 L p F P
0 g
s
.68 .977 .886 r
.60019 .32184 m .5801 .33511 L .57344 .33573 L p F P
0 g
s
.696 .982 .875 r
.55373 .35001 m .57344 .33573 L .5801 .33511 L p F P
0 g
s
.116 0 0 r
.32871 .47809 m .34198 .47681 L .3459 .47229 L p F P
0 g
s
.55 .922 .773 r
.50874 .37886 m .48969 .39135 L .484 .39354 L p F P
0 g
s
.494 .893 .75 r
.46544 .40498 m .484 .39354 L .48969 .39135 L p F P
0 g
s
0 0 0 r
.39767 .44163 m .41449 .43413 L .41935 .4304 L p F P
0 g
s
0 0 0 r
.41449 .43413 m .39767 .44163 L .39314 .44557 L p F P
0 g
s
.153 .514 .914 r
.72438 .36653 m .74794 .37547 L .75591 .38442 L p F P
0 g
s
.14 .493 .905 r
.74794 .37547 m .72438 .36653 L .71649 .35654 L p F P
0 g
s
.271 .549 .926 r
.65618 .32227 m .67808 .32841 L .68587 .33834 L p F P
0 g
s
.307 .587 .942 r
.67808 .32841 m .65618 .32227 L .6487 .31477 L p F P
0 g
s
.662 .973 .843 r
.55373 .35001 m .53414 .36409 L .52792 .36545 L p F P
0 g
s
.637 .964 .84 r
.50874 .37886 m .52792 .36545 L .53414 .36409 L p F P
0 g
s
.323 0 0 r
.84631 .43198 m .85401 .43571 L p .84073 .42913 L F P
0 g
s
.365 0 0 r
.84631 .43198 m .83836 .42692 L p .85199 .43487 L F P
0 g
s
.425 0 0 r
.8724 .44679 m .88012 .44982 L p .86437 .44151 L F P
0 g
s
.425 0 0 r
.84631 .43198 m .8724 .44679 L p .86437 .44151 L F P
0 g
s
.365 0 0 r
.8724 .44679 m .84631 .43198 L p .85199 .43487 L F P
0 g
s
.43 0 0 r
.8724 .44679 m .86437 .4422 L p .88057 .45216 L F P
0 g
s
.43 0 0 r
.89911 .46357 m .8724 .44679 L p .88057 .45216 L F P
0 g
s
.323 0 0 r
.82082 .41925 m .84631 .43198 L p .84073 .42913 L F P
0 g
s
.447 .856 .687 r
.484 .39354 m .46544 .40498 L .46 .40784 L p F P
0 g
s
.022 .465 .875 r
.75591 .38442 m .78012 .39458 L .78809 .40209 L p F P
0 g
s
.029 .451 .874 r
.78012 .39458 m .75591 .38442 L .74794 .37547 L p F P
0 g
s
0 0 0 r
.41935 .4304 m .4368 .42146 L .44197 .41809 L p F P
0 g
s
0 0 0 r
.4368 .42146 m .41935 .4304 L .41449 .43413 L p F P
0 g
s
0 .278 .681 r
.84631 .43198 m .82082 .41925 L .81295 .41351 L p F P
0 g
s
0 .378 .78 r
.78809 .40209 m .81295 .41351 L .82082 .41925 L p F P
0 g
s
.051 0 0 r
.34978 .46793 m .36432 .4643 L .36859 .45981 L p F P
0 g
s
.048 0 0 r
.36432 .4643 m .34978 .46793 L .3459 .47229 L p F P
0 g
s
0 0 0 r
.37282 .45553 m .38855 .44983 L .39314 .44557 L p F P
0 g
s
0 0 0 r
.38855 .44983 m .37282 .45553 L .36859 .45981 L p F P
0 g
s
.659 .955 .946 r
.6205 .31238 m .60019 .32184 L .59327 .32218 L p F P
0 g
s
.68 .977 .886 r
.57344 .33573 m .59327 .32218 L .60019 .32184 L p F P
0 g
s
0 .38 .803 r
.81295 .41351 m .78809 .40209 L .78012 .39458 L p F P
0 g
s
.216 .518 .915 r
.68587 .33834 m .7085 .34636 L .71649 .35654 L p F P
0 g
s
.221 .518 .914 r
.7085 .34636 m .68587 .33834 L .67808 .32841 L p F P
0 g
s
.678 .978 .852 r
.57344 .33573 m .55373 .35001 L .54724 .35133 L p F P
0 g
s
.662 .973 .843 r
.52792 .36545 m .54724 .35133 L .55373 .35001 L p F P
0 g
s
.599 .945 .793 r
.52792 .36545 m .50874 .37886 L .50273 .38102 L p F P
0 g
s
.55 .922 .773 r
.484 .39354 m .50273 .38102 L .50874 .37886 L p F P
0 g
s
0 0 0 r
.39314 .44557 m .40956 .43823 L .41449 .43413 L p F P
0 g
s
0 0 0 r
.40956 .43823 m .39314 .44557 L .38855 .44983 L p F P
0 g
s
.14 .493 .905 r
.71649 .35654 m .73983 .36594 L .74794 .37547 L p F P
0 g
s
.148 .485 .901 r
.73983 .36594 m .71649 .35654 L .7085 .34636 L p F P
0 g
s
.515 .897 .724 r
.50273 .38102 m .484 .39354 L .47823 .39638 L p F P
0 g
s
.447 .856 .687 r
.46 .40784 m .47823 .39638 L .484 .39354 L p F P
0 g
s
.307 .587 .942 r
.6487 .31477 m .67024 .31899 L .67808 .32841 L p F P
0 g
s
.384 .648 .961 r
.67024 .31899 m .6487 .31477 L .64119 .30883 L p F P
0 g
s
.505 .785 .995 r
.6205 .31238 m .64119 .30883 L .6487 .31477 L p F P
0 g
s
.591 .856 .994 r
.64119 .30883 m .6205 .31238 L .6133 .31098 L p F P
0 g
s
.659 .955 .946 r
.59327 .32218 m .6133 .31098 L .6205 .31238 L p F P
0 g
s
.048 0 0 r
.3459 .47229 m .36 .469 L .36432 .4643 L p F P
0 g
s
.043 0 0 r
.36 .469 m .3459 .47229 L .34198 .47681 L p F P
0 g
s
.54 0 0 r
.88012 .44982 m .90686 .46612 L .91427 .46701 L p F P
0 g
s
.69 .981 .878 r
.59327 .32218 m .57344 .33573 L .56668 .33686 L p F P
0 g
s
.678 .978 .852 r
.54724 .35133 m .56668 .33686 L .57344 .33573 L p F P
0 g
s
0 0 0 r
.36859 .45981 m .3839 .45434 L .38855 .44983 L p F P
0 g
s
0 0 0 r
.3839 .45434 m .36859 .45981 L .36432 .4643 L p F P
0 g
s
0 0 0 r
.41449 .43413 m .43157 .42527 L .4368 .42146 L p F P
0 g
s
0 0 0 r
.43157 .42527 m .41449 .43413 L .40956 .43823 L p F P
0 g
s
.64 .963 .812 r
.54724 .35133 m .52792 .36545 L .52163 .36751 L p F P
0 g
s
.599 .945 .793 r
.50273 .38102 m .52163 .36751 L .52792 .36545 L p F P
0 g
s
0 0 0 r
.45448 .41123 m .4368 .42146 L .43157 .42527 L p F P
0 g
s
.029 .451 .874 r
.74794 .37547 m .77198 .3862 L .78012 .39458 L p F P
0 g
s
.052 .447 .877 r
.77198 .3862 m .74794 .37547 L .73983 .36594 L p F P
0 g
s
.221 .518 .914 r
.67808 .32841 m .70042 .33594 L .7085 .34636 L p F P
0 g
s
.254 .536 .92 r
.70042 .33594 m .67808 .32841 L .67024 .31899 L p F P
0 g
s
.491 0 0 r
.90686 .46612 m .88012 .44982 L .8724 .44679 L p F P
0 g
s
0 .38 .803 r
.78012 .39458 m .80486 .40664 L .81295 .41351 L p F P
0 g
s
0 .389 .826 r
.80486 .40664 m .78012 .39458 L .77198 .3862 L p F P
0 g
s
.694 .969 .931 r
.6133 .31098 m .59327 .32218 L .58626 .32269 L p F P
0 g
s
.69 .981 .878 r
.56668 .33686 m .58626 .32269 L .59327 .32218 L p F P
0 g
s
0 .278 .681 r
.81295 .41351 m .83836 .42692 L .84631 .43198 L p F P
0 g
s
0 .305 .734 r
.83836 .42692 m .81295 .41351 L .80486 .40664 L p F P
0 g
s
0 0 0 r
.38855 .44983 m .40458 .44264 L .40956 .43823 L p F P
0 g
s
0 0 0 r
.40458 .44264 m .38855 .44983 L .3839 .45434 L p F P
0 g
s
.576 .93 .758 r
.52163 .36751 m .50273 .38102 L .49665 .38376 L p F P
0 g
s
.515 .897 .724 r
.47823 .39638 m .49665 .38376 L .50273 .38102 L p F P
0 g
s
.675 .976 .835 r
.56668 .33686 m .54724 .35133 L .54066 .35319 L p F P
0 g
s
.64 .963 .812 r
.52163 .36751 m .54066 .35319 L .54724 .35133 L p F P
0 g
s
.043 0 0 r
.34198 .47681 m .35563 .47387 L .36 .469 L p F P
0 g
s
0 0 0 r
.36432 .4643 m .3792 .45909 L .3839 .45434 L p F P
0 g
s
0 0 0 r
.3792 .45909 m .36432 .4643 L .36 .469 L p F P
0 g
s
.148 .485 .901 r
.7085 .34636 m .73159 .35574 L .73983 .36594 L p F P
0 g
s
.173 .487 .901 r
.73159 .35574 m .7085 .34636 L .70042 .33594 L p F P
0 g
s
.495 .879 .688 r
.49665 .38376 m .47823 .39638 L .47238 .39972 L p F P
0 g
s
0 0 0 r
.40956 .43823 m .42627 .42945 L .43157 .42527 L p F P
0 g
s
0 0 0 r
.42627 .42945 m .40956 .43823 L .40458 .44264 L p F P
0 g
s
.384 .648 .961 r
.64119 .30883 m .66234 .3101 L .67024 .31899 L p F P
0 g
s
.477 .717 .975 r
.66234 .3101 m .64119 .30883 L .63363 .30401 L p F P
0 g
s
.591 .856 .994 r
.6133 .31098 m .63363 .30401 L .64119 .30883 L p F P
0 g
s
0 0 0 r
.43157 .42527 m .4489 .41505 L .45448 .41123 L p F P
0 g
s
0 0 0 r
.4489 .41505 m .43157 .42527 L .42627 .42945 L p F P
0 g
s
.66 .903 .98 r
.63363 .30401 m .6133 .31098 L .606 .30991 L p F P
0 g
s
.694 .969 .931 r
.58626 .32269 m .606 .30991 L .6133 .31098 L p F P
0 g
s
.704 .985 .868 r
.58626 .32269 m .56668 .33686 L .55983 .33833 L p F P
0 g
s
.675 .976 .835 r
.54066 .35319 m .55983 .33833 L .56668 .33686 L p F P
0 g
s
.254 .536 .92 r
.67024 .31899 m .69224 .32526 L .70042 .33594 L p F P
0 g
s
.31 .568 .93 r
.69224 .32526 m .67024 .31899 L .66234 .3101 L p F P
0 g
s
.631 .956 .789 r
.54066 .35319 m .52163 .36751 L .51524 .37008 L p F P
0 g
s
.576 .93 .758 r
.49665 .38376 m .51524 .37008 L .52163 .36751 L p F P
0 g
s
.052 .447 .877 r
.73983 .36594 m .76367 .37686 L .77198 .3862 L p F P
0 g
s
.086 .449 .882 r
.76367 .37686 m .73983 .36594 L .73159 .35574 L p F P
0 g
s
0 0 0 r
.3839 .45434 m .39953 .44733 L .40458 .44264 L p F P
0 g
s
0 0 0 r
.39953 .44733 m .3839 .45434 L .3792 .45909 L p F P
0 g
s
0 0 0 r
.36 .469 m .37445 .46406 L .3792 .45909 L p F P
0 g
s
0 0 0 r
.37445 .46406 m .36 .469 L .35563 .47387 L p F P
0 g
s
0 .389 .826 r
.77198 .3862 m .79655 .39859 L .80486 .40664 L p F P
0 g
s
0 .4 .845 r
.79655 .39859 m .77198 .3862 L .76367 .37686 L p F P
0 g
s
.565 .92 .731 r
.51524 .37008 m .49665 .38376 L .49048 .38698 L p F P
0 g
s
.495 .879 .688 r
.47238 .39972 m .49048 .38698 L .49665 .38376 L p F P
0 g
s
.491 0 0 r
.8724 .44679 m .89911 .46357 L .90686 .46612 L p F P
0 g
s
.173 .487 .901 r
.70042 .33594 m .72322 .34481 L .73159 .35574 L p F P
0 g
s
.211 .498 .904 r
.72322 .34481 m .70042 .33594 L .69224 .32526 L p F P
0 g
s
.724 .979 .915 r
.606 .30991 m .58626 .32269 L .57914 .32339 L p F P
0 g
s
.704 .985 .868 r
.55983 .33833 m .57914 .32339 L .58626 .32269 L p F P
0 g
s
0 0 0 r
.40458 .44264 m .4209 .43395 L .42627 .42945 L p F P
0 g
s
0 0 0 r
.4209 .43395 m .40458 .44264 L .39953 .44733 L p F P
0 g
s
.679 .976 .821 r
.55983 .33833 m .54066 .35319 L .53399 .35545 L p F P
0 g
s
.631 .956 .789 r
.51524 .37008 m .53399 .35545 L .54066 .35319 L p F P
0 g
s
0 .305 .734 r
.80486 .40664 m .83015 .42047 L .83836 .42692 L p F P
0 g
s
0 .331 .778 r
.83015 .42047 m .80486 .40664 L .79655 .39859 L p F P
0 g
s
.365 0 0 r
.86437 .4422 m .8724 .44679 L p .85553 .43694 L F P
0 g
s
0 .187 .621 r
.86437 .4422 m .85605 .43602 L p .87338 .44756 L F P
0 g
s
.43 0 0 r
.86437 .4422 m .89102 .45931 L .89911 .46357 L p F P
0 g
s
0 .187 .621 r
.89102 .45931 m .86437 .4422 L p .87338 .44756 L F P
0 g
s
.365 0 0 r
.83836 .42692 m .86437 .4422 L p .85553 .43694 L F P
0 g
s
0 .241 .673 r
.86437 .4422 m .83836 .42692 L .83015 .42047 L p F P
0 g
s
.484 .866 .661 r
.49048 .38698 m .47238 .39972 L .46645 .40348 L p F P
0 g
s
.401 .811 .606 r
.4489 .41505 m .46645 .40348 L p .46762 .40283 L F P
0 g
s
0 0 0 r
.46645 .40348 m .4489 .41505 L .44323 .41924 L p F P
0 g
s
0 0 0 r
.46044 .40759 m .46645 .40348 L p .46251 .40615 L F P
0 g
s
0 0 0 r
.44323 .41924 m .46044 .40759 L p .46251 .40615 L F P
0 g
s
0 0 0 r
.46044 .40759 m .44323 .41924 L .43749 .42375 L p F P
0 g
s
0 0 0 r
.45434 .41202 m .46044 .40759 L p .45709 .40995 L F P
0 g
s
0 0 0 r
.43749 .42375 m .45434 .41202 L p .45709 .40995 L F P
0 g
s
0 0 0 r
.44815 .41675 m .45434 .41202 L p .4514 .41416 L F P
0 g
s
0 0 0 r
.43167 .42855 m .44815 .41675 L p .4514 .41416 L F P
0 g
s
0 0 0 r
.44188 .42176 m .44815 .41675 L p .44551 .41874 L F P
0 g
s
0 0 0 r
.42576 .43362 m .44188 .42176 L p .44551 .41874 L F P
0 g
s
.492 .846 .585 r
.44188 .42176 m .43551 .42704 L p .43819 .42482 L F P
0 g
s
0 0 0 r
.45434 .41202 m .43749 .42375 L .43167 .42855 L p F P
0 g
s
0 0 0 r
.44815 .41675 m .43167 .42855 L .42576 .43362 L p F P
0 g
s
.488 .848 .597 r
.44188 .42176 m .45826 .40818 L .4649 .40333 L p F P
0 g
s
.492 .846 .585 r
.45826 .40818 m .44188 .42176 L p .43819 .42482 L F P
0 g
s
.488 .848 .597 r
.44815 .41675 m .44188 .42176 L p .44486 .41937 L F P
0 g
s
.488 .848 .597 r
.4649 .40333 m .44815 .41675 L p .44486 .41937 L F P
0 g
s
.483 .85 .609 r
.45434 .41202 m .44815 .41675 L p .45156 .41412 L F P
0 g
s
.483 .85 .609 r
.47144 .39877 m .45434 .41202 L p .45156 .41412 L F P
0 g
s
.481 .853 .623 r
.46044 .40759 m .45434 .41202 L p .45834 .40905 L F P
0 g
s
.481 .853 .623 r
.47788 .39452 m .46044 .40759 L p .45834 .40905 L F P
0 g
s
.48 .859 .64 r
.46645 .40348 m .46044 .40759 L p .46527 .40413 L F P
0 g
s
.48 .859 .64 r
.48422 .39058 m .46645 .40348 L p .46527 .40413 L F P
0 g
s
.401 .811 .606 r
.46645 .40348 m .47238 .39972 L p .46762 .40283 L F P
0 g
s
.477 .717 .975 r
.63363 .30401 m .65438 .30182 L .66234 .3101 L p F P
0 g
s
.569 .781 .978 r
.65438 .30182 m .63363 .30401 L .626 .30002 L p F P
0 g
s
.66 .903 .98 r
.606 .30991 m .626 .30002 L .63363 .30401 L p F P
0 g
s
0 0 0 r
.42627 .42945 m .44323 .41924 L .4489 .41505 L p F P
0 g
s
0 0 0 r
.44323 .41924 m .42627 .42945 L .4209 .43395 L p F P
0 g
s
.31 .568 .93 r
.66234 .3101 m .68396 .31439 L .69224 .32526 L p F P
0 g
s
.383 .612 .94 r
.68396 .31439 m .66234 .3101 L .65438 .30182 L p F P
0 g
s
.086 .449 .882 r
.73159 .35574 m .75518 .36649 L .76367 .37686 L p F P
0 g
s
.126 .456 .886 r
.75518 .36649 m .73159 .35574 L .72322 .34481 L p F P
0 g
s
0 0 0 r
.3792 .45909 m .39441 .45226 L .39953 .44733 L p F P
0 g
s
0 0 0 r
.39441 .45226 m .3792 .45909 L .37445 .46406 L p F P
0 g
s
.629 .952 .771 r
.53399 .35545 m .51524 .37008 L .50876 .37306 L p F P
0 g
s
.565 .92 .731 r
.49048 .38698 m .50876 .37306 L .51524 .37008 L p F P
0 g
s
0 0 0 r
.35563 .47387 m .36963 .46922 L .37445 .46406 L p F P
0 g
s
.713 .934 .961 r
.626 .30002 m .606 .30991 L .5986 .30913 L p F P
0 g
s
.724 .979 .915 r
.57914 .32339 m .5986 .30913 L .606 .30991 L p F P
0 g
s
.719 .988 .857 r
.57914 .32339 m .55983 .33833 L .55288 .34008 L p F P
0 g
s
.679 .976 .821 r
.53399 .35545 m .55288 .34008 L .55983 .33833 L p F P
0 g
s
.211 .498 .904 r
.69224 .32526 m .71471 .33317 L .72322 .34481 L p F P
0 g
s
.26 .517 .907 r
.71471 .33317 m .69224 .32526 L .68396 .31439 L p F P
0 g
s
0 .4 .845 r
.76367 .37686 m .78803 .38928 L .79655 .39859 L p F P
0 g
s
.028 .412 .86 r
.78803 .38928 m .76367 .37686 L .75518 .36649 L p F P
0 g
s
0 0 0 r
.39953 .44733 m .41545 .43874 L .4209 .43395 L p F P
0 g
s
0 0 0 r
.41545 .43874 m .39953 .44733 L .39441 .45226 L p F P
0 g
s
.562 .913 .711 r
.50876 .37306 m .49048 .38698 L .48422 .39058 L p F P
0 g
s
.484 .866 .661 r
.46645 .40348 m .48422 .39058 L .49048 .38698 L p F P
0 g
s
.748 .987 .899 r
.5986 .30913 m .57914 .32339 L .57192 .32431 L p F P
0 g
s
.719 .988 .857 r
.55288 .34008 m .57192 .32431 L .57914 .32339 L p F P
0 g
s
0 0 0 r
.4209 .43395 m .43749 .42375 L .44323 .41924 L p F P
0 g
s
0 0 0 r
.43749 .42375 m .4209 .43395 L .41545 .43874 L p F P
0 g
s
.685 .977 .808 r
.55288 .34008 m .53399 .35545 L .52722 .35806 L p F P
0 g
s
.629 .952 .771 r
.50876 .37306 m .52722 .35806 L .53399 .35545 L p F P
0 g
s
0 .331 .778 r
.79655 .39859 m .82169 .41258 L .83015 .42047 L p F P
0 g
s
0 .355 .812 r
.82169 .41258 m .79655 .39859 L .78803 .38928 L p F P
0 g
s
0 0 0 r
.37445 .46406 m .38923 .45742 L .39441 .45226 L p F P
0 g
s
0 0 0 r
.38923 .45742 m .37445 .46406 L .36963 .46922 L p F P
0 g
s
.383 .612 .94 r
.65438 .30182 m .67559 .30345 L .68396 .31439 L p F P
0 g
s
.466 .662 .947 r
.67559 .30345 m .65438 .30182 L .64634 .29422 L p F P
0 g
s
.569 .781 .978 r
.626 .30002 m .64634 .29422 L .65438 .30182 L p F P
0 g
s
.649 .834 .972 r
.64634 .29422 m .626 .30002 L .61828 .29669 L p F P
0 g
s
.713 .934 .961 r
.5986 .30913 m .61828 .29669 L .626 .30002 L p F P
0 g
s
.126 .456 .886 r
.72322 .34481 m .74652 .35507 L .75518 .36649 L p F P
0 g
s
.171 .466 .888 r
.74652 .35507 m .72322 .34481 L .71471 .33317 L p F P
0 g
s
0 .241 .673 r
.83015 .42047 m .85605 .43602 L .86437 .4422 L p F P
0 g
s
0 .279 .732 r
.85605 .43602 m .83015 .42047 L .82169 .41258 L p F P
0 g
s
.631 .95 .755 r
.52722 .35806 m .50876 .37306 L .50219 .37639 L p F P
0 g
s
.562 .913 .711 r
.48422 .39058 m .50219 .37639 L .50876 .37306 L p F P
0 g
s
.26 .517 .907 r
.68396 .31439 m .70607 .32083 L .71471 .33317 L p F P
0 g
s
.318 .542 .911 r
.70607 .32083 m .68396 .31439 L .67559 .30345 L p F P
0 g
s
.753 .955 .939 r
.61828 .29669 m .5986 .30913 L .5911 .30866 L p F P
0 g
s
.748 .987 .899 r
.57192 .32431 m .5911 .30866 L .5986 .30913 L p F P
0 g
s
.733 .991 .845 r
.57192 .32431 m .55288 .34008 L .54583 .34212 L p F P
0 g
s
.685 .977 .808 r
.52722 .35806 m .54583 .34212 L .55288 .34008 L p F P
0 g
s
0 0 0 r
.39441 .45226 m .40994 .44378 L .41545 .43874 L p F P
0 g
s
0 0 0 r
.40994 .44378 m .39441 .45226 L .38923 .45742 L p F P
0 g
s
.028 .412 .86 r
.75518 .36649 m .7793 .37868 L .78803 .38928 L p F P
0 g
s
.08 .423 .869 r
.7793 .37868 m .75518 .36649 L .74652 .35507 L p F P
0 g
s
.562 .909 .693 r
.50219 .37639 m .48422 .39058 L .47788 .39452 L p F P
0 g
s
.48 .859 .64 r
.46044 .40759 m .47788 .39452 L .48422 .39058 L p F P
0 g
s
0 0 0 r
.36963 .46922 m .38399 .4628 L .38923 .45742 L p F P
0 g
s
0 0 0 r
.41545 .43874 m .43167 .42855 L .43749 .42375 L p F P
0 g
s
0 0 0 r
.43167 .42855 m .41545 .43874 L .40994 .44378 L p F P
0 g
s
.171 .466 .888 r
.71471 .33317 m .73769 .34259 L .74652 .35507 L p F P
0 g
s
.218 .478 .89 r
.73769 .34259 m .71471 .33317 L .70607 .32083 L p F P
0 g
s
.466 .662 .947 r
.64634 .29422 m .66714 .2926 L .67559 .30345 L p F P
0 g
s
.551 .714 .948 r
.66714 .2926 m .64634 .29422 L .63824 .28739 L p F P
0 g
s
.649 .834 .972 r
.61828 .29669 m .63824 .28739 L .64634 .29422 L p F P
0 g
s
0 .355 .812 r
.78803 .38928 m .81297 .40322 L .82169 .41258 L p F P
0 g
s
0 .375 .835 r
.81297 .40322 m .78803 .38928 L .7793 .37868 L p F P
0 g
s
.693 .977 .795 r
.54583 .34212 m .52722 .35806 L .52035 .36098 L p F P
0 g
s
.631 .95 .755 r
.50219 .37639 m .52035 .36098 L .52722 .35806 L p F P
0 g
s
.769 .992 .882 r
.5911 .30866 m .57192 .32431 L .56458 .32549 L p F P
0 g
s
.733 .991 .845 r
.54583 .34212 m .56458 .32549 L .57192 .32431 L p F P
0 g
s
.714 .877 .957 r
.63824 .28739 m .61828 .29669 L .61046 .29396 L p F P
0 g
s
.753 .955 .939 r
.5911 .30866 m .61046 .29396 L .61828 .29669 L p F P
0 g
s
.318 .542 .911 r
.67559 .30345 m .6973 .30788 L .70607 .32083 L p F P
0 g
s
.384 .574 .914 r
.6973 .30788 m .67559 .30345 L .66714 .2926 L p F P
0 g
s
0 .279 .732 r
.82169 .41258 m .84743 .4282 L .85605 .43602 L p F P
0 g
s
0 .311 .778 r
.84743 .4282 m .82169 .41258 L .81297 .40322 L p F P
0 g
s
0 0 0 r
.38923 .45742 m .40435 .44907 L .40994 .44378 L p F P
0 g
s
0 0 0 r
.40435 .44907 m .38923 .45742 L .38399 .4628 L p F P
0 g
s
.636 .948 .74 r
.52035 .36098 m .50219 .37639 L .49552 .38004 L p F P
0 g
s
.562 .909 .693 r
.47788 .39452 m .49552 .38004 L .50219 .37639 L p F P
0 g
s
.08 .423 .869 r
.74652 .35507 m .77036 .36676 L .7793 .37868 L p F P
0 g
s
.13 .434 .873 r
.77036 .36676 m .74652 .35507 L .73769 .34259 L p F P
0 g
s
0 .187 .621 r
.85605 .43602 m .88259 .45329 L .89102 .45931 L p F P
0 g
s
0 .232 .691 r
.88259 .45329 m .85605 .43602 L .84743 .4282 L p F P
0 g
s
.785 .97 .917 r
.61046 .29396 m .5911 .30866 L .58348 .30852 L p F P
0 g
s
.769 .992 .882 r
.56458 .32549 m .58348 .30852 L .5911 .30866 L p F P
0 g
s
.745 .993 .831 r
.56458 .32549 m .54583 .34212 L .53866 .34445 L p F P
0 g
s
.693 .977 .795 r
.52035 .36098 m .53866 .34445 L .54583 .34212 L p F P
0 g
s
0 0 0 r
.40994 .44378 m .42576 .43362 L .43167 .42855 L p F P
0 g
s
0 0 0 r
.42576 .43362 m .40994 .44378 L .40435 .44907 L p F P
0 g
s
.565 .906 .679 r
.49552 .38004 m .47788 .39452 L .47144 .39877 L p F P
0 g
s
.481 .853 .623 r
.45434 .41202 m .47144 .39877 L .47788 .39452 L p F P
0 g
s
.218 .478 .89 r
.70607 .32083 m .72869 .32906 L .73769 .34259 L p F P
0 g
s
.269 .494 .889 r
.72869 .32906 m .70607 .32083 L .6973 .30788 L p F P
0 g
s
.551 .714 .948 r
.63824 .28739 m .6586 .28209 L .66714 .2926 L p F P
0 g
s
.632 .766 .944 r
.6586 .28209 m .63824 .28739 L .63006 .2814 L p F P
0 g
s
.714 .877 .957 r
.61046 .29396 m .63006 .2814 L .63824 .28739 L p F P
0 g
s
0 .375 .835 r
.7793 .37868 m .804 .39234 L .81297 .40322 L p F P
0 g
s
.034 .391 .85 r
.804 .39234 m .7793 .37868 L .77036 .36676 L p F P
0 g
s
.384 .574 .914 r
.66714 .2926 m .68842 .29445 L .6973 .30788 L p F P
0 g
s
.456 .612 .915 r
.68842 .29445 m .66714 .2926 L .6586 .28209 L p F P
0 g
s
.7 .977 .781 r
.53866 .34445 m .52035 .36098 L .51337 .36421 L p F P
0 g
s
.636 .948 .74 r
.49552 .38004 m .51337 .36421 L .52035 .36098 L p F P
0 g
s
0 0 0 r
.38399 .4628 m .39868 .45459 L .40435 .44907 L p F P
0 g
s
.785 .996 .865 r
.58348 .30852 m .56458 .32549 L .55714 .32696 L p F P
0 g
s
.745 .993 .831 r
.53866 .34445 m .55714 .32696 L .56458 .32549 L p F P
0 g
s
.766 .911 .938 r
.63006 .2814 m .61046 .29396 L .60254 .29182 L p F P
0 g
s
.785 .97 .917 r
.58348 .30852 m .60254 .29182 L .61046 .29396 L p F P
0 g
s
.13 .434 .873 r
.73769 .34259 m .76121 .35352 L .77036 .36676 L p F P
0 g
s
.179 .445 .874 r
.76121 .35352 m .73769 .34259 L .72869 .32906 L p F P
0 g
s
0 .311 .778 r
.81297 .40322 m .83852 .41872 L .84743 .4282 L p F P
0 g
s
0 .338 .81 r
.83852 .41872 m .81297 .40322 L .804 .39234 L p F P
0 g
s
.641 .947 .726 r
.51337 .36421 m .49552 .38004 L .48875 .38401 L p F P
0 g
s
.565 .906 .679 r
.47144 .39877 m .48875 .38401 L .49552 .38004 L p F P
0 g
s
.269 .494 .889 r
.6973 .30788 m .71954 .31452 L .72869 .32906 L p F P
0 g
s
.322 .513 .888 r
.71954 .31452 m .6973 .30788 L .68842 .29445 L p F P
0 g
s
0 0 0 r
.40435 .44907 m .41978 .43895 L .42576 .43362 L p F P
0 g
s
0 0 0 r
.41978 .43895 m .40435 .44907 L .39868 .45459 L p F P
0 g
s
0 .232 .691 r
.84743 .4282 m .87383 .44548 L .88259 .45329 L p F P
0 g
s
0 .27 .745 r
.87383 .44548 m .84743 .4282 L .83852 .41872 L p F P
0 g
s
.755 .994 .816 r
.55714 .32696 m .53866 .34445 L .53139 .34708 L p F P
0 g
s
.7 .977 .781 r
.51337 .36421 m .53139 .34708 L .53866 .34445 L p F P
0 g
s
.569 .903 .665 r
.48875 .38401 m .47144 .39877 L .4649 .40333 L p F P
0 g
s
.483 .85 .609 r
.44815 .41675 m .4649 .40333 L .47144 .39877 L p F P
0 g
s
.808 .98 .895 r
.60254 .29182 m .58348 .30852 L .57575 .30876 L p F P
0 g
s
.785 .996 .865 r
.55714 .32696 m .57575 .30876 L .58348 .30852 L p F P
0 g
s
0 0 0 r
.44188 .42176 m .42576 .43362 L .41978 .43895 L p F P
0 g
s
.456 .612 .915 r
.6586 .28209 m .67944 .28074 L .68842 .29445 L p F P
0 g
s
.533 .655 .914 r
.67944 .28074 m .6586 .28209 L .65 .2722 L p F P
0 g
s
.632 .766 .944 r
.63006 .2814 m .65 .2722 L .6586 .28209 L p F P
0 g
s
.034 .391 .85 r
.77036 .36676 m .79478 .37993 L .804 .39234 L p F P
0 g
s
.09 .404 .857 r
.79478 .37993 m .77036 .36676 L .76121 .35352 L p F P
0 g
s
.704 .815 .934 r
.65 .2722 m .63006 .2814 L .6218 .2763 L p F P
0 g
s
.766 .911 .938 r
.60254 .29182 m .6218 .2763 L .63006 .2814 L p F P
0 g
s
.179 .445 .874 r
.72869 .32906 m .75187 .33895 L .76121 .35352 L p F P
0 g
s
.227 .456 .872 r
.75187 .33895 m .72869 .32906 L .71954 .31452 L p F P
0 g
s
.707 .976 .767 r
.53139 .34708 m .51337 .36421 L .50628 .36775 L p F P
0 g
s
.641 .947 .726 r
.48875 .38401 m .50628 .36775 L .51337 .36421 L p F P
0 g
s
.322 .513 .888 r
.68842 .29445 m .71025 .29904 L .71954 .31452 L p F P
0 g
s
.38 .537 .886 r
.71025 .29904 m .68842 .29445 L .67944 .28074 L p F P
0 g
s
.805 .937 .916 r
.6218 .2763 m .60254 .29182 L .59452 .29026 L p F P
0 g
s
.808 .98 .895 r
.57575 .30876 m .59452 .29026 L .60254 .29182 L p F P
0 g
s
.798 .998 .847 r
.57575 .30876 m .55714 .32696 L .54957 .32877 L p F P
0 g
s
.755 .994 .816 r
.53139 .34708 m .54957 .32877 L .55714 .32696 L p F P
0 g
s
0 .338 .81 r
.804 .39234 m .82932 .40754 L .83852 .41872 L p F P
0 g
s
0 .358 .83 r
.82932 .40754 m .804 .39234 L .79478 .37993 L p F P
0 g
s
0 0 0 r
.39868 .45459 m .4137 .44453 L .41978 .43895 L p F P
0 g
s
.646 .945 .713 r
.50628 .36775 m .48875 .38401 L .48188 .38828 L p F P
0 g
s
.569 .903 .665 r
.4649 .40333 m .48188 .38828 L .48875 .38401 L p F P
0 g
s
.497 .844 .574 r
.43551 .42704 m .42904 .43261 L p .43151 .43049 L F P
0 g
s
0 0 0 r
.43551 .42704 m .44188 .42176 L p .43944 .42365 L F P
0 g
s
.492 .846 .585 r
.43551 .42704 m .45152 .41333 L .45826 .40818 L p F P
0 g
s
.497 .844 .574 r
.45152 .41333 m .43551 .42704 L p .43151 .43049 L F P
0 g
s
0 0 0 r
.41978 .43895 m .43551 .42704 L p .43944 .42365 L F P
0 g
s
0 0 0 r
.43551 .42704 m .41978 .43895 L .4137 .44453 L p F P
0 g
s
.573 .901 .652 r
.48188 .38828 m .4649 .40333 L .45826 .40818 L p F P
0 g
s
.533 .655 .914 r
.65 .2722 m .67037 .26704 L .67944 .28074 L p F P
0 g
s
.611 .703 .91 r
.67037 .26704 m .65 .2722 L .64133 .26321 L p F P
0 g
s
.704 .815 .934 r
.6218 .2763 m .64133 .26321 L .65 .2722 L p F P
0 g
s
.09 .404 .857 r
.76121 .35352 m .78533 .36597 L .79478 .37993 L p F P
0 g
s
.141 .415 .859 r
.78533 .36597 m .76121 .35352 L .75187 .33895 L p F P
0 g
s
0 .27 .745 r
.83852 .41872 m .86473 .43584 L .87383 .44548 L p F P
0 g
s
0 .301 .784 r
.86473 .43584 m .83852 .41872 L .82932 .40754 L p F P
0 g
s
.763 .994 .801 r
.54957 .32877 m .53139 .34708 L .524 .35004 L p F P
0 g
s
.707 .976 .767 r
.50628 .36775 m .524 .35004 L .53139 .34708 L p F P
0 g
s
.826 .988 .873 r
.59452 .29026 m .57575 .30876 L .5679 .30943 L p F P
0 g
s
.798 .998 .847 r
.54957 .32877 m .5679 .30943 L .57575 .30876 L p F P
0 g
s
.227 .456 .872 r
.71954 .31452 m .74234 .32306 L .75187 .33895 L p F P
0 g
s
.274 .468 .868 r
.74234 .32306 m .71954 .31452 L .71025 .29904 L p F P
0 g
s
.765 .859 .919 r
.64133 .26321 m .6218 .2763 L .61344 .27212 L p F P
0 g
s
.805 .937 .916 r
.59452 .29026 m .61344 .27212 L .6218 .2763 L p F P
0 g
s
.38 .537 .886 r
.67944 .28074 m .70082 .28274 L .71025 .29904 L p F P
0 g
s
.443 .566 .883 r
.70082 .28274 m .67944 .28074 L .67037 .26704 L p F P
0 g
s
.712 .975 .752 r
.524 .35004 m .50628 .36775 L .49908 .37162 L p F P
0 g
s
.646 .945 .713 r
.48188 .38828 m .49908 .37162 L .50628 .36775 L p F P
0 g
s
0 .358 .83 r
.79478 .37993 m .81984 .39464 L .82932 .40754 L p F P
0 g
s
.05 .374 .841 r
.81984 .39464 m .79478 .37993 L .78533 .36597 L p F P
0 g
s
.835 .956 .892 r
.61344 .27212 m .59452 .29026 L .58637 .28932 L p F P
0 g
s
.826 .988 .873 r
.5679 .30943 m .58637 .28932 L .59452 .29026 L p F P
0 g
s
.807 1 .828 r
.5679 .30943 m .54957 .32877 L .54188 .33095 L p F P
0 g
s
.763 .994 .801 r
.524 .35004 m .54188 .33095 L .54957 .32877 L p F P
0 g
s
.141 .415 .859 r
.75187 .33895 m .77565 .35046 L .78533 .36597 L p F P
0 g
s
.188 .424 .857 r
.77565 .35046 m .75187 .33895 L .74234 .32306 L p F P
0 g
s
.65 .943 .698 r
.49908 .37162 m .48188 .38828 L .47489 .39287 L p F P
0 g
s
.573 .901 .652 r
.45826 .40818 m .47489 .39287 L .48188 .38828 L p F P
0 g
s
.274 .468 .868 r
.71025 .29904 m .73264 .3059 L .74234 .32306 L p F P
0 g
s
.321 .482 .863 r
.73264 .3059 m .71025 .29904 L .70082 .28274 L p F P
0 g
s
0 0 0 r
.4137 .44453 m .42904 .43261 L .43551 .42704 L p F P
0 g
s
.611 .703 .91 r
.64133 .26321 m .66123 .25377 L .67037 .26704 L p F P
0 g
s
.687 .754 .902 r
.66123 .25377 m .64133 .26321 L .63258 .25537 L p F P
0 g
s
.765 .859 .919 r
.61344 .27212 m .63258 .25537 L .64133 .26321 L p F P
0 g
s
.577 .898 .639 r
.47489 .39287 m .45826 .40818 L .45152 .41333 L p F P
0 g
s
.443 .566 .883 r
.67037 .26704 m .69127 .26583 L .70082 .28274 L p F P
0 g
s
.513 .602 .88 r
.69127 .26583 m .67037 .26704 L .66123 .25377 L p F P
0 g
s
0 .301 .784 r
.82932 .40754 m .85531 .42434 L .86473 .43584 L p F P
0 g
s
0 .326 .809 r
.85531 .42434 m .82932 .40754 L .81984 .39464 L p F P
0 g
s
.769 .993 .784 r
.54188 .33095 m .524 .35004 L .51648 .35336 L p F P
0 g
s
.712 .975 .752 r
.49908 .37162 m .51648 .35336 L .524 .35004 L p F P
0 g
s
.814 .897 .901 r
.63258 .25537 m .61344 .27212 L .60498 .2689 L p F P
0 g
s
.835 .956 .892 r
.58637 .28932 m .60498 .2689 L .61344 .27212 L p F P
0 g
s
.839 .993 .851 r
.58637 .28932 m .5679 .30943 L .55992 .31055 L p F P
0 g
s
.807 1 .828 r
.54188 .33095 m .55992 .31055 L .5679 .30943 L p F P
0 g
s
.05 .374 .841 r
.78533 .36597 m .81009 .38 L .81984 .39464 L p F P
0 g
s
.103 .386 .844 r
.81009 .38 m .78533 .36597 L .77565 .35046 L p F P
0 g
s
.321 .482 .863 r
.70082 .28274 m .72276 .28751 L .73264 .3059 L p F P
0 g
s
.371 .5 .858 r
.72276 .28751 m .70082 .28274 L .69127 .26583 L p F P
0 g
s
.188 .424 .857 r
.74234 .32306 m .76575 .33339 L .77565 .35046 L p F P
0 g
s
.232 .432 .852 r
.76575 .33339 m .74234 .32306 L .73264 .3059 L p F P
0 g
s
.717 .972 .736 r
.51648 .35336 m .49908 .37162 L .49176 .37583 L p F P
0 g
s
.65 .943 .698 r
.47489 .39287 m .49176 .37583 L .49908 .37162 L p F P
0 g
s
.856 .971 .868 r
.60498 .2689 m .58637 .28932 L .5781 .28903 L p F P
0 g
s
.839 .993 .851 r
.55992 .31055 m .5781 .28903 L .58637 .28932 L p F P
0 g
s
.513 .602 .88 r
.66123 .25377 m .68161 .24861 L .69127 .26583 L p F P
0 g
s
.588 .646 .875 r
.68161 .24861 m .66123 .25377 L .65202 .24141 L p F P
0 g
s
.687 .754 .902 r
.63258 .25537 m .65202 .24141 L .66123 .25377 L p F P
0 g
s
.814 1 .809 r
.55992 .31055 m .54188 .33095 L .53406 .33353 L p F P
0 g
s
.769 .993 .784 r
.51648 .35336 m .53406 .33353 L .54188 .33095 L p F P
0 g
s
.757 .806 .892 r
.65202 .24141 m .63258 .25537 L .62376 .24888 L p F P
0 g
s
.814 .897 .901 r
.60498 .2689 m .62376 .24888 L .63258 .25537 L p F P
0 g
s
.653 .94 .684 r
.49176 .37583 m .47489 .39287 L .46779 .39779 L p F P
0 g
s
.577 .898 .639 r
.45152 .41333 m .46779 .39779 L .47489 .39287 L p F P
0 g
s
.497 .844 .574 r
.42904 .43261 m .44467 .41879 L .45152 .41333 L p F P
0 g
s
.581 .896 .626 r
.46779 .39779 m .45152 .41333 L .44467 .41879 L p F P
0 g
s
0 .326 .809 r
.81984 .39464 m .84558 .41095 L .85531 .42434 L p F P
0 g
s
.01 .344 .823 r
.84558 .41095 m .81984 .39464 L .81009 .38 L p F P
0 g
s
.371 .5 .858 r
.69127 .26583 m .71273 .268 L .72276 .28751 L p F P
0 g
s
.426 .522 .853 r
.71273 .268 m .69127 .26583 L .68161 .24861 L p F P
0 g
s
.232 .432 .852 r
.73264 .3059 m .75563 .31477 L .76575 .33339 L p F P
0 g
s
.273 .441 .846 r
.75563 .31477 m .73264 .3059 L .72276 .28751 L p F P
0 g
s
.103 .386 .844 r
.77565 .35046 m .80007 .3636 L .81009 .38 L p F P
0 g
s
.151 .394 .842 r
.80007 .3636 m .77565 .35046 L .76575 .33339 L p F P
0 g
s
.772 .991 .766 r
.53406 .33353 m .51648 .35336 L .50884 .35706 L p F P
0 g
s
.717 .972 .736 r
.49176 .37583 m .50884 .35706 L .51648 .35336 L p F P
0 g
s
.852 .928 .878 r
.62376 .24888 m .60498 .2689 L .59641 .26664 L p F P
0 g
s
.856 .971 .868 r
.5781 .28903 m .59641 .26664 L .60498 .2689 L p F P
0 g
s
.848 .996 .828 r
.5781 .28903 m .55992 .31055 L .55181 .31219 L p F P
0 g
s
.814 1 .809 r
.53406 .33353 m .55181 .31219 L .55992 .31055 L p F P
0 g
s
.588 .646 .875 r
.65202 .24141 m .67188 .23155 L .68161 .24861 L p F P
0 g
s
.667 .698 .869 r
.67188 .23155 m .65202 .24141 L .64276 .23049 L p F P
0 g
s
.757 .806 .892 r
.62376 .24888 m .64276 .23049 L .65202 .24141 L p F P
0 g
s
.719 .969 .72 r
.50884 .35706 m .49176 .37583 L .48432 .3804 L p F P
0 g
s
.653 .94 .684 r
.46779 .39779 m .48432 .3804 L .49176 .37583 L p F P
0 g
s
.817 .856 .877 r
.64276 .23049 m .62376 .24888 L .61485 .24384 L p F P
0 g
s
.852 .928 .878 r
.59641 .26664 m .61485 .24384 L .62376 .24888 L p F P
0 g
s
.426 .522 .853 r
.68161 .24861 m .70257 .24753 L .71273 .268 L p F P
0 g
s
.488 .552 .848 r
.70257 .24753 m .68161 .24861 L .67188 .23155 L p F P
0 g
s
.273 .441 .846 r
.72276 .28751 m .74532 .29462 L .75563 .31477 L p F P
0 g
s
.314 .45 .839 r
.74532 .29462 m .72276 .28751 L .71273 .268 L p F P
0 g
s
.87 .981 .843 r
.59641 .26664 m .5781 .28903 L .56969 .28942 L p F P
0 g
s
.848 .996 .828 r
.55181 .31219 m .56969 .28942 L .5781 .28903 L p F P
0 g
s
.656 .936 .669 r
.48432 .3804 m .46779 .39779 L .46058 .40304 L p F P
0 g
s
.581 .896 .626 r
.44467 .41879 m .46058 .40304 L .46779 .39779 L p F P
0 g
s
.818 .999 .789 r
.55181 .31219 m .53406 .33353 L .52611 .33656 L p F P
0 g
s
.772 .991 .766 r
.50884 .35706 m .52611 .33656 L .53406 .33353 L p F P
0 g
s
.01 .344 .823 r
.81009 .38 m .83553 .39565 L .84558 .41095 L p F P
0 g
s
.066 .357 .829 r
.83553 .39565 m .81009 .38 L .80007 .3636 L p F P
0 g
s
.151 .394 .842 r
.76575 .33339 m .7898 .34545 L .80007 .3636 L p F P
0 g
s
.193 .401 .838 r
.7898 .34545 m .76575 .33339 L .75563 .31477 L p F P
0 g
s
.774 .987 .748 r
.52611 .33656 m .50884 .35706 L .50106 .36117 L p F P
0 g
s
.719 .969 .72 r
.48432 .3804 m .50106 .36117 L .50884 .35706 L p F P
0 g
s
.877 .951 .854 r
.61485 .24384 m .59641 .26664 L .58771 .26536 L p F P
0 g
s
.87 .981 .843 r
.56969 .28942 m .58771 .26536 L .59641 .26664 L p F P
0 g
s
.667 .698 .869 r
.64276 .23049 m .6621 .21537 L .67188 .23155 L p F P
0 g
s
.746 .757 .862 r
.6621 .21537 m .64276 .23049 L .63345 .22146 L p F P
0 g
s
.817 .856 .877 r
.61485 .24384 m .63345 .22146 L .64276 .23049 L p F P
0 g
s
.314 .45 .839 r
.71273 .268 m .73482 .273 L .74532 .29462 L p F P
0 g
s
.356 .463 .831 r
.73482 .273 m .71273 .268 L .70257 .24753 L p F P
0 g
s
.488 .552 .848 r
.67188 .23155 m .69229 .2264 L .70257 .24753 L p F P
0 g
s
.561 .592 .842 r
.69229 .2264 m .67188 .23155 L .6621 .21537 L p F P
0 g
s
.853 .998 .806 r
.56969 .28942 m .55181 .31219 L .54355 .31438 L p F P
0 g
s
.818 .999 .789 r
.52611 .33656 m .54355 .31438 L .55181 .31219 L p F P
0 g
s
.193 .401 .838 r
.75563 .31477 m .77928 .32553 L .7898 .34545 L p F P
0 g
s
.231 .407 .831 r
.77928 .32553 m .75563 .31477 L .74532 .29462 L p F P
0 g
s
.72 .965 .703 r
.50106 .36117 m .48432 .3804 L .47674 .38536 L p F P
0 g
s
.656 .936 .669 r
.46058 .40304 m .47674 .38536 L .48432 .3804 L p F P
0 g
s
.066 .357 .829 r
.80007 .3636 m .82519 .37842 L .83553 .39565 L p F P
0 g
s
.115 .367 .829 r
.82519 .37842 m .80007 .3636 L .7898 .34545 L p F P
0 g
s
.864 .901 .858 r
.63345 .22146 m .61485 .24384 L .60584 .24027 L p F P
0 g
s
.877 .951 .854 r
.58771 .26536 m .60584 .24027 L .61485 .24384 L p F P
0 g
s
.878 .988 .818 r
.58771 .26536 m .56969 .28942 L .56115 .29053 L p F P
0 g
s
.853 .998 .806 r
.54355 .31438 m .56115 .29053 L .56969 .28942 L p F P
0 g
s
.819 .996 .769 r
.54355 .31438 m .52611 .33656 L .51802 .34008 L p F P
0 g
s
.774 .987 .748 r
.50106 .36117 m .51802 .34008 L .52611 .33656 L p F P
0 g
s
.356 .463 .831 r
.70257 .24753 m .72415 .24995 L .73482 .273 L p F P
0 g
s
.402 .479 .825 r
.72415 .24995 m .70257 .24753 L .69229 .2264 L p F P
0 g
s
.561 .592 .842 r
.6621 .21537 m .68192 .2051 L .69229 .2264 L p F P
0 g
s
.643 .645 .836 r
.68192 .2051 m .6621 .21537 L .65229 .20096 L p F P
0 g
s
.746 .757 .862 r
.63345 .22146 m .65229 .20096 L .6621 .21537 L p F P
0 g
s
.231 .407 .831 r
.74532 .29462 m .76854 .30386 L .77928 .32553 L p F P
0 g
s
.267 .412 .823 r
.76854 .30386 m .74532 .29462 L .73482 .273 L p F P
0 g
s
.819 .822 .851 r
.65229 .20096 m .63345 .22146 L .62408 .2146 L p F P
0 g
s
.864 .901 .858 r
.60584 .24027 m .62408 .2146 L .63345 .22146 L p F P
0 g
s
.774 .983 .729 r
.51802 .34008 m .50106 .36117 L .49315 .36572 L p F P
0 g
s
.72 .965 .703 r
.47674 .38536 m .49315 .36572 L .50106 .36117 L p F P
0 g
s
.115 .367 .829 r
.7898 .34545 m .81455 .35926 L .82519 .37842 L p F P
0 g
s
.157 .373 .824 r
.81455 .35926 m .7898 .34545 L .77928 .32553 L p F P
0 g
s
.893 .968 .827 r
.60584 .24027 m .58771 .26536 L .57887 .26509 L p F P
0 g
s
.878 .988 .818 r
.56115 .29053 m .57887 .26509 L .58771 .26536 L p F P
0 g
s
.402 .479 .825 r
.69229 .2264 m .71332 .22561 L .72415 .24995 L p F P
0 g
s
.457 .503 .818 r
.71332 .22561 m .69229 .2264 L .68192 .2051 L p F P
0 g
s
.854 .997 .783 r
.56115 .29053 m .54355 .31438 L .53515 .31716 L p F P
0 g
s
.819 .996 .769 r
.51802 .34008 m .53515 .31716 L .54355 .31438 L p F P
0 g
s
.267 .412 .823 r
.73482 .273 m .75757 .28044 L .76854 .30386 L p F P
0 g
s
.3 .418 .814 r
.75757 .28044 m .73482 .273 L .72415 .24995 L p F P
0 g
s
.643 .645 .836 r
.65229 .20096 m .6715 .18452 L .68192 .2051 L p F P
0 g
s
.734 .712 .831 r
.6715 .18452 m .65229 .20096 L .64247 .18927 L p F P
0 g
s
.819 .822 .851 r
.62408 .2146 m .64247 .18927 L .65229 .20096 L p F P
0 g
s
.896 .936 .833 r
.62408 .2146 m .60584 .24027 L .5967 .23817 L p F P
0 g
s
.893 .968 .827 r
.57887 .26509 m .5967 .23817 L .60584 .24027 L p F P
0 g
s
.457 .503 .818 r
.68192 .2051 m .70236 .2002 L .71332 .22561 L p F P
0 g
s
.526 .539 .812 r
.70236 .2002 m .68192 .2051 L .6715 .18452 L p F P
0 g
s
.157 .373 .824 r
.77928 .32553 m .80364 .33815 L .81455 .35926 L p F P
0 g
s
.193 .377 .818 r
.80364 .33815 m .77928 .32553 L .76854 .30386 L p F P
0 g
s
.818 .993 .747 r
.53515 .31716 m .51802 .34008 L .50977 .34413 L p F P
0 g
s
.774 .983 .729 r
.49315 .36572 m .50977 .34413 L .51802 .34008 L p F P
0 g
s
.881 .991 .793 r
.57887 .26509 m .56115 .29053 L .55245 .2924 L p F P
0 g
s
.854 .997 .783 r
.53515 .31716 m .55245 .2924 L .56115 .29053 L p F P
0 g
s
.878 .883 .834 r
.64247 .18927 m .62408 .2146 L .61462 .20997 L p F P
0 g
s
.896 .936 .833 r
.5967 .23817 m .61462 .20997 L .62408 .2146 L p F P
0 g
s
.3 .418 .814 r
.72415 .24995 m .7464 .25531 L .75757 .28044 L p F P
0 g
s
.334 .425 .806 r
.7464 .25531 m .72415 .24995 L .71332 .22561 L p F P
0 g
s
.901 .979 .799 r
.5967 .23817 m .57887 .26509 L .56988 .26584 L p F P
0 g
s
.881 .991 .793 r
.55245 .2924 m .56988 .26584 L .57887 .26509 L p F P
0 g
s
.526 .539 .812 r
.6715 .18452 m .69129 .17415 L .70236 .2002 L p F P
0 g
s
.614 .592 .805 r
.69129 .17415 m .6715 .18452 L .6611 .16615 L p F P
0 g
s
.734 .712 .831 r
.64247 .18927 m .6611 .16615 L .6715 .18452 L p F P
0 g
s
.193 .377 .818 r
.76854 .30386 m .79246 .3151 L .80364 .33815 L p F P
0 g
s
.225 .38 .81 r
.79246 .3151 m .76854 .30386 L .75757 .28044 L p F P
0 g
s
.853 .995 .76 r
.55245 .2924 m .53515 .31716 L .5266 .32058 L p F P
0 g
s
.818 .993 .747 r
.50977 .34413 m .5266 .32058 L .53515 .31716 L p F P
0 g
s
.825 .796 .824 r
.6611 .16615 m .64247 .18927 L .63263 .18088 L p F P
0 g
s
.878 .883 .834 r
.61462 .20997 m .63263 .18088 L .64247 .18927 L p F P
0 g
s
.334 .425 .806 r
.71332 .22561 m .73503 .22849 L .7464 .25531 L p F P
0 g
s
.37 .436 .798 r
.73503 .22849 m .71332 .22561 L .70236 .2002 L p F P
0 g
s
.913 .96 .804 r
.61462 .20997 m .5967 .23817 L .58742 .23751 L p F P
0 g
s
.901 .979 .799 r
.56988 .26584 m .58742 .23751 L .5967 .23817 L p F P
0 g
s
.37 .436 .798 r
.70236 .2002 m .7235 .20005 L .73503 .22849 L p F P
0 g
s
.415 .452 .791 r
.7235 .20005 m .70236 .2002 L .69129 .17415 L p F P
0 g
s
.225 .38 .81 r
.75757 .28044 m .78103 .29012 L .79246 .3151 L p F P
0 g
s
.253 .382 .801 r
.78103 .29012 m .75757 .28044 L .7464 .25531 L p F P
0 g
s
.88 .992 .767 r
.56988 .26584 m .55245 .2924 L .54359 .29507 L p F P
0 g
s
.853 .995 .76 r
.5266 .32058 m .54359 .29507 L .55245 .2924 L p F P
0 g
s
.614 .592 .805 r
.6611 .16615 m .68018 .14844 L .69129 .17415 L p F P
0 g
s
.722 .671 .799 r
.68018 .14844 m .6611 .16615 L .65076 .15185 L p F P
0 g
s
.825 .796 .824 r
.63263 .18088 m .65076 .15185 L .6611 .16615 L p F P
0 g
s
.915 .931 .807 r
.63263 .18088 m .61462 .20997 L .60505 .20748 L p F P
0 g
s
.913 .96 .804 r
.58742 .23751 m .60505 .20748 L .61462 .20997 L p F P
0 g
s
.415 .452 .791 r
.69129 .17415 m .71181 .17011 L .7235 .20005 L p F P
0 g
s
.477 .482 .784 r
.71181 .17011 m .69129 .17415 L .68018 .14844 L p F P
0 g
s
.253 .382 .801 r
.7464 .25531 m .76936 .26321 L .78103 .29012 L p F P
0 g
s
.278 .384 .792 r
.76936 .26321 m .7464 .25531 L .73503 .22849 L p F P
0 g
s
.899 .882 .808 r
.65076 .15185 m .63263 .18088 L .62274 .17586 L p F P
0 g
s
.915 .931 .807 r
.60505 .20748 m .62274 .17586 L .63263 .18088 L p F P
0 g
s
.902 .985 .771 r
.58742 .23751 m .56988 .26584 L .56073 .26763 L p F P
0 g
s
.88 .992 .767 r
.54359 .29507 m .56073 .26763 L .56988 .26584 L p F P
0 g
s
.477 .482 .784 r
.68018 .14844 m .69999 .1389 L .71181 .17011 L p F P
0 g
s
.572 .535 .775 r
.69999 .1389 m .68018 .14844 L .66913 .12539 L p F P
0 g
s
.722 .671 .799 r
.65076 .15185 m .66913 .12539 L .68018 .14844 L p F P
0 g
s
.843 .788 .798 r
.66913 .12539 m .65076 .15185 L .64049 .14287 L p F P
0 g
s
.899 .882 .808 r
.62274 .17586 m .64049 .14287 L .65076 .15185 L p F P
0 g
s
.278 .384 .792 r
.73503 .22849 m .75748 .23441 L .76936 .26321 L p F P
0 g
s
.302 .386 .783 r
.75748 .23441 m .73503 .22849 L .7235 .20005 L p F P
0 g
s
.917 .975 .773 r
.60505 .20748 m .58742 .23751 L .57798 .23826 L p F P
0 g
s
.902 .985 .771 r
.56073 .26763 m .57798 .23826 L .58742 .23751 L p F P
0 g
s
.302 .386 .783 r
.7235 .20005 m .74539 .20373 L .75748 .23441 L p F P
0 g
s
.326 .389 .774 r
.74539 .20373 m .7235 .20005 L .71181 .17011 L p F P
0 g
s
.929 .961 .773 r
.62274 .17586 m .60505 .20748 L .59534 .207 L p F P
0 g
s
.917 .975 .773 r
.57798 .23826 m .59534 .207 L .60505 .20748 L p F P
0 g
s
.572 .535 .775 r
.66913 .12539 m .6881 .10714 L .69999 .1389 L p F P
0 g
s
.711 .629 .764 r
.6881 .10714 m .66913 .12539 L .65829 .1092 L p F P
0 g
s
.843 .788 .798 r
.64049 .14287 m .65829 .1092 L .66913 .12539 L p F P
0 g
s
.326 .389 .774 r
.71181 .17011 m .73311 .17121 L .74539 .20373 L p F P
0 g
s
.354 .396 .766 r
.73311 .17121 m .71181 .17011 L .69999 .1389 L p F P
0 g
s
.935 .942 .773 r
.64049 .14287 m .62274 .17586 L .61276 .17388 L p F P
0 g
s
.929 .961 .773 r
.59534 .207 m .61276 .17388 L .62274 .17586 L p F P
0 g
s
.354 .396 .766 r
.69999 .1389 m .72067 .1369 L .73311 .17121 L p F P
0 g
s
.395 .411 .759 r
.72067 .1369 m .69999 .1389 L .6881 .10714 L p F P
0 g
s
.932 .911 .776 r
.65829 .1092 m .64049 .14287 L .63022 .13894 L p F P
0 g
s
.935 .942 .773 r
.61276 .17388 m .63022 .13894 L .64049 .14287 L p F P
0 g
s
.395 .411 .759 r
.6881 .10714 m .70808 .10083 L .72067 .1369 L p F P
0 g
s
.487 .46 .753 r
.70808 .10083 m .6881 .10714 L .6763 .07809 L p F P
0 g
s
.711 .629 .764 r
.65829 .1092 m .6763 .07809 L .6881 .10714 L p F P
0 g
s
.892 .829 .778 r
.6763 .07809 m .65829 .1092 L .64769 .10221 L p F P
0 g
s
.932 .911 .776 r
.63022 .13894 m .64769 .10221 L .65829 .1092 L p F P
0 g
s
.487 .46 .753 r
.6763 .07809 m .69537 .06305 L .70808 .10083 L p F P
0 g
s
.701 .577 .713 r
.69537 .06305 m .6763 .07809 L .66514 .06376 L p F P
0 g
s
.892 .829 .778 r
.64769 .10221 m .66514 .06376 L .6763 .07809 L p F P
0 g
s
.701 .577 .713 r
.66514 .06376 m .68254 .02363 L .69537 .06305 L p F P
0 g
s
.25 Mabswid
.69167 0 m
.97681 .43105 L
s
.97681 .43105 m
1 .60069 L
s
1 .60069 m
.70245 .18561 L
s
.70245 .18561 m
.69167 0 L
s
.02811 .25642 m
0 .43378 L
s
0 .43378 m
.70245 .18561 L
s
.70245 .18561 m
.69167 0 L
s
.69167 0 m
.02811 .25642 L
s
.02811 .25642 m
.69167 0 L
s
.04211 .25101 m
.04692 .25547 L
s
[(-2)] .03249 .24209 1 .92762 Mshowa
.23653 .17588 m
.24103 .18065 L
s
[(-1)] .22754 .16633 .94257 1 Mshowa
.44647 .09475 m
.45059 .09986 L
s
[(0)] .43823 .08455 .80711 1 Mshowa
.67386 .00689 m
.67751 .01233 L
s
[(1)] .66654 -0.004 .67166 1 Mshowa
.125 Mabswid
.07984 .23643 m
.08269 .23914 L
s
.11813 .22163 m
.12095 .22438 L
s
.157 .20661 m
.15978 .2094 L
s
.19646 .19136 m
.1992 .19418 L
s
.27722 .16015 m
.27988 .16306 L
s
.31854 .14419 m
.32116 .14713 L
s
.36052 .12797 m
.36308 .13095 L
s
.40315 .11149 m
.40567 .11451 L
s
.49048 .07774 m
.4929 .08085 L
s
.53521 .06046 m
.53758 .0636 L
s
.58067 .04289 m
.58298 .04608 L
s
.62688 .02504 m
.62913 .02826 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 219.312},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {218.312, 0}} -> {-0.0689393, 0.0442716, \
0.00356074, 0.00356074}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics3D", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", " ", 
  RowBox[{
  "\"\</local/constant/ElasticaBook/C07_EnergyVariational/EPS/C07_triangle_\
tresca.eps\>\"", ",", " ", "%131"}], "]"}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/C07_EnergyVariational/EPS/C07_\
triangle_tresca.eps\"\>"], "Output"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{987, 821},
WindowMargins->{{45, Automatic}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[1309, 36, 292, 9, 46, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1626, 49, 320, 9, 77, "Input"],
Cell[1949, 60, 72, 0, 31, "Output"]
}, Open  ]],
Cell[2036, 63, 111, 2, 77, "Input"],
Cell[CellGroupData[{
Cell[2172, 69, 158, 4, 55, "Input"],
Cell[2333, 75, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2466, 82, 49, 0, 39, "Subsection"],
Cell[2518, 84, 178, 4, 32, "Input"],
Cell[2699, 90, 558, 16, 32, "Input"],
Cell[CellGroupData[{
Cell[3282, 110, 1109, 30, 99, "Input"],
Cell[4394, 142, 3644, 115, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8075, 262, 113, 2, 32, "Input"],
Cell[8191, 266, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8311, 273, 296, 7, 55, "Input"],
Cell[8610, 282, 391, 8, 24, "Message"],
Cell[9004, 292, 83, 2, 31, "Output"],
Cell[9090, 296, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9210, 303, 599, 17, 55, "Input"],
Cell[9812, 322, 115, 4, 40, "Output"],
Cell[9930, 328, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10050, 335, 627, 18, 55, "Input"],
Cell[10680, 355, 135, 5, 40, "Output"],
Cell[10818, 362, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10938, 369, 1320, 40, 99, "Input"],
Cell[12261, 411, 3856, 121, 110, "Output"],
Cell[16120, 534, 237, 7, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16394, 546, 1331, 39, 55, "Input"],
Cell[17728, 587, 183, 5, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17948, 597, 511, 13, 77, "Input"],
Cell[18462, 612, 406, 12, 46, "Output"],
Cell[18871, 626, 136, 4, 46, "Output"],
Cell[19010, 632, 199, 6, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19246, 643, 241, 4, 77, "Input"],
Cell[19490, 649, 260, 8, 31, "Output"],
Cell[19753, 659, 436, 12, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20226, 676, 430, 14, 32, "Input"],
Cell[20659, 692, 136, 4, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20832, 701, 961, 27, 55, "Input"],
Cell[21796, 730, 195, 5, 33, "Output"],
Cell[21994, 737, 538, 17, 52, "Output"]
}, Open  ]],
Cell[22547, 757, 63, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[22635, 762, 29, 0, 32, "Input"],
Cell[22667, 764, 3578, 115, 131, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26282, 884, 1492, 39, 77, "Input"],
Cell[27777, 925, 1303, 42, 71, "Output"],
Cell[29083, 969, 18982, 935, 236, 14097, 851, "GraphicsData", "PostScript", \
"Graphics"],
Cell[48068, 1906, 134, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48239, 1915, 1005, 28, 55, "Input"],
Cell[49247, 1945, 134, 4, 31, "Output"],
Cell[49384, 1951, 16214, 585, 293, 9839, 477, "GraphicsData", "PostScript", \
"Graphics"],
Cell[65601, 2538, 134, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65772, 2547, 196, 4, 55, "Input"],
Cell[65971, 2553, 127, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66135, 2559, 407, 11, 32, "Input"],
Cell[66545, 2572, 149080, 7416, 224, 133470, 7157, "GraphicsData", \
"PostScript", "Graphics"],
Cell[215628, 9990, 136, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[215801, 9999, 187, 4, 55, "Input"],
Cell[215991, 10005, 117, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[216145, 10011, 104, 2, 32, "Input"],
Cell[216252, 10015, 3163, 85, 82, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[219452, 10105, 1191, 33, 55, "Input"],
Cell[220646, 10140, 695, 18, 41, "Output"],
Cell[221344, 10160, 1375, 38, 104, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[222756, 10203, 749, 19, 55, "Input"],
Cell[223508, 10224, 384292, 19875, 281, 370595, 19647, "GraphicsData", \
"PostScript", "Graphics"],
Cell[607803, 30101, 136, 4, 31, "Output"]
}, Open  ]],
Cell[607954, 30108, 75, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[608054, 30113, 411, 11, 32, "Input"],
Cell[608468, 30126, 148185, 7480, 228, 133428, 7235, "GraphicsData", \
"PostScript", "Graphics"],
Cell[756656, 37608, 136, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[756829, 37617, 185, 4, 55, "Input"],
Cell[757017, 37623, 115, 1, 31, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

