(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     41813,       1438]
NotebookOptionsPosition[     37913,       1301]
NotebookOutlinePosition[     38417,       1321]
CellTagsIndexPosition[     38374,       1318]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"Vibration", " ", "of", " ", 
    StyleBox["a",
     FontSlant->"Plain"], " ", "cantilever", " ", "beam"}], "Subtitle"], 
  TraditionalForm]], "Input",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
    "]"}], "\n", "\[IndentingNewLine]", 
   RowBox[{"FileNames", "[", "\"\<*\>\"", "]"}]}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Displacement_Jun05.m\"\>", 
   ",", "\<\"Displacement_Kolosov.m\"\>", 
   ",", "\<\"DisplacementKolosov.m\"\>", ",", "\<\"Displacement.m\"\>", 
   ",", "\<\"T2Analysis.m\"\>", ",", "\<\"Tensor2Analysis_Jun05.m\"\>", 
   ",", "\<\"Tensor2Analysis.m\"\>", ",", "\<\"Tensor2AnalysisOld.m\"\>"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\n", 
 RowBox[{"<<", "Displacement.m"}], "\n"}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SetCoordinates", "[", 
   RowBox[{"Cartesian", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], "\n"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
domain = {{x, 0, L}, {y, -a/2, a/2}, {z, -b/2, b/2}}
w = A ( Cos[Pi*x/L] - 1) + B ( Cos[2*Pi*x/L] - 1)
u := {-y D[w, x], w, 0}
u\
\>", "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "L"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", 
      FractionBox["a", "2"]}], ",", 
     FractionBox["a", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", 
      FractionBox["b", "2"]}], ",", 
     FractionBox["b", "2"]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"\[Pi]", " ", "x"}], "L"], "]"}]}], ")"}]}], "+", 
  RowBox[{"B", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"2", " ", "\[Pi]", " ", "x"}], "L"], "]"}]}], 
    ")"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "y"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"A", " ", "\[Pi]", " ", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{"\[Pi]", " ", "x"}], "L"], "]"}]}], "L"]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "B", " ", "\[Pi]", " ", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{"2", " ", "\[Pi]", " ", "x"}], "L"], "]"}]}], "L"]}], 
     ")"}]}], ",", 
   RowBox[{
    RowBox[{"A", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"\[Pi]", " ", "x"}], "L"], "]"}]}], ")"}]}], "+", 
    RowBox[{"B", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"2", " ", "\[Pi]", " ", "x"}], "L"], "]"}]}], ")"}]}]}], ",",
    "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["check kinematic compatibility of the displacement \
field",
 FontFamily->"Helvetica"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "/.", " ", 
  RowBox[{"x", " ", "\[Rule]", "0", " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["compute stress and strains",
 FontFamily->"Helvetica"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{"eps", "=", 
    RowBox[{"Strain", "[", "u", "]"}]}], ")"}], "//", "MatrixForm"}], "\n", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"sig", "=", " ", 
    RowBox[{"EE", " ", 
     RowBox[{"Stress", "[", "eps", "]"}]}]}], ")"}], "//", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", "y"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"A", " ", 
            SuperscriptBox["\[Pi]", "2"], " ", 
            RowBox[{"Cos", "[", 
             FractionBox[
              RowBox[{"\[Pi]", " ", "x"}], "L"], "]"}]}], 
           SuperscriptBox["L", "2"]]}], "-", 
         FractionBox[
          RowBox[{"4", " ", "B", " ", 
           SuperscriptBox["\[Pi]", "2"], " ", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "x"}], "L"], "]"}]}], 
          SuperscriptBox["L", "2"]]}], ")"}]}], "0", "0"},
     {"0", "0", "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", "EE"}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"1", "+", "nu"}]], "+", 
         FractionBox["nu", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "nu"}], ")"}]}]]}], ")"}], " ", "y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"A", " ", 
            SuperscriptBox["\[Pi]", "2"], " ", 
            RowBox[{"Cos", "[", 
             FractionBox[
              RowBox[{"\[Pi]", " ", "x"}], "L"], "]"}]}], 
           SuperscriptBox["L", "2"]]}], "-", 
         FractionBox[
          RowBox[{"4", " ", "B", " ", 
           SuperscriptBox["\[Pi]", "2"], " ", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "x"}], "L"], "]"}]}], 
          SuperscriptBox["L", "2"]]}], ")"}]}], "0", "0"},
     {"0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"EE", " ", "nu", " ", "y", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"A", " ", 
              SuperscriptBox["\[Pi]", "2"], " ", 
              RowBox[{"Cos", "[", 
               FractionBox[
                RowBox[{"\[Pi]", " ", "x"}], "L"], "]"}]}], 
             SuperscriptBox["L", "2"]]}], "-", 
           FractionBox[
            RowBox[{"4", " ", "B", " ", 
             SuperscriptBox["\[Pi]", "2"], " ", 
             RowBox[{"Cos", "[", 
              FractionBox[
               RowBox[{"2", " ", "\[Pi]", " ", "x"}], "L"], "]"}]}], 
            SuperscriptBox["L", "2"]]}], ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}]}]]}], "0"},
     {"0", "0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"EE", " ", "nu", " ", "y", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"A", " ", 
              SuperscriptBox["\[Pi]", "2"], " ", 
              RowBox[{"Cos", "[", 
               FractionBox[
                RowBox[{"\[Pi]", " ", "x"}], "L"], "]"}]}], 
             SuperscriptBox["L", "2"]]}], "-", 
           FractionBox[
            RowBox[{"4", " ", "B", " ", 
             SuperscriptBox["\[Pi]", "2"], " ", 
             RowBox[{"Cos", "[", 
              FractionBox[
               RowBox[{"2", " ", "\[Pi]", " ", "x"}], "L"], "]"}]}], 
            SuperscriptBox["L", "2"]]}], ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "nu"}], ")"}]}]]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["stresses do not assure a free external  boundary -> \
approximate solution  ",
 FontFamily->"Helvetica"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sig", " ", ".", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", 
     RowBox[{"-", "1"}], ",", " ", "0"}], "}"}]}], " ", "/.", " ", 
  RowBox[{"y", " ", "\[Rule]", " ", 
   RowBox[{
    RowBox[{"-", "a"}], "/", "2", " "}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Series", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"sig", " ", ".", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "1", ",", " ", "0"}], "}"}]}], " ", "/.", " ", 
      
      RowBox[{"y", " ", "\[Rule]", " ", 
       RowBox[{
        RowBox[{"+", " ", "a"}], "/", "2"}]}]}], "  ", "/.", " ", 
     RowBox[{"a", "  ", "\[Rule]", " ", 
      RowBox[{"aoL", " ", "L"}]}]}], " ", ",", " ", 
    RowBox[{"{", 
     RowBox[{"aoL", " ", ",", " ", "0", ",", " ", "1"}], "}"}]}], " ", "]"}], 
  " ", "/.", " ", 
  RowBox[{"aoL", " ", "\[Rule]", " ", 
   RowBox[{"a", "/", "L", " "}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sig", " ", ".", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", "0", ",", " ", 
     RowBox[{"-", "1"}]}], "}"}]}], " ", "/.", " ", 
  RowBox[{"z", " ", "\[Rule]", " ", 
   RowBox[{
    RowBox[{"-", " ", "b"}], "/", "2", " "}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Series", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"sig", " ", ".", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "0", ",", " ", 
         RowBox[{"-", "1"}]}], "}"}]}], " ", "/.", " ", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       RowBox[{
        RowBox[{"-", " ", "b"}], "/", "2"}]}]}], "  ", "/.", " ", 
     RowBox[{"y", "  ", "\[Rule]", " ", 
      RowBox[{"yoL", " ", "L"}]}]}], " ", ",", " ", 
    RowBox[{"{", 
     RowBox[{"yoL", " ", ",", " ", "0", ",", " ", "1"}], "}"}]}], " ", "]"}], 
  " ", "/.", " ", 
  RowBox[{"yoL", " ", "\[Rule]", " ", 
   RowBox[{"a", "/", "L", " "}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sig", " ", ".", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}]}], " ", "/.", " ", 
  RowBox[{"z", " ", "\[Rule]", " ", 
   RowBox[{
    RowBox[{"+", " ", "b"}], "/", "2", " "}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Series", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"sig", " ", ".", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "}"}]}], " ", "/.", " ", 
      
      RowBox[{"x", " ", "\[Rule]", " ", "L"}]}], " ", "/.", " ", 
     RowBox[{"y", "  ", "\[Rule]", " ", 
      RowBox[{"yoL", " ", "L"}]}]}], " ", ",", " ", 
    RowBox[{"{", 
     RowBox[{"yoL", " ", ",", " ", "0", ",", " ", "1"}], "}"}]}], " ", "]"}], 
  " ", "/.", " ", 
  RowBox[{"yoL", " ", "\[Rule]", " ", 
   RowBox[{
    RowBox[{"y", "/", "L"}], "  "}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"a", " ", "EE", " ", "nu", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"A", " ", 
           SuperscriptBox["\[Pi]", "2"], " ", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"\[Pi]", " ", "x"}], "L"], "]"}]}], 
          SuperscriptBox["L", "2"]]}], "-", 
        FractionBox[
         RowBox[{"4", " ", "B", " ", 
          SuperscriptBox["\[Pi]", "2"], " ", 
          RowBox[{"Cos", "[", 
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "x"}], "L"], "]"}]}], 
         SuperscriptBox["L", "2"]]}], ")"}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "nu"}], ")"}]}]]}], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"A", " ", "EE", " ", "nu", " ", 
           SuperscriptBox["\[Pi]", "2"], " ", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"\[Pi]", " ", "x"}], "L"], "]"}]}], 
          RowBox[{"2", " ", "L", " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "nu"}], ")"}]}]], "+", 
         FractionBox[
          RowBox[{"2", " ", "B", " ", "EE", " ", "nu", " ", 
           SuperscriptBox["\[Pi]", "2"], " ", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "x"}], "L"], "]"}]}], 
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "nu"}], ")"}]}]]}], ")"}], " ", "a"}], "L"], 
     "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["a", "L"], "]"}], "2"],
      SeriesData[a/L, 0, {}, 1, 2, 1],
      Editable->False]}],
    SeriesData[
    a/L, 0, {Rational[1, 2] A EE L^(-1) (1 - 2 nu)^(-1) nu (1 + nu)^(-1) Pi^2 
       Cos[L^(-1) Pi x] + 
      2 B EE L^(-1) (1 - 2 nu)^(-1) nu (1 + nu)^(-1) Pi^2 Cos[2 L^(-1) Pi x]},
      1, 2, 1],
    Editable->False], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   FractionBox[
    RowBox[{"EE", " ", "nu", " ", "y", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"A", " ", 
          SuperscriptBox["\[Pi]", "2"], " ", 
          RowBox[{"Cos", "[", 
           FractionBox[
            RowBox[{"\[Pi]", " ", "x"}], "L"], "]"}]}], 
         SuperscriptBox["L", "2"]]}], "-", 
       FractionBox[
        RowBox[{"4", " ", "B", " ", 
         SuperscriptBox["\[Pi]", "2"], " ", 
         RowBox[{"Cos", "[", 
          FractionBox[
           RowBox[{"2", " ", "\[Pi]", " ", "x"}], "L"], "]"}]}], 
        SuperscriptBox["L", "2"]]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "nu"}], ")"}]}]]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"A", " ", "EE", " ", "nu", " ", 
            SuperscriptBox["\[Pi]", "2"], " ", 
            RowBox[{"Cos", "[", 
             FractionBox[
              RowBox[{"\[Pi]", " ", "x"}], "L"], "]"}]}], 
           RowBox[{"L", " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "nu"}], ")"}]}]]}], "-", 
         FractionBox[
          RowBox[{"4", " ", "B", " ", "EE", " ", "nu", " ", 
           SuperscriptBox["\[Pi]", "2"], " ", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"2", " ", "\[Pi]", " ", "x"}], "L"], "]"}]}], 
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "nu"}], ")"}]}]]}], ")"}], " ", "a"}], "L"], 
     "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["a", "L"], "]"}], "2"],
      SeriesData[a/L, 0, {}, 1, 2, 1],
      Editable->False]}],
    SeriesData[
    a/L, 0, {-A EE L^(-1) (1 - 2 nu)^(-1) nu (1 + nu)^(-1) Pi^2 
       Cos[L^(-1) Pi x] - 4 B EE L^(-1) (1 - 2 nu)^(-1) nu (1 + nu)^(-1) Pi^2 
      Cos[2 L^(-1) Pi x]}, 1, 2, 1],
    Editable->False]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"EE", " ", "nu", " ", "y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"A", " ", 
           SuperscriptBox["\[Pi]", "2"], " ", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"\[Pi]", " ", "x"}], "L"], "]"}]}], 
          SuperscriptBox["L", "2"]]}], "-", 
        FractionBox[
         RowBox[{"4", " ", "B", " ", 
          SuperscriptBox["\[Pi]", "2"], " ", 
          RowBox[{"Cos", "[", 
           FractionBox[
            RowBox[{"2", " ", "\[Pi]", " ", "x"}], "L"], "]"}]}], 
         SuperscriptBox["L", "2"]]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "nu"}], ")"}]}]]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"EE", " ", "L", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"1", "+", "nu"}]], "+", 
          FractionBox["nu", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", " ", "nu"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "nu"}], ")"}]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"A", " ", 
            SuperscriptBox["\[Pi]", "2"]}], 
           SuperscriptBox["L", "2"]], "-", 
          FractionBox[
           RowBox[{"4", " ", "B", " ", 
            SuperscriptBox["\[Pi]", "2"]}], 
           SuperscriptBox["L", "2"]]}], ")"}], " ", "y"}], "L"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["y", "L"], "]"}], "2"],
      SeriesData[L^(-1) y, 0, {}, 1, 2, 1],
      Editable->False]}],
    SeriesData[
    L^(-1) y, 
     0, {-EE L ((1 + nu)^(-1) + (1 - 2 nu)^(-1) nu/(1 + nu)) (A L^(-2) Pi^2 - 
       4 B L^(-2) Pi^2)}, 1, 2, 1],
    Editable->False], ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["compute the mass integral M and matrix MM",
 FontFamily->"Helvetica"]], "Subsection"],

Cell[CellGroupData[{

Cell["M = Integrate @@ Prepend[domain, rho u . u]", "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"a", " ", "b", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"12", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["A", "2"]}], "+", 
        RowBox[{"4", " ", "A", " ", "B"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["B", "2"]}]}], ")"}], " ", 
      SuperscriptBox["L", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["A", "2"], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["B", "2"]}]}], ")"}], " ", 
      SuperscriptBox["\[Pi]", "2"]}]}], ")"}], " ", "rho"}], 
  RowBox[{"24", " ", "L"}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["coeflist = CoefficientList[M, {A, B}]", "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       FractionBox["3", "2"], " ", "a", " ", "b", " ", "L", " ", "rho"}], "+",
       
      FractionBox[
       RowBox[{
        SuperscriptBox["a", "3"], " ", "b", " ", 
        SuperscriptBox["\[Pi]", "2"], " ", "rho"}], 
       RowBox[{"6", " ", "L"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"2", " ", "a", " ", "b", " ", "L", " ", "rho"}], ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["3", "2"], " ", "a", " ", "b", " ", "L", " ", "rho"}], "+",
       
      FractionBox[
       RowBox[{
        SuperscriptBox["a", "3"], " ", "b", " ", 
        SuperscriptBox["\[Pi]", "2"], " ", "rho"}], 
       RowBox[{"24", " ", "L"}]]}], ",", "0", ",", "0"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
MM = {{coeflist[[1,3]], coeflist[[2,2]]/2}, {coeflist[[2,2]]/2, 
    coeflist[[3,1]]}}\
\>", "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["3", "2"], " ", "a", " ", "b", " ", "L", " ", "rho"}], "+",
       
      FractionBox[
       RowBox[{
        SuperscriptBox["a", "3"], " ", "b", " ", 
        SuperscriptBox["\[Pi]", "2"], " ", "rho"}], 
       RowBox[{"6", " ", "L"}]]}], ",", 
     RowBox[{"a", " ", "b", " ", "L", " ", "rho"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", "b", " ", "L", " ", "rho"}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["3", "2"], " ", "a", " ", "b", " ", "L", " ", "rho"}], "+",
       
      FractionBox[
       RowBox[{
        SuperscriptBox["a", "3"], " ", "b", " ", 
        SuperscriptBox["\[Pi]", "2"], " ", "rho"}], 
       RowBox[{"24", " ", "L"}]]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["compute the stiffness integral K and matrix KK",
 FontFamily->"Helvetica"]], "Subsection"],

Cell[CellGroupData[{

Cell["\<\
K = Integrate @@ Prepend[domain, Flatten[eps] . Flatten[sig]]\
\>", "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["a", "3"], " ", "b", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["A", "2"], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["B", "2"]}]}], ")"}], " ", "EE", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
   SuperscriptBox["\[Pi]", "4"]}], 
  RowBox[{"24", " ", 
   SuperscriptBox["L", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["nu", "2"]}]}], ")"}]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["coeflist = CoefficientList[K, {A, B}]", "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", "EE", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
       SuperscriptBox["\[Pi]", "4"]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["L", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["nu", "2"]}]}], ")"}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", "EE", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
       SuperscriptBox["\[Pi]", "4"]}], 
      RowBox[{"24", " ", 
       SuperscriptBox["L", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["nu", "2"]}]}], ")"}]}]], ",", "0", ",", "0"}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
KK = {{coeflist[[1,3]], coeflist[[2,2]]/2}, {coeflist[[2,2]]/2, 
    coeflist[[3,1]]}}\
\>", "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", "EE", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
       SuperscriptBox["\[Pi]", "4"]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["L", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["nu", "2"]}]}], ")"}]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", "EE", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
       SuperscriptBox["\[Pi]", "4"]}], 
      RowBox[{"24", " ", 
       SuperscriptBox["L", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "nu", "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["nu", "2"]}]}], ")"}]}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["compute the eigenvalues expressions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"cm", " ", "=", " ", 
  RowBox[{"a", " ", "b", " ", "L", " ", "rho"}]}], "\[IndentingNewLine]", 
 RowBox[{"Mc", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"MM", "/", "cm"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"a", " ", "b", " ", "L", " ", "rho"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["\[Pi]", "2"]}], 
         SuperscriptBox["L", "2"]]}], ")"}]}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{
      FractionBox["3", "2"], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["\[Pi]", "2"]}], 
       RowBox[{"24", " ", 
        SuperscriptBox["L", "2"]}]]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mclim", " ", "=", " ", 
  RowBox[{"Normal", "[", " ", 
   RowBox[{"Series", "[", " ", 
    RowBox[{
     RowBox[{"Mc", " ", "/.", " ", 
      RowBox[{"a", " ", "\[Rule]", " ", "aoL"}]}], " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"aoL", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["3", "2"], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox["3", "2"]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ck", " ", "=", " ", 
  RowBox[{
   SuperscriptBox["a", "3"], " ", "b", " ", "EE", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["\[Pi]", "4"], " ", "/", " ", 
    RowBox[{"(", " ", 
     RowBox[{"24", "  ", 
      SuperscriptBox["L", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "nu", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["nu", "2"]}]}], ")"}]}], " ", 
     ")"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Kc", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"KK", "/", "ck"}], "]"}]}]}], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["a", "3"], " ", "b", " ", "EE", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu"}], ")"}], " ", 
   SuperscriptBox["\[Pi]", "4"]}], 
  RowBox[{"24", " ", 
   SuperscriptBox["L", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "nu", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["nu", "2"]}]}], ")"}]}]]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"16", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Kclim", " ", "=", " ", "Kc"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"16", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"elsol", " ", "=", " ", 
  RowBox[{"Solve", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Det", "[", " ", 
      RowBox[{"Kc", " ", "-", " ", 
       RowBox[{"el", " ", "Mc"}]}], "]"}], " ", "\[Equal]", " ", "0"}], ",", 
    " ", 
    RowBox[{"{", "el", "}"}]}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"el", "\[Rule]", 
     FractionBox[
      RowBox[{"12", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"153", " ", 
          SuperscriptBox["L", "4"]}], "+", 
         RowBox[{"5", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["L", "2"], " ", 
          SuperscriptBox["\[Pi]", "2"]}], "-", 
         RowBox[{"3", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"2281", " ", 
             SuperscriptBox["L", "8"]}], "+", 
            RowBox[{"90", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["L", "6"], " ", 
             SuperscriptBox["\[Pi]", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "4"], " ", 
             SuperscriptBox["L", "4"], " ", 
             SuperscriptBox["\[Pi]", "4"]}]}]]}]}], ")"}]}], 
      RowBox[{
       RowBox[{"180", " ", 
        SuperscriptBox["L", "4"]}], "+", 
       RowBox[{"45", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["L", "2"], " ", 
        SuperscriptBox["\[Pi]", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["a", "4"], " ", 
        SuperscriptBox["\[Pi]", "4"]}]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"el", "\[Rule]", 
     FractionBox[
      RowBox[{"12", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"153", " ", 
          SuperscriptBox["L", "4"]}], "+", 
         RowBox[{"5", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["L", "2"], " ", 
          SuperscriptBox["\[Pi]", "2"]}], "+", 
         RowBox[{"3", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"2281", " ", 
             SuperscriptBox["L", "8"]}], "+", 
            RowBox[{"90", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["L", "6"], " ", 
             SuperscriptBox["\[Pi]", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "4"], " ", 
             SuperscriptBox["L", "4"], " ", 
             SuperscriptBox["\[Pi]", "4"]}]}]]}]}], ")"}]}], 
      RowBox[{
       RowBox[{"180", " ", 
        SuperscriptBox["L", "4"]}], "+", 
       RowBox[{"45", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["L", "2"], " ", 
        SuperscriptBox["\[Pi]", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["a", "4"], " ", 
        SuperscriptBox["\[Pi]", "4"]}]}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[" "], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ellim", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{"Map", "[", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Series", "[", " ", 
         RowBox[{
          RowBox[{"#", " ", "/.", " ", 
           RowBox[{"a", " ", "\[Rule]", " ", "aoL"}]}], " ", ",", " ", 
          RowBox[{"{", 
           RowBox[{"aoL", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}], " ",
         "&"}], "  ", ")"}], "  ", ",", " ", "elsol"}], " ", "]"}], ",", " ", 
    
    RowBox[{"L", " ", ">", " ", "0"}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"el", "\[Rule]", 
     RowBox[{
      FractionBox["1", "5"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "-", 
        SqrtBox["2281"]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"el", "\[Rule]", 
     RowBox[{
      FractionBox["1", "5"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "+", 
        SqrtBox["2281"]}], ")"}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", "ellim", "]"}], "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"el", "\[Rule]", "0.648036850992358`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"el", "\[Rule]", "19.751963149007643`"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"system", " ", "=", " ", 
  RowBox[{
   RowBox[{"Thread", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Kclim", " ", "-", " ", 
        RowBox[{"el", " ", "Mclim"}]}], ")"}], ".", " ", 
      RowBox[{"{", 
       RowBox[{"A", ",", "B"}], "}"}]}], " ", "\[Equal]", " ", "0"}], "  ", 
    "]"}], " ", "/.", " ", "ellim"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"16", "-", 
          RowBox[{
           FractionBox["3", "10"], " ", 
           RowBox[{"(", 
            RowBox[{"51", "-", 
             SqrtBox["2281"]}], ")"}]}]}], ")"}], " ", "A"}], "-", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        RowBox[{"(", 
         RowBox[{"51", "-", 
          SqrtBox["2281"]}], ")"}], " ", "B"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        RowBox[{"(", 
         RowBox[{"51", "-", 
          SqrtBox["2281"]}], ")"}], " ", "A"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           FractionBox["3", "10"], " ", 
           RowBox[{"(", 
            RowBox[{"51", "-", 
             SqrtBox["2281"]}], ")"}]}]}], ")"}], " ", "B"}]}], "\[Equal]", 
      "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"16", "-", 
          RowBox[{
           FractionBox["3", "10"], " ", 
           RowBox[{"(", 
            RowBox[{"51", "+", 
             SqrtBox["2281"]}], ")"}]}]}], ")"}], " ", "A"}], "-", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        RowBox[{"(", 
         RowBox[{"51", "+", 
          SqrtBox["2281"]}], ")"}], " ", "B"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        RowBox[{"(", 
         RowBox[{"51", "+", 
          SqrtBox["2281"]}], ")"}], " ", "A"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           FractionBox["3", "10"], " ", 
           RowBox[{"(", 
            RowBox[{"51", "+", 
             SqrtBox["2281"]}], ")"}]}]}], ")"}], " ", "B"}]}], "\[Equal]", 
      "0"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Map", "[", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", " ", 
        RowBox[{"#", " ", ",", " ", 
         RowBox[{"{", 
          RowBox[{"A", ",", "B"}], "}"}]}], " ", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", "&"}], " ", ")"}], " ", 
    ",", "system"}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "::", "\<\"svars\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Equations may not give solutions for all \\\"solve\\\" \
variables. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Solve::svars\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "::", "\<\"svars\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Equations may not give solutions for all \\\"solve\\\" \
variables. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Solve::svars\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "143"}], "+", 
         RowBox[{"3", " ", 
          SqrtBox["2281"]}]}], ")"}], " ", "B"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "51"}], "+", 
         SqrtBox["2281"]}], ")"}]}]]}]}], ",", 
   RowBox[{"A", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"143", "+", 
         RowBox[{"3", " ", 
          SqrtBox["2281"]}]}], ")"}], " ", "B"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"51", "+", 
         SqrtBox["2281"]}], ")"}]}]]}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{815, 821},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[1309, 36, 219, 7, 46, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1553, 47, 376, 10, 99, "Input"],
Cell[1932, 59, 72, 0, 31, "Output"],
Cell[2007, 61, 357, 7, 52, "Output"]
}, Open  ]],
Cell[2379, 71, 111, 2, 77, "Input"],
Cell[CellGroupData[{
Cell[2515, 77, 158, 4, 55, "Input"],
Cell[2676, 83, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2809, 90, 153, 5, 86, "Input"],
Cell[2965, 97, 400, 14, 46, "Output"],
Cell[3368, 113, 431, 16, 46, "Output"],
Cell[3802, 131, 995, 34, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4834, 170, 125, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[4984, 176, 99, 2, 32, "Input"],
Cell[5086, 180, 83, 2, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5218, 188, 94, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[5337, 193, 309, 10, 55, "Input"],
Cell[5649, 205, 870, 27, 100, "Output"],
Cell[6522, 234, 3072, 90, 172, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9643, 330, 144, 2, 38, "Subsection"],
Cell[CellGroupData[{
Cell[9812, 336, 2762, 79, 107, "Input"],
Cell[12577, 417, 934, 28, 70, "Output"],
Cell[13514, 447, 1574, 45, 68, "Output"],
Cell[15091, 494, 880, 27, 70, "Output"],
Cell[15974, 523, 1581, 45, 68, "Output"],
Cell[17558, 570, 924, 28, 70, "Output"],
Cell[18485, 600, 1270, 39, 55, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19804, 645, 109, 1, 38, "Subsection"],
Cell[CellGroupData[{
Cell[19938, 650, 60, 0, 27, "Input"],
Cell[20001, 652, 696, 22, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20734, 679, 54, 0, 27, "Input"],
Cell[20791, 681, 897, 29, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21725, 715, 111, 3, 42, "Input"],
Cell[21839, 720, 838, 26, 46, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22726, 752, 114, 1, 38, "Subsection"],
Cell[CellGroupData[{
Cell[22865, 757, 86, 2, 27, "Input"],
Cell[22954, 761, 563, 19, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23554, 785, 54, 0, 27, "Input"],
Cell[23611, 787, 1174, 37, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24822, 829, 111, 3, 42, "Input"],
Cell[24936, 834, 1080, 34, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26065, 874, 57, 0, 38, "Subsection"],
Cell[CellGroupData[{
Cell[26147, 878, 219, 5, 43, "Input"],
Cell[26369, 885, 72, 1, 27, "Output"],
Cell[26444, 888, 660, 23, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27141, 916, 342, 9, 27, "Input"],
Cell[27486, 927, 219, 8, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27742, 940, 646, 20, 48, "Input"],
Cell[28391, 962, 422, 14, 48, "Output"],
Cell[28816, 978, 172, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29025, 989, 64, 1, 27, "Input"],
Cell[29092, 992, 172, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29301, 1003, 313, 9, 27, "Input"],
Cell[29617, 1014, 2471, 72, 105, "Output"]
}, Open  ]],
Cell[32103, 1089, 27, 0, 27, "Input"],
Cell[CellGroupData[{
Cell[32155, 1093, 591, 16, 27, "Input"],
Cell[32749, 1111, 441, 16, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33227, 1132, 94, 2, 43, "Input"],
Cell[33324, 1136, 223, 7, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33584, 1148, 383, 11, 27, "Input"],
Cell[33970, 1161, 2033, 70, 81, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36040, 1236, 415, 13, 27, "Input"],
Cell[36458, 1251, 329, 7, 20, "Message"],
Cell[36790, 1260, 329, 7, 20, "Message"],
Cell[37122, 1269, 763, 28, 57, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

